/* -*- mode: C++; c-basic-offset: 2; indent-tabs-mode: nil -*- */
/*
 *  Main authors:
 *     Christian Schulte <schulte@gecode.org>
 *
 *  Copyright:
 *     Christian Schulte, 2019
 *
 *  This file is part of Gecode, the generic constraint
 *  development environment:
 *     http://www.gecode.org
 *
 *  Permission is hereby granted, free of charge, to any person obtaining
 *  a copy of this software and associated documentation files (the
 *  "Software"), to deal in the Software without restriction, including
 *  without limitation the rights to use, copy, modify, merge, publish,
 *  distribute, sublicense, and/or sell copies of the Software, and to
 *  permit persons to whom the Software is furnished to do so, subject to
 *  the following conditions:
 *
 *  The above copyright notice and this permission notice shall be
 *  included in all copies or substantial portions of the Software.
 *
 *  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 *  EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 *  MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 *  NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 *  LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 *  OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 *  WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 *
 */

namespace {

  /*
   * These instances are contributed to the OR-Library by
   * Dirk C. Mattfeld (email dirk@uni-bremen.de) and 
   * Rob J.M. Vaessens (email robv@win.tue.nl).
   *
   * o abz5-abz9 are from
   *   J. Adams, E. Balas and D. Zawack (1988),
   *   The shifting bottleneck procedure for job shop scheduling,
   *   Management Science 34, 391-401.
   * o ft06, ft10, and ft20 are from 
   *   H. Fisher, G.L. Thompson (1963), 
   *   Probabilistic learning combinations of local job-shop scheduling rules, 
   *     J.F. Muth, G.L. Thompson (eds.), 
   *     Industrial Scheduling, 
   *     Prentice Hall, Englewood Cliffs, New Jersey, 
   *   225-251.
   * o la01-la40 are from 
   *   S. Lawrence (1984),
   *   Resource constrained project scheduling: an experimental investigation of 
   *     heuristic scheduling techniques (Supplement), 
   *   Graduate School of Industrial Administration,
   *   Carnegie-Mellon University, Pittsburgh, Pennsylvania.
   * o orb01-orb10 are from 
   *   D. Applegate, W. Cook (1991),
   *   A computational study of the job-shop scheduling instance,
   *   ORSA Journal on Computing 3, 149-156. 
   *   (they were generated in Bonn in 1986)
   * o swv01-swv20 are from 
   *   R.H. Storer, S.D. Wu, R. Vaccari (1992),
   *   New search spaces for sequencing instances with application to job shop 
   *     scheduling, 
   *   Management Science 38, 1495-1509.
   * o yn1-yn4 are from 
   *   T. Yamada, R. Nakano (1992),
   *   A genetic algorithm applicable to large-scale job-shop instances,
   *     R. Manner, B. Manderick (eds.),
   *     Parallel instance solving from nature 2,
   *     North-Holland, Amsterdam, 
   *   281-290.
   *
   * The following are from E. Taillard, "Benchmarks for basic scheduling problems", 
   * EJOR 64(2):278-285, 1993.
   * o taillard-n-m-i: n jobs, m machines, i-th instance
   *   the machine numbers are decremented by one to start with machine 0.
   *
   */

  // Adams, Balas, and Zawack 10x10 instance (Table 1, instance 5)
  const int abz5[] = {
    10, 10, // Number of jobs and machines
    4, 88, 8, 68, 6, 94, 5, 99, 1, 67, 2, 89, 9, 77, 7, 99, 0, 86, 3, 92, 
    5, 72, 3, 50, 6, 69, 4, 75, 2, 94, 8, 66, 0, 92, 1, 82, 7, 94, 9, 63, 
    9, 83, 8, 61, 0, 83, 1, 65, 6, 64, 5, 85, 7, 78, 4, 85, 2, 55, 3, 77, 
    7, 94, 2, 68, 1, 61, 4, 99, 3, 54, 6, 75, 5, 66, 0, 76, 9, 63, 8, 67, 
    3, 69, 4, 88, 9, 82, 8, 95, 0, 99, 2, 67, 6, 95, 5, 68, 7, 67, 1, 86, 
    1, 99, 4, 81, 5, 64, 6, 66, 8, 80, 2, 80, 7, 69, 9, 62, 3, 79, 0, 88, 
    7, 50, 1, 86, 4, 97, 3, 96, 0, 95, 8, 97, 2, 66, 5, 99, 6, 52, 9, 71, 
    4, 98, 6, 73, 3, 82, 2, 51, 1, 71, 5, 94, 7, 85, 0, 62, 8, 95, 9, 79, 
    0, 94, 6, 71, 3, 81, 7, 85, 1, 66, 2, 90, 4, 76, 5, 58, 8, 93, 9, 97, 
    3, 50, 0, 59, 1, 82, 8, 67, 7, 56, 9, 96, 6, 58, 4, 81, 5, 59, 2, 96
  };
  // Adams, and Zawack 10x10 instance (Table 1, instance 6)
  const int abz6[] = {
    10, 10, // Number of jobs and machines
    7, 62, 8, 24, 5, 25, 3, 84, 4, 47, 6, 38, 2, 82, 0, 93, 9, 24, 1, 66, 
    5, 47, 2, 97, 8, 92, 9, 22, 1, 93, 4, 29, 7, 56, 3, 80, 0, 78, 6, 67, 
    1, 45, 7, 46, 6, 22, 2, 26, 9, 38, 0, 69, 4, 40, 3, 33, 8, 75, 5, 96, 
    4, 85, 8, 76, 5, 68, 9, 88, 3, 36, 6, 75, 2, 56, 1, 35, 0, 77, 7, 85, 
    8, 60, 9, 20, 7, 25, 3, 63, 4, 81, 0, 52, 1, 30, 5, 98, 6, 54, 2, 86, 
    3, 87, 9, 73, 5, 51, 2, 95, 4, 65, 1, 86, 6, 22, 8, 58, 0, 80, 7, 65, 
    5, 81, 2, 53, 7, 57, 6, 71, 9, 81, 0, 43, 4, 26, 8, 54, 3, 58, 1, 69, 
    4, 20, 6, 86, 5, 21, 8, 79, 9, 62, 2, 34, 0, 27, 1, 81, 7, 30, 3, 46, 
    9, 68, 6, 66, 5, 98, 8, 86, 7, 66, 0, 56, 3, 82, 1, 95, 4, 47, 2, 78, 
    0, 30, 3, 50, 7, 34, 2, 58, 1, 77, 5, 34, 8, 84, 4, 40, 9, 46, 6, 44
  };
  // Adams, Balas, and Zawack 15 x 20 instance (Table 1, instance 7)
  const int abz7[] = {
    20, 15, // Number of jobs and machines
    2, 24, 3, 12, 9, 17, 4, 27, 0, 21, 6, 25, 8, 27, 7, 26, 1, 30, 5, 31, 11, 18, 14, 16, 13, 39, 10, 19, 12, 26, 
    6, 30, 3, 15, 12, 20, 11, 19, 1, 24, 13, 15, 10, 28, 2, 36, 5, 26, 7, 15, 0, 11, 8, 23, 14, 20, 9, 26, 4, 28, 
    6, 35, 0, 22, 13, 23, 7, 32, 2, 20, 3, 12, 12, 19, 10, 23, 9, 17, 1, 14, 5, 16, 11, 29, 8, 16, 4, 22, 14, 22, 
    9, 20, 6, 29, 1, 19, 7, 14, 12, 33, 4, 30, 0, 32, 5, 21, 11, 29, 10, 24, 14, 25, 2, 29, 3, 13, 8, 20, 13, 18, 
    11, 23, 13, 20, 1, 28, 6, 32, 7, 16, 5, 18, 8, 24, 9, 23, 3, 24, 10, 34, 2, 24, 0, 24, 14, 28, 12, 15, 4, 18, 
    8, 24, 11, 19, 14, 21, 1, 33, 7, 34, 6, 35, 5, 40, 10, 36, 3, 23, 2, 26, 4, 15, 9, 28, 13, 38, 12, 13, 0, 25, 
    13, 27, 3, 30, 6, 21, 8, 19, 12, 12, 4, 27, 2, 39, 9, 13, 14, 12, 5, 36, 10, 21, 11, 17, 1, 29, 0, 17, 7, 33, 
    5, 27, 4, 19, 6, 29, 9, 20, 3, 21, 10, 40, 8, 14, 14, 39, 13, 39, 2, 27, 1, 36, 12, 12, 11, 37, 7, 22, 0, 13, 
    13, 32, 11, 29, 8, 24, 3, 27, 5, 40, 4, 21, 9, 26, 0, 27, 14, 27, 6, 16, 2, 21, 10, 13, 7, 28, 12, 28, 1, 32, 
    12, 35, 1, 11, 5, 39, 14, 18, 7, 23, 0, 34, 3, 24, 13, 11, 8, 30, 11, 31, 4, 15, 10, 15, 2, 28, 9, 26, 6, 33, 
    10, 28, 5, 37, 12, 29, 1, 31, 7, 25, 8, 13, 14, 14, 4, 20, 3, 27, 9, 25, 13, 31, 11, 14, 6, 25, 2, 39, 0, 36, 
    0, 22, 11, 25, 5, 28, 13, 35, 4, 31, 8, 21, 9, 20, 14, 19, 2, 29, 7, 32, 10, 18, 1, 18, 3, 11, 12, 17, 6, 15, 
    12, 39, 5, 32, 2, 36, 8, 14, 3, 28, 13, 37, 0, 38, 6, 20, 7, 19, 11, 12, 14, 22, 1, 36, 4, 15, 9, 32, 10, 16, 
    8, 28, 1, 29, 14, 40, 12, 23, 4, 34, 5, 33, 6, 27, 10, 17, 0, 20, 7, 28, 11, 21, 2, 21, 13, 20, 9, 33, 3, 27, 
    9, 21, 14, 34, 3, 30, 12, 38, 0, 11, 11, 16, 2, 14, 5, 14, 1, 34, 8, 33, 4, 23, 13, 40, 10, 12, 6, 23, 7, 27, 
    9, 13, 14, 40, 7, 36, 4, 17, 0, 13, 5, 33, 8, 25, 13, 24, 10, 23, 3, 36, 2, 29, 1, 18, 11, 13, 6, 33, 12, 13, 
    3, 25, 5, 15, 2, 28, 12, 40, 7, 39, 1, 31, 8, 35, 6, 31, 11, 36, 4, 12, 10, 33, 14, 19, 9, 16, 13, 27, 0, 21, 
    12, 22, 10, 14, 0, 12, 2, 20, 5, 12, 1, 18, 11, 17, 8, 39, 14, 31, 3, 31, 7, 32, 9, 20, 13, 29, 4, 13, 6, 26, 
    5, 18, 10, 30, 7, 38, 14, 22, 13, 15, 11, 20, 9, 16, 3, 17, 1, 12, 2, 13, 12, 40, 6, 17, 8, 30, 4, 38, 0, 13, 
    9, 31, 8, 39, 12, 27, 1, 14, 5, 33, 3, 31, 11, 22, 13, 36, 0, 16, 7, 11, 14, 14, 4, 29, 6, 28, 2, 22, 10, 17
  };
  // Adams, Balas, and Zawack 15 x 20 instance (Table 1, instance 8)
  const int abz8[] = {
    20, 15, // Number of jobs and machines
    0, 19, 9, 33, 2, 32, 13, 18, 10, 39, 8, 34, 6, 25, 4, 36, 11, 40, 12, 33, 1, 31, 14, 30, 3, 34, 5, 26, 7, 13, 
    9, 11, 10, 22, 14, 19, 5, 12, 4, 25, 6, 38, 0, 29, 7, 39, 13, 19, 11, 22, 1, 23, 3, 20, 2, 40, 12, 19, 8, 26, 
    3, 25, 8, 17, 11, 24, 13, 40, 10, 32, 14, 16, 5, 39, 9, 19, 0, 24, 1, 39, 4, 17, 2, 35, 7, 38, 6, 20, 12, 31, 
    14, 22, 3, 36, 2, 34, 12, 17, 4, 30, 13, 12, 1, 13, 6, 25, 9, 12, 7, 18, 10, 31, 0, 39, 5, 40, 8, 26, 11, 37, 
    12, 32, 14, 15, 1, 35, 7, 13, 8, 32, 11, 23, 6, 22, 4, 21, 0, 38, 2, 38, 3, 40, 10, 31, 5, 11, 13, 37, 9, 16, 
    10, 23, 12, 38, 8, 11, 14, 27, 9, 11, 6, 25, 5, 14, 4, 12, 2, 27, 11, 26, 7, 29, 3, 28, 13, 21, 0, 20, 1, 30, 
    6, 39, 8, 38, 0, 15, 12, 27, 10, 22, 9, 27, 2, 32, 4, 40, 3, 12, 13, 20, 14, 21, 11, 22, 5, 17, 7, 38, 1, 27, 
    11, 11, 13, 24, 10, 38, 8, 15, 9, 19, 14, 13, 5, 30, 0, 26, 2, 29, 6, 33, 12, 21, 1, 15, 3, 21, 4, 28, 7, 33, 
    8, 20, 6, 17, 5, 26, 3, 34, 9, 23, 0, 16, 2, 18, 4, 35, 12, 24, 10, 16, 11, 26, 7, 12, 14, 13, 13, 27, 1, 19, 
    1, 18, 7, 37, 14, 27, 9, 40, 5, 40, 6, 17, 8, 22, 3, 17, 10, 30, 0, 38, 4, 21, 12, 32, 11, 24, 13, 24, 2, 30, 
    11, 19, 0, 22, 13, 36, 6, 18, 5, 22, 3, 17, 14, 35, 10, 34, 7, 23, 8, 19, 2, 29, 1, 22, 12, 17, 4, 33, 9, 39, 
    6, 32, 3, 22, 12, 24, 5, 13, 4, 13, 1, 11, 0, 11, 13, 25, 8, 13, 2, 15, 10, 33, 11, 17, 14, 16, 9, 38, 7, 24, 
    14, 16, 13, 16, 1, 37, 8, 25, 2, 26, 3, 11, 9, 34, 4, 14, 0, 20, 6, 36, 12, 12, 5, 29, 10, 25, 7, 32, 11, 12, 
    8, 20, 10, 24, 11, 27, 9, 38, 5, 34, 12, 39, 7, 33, 4, 37, 2, 31, 13, 15, 14, 34, 3, 33, 6, 26, 1, 36, 0, 14, 
    8, 31, 0, 17, 9, 13, 1, 21, 10, 17, 7, 19, 13, 14, 3, 40, 5, 32, 11, 25, 2, 34, 14, 23, 6, 13, 12, 40, 4, 26, 
    8, 38, 12, 17, 3, 14, 13, 17, 4, 12, 1, 35, 6, 35, 0, 19, 10, 36, 7, 19, 9, 29, 2, 31, 5, 26, 11, 35, 14, 37, 
    14, 20, 3, 16, 0, 33, 10, 14, 5, 27, 7, 31, 8, 16, 6, 31, 12, 28, 9, 37, 4, 37, 2, 29, 11, 38, 1, 30, 13, 36, 
    11, 18, 3, 37, 14, 16, 6, 15, 8, 14, 12, 11, 13, 32, 5, 12, 1, 11, 10, 29, 7, 19, 4, 12, 9, 18, 2, 26, 0, 39, 
    11, 11, 2, 11, 12, 22, 9, 35, 14, 20, 7, 31, 4, 19, 3, 39, 5, 28, 6, 33, 10, 34, 1, 38, 0, 20, 13, 17, 8, 28, 
    2, 12, 12, 25, 5, 23, 8, 21, 6, 27, 9, 30, 14, 23, 11, 39, 3, 26, 13, 34, 7, 17, 1, 24, 4, 12, 0, 19, 10, 36
  };
  // Adams, Balas, and Zawack 15 x 20 instance (Table 1, instance 9)
  const int abz9[] = {
    20, 15, // Number of jobs and machines
    6, 14, 5, 21, 8, 13, 4, 11, 1, 11, 14, 35, 13, 20, 11, 17, 10, 18, 12, 11, 2, 23, 3, 13, 0, 15, 7, 11, 9, 35, 
    1, 35, 5, 31, 0, 13, 3, 26, 6, 14, 9, 17, 7, 38, 12, 20, 10, 19, 13, 12, 8, 16, 4, 34, 11, 15, 14, 12, 2, 14, 
    0, 30, 4, 35, 2, 40, 10, 35, 6, 30, 14, 23, 8, 29, 13, 37, 7, 38, 3, 40, 9, 26, 12, 11, 1, 40, 11, 36, 5, 17, 
    7, 40, 5, 18, 4, 12, 8, 23, 0, 23, 9, 14, 13, 16, 12, 14, 10, 23, 3, 12, 6, 16, 14, 32, 1, 40, 11, 25, 2, 29, 
    2, 35, 3, 15, 12, 31, 11, 28, 6, 32, 4, 30, 10, 27, 7, 29, 0, 38, 13, 11, 1, 23, 14, 17, 5, 27, 9, 37, 8, 29, 
    5, 33, 3, 33, 6, 19, 12, 40, 10, 19, 0, 33, 13, 26, 2, 31, 11, 28, 7, 36, 4, 38, 1, 21, 14, 25, 9, 40, 8, 35, 
    13, 25, 0, 32, 11, 33, 12, 18, 4, 32, 6, 28, 5, 15, 3, 35, 9, 14, 2, 34, 7, 23, 10, 32, 1, 17, 14, 26, 8, 19, 
    2, 16, 12, 33, 9, 34, 11, 30, 13, 40, 8, 12, 14, 26, 5, 26, 6, 15, 3, 21, 1, 40, 4, 32, 0, 14, 7, 30, 10, 35, 
    2, 17, 10, 16, 14, 20, 6, 24, 8, 26, 3, 36, 12, 22, 0, 14, 13, 11, 9, 20, 7, 23, 1, 29, 11, 23, 4, 15, 5, 40, 
    4, 27, 9, 37, 3, 40, 11, 14, 13, 25, 7, 30, 0, 34, 2, 11, 5, 15, 12, 32, 1, 36, 10, 12, 14, 28, 8, 31, 6, 23, 
    13, 25, 0, 22, 3, 27, 8, 14, 5, 25, 6, 20, 14, 18, 7, 14, 1, 19, 2, 17, 4, 27, 9, 22, 12, 22, 11, 27, 10, 21, 
    14, 34, 10, 15, 0, 22, 3, 29, 13, 34, 6, 40, 7, 17, 2, 32, 12, 20, 5, 39, 4, 31, 11, 16, 1, 37, 8, 33, 9, 13, 
    6, 12, 12, 27, 4, 17, 2, 24, 8, 11, 5, 19, 14, 11, 3, 17, 9, 25, 1, 11, 11, 31, 13, 33, 7, 31, 10, 12, 0, 22, 
    5, 22, 14, 15, 0, 16, 8, 32, 7, 20, 4, 22, 9, 11, 13, 19, 1, 30, 12, 33, 6, 29, 11, 18, 3, 34, 10, 32, 2, 18, 
    5, 27, 3, 26, 10, 28, 6, 37, 4, 18, 12, 12, 11, 11, 13, 26, 7, 27, 9, 40, 14, 19, 1, 24, 2, 18, 0, 12, 8, 34, 
    8, 15, 5, 28, 9, 25, 6, 32, 1, 13, 7, 38, 11, 11, 2, 34, 4, 25, 0, 20, 10, 32, 3, 23, 12, 14, 14, 16, 13, 20, 
    1, 15, 4, 13, 8, 37, 3, 14, 10, 22, 5, 24, 12, 26, 7, 22, 9, 34, 14, 22, 11, 19, 13, 32, 0, 29, 2, 13, 6, 35, 
    7, 36, 5, 33, 13, 28, 9, 20, 10, 30, 4, 33, 14, 29, 0, 34, 3, 22, 11, 12, 6, 30, 8, 12, 1, 35, 2, 13, 12, 35, 
    14, 26, 11, 31, 5, 35, 2, 38, 13, 19, 10, 35, 4, 27, 8, 29, 3, 39, 9, 13, 6, 14, 7, 26, 0, 17, 1, 22, 12, 15, 
    1, 36, 7, 34, 11, 33, 8, 17, 14, 38, 6, 39, 5, 16, 3, 27, 13, 29, 2, 16, 0, 16, 4, 19, 9, 40, 12, 35, 10, 39
  };

  // Fisher and Thompson 6x6 instance, alternate name (mt06)
  const int ft06[] = {
    6, 6, // Number of jobs and machines
    2, 1, 0, 3, 1, 6, 3, 7, 5, 3, 4, 6, 
    1, 8, 2, 5, 4, 10, 5, 10, 0, 10, 3, 4, 
    2, 5, 3, 4, 5, 8, 0, 9, 1, 1, 4, 7, 
    1, 5, 0, 5, 2, 5, 3, 3, 4, 8, 5, 9, 
    2, 9, 1, 3, 4, 5, 5, 4, 0, 3, 3, 1, 
    1, 3, 3, 3, 5, 9, 0, 10, 4, 4, 2, 1
  };
  // Fisher and Thompson 10x10 instance, alternate name (mt10)
  const int ft10[] = {
    10, 10, // Number of jobs and machines
    0, 29, 1, 78, 2, 9, 3, 36, 4, 49, 5, 11, 6, 62, 7, 56, 8, 44, 9, 21, 
    0, 43, 2, 90, 4, 75, 9, 11, 3, 69, 1, 28, 6, 46, 5, 46, 7, 72, 8, 30, 
    1, 91, 0, 85, 3, 39, 2, 74, 8, 90, 5, 10, 7, 12, 6, 89, 9, 45, 4, 33, 
    1, 81, 2, 95, 0, 71, 4, 99, 6, 9, 8, 52, 7, 85, 3, 98, 9, 22, 5, 43, 
    2, 14, 0, 6, 1, 22, 5, 61, 3, 26, 4, 69, 8, 21, 7, 49, 9, 72, 6, 53, 
    2, 84, 1, 2, 5, 52, 3, 95, 8, 48, 9, 72, 0, 47, 6, 65, 4, 6, 7, 25, 
    1, 46, 0, 37, 3, 61, 2, 13, 6, 32, 5, 21, 9, 32, 8, 89, 7, 30, 4, 55, 
    2, 31, 0, 86, 1, 46, 5, 74, 4, 32, 6, 88, 8, 19, 9, 48, 7, 36, 3, 79, 
    0, 76, 1, 69, 3, 76, 5, 51, 2, 85, 9, 11, 6, 40, 7, 89, 4, 26, 8, 74, 
    1, 85, 0, 13, 2, 61, 6, 7, 8, 64, 9, 76, 5, 47, 3, 52, 4, 90, 7, 45
  };
  // Fisher and Thompson 20x5 instance, alternate name (mt20)
  const int ft20[] = {
    20, 5, // Number of jobs and machines
    0, 29, 1, 9, 2, 49, 3, 62, 4, 44, 
    0, 43, 1, 75, 3, 69, 2, 46, 4, 72, 
    1, 91, 0, 39, 2, 90, 4, 12, 3, 45, 
    1, 81, 0, 71, 4, 9, 2, 85, 3, 22, 
    2, 14, 1, 22, 0, 26, 3, 21, 4, 72, 
    2, 84, 1, 52, 4, 48, 0, 47, 3, 6, 
    1, 46, 0, 61, 2, 32, 3, 32, 4, 30, 
    2, 31, 1, 46, 0, 32, 3, 19, 4, 36, 
    0, 76, 3, 76, 2, 85, 1, 40, 4, 26, 
    1, 85, 2, 61, 0, 64, 3, 47, 4, 90, 
    1, 78, 3, 36, 0, 11, 4, 56, 2, 21, 
    2, 90, 0, 11, 1, 28, 3, 46, 4, 30, 
    0, 85, 2, 74, 1, 10, 3, 89, 4, 33, 
    2, 95, 0, 99, 1, 52, 3, 98, 4, 43, 
    0, 6, 1, 61, 4, 69, 2, 49, 3, 53, 
    1, 2, 0, 95, 3, 72, 4, 65, 2, 25, 
    0, 37, 2, 13, 1, 21, 3, 89, 4, 55, 
    0, 86, 1, 74, 4, 88, 2, 48, 3, 79, 
    1, 69, 2, 51, 0, 11, 3, 89, 4, 74, 
    0, 13, 1, 7, 2, 76, 3, 52, 4, 45
  };

  // Lawrence 10x5 instance (Table 3, instance 1); also called (setf1) or (F1)
  const int la01[] = {
    10, 5, // Number of jobs and machines
    1, 21, 0, 53, 4, 95, 3, 55, 2, 34, 
    0, 21, 3, 52, 4, 16, 2, 26, 1, 71, 
    3, 39, 4, 98, 1, 42, 2, 31, 0, 12, 
    1, 77, 0, 55, 4, 79, 2, 66, 3, 77, 
    0, 83, 3, 34, 2, 64, 1, 19, 4, 37, 
    1, 54, 2, 43, 4, 79, 0, 92, 3, 62, 
    3, 69, 4, 77, 1, 87, 2, 87, 0, 93, 
    2, 38, 0, 60, 1, 41, 3, 24, 4, 83, 
    3, 17, 1, 49, 4, 25, 0, 44, 2, 98, 
    4, 77, 3, 79, 2, 43, 1, 75, 0, 96
  };
  // Lawrence 10x5 instance (Table 3, instance 2); also called (setf2) or (F2)
  const int la02[] = {
    10, 5, // Number of jobs and machines
    0, 20, 3, 87, 1, 31, 4, 76, 2, 17, 
    4, 25, 2, 32, 0, 24, 1, 18, 3, 81, 
    1, 72, 2, 23, 4, 28, 0, 58, 3, 99, 
    2, 86, 1, 76, 4, 97, 0, 45, 3, 90, 
    4, 27, 0, 42, 3, 48, 2, 17, 1, 46, 
    1, 67, 0, 98, 4, 48, 3, 27, 2, 62, 
    4, 28, 1, 12, 3, 19, 0, 80, 2, 50, 
    1, 63, 0, 94, 2, 98, 3, 50, 4, 80, 
    4, 14, 0, 75, 2, 50, 1, 41, 3, 55, 
    4, 72, 2, 18, 1, 37, 3, 79, 0, 61
  };
  // Lawrence 10x5 instance (Table 3, instance 3); also called (setf3) or (F3)
  const int la03[] = {
    10, 5, // Number of jobs and machines
    1, 23, 2, 45, 0, 82, 4, 84, 3, 38, 
    2, 21, 1, 29, 0, 18, 4, 41, 3, 50, 
    2, 38, 3, 54, 4, 16, 0, 52, 1, 52, 
    4, 37, 0, 54, 2, 74, 1, 62, 3, 57, 
    4, 57, 0, 81, 1, 61, 3, 68, 2, 30, 
    4, 81, 0, 79, 1, 89, 2, 89, 3, 11, 
    3, 33, 2, 20, 0, 91, 4, 20, 1, 66, 
    4, 24, 1, 84, 0, 32, 2, 55, 3, 8, 
    4, 56, 0, 7, 3, 54, 2, 64, 1, 39, 
    4, 40, 1, 83, 0, 19, 2, 8, 3, 7
  };
  // Lawrence 10x5 instance (Table 3, instance 4); also called (setf4) or (F4)
  const int la04[] = {
    10, 5, // Number of jobs and machines
    0, 12, 2, 94, 3, 92, 4, 91, 1, 7, 
    1, 19, 3, 11, 4, 66, 2, 21, 0, 87, 
    1, 14, 0, 75, 3, 13, 4, 16, 2, 20, 
    2, 95, 4, 66, 0, 7, 3, 7, 1, 77, 
    1, 45, 3, 6, 4, 89, 0, 15, 2, 34, 
    3, 77, 2, 20, 0, 76, 4, 88, 1, 53, 
    2, 74, 1, 88, 0, 52, 3, 27, 4, 9, 
    1, 88, 3, 69, 0, 62, 4, 98, 2, 52, 
    2, 61, 4, 9, 0, 62, 1, 52, 3, 90, 
    2, 54, 4, 5, 3, 59, 1, 15, 0, 88
  };
  // Lawrence 10x5 instance (Table 3, instance 5); also called (setf5) or (F5)
  const int la05[] = {
    10, 5, // Number of jobs and machines
    1, 72, 0, 87, 4, 95, 2, 66, 3, 60, 
    4, 5, 3, 35, 0, 48, 2, 39, 1, 54, 
    1, 46, 3, 20, 2, 21, 0, 97, 4, 55, 
    0, 59, 3, 19, 4, 46, 1, 34, 2, 37, 
    4, 23, 2, 73, 3, 25, 1, 24, 0, 28, 
    3, 28, 0, 45, 4, 5, 1, 78, 2, 83, 
    0, 53, 3, 71, 1, 37, 4, 29, 2, 12, 
    4, 12, 2, 87, 3, 33, 1, 55, 0, 38, 
    2, 49, 3, 83, 1, 40, 0, 48, 4, 7, 
    2, 65, 3, 17, 0, 90, 4, 27, 1, 23
  };
  // Lawrence 15x5 instance (Table 4, instance 1); also called (setg1) or (G1)
  const int la06[] = {
    15, 5, // Number of jobs and machines
    1, 21, 2, 34, 4, 95, 0, 53, 3, 55, 
    3, 52, 4, 16, 1, 71, 2, 26, 0, 21, 
    2, 31, 0, 12, 1, 42, 3, 39, 4, 98, 
    3, 77, 1, 77, 4, 79, 0, 55, 2, 66, 
    4, 37, 3, 34, 2, 64, 1, 19, 0, 83, 
    2, 43, 1, 54, 0, 92, 3, 62, 4, 79, 
    0, 93, 3, 69, 1, 87, 4, 77, 2, 87, 
    0, 60, 1, 41, 2, 38, 4, 83, 3, 24, 
    2, 98, 3, 17, 4, 25, 0, 44, 1, 49, 
    0, 96, 4, 77, 3, 79, 1, 75, 2, 43, 
    4, 28, 2, 35, 0, 95, 3, 76, 1, 7, 
    0, 61, 4, 10, 2, 95, 1, 9, 3, 35, 
    4, 59, 3, 16, 1, 91, 2, 59, 0, 46, 
    4, 43, 1, 52, 0, 28, 2, 27, 3, 50, 
    0, 87, 1, 45, 2, 39, 4, 9, 3, 41
  };
  // Lawrence 15x5 instance (Table 4, instance 2); also called (setg2) or (G2)
  const int la07[] = {
    15, 5, // Number of jobs and machines
    0, 47, 4, 57, 1, 71, 3, 96, 2, 14, 
    0, 75, 1, 60, 4, 22, 3, 79, 2, 65, 
    3, 32, 0, 33, 2, 69, 1, 31, 4, 58, 
    0, 44, 1, 34, 4, 51, 3, 58, 2, 47, 
    3, 29, 1, 44, 0, 62, 2, 17, 4, 8, 
    1, 15, 2, 40, 0, 97, 4, 38, 3, 66, 
    2, 58, 1, 39, 0, 57, 4, 20, 3, 50, 
    2, 57, 3, 32, 4, 87, 0, 63, 1, 21, 
    4, 56, 0, 84, 2, 90, 1, 85, 3, 61, 
    4, 15, 0, 20, 1, 67, 3, 30, 2, 70, 
    4, 84, 0, 82, 1, 23, 2, 45, 3, 38, 
    3, 50, 2, 21, 0, 18, 4, 41, 1, 29, 
    4, 16, 1, 52, 0, 52, 2, 38, 3, 54, 
    4, 37, 0, 54, 3, 57, 2, 74, 1, 62, 
    4, 57, 1, 61, 0, 81, 2, 30, 3, 68
  };
  // Lawrence 15x5 instance (Table 4, instance 3); also called (setg3) or (G3)
  const int la08[] = {
    15, 5, // Number of jobs and machines
    3, 92, 2, 94, 0, 12, 4, 91, 1, 7, 
    2, 21, 1, 19, 0, 87, 3, 11, 4, 66, 
    1, 14, 3, 13, 0, 75, 4, 16, 2, 20, 
    2, 95, 4, 66, 0, 7, 1, 77, 3, 7, 
    2, 34, 4, 89, 3, 6, 1, 45, 0, 15, 
    4, 88, 3, 77, 2, 20, 1, 53, 0, 76, 
    4, 9, 3, 27, 0, 52, 1, 88, 2, 74, 
    3, 69, 2, 52, 0, 62, 1, 88, 4, 98, 
    3, 90, 0, 62, 4, 9, 2, 61, 1, 52, 
    4, 5, 2, 54, 3, 59, 0, 88, 1, 15, 
    0, 41, 1, 50, 4, 78, 3, 53, 2, 23, 
    0, 38, 4, 72, 2, 91, 3, 68, 1, 71, 
    0, 45, 3, 95, 4, 52, 2, 25, 1, 6, 
    3, 30, 1, 66, 0, 23, 4, 36, 2, 17, 
    2, 95, 0, 71, 3, 76, 1, 8, 4, 88
  };
  // Lawrence 15x5 instance (Table 4, instance 4); also called (setg4) or (G4)
  const int la09[] = {
    15, 5, // Number of jobs and machines
    1, 66, 3, 85, 2, 84, 0, 62, 4, 19, 
    3, 59, 1, 64, 2, 46, 4, 13, 0, 25, 
    4, 88, 3, 80, 1, 73, 2, 53, 0, 41, 
    0, 14, 1, 67, 2, 57, 3, 74, 4, 47, 
    0, 84, 4, 64, 2, 41, 3, 84, 1, 78, 
    0, 63, 3, 28, 1, 46, 2, 26, 4, 52, 
    3, 10, 2, 17, 4, 73, 1, 11, 0, 64, 
    2, 67, 1, 97, 3, 95, 4, 38, 0, 85, 
    2, 95, 4, 46, 0, 59, 1, 65, 3, 93, 
    2, 43, 4, 85, 3, 32, 1, 85, 0, 60, 
    4, 49, 3, 41, 2, 61, 0, 66, 1, 90, 
    1, 17, 0, 23, 3, 70, 4, 99, 2, 49, 
    4, 40, 3, 73, 0, 73, 1, 98, 2, 68, 
    3, 57, 1, 9, 2, 7, 0, 13, 4, 98, 
    0, 37, 1, 85, 2, 17, 4, 79, 3, 41
  };
  // Lawrence 15x5 instance (Table 4, instance 5); also called (setg5) or (G5)
  const int la10[] = {
    15, 5, // Number of jobs and machines
    1, 58, 2, 44, 3, 5, 0, 9, 4, 58, 
    1, 89, 0, 97, 4, 96, 3, 77, 2, 84, 
    0, 77, 1, 87, 2, 81, 4, 39, 3, 85, 
    3, 57, 1, 21, 2, 31, 0, 15, 4, 73, 
    2, 48, 0, 40, 1, 49, 3, 70, 4, 71, 
    3, 34, 4, 82, 2, 80, 0, 10, 1, 22, 
    1, 91, 4, 75, 0, 55, 2, 17, 3, 7, 
    2, 62, 3, 47, 1, 72, 4, 35, 0, 11, 
    0, 64, 3, 75, 4, 50, 1, 90, 2, 94, 
    2, 67, 4, 20, 3, 15, 0, 12, 1, 71, 
    0, 52, 4, 93, 3, 68, 2, 29, 1, 57, 
    2, 70, 0, 58, 1, 93, 4, 7, 3, 77, 
    3, 27, 2, 82, 1, 63, 4, 6, 0, 95, 
    1, 87, 2, 56, 4, 36, 0, 26, 3, 48, 
    3, 76, 2, 36, 0, 36, 4, 15, 1, 8
  };
  // Lawrence 20x5 instance (Table 5, instance 1); also called (seth1) or H1
  const int la11[] = {
    20, 5, // Number of jobs and machines
    2, 34, 1, 21, 0, 53, 3, 55, 4, 95, 
    0, 21, 3, 52, 1, 71, 4, 16, 2, 26, 
    0, 12, 1, 42, 2, 31, 4, 98, 3, 39, 
    2, 66, 3, 77, 4, 79, 0, 55, 1, 77, 
    0, 83, 4, 37, 3, 34, 1, 19, 2, 64, 
    4, 79, 2, 43, 0, 92, 3, 62, 1, 54, 
    0, 93, 4, 77, 2, 87, 1, 87, 3, 69, 
    4, 83, 3, 24, 1, 41, 2, 38, 0, 60, 
    4, 25, 1, 49, 0, 44, 2, 98, 3, 17, 
    0, 96, 1, 75, 2, 43, 4, 77, 3, 79, 
    0, 95, 3, 76, 1, 7, 4, 28, 2, 35, 
    4, 10, 2, 95, 0, 61, 1, 9, 3, 35, 
    1, 91, 2, 59, 4, 59, 0, 46, 3, 16, 
    2, 27, 1, 52, 4, 43, 0, 28, 3, 50, 
    4, 9, 0, 87, 3, 41, 2, 39, 1, 45, 
    1, 54, 0, 20, 4, 43, 3, 14, 2, 71, 
    4, 33, 1, 28, 3, 26, 0, 78, 2, 37, 
    1, 89, 0, 33, 2, 8, 3, 66, 4, 42, 
    4, 84, 0, 69, 2, 94, 1, 74, 3, 27, 
    4, 81, 2, 45, 1, 78, 3, 69, 0, 96
  };
  // Lawrence 20x5 instance (Table 5, instance 2); also called (seth2) or H2
  const int la12[] = {
    20, 5, // Number of jobs and machines
    1, 23, 0, 82, 4, 84, 2, 45, 3, 38, 
    3, 50, 4, 41, 1, 29, 0, 18, 2, 21, 
    4, 16, 3, 54, 1, 52, 2, 38, 0, 52, 
    1, 62, 3, 57, 4, 37, 2, 74, 0, 54, 
    3, 68, 1, 61, 2, 30, 0, 81, 4, 57, 
    1, 89, 2, 89, 3, 11, 0, 79, 4, 81, 
    1, 66, 0, 91, 3, 33, 4, 20, 2, 20, 
    3, 8, 4, 24, 2, 55, 0, 32, 1, 84, 
    0, 7, 2, 64, 1, 39, 4, 56, 3, 54, 
    0, 19, 4, 40, 3, 7, 2, 8, 1, 83, 
    0, 63, 2, 64, 3, 91, 4, 40, 1, 6, 
    1, 42, 3, 61, 4, 15, 2, 98, 0, 74, 
    1, 80, 0, 26, 3, 75, 4, 6, 2, 87, 
    2, 39, 4, 22, 0, 75, 3, 24, 1, 44, 
    1, 15, 3, 79, 4, 8, 0, 12, 2, 20, 
    3, 26, 2, 43, 0, 80, 4, 22, 1, 61, 
    2, 62, 1, 36, 0, 63, 3, 96, 4, 40, 
    1, 33, 3, 18, 0, 22, 4, 5, 2, 10, 
    2, 64, 4, 64, 0, 89, 1, 96, 3, 95, 
    2, 18, 4, 23, 3, 15, 1, 38, 0, 8
  };
  // Lawrence 20x5 instance (Table 5, instance 3); also called (seth3) or (H3)
  const int la13[] = {
    20, 5, // Number of jobs and machines
    3, 60, 0, 87, 1, 72, 4, 95, 2, 66, 
    1, 54, 0, 48, 2, 39, 3, 35, 4, 5, 
    3, 20, 1, 46, 0, 97, 2, 21, 4, 55, 
    2, 37, 0, 59, 3, 19, 1, 34, 4, 46, 
    2, 73, 3, 25, 1, 24, 0, 28, 4, 23, 
    1, 78, 3, 28, 2, 83, 0, 45, 4, 5, 
    3, 71, 1, 37, 2, 12, 4, 29, 0, 53, 
    4, 12, 3, 33, 1, 55, 2, 87, 0, 38, 
    0, 48, 1, 40, 2, 49, 3, 83, 4, 7, 
    0, 90, 4, 27, 2, 65, 3, 17, 1, 23, 
    0, 62, 3, 85, 1, 66, 2, 84, 4, 19, 
    3, 59, 2, 46, 4, 13, 1, 64, 0, 25, 
    2, 53, 1, 73, 3, 80, 4, 88, 0, 41, 
    2, 57, 4, 47, 0, 14, 1, 67, 3, 74, 
    2, 41, 4, 64, 3, 84, 1, 78, 0, 84, 
    4, 52, 3, 28, 2, 26, 0, 63, 1, 46, 
    1, 11, 0, 64, 3, 10, 4, 73, 2, 17, 
    4, 38, 3, 95, 0, 85, 1, 97, 2, 67, 
    3, 93, 1, 65, 2, 95, 0, 59, 4, 46, 
    0, 60, 1, 85, 2, 43, 4, 85, 3, 32
  };
  // Lawrence 20x5 instance (Table 5, instance 4); also called (seth4) or (H4)
  const int la14[] = {
    20, 5, // Number of jobs and machines
    3, 5, 4, 58, 2, 44, 0, 9, 1, 58, 
    1, 89, 4, 96, 0, 97, 2, 84, 3, 77, 
    2, 81, 3, 85, 1, 87, 4, 39, 0, 77, 
    0, 15, 3, 57, 4, 73, 1, 21, 2, 31, 
    2, 48, 4, 71, 3, 70, 0, 40, 1, 49, 
    0, 10, 4, 82, 3, 34, 2, 80, 1, 22, 
    2, 17, 0, 55, 1, 91, 4, 75, 3, 7, 
    3, 47, 2, 62, 1, 72, 4, 35, 0, 11, 
    1, 90, 2, 94, 4, 50, 0, 64, 3, 75, 
    3, 15, 2, 67, 0, 12, 4, 20, 1, 71, 
    4, 93, 2, 29, 0, 52, 1, 57, 3, 68, 
    3, 77, 1, 93, 0, 58, 2, 70, 4, 7, 
    1, 63, 3, 27, 0, 95, 4, 6, 2, 82, 
    4, 36, 0, 26, 3, 48, 2, 56, 1, 87, 
    2, 36, 1, 8, 4, 15, 3, 76, 0, 36, 
    4, 78, 1, 84, 3, 41, 0, 30, 2, 76, 
    1, 78, 0, 75, 4, 88, 3, 13, 2, 81, 
    0, 54, 4, 40, 2, 13, 1, 82, 3, 29, 
    1, 26, 4, 82, 0, 52, 3, 6, 2, 6, 
    3, 54, 1, 64, 0, 54, 2, 32, 4, 88
  };
  // Lawrence 20x5 instance (Table 5, instance 5); also called (seth5) or (H5)
  const int la15[] = {
    20, 5, // Number of jobs and machines
    0, 6, 2, 40, 1, 81, 3, 37, 4, 19, 
    2, 40, 3, 32, 0, 55, 4, 81, 1, 9, 
    1, 46, 4, 65, 2, 70, 3, 55, 0, 77, 
    2, 21, 4, 65, 0, 64, 3, 25, 1, 15, 
    2, 85, 0, 40, 1, 44, 3, 24, 4, 37, 
    0, 89, 4, 29, 1, 83, 3, 31, 2, 84, 
    4, 59, 3, 38, 1, 80, 2, 30, 0, 8, 
    0, 80, 2, 56, 1, 77, 4, 41, 3, 97, 
    4, 56, 0, 91, 3, 50, 2, 71, 1, 17, 
    1, 40, 0, 88, 4, 59, 2, 7, 3, 80, 
    0, 45, 1, 29, 2, 8, 4, 77, 3, 58, 
    2, 36, 0, 54, 3, 96, 1, 9, 4, 10, 
    0, 28, 2, 73, 1, 98, 3, 92, 4, 87, 
    0, 70, 3, 86, 2, 27, 1, 99, 4, 96, 
    1, 95, 0, 59, 4, 56, 3, 85, 2, 41, 
    1, 81, 2, 92, 4, 32, 0, 52, 3, 39, 
    1, 7, 4, 22, 2, 12, 0, 88, 3, 60, 
    3, 45, 0, 93, 2, 69, 4, 49, 1, 27, 
    0, 21, 1, 84, 2, 61, 3, 68, 4, 26, 
    1, 82, 2, 33, 4, 71, 0, 99, 3, 44
  };
  // Lawrence 10x10 instance (Table 6, instance 1); also called (seta1) or (A1)
  const int la16[] = {
    10, 10, // Number of jobs and machines
    1, 21, 6, 71, 9, 16, 8, 52, 7, 26, 2, 34, 0, 53, 4, 21, 3, 55, 5, 95, 
    4, 55, 2, 31, 5, 98, 9, 79, 0, 12, 7, 66, 1, 42, 8, 77, 6, 77, 3, 39, 
    3, 34, 2, 64, 8, 62, 1, 19, 4, 92, 9, 79, 7, 43, 6, 54, 0, 83, 5, 37, 
    1, 87, 3, 69, 2, 87, 7, 38, 8, 24, 9, 83, 6, 41, 0, 93, 5, 77, 4, 60, 
    2, 98, 0, 44, 5, 25, 6, 75, 7, 43, 1, 49, 4, 96, 9, 77, 3, 17, 8, 79, 
    2, 35, 3, 76, 5, 28, 9, 10, 4, 61, 6, 9, 0, 95, 8, 35, 1, 7, 7, 95, 
    3, 16, 2, 59, 0, 46, 1, 91, 9, 43, 8, 50, 6, 52, 5, 59, 4, 28, 7, 27, 
    1, 45, 0, 87, 3, 41, 4, 20, 6, 54, 9, 43, 8, 14, 5, 9, 2, 39, 7, 71, 
    4, 33, 2, 37, 8, 66, 5, 33, 3, 26, 7, 8, 1, 28, 6, 89, 9, 42, 0, 78, 
    8, 69, 9, 81, 2, 94, 4, 96, 3, 27, 0, 69, 7, 45, 6, 78, 1, 74, 5, 84
  };
  // Lawrence 10x10 instance (Table 6, instance 2); also called (seta2) or (A2)
  const int la17[] = {
    10, 10, // Number of jobs and machines
    4, 18, 7, 21, 9, 41, 2, 45, 3, 38, 8, 50, 5, 84, 6, 29, 1, 23, 0, 82, 
    8, 57, 5, 16, 1, 52, 7, 74, 2, 38, 3, 54, 6, 62, 9, 37, 4, 54, 0, 52, 
    2, 30, 4, 79, 3, 68, 1, 61, 8, 11, 6, 89, 7, 89, 0, 81, 9, 81, 5, 57, 
    0, 91, 8, 8, 3, 33, 7, 55, 5, 20, 2, 20, 4, 32, 6, 84, 1, 66, 9, 24, 
    9, 40, 0, 7, 4, 19, 8, 7, 6, 83, 2, 64, 5, 56, 3, 54, 7, 8, 1, 39, 
    3, 91, 2, 64, 5, 40, 0, 63, 7, 98, 4, 74, 8, 61, 1, 6, 6, 42, 9, 15, 
    1, 80, 7, 39, 8, 24, 3, 75, 4, 75, 5, 6, 6, 44, 0, 26, 2, 87, 9, 22, 
    1, 15, 7, 43, 2, 20, 0, 12, 8, 26, 6, 61, 3, 79, 9, 22, 5, 8, 4, 80, 
    2, 62, 3, 96, 4, 22, 9, 5, 0, 63, 6, 33, 7, 10, 8, 18, 1, 36, 5, 40, 
    1, 96, 0, 89, 5, 64, 3, 95, 9, 23, 7, 18, 8, 15, 2, 64, 6, 38, 4, 8
  };
  // Lawrence 10x10 instance (Table 6, instance 3); also called (seta3) or (A3)
  const int la18[] = {
    10, 10, // Number of jobs and machines
    6, 54, 0, 87, 4, 48, 3, 60, 7, 39, 8, 35, 1, 72, 5, 95, 2, 66, 9, 5, 
    3, 20, 9, 46, 6, 34, 5, 55, 0, 97, 8, 19, 4, 59, 2, 21, 7, 37, 1, 46, 
    4, 45, 1, 24, 8, 28, 0, 28, 7, 83, 6, 78, 5, 23, 3, 25, 9, 5, 2, 73, 
    9, 12, 1, 37, 4, 38, 3, 71, 8, 33, 2, 12, 6, 55, 0, 53, 7, 87, 5, 29, 
    3, 83, 2, 49, 6, 23, 9, 27, 7, 65, 0, 48, 4, 90, 5, 7, 1, 40, 8, 17, 
    1, 66, 4, 25, 0, 62, 2, 84, 9, 13, 6, 64, 7, 46, 8, 59, 5, 19, 3, 85, 
    1, 73, 3, 80, 0, 41, 2, 53, 9, 47, 7, 57, 8, 74, 4, 14, 6, 67, 5, 88, 
    5, 64, 3, 84, 6, 46, 1, 78, 0, 84, 7, 26, 8, 28, 9, 52, 2, 41, 4, 63, 
    1, 11, 0, 64, 7, 67, 4, 85, 3, 10, 5, 73, 9, 38, 8, 95, 6, 97, 2, 17, 
    4, 60, 8, 32, 2, 95, 3, 93, 1, 65, 6, 85, 7, 43, 9, 85, 5, 46, 0, 59
  };
  // Lawrence 10x10 instance (Table 6, instance 4); also called (seta4) or (A4)
  const int la19[] = {
    10, 10, // Number of jobs and machines
    2, 44, 3, 5, 5, 58, 4, 97, 0, 9, 7, 84, 8, 77, 9, 96, 1, 58, 6, 89, 
    4, 15, 7, 31, 1, 87, 8, 57, 0, 77, 3, 85, 2, 81, 5, 39, 9, 73, 6, 21, 
    9, 82, 6, 22, 4, 10, 3, 70, 1, 49, 0, 40, 8, 34, 2, 48, 7, 80, 5, 71, 
    1, 91, 2, 17, 7, 62, 5, 75, 8, 47, 4, 11, 3, 7, 6, 72, 9, 35, 0, 55, 
    6, 71, 1, 90, 3, 75, 0, 64, 2, 94, 8, 15, 4, 12, 7, 67, 9, 20, 5, 50, 
    7, 70, 5, 93, 8, 77, 2, 29, 4, 58, 6, 93, 3, 68, 1, 57, 9, 7, 0, 52, 
    6, 87, 1, 63, 4, 26, 5, 6, 2, 82, 3, 27, 7, 56, 8, 48, 9, 36, 0, 95, 
    0, 36, 5, 15, 8, 41, 9, 78, 3, 76, 6, 84, 4, 30, 7, 76, 2, 36, 1, 8, 
    5, 88, 2, 81, 3, 13, 6, 82, 4, 54, 7, 13, 8, 29, 9, 40, 1, 78, 0, 75, 
    9, 88, 4, 54, 6, 64, 7, 32, 0, 52, 2, 6, 8, 54, 5, 82, 3, 6, 1, 26
  };
  // Lawrence 10x10 instance (Table 6, instance 5); also called (seta5) or (A5)
  const int la20[] = {
    10, 10, // Number of jobs and machines
    6, 9, 1, 81, 4, 55, 2, 40, 8, 32, 3, 37, 0, 6, 5, 19, 9, 81, 7, 40, 
    7, 21, 2, 70, 9, 65, 4, 64, 1, 46, 5, 65, 8, 25, 0, 77, 3, 55, 6, 15, 
    2, 85, 5, 37, 0, 40, 3, 24, 1, 44, 6, 83, 4, 89, 8, 31, 7, 84, 9, 29, 
    4, 80, 6, 77, 7, 56, 0, 8, 2, 30, 5, 59, 3, 38, 1, 80, 9, 41, 8, 97, 
    0, 91, 6, 40, 4, 88, 1, 17, 2, 71, 3, 50, 9, 59, 8, 80, 5, 56, 7, 7, 
    2, 8, 6, 9, 3, 58, 5, 77, 1, 29, 8, 96, 0, 45, 9, 10, 4, 54, 7, 36, 
    4, 70, 3, 92, 1, 98, 5, 87, 6, 99, 7, 27, 8, 86, 9, 96, 0, 28, 2, 73, 
    1, 95, 7, 92, 3, 85, 4, 52, 6, 81, 9, 32, 8, 39, 0, 59, 2, 41, 5, 56, 
    3, 60, 8, 45, 0, 88, 2, 12, 1, 7, 5, 22, 4, 93, 9, 49, 7, 69, 6, 27, 
    0, 21, 2, 61, 3, 68, 5, 26, 6, 82, 9, 71, 8, 44, 4, 99, 7, 33, 1, 84
  };
  // Lawrence 15x10 instance (Table 7, instance 1); also called (setb1) or (B1)
  const int la21[] = {
    15, 10, // Number of jobs and machines
    2, 34, 3, 55, 5, 95, 9, 16, 4, 21, 6, 71, 0, 53, 8, 52, 1, 21, 7, 26, 
    3, 39, 2, 31, 0, 12, 1, 42, 9, 79, 8, 77, 6, 77, 5, 98, 4, 55, 7, 66, 
    1, 19, 0, 83, 3, 34, 4, 92, 6, 54, 9, 79, 8, 62, 5, 37, 2, 64, 7, 43, 
    4, 60, 2, 87, 8, 24, 5, 77, 3, 69, 7, 38, 1, 87, 6, 41, 9, 83, 0, 93, 
    8, 79, 9, 77, 2, 98, 4, 96, 3, 17, 0, 44, 7, 43, 6, 75, 1, 49, 5, 25, 
    8, 35, 7, 95, 6, 9, 9, 10, 2, 35, 1, 7, 5, 28, 4, 61, 0, 95, 3, 76, 
    4, 28, 5, 59, 3, 16, 9, 43, 0, 46, 8, 50, 6, 52, 7, 27, 2, 59, 1, 91, 
    5, 9, 4, 20, 2, 39, 6, 54, 1, 45, 7, 71, 0, 87, 3, 41, 9, 43, 8, 14, 
    1, 28, 5, 33, 0, 78, 3, 26, 2, 37, 7, 8, 8, 66, 6, 89, 9, 42, 4, 33, 
    2, 94, 5, 84, 6, 78, 9, 81, 1, 74, 3, 27, 8, 69, 0, 69, 7, 45, 4, 96, 
    1, 31, 4, 24, 0, 20, 2, 17, 9, 25, 8, 81, 5, 76, 3, 87, 7, 32, 6, 18, 
    5, 28, 9, 97, 0, 58, 4, 45, 6, 76, 3, 99, 2, 23, 1, 72, 8, 90, 7, 86, 
    5, 27, 9, 48, 8, 27, 7, 62, 4, 98, 6, 67, 3, 48, 0, 42, 1, 46, 2, 17, 
    1, 12, 8, 50, 0, 80, 2, 50, 9, 80, 3, 19, 5, 28, 6, 63, 4, 94, 7, 98, 
    4, 61, 3, 55, 6, 37, 5, 14, 2, 50, 8, 79, 1, 41, 9, 72, 7, 18, 0, 75
  };
  // Lawrence 15x10 instance (Table 7, instance 2); also called (setb2) or (B2)
  const int la22[] = {
    15, 10, // Number of jobs and machines
    9, 66, 5, 91, 4, 87, 2, 94, 7, 21, 3, 92, 1, 7, 0, 12, 8, 11, 6, 19, 
    3, 13, 2, 20, 4, 7, 1, 14, 9, 66, 0, 75, 6, 77, 5, 16, 7, 95, 8, 7, 
    8, 77, 7, 20, 2, 34, 0, 15, 9, 88, 5, 89, 6, 53, 3, 6, 1, 45, 4, 76, 
    3, 27, 2, 74, 6, 88, 4, 62, 7, 52, 8, 69, 5, 9, 9, 98, 0, 52, 1, 88, 
    4, 88, 6, 15, 1, 52, 2, 61, 7, 54, 0, 62, 8, 59, 5, 9, 3, 90, 9, 5, 
    6, 71, 0, 41, 4, 38, 3, 53, 7, 91, 8, 68, 1, 50, 5, 78, 2, 23, 9, 72, 
    3, 95, 9, 36, 6, 66, 5, 52, 0, 45, 8, 30, 4, 23, 2, 25, 7, 17, 1, 6, 
    4, 65, 1, 8, 8, 85, 0, 71, 7, 65, 6, 28, 5, 88, 3, 76, 9, 27, 2, 95, 
    9, 37, 1, 37, 4, 28, 3, 51, 8, 86, 2, 9, 6, 55, 0, 73, 7, 51, 5, 90, 
    3, 39, 2, 15, 6, 83, 9, 44, 7, 53, 0, 16, 4, 46, 5, 24, 1, 25, 8, 82, 
    1, 72, 4, 48, 0, 87, 2, 66, 9, 5, 6, 54, 7, 39, 8, 35, 5, 95, 3, 60, 
    1, 46, 3, 20, 0, 97, 2, 21, 9, 46, 7, 37, 8, 19, 4, 59, 6, 34, 5, 55, 
    5, 23, 3, 25, 6, 78, 1, 24, 0, 28, 7, 83, 8, 28, 9, 5, 2, 73, 4, 45, 
    1, 37, 0, 53, 7, 87, 4, 38, 3, 71, 5, 29, 9, 12, 8, 33, 6, 55, 2, 12, 
    4, 90, 8, 17, 2, 49, 3, 83, 1, 40, 6, 23, 7, 65, 9, 27, 5, 7, 0, 48
  };
  // Lawrence 15x10 instance (Table 7, instance 3); also called (setb3) or (B3)
  const int la23[] = {
    15, 10, // Number of jobs and machines
    7, 84, 5, 58, 8, 77, 2, 44, 4, 97, 6, 89, 3, 5, 1, 58, 9, 96, 0, 9, 
    6, 21, 1, 87, 4, 15, 5, 39, 2, 81, 3, 85, 7, 31, 8, 57, 9, 73, 0, 77, 
    0, 40, 5, 71, 8, 34, 9, 82, 3, 70, 6, 22, 4, 10, 7, 80, 2, 48, 1, 49, 
    5, 75, 2, 17, 3, 7, 6, 72, 4, 11, 7, 62, 8, 47, 9, 35, 1, 91, 0, 55, 
    9, 20, 4, 12, 6, 71, 7, 67, 0, 64, 2, 94, 8, 15, 5, 50, 3, 75, 1, 90, 
    6, 93, 5, 93, 1, 57, 7, 70, 8, 77, 4, 58, 0, 52, 2, 29, 9, 7, 3, 68, 
    7, 56, 0, 95, 8, 48, 4, 26, 2, 82, 1, 63, 9, 36, 3, 27, 6, 87, 5, 6, 
    3, 76, 5, 15, 9, 78, 1, 8, 8, 41, 2, 36, 4, 30, 6, 84, 0, 36, 7, 76, 
    0, 75, 7, 13, 2, 81, 8, 29, 4, 54, 6, 82, 5, 88, 1, 78, 9, 40, 3, 13, 
    2, 6, 1, 26, 7, 32, 6, 64, 4, 54, 0, 52, 5, 82, 3, 6, 9, 88, 8, 54, 
    8, 62, 2, 67, 5, 32, 0, 62, 7, 69, 3, 61, 1, 35, 4, 72, 9, 5, 6, 93, 
    2, 78, 9, 90, 0, 85, 1, 72, 8, 64, 6, 63, 3, 11, 7, 82, 5, 88, 4, 7, 
    4, 28, 9, 11, 7, 50, 6, 88, 0, 44, 5, 31, 2, 27, 1, 66, 8, 49, 3, 35, 
    2, 14, 5, 39, 6, 56, 4, 62, 3, 97, 9, 66, 7, 69, 1, 7, 8, 47, 0, 76, 
    1, 18, 8, 93, 7, 58, 6, 47, 3, 69, 9, 57, 2, 41, 5, 53, 4, 79, 0, 64
  };
  // Lawrence 15x10 instance (Table 7, instance 4); also called (setb4) or (B4)
  const int la24[] = {
    15, 10, // Number of jobs and machines
    7, 8, 9, 75, 0, 72, 6, 74, 4, 30, 8, 43, 2, 38, 5, 98, 1, 26, 3, 19, 
    6, 19, 8, 73, 3, 43, 0, 23, 1, 85, 4, 39, 5, 13, 9, 26, 2, 67, 7, 9, 
    1, 50, 3, 93, 5, 80, 4, 7, 0, 55, 2, 61, 6, 57, 8, 72, 9, 42, 7, 46, 
    1, 68, 7, 43, 4, 99, 6, 60, 5, 68, 0, 91, 8, 11, 3, 96, 9, 11, 2, 72, 
    7, 84, 2, 34, 8, 40, 5, 7, 1, 70, 6, 74, 3, 12, 0, 43, 9, 69, 4, 30, 
    8, 60, 0, 49, 4, 59, 5, 72, 9, 63, 1, 69, 7, 99, 6, 45, 3, 27, 2, 9, 
    6, 71, 2, 91, 8, 65, 1, 90, 9, 98, 4, 8, 7, 50, 0, 75, 5, 37, 3, 17, 
    8, 62, 7, 90, 5, 98, 3, 31, 2, 91, 4, 38, 9, 72, 1, 9, 0, 72, 6, 49, 
    4, 35, 0, 39, 9, 74, 5, 25, 7, 47, 3, 52, 2, 63, 8, 21, 6, 35, 1, 80, 
    9, 58, 0, 5, 3, 50, 8, 52, 1, 88, 6, 20, 2, 68, 5, 24, 4, 53, 7, 57, 
    7, 99, 3, 91, 4, 33, 5, 19, 2, 18, 6, 38, 0, 24, 9, 35, 1, 49, 8, 9, 
    0, 68, 3, 60, 2, 77, 7, 10, 8, 60, 5, 15, 9, 72, 1, 18, 6, 90, 4, 18, 
    9, 79, 1, 60, 3, 56, 6, 91, 2, 40, 8, 86, 7, 72, 0, 80, 5, 89, 4, 51, 
    4, 10, 2, 92, 5, 23, 6, 46, 8, 40, 7, 72, 3, 6, 1, 23, 0, 95, 9, 34, 
    2, 24, 5, 29, 9, 49, 8, 55, 0, 47, 6, 77, 3, 77, 7, 8, 1, 28, 4, 48
  };
  // Lawrence 15x10 instance (Table 7, instance 5); also called (setb5) or (B5)
  const int la25[] = {
    15, 10, // Number of jobs and machines
    8, 14, 4, 75, 3, 12, 2, 38, 0, 76, 5, 97, 9, 12, 1, 29, 7, 44, 6, 66, 
    5, 38, 3, 82, 2, 85, 4, 58, 6, 87, 9, 89, 0, 43, 1, 80, 7, 69, 8, 92, 
    9, 5, 1, 84, 0, 43, 6, 48, 4, 8, 7, 7, 3, 41, 5, 61, 8, 66, 2, 14, 
    2, 42, 1, 8, 0, 96, 5, 19, 4, 59, 7, 97, 9, 73, 8, 43, 3, 74, 6, 41, 
    6, 55, 2, 70, 3, 75, 8, 42, 4, 37, 7, 23, 1, 48, 5, 5, 9, 38, 0, 7, 
    8, 9, 2, 72, 7, 31, 0, 79, 5, 73, 3, 95, 4, 25, 6, 43, 9, 60, 1, 56, 
    0, 97, 2, 64, 3, 78, 5, 21, 4, 94, 9, 31, 8, 53, 6, 16, 7, 86, 1, 7, 
    3, 86, 7, 85, 9, 63, 0, 61, 2, 65, 4, 30, 5, 32, 1, 33, 8, 44, 6, 59, 
    2, 44, 3, 16, 4, 11, 6, 45, 1, 30, 9, 84, 8, 93, 0, 60, 5, 61, 7, 90, 
    7, 36, 8, 31, 4, 47, 6, 52, 0, 32, 5, 11, 2, 28, 9, 35, 3, 20, 1, 49, 
    8, 20, 6, 49, 7, 74, 4, 10, 5, 17, 3, 34, 0, 85, 2, 77, 9, 68, 1, 84, 
    1, 85, 5, 7, 8, 71, 6, 59, 4, 76, 0, 17, 3, 29, 2, 17, 7, 48, 9, 13, 
    2, 15, 6, 87, 7, 11, 1, 39, 4, 39, 8, 43, 0, 19, 3, 32, 9, 16, 5, 64, 
    6, 32, 2, 92, 5, 33, 8, 82, 1, 83, 7, 57, 9, 99, 4, 91, 3, 99, 0, 8, 
    4, 88, 7, 7, 8, 27, 1, 38, 3, 91, 2, 69, 6, 21, 9, 62, 5, 39, 0, 48
  };
  // Lawrence 20x10 instance (Table 8, instance 1); also called (setc1) or (C1)
  const int la26[] = {
    20, 10, // Number of jobs and machines
    8, 52, 7, 26, 6, 71, 9, 16, 2, 34, 1, 21, 5, 95, 4, 21, 0, 53, 3, 55, 
    4, 55, 5, 98, 3, 39, 9, 79, 0, 12, 8, 77, 6, 77, 7, 66, 2, 31, 1, 42, 
    5, 37, 4, 92, 2, 64, 6, 54, 1, 19, 7, 43, 0, 83, 3, 34, 9, 79, 8, 62, 
    1, 87, 5, 77, 0, 93, 3, 69, 2, 87, 7, 38, 8, 24, 6, 41, 9, 83, 4, 60, 
    2, 98, 5, 25, 6, 75, 9, 77, 1, 49, 3, 17, 8, 79, 0, 44, 7, 43, 4, 96, 
    1, 7, 4, 61, 0, 95, 2, 35, 9, 10, 8, 35, 5, 28, 3, 76, 7, 95, 6, 9, 
    5, 59, 9, 43, 0, 46, 4, 28, 6, 52, 3, 16, 2, 59, 1, 91, 8, 50, 7, 27, 
    5, 9, 9, 43, 8, 14, 7, 71, 4, 20, 6, 54, 3, 41, 0, 87, 1, 45, 2, 39, 
    1, 28, 8, 66, 0, 78, 2, 37, 9, 42, 3, 26, 5, 33, 6, 89, 4, 33, 7, 8, 
    4, 96, 3, 27, 6, 78, 5, 84, 2, 94, 8, 69, 1, 74, 9, 81, 7, 45, 0, 69, 
    4, 24, 7, 32, 9, 25, 2, 17, 3, 87, 8, 81, 5, 76, 6, 18, 1, 31, 0, 20, 
    8, 90, 5, 28, 1, 72, 7, 86, 2, 23, 3, 99, 6, 76, 9, 97, 4, 45, 0, 58, 
    2, 17, 4, 98, 3, 48, 1, 46, 8, 27, 6, 67, 7, 62, 0, 42, 9, 48, 5, 27, 
    0, 80, 8, 50, 3, 19, 7, 98, 5, 28, 2, 50, 4, 94, 6, 63, 1, 12, 9, 80, 
    9, 72, 0, 75, 4, 61, 8, 79, 6, 37, 2, 50, 5, 14, 3, 55, 7, 18, 1, 41, 
    3, 96, 2, 14, 5, 57, 0, 47, 7, 65, 4, 75, 8, 79, 1, 71, 6, 60, 9, 22, 
    1, 31, 7, 47, 8, 58, 3, 32, 4, 44, 5, 58, 6, 34, 0, 33, 2, 69, 9, 51, 
    1, 44, 7, 40, 2, 17, 0, 62, 8, 66, 6, 15, 3, 29, 9, 38, 5, 8, 4, 97, 
    2, 58, 3, 50, 4, 63, 9, 87, 0, 57, 6, 21, 7, 57, 8, 32, 1, 39, 5, 20, 
    1, 85, 0, 84, 5, 56, 3, 61, 9, 15, 7, 70, 8, 30, 2, 90, 6, 67, 4, 20
  };
  // Lawrence 20x10 instance (Table 8, instance 2); also called (setc2) or (C2)
  const int la27[] = {
    20, 10, // Number of jobs and machines
    3, 60, 4, 48, 5, 95, 0, 87, 1, 72, 9, 5, 8, 35, 7, 39, 6, 54, 2, 66, 
    7, 37, 6, 34, 0, 97, 5, 55, 2, 21, 3, 20, 4, 59, 9, 46, 8, 19, 1, 46, 
    4, 45, 2, 73, 1, 24, 8, 28, 0, 28, 3, 25, 5, 23, 7, 83, 9, 5, 6, 78, 
    0, 53, 2, 12, 9, 12, 1, 37, 8, 33, 3, 71, 6, 55, 5, 29, 7, 87, 4, 38, 
    4, 90, 2, 49, 9, 27, 7, 65, 5, 7, 6, 23, 0, 48, 3, 83, 8, 17, 1, 40, 
    3, 85, 4, 25, 2, 84, 6, 64, 9, 13, 1, 66, 7, 46, 8, 59, 0, 62, 5, 19, 
    5, 88, 6, 67, 4, 14, 0, 41, 1, 73, 7, 57, 2, 53, 3, 80, 9, 47, 8, 74, 
    1, 78, 5, 64, 4, 63, 6, 46, 3, 84, 0, 84, 8, 28, 9, 52, 7, 26, 2, 41, 
    1, 11, 0, 64, 6, 97, 9, 38, 2, 17, 4, 85, 5, 73, 3, 10, 8, 95, 7, 67, 
    3, 93, 2, 95, 7, 43, 1, 65, 8, 32, 0, 59, 6, 85, 5, 46, 9, 85, 4, 60, 
    2, 61, 3, 41, 5, 49, 4, 23, 0, 66, 7, 49, 8, 70, 9, 99, 1, 90, 6, 17, 
    4, 13, 7, 7, 1, 98, 8, 57, 0, 73, 3, 73, 2, 68, 5, 40, 9, 98, 6, 9, 
    9, 86, 6, 76, 4, 14, 3, 41, 1, 85, 0, 37, 8, 19, 2, 17, 7, 54, 5, 79, 
    1, 40, 2, 53, 7, 97, 5, 87, 8, 96, 4, 84, 3, 16, 6, 66, 9, 52, 0, 95, 
    6, 33, 1, 33, 3, 87, 0, 18, 2, 55, 8, 13, 4, 77, 7, 60, 9, 42, 5, 74, 
    7, 92, 5, 91, 8, 79, 2, 54, 4, 69, 6, 79, 3, 33, 1, 61, 9, 39, 0, 16, 
    6, 82, 1, 41, 4, 28, 5, 64, 2, 78, 3, 76, 7, 6, 8, 49, 9, 47, 0, 58, 
    0, 52, 5, 42, 8, 24, 9, 91, 3, 47, 6, 88, 4, 91, 7, 52, 2, 28, 1, 35, 
    5, 82, 2, 76, 3, 86, 6, 93, 4, 84, 7, 38, 8, 95, 9, 37, 1, 21, 0, 23, 
    9, 77, 4, 8, 6, 42, 7, 64, 0, 70, 2, 45, 8, 45, 5, 28, 3, 67, 1, 86
  };
  // Lawrence 20x10 instance (Table 8, instance 3); also called (setc3) or (C3)
  const int la28[] = {
    20, 10, // Number of jobs and machines
    8, 32, 1, 81, 4, 55, 7, 40, 0, 6, 5, 19, 9, 81, 3, 37, 2, 40, 6, 9, 
    2, 70, 3, 55, 7, 21, 4, 64, 1, 46, 8, 25, 9, 65, 0, 77, 5, 65, 6, 15, 
    7, 84, 4, 89, 3, 24, 1, 44, 2, 85, 8, 31, 9, 29, 6, 83, 5, 37, 0, 40, 
    4, 80, 5, 59, 0, 8, 2, 30, 6, 77, 3, 38, 1, 80, 7, 56, 9, 41, 8, 97, 
    6, 40, 2, 71, 0, 91, 7, 7, 9, 59, 8, 80, 3, 50, 5, 56, 1, 17, 4, 88, 
    7, 36, 9, 10, 0, 45, 6, 9, 4, 54, 8, 96, 2, 8, 5, 77, 1, 29, 3, 58, 
    6, 99, 8, 86, 3, 92, 0, 28, 1, 98, 4, 70, 5, 87, 9, 96, 2, 73, 7, 27, 
    1, 95, 3, 85, 5, 56, 4, 52, 0, 59, 2, 41, 6, 81, 8, 39, 9, 32, 7, 92, 
    1, 7, 7, 69, 4, 93, 6, 27, 5, 22, 0, 88, 8, 45, 3, 60, 9, 49, 2, 12, 
    7, 33, 2, 61, 8, 44, 5, 26, 1, 84, 6, 82, 3, 68, 0, 21, 9, 71, 4, 99, 
    8, 43, 0, 72, 4, 30, 5, 98, 9, 75, 1, 26, 7, 8, 6, 74, 3, 19, 2, 38, 
    6, 19, 2, 67, 8, 73, 1, 85, 9, 26, 4, 39, 7, 9, 0, 23, 5, 13, 3, 43, 
    8, 72, 7, 46, 5, 80, 3, 93, 2, 61, 4, 7, 9, 42, 1, 50, 0, 55, 6, 57, 
    4, 99, 0, 91, 9, 11, 5, 68, 7, 43, 3, 96, 2, 72, 8, 11, 6, 60, 1, 68, 
    9, 69, 0, 43, 3, 12, 8, 40, 1, 70, 6, 74, 2, 34, 5, 7, 4, 30, 7, 84, 
    7, 99, 3, 27, 4, 59, 5, 72, 2, 9, 6, 45, 0, 49, 9, 63, 1, 69, 8, 60, 
    0, 75, 3, 17, 2, 91, 7, 50, 8, 65, 5, 37, 9, 98, 1, 90, 6, 71, 4, 8, 
    9, 72, 1, 9, 3, 31, 6, 49, 2, 91, 8, 62, 7, 90, 0, 72, 5, 98, 4, 38, 
    4, 35, 2, 63, 5, 25, 6, 35, 8, 21, 7, 47, 3, 52, 1, 80, 0, 39, 9, 74, 
    2, 68, 5, 24, 9, 58, 8, 52, 0, 5, 6, 20, 3, 50, 7, 57, 1, 88, 4, 53
  };
  // Lawrence 20x10 instance (Table 8, instance 4); also called (setc4) or (C4)
  const int la29[] = {
    20, 10, // Number of jobs and machines
    8, 14, 2, 38, 7, 44, 0, 76, 5, 97, 3, 12, 4, 75, 6, 66, 9, 12, 1, 29, 
    0, 43, 2, 85, 3, 82, 5, 38, 4, 58, 9, 89, 8, 92, 6, 87, 7, 69, 1, 80, 
    3, 41, 7, 7, 9, 5, 0, 43, 2, 14, 4, 8, 5, 61, 1, 84, 8, 66, 6, 48, 
    2, 42, 3, 74, 4, 59, 6, 41, 1, 8, 9, 73, 8, 43, 0, 96, 5, 19, 7, 97, 
    7, 23, 8, 42, 4, 37, 6, 55, 0, 7, 5, 5, 2, 70, 9, 38, 3, 75, 1, 48, 
    8, 9, 6, 43, 7, 31, 4, 25, 5, 73, 3, 95, 0, 79, 2, 72, 9, 60, 1, 56, 
    1, 7, 5, 21, 8, 53, 6, 16, 4, 94, 0, 97, 3, 78, 2, 64, 7, 86, 9, 31, 
    2, 65, 6, 59, 7, 85, 1, 33, 4, 30, 8, 44, 0, 61, 3, 86, 9, 63, 5, 32, 
    6, 45, 2, 44, 5, 61, 8, 93, 1, 30, 7, 90, 9, 84, 4, 11, 3, 16, 0, 60, 
    4, 47, 7, 36, 8, 31, 1, 49, 3, 20, 2, 28, 6, 52, 9, 35, 5, 11, 0, 32, 
    2, 77, 4, 10, 9, 68, 5, 17, 0, 85, 1, 84, 8, 20, 6, 49, 7, 74, 3, 34, 
    0, 17, 5, 7, 1, 85, 3, 29, 2, 17, 4, 76, 6, 59, 8, 71, 9, 13, 7, 48, 
    6, 87, 4, 39, 8, 43, 7, 11, 2, 15, 3, 32, 5, 64, 0, 19, 1, 39, 9, 16, 
    5, 33, 3, 99, 6, 32, 4, 91, 8, 82, 2, 92, 9, 99, 7, 57, 1, 83, 0, 8, 
    3, 91, 5, 39, 2, 69, 8, 27, 7, 7, 6, 21, 1, 38, 9, 62, 4, 88, 0, 48, 
    2, 67, 7, 80, 3, 24, 0, 88, 4, 18, 1, 44, 8, 45, 9, 64, 5, 80, 6, 38, 
    9, 59, 3, 72, 6, 47, 4, 40, 7, 21, 5, 43, 0, 51, 8, 52, 1, 24, 2, 15, 
    3, 70, 2, 31, 6, 20, 8, 76, 1, 40, 7, 43, 0, 32, 5, 88, 9, 5, 4, 77, 
    4, 47, 5, 64, 9, 85, 3, 49, 7, 58, 1, 26, 0, 32, 8, 80, 2, 14, 6, 94, 
    5, 59, 2, 96, 0, 5, 7, 79, 8, 34, 4, 75, 3, 26, 6, 9, 9, 23, 1, 11
  };
  // Lawrence 20x10 instance (Table 8, instance 5); also called (setc5) or (C5)
  const int la30[] = {
    20, 10, // Number of jobs and machines
    6, 32, 3, 16, 1, 33, 8, 12, 7, 70, 4, 10, 9, 75, 0, 82, 5, 88, 2, 20, 
    8, 39, 4, 81, 3, 91, 5, 56, 9, 69, 1, 45, 6, 59, 0, 86, 2, 36, 7, 68, 
    3, 84, 2, 57, 7, 41, 5, 73, 4, 81, 0, 88, 8, 38, 9, 17, 6, 83, 1, 5, 
    4, 20, 5, 6, 2, 15, 8, 19, 1, 30, 0, 94, 6, 45, 7, 17, 3, 18, 9, 88, 
    9, 24, 6, 49, 5, 16, 4, 11, 3, 60, 7, 5, 8, 63, 1, 25, 2, 15, 0, 45, 
    1, 86, 8, 50, 2, 77, 6, 54, 9, 48, 0, 93, 3, 32, 7, 92, 5, 45, 4, 71, 
    5, 86, 6, 90, 3, 78, 9, 88, 2, 57, 0, 32, 7, 57, 8, 86, 4, 71, 1, 39, 
    2, 59, 3, 18, 9, 31, 4, 41, 7, 20, 5, 83, 8, 65, 0, 54, 6, 94, 1, 69, 
    3, 47, 4, 79, 6, 76, 0, 59, 1, 72, 2, 8, 9, 30, 5, 73, 7, 57, 8, 84, 
    0, 59, 2, 89, 4, 10, 7, 45, 3, 8, 5, 54, 6, 88, 8, 20, 9, 7, 1, 62, 
    5, 63, 6, 9, 4, 77, 3, 37, 2, 5, 8, 13, 9, 79, 1, 24, 7, 10, 0, 82, 
    0, 74, 1, 32, 2, 61, 7, 53, 4, 92, 9, 20, 8, 10, 3, 5, 6, 45, 5, 23, 
    2, 85, 9, 51, 0, 61, 5, 99, 4, 37, 6, 94, 1, 98, 8, 65, 3, 33, 7, 75, 
    0, 51, 3, 24, 5, 8, 6, 30, 7, 12, 8, 23, 2, 7, 4, 17, 9, 35, 1, 81, 
    1, 71, 5, 42, 8, 68, 2, 31, 6, 29, 3, 63, 4, 65, 9, 70, 7, 27, 0, 93, 
    1, 28, 5, 38, 4, 51, 7, 70, 2, 33, 8, 78, 9, 45, 3, 90, 6, 54, 0, 72, 
    0, 18, 2, 90, 4, 25, 6, 92, 8, 85, 5, 35, 7, 29, 1, 81, 9, 80, 3, 59, 
    5, 67, 2, 96, 1, 38, 4, 86, 0, 97, 3, 94, 7, 86, 6, 35, 9, 82, 8, 45, 
    2, 92, 8, 51, 4, 59, 6, 52, 5, 8, 9, 70, 1, 75, 3, 54, 7, 60, 0, 33, 
    3, 98, 7, 80, 5, 78, 0, 82, 2, 7, 9, 89, 1, 69, 4, 51, 8, 79, 6, 62
  };
  // Lawrence 30x10 instance (Table 9, instance 1); also called (setd1) or (D1)
  const int la31[] = {
    30, 10, // Number of jobs and machines
    4, 21, 7, 26, 9, 16, 2, 34, 3, 55, 8, 52, 5, 95, 6, 71, 1, 21, 0, 53, 
    8, 77, 5, 98, 1, 42, 7, 66, 2, 31, 3, 39, 6, 77, 9, 79, 4, 55, 0, 12, 
    2, 64, 4, 92, 3, 34, 1, 19, 8, 62, 6, 54, 7, 43, 0, 83, 9, 79, 5, 37, 
    0, 93, 8, 24, 3, 69, 7, 38, 5, 77, 2, 87, 4, 60, 6, 41, 1, 87, 9, 83, 
    9, 77, 0, 44, 4, 96, 8, 79, 6, 75, 2, 98, 5, 25, 3, 17, 7, 43, 1, 49, 
    3, 76, 2, 35, 5, 28, 0, 95, 7, 95, 4, 61, 8, 35, 1, 7, 6, 9, 9, 10, 
    1, 91, 7, 27, 8, 50, 3, 16, 4, 28, 5, 59, 6, 52, 0, 46, 2, 59, 9, 43, 
    1, 45, 7, 71, 2, 39, 0, 87, 8, 14, 6, 54, 3, 41, 9, 43, 5, 9, 4, 20, 
    2, 37, 3, 26, 4, 33, 9, 42, 0, 78, 6, 89, 7, 8, 8, 66, 1, 28, 5, 33, 
    1, 74, 0, 69, 5, 84, 3, 27, 9, 81, 7, 45, 8, 69, 2, 94, 6, 78, 4, 96, 
    5, 76, 7, 32, 6, 18, 0, 20, 3, 87, 2, 17, 9, 25, 4, 24, 1, 31, 8, 81, 
    9, 97, 8, 90, 5, 28, 7, 86, 0, 58, 1, 72, 2, 23, 6, 76, 3, 99, 4, 45, 
    9, 48, 5, 27, 6, 67, 7, 62, 4, 98, 0, 42, 1, 46, 8, 27, 3, 48, 2, 17, 
    9, 80, 3, 19, 5, 28, 1, 12, 4, 94, 6, 63, 7, 98, 8, 50, 0, 80, 2, 50, 
    2, 50, 1, 41, 4, 61, 8, 79, 5, 14, 9, 72, 7, 18, 3, 55, 6, 37, 0, 75, 
    9, 22, 5, 57, 4, 75, 2, 14, 7, 65, 3, 96, 1, 71, 0, 47, 8, 79, 6, 60, 
    3, 32, 2, 69, 4, 44, 1, 31, 9, 51, 0, 33, 6, 34, 5, 58, 7, 47, 8, 58, 
    8, 66, 7, 40, 2, 17, 0, 62, 9, 38, 5, 8, 6, 15, 3, 29, 1, 44, 4, 97, 
    3, 50, 2, 58, 6, 21, 4, 63, 7, 57, 8, 32, 5, 20, 9, 87, 0, 57, 1, 39, 
    4, 20, 6, 67, 1, 85, 2, 90, 7, 70, 0, 84, 8, 30, 5, 56, 3, 61, 9, 15, 
    6, 29, 0, 82, 4, 18, 3, 38, 7, 21, 8, 50, 1, 23, 5, 84, 2, 45, 9, 41, 
    3, 54, 9, 37, 6, 62, 5, 16, 0, 52, 8, 57, 4, 54, 2, 38, 7, 74, 1, 52, 
    4, 79, 1, 61, 8, 11, 0, 81, 7, 89, 6, 89, 5, 57, 3, 68, 9, 81, 2, 30, 
    9, 24, 1, 66, 4, 32, 3, 33, 8, 8, 2, 20, 6, 84, 0, 91, 7, 55, 5, 20, 
    3, 54, 2, 64, 6, 83, 9, 40, 7, 8, 0, 7, 4, 19, 5, 56, 1, 39, 8, 7, 
    1, 6, 4, 74, 0, 63, 2, 64, 9, 15, 6, 42, 7, 98, 8, 61, 5, 40, 3, 91, 
    1, 80, 3, 75, 0, 26, 2, 87, 9, 22, 7, 39, 8, 24, 4, 75, 6, 44, 5, 6, 
    5, 8, 3, 79, 6, 61, 1, 15, 0, 12, 7, 43, 8, 26, 9, 22, 2, 20, 4, 80, 
    1, 36, 0, 63, 7, 10, 4, 22, 3, 96, 5, 40, 9, 5, 8, 18, 6, 33, 2, 62, 
    4, 8, 8, 15, 2, 64, 3, 95, 1, 96, 6, 38, 7, 18, 9, 23, 5, 64, 0, 89
  };
  // Lawrence 30x10 instance (Table 9, instance 2); also called (setd2) or (D2)
  const int la32[] = {
    30, 10, // Number of jobs and machines
    6, 89, 1, 58, 4, 97, 2, 44, 8, 77, 3, 5, 0, 9, 5, 58, 9, 96, 7, 84, 
    7, 31, 2, 81, 9, 73, 4, 15, 1, 87, 5, 39, 8, 57, 0, 77, 3, 85, 6, 21, 
    2, 48, 5, 71, 0, 40, 3, 70, 1, 49, 6, 22, 4, 10, 8, 34, 7, 80, 9, 82, 
    4, 11, 6, 72, 7, 62, 0, 55, 2, 17, 5, 75, 3, 7, 1, 91, 9, 35, 8, 47, 
    0, 64, 6, 71, 4, 12, 1, 90, 2, 94, 3, 75, 9, 20, 8, 15, 5, 50, 7, 67, 
    2, 29, 6, 93, 3, 68, 5, 93, 1, 57, 8, 77, 0, 52, 9, 7, 4, 58, 7, 70, 
    4, 26, 3, 27, 1, 63, 5, 6, 6, 87, 7, 56, 8, 48, 9, 36, 0, 95, 2, 82, 
    1, 8, 7, 76, 3, 76, 4, 30, 6, 84, 9, 78, 8, 41, 0, 36, 2, 36, 5, 15, 
    3, 13, 8, 29, 0, 75, 2, 81, 1, 78, 5, 88, 4, 54, 9, 40, 7, 13, 6, 82, 
    0, 52, 2, 6, 3, 6, 5, 82, 6, 64, 9, 88, 8, 54, 4, 54, 7, 32, 1, 26, 
    8, 62, 1, 35, 4, 72, 7, 69, 0, 62, 5, 32, 9, 5, 3, 61, 2, 67, 6, 93, 
    2, 78, 3, 11, 7, 82, 4, 7, 1, 72, 8, 64, 9, 90, 0, 85, 5, 88, 6, 63, 
    7, 50, 4, 28, 3, 35, 1, 66, 2, 27, 8, 49, 9, 11, 6, 88, 5, 31, 0, 44, 
    4, 62, 5, 39, 0, 76, 2, 14, 6, 56, 3, 97, 1, 7, 7, 69, 9, 66, 8, 47, 
    6, 47, 2, 41, 0, 64, 7, 58, 9, 57, 8, 93, 3, 69, 5, 53, 1, 18, 4, 79, 
    7, 76, 9, 81, 0, 76, 6, 61, 4, 77, 8, 26, 2, 74, 5, 22, 1, 58, 3, 78, 
    6, 30, 8, 72, 3, 43, 0, 65, 1, 16, 4, 92, 5, 95, 9, 29, 2, 99, 7, 64, 
    1, 35, 3, 74, 5, 16, 4, 85, 0, 7, 2, 81, 6, 86, 8, 61, 9, 35, 7, 34, 
    1, 97, 7, 43, 4, 72, 6, 88, 5, 17, 0, 43, 8, 94, 3, 64, 9, 22, 2, 42, 
    7, 99, 2, 84, 8, 99, 5, 98, 1, 20, 6, 31, 3, 74, 0, 92, 9, 23, 4, 89, 
    8, 32, 0, 6, 4, 55, 5, 19, 9, 81, 1, 81, 7, 40, 6, 9, 3, 37, 2, 40, 
    6, 15, 2, 70, 8, 25, 1, 46, 9, 65, 4, 64, 7, 21, 0, 77, 5, 65, 3, 55, 
    8, 31, 7, 84, 5, 37, 3, 24, 2, 85, 4, 89, 9, 29, 1, 44, 0, 40, 6, 83, 
    4, 80, 0, 8, 9, 41, 5, 59, 7, 56, 3, 38, 2, 30, 8, 97, 6, 77, 1, 80, 
    9, 59, 0, 91, 3, 50, 8, 80, 1, 17, 6, 40, 2, 71, 5, 56, 4, 88, 7, 7, 
    7, 36, 3, 58, 4, 54, 5, 77, 2, 8, 6, 9, 0, 45, 9, 10, 1, 29, 8, 96, 
    0, 28, 3, 92, 2, 73, 7, 27, 8, 86, 5, 87, 9, 96, 1, 98, 6, 99, 4, 70, 
    9, 32, 1, 95, 3, 85, 6, 81, 2, 41, 8, 39, 7, 92, 0, 59, 5, 56, 4, 52, 
    4, 93, 2, 12, 5, 22, 6, 27, 8, 45, 7, 69, 3, 60, 1, 7, 0, 88, 9, 49, 
    2, 61, 5, 26, 9, 71, 8, 44, 0, 21, 6, 82, 3, 68, 7, 33, 1, 84, 4, 99
  };
  // Lawrence 30x10 instance (Table 9, instance 3); also called (setd3) or (D3)
  const int la33[] = {
    30, 10, // Number of jobs and machines
    2, 38, 4, 75, 9, 12, 5, 97, 0, 76, 1, 29, 8, 14, 6, 66, 7, 44, 3, 12, 
    0, 43, 5, 38, 1, 80, 3, 82, 2, 85, 4, 58, 6, 87, 8, 92, 9, 89, 7, 69, 
    6, 48, 4, 8, 8, 66, 7, 7, 2, 14, 3, 41, 5, 61, 0, 43, 1, 84, 9, 5, 
    5, 19, 3, 74, 6, 41, 4, 59, 8, 43, 2, 42, 9, 73, 7, 97, 1, 8, 0, 96, 
    3, 75, 5, 5, 2, 70, 8, 42, 7, 23, 6, 55, 1, 48, 9, 38, 4, 37, 0, 7, 
    2, 72, 7, 31, 3, 95, 0, 79, 4, 25, 1, 56, 8, 9, 9, 60, 5, 73, 6, 43, 
    9, 31, 3, 78, 6, 16, 4, 94, 7, 86, 5, 21, 0, 97, 8, 53, 1, 7, 2, 64, 
    3, 86, 2, 65, 6, 59, 8, 44, 1, 33, 7, 85, 0, 61, 5, 32, 9, 63, 4, 30, 
    4, 11, 5, 61, 9, 84, 3, 16, 7, 90, 1, 30, 0, 60, 8, 93, 2, 44, 6, 45, 
    5, 11, 2, 28, 0, 32, 7, 36, 8, 31, 4, 47, 3, 20, 6, 52, 9, 35, 1, 49, 
    5, 17, 3, 34, 6, 49, 1, 84, 0, 85, 8, 20, 7, 74, 9, 68, 4, 10, 2, 77, 
    8, 71, 5, 7, 3, 29, 1, 85, 4, 76, 6, 59, 2, 17, 0, 17, 9, 13, 7, 48, 
    1, 39, 9, 16, 4, 39, 6, 87, 7, 11, 3, 32, 2, 15, 0, 19, 5, 64, 8, 43, 
    5, 33, 8, 82, 2, 92, 1, 83, 6, 32, 3, 99, 9, 99, 4, 91, 0, 8, 7, 57, 
    7, 7, 0, 48, 9, 62, 4, 88, 6, 21, 5, 39, 8, 27, 3, 91, 1, 38, 2, 69, 
    9, 64, 8, 45, 3, 24, 7, 80, 2, 67, 4, 18, 6, 38, 0, 88, 5, 80, 1, 44, 
    2, 15, 3, 72, 4, 40, 7, 21, 8, 52, 0, 51, 9, 59, 1, 24, 6, 47, 5, 43, 
    4, 77, 7, 43, 1, 40, 2, 31, 8, 76, 6, 20, 5, 88, 3, 70, 9, 5, 0, 32, 
    2, 14, 7, 58, 9, 85, 5, 64, 1, 26, 6, 94, 0, 32, 3, 49, 8, 80, 4, 47, 
    9, 23, 1, 11, 8, 34, 4, 75, 7, 79, 3, 26, 2, 96, 0, 5, 6, 9, 5, 59, 
    0, 75, 2, 20, 8, 10, 3, 66, 6, 43, 7, 37, 1, 9, 9, 83, 4, 68, 5, 52, 
    8, 54, 1, 26, 4, 79, 7, 88, 6, 84, 0, 6, 2, 54, 9, 59, 3, 28, 5, 42, 
    4, 56, 9, 29, 3, 36, 0, 40, 6, 86, 8, 68, 2, 69, 7, 23, 5, 62, 1, 16, 
    7, 53, 1, 5, 6, 17, 9, 59, 2, 59, 8, 78, 3, 64, 0, 82, 4, 13, 5, 12, 
    9, 7, 6, 62, 7, 90, 5, 83, 1, 85, 3, 69, 0, 16, 4, 81, 2, 58, 8, 66, 
    7, 24, 2, 65, 1, 69, 5, 42, 9, 82, 6, 82, 0, 83, 3, 46, 8, 72, 4, 33, 
    1, 10, 8, 27, 7, 43, 5, 20, 4, 71, 9, 65, 2, 73, 6, 99, 0, 24, 3, 64, 
    9, 35, 3, 92, 0, 38, 5, 35, 7, 30, 8, 45, 2, 8, 4, 82, 1, 34, 6, 21, 
    5, 23, 7, 84, 9, 7, 4, 85, 8, 60, 1, 15, 2, 52, 6, 94, 3, 83, 0, 6, 
    2, 70, 6, 29, 8, 27, 9, 80, 4, 6, 7, 39, 1, 79, 0, 28, 3, 66, 5, 66
  };
  // Lawrence 30x10 instance (Table 9, instance 4); also called (setd4) or (D4)
  const int la34[] = {
    30, 10, // Number of jobs and machines
    2, 51, 7, 59, 1, 35, 5, 73, 9, 65, 0, 27, 6, 13, 3, 81, 8, 32, 4, 74, 
    4, 64, 7, 33, 5, 75, 2, 33, 8, 10, 0, 28, 3, 38, 6, 53, 9, 49, 1, 55, 
    6, 83, 1, 23, 2, 72, 3, 7, 9, 72, 0, 6, 4, 39, 5, 52, 8, 90, 7, 21, 
    3, 82, 1, 23, 2, 93, 4, 78, 6, 88, 7, 53, 9, 28, 8, 65, 5, 21, 0, 61, 
    4, 41, 6, 12, 9, 12, 3, 77, 1, 70, 7, 24, 0, 81, 5, 73, 2, 62, 8, 6, 
    4, 98, 3, 28, 6, 42, 9, 72, 0, 15, 8, 15, 5, 94, 2, 33, 1, 51, 7, 99, 
    0, 32, 8, 22, 9, 96, 4, 15, 6, 78, 3, 31, 5, 7, 1, 94, 2, 23, 7, 86, 
    7, 93, 2, 97, 3, 43, 5, 73, 0, 24, 8, 68, 9, 88, 1, 42, 4, 35, 6, 72, 
    2, 14, 0, 44, 8, 13, 5, 67, 1, 63, 3, 49, 7, 5, 4, 17, 6, 85, 9, 66, 
    7, 82, 9, 15, 3, 72, 4, 26, 0, 8, 1, 68, 6, 21, 8, 45, 2, 99, 5, 27, 
    4, 93, 6, 23, 0, 51, 8, 54, 3, 49, 1, 96, 2, 56, 9, 36, 5, 53, 7, 52, 
    8, 60, 0, 14, 4, 70, 9, 55, 1, 23, 5, 83, 3, 38, 2, 24, 7, 37, 6, 48, 
    0, 62, 7, 15, 8, 69, 9, 23, 1, 82, 6, 26, 4, 45, 5, 33, 3, 12, 2, 37, 
    6, 72, 1, 9, 7, 15, 5, 28, 8, 92, 9, 12, 0, 59, 3, 64, 4, 87, 2, 73, 
    0, 50, 1, 14, 7, 90, 5, 46, 3, 71, 4, 48, 2, 80, 9, 61, 8, 24, 6, 44, 
    0, 22, 9, 94, 5, 16, 3, 73, 2, 54, 8, 54, 4, 46, 1, 97, 6, 61, 7, 75, 
    9, 55, 3, 67, 6, 77, 4, 30, 7, 6, 1, 32, 8, 47, 5, 93, 2, 6, 0, 40, 
    1, 30, 3, 98, 7, 79, 0, 22, 6, 79, 2, 7, 8, 36, 9, 36, 5, 9, 4, 92, 
    8, 37, 7, 72, 2, 52, 4, 31, 1, 82, 9, 54, 5, 7, 6, 82, 3, 73, 0, 49, 
    1, 73, 3, 83, 7, 45, 2, 76, 4, 43, 9, 29, 0, 35, 5, 92, 8, 39, 6, 28, 
    2, 58, 0, 26, 1, 48, 8, 52, 7, 34, 6, 96, 5, 70, 4, 98, 3, 80, 9, 94, 
    1, 70, 8, 23, 5, 26, 4, 14, 6, 90, 2, 93, 3, 21, 0, 42, 7, 18, 9, 36, 
    4, 28, 6, 76, 7, 25, 0, 17, 1, 84, 2, 67, 8, 87, 3, 43, 9, 88, 5, 84, 
    7, 30, 3, 91, 8, 52, 4, 80, 0, 21, 5, 8, 9, 37, 2, 15, 6, 12, 1, 92, 
    1, 28, 4, 7, 7, 46, 6, 92, 2, 77, 3, 15, 9, 69, 8, 54, 0, 47, 5, 39, 
    9, 50, 5, 44, 2, 64, 8, 38, 4, 93, 6, 33, 7, 75, 0, 41, 1, 24, 3, 5, 
    7, 94, 0, 17, 6, 87, 2, 21, 8, 92, 9, 28, 1, 61, 4, 63, 3, 34, 5, 77, 
    3, 72, 8, 98, 9, 5, 4, 28, 2, 9, 5, 95, 6, 64, 1, 43, 0, 50, 7, 96, 
    0, 85, 2, 85, 8, 39, 1, 98, 7, 24, 3, 71, 5, 60, 4, 55, 9, 22, 6, 35, 
    3, 78, 6, 49, 2, 46, 1, 11, 0, 90, 5, 20, 9, 34, 7, 6, 4, 70, 8, 74
  };
  // Lawrence 30x10 instance (Table 9, instance 5); also called (setd5) or (D5)
  const int la35[] = {
    30, 10, // Number of jobs and machines
    0, 66, 2, 84, 3, 26, 7, 29, 9, 94, 6, 98, 8, 7, 5, 98, 1, 45, 4, 43, 
    3, 32, 0, 97, 6, 55, 2, 88, 8, 93, 9, 88, 1, 20, 4, 50, 7, 17, 5, 5, 
    4, 43, 3, 68, 8, 47, 9, 68, 1, 57, 6, 20, 5, 81, 2, 60, 7, 94, 0, 62, 
    1, 57, 5, 40, 0, 78, 6, 9, 2, 49, 9, 17, 3, 32, 4, 30, 8, 87, 7, 77, 
    0, 52, 4, 30, 3, 48, 5, 48, 1, 26, 9, 17, 6, 93, 8, 97, 7, 49, 2, 89, 
    7, 95, 0, 33, 1, 5, 6, 17, 5, 70, 3, 57, 4, 34, 2, 61, 8, 62, 9, 39, 
    7, 97, 5, 92, 1, 31, 8, 5, 2, 79, 4, 5, 3, 67, 0, 5, 9, 78, 6, 60, 
    2, 79, 4, 6, 7, 20, 8, 45, 6, 34, 3, 24, 9, 26, 5, 68, 1, 16, 0, 46, 
    7, 58, 9, 50, 2, 19, 8, 93, 6, 49, 3, 25, 5, 85, 4, 50, 0, 93, 1, 26, 
    9, 81, 6, 71, 5, 7, 1, 39, 2, 16, 8, 42, 0, 71, 4, 84, 3, 56, 7, 99, 
    8, 9, 0, 86, 9, 6, 3, 71, 6, 97, 5, 85, 4, 16, 2, 42, 7, 81, 1, 81, 
    4, 72, 3, 24, 0, 30, 8, 56, 2, 43, 1, 61, 7, 82, 6, 40, 5, 59, 9, 43, 
    9, 43, 1, 13, 6, 70, 7, 93, 0, 95, 8, 12, 4, 15, 2, 78, 5, 97, 3, 14, 
    0, 14, 6, 26, 1, 71, 3, 46, 8, 80, 5, 31, 4, 37, 9, 27, 7, 92, 2, 67, 
    2, 12, 0, 43, 5, 96, 6, 7, 3, 45, 7, 20, 1, 13, 9, 29, 4, 60, 8, 33, 
    1, 78, 5, 50, 6, 84, 0, 42, 8, 84, 4, 30, 9, 76, 2, 57, 7, 87, 3, 59, 
    4, 49, 7, 50, 1, 15, 8, 13, 0, 93, 6, 50, 9, 32, 5, 59, 3, 10, 2, 35, 
    1, 25, 0, 47, 7, 60, 8, 33, 4, 53, 5, 37, 9, 73, 2, 22, 3, 87, 6, 79, 
    0, 84, 6, 83, 1, 71, 5, 68, 9, 89, 8, 11, 3, 60, 4, 50, 2, 33, 7, 97, 
    1, 14, 0, 38, 6, 88, 5, 5, 4, 77, 7, 92, 8, 24, 2, 73, 9, 52, 3, 71, 
    7, 62, 9, 19, 6, 38, 3, 15, 8, 64, 2, 64, 4, 8, 1, 61, 0, 19, 5, 33, 
    2, 33, 5, 46, 4, 74, 0, 56, 6, 84, 9, 83, 8, 19, 7, 8, 3, 32, 1, 97, 
    4, 50, 3, 71, 6, 50, 2, 97, 9, 8, 0, 17, 7, 19, 8, 92, 5, 54, 1, 52, 
    8, 32, 1, 79, 3, 97, 5, 38, 9, 49, 4, 76, 6, 76, 0, 56, 2, 78, 7, 54, 
    5, 13, 3, 5, 2, 25, 0, 86, 1, 95, 9, 28, 6, 78, 8, 24, 7, 10, 4, 39, 
    7, 48, 2, 59, 0, 20, 9, 7, 5, 31, 6, 97, 1, 89, 4, 32, 3, 25, 8, 41, 
    5, 87, 0, 18, 9, 48, 2, 43, 1, 30, 6, 97, 7, 47, 8, 65, 3, 69, 4, 27, 
    6, 71, 5, 20, 8, 20, 1, 78, 3, 39, 0, 17, 7, 50, 2, 44, 9, 42, 4, 38, 
    0, 50, 9, 42, 3, 72, 5, 7, 1, 77, 7, 58, 4, 78, 2, 89, 6, 70, 8, 36, 
    3, 32, 9, 95, 2, 13, 0, 73, 6, 97, 8, 24, 4, 49, 5, 57, 1, 68, 7, 94
  };
  // Lawrence 15x15 instance (Table 10, instance 1); also called (seti1) or (I1)
  const int la36[] = {
    15, 15, // Number of jobs and machines
    4, 21, 3, 55, 6, 71, 14, 98, 10, 12, 2, 34, 9, 16, 1, 21, 0, 53, 7, 26, 8, 52, 5, 95, 12, 31, 11, 42, 13, 39, 
    11, 54, 4, 83, 1, 77, 7, 64, 8, 34, 14, 79, 12, 43, 0, 55, 3, 77, 6, 19, 9, 37, 5, 79, 10, 92, 13, 62, 2, 66, 
    9, 83, 5, 77, 2, 87, 7, 38, 4, 60, 12, 98, 0, 93, 13, 17, 6, 41, 10, 44, 3, 69, 11, 49, 8, 24, 1, 87, 14, 25, 
    5, 77, 0, 96, 9, 28, 6, 7, 4, 95, 13, 35, 7, 35, 8, 76, 11, 9, 12, 95, 2, 43, 1, 75, 10, 61, 14, 10, 3, 79, 
    10, 87, 4, 28, 8, 50, 2, 59, 0, 46, 11, 45, 14, 9, 9, 43, 6, 52, 7, 27, 1, 91, 13, 41, 3, 16, 5, 59, 12, 39, 
    0, 20, 2, 71, 4, 78, 13, 66, 3, 14, 12, 8, 14, 42, 6, 28, 1, 54, 9, 33, 11, 89, 8, 26, 7, 37, 10, 33, 5, 43, 
    8, 69, 4, 96, 12, 17, 0, 69, 7, 45, 11, 31, 6, 78, 10, 20, 3, 27, 13, 87, 1, 74, 5, 84, 14, 76, 2, 94, 9, 81, 
    4, 58, 13, 90, 11, 76, 3, 81, 7, 23, 9, 28, 1, 18, 2, 32, 12, 86, 8, 99, 14, 97, 0, 24, 10, 45, 6, 72, 5, 25, 
    5, 27, 1, 46, 6, 67, 8, 27, 13, 19, 10, 80, 2, 17, 3, 48, 7, 62, 11, 12, 14, 28, 4, 98, 0, 42, 9, 48, 12, 50, 
    11, 37, 5, 80, 4, 75, 8, 55, 7, 50, 0, 94, 9, 14, 6, 41, 14, 72, 3, 50, 10, 61, 13, 79, 2, 98, 12, 18, 1, 63, 
    7, 65, 3, 96, 0, 47, 4, 75, 12, 69, 14, 58, 10, 33, 1, 71, 9, 22, 13, 32, 5, 57, 8, 79, 2, 14, 11, 31, 6, 60, 
    1, 34, 2, 47, 3, 58, 5, 51, 4, 62, 6, 44, 9, 8, 7, 17, 10, 97, 8, 29, 11, 15, 13, 66, 12, 40, 0, 44, 14, 38, 
    3, 50, 7, 57, 13, 61, 5, 20, 11, 85, 12, 90, 2, 58, 4, 63, 10, 84, 1, 39, 9, 87, 6, 21, 14, 56, 8, 32, 0, 57, 
    9, 84, 7, 45, 5, 15, 14, 41, 10, 18, 4, 82, 11, 29, 2, 70, 1, 67, 3, 30, 13, 50, 6, 23, 0, 20, 12, 21, 8, 38, 
    9, 37, 10, 81, 11, 61, 14, 57, 8, 57, 0, 52, 7, 74, 6, 62, 12, 30, 1, 52, 2, 38, 13, 68, 4, 54, 3, 54, 5, 16
  };
  // Lawrence 15x15 instance (Table 10, instance 2); also called (seti2) or (I2)
  const int la37[] = {
    15, 15, // Number of jobs and machines
    5, 19, 6, 64, 11, 73, 9, 13, 2, 84, 14, 88, 3, 85, 10, 41, 12, 53, 13, 80, 1, 66, 7, 46, 8, 59, 4, 25, 0, 62, 
    1, 67, 3, 74, 7, 41, 2, 57, 14, 52, 0, 14, 9, 64, 8, 84, 6, 78, 5, 47, 13, 28, 4, 84, 10, 63, 12, 26, 11, 46, 
    6, 97, 8, 95, 0, 64, 9, 38, 10, 59, 12, 95, 2, 17, 11, 65, 13, 93, 3, 10, 5, 73, 1, 11, 4, 85, 14, 46, 7, 67, 
    10, 23, 12, 49, 3, 32, 4, 66, 2, 43, 0, 60, 8, 41, 7, 61, 13, 70, 9, 49, 11, 17, 6, 90, 1, 85, 14, 99, 5, 85, 
    9, 98, 8, 57, 3, 73, 6, 9, 0, 73, 7, 7, 1, 98, 4, 13, 13, 41, 5, 40, 11, 85, 10, 37, 2, 68, 14, 79, 12, 17, 
    11, 66, 7, 53, 5, 86, 6, 40, 0, 14, 3, 19, 13, 96, 4, 95, 2, 54, 10, 84, 12, 97, 8, 16, 14, 52, 1, 76, 9, 87, 
    4, 77, 2, 55, 9, 42, 5, 74, 14, 91, 13, 33, 10, 16, 12, 54, 0, 18, 3, 87, 7, 60, 8, 13, 6, 33, 1, 33, 11, 61, 
    6, 41, 5, 39, 11, 82, 9, 64, 14, 47, 10, 28, 7, 78, 13, 49, 1, 79, 4, 58, 2, 92, 3, 79, 12, 6, 0, 69, 8, 76, 
    11, 21, 5, 42, 9, 91, 2, 28, 0, 52, 6, 88, 12, 76, 13, 86, 10, 23, 1, 35, 7, 52, 4, 91, 3, 47, 14, 82, 8, 24, 
    11, 42, 1, 93, 3, 95, 13, 45, 9, 28, 14, 77, 0, 84, 10, 8, 7, 45, 4, 70, 5, 37, 6, 86, 12, 64, 8, 67, 2, 38, 
    4, 97, 12, 81, 1, 58, 7, 84, 5, 58, 0, 9, 11, 87, 3, 5, 2, 44, 13, 85, 6, 89, 10, 77, 9, 96, 14, 39, 8, 77, 
    12, 80, 1, 21, 10, 10, 5, 73, 8, 70, 6, 49, 2, 31, 13, 34, 4, 40, 11, 22, 0, 15, 14, 82, 3, 57, 9, 71, 7, 48, 
    2, 17, 7, 62, 5, 75, 9, 35, 1, 91, 14, 50, 3, 7, 10, 64, 13, 75, 12, 94, 0, 55, 6, 72, 8, 47, 4, 11, 11, 90, 
    11, 93, 6, 57, 1, 71, 12, 70, 9, 93, 5, 20, 3, 15, 13, 77, 10, 58, 0, 12, 2, 67, 8, 68, 14, 7, 7, 29, 4, 52, 
    13, 76, 3, 27, 4, 26, 9, 36, 11, 8, 10, 36, 0, 95, 8, 48, 2, 82, 6, 87, 5, 6, 1, 63, 7, 56, 12, 36, 14, 15
  };
  // Lawrence 15x15 instance (Table 10, instance 3); also called (seti3) or (I3)
  const int la38[] = {
    15, 15, // Number of jobs and machines
    1, 26, 12, 67, 0, 72, 6, 74, 14, 13, 8, 43, 4, 30, 3, 19, 10, 23, 11, 85, 5, 98, 13, 43, 2, 38, 7, 8, 9, 75, 
    14, 42, 0, 39, 4, 55, 12, 46, 1, 19, 8, 93, 9, 80, 5, 26, 10, 7, 6, 50, 11, 57, 3, 73, 2, 9, 7, 61, 13, 72, 
    3, 96, 4, 99, 12, 34, 6, 60, 7, 43, 14, 7, 13, 12, 8, 11, 11, 70, 10, 43, 0, 91, 1, 68, 9, 11, 5, 68, 2, 72, 
    14, 63, 11, 45, 4, 49, 1, 74, 8, 27, 0, 30, 9, 72, 7, 9, 12, 99, 13, 60, 5, 69, 6, 69, 2, 84, 3, 40, 10, 59, 
    2, 91, 0, 75, 9, 98, 3, 17, 10, 72, 13, 31, 11, 9, 14, 98, 7, 50, 5, 37, 4, 8, 8, 65, 1, 90, 12, 91, 6, 71, 
    11, 35, 6, 80, 4, 39, 3, 62, 14, 74, 5, 72, 10, 35, 9, 25, 1, 49, 8, 52, 7, 63, 2, 90, 13, 21, 12, 47, 0, 38, 
    14, 19, 7, 57, 10, 24, 13, 91, 3, 50, 0, 5, 11, 49, 12, 18, 9, 58, 5, 24, 8, 52, 1, 88, 2, 68, 6, 20, 4, 53, 
    7, 77, 14, 72, 5, 35, 11, 90, 4, 68, 6, 18, 3, 9, 0, 33, 8, 60, 10, 18, 12, 10, 13, 60, 1, 38, 2, 99, 9, 15, 
    13, 6, 8, 86, 2, 40, 9, 79, 12, 92, 11, 23, 5, 89, 10, 95, 6, 91, 7, 72, 0, 80, 1, 60, 3, 56, 4, 51, 14, 23, 
    1, 46, 6, 28, 5, 34, 11, 77, 4, 47, 0, 10, 14, 49, 8, 77, 10, 48, 7, 24, 12, 8, 2, 72, 13, 55, 9, 29, 3, 40, 
    10, 22, 4, 89, 12, 79, 0, 7, 9, 15, 1, 6, 11, 30, 6, 38, 5, 11, 8, 52, 3, 20, 7, 5, 14, 9, 2, 20, 13, 28, 
    5, 73, 14, 56, 2, 37, 3, 22, 13, 25, 6, 58, 1, 8, 7, 93, 4, 88, 8, 17, 12, 9, 11, 69, 10, 71, 9, 85, 0, 55, 
    9, 85, 14, 58, 3, 46, 8, 64, 2, 49, 6, 37, 1, 33, 4, 30, 5, 26, 0, 20, 13, 74, 10, 77, 12, 99, 11, 56, 7, 21, 
    10, 17, 3, 24, 4, 89, 5, 15, 11, 60, 1, 42, 8, 98, 2, 64, 13, 92, 0, 63, 7, 52, 12, 54, 6, 75, 14, 23, 9, 38, 
    3, 8, 5, 17, 11, 56, 7, 93, 14, 26, 9, 62, 6, 7, 10, 88, 0, 97, 1, 7, 2, 43, 8, 29, 13, 35, 12, 87, 4, 57
  };
  // Lawrence 15x15 instance (Table 10, instance 4); also called (seti4) or (I4)
  const int la39[] = {
    15, 15, // Number of jobs and machines
    10, 51, 14, 43, 7, 80, 4, 18, 6, 38, 3, 24, 2, 67, 12, 15, 11, 24, 13, 72, 8, 45, 5, 80, 9, 64, 1, 44, 0, 88, 
    6, 40, 9, 88, 10, 77, 5, 59, 11, 20, 3, 52, 8, 70, 0, 40, 4, 32, 13, 76, 12, 43, 7, 31, 2, 21, 14, 5, 1, 47, 
    0, 32, 3, 49, 10, 5, 5, 64, 7, 58, 8, 80, 6, 94, 11, 11, 1, 26, 13, 26, 14, 59, 9, 85, 4, 47, 12, 96, 2, 14, 
    5, 23, 6, 9, 0, 75, 12, 37, 11, 43, 2, 79, 4, 75, 3, 34, 7, 20, 13, 10, 14, 83, 10, 68, 9, 52, 8, 66, 1, 9, 
    12, 69, 9, 59, 3, 28, 14, 62, 13, 36, 1, 26, 6, 84, 11, 16, 8, 54, 5, 42, 2, 54, 0, 6, 10, 40, 7, 88, 4, 79, 
    13, 78, 12, 53, 11, 17, 5, 29, 4, 82, 2, 23, 9, 12, 8, 64, 1, 86, 7, 59, 6, 5, 3, 68, 14, 59, 10, 13, 0, 56, 
    10, 83, 13, 46, 9, 7, 12, 65, 11, 69, 6, 62, 0, 16, 2, 58, 8, 66, 5, 83, 7, 90, 14, 42, 4, 81, 3, 69, 1, 85, 
    7, 73, 10, 71, 8, 64, 6, 10, 9, 20, 11, 99, 4, 24, 14, 65, 5, 82, 3, 72, 12, 43, 1, 82, 13, 27, 2, 24, 0, 33, 
    4, 82, 1, 34, 3, 92, 2, 8, 0, 38, 8, 45, 6, 21, 5, 35, 12, 52, 9, 35, 11, 15, 14, 23, 10, 6, 13, 83, 7, 30, 
    2, 84, 5, 7, 9, 66, 10, 6, 4, 28, 13, 27, 6, 79, 7, 70, 0, 85, 1, 94, 3, 60, 14, 80, 12, 39, 8, 66, 11, 29, 
    3, 44, 6, 58, 13, 14, 8, 65, 1, 72, 5, 14, 12, 52, 4, 21, 9, 25, 0, 5, 11, 51, 7, 61, 14, 55, 10, 42, 2, 36, 
    14, 43, 10, 72, 5, 78, 11, 12, 12, 17, 0, 46, 9, 27, 6, 51, 2, 63, 1, 79, 8, 79, 7, 91, 4, 49, 13, 26, 3, 93, 
    7, 49, 0, 49, 4, 71, 5, 78, 9, 44, 10, 41, 12, 91, 13, 84, 8, 91, 6, 21, 11, 47, 14, 28, 3, 61, 2, 70, 1, 93, 
    3, 25, 4, 85, 0, 66, 2, 45, 10, 95, 12, 21, 8, 84, 5, 24, 9, 53, 7, 67, 6, 91, 11, 11, 13, 32, 1, 30, 14, 89, 
    3, 92, 7, 93, 0, 99, 1, 40, 10, 37, 12, 69, 5, 66, 6, 57, 14, 22, 9, 44, 8, 73, 13, 97, 11, 18, 2, 69, 4, 41
  };
  // Lawrence 15x15 instance (Table 10, instance 5); also called (seti5) or (I5)
  const int la40[] = {
    15, 15, // Number of jobs and machines
    9, 65, 10, 28, 4, 74, 12, 33, 2, 51, 14, 75, 5, 73, 8, 32, 6, 13, 3, 81, 1, 35, 7, 59, 13, 38, 11, 55, 0, 27, 
    0, 64, 1, 53, 11, 83, 2, 33, 4, 6, 9, 52, 14, 72, 8, 7, 13, 90, 12, 21, 6, 23, 3, 10, 10, 39, 5, 49, 7, 72, 
    14, 73, 3, 82, 1, 23, 12, 62, 6, 88, 5, 21, 8, 65, 11, 70, 7, 53, 10, 81, 2, 93, 13, 77, 0, 61, 9, 28, 4, 78, 
    1, 12, 6, 51, 7, 33, 4, 15, 14, 72, 10, 98, 9, 94, 5, 12, 11, 42, 2, 24, 13, 15, 8, 28, 3, 6, 12, 99, 0, 41, 
    12, 97, 5, 7, 9, 96, 4, 15, 14, 73, 13, 43, 0, 32, 8, 22, 11, 42, 1, 94, 2, 23, 7, 86, 6, 78, 10, 24, 3, 31, 
    1, 72, 5, 88, 2, 93, 13, 13, 4, 44, 14, 66, 6, 63, 7, 14, 9, 67, 10, 17, 11, 85, 0, 35, 3, 68, 12, 5, 8, 49, 
    9, 15, 7, 82, 6, 21, 14, 53, 3, 72, 13, 49, 2, 99, 4, 26, 12, 56, 8, 45, 1, 68, 10, 51, 0, 8, 5, 27, 11, 96, 
    3, 54, 7, 24, 4, 14, 8, 38, 5, 36, 2, 52, 14, 55, 12, 37, 11, 48, 0, 93, 13, 60, 10, 70, 1, 23, 6, 23, 9, 83, 
    3, 12, 8, 69, 6, 26, 9, 23, 14, 28, 1, 82, 5, 33, 4, 45, 13, 64, 7, 15, 11, 9, 12, 73, 10, 59, 2, 37, 0, 62, 
    0, 87, 5, 12, 7, 80, 4, 50, 10, 48, 12, 90, 1, 72, 13, 24, 6, 14, 8, 71, 11, 44, 9, 46, 2, 15, 14, 61, 3, 92, 
    2, 54, 0, 22, 6, 61, 4, 46, 3, 73, 5, 16, 12, 6, 9, 94, 14, 93, 13, 67, 8, 54, 7, 75, 11, 32, 10, 40, 1, 97, 
    10, 92, 14, 36, 4, 22, 9, 9, 3, 47, 1, 77, 12, 79, 13, 36, 6, 30, 8, 98, 11, 79, 7, 7, 5, 55, 2, 6, 0, 30, 
    0, 49, 13, 83, 3, 73, 6, 82, 1, 82, 14, 92, 11, 73, 4, 31, 10, 35, 9, 54, 5, 7, 8, 37, 7, 72, 2, 52, 12, 76, 
    10, 98, 12, 34, 13, 52, 4, 26, 1, 28, 3, 39, 8, 80, 5, 29, 9, 70, 0, 43, 6, 48, 7, 58, 2, 45, 14, 94, 11, 96, 
    1, 70, 10, 17, 6, 90, 12, 67, 4, 14, 8, 23, 3, 21, 7, 18, 13, 43, 11, 84, 5, 26, 9, 36, 2, 93, 14, 84, 0, 42
  };

  // trivial 10x10 instance from Bill Cook (BIC2)
  const int orb01[] = {
    10, 10, // Number of jobs and machines
    0, 72, 1, 64, 2, 55, 3, 31, 4, 53, 5, 95, 6, 11, 7, 52, 8, 6, 9, 84, 
    0, 61, 3, 27, 4, 88, 2, 78, 1, 49, 5, 83, 8, 91, 6, 74, 7, 29, 9, 87, 
    0, 86, 3, 32, 1, 35, 2, 37, 5, 18, 4, 48, 6, 91, 7, 52, 9, 60, 8, 30, 
    0, 8, 1, 82, 4, 27, 3, 99, 6, 74, 5, 9, 2, 33, 9, 20, 7, 59, 8, 98, 
    1, 50, 0, 94, 5, 43, 3, 62, 4, 55, 7, 48, 2, 5, 8, 36, 9, 47, 6, 36, 
    0, 53, 6, 30, 2, 7, 3, 12, 1, 68, 8, 87, 4, 28, 9, 70, 7, 45, 5, 7, 
    2, 29, 3, 96, 0, 99, 1, 14, 4, 34, 7, 14, 5, 7, 6, 76, 8, 57, 9, 76, 
    2, 90, 0, 19, 3, 87, 4, 51, 1, 84, 5, 45, 9, 84, 6, 58, 7, 81, 8, 96, 
    2, 97, 1, 99, 4, 93, 0, 38, 7, 13, 5, 96, 3, 40, 9, 64, 6, 32, 8, 45, 
    2, 44, 0, 60, 8, 29, 3, 5, 6, 74, 1, 85, 4, 34, 7, 95, 9, 51, 5, 47
  };
  // doomed 10x10 instance from Monika (MON2)
  const int orb02[] = {
    10, 10, // Number of jobs and machines
    0, 72, 1, 54, 2, 33, 3, 86, 4, 75, 5, 16, 6, 96, 7, 7, 8, 99, 9, 76, 
    0, 16, 3, 88, 4, 48, 8, 52, 9, 60, 6, 29, 7, 18, 5, 89, 2, 80, 1, 76, 
    0, 47, 7, 11, 3, 14, 2, 56, 6, 16, 4, 83, 1, 10, 5, 61, 8, 24, 9, 58, 
    0, 49, 1, 31, 3, 17, 8, 50, 5, 63, 2, 35, 4, 65, 7, 23, 6, 50, 9, 29, 
    0, 55, 6, 6, 1, 28, 3, 96, 5, 86, 2, 99, 9, 14, 7, 70, 8, 64, 4, 24, 
    4, 46, 0, 23, 6, 70, 8, 19, 2, 54, 3, 22, 9, 85, 7, 87, 5, 79, 1, 93, 
    4, 76, 3, 60, 0, 76, 9, 98, 2, 76, 1, 50, 8, 86, 7, 14, 6, 27, 5, 57, 
    4, 93, 6, 27, 9, 57, 3, 87, 8, 86, 2, 54, 7, 24, 5, 49, 0, 20, 1, 47, 
    2, 28, 6, 11, 8, 78, 7, 85, 4, 63, 9, 81, 3, 10, 1, 9, 5, 46, 0, 32, 
    2, 22, 9, 76, 5, 89, 8, 13, 6, 88, 3, 10, 7, 75, 4, 98, 1, 78, 0, 17
  };
  // deadlier 10x10 instance from Bruce Gamble (BRG1)
  const int orb03[] = {
    10, 10, // Number of jobs and machines
    0, 96, 1, 69, 2, 25, 3, 5, 4, 55, 5, 15, 6, 88, 7, 11, 8, 17, 9, 82, 
    0, 11, 1, 48, 2, 67, 3, 38, 4, 18, 7, 24, 6, 62, 5, 92, 9, 96, 8, 81, 
    2, 67, 1, 63, 0, 93, 4, 85, 3, 25, 5, 72, 6, 51, 7, 81, 8, 58, 9, 15, 
    2, 30, 1, 35, 0, 27, 4, 82, 3, 44, 7, 92, 6, 25, 5, 49, 9, 28, 8, 77, 
    1, 53, 0, 83, 4, 73, 3, 26, 2, 77, 6, 33, 5, 92, 9, 99, 8, 38, 7, 38, 
    1, 20, 0, 44, 4, 81, 3, 88, 2, 66, 6, 70, 5, 91, 9, 37, 8, 55, 7, 96, 
    1, 21, 2, 93, 4, 22, 0, 56, 3, 34, 6, 40, 7, 53, 9, 46, 5, 29, 8, 63, 
    1, 32, 2, 63, 4, 36, 0, 26, 3, 17, 5, 85, 7, 15, 8, 55, 9, 16, 6, 82, 
    0, 73, 2, 46, 3, 89, 4, 24, 1, 99, 6, 92, 7, 7, 9, 51, 5, 19, 8, 14, 
    0, 52, 2, 20, 3, 70, 4, 98, 1, 23, 5, 15, 7, 81, 8, 71, 9, 24, 6, 81
  };
  // deadly 10x10 instance from Bruce Shepherd (BRS1)
  const int orb04[] = {
    10, 10, // Number of jobs and machines
    0, 8, 1, 10, 2, 35, 3, 44, 4, 15, 5, 92, 6, 70, 7, 89, 8, 50, 9, 12, 
    0, 63, 8, 39, 3, 80, 5, 22, 2, 88, 1, 39, 9, 85, 6, 27, 7, 74, 4, 69, 
    0, 52, 6, 22, 1, 33, 3, 68, 8, 27, 2, 68, 5, 25, 4, 34, 7, 24, 9, 84, 
    0, 31, 1, 85, 4, 55, 8, 80, 5, 58, 7, 11, 6, 69, 9, 56, 3, 73, 2, 25, 
    0, 97, 5, 98, 9, 87, 8, 47, 7, 77, 4, 90, 3, 98, 2, 80, 1, 39, 6, 40, 
    1, 97, 5, 68, 0, 44, 9, 67, 2, 44, 8, 85, 3, 78, 6, 90, 7, 33, 4, 81, 
    0, 34, 3, 76, 8, 48, 7, 61, 9, 11, 2, 36, 4, 33, 6, 98, 1, 7, 5, 44, 
    0, 44, 9, 5, 4, 85, 1, 51, 5, 58, 7, 79, 2, 95, 6, 48, 3, 86, 8, 73, 
    0, 24, 1, 63, 9, 48, 7, 77, 8, 73, 6, 74, 4, 63, 5, 17, 2, 93, 3, 84, 
    0, 51, 2, 5, 4, 40, 9, 60, 1, 46, 5, 58, 8, 54, 3, 72, 6, 29, 7, 94
  };
  // 10x10 instance from George Steiner (GES1)
  const int orb05[] = {
    10, 10, // Number of jobs and machines
    9, 11, 8, 93, 0, 48, 7, 76, 6, 13, 5, 71, 3, 59, 2, 90, 4, 10, 1, 65, 
    8, 52, 9, 76, 0, 84, 7, 73, 5, 56, 4, 10, 6, 26, 2, 43, 3, 39, 1, 49, 
    9, 28, 8, 44, 7, 26, 6, 66, 4, 68, 5, 74, 3, 27, 2, 14, 1, 6, 0, 21, 
    0, 18, 1, 58, 3, 62, 2, 46, 6, 25, 4, 6, 5, 60, 7, 28, 8, 80, 9, 30, 
    0, 78, 1, 47, 7, 29, 5, 16, 4, 29, 6, 57, 3, 78, 2, 87, 8, 39, 9, 73, 
    9, 66, 8, 51, 3, 12, 7, 64, 5, 67, 4, 15, 6, 66, 2, 26, 1, 20, 0, 98, 
    8, 23, 9, 76, 6, 45, 7, 75, 5, 24, 3, 18, 4, 83, 2, 15, 1, 88, 0, 17, 
    9, 56, 8, 83, 7, 80, 6, 16, 4, 31, 5, 93, 3, 30, 2, 29, 1, 66, 0, 28, 
    9, 79, 8, 69, 2, 82, 4, 16, 5, 62, 3, 41, 6, 91, 7, 35, 0, 34, 1, 75, 
    0, 5, 1, 19, 2, 20, 3, 12, 4, 94, 5, 60, 6, 99, 7, 31, 8, 96, 9, 63
  };
  // trivial 10X10 instance from Bill Cook (BIC1)
  const int orb06[] = {
    10, 10, // Number of jobs and machines
    0, 99, 1, 74, 2, 49, 3, 67, 4, 17, 5, 7, 6, 9, 7, 39, 8, 35, 9, 49, 
    0, 49, 3, 67, 4, 82, 2, 92, 1, 62, 5, 84, 8, 45, 6, 30, 7, 42, 9, 71, 
    0, 26, 3, 33, 1, 82, 2, 98, 5, 83, 4, 16, 6, 64, 7, 65, 9, 36, 8, 77, 
    0, 41, 1, 62, 4, 73, 3, 94, 6, 51, 5, 46, 2, 55, 9, 31, 7, 64, 8, 46, 
    1, 68, 0, 26, 5, 50, 3, 46, 4, 25, 7, 88, 2, 6, 8, 13, 9, 98, 6, 84, 
    0, 24, 6, 80, 2, 91, 3, 55, 1, 48, 8, 99, 4, 72, 9, 91, 7, 84, 5, 12, 
    2, 16, 3, 13, 0, 9, 1, 58, 4, 23, 7, 85, 5, 36, 6, 89, 8, 71, 9, 41, 
    2, 54, 0, 41, 3, 38, 4, 53, 1, 11, 5, 74, 9, 88, 6, 46, 7, 41, 8, 65, 
    2, 53, 1, 50, 4, 40, 0, 90, 7, 7, 5, 80, 3, 57, 9, 60, 6, 91, 8, 47, 
    2, 45, 0, 59, 8, 81, 3, 99, 6, 71, 1, 19, 4, 75, 7, 77, 9, 94, 5, 95
  };
  // doomed 10x10 instance from Monika (MON1)
  const int orb07[] = {
    10, 10, // Number of jobs and machines
    0, 32, 1, 14, 2, 15, 3, 37, 4, 18, 5, 43, 6, 19, 7, 27, 8, 28, 9, 31, 
    0, 8, 3, 12, 4, 49, 8, 24, 9, 52, 6, 19, 7, 23, 5, 19, 2, 17, 1, 32, 
    0, 25, 7, 19, 3, 27, 2, 45, 6, 21, 4, 15, 1, 13, 5, 16, 8, 43, 9, 19, 
    0, 24, 1, 18, 3, 41, 8, 29, 5, 14, 2, 17, 4, 23, 7, 15, 6, 18, 9, 23, 
    0, 27, 6, 29, 1, 39, 3, 21, 5, 15, 2, 15, 9, 25, 7, 26, 8, 44, 4, 20, 
    4, 17, 0, 15, 6, 51, 8, 17, 2, 46, 3, 16, 9, 33, 7, 25, 5, 30, 1, 25, 
    4, 15, 3, 31, 0, 25, 9, 12, 2, 13, 1, 51, 8, 19, 7, 21, 6, 12, 5, 26, 
    4, 8, 6, 29, 9, 25, 3, 15, 8, 17, 2, 22, 7, 32, 5, 20, 0, 11, 1, 28, 
    2, 41, 6, 10, 8, 32, 7, 5, 4, 21, 9, 59, 3, 26, 1, 10, 5, 16, 0, 29, 
    2, 20, 9, 7, 5, 44, 8, 22, 6, 33, 3, 25, 7, 29, 4, 12, 1, 14, 0, 0
  };
  // deadlier 10x10 instance from Bruce Gamble (BRG2)
  const int orb08[] = {
    10, 10, // Number of jobs and machines
    0, 55, 1, 74, 2, 45, 3, 23, 4, 76, 5, 19, 6, 18, 7, 61, 8, 44, 9, 11, 
    0, 63, 1, 43, 2, 51, 3, 18, 4, 42, 7, 11, 6, 29, 5, 52, 9, 29, 8, 88, 
    2, 88, 1, 31, 0, 47, 4, 10, 3, 62, 5, 60, 6, 58, 7, 29, 8, 52, 9, 92, 
    2, 16, 1, 71, 0, 55, 4, 55, 3, 9, 7, 49, 6, 83, 5, 54, 9, 7, 8, 57, 
    1, 7, 0, 41, 4, 92, 3, 94, 2, 46, 6, 79, 5, 34, 9, 38, 8, 8, 7, 18, 
    1, 25, 0, 5, 4, 89, 3, 94, 2, 14, 6, 94, 5, 20, 9, 23, 8, 44, 7, 39, 
    1, 24, 2, 21, 4, 47, 0, 40, 3, 94, 6, 71, 7, 89, 9, 75, 5, 97, 8, 15, 
    1, 5, 2, 7, 4, 74, 0, 28, 3, 72, 5, 61, 7, 9, 8, 53, 9, 32, 6, 97, 
    0, 34, 2, 52, 3, 37, 4, 6, 1, 94, 6, 6, 7, 56, 9, 41, 5, 5, 8, 16, 
    0, 77, 2, 74, 3, 82, 4, 10, 1, 29, 5, 15, 7, 51, 8, 65, 9, 37, 6, 21
  };
  // deadly 10x10 instance from Bruce Shepherd (BRS2)
  const int orb09[] = {
    10, 10, // Number of jobs and machines
    0, 36, 1, 96, 2, 86, 3, 7, 4, 20, 5, 9, 6, 39, 7, 79, 8, 82, 9, 24, 
    0, 16, 8, 95, 3, 67, 5, 63, 2, 87, 1, 24, 9, 62, 6, 49, 7, 92, 4, 16, 
    0, 65, 6, 71, 1, 9, 3, 67, 8, 70, 2, 48, 5, 49, 4, 66, 7, 5, 9, 96, 
    0, 50, 1, 31, 4, 6, 8, 13, 5, 98, 7, 97, 6, 93, 9, 30, 3, 34, 2, 83, 
    0, 99, 5, 7, 9, 55, 8, 78, 7, 68, 4, 81, 3, 90, 2, 75, 1, 66, 6, 40, 
    1, 42, 5, 11, 0, 5, 9, 39, 2, 10, 8, 30, 3, 39, 6, 50, 7, 20, 4, 51, 
    0, 38, 3, 68, 8, 86, 7, 77, 9, 32, 2, 89, 4, 37, 6, 53, 1, 43, 5, 89, 
    0, 19, 9, 11, 4, 37, 1, 41, 5, 72, 7, 7, 2, 52, 6, 31, 3, 68, 8, 10, 
    0, 83, 1, 21, 9, 23, 7, 87, 8, 58, 6, 89, 4, 74, 5, 29, 2, 74, 3, 23, 
    0, 44, 2, 57, 4, 69, 9, 50, 1, 65, 5, 69, 8, 60, 3, 58, 6, 89, 7, 13
  };
  // 10x10 instance from George Steiner (GES2)
  const int orb10[] = {
    10, 10, // Number of jobs and machines
    9, 66, 8, 13, 0, 93, 7, 91, 6, 14, 5, 70, 3, 99, 2, 53, 4, 86, 1, 16, 
    8, 34, 9, 99, 0, 62, 7, 65, 5, 62, 4, 64, 6, 21, 2, 12, 3, 9, 1, 75, 
    9, 12, 8, 26, 7, 64, 6, 92, 4, 67, 5, 28, 3, 66, 2, 83, 1, 38, 0, 58, 
    0, 77, 1, 73, 3, 82, 2, 75, 6, 84, 4, 19, 5, 18, 7, 89, 8, 8, 9, 73, 
    0, 34, 1, 74, 7, 48, 5, 44, 4, 92, 6, 40, 3, 60, 2, 62, 8, 22, 9, 67, 
    9, 8, 8, 85, 3, 58, 7, 97, 5, 92, 4, 89, 6, 75, 2, 77, 1, 95, 0, 5, 
    8, 52, 9, 43, 6, 5, 7, 78, 5, 12, 3, 62, 4, 21, 2, 80, 1, 60, 0, 31, 
    9, 81, 8, 23, 7, 23, 6, 75, 4, 78, 5, 56, 3, 51, 2, 39, 1, 53, 0, 96, 
    9, 79, 8, 55, 2, 88, 4, 21, 5, 83, 3, 93, 6, 47, 7, 10, 0, 63, 1, 14, 
    0, 43, 1, 63, 2, 83, 3, 29, 4, 52, 5, 98, 6, 54, 7, 39, 8, 33, 9, 23
  };

  // Storer, Wu, and Vaccari hard 20x10 instance (Table 2, instance 1)
  const int swv01[] = {
    20, 10, // Number of jobs and machines
    3, 19, 2, 27, 1, 39, 4, 13, 0, 25, 8, 37, 9, 40, 5, 54, 7, 74, 6, 93, 
    2, 69, 0, 30, 4, 1, 3, 4, 1, 64, 7, 71, 5, 2, 9, 84, 6, 31, 8, 8, 
    4, 79, 3, 80, 0, 86, 2, 55, 1, 54, 8, 81, 6, 72, 7, 86, 5, 59, 9, 75, 
    2, 76, 3, 15, 1, 26, 0, 17, 4, 30, 8, 44, 7, 91, 6, 83, 5, 52, 9, 68, 
    4, 73, 3, 87, 1, 74, 0, 39, 2, 98, 9, 100, 5, 43, 8, 17, 7, 7, 6, 77, 
    1, 63, 0, 49, 2, 16, 3, 55, 4, 9, 9, 73, 5, 61, 8, 34, 6, 82, 7, 46, 
    0, 87, 1, 71, 4, 43, 3, 80, 2, 39, 7, 70, 8, 18, 6, 41, 9, 79, 5, 44, 
    4, 70, 2, 22, 0, 73, 3, 62, 1, 64, 5, 25, 8, 19, 6, 69, 9, 41, 7, 28, 
    3, 16, 0, 84, 1, 58, 4, 7, 2, 9, 5, 8, 6, 10, 7, 17, 8, 42, 9, 65, 
    3, 8, 0, 10, 1, 3, 4, 41, 2, 3, 7, 40, 8, 56, 5, 53, 9, 96, 6, 13, 
    4, 62, 1, 60, 3, 64, 2, 12, 0, 39, 5, 2, 7, 64, 6, 87, 9, 21, 8, 60, 
    2, 66, 1, 71, 3, 23, 4, 75, 0, 78, 7, 74, 6, 35, 9, 24, 8, 23, 5, 50, 
    1, 5, 3, 92, 4, 6, 0, 69, 2, 80, 7, 13, 5, 17, 9, 89, 6, 80, 8, 47, 
    0, 82, 3, 84, 1, 24, 2, 47, 4, 93, 7, 85, 5, 34, 6, 73, 8, 28, 9, 91, 
    4, 55, 0, 57, 3, 63, 2, 24, 1, 40, 7, 30, 6, 37, 5, 99, 8, 88, 9, 41, 
    1, 75, 2, 47, 3, 68, 0, 7, 4, 78, 7, 80, 6, 2, 9, 23, 8, 49, 5, 50, 
    0, 91, 4, 25, 2, 10, 1, 21, 3, 94, 8, 6, 7, 59, 5, 84, 9, 75, 6, 70, 
    2, 85, 1, 31, 0, 94, 4, 94, 3, 11, 5, 21, 9, 7, 6, 61, 8, 50, 7, 93, 
    1, 27, 0, 77, 4, 13, 2, 30, 3, 2, 5, 88, 7, 4, 9, 39, 6, 53, 8, 54, 
    1, 34, 2, 12, 3, 31, 0, 24, 4, 24, 7, 16, 5, 6, 9, 88, 8, 81, 6, 11
  };
  // Storer, Wu, and Vaccari hard 20x10 instance (Table 2, instance 2)
  const int swv02[] = {
    20, 10, // Number of jobs and machines
    2, 16, 1, 58, 0, 22, 4, 24, 3, 53, 8, 9, 9, 57, 7, 63, 5, 92, 6, 43, 
    3, 6, 1, 48, 4, 14, 0, 66, 2, 24, 7, 2, 9, 85, 6, 73, 8, 19, 5, 99, 
    4, 100, 2, 90, 0, 63, 1, 14, 3, 31, 5, 27, 9, 15, 8, 1, 6, 51, 7, 33, 
    2, 98, 3, 84, 4, 52, 0, 12, 1, 96, 9, 60, 6, 74, 8, 93, 5, 45, 7, 49, 
    4, 39, 0, 54, 2, 28, 3, 8, 1, 30, 8, 57, 6, 75, 5, 9, 7, 41, 9, 19, 
    3, 94, 0, 8, 2, 89, 1, 13, 4, 37, 8, 36, 6, 63, 9, 24, 5, 71, 7, 97, 
    3, 90, 2, 69, 1, 25, 4, 15, 0, 65, 7, 52, 6, 56, 9, 91, 8, 83, 5, 86, 
    3, 59, 1, 99, 4, 41, 0, 68, 2, 14, 7, 4, 9, 55, 6, 48, 8, 13, 5, 15, 
    4, 36, 2, 17, 1, 51, 0, 16, 3, 54, 8, 45, 5, 50, 7, 98, 6, 68, 9, 82, 
    1, 75, 0, 11, 4, 55, 2, 93, 3, 51, 6, 61, 9, 40, 7, 19, 8, 24, 5, 55, 
    4, 56, 0, 73, 3, 59, 2, 38, 1, 51, 6, 99, 8, 29, 9, 53, 5, 7, 7, 72, 
    3, 68, 4, 50, 1, 88, 2, 88, 0, 33, 5, 47, 8, 52, 6, 26, 9, 74, 7, 68, 
    2, 3, 3, 42, 0, 45, 1, 57, 4, 28, 5, 14, 8, 22, 9, 31, 6, 44, 7, 38, 
    3, 89, 0, 73, 4, 12, 1, 9, 2, 49, 5, 11, 8, 15, 7, 41, 9, 37, 6, 10, 
    3, 76, 2, 97, 4, 100, 1, 92, 0, 25, 5, 8, 9, 92, 7, 51, 6, 58, 8, 65, 
    4, 50, 0, 54, 3, 85, 1, 47, 2, 45, 6, 99, 9, 39, 5, 32, 8, 87, 7, 56, 
    0, 70, 2, 58, 3, 33, 1, 85, 4, 25, 8, 5, 7, 65, 9, 20, 6, 52, 5, 44, 
    1, 22, 3, 45, 4, 60, 0, 66, 2, 5, 7, 61, 6, 73, 9, 60, 5, 14, 8, 44, 
    4, 64, 0, 97, 2, 31, 1, 4, 3, 43, 9, 47, 7, 93, 6, 100, 5, 10, 8, 51, 
    3, 9, 4, 87, 2, 34, 0, 62, 1, 56, 5, 66, 8, 95, 7, 56, 9, 42, 6, 86
  };
  // Storer, Wu, and Vaccari hard 20x10 instance (Table 2, instance 3)
  const int swv03[] = {
    20, 10, // Number of jobs and machines
    2, 19, 0, 30, 1, 68, 4, 55, 3, 24, 8, 34, 7, 72, 5, 32, 9, 62, 6, 45, 
    2, 63, 1, 11, 4, 65, 3, 16, 0, 67, 9, 95, 8, 23, 7, 82, 6, 52, 5, 53, 
    2, 19, 4, 17, 1, 79, 3, 49, 0, 12, 7, 41, 9, 67, 8, 40, 6, 25, 5, 42, 
    0, 42, 2, 71, 3, 27, 4, 95, 1, 19, 5, 48, 8, 100, 6, 31, 7, 25, 9, 38, 
    3, 1, 1, 100, 4, 68, 0, 94, 2, 89, 5, 86, 7, 35, 9, 29, 8, 56, 6, 55, 
    4, 93, 1, 53, 2, 4, 3, 48, 0, 57, 8, 99, 7, 67, 5, 86, 6, 80, 9, 60, 
    4, 82, 1, 95, 2, 12, 0, 60, 3, 80, 8, 88, 7, 5, 6, 81, 9, 52, 5, 69, 
    3, 79, 1, 31, 4, 63, 0, 28, 2, 64, 8, 63, 5, 29, 7, 75, 9, 18, 6, 33, 
    4, 9, 1, 64, 2, 31, 0, 13, 3, 33, 9, 82, 6, 79, 5, 30, 7, 84, 8, 20, 
    2, 14, 0, 56, 1, 95, 4, 34, 3, 13, 6, 16, 5, 44, 7, 45, 8, 62, 9, 86, 
    4, 66, 3, 9, 2, 66, 1, 46, 0, 12, 5, 10, 7, 58, 6, 6, 8, 62, 9, 17, 
    4, 89, 1, 52, 2, 37, 3, 74, 0, 7, 8, 43, 5, 96, 7, 89, 6, 21, 9, 66, 
    1, 73, 3, 68, 2, 5, 4, 49, 0, 67, 9, 23, 7, 7, 5, 44, 8, 30, 6, 29, 
    2, 21, 0, 68, 1, 88, 4, 75, 3, 64, 6, 6, 8, 72, 7, 66, 9, 66, 5, 56, 
    1, 24, 4, 25, 2, 69, 0, 27, 3, 51, 9, 60, 8, 26, 6, 45, 5, 77, 7, 93, 
    2, 19, 3, 17, 1, 82, 4, 75, 0, 34, 5, 67, 9, 89, 6, 91, 7, 13, 8, 35, 
    4, 2, 0, 21, 3, 83, 1, 19, 2, 65, 6, 65, 8, 8, 9, 68, 7, 60, 5, 7, 
    1, 63, 3, 49, 2, 4, 4, 2, 0, 50, 9, 99, 5, 27, 6, 68, 8, 46, 7, 89, 
    0, 48, 4, 45, 3, 100, 2, 66, 1, 30, 6, 58, 7, 73, 9, 94, 5, 36, 8, 5, 
    2, 36, 0, 53, 4, 56, 3, 57, 1, 77, 9, 7, 6, 59, 8, 8, 5, 15, 7, 23
  };
  // Storer, Wu, and Vaccari hard 20x10 instance (Table 2, instance 4)
  const int swv04[] = {
    20, 10, // Number of jobs and machines
    2, 16, 0, 59, 4, 10, 3, 95, 1, 64, 8, 92, 9, 56, 7, 3, 5, 73, 6, 17, 
    1, 5, 4, 64, 3, 30, 2, 14, 0, 96, 9, 11, 8, 73, 7, 35, 6, 93, 5, 12, 
    3, 35, 4, 75, 0, 54, 1, 30, 2, 83, 9, 20, 8, 29, 7, 38, 6, 90, 5, 39, 
    4, 29, 3, 21, 0, 52, 2, 93, 1, 20, 5, 5, 7, 11, 8, 53, 9, 56, 6, 98, 
    0, 17, 3, 16, 4, 41, 1, 78, 2, 100, 5, 55, 8, 27, 6, 2, 7, 87, 9, 55, 
    3, 97, 1, 32, 4, 84, 2, 71, 0, 38, 9, 64, 7, 16, 5, 5, 6, 41, 8, 41, 
    3, 41, 1, 57, 4, 37, 0, 64, 2, 92, 6, 19, 9, 47, 7, 94, 8, 79, 5, 21, 
    0, 23, 3, 67, 1, 39, 4, 98, 2, 63, 8, 83, 5, 45, 6, 89, 9, 81, 7, 44, 
    1, 88, 0, 59, 3, 39, 2, 63, 4, 91, 8, 36, 5, 44, 6, 45, 9, 43, 7, 12, 
    2, 29, 1, 17, 0, 6, 3, 74, 4, 51, 9, 14, 6, 2, 5, 56, 7, 49, 8, 14, 
    3, 75, 2, 10, 4, 1, 0, 35, 1, 99, 7, 56, 5, 95, 9, 78, 6, 53, 8, 82, 
    0, 75, 2, 96, 1, 21, 3, 90, 4, 55, 6, 23, 7, 40, 9, 76, 8, 55, 5, 45, 
    3, 90, 4, 64, 0, 72, 2, 33, 1, 59, 7, 51, 6, 74, 5, 85, 9, 76, 8, 38, 
    3, 57, 1, 84, 2, 87, 4, 2, 0, 68, 8, 4, 5, 77, 6, 37, 7, 37, 9, 94, 
    1, 16, 3, 46, 4, 34, 2, 23, 0, 77, 7, 68, 8, 14, 9, 54, 5, 37, 6, 99, 
    4, 24, 1, 73, 2, 92, 0, 43, 3, 42, 5, 81, 7, 99, 8, 88, 9, 80, 6, 5, 
    1, 56, 2, 51, 0, 3, 4, 87, 3, 25, 5, 62, 7, 11, 8, 88, 6, 68, 9, 29, 
    2, 85, 3, 3, 4, 21, 0, 49, 1, 79, 8, 38, 5, 37, 9, 72, 7, 18, 6, 18, 
    0, 2, 3, 55, 1, 31, 2, 29, 4, 98, 5, 92, 6, 43, 8, 99, 7, 67, 9, 41, 
    4, 69, 3, 64, 0, 61, 1, 13, 2, 31, 5, 6, 8, 84, 9, 94, 7, 32, 6, 54
  };
  // Storer, Wu, and Vaccari hard 20x10 instance (Table 2, instance 5)
  const int swv05[] = {
    20, 10, // Number of jobs and machines
    2, 19, 1, 30, 3, 80, 0, 84, 4, 14, 8, 51, 5, 73, 6, 91, 7, 81, 9, 71, 
    2, 74, 4, 79, 1, 39, 0, 7, 3, 66, 9, 6, 5, 93, 8, 76, 6, 21, 7, 76, 
    4, 90, 3, 33, 1, 38, 2, 73, 0, 61, 8, 61, 7, 76, 5, 86, 9, 28, 6, 35, 
    4, 1, 3, 22, 2, 1, 0, 77, 1, 33, 6, 98, 5, 4, 9, 27, 8, 8, 7, 68, 
    2, 63, 4, 5, 1, 95, 0, 7, 3, 50, 8, 46, 9, 28, 6, 70, 5, 60, 7, 34, 
    0, 98, 1, 73, 4, 15, 3, 21, 2, 32, 7, 24, 9, 9, 8, 24, 5, 7, 6, 34, 
    3, 51, 4, 47, 2, 30, 1, 16, 0, 51, 5, 41, 6, 79, 7, 79, 9, 3, 8, 72, 
    4, 3, 1, 59, 0, 53, 3, 20, 2, 19, 6, 20, 9, 16, 7, 90, 5, 96, 8, 18, 
    1, 34, 2, 55, 3, 97, 0, 93, 4, 90, 7, 81, 5, 63, 8, 41, 6, 1, 9, 51, 
    4, 77, 3, 87, 1, 92, 2, 83, 0, 45, 7, 75, 9, 60, 6, 75, 5, 93, 8, 33, 
    0, 31, 2, 66, 1, 58, 4, 17, 3, 94, 5, 63, 7, 80, 9, 61, 6, 78, 8, 52, 
    4, 70, 1, 25, 2, 75, 0, 89, 3, 41, 7, 100, 5, 73, 6, 28, 8, 94, 9, 88, 
    1, 67, 4, 62, 3, 12, 2, 55, 0, 62, 5, 58, 8, 66, 7, 73, 6, 55, 9, 1, 
    4, 81, 0, 37, 1, 2, 3, 39, 2, 17, 7, 74, 6, 71, 8, 61, 5, 42, 9, 5, 
    3, 62, 0, 31, 4, 63, 2, 31, 1, 5, 9, 7, 7, 77, 8, 34, 6, 34, 5, 3, 
    0, 5, 2, 55, 3, 62, 1, 82, 4, 80, 6, 6, 8, 7, 7, 29, 5, 80, 9, 89, 
    3, 26, 1, 50, 2, 58, 0, 22, 4, 68, 7, 12, 6, 9, 9, 34, 5, 90, 8, 87, 
    0, 50, 2, 28, 1, 64, 4, 34, 3, 63, 7, 9, 9, 48, 6, 63, 8, 61, 5, 2, 
    0, 47, 2, 23, 1, 23, 4, 82, 3, 98, 7, 66, 6, 78, 8, 100, 9, 79, 5, 32, 
    1, 13, 4, 14, 0, 90, 2, 77, 3, 80, 9, 30, 7, 31, 5, 36, 6, 51, 8, 69
  };
  // Storer, Wu, and Vaccari hard 20x15 instance (Table 2, instance 6)
  const int swv06[] = {
    20, 15, // Number of jobs and machines
    1, 16, 6, 58, 2, 22, 4, 24, 5, 53, 3, 9, 0, 57, 10, 63, 8, 92, 12, 43, 7, 41, 13, 26, 14, 20, 9, 44, 11, 93, 
    2, 89, 1, 94, 0, 86, 3, 13, 6, 54, 4, 41, 5, 55, 7, 98, 13, 38, 14, 80, 9, 1, 11, 100, 12, 90, 10, 63, 8, 14, 
    1, 26, 6, 96, 3, 32, 4, 75, 5, 9, 0, 57, 2, 39, 12, 54, 14, 28, 10, 8, 11, 30, 13, 57, 9, 75, 7, 9, 8, 41, 
    3, 37, 2, 36, 5, 63, 0, 24, 6, 71, 1, 97, 4, 74, 14, 19, 12, 45, 8, 24, 11, 71, 13, 53, 10, 61, 9, 6, 7, 32, 
    3, 57, 0, 55, 1, 21, 5, 84, 2, 23, 6, 79, 4, 90, 11, 8, 14, 59, 10, 99, 9, 41, 12, 68, 8, 14, 13, 4, 7, 55, 
    4, 10, 2, 81, 1, 13, 3, 78, 0, 78, 5, 10, 6, 48, 9, 37, 11, 21, 7, 88, 12, 75, 14, 11, 13, 55, 10, 93, 8, 51, 
    6, 100, 2, 52, 3, 54, 1, 37, 5, 26, 4, 74, 0, 87, 8, 13, 12, 88, 10, 94, 14, 73, 7, 55, 11, 68, 9, 50, 13, 88, 
    4, 47, 5, 70, 6, 7, 2, 72, 0, 62, 3, 30, 1, 95, 10, 18, 9, 65, 7, 69, 13, 89, 8, 89, 14, 64, 12, 81, 11, 25, 
    6, 1, 1, 10, 0, 72, 3, 59, 4, 92, 5, 53, 2, 89, 14, 52, 7, 48, 8, 8, 13, 69, 10, 49, 9, 26, 12, 76, 11, 97, 
    6, 85, 2, 47, 4, 45, 1, 99, 0, 39, 5, 32, 3, 87, 10, 56, 8, 98, 11, 13, 7, 96, 12, 71, 14, 95, 9, 11, 13, 78, 
    0, 17, 2, 21, 3, 87, 6, 41, 5, 41, 4, 31, 1, 96, 8, 17, 11, 95, 13, 29, 14, 3, 10, 71, 7, 64, 9, 97, 12, 31, 
    6, 9, 0, 87, 4, 34, 1, 62, 3, 56, 5, 66, 2, 95, 9, 56, 14, 42, 8, 86, 7, 68, 12, 82, 10, 82, 13, 52, 11, 97, 
    3, 86, 1, 37, 2, 49, 0, 2, 6, 30, 5, 63, 4, 4, 14, 47, 8, 84, 10, 5, 13, 13, 9, 39, 12, 18, 7, 76, 11, 63, 
    0, 29, 6, 34, 1, 53, 3, 7, 5, 19, 4, 26, 2, 63, 12, 22, 10, 98, 13, 77, 14, 11, 7, 87, 9, 5, 11, 44, 8, 42, 
    6, 44, 4, 91, 1, 91, 2, 58, 0, 77, 3, 51, 5, 14, 13, 1, 9, 17, 7, 55, 12, 40, 8, 95, 14, 31, 11, 54, 10, 37, 
    5, 59, 4, 47, 1, 56, 6, 39, 2, 7, 0, 43, 3, 39, 13, 75, 10, 43, 12, 32, 9, 6, 11, 93, 7, 69, 8, 47, 14, 93, 
    4, 24, 1, 30, 3, 97, 6, 17, 0, 7, 2, 55, 5, 8, 7, 70, 10, 87, 8, 29, 12, 20, 13, 29, 11, 51, 9, 14, 14, 32, 
    2, 29, 4, 99, 3, 17, 0, 96, 1, 50, 5, 67, 6, 91, 10, 91, 13, 14, 12, 14, 7, 19, 8, 36, 11, 11, 14, 83, 9, 6, 
    0, 7, 6, 60, 3, 31, 5, 76, 1, 23, 2, 83, 4, 30, 8, 73, 14, 76, 11, 17, 10, 53, 13, 9, 12, 72, 7, 89, 9, 24, 
    3, 63, 0, 89, 2, 2, 1, 46, 6, 86, 5, 74, 4, 1, 7, 34, 9, 30, 12, 19, 13, 48, 11, 75, 8, 72, 14, 47, 10, 58
  };
  // Storer, Wu, and Vaccari hard 20x15 instance (Table 2, instance 7)
  const int swv07[] = {
    20, 15, // Number of jobs and machines
    3, 92, 1, 49, 2, 93, 6, 48, 0, 1, 4, 52, 5, 57, 8, 16, 12, 6, 13, 6, 11, 19, 9, 96, 7, 27, 14, 76, 10, 60, 
    5, 4, 3, 96, 6, 52, 1, 87, 2, 94, 4, 83, 0, 9, 11, 85, 10, 47, 8, 63, 9, 31, 13, 26, 12, 46, 7, 49, 14, 48, 
    1, 34, 6, 34, 4, 37, 2, 82, 0, 25, 5, 43, 3, 11, 9, 71, 14, 55, 7, 34, 11, 77, 12, 20, 8, 89, 10, 23, 13, 32, 
    3, 49, 5, 12, 6, 52, 2, 76, 0, 64, 1, 51, 4, 84, 10, 42, 12, 5, 7, 45, 8, 20, 11, 93, 14, 48, 13, 75, 9, 100, 
    2, 35, 1, 1, 3, 15, 6, 49, 5, 78, 4, 80, 0, 99, 9, 88, 7, 24, 11, 20, 10, 100, 8, 28, 14, 71, 13, 1, 12, 7, 
    3, 69, 6, 24, 5, 21, 4, 3, 1, 28, 2, 8, 0, 42, 10, 33, 11, 40, 9, 50, 8, 8, 13, 5, 12, 13, 7, 42, 14, 73, 
    0, 83, 4, 15, 2, 62, 6, 27, 5, 5, 1, 65, 3, 100, 14, 65, 10, 82, 7, 89, 13, 81, 9, 92, 8, 38, 11, 47, 12, 96, 
    6, 98, 4, 24, 2, 75, 0, 57, 1, 93, 3, 74, 5, 10, 7, 44, 13, 59, 11, 51, 12, 82, 14, 65, 10, 8, 8, 12, 9, 24, 
    4, 55, 0, 44, 3, 47, 5, 75, 2, 81, 6, 30, 1, 42, 10, 100, 8, 81, 7, 29, 13, 31, 9, 47, 11, 34, 12, 77, 14, 92, 
    2, 18, 5, 42, 0, 37, 4, 1, 3, 67, 6, 20, 1, 91, 8, 21, 14, 57, 12, 100, 10, 100, 11, 59, 13, 77, 9, 21, 7, 98, 
    3, 42, 1, 16, 4, 19, 6, 70, 2, 7, 0, 74, 5, 7, 12, 50, 9, 74, 8, 46, 14, 88, 13, 71, 10, 42, 7, 34, 11, 60, 
    6, 12, 4, 45, 2, 7, 0, 15, 1, 22, 3, 31, 5, 70, 13, 88, 9, 46, 8, 44, 14, 45, 12, 87, 11, 5, 7, 99, 10, 70, 
    4, 51, 5, 39, 0, 50, 2, 9, 3, 23, 6, 28, 1, 49, 13, 5, 12, 17, 14, 40, 10, 30, 11, 62, 8, 65, 7, 84, 9, 12, 
    6, 92, 0, 67, 5, 85, 1, 88, 3, 18, 4, 13, 2, 70, 7, 69, 14, 10, 13, 52, 8, 42, 11, 82, 10, 19, 12, 21, 9, 5, 
    4, 34, 0, 60, 1, 52, 5, 70, 2, 51, 6, 2, 3, 43, 10, 75, 11, 45, 8, 53, 12, 96, 13, 1, 14, 44, 7, 66, 9, 19, 
    6, 31, 1, 44, 0, 84, 3, 16, 4, 10, 2, 4, 5, 48, 13, 67, 14, 11, 12, 21, 8, 78, 7, 42, 11, 44, 9, 37, 10, 35, 
    1, 20, 4, 40, 3, 37, 2, 68, 6, 42, 0, 11, 5, 6, 10, 44, 11, 43, 12, 17, 14, 3, 7, 77, 13, 100, 9, 82, 8, 5, 
    5, 14, 0, 5, 3, 40, 1, 70, 4, 63, 2, 59, 6, 42, 9, 74, 13, 32, 7, 50, 10, 21, 14, 29, 12, 83, 11, 64, 8, 45, 
    6, 70, 0, 28, 3, 79, 4, 25, 5, 98, 2, 24, 1, 54, 12, 65, 13, 93, 10, 74, 7, 22, 9, 73, 11, 75, 8, 69, 14, 9, 
    5, 100, 2, 46, 4, 69, 3, 41, 1, 3, 6, 18, 0, 41, 8, 94, 11, 97, 12, 30, 14, 96, 7, 7, 9, 86, 13, 83, 10, 90
  };
  // Storer, Wu, and Vaccari hard 20x15 instance (Table 2, instance 8)
  const int swv08[] = {
    20, 15, // Number of jobs and machines
    3, 8, 4, 73, 2, 49, 5, 24, 6, 81, 1, 68, 0, 23, 12, 69, 8, 74, 10, 45, 11, 4, 14, 59, 9, 25, 7, 70, 13, 68, 
    3, 34, 2, 33, 5, 7, 1, 69, 4, 54, 6, 18, 0, 38, 8, 28, 12, 12, 14, 50, 10, 66, 7, 81, 9, 81, 13, 91, 11, 66, 
    0, 8, 6, 20, 3, 52, 4, 83, 5, 18, 2, 82, 1, 68, 7, 50, 14, 54, 11, 6, 10, 73, 13, 48, 9, 20, 8, 93, 12, 99, 
    2, 41, 0, 72, 1, 91, 4, 52, 5, 30, 3, 1, 6, 92, 13, 52, 8, 41, 9, 45, 14, 43, 12, 97, 10, 64, 11, 71, 7, 76, 
    0, 48, 1, 44, 5, 49, 6, 92, 3, 29, 2, 29, 4, 88, 14, 14, 10, 99, 8, 22, 13, 79, 9, 93, 12, 69, 11, 63, 7, 68, 
    0, 56, 6, 42, 2, 42, 3, 93, 1, 80, 4, 54, 5, 94, 12, 80, 14, 69, 11, 39, 8, 85, 10, 95, 13, 12, 9, 28, 7, 64, 
    0, 90, 4, 75, 6, 9, 1, 46, 2, 91, 3, 93, 5, 93, 14, 77, 9, 63, 11, 50, 12, 82, 13, 74, 8, 67, 7, 72, 10, 76, 
    0, 55, 2, 90, 6, 11, 3, 60, 4, 75, 1, 23, 5, 74, 11, 54, 7, 97, 12, 32, 13, 67, 10, 15, 14, 48, 8, 100, 9, 55, 
    6, 71, 5, 64, 2, 40, 0, 32, 3, 92, 1, 59, 4, 69, 13, 68, 14, 34, 12, 71, 8, 28, 9, 94, 7, 82, 10, 1, 11, 58, 
    6, 36, 4, 46, 1, 50, 5, 87, 3, 33, 2, 94, 0, 3, 14, 60, 11, 45, 13, 84, 9, 1, 8, 38, 10, 22, 12, 39, 7, 50, 
    1, 53, 0, 34, 5, 56, 6, 97, 3, 95, 4, 32, 2, 28, 14, 48, 7, 54, 12, 98, 8, 84, 9, 77, 10, 46, 13, 65, 11, 94, 
    2, 1, 5, 97, 0, 77, 4, 82, 6, 14, 1, 18, 3, 74, 14, 52, 11, 14, 12, 93, 9, 35, 8, 34, 13, 84, 10, 6, 7, 81, 
    1, 62, 0, 86, 2, 57, 6, 80, 5, 37, 3, 94, 4, 77, 7, 72, 9, 26, 11, 41, 10, 7, 8, 56, 13, 98, 14, 67, 12, 47, 
    5, 45, 3, 30, 0, 57, 6, 68, 1, 61, 2, 34, 4, 2, 7, 57, 13, 96, 9, 10, 12, 85, 14, 42, 10, 93, 8, 89, 11, 43, 
    6, 49, 4, 53, 1, 51, 2, 4, 0, 17, 5, 21, 3, 31, 10, 45, 13, 45, 9, 63, 11, 21, 8, 4, 7, 23, 14, 90, 12, 1, 
    6, 68, 5, 18, 0, 87, 3, 6, 4, 13, 2, 9, 1, 40, 8, 83, 7, 95, 12, 27, 10, 94, 14, 68, 11, 22, 13, 28, 9, 66, 
    2, 80, 6, 14, 0, 67, 5, 15, 1, 14, 3, 97, 4, 23, 8, 45, 10, 1, 11, 5, 14, 87, 7, 34, 12, 12, 9, 98, 13, 35, 
    4, 33, 2, 20, 3, 74, 6, 20, 5, 3, 0, 90, 1, 37, 13, 56, 12, 38, 8, 7, 14, 84, 9, 100, 11, 41, 10, 6, 7, 97, 
    6, 47, 4, 63, 3, 1, 0, 28, 2, 99, 1, 41, 5, 45, 14, 60, 13, 2, 7, 25, 8, 59, 9, 39, 10, 76, 11, 89, 12, 5, 
    6, 67, 2, 46, 3, 25, 1, 2, 5, 22, 4, 8, 0, 22, 13, 64, 7, 82, 12, 99, 11, 79, 10, 87, 8, 71, 9, 24, 14, 19
  };
  // Storer, Wu, and Vaccari hard 20x15 instance (Table 2, instance 9)
  const int swv09[] = {
    20, 15, // Number of jobs and machines
    5, 8, 3, 73, 0, 69, 2, 38, 6, 6, 4, 62, 1, 78, 9, 79, 8, 59, 13, 77, 11, 22, 10, 80, 12, 58, 14, 49, 7, 48, 
    3, 34, 4, 29, 2, 69, 0, 5, 5, 63, 1, 82, 6, 94, 14, 17, 11, 94, 9, 29, 10, 5, 13, 75, 7, 15, 8, 61, 12, 61, 
    1, 52, 2, 30, 0, 25, 6, 17, 3, 46, 4, 86, 5, 3, 14, 70, 11, 34, 9, 23, 10, 68, 13, 76, 8, 53, 12, 71, 7, 9, 
    2, 50, 4, 20, 3, 24, 0, 53, 1, 97, 5, 79, 6, 92, 14, 3, 12, 52, 10, 75, 9, 74, 8, 59, 7, 75, 13, 84, 11, 99, 
    2, 15, 0, 61, 3, 47, 4, 38, 6, 49, 5, 21, 1, 6, 11, 8, 8, 71, 14, 83, 13, 24, 12, 18, 9, 33, 7, 70, 10, 100, 
    4, 48, 5, 50, 2, 66, 0, 92, 6, 2, 3, 58, 1, 23, 9, 84, 8, 66, 10, 12, 7, 36, 14, 4, 12, 88, 13, 64, 11, 12, 
    3, 29, 0, 25, 6, 44, 5, 87, 2, 42, 1, 44, 4, 86, 8, 28, 10, 86, 9, 74, 14, 77, 13, 59, 12, 94, 7, 58, 11, 16, 
    4, 31, 3, 58, 0, 94, 5, 69, 2, 44, 1, 93, 6, 92, 9, 80, 8, 63, 12, 47, 13, 3, 7, 79, 11, 39, 14, 80, 10, 75, 
    1, 69, 2, 27, 0, 76, 5, 19, 6, 86, 3, 16, 4, 31, 12, 33, 9, 69, 13, 19, 10, 43, 14, 9, 11, 37, 7, 35, 8, 24, 
    2, 75, 3, 78, 6, 41, 4, 60, 5, 59, 0, 42, 1, 60, 12, 18, 8, 31, 10, 15, 7, 54, 14, 60, 9, 20, 11, 61, 13, 69, 
    4, 89, 6, 20, 1, 27, 5, 78, 3, 2, 2, 21, 0, 55, 13, 79, 11, 77, 10, 99, 9, 70, 12, 30, 7, 97, 8, 41, 14, 98, 
    6, 1, 2, 10, 4, 84, 5, 72, 0, 14, 1, 9, 3, 51, 7, 22, 14, 65, 10, 100, 13, 65, 11, 43, 8, 10, 12, 14, 9, 19, 
    5, 50, 2, 13, 3, 49, 6, 75, 1, 42, 0, 81, 4, 89, 9, 100, 14, 54, 13, 37, 10, 7, 11, 38, 8, 25, 12, 78, 7, 79, 
    2, 44, 3, 77, 5, 26, 1, 42, 4, 9, 6, 73, 0, 60, 9, 61, 10, 85, 12, 14, 11, 92, 7, 100, 14, 49, 8, 46, 13, 12, 
    2, 72, 0, 53, 1, 43, 5, 65, 6, 59, 4, 87, 3, 13, 8, 71, 12, 25, 9, 71, 10, 89, 11, 2, 7, 76, 14, 21, 13, 12, 
    2, 60, 6, 28, 5, 33, 1, 36, 0, 6, 3, 96, 4, 48, 9, 40, 11, 79, 10, 60, 8, 39, 13, 34, 7, 54, 12, 20, 14, 52, 
    5, 82, 2, 12, 3, 11, 4, 61, 1, 21, 0, 21, 6, 34, 12, 86, 14, 53, 8, 7, 9, 4, 7, 95, 10, 62, 13, 54, 11, 82, 
    5, 72, 0, 13, 3, 46, 6, 97, 1, 87, 4, 87, 2, 11, 7, 45, 14, 85, 11, 66, 8, 43, 9, 39, 13, 34, 10, 30, 12, 55, 
    1, 39, 5, 19, 0, 19, 4, 73, 6, 63, 3, 30, 2, 69, 9, 36, 7, 13, 10, 96, 12, 27, 13, 59, 14, 76, 11, 62, 8, 14, 
    1, 7, 4, 14, 3, 79, 2, 27, 6, 43, 0, 96, 5, 24, 11, 30, 7, 27, 12, 2, 8, 69, 14, 75, 13, 34, 10, 79, 9, 96
  };
  // Storer, Wu, and Vaccari hard 20x15 instance (Table 2, instance 10)
  const int swv10[] = {
    20, 15, // Number of jobs and machines
    3, 8, 2, 73, 1, 79, 0, 95, 6, 69, 4, 9, 5, 5, 8, 85, 9, 52, 11, 43, 14, 32, 7, 91, 10, 24, 13, 89, 12, 38, 
    6, 45, 1, 70, 4, 84, 3, 24, 5, 18, 0, 20, 2, 71, 8, 21, 7, 60, 9, 98, 10, 70, 13, 52, 12, 34, 11, 23, 14, 52, 
    6, 16, 4, 68, 1, 85, 0, 39, 5, 40, 2, 98, 3, 61, 10, 77, 7, 60, 11, 73, 9, 66, 14, 84, 8, 16, 13, 43, 12, 88, 
    0, 72, 1, 17, 3, 68, 4, 89, 2, 94, 6, 98, 5, 56, 10, 88, 13, 27, 9, 60, 12, 61, 8, 8, 7, 88, 11, 48, 14, 65, 
    6, 78, 2, 24, 5, 28, 0, 73, 4, 21, 1, 69, 3, 52, 14, 32, 8, 83, 11, 48, 10, 29, 13, 48, 12, 92, 9, 43, 7, 82, 
    4, 54, 6, 31, 5, 14, 3, 47, 0, 82, 1, 75, 2, 4, 8, 31, 12, 72, 7, 58, 9, 45, 13, 91, 14, 31, 11, 61, 10, 27, 
    4, 88, 1, 28, 5, 92, 6, 62, 3, 93, 0, 14, 2, 65, 7, 33, 9, 44, 8, 31, 14, 32, 11, 72, 13, 47, 12, 61, 10, 34, 
    0, 52, 1, 59, 5, 98, 3, 6, 2, 19, 6, 53, 4, 39, 8, 74, 12, 48, 10, 33, 13, 49, 11, 92, 7, 22, 14, 41, 9, 37, 
    0, 2, 6, 85, 3, 34, 2, 51, 4, 97, 5, 95, 1, 73, 14, 61, 9, 28, 12, 73, 8, 21, 11, 85, 7, 75, 13, 42, 10, 7, 
    5, 94, 1, 28, 0, 77, 2, 56, 6, 79, 4, 2, 3, 82, 9, 88, 10, 93, 12, 44, 14, 5, 8, 96, 7, 34, 13, 56, 11, 41, 
    2, 15, 5, 88, 6, 18, 3, 14, 1, 82, 0, 58, 4, 33, 13, 19, 10, 42, 9, 36, 14, 57, 12, 85, 7, 3, 11, 62, 8, 36, 
    3, 30, 6, 33, 0, 13, 4, 4, 2, 74, 1, 37, 5, 78, 14, 2, 13, 56, 9, 21, 10, 61, 11, 81, 7, 18, 8, 59, 12, 62, 
    5, 40, 1, 75, 6, 45, 0, 41, 3, 97, 2, 65, 4, 92, 7, 11, 12, 44, 8, 40, 9, 100, 11, 91, 14, 66, 13, 53, 10, 27, 
    1, 83, 2, 52, 0, 84, 3, 66, 5, 3, 6, 5, 4, 71, 13, 41, 10, 42, 11, 63, 12, 50, 14, 43, 8, 3, 9, 35, 7, 18, 
    4, 44, 0, 26, 1, 59, 6, 81, 2, 84, 5, 81, 3, 91, 13, 41, 7, 42, 11, 53, 8, 63, 14, 89, 9, 15, 10, 64, 12, 40, 
    1, 46, 0, 97, 5, 67, 4, 97, 3, 71, 6, 88, 2, 69, 14, 44, 12, 20, 11, 52, 13, 34, 10, 74, 8, 79, 7, 10, 9, 87, 
    3, 71, 6, 13, 4, 100, 2, 67, 1, 57, 5, 24, 0, 36, 7, 88, 14, 79, 8, 21, 9, 86, 12, 60, 11, 28, 10, 14, 13, 3, 
    0, 97, 6, 24, 2, 41, 4, 40, 1, 51, 5, 73, 3, 19, 9, 27, 12, 70, 13, 98, 10, 11, 11, 83, 7, 76, 8, 60, 14, 12, 
    5, 88, 3, 48, 1, 33, 4, 96, 6, 10, 0, 49, 2, 52, 10, 38, 13, 49, 7, 31, 12, 94, 14, 23, 9, 7, 11, 5, 8, 4, 
    2, 85, 0, 100, 5, 51, 6, 91, 1, 21, 3, 83, 4, 30, 12, 23, 9, 48, 8, 19, 11, 47, 10, 95, 7, 23, 14, 78, 13, 22
  };
  // Storer, Wu, and Vaccari hard 50x10 instance (Table 2, instance 11)
  const int swv11[] = {
    50, 10, // Number of jobs and machines
    0, 92, 4, 47, 3, 56, 2, 91, 1, 49, 5, 39, 9, 63, 7, 12, 6, 1, 8, 37, 
    0, 86, 2, 100, 1, 75, 3, 92, 4, 90, 5, 11, 7, 85, 8, 54, 9, 100, 6, 38, 
    1, 4, 4, 94, 3, 44, 2, 40, 0, 92, 8, 53, 6, 40, 9, 5, 5, 68, 7, 27, 
    4, 87, 0, 48, 1, 59, 2, 92, 3, 35, 6, 99, 7, 46, 9, 27, 8, 83, 5, 91, 
    0, 83, 1, 78, 4, 76, 3, 64, 2, 44, 8, 12, 9, 91, 6, 31, 7, 98, 5, 63, 
    3, 49, 0, 15, 1, 100, 4, 18, 2, 24, 6, 92, 9, 65, 5, 26, 7, 29, 8, 24, 
    0, 28, 3, 53, 4, 84, 2, 47, 1, 85, 7, 100, 5, 34, 6, 35, 8, 90, 9, 88, 
    2, 61, 4, 71, 3, 54, 1, 34, 0, 13, 9, 47, 8, 2, 6, 97, 7, 27, 5, 97, 
    0, 85, 2, 75, 1, 33, 4, 72, 3, 49, 7, 23, 5, 12, 8, 90, 6, 87, 9, 42, 
    2, 24, 3, 20, 1, 65, 4, 33, 0, 75, 9, 47, 6, 84, 8, 44, 7, 74, 5, 29, 
    2, 48, 3, 27, 4, 1, 0, 23, 1, 66, 6, 35, 7, 46, 9, 29, 5, 63, 8, 44, 
    2, 79, 0, 4, 4, 61, 3, 46, 1, 69, 7, 10, 8, 88, 9, 19, 6, 50, 5, 34, 
    0, 16, 4, 31, 3, 77, 2, 3, 1, 25, 8, 88, 7, 97, 9, 49, 6, 79, 5, 22, 
    1, 40, 0, 39, 4, 15, 2, 93, 3, 48, 6, 63, 9, 74, 8, 46, 7, 91, 5, 51, 
    4, 48, 0, 93, 2, 8, 3, 50, 1, 5, 6, 48, 7, 46, 9, 35, 5, 88, 8, 97, 
    3, 70, 1, 8, 2, 65, 0, 32, 4, 84, 8, 9, 6, 43, 7, 10, 5, 72, 9, 60, 
    0, 21, 2, 28, 1, 26, 3, 91, 4, 58, 9, 90, 6, 43, 8, 64, 5, 39, 7, 93, 
    1, 50, 2, 60, 0, 51, 4, 90, 3, 93, 7, 20, 9, 33, 8, 27, 6, 12, 5, 89, 
    1, 21, 3, 3, 2, 47, 4, 34, 0, 53, 9, 67, 8, 8, 5, 68, 7, 1, 6, 71, 
    3, 57, 4, 26, 2, 36, 0, 48, 1, 11, 9, 44, 7, 25, 5, 30, 8, 92, 6, 57, 
    1, 20, 0, 20, 4, 6, 3, 74, 2, 48, 9, 77, 8, 15, 5, 80, 7, 27, 6, 10, 
    3, 71, 1, 40, 0, 86, 2, 23, 4, 29, 7, 99, 8, 56, 6, 100, 9, 77, 5, 28, 
    4, 83, 0, 61, 3, 27, 1, 86, 2, 99, 7, 31, 5, 60, 8, 40, 9, 84, 6, 26, 
    4, 68, 1, 94, 3, 46, 2, 60, 0, 33, 7, 46, 5, 86, 9, 63, 6, 70, 8, 89, 
    4, 33, 1, 13, 2, 91, 3, 27, 0, 38, 8, 82, 7, 31, 6, 23, 9, 27, 5, 87, 
    4, 58, 3, 30, 0, 24, 2, 12, 1, 38, 8, 2, 9, 37, 5, 59, 6, 37, 7, 36, 
    2, 62, 1, 47, 4, 5, 3, 39, 0, 75, 7, 60, 9, 65, 8, 61, 6, 77, 5, 31, 
    4, 100, 0, 21, 1, 53, 3, 74, 2, 3, 8, 34, 6, 6, 7, 91, 9, 80, 5, 28, 
    1, 8, 0, 3, 2, 88, 3, 54, 4, 18, 9, 4, 6, 34, 5, 54, 8, 59, 7, 42, 
    3, 33, 4, 72, 0, 83, 2, 17, 1, 23, 6, 24, 8, 60, 9, 96, 7, 78, 5, 70, 
    4, 63, 2, 36, 3, 70, 0, 97, 1, 99, 6, 71, 9, 92, 5, 41, 8, 73, 7, 97, 
    2, 28, 1, 37, 4, 24, 0, 30, 3, 55, 8, 38, 5, 9, 9, 77, 7, 17, 6, 51, 
    3, 15, 0, 46, 2, 14, 4, 18, 1, 99, 9, 48, 6, 41, 5, 10, 7, 47, 8, 80, 
    4, 89, 3, 78, 2, 51, 1, 63, 0, 29, 7, 70, 9, 7, 5, 14, 8, 84, 6, 32, 
    4, 26, 1, 69, 2, 92, 3, 15, 0, 23, 8, 42, 6, 95, 5, 47, 9, 83, 7, 56, 
    1, 38, 2, 44, 3, 47, 4, 23, 0, 10, 9, 63, 7, 65, 6, 21, 5, 70, 8, 56, 
    3, 42, 4, 85, 1, 29, 0, 35, 2, 66, 9, 46, 8, 25, 5, 90, 7, 85, 6, 75, 
    3, 99, 0, 46, 4, 74, 2, 96, 1, 48, 5, 52, 6, 13, 7, 88, 8, 4, 9, 30, 
    1, 15, 3, 80, 4, 47, 2, 25, 0, 8, 9, 61, 7, 70, 8, 23, 6, 93, 5, 5, 
    0, 90, 2, 51, 3, 66, 4, 5, 1, 86, 5, 59, 6, 97, 9, 28, 7, 85, 8, 9, 
    0, 59, 1, 50, 4, 40, 3, 23, 2, 93, 7, 61, 9, 96, 8, 63, 6, 34, 5, 14, 
    1, 62, 2, 72, 4, 30, 0, 21, 3, 15, 5, 77, 6, 13, 7, 2, 8, 22, 9, 22, 
    2, 20, 4, 14, 3, 85, 1, 4, 0, 2, 9, 33, 7, 90, 5, 48, 8, 90, 6, 62, 
    0, 49, 3, 49, 4, 46, 1, 89, 2, 64, 9, 72, 8, 6, 5, 83, 6, 13, 7, 66, 
    4, 74, 1, 55, 2, 73, 0, 25, 3, 16, 7, 19, 9, 38, 6, 22, 5, 26, 8, 63, 
    3, 13, 2, 96, 1, 8, 0, 15, 4, 97, 6, 95, 7, 2, 5, 66, 8, 57, 9, 46, 
    4, 73, 1, 97, 3, 39, 0, 22, 2, 90, 9, 64, 6, 65, 8, 31, 5, 98, 7, 85, 
    3, 43, 2, 67, 0, 38, 1, 77, 4, 11, 7, 61, 5, 7, 9, 95, 8, 97, 6, 69, 
    0, 35, 2, 68, 1, 5, 3, 46, 4, 4, 7, 51, 6, 44, 5, 58, 9, 69, 8, 98, 
    2, 68, 1, 81, 0, 2, 3, 4, 4, 59, 9, 53, 8, 69, 5, 69, 6, 14, 7, 21
  };
  // Storer, Wu, and Vaccari hard 50x10 instance (Table 2, instance 12)
  const int swv12[] = {
    50, 10, // Number of jobs and machines
    0, 92, 4, 49, 1, 93, 3, 48, 2, 1, 7, 52, 6, 57, 9, 16, 5, 6, 8, 6, 
    4, 82, 3, 25, 2, 69, 1, 86, 0, 54, 6, 15, 5, 31, 9, 5, 7, 6, 8, 18, 
    0, 31, 1, 26, 3, 46, 2, 49, 4, 48, 8, 74, 7, 82, 5, 47, 9, 93, 6, 91, 
    0, 34, 4, 37, 1, 82, 3, 25, 2, 43, 6, 11, 9, 71, 5, 55, 7, 34, 8, 77, 
    4, 22, 0, 91, 3, 54, 2, 49, 1, 97, 9, 2, 7, 46, 5, 98, 6, 27, 8, 89, 
    2, 46, 3, 70, 1, 3, 0, 44, 4, 24, 9, 65, 6, 60, 5, 94, 8, 58, 7, 22, 
    3, 53, 0, 99, 1, 80, 2, 74, 4, 29, 6, 72, 7, 54, 5, 98, 8, 60, 9, 69, 
    3, 96, 1, 87, 0, 36, 2, 57, 4, 7, 8, 36, 9, 26, 5, 94, 6, 47, 7, 70, 
    3, 5, 2, 47, 1, 59, 0, 57, 4, 28, 9, 24, 8, 79, 6, 19, 5, 44, 7, 35, 
    0, 96, 1, 4, 3, 60, 2, 43, 4, 39, 7, 97, 5, 2, 9, 81, 6, 89, 8, 91, 
    2, 23, 4, 74, 3, 98, 0, 24, 1, 75, 9, 57, 8, 93, 6, 74, 5, 10, 7, 44, 
    3, 36, 4, 5, 2, 36, 0, 49, 1, 90, 8, 62, 5, 74, 9, 4, 6, 85, 7, 53, 
    2, 44, 1, 47, 3, 75, 4, 81, 0, 30, 7, 42, 8, 100, 9, 81, 6, 29, 5, 31, 
    1, 2, 0, 18, 3, 88, 2, 27, 4, 5, 5, 36, 7, 30, 6, 51, 8, 51, 9, 31, 
    1, 21, 0, 57, 3, 100, 2, 100, 4, 59, 8, 77, 7, 21, 5, 98, 6, 38, 9, 84, 
    4, 97, 2, 72, 1, 70, 3, 99, 0, 42, 6, 94, 5, 59, 9, 90, 8, 78, 7, 13, 
    3, 16, 2, 19, 1, 70, 0, 7, 4, 74, 6, 7, 5, 50, 9, 74, 8, 46, 7, 88, 
    3, 45, 4, 91, 2, 28, 0, 52, 1, 12, 5, 45, 6, 7, 7, 15, 9, 22, 8, 31, 
    3, 56, 2, 3, 1, 8, 4, 25, 0, 90, 8, 99, 6, 22, 9, 65, 7, 51, 5, 31, 
    0, 23, 3, 28, 1, 49, 2, 5, 4, 17, 7, 40, 9, 30, 5, 62, 8, 65, 6, 84, 
    2, 88, 0, 86, 4, 8, 1, 41, 3, 12, 6, 67, 9, 77, 5, 94, 7, 80, 8, 11, 
    4, 81, 3, 42, 0, 19, 2, 100, 1, 10, 5, 23, 9, 71, 8, 18, 6, 93, 7, 36, 
    4, 74, 2, 73, 3, 63, 1, 9, 0, 51, 8, 39, 7, 7, 6, 96, 5, 81, 9, 22, 
    1, 1, 3, 44, 0, 66, 4, 19, 2, 65, 7, 10, 6, 23, 8, 26, 9, 76, 5, 77, 
    1, 54, 2, 18, 4, 99, 0, 79, 3, 22, 5, 2, 6, 42, 8, 54, 7, 90, 9, 28, 
    3, 16, 4, 1, 1, 28, 0, 54, 2, 97, 5, 71, 6, 53, 8, 32, 7, 26, 9, 28, 
    0, 82, 3, 5, 2, 18, 4, 71, 1, 50, 5, 41, 7, 62, 9, 89, 6, 93, 8, 54, 
    2, 63, 3, 59, 0, 42, 1, 74, 4, 32, 5, 50, 6, 21, 7, 29, 8, 83, 9, 64, 
    4, 29, 2, 76, 1, 6, 3, 44, 0, 4, 9, 81, 5, 29, 7, 95, 8, 66, 6, 89, 
    3, 55, 4, 84, 1, 36, 0, 42, 2, 64, 5, 81, 8, 85, 6, 76, 7, 4, 9, 16, 
    4, 100, 0, 46, 1, 69, 3, 41, 2, 3, 6, 18, 5, 41, 7, 94, 8, 97, 9, 30, 
    3, 34, 4, 35, 2, 18, 1, 58, 0, 98, 9, 78, 8, 17, 5, 53, 6, 85, 7, 86, 
    4, 68, 2, 89, 1, 99, 0, 3, 3, 92, 5, 10, 6, 52, 7, 30, 8, 66, 9, 69, 
    0, 21, 3, 65, 4, 19, 2, 14, 1, 76, 9, 84, 6, 45, 5, 24, 8, 54, 7, 73, 
    4, 47, 0, 68, 2, 87, 3, 92, 1, 96, 6, 29, 5, 90, 8, 29, 7, 39, 9, 100, 
    2, 35, 0, 60, 4, 61, 1, 61, 3, 72, 9, 57, 8, 94, 5, 77, 7, 1, 6, 53, 
    3, 85, 2, 38, 0, 79, 4, 43, 1, 71, 6, 44, 5, 87, 8, 61, 7, 51, 9, 37, 
    1, 100, 2, 33, 3, 94, 0, 59, 4, 25, 5, 88, 9, 50, 6, 19, 8, 4, 7, 66, 
    2, 8, 0, 85, 1, 80, 4, 75, 3, 1, 7, 17, 9, 32, 6, 60, 5, 30, 8, 57, 
    4, 25, 2, 98, 1, 94, 3, 49, 0, 34, 9, 37, 7, 80, 6, 50, 8, 25, 5, 72, 
    3, 51, 4, 49, 1, 53, 2, 7, 0, 73, 6, 96, 7, 19, 9, 41, 5, 55, 8, 42, 
    0, 57, 1, 86, 2, 1, 4, 61, 3, 66, 6, 28, 5, 56, 7, 68, 8, 21, 9, 65, 
    2, 98, 1, 100, 0, 47, 4, 28, 3, 4, 7, 34, 9, 55, 5, 32, 6, 72, 8, 66, 
    4, 2, 0, 74, 2, 20, 1, 39, 3, 63, 5, 88, 9, 3, 7, 22, 6, 8, 8, 73, 
    2, 44, 0, 1, 3, 52, 1, 43, 4, 4, 6, 36, 9, 75, 8, 58, 5, 61, 7, 38, 
    2, 21, 4, 6, 3, 32, 1, 74, 0, 57, 5, 72, 8, 10, 9, 34, 6, 91, 7, 94, 
    4, 26, 0, 59, 3, 53, 1, 45, 2, 23, 5, 55, 8, 12, 7, 34, 6, 98, 9, 43, 
    2, 4, 1, 53, 4, 57, 3, 95, 0, 6, 6, 30, 8, 1, 7, 92, 9, 20, 5, 86, 
    1, 98, 2, 77, 3, 65, 4, 51, 0, 85, 7, 23, 6, 79, 5, 30, 8, 41, 9, 17, 
    4, 58, 2, 43, 3, 14, 0, 74, 1, 64, 7, 37, 8, 78, 6, 33, 9, 42, 5, 80
  };
  // Storer, Wu, and Vaccari hard 50x10 instance (Table 2, instance 13)
  const int swv13[] = {
    50, 10, // Number of jobs and machines
    4, 68, 1, 39, 2, 79, 0, 72, 3, 65, 5, 82, 7, 33, 6, 82, 8, 66, 9, 55, 
    2, 14, 3, 45, 0, 18, 4, 72, 1, 27, 7, 57, 6, 90, 8, 19, 9, 19, 5, 50, 
    4, 25, 1, 77, 0, 64, 3, 18, 2, 19, 8, 27, 6, 97, 9, 81, 7, 65, 5, 11, 
    3, 70, 0, 29, 2, 31, 1, 39, 4, 62, 8, 12, 9, 2, 5, 91, 7, 98, 6, 91, 
    2, 90, 4, 51, 3, 38, 1, 27, 0, 29, 6, 67, 8, 95, 9, 60, 7, 86, 5, 64, 
    4, 90, 0, 55, 3, 69, 1, 76, 2, 97, 7, 94, 5, 57, 8, 65, 9, 80, 6, 24, 
    1, 23, 4, 13, 0, 90, 3, 24, 2, 41, 8, 69, 7, 8, 5, 81, 6, 94, 9, 76, 
    3, 19, 1, 37, 0, 16, 4, 4, 2, 68, 6, 45, 8, 79, 9, 4, 7, 30, 5, 33, 
    2, 36, 0, 76, 3, 97, 4, 71, 1, 19, 9, 87, 6, 97, 8, 64, 5, 84, 7, 43, 
    2, 20, 1, 77, 0, 71, 3, 73, 4, 47, 7, 88, 5, 100, 9, 16, 8, 69, 6, 77, 
    3, 55, 4, 96, 0, 8, 2, 61, 1, 40, 8, 46, 7, 29, 9, 71, 5, 89, 6, 59, 
    2, 21, 0, 18, 3, 37, 4, 97, 1, 59, 7, 79, 6, 2, 5, 80, 8, 85, 9, 59, 
    4, 19, 1, 83, 2, 1, 0, 95, 3, 48, 9, 37, 7, 59, 5, 56, 8, 57, 6, 81, 
    0, 8, 1, 60, 4, 91, 3, 85, 2, 27, 9, 39, 5, 31, 6, 62, 7, 94, 8, 12, 
    4, 2, 3, 10, 0, 17, 1, 38, 2, 96, 6, 21, 9, 81, 8, 64, 5, 76, 7, 46, 
    2, 46, 1, 4, 4, 25, 3, 41, 0, 11, 5, 96, 9, 56, 6, 10, 7, 25, 8, 32, 
    0, 21, 1, 77, 4, 22, 2, 72, 3, 53, 9, 28, 7, 23, 5, 2, 8, 52, 6, 83, 
    3, 9, 4, 37, 0, 2, 2, 74, 1, 15, 8, 26, 5, 83, 6, 90, 7, 51, 9, 80, 
    3, 6, 1, 7, 0, 57, 2, 4, 4, 56, 7, 11, 5, 57, 8, 12, 6, 94, 9, 29, 
    1, 40, 2, 93, 3, 65, 4, 66, 0, 96, 9, 5, 7, 32, 8, 85, 5, 93, 6, 94, 
    1, 38, 2, 19, 4, 22, 0, 73, 3, 7, 5, 63, 8, 28, 6, 23, 9, 11, 7, 84, 
    1, 96, 4, 10, 0, 29, 3, 59, 2, 94, 5, 26, 7, 22, 8, 52, 6, 37, 9, 50, 
    1, 38, 3, 31, 2, 76, 0, 8, 4, 8, 6, 50, 5, 95, 8, 5, 9, 25, 7, 62, 
    0, 15, 2, 84, 4, 100, 3, 76, 1, 66, 7, 56, 5, 95, 8, 94, 6, 56, 9, 85, 
    3, 73, 2, 38, 1, 84, 0, 42, 4, 37, 5, 16, 7, 24, 9, 59, 6, 60, 8, 23, 
    3, 43, 1, 79, 0, 80, 2, 44, 4, 65, 5, 81, 7, 7, 8, 93, 6, 55, 9, 34, 
    2, 8, 4, 2, 0, 12, 3, 55, 1, 60, 9, 91, 6, 6, 5, 83, 8, 31, 7, 91, 
    0, 8, 4, 46, 3, 47, 2, 57, 1, 47, 9, 55, 8, 74, 7, 98, 6, 54, 5, 51, 
    2, 56, 4, 90, 1, 41, 0, 35, 3, 62, 7, 4, 5, 15, 9, 89, 6, 73, 8, 66, 
    0, 2, 4, 39, 3, 44, 1, 68, 2, 54, 7, 7, 8, 76, 9, 29, 5, 90, 6, 53, 
    2, 34, 0, 94, 3, 1, 1, 23, 4, 45, 8, 83, 7, 84, 5, 49, 6, 67, 9, 49, 
    4, 4, 2, 70, 1, 19, 0, 19, 3, 92, 5, 70, 7, 33, 9, 50, 8, 82, 6, 48, 
    4, 64, 2, 76, 0, 70, 3, 83, 1, 91, 7, 98, 8, 37, 5, 3, 9, 75, 6, 92, 
    3, 96, 1, 17, 0, 20, 4, 13, 2, 28, 7, 21, 9, 65, 5, 87, 6, 54, 8, 98, 
    0, 68, 4, 40, 3, 98, 2, 90, 1, 38, 7, 45, 8, 21, 5, 9, 9, 3, 6, 47, 
    0, 58, 4, 19, 2, 16, 3, 74, 1, 32, 9, 32, 5, 58, 6, 93, 7, 1, 8, 80, 
    0, 32, 2, 99, 1, 95, 3, 2, 4, 8, 9, 55, 6, 32, 8, 26, 5, 6, 7, 68, 
    3, 7, 4, 45, 2, 19, 0, 97, 1, 56, 7, 22, 9, 72, 8, 98, 5, 59, 6, 20, 
    2, 97, 4, 98, 3, 43, 0, 28, 1, 23, 5, 3, 8, 75, 9, 43, 7, 58, 6, 71, 
    3, 31, 0, 88, 2, 88, 1, 82, 4, 65, 5, 53, 9, 15, 7, 68, 6, 60, 8, 99, 
    4, 4, 0, 100, 2, 95, 1, 11, 3, 28, 5, 80, 7, 25, 9, 87, 6, 25, 8, 9, 
    0, 75, 3, 10, 4, 59, 2, 80, 1, 60, 5, 75, 8, 87, 6, 33, 9, 10, 7, 31, 
    0, 54, 3, 6, 4, 7, 1, 72, 2, 49, 7, 72, 8, 64, 6, 32, 9, 86, 5, 69, 
    4, 15, 3, 19, 1, 18, 0, 84, 2, 96, 9, 71, 8, 64, 6, 38, 5, 58, 7, 62, 
    1, 32, 4, 80, 2, 83, 3, 83, 0, 50, 5, 81, 7, 82, 9, 33, 8, 10, 6, 55, 
    0, 65, 4, 95, 3, 84, 2, 64, 1, 18, 9, 27, 6, 70, 7, 74, 5, 87, 8, 68, 
    1, 50, 2, 49, 0, 96, 3, 1, 4, 89, 8, 42, 5, 88, 9, 91, 6, 64, 7, 3, 
    3, 44, 0, 91, 1, 5, 2, 100, 4, 77, 6, 20, 5, 13, 7, 25, 9, 71, 8, 71, 
    0, 86, 4, 91, 1, 19, 2, 69, 3, 71, 5, 13, 8, 87, 6, 98, 9, 43, 7, 13, 
    4, 8, 0, 60, 3, 31, 2, 93, 1, 8, 9, 1, 7, 19, 6, 8, 5, 85, 8, 24
  };
  // Storer, Wu, and Vaccari hard 50x10 instance (Table 2, instance 14)
  const int swv14[] = {
    50, 10, // Number of jobs and machines
    4, 69, 0, 37, 3, 64, 1, 1, 2, 65, 9, 34, 5, 67, 8, 43, 7, 72, 6, 79, 
    1, 11, 0, 7, 3, 68, 4, 43, 2, 52, 6, 29, 9, 71, 7, 81, 8, 12, 5, 36, 
    4, 90, 3, 29, 1, 1, 2, 1, 0, 14, 8, 38, 5, 13, 9, 21, 7, 41, 6, 97, 
    1, 46, 0, 26, 4, 83, 2, 36, 3, 20, 9, 4, 8, 23, 7, 65, 5, 56, 6, 42, 
    4, 46, 0, 39, 2, 92, 3, 53, 1, 62, 9, 68, 7, 65, 8, 74, 6, 87, 5, 46, 
    4, 13, 1, 44, 3, 43, 2, 67, 0, 75, 6, 5, 9, 94, 5, 95, 7, 28, 8, 85, 
    1, 1, 2, 99, 4, 36, 3, 86, 0, 65, 8, 32, 5, 17, 7, 71, 6, 15, 9, 61, 
    2, 18, 4, 63, 3, 15, 0, 59, 1, 33, 7, 95, 5, 63, 6, 85, 8, 34, 9, 3, 
    4, 13, 2, 25, 0, 82, 3, 23, 1, 26, 7, 22, 9, 35, 8, 16, 6, 24, 5, 41, 
    3, 1, 1, 7, 0, 21, 2, 73, 4, 39, 6, 32, 7, 77, 5, 29, 8, 89, 9, 21, 
    1, 53, 3, 27, 4, 55, 0, 16, 2, 64, 5, 78, 9, 32, 8, 60, 7, 20, 6, 20, 
    1, 71, 2, 54, 3, 21, 0, 20, 4, 23, 9, 40, 5, 99, 7, 61, 6, 94, 8, 71, 
    2, 76, 4, 72, 3, 91, 0, 75, 1, 7, 6, 53, 8, 32, 7, 71, 5, 63, 9, 53, 
    2, 12, 1, 3, 4, 35, 0, 64, 3, 30, 5, 94, 8, 67, 7, 31, 6, 79, 9, 14, 
    4, 63, 1, 28, 3, 87, 0, 89, 2, 52, 8, 2, 9, 21, 7, 92, 6, 44, 5, 37, 
    0, 79, 1, 65, 4, 35, 3, 78, 2, 17, 8, 90, 5, 54, 9, 91, 7, 57, 6, 23, 
    3, 20, 1, 93, 4, 61, 0, 76, 2, 23, 5, 10, 8, 34, 7, 20, 9, 87, 6, 77, 
    0, 37, 2, 17, 1, 92, 4, 30, 3, 59, 5, 47, 8, 7, 7, 45, 6, 13, 9, 60, 
    4, 90, 3, 74, 0, 46, 2, 36, 1, 2, 6, 9, 5, 83, 8, 90, 7, 88, 9, 39, 
    3, 83, 0, 85, 2, 20, 4, 88, 1, 94, 6, 14, 5, 16, 7, 62, 9, 53, 8, 9, 
    0, 4, 4, 16, 2, 64, 1, 60, 3, 79, 5, 37, 6, 49, 7, 67, 9, 95, 8, 5, 
    3, 32, 0, 86, 1, 5, 4, 66, 2, 77, 7, 15, 5, 68, 9, 40, 8, 1, 6, 4, 
    0, 2, 1, 48, 4, 23, 3, 25, 2, 58, 9, 55, 7, 14, 8, 21, 6, 85, 5, 27, 
    1, 71, 4, 92, 3, 99, 2, 56, 0, 81, 7, 79, 6, 66, 9, 42, 8, 47, 5, 43, 
    1, 77, 4, 85, 3, 72, 2, 19, 0, 71, 5, 34, 7, 9, 9, 14, 6, 62, 8, 58, 
    4, 38, 0, 3, 2, 61, 3, 98, 1, 76, 5, 14, 9, 56, 8, 26, 7, 43, 6, 44, 
    1, 68, 4, 54, 0, 62, 2, 93, 3, 22, 6, 57, 7, 79, 9, 19, 5, 77, 8, 45, 
    2, 62, 1, 96, 4, 56, 0, 68, 3, 24, 5, 41, 6, 19, 7, 2, 8, 73, 9, 50, 
    2, 86, 0, 53, 3, 3, 1, 89, 4, 37, 7, 100, 5, 59, 9, 23, 6, 19, 8, 35, 
    3, 90, 4, 94, 0, 21, 2, 78, 1, 85, 5, 94, 6, 90, 8, 28, 9, 92, 7, 56, 
    4, 85, 2, 97, 0, 8, 3, 27, 1, 86, 9, 26, 7, 5, 8, 96, 5, 68, 6, 57, 
    0, 58, 3, 4, 4, 49, 2, 1, 1, 79, 8, 10, 6, 44, 9, 87, 5, 16, 7, 13, 
    3, 85, 0, 24, 4, 23, 1, 41, 2, 59, 8, 20, 6, 52, 5, 58, 9, 75, 7, 77, 
    0, 47, 1, 89, 2, 68, 4, 88, 3, 17, 6, 48, 8, 84, 9, 100, 5, 92, 7, 47, 
    1, 30, 0, 1, 3, 61, 4, 20, 2, 73, 8, 78, 7, 41, 9, 52, 5, 43, 6, 74, 
    0, 11, 4, 58, 3, 66, 2, 67, 1, 18, 8, 42, 7, 88, 9, 49, 5, 62, 6, 71, 
    4, 5, 2, 51, 3, 67, 1, 20, 0, 11, 7, 37, 6, 42, 8, 25, 9, 57, 5, 1, 
    0, 58, 4, 83, 2, 9, 3, 68, 1, 21, 6, 28, 9, 77, 5, 19, 7, 32, 8, 66, 
    3, 85, 2, 58, 0, 65, 1, 80, 4, 50, 7, 79, 5, 43, 8, 29, 9, 9, 6, 18, 
    3, 74, 2, 29, 0, 11, 1, 23, 4, 34, 7, 84, 8, 57, 5, 77, 6, 83, 9, 82, 
    2, 6, 4, 67, 0, 97, 3, 66, 1, 21, 8, 90, 9, 46, 6, 12, 5, 17, 7, 96, 
    4, 34, 1, 5, 2, 13, 0, 100, 3, 12, 8, 63, 7, 59, 5, 75, 6, 91, 9, 89, 
    1, 30, 2, 66, 0, 33, 3, 70, 4, 16, 6, 80, 5, 58, 8, 8, 7, 86, 9, 66, 
    3, 55, 0, 46, 2, 1, 1, 77, 4, 19, 7, 85, 9, 32, 6, 59, 5, 37, 8, 69, 
    2, 3, 0, 16, 1, 48, 4, 8, 3, 51, 7, 72, 6, 19, 8, 58, 9, 59, 5, 94, 
    3, 30, 4, 23, 1, 92, 0, 18, 2, 19, 9, 32, 6, 57, 5, 50, 7, 64, 8, 27, 
    2, 18, 0, 72, 4, 92, 1, 6, 3, 67, 8, 100, 6, 32, 9, 14, 5, 51, 7, 55, 
    4, 48, 0, 87, 1, 96, 2, 58, 3, 83, 8, 77, 5, 26, 7, 77, 9, 72, 6, 86, 
    1, 80, 4, 5, 0, 50, 3, 65, 2, 85, 7, 88, 5, 47, 6, 33, 8, 50, 9, 75, 
    1, 78, 0, 96, 4, 80, 3, 5, 2, 99, 9, 58, 5, 38, 7, 29, 8, 69, 6, 44
  };
  // Storer, Wu, and Vaccari hard 50x10 instance (Table 2, instance 15)
  const int swv15[] = {
    50, 10, // Number of jobs and machines
    2, 93, 4, 40, 0, 1, 3, 77, 1, 77, 5, 16, 9, 74, 8, 11, 6, 51, 7, 92, 
    0, 92, 4, 80, 1, 76, 3, 59, 2, 70, 5, 86, 9, 17, 6, 78, 7, 30, 8, 93, 
    1, 44, 2, 92, 3, 96, 4, 77, 0, 53, 9, 10, 7, 49, 5, 84, 8, 59, 6, 14, 
    1, 60, 2, 19, 3, 76, 0, 73, 4, 85, 7, 13, 8, 93, 5, 68, 9, 50, 6, 78, 
    2, 20, 0, 24, 3, 41, 1, 2, 4, 4, 9, 44, 7, 79, 8, 81, 5, 16, 6, 39, 
    3, 41, 2, 35, 1, 32, 4, 18, 0, 15, 8, 98, 6, 29, 5, 19, 7, 14, 9, 26, 
    1, 59, 0, 45, 4, 53, 3, 44, 2, 98, 5, 84, 6, 23, 7, 45, 8, 39, 9, 89, 
    1, 30, 4, 51, 3, 25, 0, 51, 2, 84, 6, 60, 5, 45, 7, 89, 8, 25, 9, 97, 
    0, 47, 3, 18, 2, 40, 4, 62, 1, 58, 5, 36, 7, 93, 8, 77, 9, 90, 6, 15, 
    3, 33, 1, 68, 0, 41, 4, 72, 2, 20, 6, 69, 7, 47, 5, 22, 9, 47, 8, 22, 
    2, 28, 1, 100, 4, 20, 0, 35, 3, 26, 5, 24, 9, 41, 6, 42, 7, 100, 8, 32, 
    0, 65, 2, 12, 4, 53, 3, 93, 1, 40, 8, 18, 7, 23, 5, 60, 6, 89, 9, 53, 
    0, 58, 1, 60, 4, 97, 3, 31, 2, 50, 9, 85, 5, 64, 7, 38, 6, 85, 8, 35, 
    3, 64, 0, 58, 1, 49, 2, 45, 4, 9, 8, 49, 6, 22, 5, 99, 9, 15, 7, 7, 
    0, 10, 4, 85, 3, 72, 2, 37, 1, 77, 5, 70, 7, 45, 9, 8, 6, 83, 8, 57, 
    4, 93, 0, 87, 1, 87, 2, 18, 3, 4, 8, 78, 5, 67, 9, 20, 6, 17, 7, 35, 
    4, 72, 0, 56, 3, 57, 2, 15, 1, 45, 6, 41, 5, 40, 9, 85, 8, 32, 7, 81, 
    0, 36, 3, 63, 4, 79, 2, 32, 1, 5, 6, 25, 7, 86, 9, 91, 5, 21, 8, 35, 
    2, 83, 4, 29, 0, 9, 1, 38, 3, 73, 7, 50, 9, 99, 5, 18, 8, 29, 6, 41, 
    0, 100, 3, 29, 2, 60, 4, 63, 1, 64, 8, 71, 6, 35, 5, 26, 9, 9, 7, 22, 
    1, 81, 0, 60, 3, 62, 4, 48, 2, 68, 7, 28, 5, 69, 8, 92, 6, 79, 9, 10, 
    0, 40, 4, 80, 1, 41, 2, 10, 3, 68, 8, 28, 9, 51, 7, 33, 6, 82, 5, 25, 
    4, 30, 2, 12, 0, 35, 3, 17, 1, 70, 9, 29, 7, 18, 8, 93, 6, 94, 5, 37, 
    1, 36, 2, 41, 3, 27, 4, 36, 0, 78, 7, 64, 6, 88, 5, 25, 9, 92, 8, 66, 
    2, 65, 3, 27, 4, 74, 0, 32, 1, 40, 5, 88, 8, 73, 6, 92, 7, 83, 9, 42, 
    0, 48, 1, 85, 2, 92, 4, 95, 3, 61, 8, 72, 9, 76, 5, 58, 7, 11, 6, 89, 
    3, 84, 2, 50, 0, 70, 4, 24, 1, 42, 9, 55, 5, 100, 6, 70, 7, 4, 8, 68, 
    0, 95, 4, 41, 2, 11, 3, 98, 1, 85, 5, 64, 6, 8, 7, 26, 8, 6, 9, 6, 
    0, 84, 2, 49, 1, 17, 3, 69, 4, 55, 8, 75, 6, 45, 9, 38, 7, 59, 5, 28, 
    2, 48, 0, 29, 4, 1, 1, 64, 3, 41, 5, 23, 7, 64, 9, 31, 6, 56, 8, 12, 
    2, 81, 4, 25, 3, 33, 0, 22, 1, 50, 5, 74, 9, 56, 8, 33, 7, 85, 6, 83, 
    1, 62, 4, 25, 0, 21, 2, 20, 3, 8, 6, 36, 9, 9, 5, 91, 8, 90, 7, 49, 
    1, 43, 0, 16, 2, 91, 3, 96, 4, 24, 5, 11, 9, 91, 7, 41, 8, 35, 6, 66, 
    1, 91, 2, 20, 4, 44, 0, 42, 3, 87, 9, 57, 6, 15, 5, 38, 8, 42, 7, 89, 
    0, 33, 3, 95, 4, 68, 2, 22, 1, 80, 7, 53, 8, 13, 9, 70, 5, 22, 6, 69, 
    0, 15, 3, 47, 1, 24, 2, 31, 4, 41, 8, 14, 9, 28, 7, 59, 5, 52, 6, 39, 
    2, 95, 0, 42, 4, 5, 1, 57, 3, 67, 6, 30, 9, 21, 8, 70, 5, 9, 7, 20, 
    2, 54, 0, 15, 1, 20, 3, 64, 4, 83, 9, 40, 7, 6, 5, 89, 6, 91, 8, 48, 
    0, 22, 4, 27, 1, 77, 3, 25, 2, 16, 8, 72, 9, 61, 6, 75, 7, 4, 5, 19, 
    3, 68, 1, 82, 2, 16, 0, 83, 4, 2, 7, 10, 8, 88, 5, 41, 9, 21, 6, 66, 
    1, 64, 0, 76, 2, 85, 3, 71, 4, 97, 5, 97, 7, 8, 6, 40, 8, 70, 9, 35, 
    0, 94, 1, 45, 2, 94, 4, 84, 3, 44, 8, 41, 5, 30, 7, 47, 6, 19, 9, 22, 
    2, 23, 1, 10, 0, 82, 3, 93, 4, 90, 8, 67, 7, 9, 9, 18, 5, 22, 6, 87, 
    0, 75, 2, 27, 4, 97, 3, 9, 1, 57, 9, 14, 5, 50, 7, 31, 8, 62, 6, 23, 
    1, 42, 3, 41, 2, 35, 0, 75, 4, 18, 9, 65, 7, 38, 6, 38, 8, 51, 5, 56, 
    4, 72, 1, 63, 0, 33, 2, 27, 3, 41, 5, 52, 7, 42, 9, 10, 6, 14, 8, 71, 
    2, 91, 1, 89, 0, 44, 4, 91, 3, 26, 6, 49, 5, 22, 8, 31, 9, 69, 7, 5, 
    3, 42, 1, 34, 0, 4, 4, 34, 2, 16, 6, 86, 7, 25, 8, 99, 5, 67, 9, 25, 
    4, 34, 1, 93, 0, 26, 3, 81, 2, 9, 7, 96, 8, 79, 9, 68, 5, 76, 6, 10, 
    3, 19, 1, 47, 4, 13, 2, 98, 0, 32, 7, 12, 9, 45, 6, 52, 8, 49, 5, 34
  };
  // Storer, Wu, and Vaccari easy 50x10 instance (Table 2, instance 16)
  const int swv16[] = {
    50, 10, // Number of jobs and machines
    1, 55, 3, 46, 5, 71, 8, 29, 0, 47, 2, 12, 7, 57, 4, 79, 6, 91, 9, 30, 
    2, 96, 6, 94, 8, 98, 0, 55, 3, 10, 1, 95, 5, 95, 7, 37, 9, 82, 4, 2, 
    6, 43, 3, 93, 8, 30, 2, 41, 0, 23, 1, 60, 7, 14, 4, 15, 5, 42, 9, 56, 
    0, 45, 6, 85, 2, 59, 7, 76, 1, 93, 9, 62, 4, 33, 8, 46, 5, 33, 3, 35, 
    2, 45, 3, 36, 8, 11, 6, 96, 7, 96, 1, 8, 0, 75, 5, 6, 4, 13, 9, 2, 
    9, 51, 7, 75, 0, 4, 3, 13, 5, 12, 1, 4, 2, 38, 6, 30, 4, 42, 8, 28, 
    9, 58, 4, 33, 6, 77, 2, 11, 3, 37, 8, 64, 5, 94, 7, 89, 1, 96, 0, 93, 
    6, 37, 3, 67, 0, 88, 9, 92, 8, 19, 4, 27, 7, 46, 1, 58, 2, 60, 5, 55, 
    4, 60, 2, 88, 0, 23, 5, 69, 8, 60, 1, 32, 7, 4, 6, 56, 9, 25, 3, 14, 
    2, 98, 5, 56, 1, 68, 6, 63, 7, 61, 3, 78, 8, 45, 0, 62, 4, 31, 9, 70, 
    7, 66, 8, 80, 0, 18, 3, 97, 9, 47, 5, 38, 1, 26, 2, 8, 6, 90, 4, 90, 
    0, 16, 7, 6, 4, 53, 6, 86, 5, 81, 8, 49, 3, 90, 2, 57, 1, 34, 9, 56, 
    2, 69, 8, 65, 5, 20, 4, 15, 1, 61, 3, 71, 6, 71, 9, 58, 0, 24, 7, 71, 
    4, 84, 5, 20, 9, 58, 0, 55, 8, 98, 2, 75, 7, 46, 3, 81, 1, 71, 6, 46, 
    5, 6, 6, 58, 7, 90, 1, 54, 9, 73, 0, 92, 4, 39, 3, 23, 2, 100, 8, 18, 
    2, 32, 5, 58, 6, 97, 1, 49, 3, 61, 0, 69, 8, 2, 4, 3, 9, 32, 7, 46, 
    0, 78, 7, 14, 4, 98, 3, 26, 8, 25, 9, 45, 6, 12, 2, 98, 1, 99, 5, 69, 
    2, 50, 1, 95, 4, 82, 9, 25, 0, 68, 8, 83, 5, 36, 7, 78, 3, 35, 6, 27, 
    6, 29, 7, 20, 8, 55, 4, 14, 2, 66, 5, 52, 0, 75, 9, 63, 1, 93, 3, 64, 
    1, 11, 0, 18, 9, 42, 4, 81, 7, 2, 2, 39, 3, 83, 6, 11, 5, 38, 8, 52, 
    4, 11, 8, 99, 9, 2, 7, 10, 3, 91, 5, 83, 6, 61, 0, 21, 2, 69, 1, 8, 
    9, 11, 7, 65, 1, 14, 2, 85, 3, 5, 8, 5, 5, 11, 4, 47, 6, 67, 0, 41, 
    9, 60, 7, 9, 8, 16, 2, 4, 5, 34, 6, 2, 4, 30, 1, 32, 0, 51, 3, 51, 
    9, 31, 2, 41, 1, 13, 6, 28, 5, 97, 3, 8, 7, 42, 4, 95, 8, 46, 0, 93, 
    4, 1, 6, 91, 8, 49, 3, 75, 1, 19, 7, 100, 0, 58, 2, 14, 5, 34, 9, 82, 
    3, 28, 5, 68, 9, 30, 7, 68, 1, 10, 6, 20, 8, 47, 4, 51, 0, 44, 2, 32, 
    9, 86, 3, 9, 1, 80, 0, 89, 5, 93, 4, 12, 8, 13, 7, 10, 6, 18, 2, 4, 
    0, 22, 5, 12, 8, 95, 4, 24, 3, 30, 1, 81, 2, 21, 7, 28, 9, 100, 6, 27, 
    1, 87, 0, 68, 2, 64, 3, 33, 7, 59, 5, 95, 6, 1, 9, 14, 8, 82, 4, 43, 
    2, 14, 6, 98, 0, 86, 1, 85, 8, 85, 5, 12, 4, 99, 7, 8, 3, 21, 9, 7, 
    5, 47, 9, 90, 0, 88, 1, 52, 8, 43, 4, 62, 7, 33, 3, 51, 6, 97, 2, 22, 
    2, 59, 7, 26, 4, 76, 0, 26, 3, 71, 8, 59, 1, 73, 9, 70, 5, 57, 6, 10, 
    6, 92, 2, 10, 9, 45, 0, 11, 1, 53, 3, 35, 8, 76, 4, 83, 7, 55, 5, 79, 
    9, 96, 4, 3, 3, 92, 7, 67, 6, 60, 8, 35, 5, 70, 0, 52, 2, 39, 1, 94, 
    4, 65, 0, 17, 9, 26, 7, 46, 5, 81, 1, 42, 2, 64, 6, 46, 3, 96, 8, 59, 
    9, 6, 3, 21, 8, 46, 0, 82, 2, 74, 5, 56, 7, 94, 6, 83, 4, 63, 1, 21, 
    6, 89, 5, 23, 8, 78, 2, 33, 9, 4, 7, 97, 3, 60, 1, 29, 0, 79, 4, 93, 
    0, 46, 1, 46, 4, 20, 7, 91, 2, 76, 9, 83, 3, 14, 6, 61, 5, 84, 8, 76, 
    7, 82, 8, 43, 6, 76, 1, 36, 0, 27, 9, 93, 5, 71, 4, 81, 2, 45, 3, 62, 
    7, 51, 9, 27, 5, 12, 6, 52, 4, 85, 8, 66, 0, 100, 3, 44, 2, 82, 1, 36, 
    3, 75, 7, 13, 6, 63, 1, 78, 4, 1, 8, 60, 2, 24, 5, 10, 9, 56, 0, 3, 
    5, 48, 4, 32, 2, 82, 0, 1, 1, 2, 7, 35, 3, 16, 9, 67, 8, 74, 6, 39, 
    7, 24, 0, 8, 8, 96, 3, 59, 2, 41, 4, 23, 1, 37, 9, 4, 5, 69, 6, 27, 
    1, 23, 9, 3, 2, 85, 6, 93, 5, 18, 7, 47, 0, 96, 8, 6, 4, 60, 3, 3, 
    6, 99, 2, 14, 9, 16, 3, 81, 8, 89, 1, 53, 7, 86, 4, 39, 5, 3, 0, 87, 
    5, 67, 8, 53, 0, 77, 4, 69, 2, 55, 3, 78, 6, 95, 1, 76, 7, 2, 9, 71, 
    1, 5, 6, 89, 0, 37, 3, 88, 7, 20, 9, 4, 4, 77, 8, 27, 5, 31, 2, 47, 
    1, 66, 2, 55, 4, 15, 7, 35, 3, 76, 9, 91, 6, 35, 5, 37, 8, 54, 0, 33, 
    3, 79, 5, 2, 6, 17, 1, 65, 7, 27, 8, 53, 4, 52, 9, 35, 0, 23, 2, 59, 
    9, 100, 0, 55, 5, 14, 2, 86, 4, 69, 3, 87, 8, 46, 1, 3, 6, 89, 7, 100
  };
  // Storer, Wu, and Vaccari easy 50x10 instance (Table 2, instance 17)
  const int swv17[] = {
    50, 10, // Number of jobs and machines
    7, 9, 2, 57, 9, 62, 5, 34, 6, 83, 0, 33, 1, 80, 4, 46, 3, 21, 8, 89, 
    9, 82, 1, 35, 8, 37, 5, 26, 6, 21, 3, 78, 7, 64, 4, 33, 2, 40, 0, 21, 
    7, 14, 5, 49, 3, 48, 9, 34, 4, 52, 1, 16, 2, 78, 0, 24, 8, 58, 6, 43, 
    2, 94, 3, 86, 8, 41, 5, 27, 7, 29, 6, 53, 9, 5, 0, 36, 4, 98, 1, 37, 
    7, 55, 1, 87, 8, 51, 5, 29, 9, 93, 3, 51, 0, 54, 6, 85, 2, 20, 4, 29, 
    2, 88, 1, 98, 3, 67, 8, 41, 6, 23, 9, 70, 7, 26, 4, 28, 5, 17, 0, 87, 
    2, 78, 0, 18, 4, 43, 3, 86, 9, 78, 6, 43, 7, 62, 8, 42, 1, 44, 5, 9, 
    9, 37, 4, 89, 3, 26, 6, 59, 0, 89, 5, 90, 1, 91, 8, 28, 7, 37, 2, 51, 
    3, 82, 2, 31, 1, 98, 5, 25, 0, 16, 7, 23, 9, 92, 4, 89, 6, 32, 8, 12, 
    6, 66, 1, 58, 5, 14, 3, 42, 0, 62, 8, 66, 4, 46, 7, 88, 2, 89, 9, 97, 
    8, 94, 9, 11, 6, 3, 1, 86, 2, 4, 5, 19, 7, 93, 4, 43, 0, 78, 3, 11, 
    5, 22, 1, 87, 9, 61, 2, 2, 3, 15, 6, 37, 7, 81, 0, 17, 8, 31, 4, 73, 
    6, 28, 0, 86, 3, 54, 2, 68, 4, 63, 1, 33, 8, 22, 5, 35, 9, 84, 7, 15, 
    6, 18, 1, 2, 2, 23, 8, 49, 7, 82, 9, 8, 4, 73, 5, 31, 3, 20, 0, 1, 
    7, 49, 5, 8, 2, 36, 8, 31, 6, 47, 3, 90, 0, 7, 9, 6, 1, 44, 4, 51, 
    4, 43, 1, 95, 0, 18, 9, 99, 7, 98, 3, 26, 8, 99, 5, 90, 2, 24, 6, 91, 
    1, 49, 6, 69, 3, 73, 9, 52, 0, 10, 7, 41, 8, 42, 5, 96, 4, 85, 2, 76, 
    0, 5, 1, 69, 3, 38, 7, 35, 5, 23, 2, 40, 8, 17, 4, 33, 6, 99, 9, 82, 
    3, 42, 1, 93, 4, 90, 6, 88, 2, 70, 8, 11, 9, 54, 7, 76, 5, 40, 0, 94, 
    5, 88, 9, 44, 0, 63, 7, 92, 1, 4, 4, 91, 6, 92, 8, 53, 3, 52, 2, 38, 
    5, 83, 3, 75, 1, 44, 2, 79, 7, 63, 6, 32, 0, 10, 4, 2, 9, 6, 8, 56, 
    7, 71, 0, 23, 5, 93, 3, 44, 6, 36, 4, 27, 2, 96, 1, 23, 9, 35, 8, 21, 
    5, 42, 2, 43, 6, 37, 9, 98, 0, 55, 3, 35, 4, 45, 1, 8, 8, 5, 7, 100, 
    0, 40, 8, 34, 2, 7, 9, 17, 5, 60, 4, 98, 7, 34, 6, 23, 1, 37, 3, 58, 
    9, 87, 2, 39, 3, 23, 8, 48, 6, 83, 7, 50, 5, 9, 1, 49, 0, 37, 4, 42, 
    6, 60, 5, 3, 2, 60, 7, 40, 0, 54, 1, 68, 4, 49, 8, 50, 9, 22, 3, 34, 
    5, 22, 1, 55, 2, 32, 0, 83, 8, 38, 4, 22, 6, 29, 7, 23, 9, 59, 3, 90, 
    9, 51, 2, 27, 6, 81, 8, 87, 0, 79, 7, 1, 3, 14, 5, 73, 4, 25, 1, 14, 
    6, 88, 1, 46, 5, 16, 2, 62, 9, 95, 7, 63, 4, 78, 0, 9, 3, 68, 8, 37, 
    4, 77, 2, 13, 8, 96, 3, 61, 0, 21, 7, 39, 5, 12, 6, 49, 9, 73, 1, 86, 
    7, 91, 5, 14, 3, 37, 0, 17, 9, 49, 4, 27, 1, 68, 2, 60, 6, 42, 8, 15, 
    9, 13, 4, 25, 6, 62, 0, 4, 1, 31, 8, 76, 5, 3, 7, 8, 3, 26, 2, 95, 
    7, 45, 5, 50, 1, 14, 0, 69, 9, 43, 4, 1, 6, 73, 8, 35, 3, 1, 2, 61, 
    4, 57, 1, 1, 0, 74, 8, 1, 6, 96, 2, 92, 7, 85, 5, 42, 3, 12, 9, 38, 
    7, 49, 5, 31, 8, 79, 6, 83, 1, 40, 4, 65, 3, 34, 2, 32, 9, 97, 0, 25, 
    9, 24, 5, 40, 4, 81, 3, 10, 6, 59, 8, 83, 2, 66, 1, 28, 7, 33, 0, 31, 
    5, 33, 4, 39, 3, 50, 1, 96, 7, 62, 2, 72, 8, 42, 6, 86, 9, 66, 0, 80, 
    3, 88, 7, 47, 0, 35, 4, 69, 1, 79, 9, 61, 2, 25, 8, 56, 5, 68, 6, 96, 
    9, 23, 6, 95, 0, 42, 1, 84, 8, 57, 4, 42, 2, 2, 5, 79, 3, 29, 7, 90, 
    9, 96, 8, 21, 4, 17, 7, 12, 1, 25, 2, 9, 6, 7, 5, 26, 0, 81, 3, 51, 
    1, 63, 7, 16, 6, 40, 2, 22, 9, 48, 5, 87, 0, 15, 8, 24, 3, 37, 4, 55, 
    7, 95, 0, 60, 3, 62, 2, 7, 9, 2, 8, 81, 5, 83, 4, 64, 1, 68, 6, 66, 
    3, 24, 7, 60, 6, 35, 2, 77, 1, 85, 8, 57, 9, 29, 5, 59, 4, 53, 0, 14, 
    1, 24, 6, 30, 0, 9, 3, 89, 8, 72, 4, 77, 2, 7, 5, 23, 9, 73, 7, 35, 
    0, 66, 8, 12, 1, 9, 5, 50, 2, 14, 9, 76, 4, 90, 3, 43, 7, 48, 6, 63, 
    3, 97, 1, 29, 0, 59, 4, 64, 9, 17, 2, 77, 5, 60, 7, 16, 6, 61, 8, 40, 
    9, 5, 4, 22, 2, 3, 8, 63, 5, 1, 7, 23, 0, 1, 3, 61, 1, 92, 6, 19, 
    6, 91, 8, 74, 1, 88, 5, 2, 7, 61, 4, 39, 0, 35, 2, 23, 9, 84, 3, 27, 
    8, 87, 5, 58, 7, 44, 1, 6, 6, 22, 3, 57, 9, 78, 4, 19, 2, 74, 0, 6, 
    4, 6, 1, 94, 0, 45, 2, 54, 9, 67, 7, 90, 5, 19, 8, 72, 6, 70, 3, 58
  };
  // Storer, Wu, and Vaccari easy 50x10 instance (Table 2, instance 18)
  const int swv18[] = {
    50, 10, // Number of jobs and machines
    7, 35, 6, 23, 2, 92, 4, 5, 5, 40, 1, 90, 3, 30, 9, 35, 8, 8, 0, 86, 
    2, 60, 3, 97, 8, 21, 9, 70, 7, 82, 0, 12, 4, 3, 5, 45, 1, 75, 6, 69, 
    7, 96, 2, 38, 0, 61, 1, 55, 4, 31, 5, 48, 9, 79, 3, 4, 6, 12, 8, 29, 
    4, 83, 7, 82, 8, 97, 1, 43, 0, 95, 6, 92, 2, 18, 3, 29, 5, 4, 9, 67, 
    3, 46, 9, 80, 8, 66, 2, 38, 4, 95, 1, 40, 7, 89, 0, 32, 6, 64, 5, 1, 
    6, 57, 4, 80, 8, 68, 7, 27, 0, 90, 5, 45, 3, 98, 9, 59, 1, 6, 2, 94, 
    5, 50, 0, 91, 2, 97, 9, 63, 7, 52, 3, 48, 4, 4, 8, 96, 1, 18, 6, 100, 
    7, 23, 6, 43, 3, 25, 8, 83, 2, 76, 9, 41, 1, 88, 0, 31, 5, 44, 4, 13, 
    2, 20, 3, 90, 9, 20, 4, 42, 8, 72, 5, 46, 1, 27, 0, 81, 6, 40, 7, 34, 
    7, 80, 5, 97, 0, 42, 2, 49, 9, 10, 1, 10, 3, 71, 4, 71, 6, 14, 8, 98, 
    2, 79, 3, 29, 0, 96, 7, 66, 1, 58, 8, 31, 4, 47, 5, 76, 6, 59, 9, 88, 
    8, 93, 6, 3, 1, 7, 3, 27, 5, 66, 7, 23, 0, 60, 4, 97, 2, 66, 9, 55, 
    9, 12, 8, 39, 4, 77, 5, 79, 0, 26, 7, 58, 2, 98, 6, 38, 3, 31, 1, 28, 
    6, 8, 9, 48, 4, 4, 1, 87, 3, 38, 2, 28, 8, 10, 0, 19, 7, 82, 5, 83, 
    5, 6, 9, 13, 2, 86, 6, 19, 3, 26, 7, 79, 0, 55, 1, 85, 8, 33, 4, 30, 
    3, 37, 8, 26, 7, 29, 6, 74, 9, 43, 5, 17, 0, 45, 2, 28, 1, 58, 4, 15, 
    7, 15, 3, 37, 6, 21, 5, 47, 2, 90, 0, 37, 9, 33, 1, 42, 4, 7, 8, 62, 
    8, 49, 4, 46, 1, 28, 7, 18, 6, 41, 2, 57, 0, 75, 3, 21, 9, 3, 5, 32, 
    6, 98, 1, 30, 8, 24, 4, 91, 9, 73, 7, 25, 5, 49, 0, 40, 2, 9, 3, 4, 
    6, 33, 3, 94, 1, 21, 2, 90, 9, 86, 7, 85, 5, 29, 0, 17, 4, 94, 8, 90, 
    6, 3, 4, 85, 1, 66, 7, 61, 8, 57, 3, 84, 2, 5, 9, 40, 0, 54, 5, 70, 
    7, 81, 1, 98, 2, 45, 0, 18, 6, 65, 9, 1, 4, 98, 3, 30, 8, 84, 5, 82, 
    6, 40, 7, 77, 3, 72, 1, 97, 5, 39, 4, 21, 0, 59, 8, 42, 9, 90, 2, 26, 
    5, 57, 3, 63, 1, 14, 4, 64, 6, 23, 8, 78, 2, 54, 0, 51, 9, 100, 7, 96, 
    5, 61, 1, 55, 6, 73, 2, 87, 4, 35, 3, 41, 7, 96, 0, 32, 8, 91, 9, 60, 
    9, 19, 5, 90, 8, 91, 0, 45, 3, 66, 2, 84, 1, 61, 7, 3, 6, 84, 4, 100, 
    2, 33, 9, 72, 6, 27, 8, 14, 3, 59, 0, 39, 7, 20, 5, 29, 4, 54, 1, 88, 
    4, 45, 0, 18, 3, 73, 2, 26, 8, 55, 6, 22, 7, 27, 1, 46, 9, 43, 5, 77, 
    2, 57, 9, 16, 1, 71, 8, 25, 7, 50, 3, 41, 6, 58, 5, 71, 4, 9, 0, 32, 
    8, 48, 9, 32, 0, 42, 3, 73, 1, 56, 7, 53, 6, 3, 5, 66, 4, 15, 2, 44, 
    6, 69, 7, 14, 1, 2, 8, 40, 4, 70, 9, 90, 3, 38, 2, 31, 5, 55, 0, 50, 
    9, 100, 8, 14, 0, 55, 2, 5, 5, 12, 4, 79, 1, 68, 3, 83, 6, 89, 7, 78, 
    4, 26, 5, 44, 8, 39, 1, 84, 7, 64, 9, 98, 3, 38, 2, 2, 6, 27, 0, 18, 
    3, 98, 2, 10, 9, 99, 8, 50, 0, 20, 6, 12, 4, 7, 1, 57, 7, 87, 5, 89, 
    0, 64, 8, 63, 7, 98, 5, 31, 1, 30, 6, 62, 3, 11, 4, 89, 9, 31, 2, 34, 
    3, 26, 6, 43, 4, 69, 7, 27, 8, 92, 2, 51, 1, 10, 5, 29, 9, 21, 0, 37, 
    8, 21, 5, 98, 0, 64, 6, 38, 2, 23, 1, 13, 7, 89, 9, 89, 4, 21, 3, 27, 
    4, 39, 7, 32, 1, 67, 0, 33, 5, 16, 2, 43, 6, 62, 3, 42, 9, 70, 8, 90, 
    7, 73, 9, 45, 3, 37, 0, 45, 2, 61, 6, 25, 5, 15, 4, 5, 8, 58, 1, 98, 
    7, 94, 0, 17, 6, 15, 5, 81, 9, 64, 3, 62, 1, 2, 8, 16, 2, 35, 4, 40, 
    5, 32, 6, 37, 9, 11, 0, 25, 1, 37, 8, 21, 2, 76, 7, 52, 4, 56, 3, 87, 
    3, 23, 2, 40, 1, 6, 7, 31, 6, 25, 9, 98, 8, 29, 4, 4, 5, 25, 0, 33, 
    8, 96, 9, 30, 1, 95, 3, 2, 6, 3, 2, 22, 0, 62, 4, 30, 7, 1, 5, 99, 
    9, 54, 5, 3, 0, 78, 2, 43, 6, 90, 7, 88, 4, 1, 8, 97, 1, 30, 3, 96, 
    5, 29, 6, 60, 3, 80, 1, 94, 2, 67, 0, 42, 8, 17, 9, 27, 7, 75, 4, 86, 
    1, 17, 5, 62, 2, 25, 7, 80, 6, 62, 9, 19, 8, 81, 3, 73, 0, 57, 4, 90, 
    9, 31, 3, 54, 5, 28, 1, 19, 4, 4, 2, 34, 8, 64, 6, 46, 7, 60, 0, 27, 
    9, 95, 7, 1, 2, 43, 3, 6, 4, 7, 8, 66, 1, 45, 5, 13, 0, 80, 6, 1, 
    3, 20, 7, 82, 0, 87, 1, 65, 6, 64, 8, 61, 2, 21, 5, 32, 9, 16, 4, 37, 
    0, 49, 3, 54, 2, 31, 8, 69, 1, 21, 5, 2, 6, 73, 9, 35, 4, 66, 7, 82
  };
  // Storer, Wu, and Vaccari easy 50x10 instance (Table 2, instance 19)
  const int swv19[] = {
    50, 10, // Number of jobs and machines
    7, 74, 1, 27, 5, 66, 3, 89, 6, 58, 0, 11, 8, 77, 9, 17, 2, 70, 4, 97, 
    5, 10, 0, 11, 2, 38, 3, 60, 1, 50, 7, 35, 6, 94, 9, 52, 4, 2, 8, 20, 
    7, 17, 0, 65, 6, 93, 8, 62, 9, 91, 5, 2, 1, 51, 2, 4, 3, 19, 4, 10, 
    4, 87, 3, 3, 9, 81, 0, 17, 6, 44, 2, 82, 7, 16, 5, 13, 8, 100, 1, 85, 
    9, 18, 6, 33, 7, 35, 0, 78, 2, 68, 3, 68, 8, 3, 5, 2, 4, 53, 1, 25, 
    2, 36, 8, 41, 6, 60, 9, 43, 0, 66, 5, 34, 3, 24, 7, 11, 1, 5, 4, 55, 
    9, 52, 4, 99, 6, 62, 0, 50, 1, 24, 8, 73, 7, 19, 3, 23, 2, 15, 5, 2, 
    4, 85, 9, 21, 3, 27, 7, 53, 0, 86, 1, 36, 6, 35, 5, 99, 8, 30, 2, 43, 
    6, 43, 5, 31, 9, 99, 2, 12, 0, 6, 7, 79, 3, 81, 1, 18, 8, 73, 4, 55, 
    4, 90, 6, 100, 1, 15, 0, 40, 7, 96, 9, 25, 5, 43, 8, 23, 2, 31, 3, 7, 
    5, 61, 4, 88, 6, 10, 3, 48, 0, 100, 2, 62, 1, 83, 8, 20, 7, 42, 9, 19, 
    9, 35, 7, 41, 6, 16, 3, 58, 0, 86, 2, 69, 5, 58, 1, 93, 4, 47, 8, 77, 
    2, 61, 0, 40, 4, 99, 1, 51, 7, 46, 6, 39, 3, 43, 9, 37, 8, 88, 5, 9, 
    4, 15, 8, 38, 2, 84, 5, 98, 6, 17, 1, 91, 7, 91, 9, 23, 3, 48, 0, 98, 
    3, 26, 2, 42, 8, 55, 4, 24, 0, 43, 1, 83, 9, 27, 7, 38, 6, 37, 5, 58, 
    5, 21, 8, 78, 6, 97, 0, 77, 9, 82, 4, 26, 3, 22, 1, 90, 7, 57, 2, 31, 
    4, 3, 9, 44, 3, 90, 1, 64, 5, 52, 8, 35, 7, 18, 2, 45, 0, 4, 6, 14, 
    8, 60, 6, 59, 3, 67, 2, 85, 0, 43, 7, 93, 5, 44, 4, 22, 1, 68, 9, 38, 
    4, 77, 8, 41, 2, 74, 6, 99, 0, 100, 1, 45, 9, 14, 3, 26, 7, 98, 5, 77, 
    8, 38, 9, 57, 7, 42, 5, 64, 1, 80, 6, 81, 4, 70, 3, 13, 2, 41, 0, 65, 
    9, 36, 4, 22, 8, 39, 0, 76, 1, 78, 2, 27, 5, 55, 3, 10, 6, 5, 7, 71, 
    7, 70, 9, 81, 1, 60, 5, 85, 3, 63, 6, 97, 2, 61, 8, 44, 0, 5, 4, 35, 
    9, 38, 0, 94, 2, 46, 5, 20, 8, 87, 1, 41, 4, 41, 3, 40, 7, 99, 6, 48, 
    7, 30, 6, 9, 5, 13, 2, 79, 8, 81, 0, 25, 9, 93, 4, 85, 3, 78, 1, 76, 
    4, 6, 8, 58, 6, 51, 7, 48, 2, 68, 3, 34, 5, 78, 9, 59, 1, 98, 0, 36, 
    4, 90, 6, 56, 7, 97, 9, 37, 0, 38, 1, 47, 2, 56, 3, 8, 5, 37, 8, 7, 
    0, 66, 8, 15, 1, 39, 5, 89, 7, 3, 9, 54, 3, 24, 2, 14, 6, 99, 4, 73, 
    3, 12, 9, 37, 4, 79, 8, 95, 0, 50, 1, 74, 6, 1, 5, 55, 7, 98, 2, 49, 
    8, 99, 9, 79, 3, 99, 2, 87, 0, 80, 4, 13, 5, 99, 6, 13, 1, 54, 7, 61, 
    1, 51, 9, 21, 3, 32, 6, 20, 0, 80, 7, 58, 2, 91, 5, 84, 8, 62, 4, 91, 
    1, 11, 8, 38, 2, 14, 9, 12, 3, 39, 5, 34, 0, 37, 6, 94, 4, 10, 7, 2, 
    6, 76, 9, 86, 3, 40, 4, 30, 2, 97, 0, 59, 8, 100, 7, 9, 5, 55, 1, 86, 
    3, 33, 1, 49, 0, 94, 2, 17, 6, 17, 8, 70, 5, 17, 7, 42, 4, 26, 9, 24, 
    4, 75, 1, 20, 9, 93, 2, 58, 3, 51, 0, 94, 6, 24, 7, 70, 8, 51, 5, 82, 
    8, 59, 1, 9, 3, 59, 5, 62, 9, 79, 7, 53, 6, 48, 4, 98, 2, 76, 0, 71, 
    6, 90, 2, 35, 5, 89, 0, 59, 9, 28, 7, 51, 4, 69, 3, 36, 1, 32, 8, 27, 
    5, 10, 6, 85, 4, 97, 1, 3, 0, 79, 9, 86, 3, 10, 7, 80, 2, 37, 8, 39, 
    7, 60, 0, 27, 5, 69, 8, 58, 6, 67, 2, 36, 9, 31, 3, 69, 1, 16, 4, 22, 
    2, 27, 5, 16, 6, 15, 4, 40, 8, 16, 1, 92, 9, 60, 7, 43, 3, 2, 0, 7, 
    1, 79, 7, 99, 0, 27, 9, 56, 5, 29, 6, 17, 8, 67, 4, 34, 3, 86, 2, 61, 
    6, 57, 7, 100, 4, 73, 9, 17, 8, 3, 3, 64, 2, 99, 0, 71, 5, 27, 1, 90, 
    2, 80, 5, 23, 4, 54, 6, 39, 9, 77, 3, 65, 7, 59, 0, 7, 1, 63, 8, 32, 
    4, 98, 6, 17, 8, 44, 5, 1, 3, 10, 7, 56, 2, 95, 9, 80, 0, 99, 1, 64, 
    8, 60, 7, 74, 3, 60, 6, 30, 0, 81, 5, 25, 4, 89, 9, 19, 2, 59, 1, 21, 
    1, 67, 0, 42, 8, 93, 2, 47, 5, 34, 7, 11, 6, 100, 9, 15, 4, 99, 3, 2, 
    9, 35, 3, 61, 5, 93, 8, 83, 7, 87, 4, 66, 0, 96, 2, 55, 1, 41, 6, 61, 
    8, 22, 5, 25, 7, 29, 3, 70, 6, 93, 1, 19, 0, 49, 9, 62, 2, 19, 4, 73, 
    8, 11, 4, 93, 5, 97, 1, 28, 2, 14, 0, 75, 7, 41, 3, 40, 9, 62, 6, 66, 
    7, 76, 6, 61, 8, 64, 3, 90, 0, 20, 2, 43, 9, 50, 1, 13, 5, 4, 4, 47, 
    3, 38, 4, 11, 0, 30, 5, 37, 7, 57, 9, 64, 1, 68, 8, 42, 2, 19, 6, 79
  };
  // Storer, Wu, and Vaccari easy 50x10 instance (Table 2, instance 20)
  const int swv20[] = {
    50, 10, // Number of jobs and machines
    8, 100, 7, 30, 4, 42, 9, 11, 2, 31, 1, 71, 5, 41, 0, 1, 3, 55, 6, 94, 
    4, 81, 6, 20, 3, 96, 7, 39, 8, 29, 0, 90, 9, 61, 2, 64, 1, 86, 5, 47, 
    5, 80, 0, 56, 1, 88, 7, 19, 2, 68, 8, 95, 3, 44, 4, 22, 9, 60, 6, 80, 
    4, 86, 6, 70, 0, 88, 2, 15, 7, 50, 1, 54, 9, 88, 3, 25, 8, 89, 5, 33, 
    0, 48, 1, 57, 4, 86, 8, 60, 3, 78, 5, 4, 9, 60, 7, 40, 2, 11, 6, 25, 
    6, 23, 7, 9, 1, 90, 0, 51, 2, 52, 9, 14, 5, 30, 4, 1, 8, 25, 3, 83, 
    1, 30, 4, 75, 5, 76, 9, 100, 7, 54, 2, 41, 6, 50, 8, 75, 0, 1, 3, 28, 
    2, 46, 3, 78, 1, 37, 7, 12, 6, 56, 4, 50, 8, 66, 5, 39, 0, 8, 9, 72, 
    1, 24, 6, 90, 0, 32, 3, 6, 2, 99, 9, 22, 8, 12, 4, 63, 7, 81, 5, 52, 
    6, 62, 3, 9, 8, 59, 0, 66, 4, 41, 1, 32, 5, 29, 7, 79, 9, 84, 2, 4, 
    9, 57, 5, 99, 6, 2, 3, 17, 0, 51, 7, 10, 4, 14, 1, 64, 2, 99, 8, 27, 
    7, 81, 0, 67, 9, 83, 2, 30, 5, 25, 6, 87, 1, 29, 3, 7, 8, 93, 4, 1, 
    5, 65, 8, 53, 9, 48, 4, 28, 7, 74, 0, 60, 6, 77, 2, 22, 1, 5, 3, 98, 
    1, 97, 5, 37, 0, 71, 7, 49, 6, 51, 3, 17, 4, 38, 9, 67, 8, 28, 2, 31, 
    0, 20, 8, 94, 3, 39, 6, 73, 9, 63, 4, 8, 2, 57, 1, 27, 7, 26, 5, 42, 
    8, 77, 1, 68, 9, 20, 7, 100, 4, 1, 5, 77, 6, 17, 3, 35, 2, 65, 0, 86, 
    8, 68, 6, 62, 4, 79, 7, 84, 1, 60, 3, 56, 0, 10, 9, 86, 5, 60, 2, 30, 
    4, 71, 2, 74, 6, 6, 1, 56, 3, 69, 0, 8, 8, 50, 9, 78, 5, 4, 7, 89, 
    8, 29, 5, 5, 1, 59, 3, 96, 0, 46, 4, 91, 2, 48, 7, 53, 6, 21, 9, 82, 
    2, 19, 9, 96, 0, 73, 1, 39, 5, 54, 8, 50, 7, 60, 3, 50, 4, 65, 6, 78, 
    7, 68, 4, 15, 2, 26, 3, 26, 0, 13, 9, 13, 5, 96, 8, 70, 6, 27, 1, 93, 
    6, 41, 8, 18, 4, 66, 7, 9, 1, 31, 2, 92, 0, 3, 3, 78, 5, 41, 9, 53, 
    5, 9, 0, 64, 2, 15, 6, 73, 4, 12, 1, 43, 8, 89, 7, 69, 3, 32, 9, 22, 
    5, 93, 6, 19, 3, 74, 8, 81, 0, 72, 2, 94, 9, 19, 1, 26, 4, 53, 7, 7, 
    3, 48, 2, 29, 5, 51, 8, 72, 7, 35, 6, 32, 1, 38, 0, 98, 4, 58, 9, 54, 
    0, 94, 9, 23, 4, 41, 6, 53, 2, 53, 7, 27, 1, 62, 3, 68, 8, 84, 5, 49, 
    4, 4, 1, 4, 0, 66, 7, 90, 9, 78, 2, 29, 5, 2, 6, 86, 3, 23, 8, 46, 
    3, 78, 5, 61, 2, 97, 7, 68, 8, 92, 0, 15, 4, 12, 6, 77, 1, 12, 9, 22, 
    0, 100, 7, 89, 6, 71, 2, 70, 8, 89, 4, 72, 5, 78, 3, 23, 9, 37, 1, 2, 
    0, 91, 3, 74, 2, 36, 4, 72, 6, 62, 1, 80, 9, 20, 7, 77, 5, 47, 8, 80, 
    1, 44, 0, 67, 4, 66, 8, 99, 6, 59, 5, 5, 7, 15, 2, 38, 3, 40, 9, 19, 
    1, 69, 9, 35, 3, 86, 0, 7, 2, 35, 5, 32, 6, 66, 4, 89, 8, 63, 7, 52, 
    3, 3, 4, 68, 1, 66, 7, 27, 6, 41, 5, 2, 9, 77, 0, 45, 2, 40, 8, 39, 
    4, 66, 3, 42, 7, 79, 0, 55, 6, 98, 9, 44, 5, 6, 8, 73, 1, 55, 2, 1, 
    3, 80, 8, 18, 9, 94, 2, 27, 5, 42, 4, 17, 7, 74, 0, 65, 6, 6, 1, 27, 
    2, 73, 4, 70, 5, 51, 0, 84, 8, 29, 9, 95, 1, 97, 7, 28, 3, 68, 6, 89, 
    9, 85, 6, 56, 5, 54, 3, 76, 2, 50, 0, 43, 1, 8, 7, 93, 4, 17, 8, 65, 
    1, 1, 3, 17, 2, 61, 5, 38, 4, 71, 7, 18, 0, 40, 9, 94, 6, 41, 8, 74, 
    3, 30, 8, 22, 6, 39, 9, 56, 5, 3, 7, 64, 4, 74, 2, 21, 0, 93, 1, 1, 
    0, 17, 8, 8, 9, 20, 5, 38, 3, 85, 7, 5, 2, 63, 1, 18, 4, 89, 6, 88, 
    8, 87, 5, 44, 0, 42, 1, 34, 9, 11, 7, 13, 3, 71, 4, 88, 6, 32, 2, 12, 
    2, 39, 1, 73, 6, 43, 0, 48, 9, 77, 8, 48, 5, 23, 7, 66, 3, 94, 4, 68, 
    1, 98, 7, 19, 3, 69, 6, 5, 8, 85, 9, 19, 0, 30, 2, 43, 5, 87, 4, 70, 
    2, 45, 1, 60, 4, 30, 9, 71, 5, 35, 0, 75, 3, 75, 6, 41, 8, 67, 7, 37, 
    3, 63, 7, 39, 2, 16, 9, 69, 1, 46, 5, 20, 6, 57, 4, 51, 0, 66, 8, 40, 
    2, 7, 7, 73, 6, 17, 1, 21, 0, 24, 8, 2, 5, 68, 4, 22, 9, 36, 3, 60, 
    1, 20, 4, 17, 8, 12, 9, 29, 5, 28, 0, 7, 3, 38, 6, 57, 7, 22, 2, 75, 
    5, 53, 4, 7, 7, 5, 8, 27, 9, 38, 2, 100, 6, 48, 0, 53, 1, 11, 3, 18, 
    1, 49, 7, 47, 4, 81, 8, 9, 0, 20, 2, 63, 3, 15, 6, 1, 9, 10, 5, 5, 
    4, 49, 6, 27, 7, 17, 5, 64, 2, 30, 8, 56, 0, 42, 3, 97, 9, 82, 1, 34
  };

  // Yamada and Nakano 20x20 instance (Table 4, instance 1)
  const int yn1[] = {
    20, 20, // Number of jobs and machines
    17, 13, 2, 26, 11, 35, 4, 45, 12, 29, 13, 21, 7, 40, 0, 45, 3, 16, 15, 10, 18, 49, 10, 43, 14, 25, 8, 25, 1, 40, 6, 16, 19, 43, 5, 48, 9, 36, 16, 11, 
    8, 21, 6, 22, 14, 15, 5, 28, 10, 10, 2, 46, 11, 19, 19, 13, 13, 18, 18, 14, 3, 11, 4, 21, 16, 30, 1, 29, 0, 16, 15, 41, 17, 40, 12, 38, 7, 28, 9, 39, 
    4, 39, 3, 28, 8, 32, 17, 46, 0, 35, 14, 14, 1, 44, 10, 20, 13, 12, 6, 23, 18, 22, 9, 15, 11, 35, 7, 27, 16, 26, 5, 27, 15, 23, 2, 27, 12, 31, 19, 31, 
    4, 31, 10, 24, 3, 34, 6, 44, 18, 43, 12, 32, 2, 35, 15, 34, 19, 21, 7, 46, 13, 15, 5, 10, 9, 24, 14, 37, 17, 38, 1, 41, 8, 34, 0, 32, 16, 11, 11, 36, 
    19, 45, 1, 23, 5, 34, 9, 23, 7, 41, 16, 10, 11, 40, 12, 46, 14, 27, 8, 13, 4, 20, 2, 40, 15, 28, 13, 44, 17, 34, 18, 21, 10, 27, 0, 12, 6, 37, 3, 30, 
    13, 48, 2, 34, 3, 22, 7, 14, 12, 22, 14, 10, 8, 45, 19, 38, 6, 32, 16, 38, 11, 16, 4, 20, 0, 12, 5, 40, 9, 33, 17, 35, 1, 32, 10, 15, 15, 31, 18, 49, 
    9, 19, 5, 33, 18, 32, 16, 37, 12, 28, 3, 16, 2, 40, 10, 37, 4, 10, 11, 20, 1, 17, 17, 48, 6, 44, 13, 29, 14, 44, 15, 48, 8, 21, 0, 31, 7, 36, 19, 43, 
    9, 20, 6, 43, 1, 13, 5, 22, 2, 33, 7, 28, 16, 39, 12, 16, 13, 34, 17, 20, 10, 47, 18, 43, 19, 44, 8, 29, 15, 22, 4, 14, 11, 28, 14, 44, 0, 33, 3, 28, 
    7, 14, 12, 40, 8, 19, 0, 49, 13, 11, 10, 13, 9, 47, 18, 22, 2, 27, 17, 26, 3, 47, 5, 37, 6, 19, 15, 43, 14, 41, 1, 34, 11, 21, 4, 30, 19, 32, 16, 45, 
    16, 32, 7, 22, 15, 30, 6, 18, 18, 41, 19, 34, 9, 22, 11, 11, 17, 29, 10, 37, 4, 30, 2, 25, 1, 27, 0, 31, 14, 16, 13, 20, 3, 26, 12, 14, 5, 24, 8, 43, 
    18, 22, 17, 22, 12, 30, 15, 31, 13, 15, 4, 13, 16, 47, 19, 18, 6, 33, 3, 30, 7, 46, 2, 48, 11, 42, 0, 18, 1, 16, 8, 25, 10, 43, 5, 21, 9, 27, 14, 14, 
    5, 48, 1, 39, 2, 21, 18, 18, 13, 20, 0, 28, 15, 20, 8, 36, 6, 24, 9, 35, 7, 22, 19, 36, 3, 39, 14, 34, 4, 49, 17, 36, 11, 38, 10, 46, 12, 44, 16, 13, 
    14, 26, 1, 32, 2, 11, 15, 10, 9, 41, 13, 10, 6, 26, 19, 26, 12, 13, 11, 35, 5, 22, 0, 11, 7, 24, 17, 33, 8, 11, 10, 34, 16, 11, 3, 22, 4, 12, 18, 17, 
    16, 39, 10, 24, 17, 43, 14, 28, 3, 49, 15, 34, 18, 46, 13, 29, 6, 31, 11, 40, 7, 24, 1, 47, 9, 15, 2, 26, 8, 40, 12, 46, 5, 18, 19, 16, 4, 14, 0, 21, 
    11, 41, 19, 26, 16, 14, 3, 47, 0, 49, 5, 16, 17, 31, 9, 43, 15, 20, 10, 25, 14, 10, 13, 49, 8, 32, 6, 36, 7, 19, 4, 23, 2, 20, 18, 15, 12, 34, 1, 33, 
    11, 37, 5, 48, 10, 31, 7, 42, 2, 24, 1, 13, 9, 30, 15, 24, 0, 19, 13, 34, 19, 35, 8, 42, 3, 10, 14, 40, 4, 39, 6, 42, 12, 38, 16, 12, 18, 27, 17, 40, 
    14, 19, 1, 27, 8, 39, 12, 41, 5, 45, 11, 40, 10, 46, 6, 48, 7, 37, 3, 30, 17, 31, 4, 16, 18, 29, 15, 44, 0, 41, 16, 35, 13, 47, 9, 21, 2, 10, 19, 48, 
    18, 38, 0, 27, 13, 32, 9, 30, 7, 17, 14, 21, 1, 14, 4, 37, 17, 15, 16, 31, 5, 27, 10, 25, 15, 41, 11, 48, 3, 48, 6, 36, 2, 30, 12, 45, 8, 26, 19, 17, 
    1, 17, 10, 40, 9, 16, 5, 36, 4, 34, 16, 47, 19, 14, 0, 24, 18, 10, 6, 14, 13, 14, 3, 30, 12, 23, 2, 37, 17, 11, 11, 23, 8, 40, 15, 15, 14, 10, 7, 46, 
    14, 37, 10, 28, 13, 13, 0, 28, 2, 18, 1, 43, 16, 46, 8, 39, 3, 30, 12, 15, 11, 38, 17, 38, 18, 45, 19, 44, 9, 16, 15, 29, 5, 33, 6, 20, 7, 35, 4, 34
  };
  // Yamada and Nakano 20x20 instance (Table 4, instance 2)
  const int yn2[] = {
    20, 20, // Number of jobs and machines
    17, 15, 2, 28, 11, 10, 4, 46, 12, 19, 13, 13, 7, 18, 0, 14, 3, 11, 15, 21, 18, 30, 10, 29, 14, 16, 8, 41, 1, 40, 6, 38, 19, 28, 5, 39, 9, 39, 16, 28, 
    8, 32, 6, 46, 14, 35, 5, 14, 10, 44, 2, 20, 11, 12, 19, 23, 13, 22, 18, 15, 3, 35, 4, 27, 16, 26, 1, 27, 0, 23, 15, 27, 17, 31, 12, 31, 7, 31, 9, 24, 
    4, 34, 3, 44, 8, 43, 17, 32, 0, 35, 14, 34, 1, 21, 10, 46, 13, 15, 6, 10, 18, 24, 9, 37, 11, 38, 7, 41, 16, 34, 5, 32, 15, 11, 2, 36, 12, 45, 19, 23, 
    4, 34, 10, 23, 3, 41, 6, 10, 18, 40, 12, 46, 2, 27, 15, 13, 19, 20, 7, 40, 13, 28, 5, 44, 9, 34, 14, 21, 17, 27, 1, 12, 8, 37, 0, 30, 16, 48, 11, 34, 
    19, 22, 1, 14, 5, 22, 9, 10, 7, 45, 16, 38, 11, 32, 12, 38, 14, 16, 8, 20, 4, 12, 2, 40, 15, 33, 13, 35, 17, 32, 18, 15, 10, 31, 0, 49, 6, 19, 3, 33, 
    13, 32, 2, 37, 3, 28, 7, 16, 12, 40, 14, 37, 8, 10, 19, 20, 6, 17, 16, 48, 11, 44, 4, 29, 0, 44, 5, 48, 9, 21, 17, 31, 1, 36, 10, 43, 15, 20, 18, 43, 
    9, 13, 5, 22, 18, 33, 16, 28, 12, 39, 3, 16, 2, 34, 10, 20, 4, 47, 11, 43, 1, 44, 17, 29, 6, 22, 13, 14, 14, 28, 15, 44, 8, 33, 0, 28, 7, 14, 19, 40, 
    9, 19, 6, 49, 1, 11, 5, 13, 2, 47, 7, 22, 16, 27, 12, 26, 13, 47, 17, 37, 10, 19, 18, 43, 19, 41, 8, 34, 15, 21, 4, 30, 11, 32, 14, 45, 0, 32, 3, 22, 
    7, 30, 12, 18, 8, 41, 0, 34, 13, 22, 10, 11, 9, 29, 18, 37, 2, 30, 17, 25, 3, 27, 5, 31, 6, 16, 15, 20, 14, 26, 1, 14, 11, 24, 4, 43, 19, 22, 16, 22, 
    16, 30, 7, 31, 15, 15, 6, 13, 18, 47, 19, 18, 9, 33, 11, 30, 17, 46, 4, 48, 10, 42, 2, 18, 1, 16, 0, 25, 14, 43, 13, 21, 3, 27, 12, 14, 5, 48, 8, 39, 
    18, 21, 17, 18, 12, 20, 15, 28, 13, 20, 4, 36, 16, 24, 19, 35, 7, 22, 3, 36, 6, 39, 10, 34, 11, 49, 0, 36, 1, 38, 8, 46, 9, 44, 5, 13, 2, 26, 14, 32, 
    9, 11, 1, 10, 2, 41, 11, 10, 13, 26, 0, 26, 12, 13, 10, 35, 6, 22, 5, 11, 7, 24, 19, 33, 3, 11, 14, 34, 17, 11, 4, 22, 18, 12, 8, 17, 15, 39, 16, 24, 
    1, 43, 15, 28, 2, 49, 14, 34, 4, 46, 12, 29, 18, 31, 19, 40, 13, 24, 11, 47, 5, 15, 0, 26, 7, 40, 17, 46, 8, 18, 10, 16, 16, 14, 3, 21, 9, 41, 6, 26, 
    16, 14, 6, 47, 17, 49, 10, 16, 3, 31, 12, 43, 4, 20, 8, 25, 14, 10, 18, 49, 7, 32, 0, 36, 9, 19, 2, 23, 15, 20, 5, 15, 13, 34, 19, 33, 11, 37, 1, 48, 
    4, 31, 11, 42, 7, 24, 6, 13, 0, 30, 14, 24, 17, 19, 19, 34, 16, 35, 10, 42, 15, 10, 13, 40, 2, 39, 8, 42, 5, 38, 9, 12, 1, 27, 18, 40, 12, 19, 3, 27, 
    6, 39, 5, 41, 13, 45, 15, 40, 2, 46, 9, 48, 7, 37, 0, 30, 1, 31, 12, 16, 19, 29, 14, 44, 3, 41, 8, 35, 10, 47, 11, 21, 4, 10, 16, 48, 18, 38, 17, 27, 
    16, 32, 1, 30, 8, 17, 18, 21, 0, 14, 17, 37, 10, 15, 12, 31, 7, 27, 3, 25, 5, 41, 4, 48, 13, 48, 6, 36, 2, 30, 15, 45, 11, 26, 9, 17, 14, 17, 19, 40, 
    18, 16, 17, 36, 4, 34, 2, 47, 10, 14, 15, 24, 1, 10, 3, 14, 7, 14, 12, 30, 5, 23, 9, 37, 8, 11, 14, 23, 11, 40, 6, 15, 16, 10, 0, 46, 13, 37, 19, 28, 
    17, 13, 13, 28, 11, 18, 16, 43, 7, 46, 8, 39, 3, 30, 5, 15, 4, 38, 2, 38, 14, 45, 0, 44, 10, 16, 6, 29, 12, 33, 1, 20, 19, 35, 15, 34, 9, 16, 18, 40, 
    17, 14, 2, 30, 0, 27, 15, 47, 18, 43, 3, 17, 14, 13, 6, 43, 7, 45, 12, 32, 13, 13, 16, 48, 1, 10, 4, 14, 10, 42, 9, 38, 5, 43, 19, 22, 11, 43, 8, 23
  };
  // Yamada and Nakano 20x20 instance (Table 4, instance 3)
  const int yn3[] = {
    20, 20, // Number of jobs and machines
    13, 47, 16, 21, 17, 27, 8, 46, 1, 27, 14, 39, 19, 24, 4, 34, 7, 27, 3, 36, 6, 11, 5, 32, 0, 13, 9, 40, 2, 40, 15, 20, 18, 45, 10, 23, 12, 36, 11, 31, 
    1, 40, 11, 20, 12, 27, 6, 32, 16, 26, 13, 36, 10, 37, 7, 26, 3, 22, 4, 44, 18, 18, 2, 11, 17, 15, 9, 27, 15, 39, 5, 25, 8, 16, 14, 13, 0, 49, 19, 25, 
    9, 40, 8, 11, 14, 47, 2, 35, 13, 41, 7, 37, 1, 37, 18, 28, 6, 42, 3, 23, 10, 41, 5, 33, 17, 25, 0, 19, 19, 15, 16, 42, 12, 37, 11, 34, 4, 10, 15, 41, 
    2, 28, 4, 18, 11, 42, 5, 26, 13, 27, 6, 24, 12, 41, 0, 25, 1, 27, 7, 40, 17, 40, 14, 49, 10, 33, 3, 30, 15, 34, 16, 17, 8, 49, 9, 21, 18, 35, 19, 42, 
    7, 26, 9, 27, 4, 25, 3, 42, 19, 28, 15, 22, 17, 34, 0, 15, 6, 46, 1, 34, 12, 47, 2, 16, 16, 34, 10, 31, 14, 24, 5, 43, 13, 45, 11, 47, 8, 18, 18, 15, 
    4, 30, 8, 48, 1, 46, 15, 13, 9, 20, 7, 31, 14, 20, 2, 20, 16, 34, 19, 38, 18, 12, 17, 11, 11, 47, 5, 19, 0, 35, 13, 17, 10, 23, 12, 11, 3, 22, 6, 11, 
    3, 27, 2, 11, 5, 17, 0, 43, 1, 25, 15, 24, 18, 36, 8, 12, 9, 21, 13, 44, 10, 17, 17, 41, 16, 34, 11, 14, 12, 45, 7, 45, 14, 27, 6, 47, 4, 47, 19, 11, 
    5, 27, 4, 41, 17, 44, 16, 16, 11, 42, 10, 29, 3, 23, 2, 15, 0, 22, 13, 28, 7, 16, 14, 39, 9, 21, 12, 15, 18, 32, 15, 36, 1, 29, 8, 18, 6, 39, 19, 33, 
    4, 44, 19, 38, 11, 24, 17, 21, 13, 34, 15, 11, 10, 16, 8, 43, 16, 41, 7, 45, 3, 37, 9, 10, 6, 36, 18, 31, 2, 17, 14, 28, 12, 43, 0, 22, 1, 25, 5, 15, 
    7, 40, 15, 23, 4, 37, 2, 12, 8, 28, 12, 19, 10, 30, 17, 40, 13, 20, 18, 11, 5, 23, 16, 46, 3, 40, 1, 37, 14, 17, 0, 16, 11, 31, 6, 15, 9, 10, 19, 22, 
    5, 10, 1, 37, 15, 22, 2, 28, 6, 10, 9, 21, 19, 38, 16, 35, 7, 34, 0, 13, 14, 33, 11, 16, 4, 26, 3, 20, 17, 10, 18, 37, 13, 21, 8, 31, 10, 27, 12, 23, 
    16, 32, 6, 32, 7, 20, 1, 14, 0, 11, 19, 27, 3, 21, 18, 32, 10, 33, 13, 13, 17, 36, 8, 25, 4, 32, 5, 41, 15, 44, 2, 32, 14, 12, 9, 32, 12, 10, 11, 28, 
    7, 28, 9, 33, 11, 35, 17, 44, 4, 43, 16, 35, 12, 31, 2, 14, 6, 48, 8, 40, 15, 28, 0, 31, 3, 22, 5, 30, 13, 27, 10, 24, 18, 47, 14, 38, 1, 46, 19, 22, 
    12, 33, 6, 33, 14, 38, 9, 15, 10, 16, 13, 24, 1, 30, 8, 18, 7, 46, 2, 30, 17, 37, 11, 24, 5, 13, 3, 14, 18, 11, 16, 38, 0, 31, 4, 24, 19, 42, 15, 30, 
    10, 15, 16, 12, 6, 43, 18, 27, 0, 24, 9, 20, 3, 41, 2, 22, 12, 41, 11, 30, 5, 26, 4, 24, 7, 45, 13, 46, 14, 22, 15, 11, 8, 20, 1, 42, 19, 11, 17, 49, 
    4, 14, 19, 30, 17, 15, 7, 17, 8, 34, 2, 48, 3, 45, 14, 16, 12, 23, 16, 29, 13, 28, 6, 28, 18, 24, 10, 21, 5, 37, 1, 38, 11, 31, 0, 29, 9, 42, 15, 22, 
    15, 41, 17, 19, 5, 37, 7, 36, 8, 47, 12, 49, 11, 29, 6, 18, 9, 33, 10, 30, 0, 49, 16, 37, 3, 11, 2, 46, 14, 36, 18, 35, 13, 45, 1, 31, 4, 33, 19, 18, 
    9, 42, 4, 11, 15, 28, 18, 48, 6, 22, 8, 15, 1, 37, 11, 36, 3, 26, 19, 21, 2, 48, 16, 17, 12, 30, 10, 27, 13, 35, 17, 20, 0, 18, 7, 14, 14, 20, 5, 41, 
    19, 35, 17, 19, 16, 20, 15, 36, 1, 15, 3, 46, 4, 13, 8, 42, 18, 19, 5, 37, 2, 10, 13, 44, 10, 30, 11, 20, 14, 42, 6, 35, 0, 26, 9, 29, 7, 21, 12, 42, 
    17, 33, 3, 11, 7, 42, 16, 45, 9, 29, 0, 27, 5, 15, 13, 37, 2, 32, 11, 25, 14, 21, 8, 49, 19, 34, 1, 31, 15, 35, 6, 32, 4, 20, 18, 30, 10, 24, 12, 29
  };
  // Yamada and Nakano 20x20 instance (Table 4, instance 4)
  const int yn4[] = {
    20, 20, // Number of jobs and machines
    16, 34, 17, 38, 0, 21, 6, 15, 15, 42, 8, 17, 7, 41, 18, 10, 10, 26, 11, 24, 1, 31, 19, 25, 14, 31, 13, 33, 4, 35, 9, 30, 3, 16, 12, 16, 5, 30, 2, 13, 
    5, 41, 11, 33, 6, 15, 16, 38, 0, 40, 14, 38, 3, 37, 1, 20, 13, 22, 4, 34, 7, 16, 17, 39, 9, 15, 2, 19, 10, 36, 12, 39, 18, 26, 8, 19, 15, 39, 19, 34, 
    17, 34, 1, 12, 16, 10, 7, 47, 13, 28, 15, 27, 0, 19, 6, 34, 19, 33, 12, 40, 9, 37, 14, 24, 8, 15, 10, 34, 2, 44, 3, 37, 18, 22, 11, 31, 4, 39, 5, 26, 
    5, 48, 7, 46, 16, 47, 10, 45, 14, 15, 8, 25, 0, 34, 3, 24, 12, 35, 18, 15, 2, 48, 13, 19, 11, 10, 1, 48, 17, 16, 15, 28, 4, 18, 6, 17, 9, 44, 19, 41, 
    12, 47, 3, 23, 9, 48, 16, 45, 14, 39, 6, 42, 8, 32, 15, 11, 13, 16, 5, 14, 11, 19, 1, 46, 19, 10, 10, 17, 7, 41, 2, 47, 17, 32, 4, 17, 0, 21, 18, 17, 
    18, 14, 16, 20, 1, 18, 12, 14, 13, 10, 6, 16, 5, 24, 4, 18, 0, 24, 11, 18, 15, 42, 19, 13, 3, 23, 14, 40, 9, 48, 8, 12, 2, 24, 10, 23, 7, 45, 17, 30, 
    0, 27, 12, 15, 4, 26, 13, 19, 17, 14, 5, 49, 7, 16, 18, 28, 16, 16, 8, 20, 9, 36, 2, 21, 14, 30, 3, 36, 1, 17, 15, 22, 6, 43, 11, 32, 10, 23, 19, 17, 
    0, 32, 16, 15, 17, 12, 7, 46, 3, 37, 18, 43, 11, 40, 13, 43, 9, 48, 4, 36, 15, 24, 8, 25, 1, 33, 14, 32, 5, 26, 6, 37, 12, 24, 10, 24, 2, 15, 19, 22, 
    10, 34, 6, 33, 15, 25, 8, 46, 0, 20, 18, 33, 4, 19, 13, 45, 2, 47, 1, 32, 3, 12, 11, 29, 16, 29, 5, 46, 12, 17, 7, 48, 14, 39, 17, 40, 19, 41, 9, 37, 
    13, 26, 3, 47, 5, 44, 6, 49, 1, 22, 17, 12, 10, 28, 19, 36, 9, 27, 4, 25, 14, 48, 7, 11, 16, 49, 12, 24, 11, 48, 2, 19, 0, 47, 18, 49, 8, 46, 15, 36, 
    13, 23, 18, 48, 14, 15, 0, 42, 3, 36, 8, 15, 6, 32, 10, 18, 1, 45, 15, 23, 11, 45, 2, 13, 17, 21, 12, 32, 7, 44, 5, 25, 19, 34, 16, 22, 9, 11, 4, 43, 
    17, 37, 7, 49, 15, 45, 2, 28, 9, 15, 8, 35, 12, 29, 13, 44, 1, 26, 4, 25, 5, 30, 3, 39, 0, 15, 14, 28, 18, 23, 6, 42, 11, 33, 16, 45, 10, 10, 19, 20, 
    0, 10, 6, 37, 3, 15, 13, 13, 10, 11, 2, 49, 1, 28, 14, 28, 15, 13, 8, 29, 12, 21, 16, 32, 11, 21, 4, 48, 5, 11, 17, 26, 9, 33, 18, 22, 7, 21, 19, 49, 
    18, 38, 0, 41, 4, 30, 13, 43, 6, 11, 2, 43, 14, 27, 3, 26, 9, 30, 15, 19, 16, 36, 1, 31, 17, 47, 5, 41, 10, 34, 8, 40, 12, 32, 7, 13, 11, 18, 19, 27, 
    6, 24, 5, 30, 7, 10, 10, 35, 8, 28, 16, 43, 19, 12, 9, 44, 15, 15, 3, 15, 2, 35, 18, 43, 0, 38, 4, 16, 1, 29, 17, 40, 14, 49, 13, 38, 12, 16, 11, 30, 
    3, 48, 6, 35, 13, 43, 2, 37, 17, 18, 5, 27, 9, 27, 7, 41, 1, 22, 15, 28, 16, 18, 10, 37, 18, 48, 4, 10, 8, 14, 11, 18, 14, 43, 0, 48, 12, 12, 19, 49, 
    0, 13, 13, 38, 7, 34, 6, 42, 1, 36, 5, 45, 18, 24, 8, 35, 14, 26, 19, 30, 12, 47, 16, 24, 11, 47, 4, 40, 10, 43, 3, 16, 15, 10, 2, 12, 9, 39, 17, 22, 
    16, 30, 13, 47, 19, 49, 8, 20, 4, 40, 3, 46, 17, 21, 14, 33, 6, 44, 7, 23, 9, 24, 0, 48, 10, 43, 15, 41, 2, 32, 5, 29, 11, 36, 1, 38, 12, 47, 18, 12, 
    13, 10, 5, 36, 12, 18, 16, 48, 0, 27, 14, 43, 10, 46, 6, 27, 7, 46, 19, 35, 11, 31, 2, 18, 8, 24, 3, 23, 17, 29, 18, 14, 9, 19, 1, 40, 15, 38, 4, 13, 
    9, 45, 16, 44, 0, 43, 17, 31, 14, 35, 13, 17, 12, 42, 3, 14, 18, 37, 10, 39, 6, 48, 7, 38, 15, 26, 4, 49, 2, 28, 11, 35, 1, 42, 5, 24, 8, 44, 19, 38
  };

  // Taillard 15x15 instance 0
  const int tai_15_15_0[] = {
    15, 15, // Number of jobs and machines
     6,94, 12,66,  4,10,  7,53,  3,26,  2,15, 10,65, 11,82,  8,10, 14,27,  9,93, 13,92,  5,96,  0,70,  1,83, 
     4,74,  5,31,  7,88, 14,51, 13,57,  8,78, 11, 8,  9, 7,  6,91, 10,79,  0,18,  3,51, 12,18,  1,99,  2,33, 
     1, 4,  8,82,  9,40, 12,86,  6,50, 11,54, 13,21,  5, 6,  0,54,  2,68,  7,82, 10,20,  4,39,  3,35, 14,68, 
     5,73,  2,23,  9,30,  6,30, 10,53,  0,94, 13,58,  4,93,  7,32, 14,91, 11,30,  8,56, 12,27,  1,92,  3, 9, 
     7,78,  8,23,  6,21, 10,60,  4,36,  9,29,  2,95, 14,99, 12,79,  5,76,  1,93, 13,42, 11,52,  0,42,  3,96, 
     5,29,  3,61, 12,88, 13,70, 11,16,  4,31, 14,65,  7,83,  2,78,  1,26, 10,50,  0,87,  9,62,  6,14,  8,30, 
    12,18,  3,75,  7,20,  8, 4, 14,91,  6,68,  1,19, 11,54,  4,85,  5,73,  2,43, 10,24,  0,37, 13,87,  9,66, 
    11,32,  5,52,  0, 9,  7,49, 12,61, 13,35, 14,99,  1,62,  2, 6,  8,62,  4, 7,  3,80,  9, 3,  6,57, 10, 7, 
    10,85, 11,30,  6,96, 14,91,  0,13,  1,87,  2,82,  5,83, 12,78,  4,56,  8,85,  7, 8,  9,66, 13,88,  3,15, 
     6, 5, 11,59,  9,30,  2,60,  8,41,  0,17, 13,66,  3,89, 10,78,  7,88,  1,69, 12,45, 14,82,  4, 6,  5,13, 
     4,90,  7,27, 13, 1,  0, 8,  5,91, 12,80,  6,89,  8,49, 14,32, 10,28,  3,90,  1,93, 11, 6,  9,35,  2,73, 
     2,47, 14,43,  0,75, 12, 8,  6,51, 10, 3,  7,84,  5,34,  8,28,  9,60, 13,69,  1,45,  3,67, 11,58,  4,87, 
     5,65,  8,62, 10,97,  2,20,  3,31,  6,33,  9,33,  0,77, 13,50,  4,80,  1,48, 11,90, 12,75,  7,96, 14,44, 
     8,28, 14,21,  4,51, 13,75,  5,17,  6,89,  9,59,  1,56, 12,63,  7,18, 11,17, 10,30,  3,16,  2, 7,  0,35, 
    10,57,  8,16, 12,42,  6,34,  4,37,  1,26, 13,68, 14,73, 11, 5,  0, 8,  7,12,  3,87,  2,83,  9,20,  5,97
  };
  // Taillard 15x15 instance 1
  const int tai_15_15_1[] = {
    15, 15, // Number of jobs and machines
     9,86, 14,60,  4,10, 13,59, 10,65,  3,94,  7,71,  8,25,  0,98,  5,49,  1,43,  2, 8, 12,90,  6,21, 11,73, 
    10,68,  8,28, 11,38, 14,36,  3,93, 13,35,  9,37,  7,28,  4,62,  2,86,  6,65,  1,11,  5,20, 12,82,  0,23, 
     7,33,  0,67,  6,96,  5,91, 14,83, 13,81,  2,60, 11,88,  4,20, 12,62,  1,22,  9,79,  3,38, 10,40,  8,82, 
     9,13, 11,14, 14,73,  0,88,  1,24,  8,16,  5,78, 10,70, 12,53,  4,68, 13,73,  3,90,  6,58,  7, 7,  2, 4, 
    11,93,  4,52, 13,63,  3,13,  8,19,  1,41, 10,71, 12,59,  2,19, 14,60,  6,85,  7,99,  0,73,  9,95,  5,19, 
     5,62,  2,60,  1,93, 10,16,  0,10,  4,72,  8,88, 14,69,  6,58,  3,41,  9,46,  7,63, 11,76, 12,83, 13,62, 
     5,50, 10,68, 13,90,  0,34,  9,44,  8, 5,  1, 8, 11,25, 14,70,  7,53, 12,78,  2,92,  6,62,  4,85,  3,70, 
    12,60,  0,64,  9,92,  3,44, 13,63,  6,91,  5,21,  7, 1,  2,96, 14,19, 11,59,  8,12, 10,41,  1,11,  4,94, 
    11,93, 10,46,  5,51, 13,37,  1,91,  9,90,  8,63,  7,40,  3,68,  6,13,  0,16,  2,83, 14,49, 12,24,  4,23, 
     2, 5, 14,35,  3,21, 10,14,  6,66,  1, 3,  0, 6, 13,98, 11,63,  4,64,  5,76,  8,94,  7,17, 12,62,  9,37, 
    11,35, 14,42, 13,62,  5,68,  4,73,  9,27,  1,52,  6,39, 12,41,  0,25,  2, 9,  8,34, 10,50,  3,41,  7,98, 
    12,23,  3,32, 10,35,  8,10,  4,29,  7,68, 13,20, 11, 8, 14,58,  1,62,  2,39,  0,32,  5, 8,  6,33,  9,91, 
     8,28, 13,31,  5, 3,  0,28, 11,66,  9,59,  4,24, 12,45,  1,81, 10, 8,  6,44,  2,42,  7, 2, 14,23,  3,53, 
     2,11,  5,93,  4,27,  3,59,  9,62,  1,23, 11,23, 13, 7,  7,77,  6,64, 10,60, 14,97,  0,36,  8,53, 12,72, 
     1,36, 10,98,  4,38,  2,24,  0,84,  7,47,  6,72,  9, 1, 11,91, 12,85,  5,68, 14,42,  3,20, 13,30,  8,30
  };
  // Taillard 15x15 instance 2
  const int tai_15_15_2[] = {
    15, 15, // Number of jobs and machines
     7,69, 11,81,  8,81,  3,62, 12,80,  1, 3, 13,38,  0,62, 14,54,  6,66,  9,88,  4,82,  2, 3, 10,12,  5,88, 
    12,83,  1,51, 11,47,  9,15,  6,89,  3,76,  2,52,  4,18,  5,22,  8,85, 13,26, 14,30, 10, 5,  0,89,  7,22, 
     1,62,  2,47,  9,93,  0,54,  3,38,  5,78,  8,71,  4,96, 14,19, 10,33, 12,44, 13,71,  7,90,  6, 9, 11,21, 
    13,33, 10,82,  6,80,  2,30, 14,96,  7,31,  4,11, 11,26,  0,41,  5,55,  9,12,  3,10,  8,92,  1, 3, 12,75, 
     1,36,  8,49,  4,10, 14,43,  6,69,  5,72,  3,19,  2,65,  9,37, 10,57, 13,32,  7,11, 11,73,  0,89, 12,12, 
     5,83, 14,32,  2, 6, 12,13, 10,87,  1,94, 11,36,  4,76,  6,46,  9,30,  0,56, 13,62,  8,32,  3,52,  7,72, 
     5,29,  2,78,  0,21,  1,27,  8,17, 14,43, 11,14, 10,15,  7,16,  9,49,  6,72, 12,19,  4,99, 13,38,  3,64, 
     4,12,  7,74, 10, 4,  1, 3,  9,15,  8,62,  2,50, 14,38, 11,49,  3,25,  5,18,  6,55, 13, 5, 12,71,  0,27, 
    14,69, 11,13,  0,33,  9,47, 10,86,  5,31,  3,97, 12,48,  8,25, 13,40,  6,94,  1,22,  7,61,  2,59,  4,16, 
     9,27,  0, 4,  3,35, 10,80, 12,49, 13,46,  5,84,  1,46,  6,96, 14,72,  8,18, 11,23,  2,96,  7,74,  4,23, 
     7,36,  2,17,  1,81, 12,67,  3,47, 14, 5,  4,51,  6,23,  5,82,  9,35,  8,96, 13, 7, 10,54,  0,92, 11,38, 
     0,78,  8,58, 14,62, 12,43,  9, 1,  5,56,  6,76, 10,49,  7,80, 11,26,  3,79,  4, 9,  1,24, 13,24,  2,42, 
     8,38, 12,86, 10,38, 11,38, 14,83,  3,36,  6,11,  1,17,  4,99,  5,14,  0,57,  9,64, 13,58,  2,96,  7,17, 
    13,10,  2,86, 11,93,  0,63, 14,61, 10,62,  3,75,  1,90, 12,40,  4,77,  5, 8,  6,27,  7,96,  9,69,  8,64, 
     1,73, 13,12,  0,14, 11,71,  2, 3, 10,47,  4,84,  8,84,  3,53,  5,58,  7,95,  6,87,  9,90, 12,68, 14,75
  };
  // Taillard 15x15 instance 3
  const int tai_15_15_3[] = {
    15, 15, // Number of jobs and machines
     3,72,  7,51,  6,42, 14,31,  9,61,  8,46,  5,88,  4,33, 10,27,  1,85,  0,70, 12,56, 11,70,  2,50, 13,25, 
     1,19, 11,79,  0,79,  5,47,  8,40, 13,67,  3,43, 10,65,  9,84,  2,61, 12,30,  6,56,  4,19,  7,91, 14,68, 
     7,94,  3, 7,  8, 2, 11,95,  0,60,  4,82,  9,76, 13,36,  1, 8, 10,85,  6, 7,  5,44, 14, 2, 12,72,  2,91, 
     6,58, 11,67,  5,84, 13,34,  3,19,  2,19,  1,94,  4,41,  9,98, 12,96,  8,25,  0,40, 14,74,  7,88, 10,74, 
     1,45, 11,60,  6, 8,  5,29,  8,32,  7,42, 12,25,  9, 4,  2,71, 14,79, 13,93,  3,28,  0,30,  4,17, 10,43, 
    11,84,  2,56, 12,46,  1,93, 14,66,  0,84,  6,40,  9, 4,  3,15, 13,15,  7,54, 10,39,  4,77,  5,55,  8,31, 
    14,65,  7,91, 11,17,  0,47, 12,77,  8,68,  9,62, 10,22,  3,72, 13,47,  4,38,  1, 7,  2,11,  6,22,  5,63, 
     7,12,  4,21, 13,60,  5,42, 14,22, 11,84,  2,60, 12,52,  6,25,  1,53,  0,53, 10,56,  9,29,  3,83,  8,32, 
     7,48,  4,28, 14,70, 10,26,  3,68,  0, 4, 13,19,  8,92,  1,24,  2,54,  6,57, 12,47, 11,84,  9,85,  5,95, 
     2,36, 12,34, 10,65,  3,64,  6,30,  5,41, 14,53,  9,74, 13,44,  4,13,  0,41, 11, 6,  7,32,  8,94,  1,37, 
    11,62,  9, 9,  3,89,  7,37,  6,28,  4,23,  0,13,  2,60,  5,46,  1,94, 10,85,  8,72, 13,18, 12,79, 14,11, 
     0,74,  4,61,  1,43,  9,26,  2,97, 11,62, 13,40, 10,60,  7,62,  6,78,  8,42, 12, 8, 14,21,  3,11,  5,70, 
     6, 9,  0,22,  4, 9, 10, 8,  2,54, 14,32,  9,92, 13,76, 11, 2, 12,63,  1,63,  8,98,  5,42,  3,12,  7,41, 
     5,67, 10, 7, 13,91,  2,52,  7,87,  4, 4,  8, 1,  6,56,  9,82,  0,47, 12,35, 11, 8,  1,92, 14,39,  3,11, 
    11,44,  2,24,  0,24,  4,14, 14,34,  5,57,  9,30, 10,64,  6, 4, 12,14,  8,69,  1,95,  7,22,  3,60, 13,61
  };
  // Taillard 15x15 instance 4
  const int tai_15_15_4[] = {
    15, 15, // Number of jobs and machines
    12,40,  1,96,  4,59,  9,95, 13,76,  0,75, 11,23,  8,65,  3,65,  5,16,  6,71, 14,52, 10,84,  2,99,  7,24, 
     5, 2,  1,88, 14,99, 10,52, 13,68,  9,13,  6,38, 12,35,  8,57,  2,37,  7,93,  0,38,  3,68,  4,94, 11,71, 
     6,87,  3,46, 10,14,  7,87, 13,30,  4,79,  5,62,  9,37,  8,54,  2, 1,  0,97,  1,16, 11, 2, 14,51, 12,96, 
    10,19,  7,15,  5,42,  0, 8,  9,72, 13,15,  2,76,  8,25,  1,78, 14,84, 11,62,  3,70, 12,81,  6,16,  4,97, 
     6,68, 12,71, 14, 3,  1,68,  7,91,  5,37, 11,73,  0,21,  2,85,  3,79,  8,51, 13,50,  4,21,  9,30, 10,64, 
     4,14,  7, 1,  6,29,  0,72,  8, 6, 13,31, 12,98, 14,50,  3,83,  2, 2,  5,86,  9,33, 10,33,  1,98, 11,59, 
    10,21, 11,80,  6,99,  9,70,  0,80,  2,71,  1,47,  8,96, 12,56,  7,78,  5,53,  3,10, 13,92, 14, 1,  4,33, 
     3,29, 10,85,  5,89,  6,10,  8,30,  4,38,  0,38, 14,48,  2,16,  7,65,  9,90, 11,73, 12,88,  1,46, 13,47, 
     1,37,  2, 9,  6,49,  7,23, 10, 1, 12,78, 14,39,  8,15,  0, 9,  3,41, 13,35,  5,83,  4, 8,  9,61, 11,60, 
    12, 1,  7,73,  6,47, 14,46,  3,10,  4,37,  0,60, 13,84, 10,26,  8,11, 11,37,  9,79,  5,75,  2,49,  1,51, 
     4,22,  3,49,  8,33, 14, 2,  2,24, 13, 3,  5,73,  6,68, 10,21, 12,61,  7,69, 11,94,  1,43,  9,39,  0,48, 
     6,81, 12,46,  7,21,  5,23,  2,86,  4,19, 13,64, 11,52,  8,22,  0,50, 10,11,  3,73,  1,77,  9,16, 14,75, 
    12,21, 13,80,  8,30,  7,32,  1,22,  6,23,  0,85,  5,92,  9,14, 10,13,  4,68,  2,60, 14,45,  3,32, 11,90, 
    12,29,  1,95,  4,52,  8,59,  6,33, 10,12,  7,73,  3,96,  0,75,  5,12, 13,83,  2, 3,  9,90, 14,57, 11, 6, 
     7,94,  5,18,  0,54, 10,42,  2,70,  3,29,  9,43,  6,50, 11,75,  8,70,  1,40,  4,48, 14, 1, 12,27, 13,12
  };
  // Taillard 15x15 instance 5
  const int tai_15_15_5[] = {
    15, 15, // Number of jobs and machines
     7,96, 12,23,  5,71,  8,26,  3,28, 14,16, 13,27,  9,71,  0,18,  1,57,  4,43,  2, 5,  6,12, 11,91, 10,63, 
     8,32,  0,81,  5,95, 13,79,  6,55,  1,45,  4,60,  2,73,  3,23, 11,44, 10,92, 12,20,  9, 5, 14,72,  7,73, 
     6,63,  8,93,  7,63,  1,79,  9,10,  5,66, 12,27,  4,93,  0,24,  2,26, 14, 8, 11,69,  3,29, 13,66, 10,97, 
    12,80,  0,87, 14,68,  7,23, 13,54,  1,16,  6,68,  8,32, 11,74,  2, 3,  3, 2,  9,71,  5, 4, 10,67,  4,28, 
     8,46,  2,96, 12,11, 11,41, 10,93,  9, 2,  4,98,  3,10, 14,43,  5,65,  0,27,  7,57,  6,75, 13,87,  1,81, 
    13, 5,  8,91,  6,92, 11,87, 14,66,  9,36, 12,67,  7,88,  0,92,  1,27, 10,13,  2, 7,  5,95,  3,66,  4,13, 
     4,90,  1,33,  2,78, 13,76,  7,93,  6,67,  0,82,  8,94, 12,12, 14, 5, 10,85,  9,42,  5, 4,  3, 2, 11,70, 
     4,79, 10,24, 14,41,  3,83,  6,45, 13,29, 11, 3,  9,42,  0, 5,  5,44,  1,83, 12,59,  8,60,  7,78,  2,44, 
     7,19,  1,55,  5,20,  4,74, 14,66,  8,37,  0,55,  9,63, 12,40,  3,73, 10,55,  2,84, 13,54, 11,62,  6, 6, 
     3,27,  6,59, 13, 6,  4,90,  5, 6, 10,37,  2,64,  8,35, 12,25, 11,59,  9,77,  7,30, 14, 1,  1, 7,  0,70, 
     1, 4,  4,53,  7, 6,  2,10, 14,51, 10,89, 12,38, 13,38,  6,35,  5,44,  9,99,  0,88,  3,52,  8,16, 11,99, 
     0,28,  7,11, 14,76, 13,51,  8,35,  3,60,  6,44,  9,39,  5,66, 12,49, 10,40,  4,34,  1,80,  2,38, 11,29, 
    14,31, 10,32,  0,40,  8,25, 12,40, 13,85,  4,39, 11,61,  1,15,  3,41,  6,93,  5,64,  2,16,  9,81,  7,97, 
    13, 9,  4,21,  8, 8,  6,55,  5,79,  2,76,  9,79,  0,61, 11,68, 12,99,  1,24,  3,23, 14,92,  7,91, 10,22, 
    14,80,  2,30,  6,67,  4,58,  3,45, 11,29,  1,48,  5,28,  7,64,  0,63,  8,80, 10,23,  9,93, 12,55, 13,48
  };
  // Taillard 15x15 instance 6
  const int tai_15_15_6[] = {
    15, 15, // Number of jobs and machines
    13,52, 12,19,  7, 6,  0,20,  5, 1, 11,26,  9,90, 10,44,  1,27,  2,18,  3,51, 14,80,  4,10,  6,51,  8,41, 
     2,44,  1,85,  8, 2, 14,78, 13,86,  0,88,  5,61, 11,20,  9,56, 12,12, 10,69,  7,34,  3,55,  4,34,  6,84, 
     0,62,  3,72,  1,74,  7,63,  4,95,  8,29, 14,24,  5,34,  6,89,  2,83, 13,90, 12,26,  9,98, 10,65, 11,31, 
     9,10, 11,15,  0,93,  7,79, 12,77, 14,61,  6, 1,  1,48, 13,22, 10,27,  4,21,  5,17,  3,45,  2,96,  8,11, 
     8,83, 13,52,  5,70, 10,78,  9, 7, 14,28, 12,97,  2,52,  3,29,  0,81,  6,60, 11,91,  7,80,  4,54,  1,35, 
    12, 3, 13,31, 14,98,  9,97,  5,77,  1,39,  6,41,  7,10,  0, 9,  3,93,  8, 7, 10,49,  4,20, 11,45,  2,59, 
     9,28,  0,93,  5, 4,  4,51, 12,67, 14, 5,  6,18,  1,52,  3,47,  8,21, 13,49, 11,63,  2,96, 10,85,  7,90, 
    12,25,  1,82,  9,58, 14,15,  6,67, 10,50,  2,66,  7,92,  4,56, 11,82, 13,57,  5,16,  3,34,  8,99,  0,61, 
     6,82,  5,31, 12,22,  4,16,  1,87, 14,48,  9,59,  0,63,  7,29,  8,99, 10,48, 13,36,  2,91, 11,61,  3,59, 
     8,28,  3,25,  5,69,  4,65,  1,62, 10,57,  7,97,  9,31, 13,15,  2,25,  0,83, 11,98,  6,55, 12,66, 14,31, 
     4,20,  2,99,  1,13,  0,88, 14,25, 10,75,  9,90,  6,84, 11,70, 12,41,  3,17,  8,54,  7,63, 13, 1,  5,95, 
     8,59,  3,22, 13,46, 14,10,  2, 1, 11,21,  5, 3,  4,84,  9,93, 12,59, 10,78,  7,73,  1,59,  0,42,  6,63, 
     7,72,  1,80, 10,12,  4,56,  0,22,  8, 8, 12,93,  6,27, 13,17,  2,38,  3,26,  9,51, 11,43, 14,80,  5,94, 
     8,72, 11,78,  3,29,  7,90,  1,46, 12,46,  6,43,  4,75, 10,90, 13,29,  2, 8,  5,92, 14,16,  9,62,  0, 6, 
     5,89, 13,44, 14,41,  6,32,  9,10, 11,85,  7,16,  2,23, 12,91,  8,46,  3,35,  4,17, 10,93,  1,45,  0,93
  };
  // Taillard 15x15 instance 7
  const int tai_15_15_7[] = {
    15, 15, // Number of jobs and machines
     3,83,  6, 1,  7,96, 13,54,  4,30,  1,80, 12,81, 10, 9,  8,49, 14,32,  0,19,  9,92,  5,65,  2,88, 11,64, 
     2, 4, 12,68,  1,79, 13,21,  3,84,  4,92,  8,66, 14,51,  0,83, 10,96,  7,68,  5,38,  9,38, 11,99,  6,76, 
     8,46, 14,57,  3,66,  0,75, 10,88,  5,58,  9,56, 13,35,  2,59, 11,82,  6,24,  4,96,  7,24,  1,55, 12,80, 
     5,34, 13,69, 11,53,  4,98, 14, 8,  2,81,  9,81,  8,38, 10,39,  3, 3,  6,59,  7,81,  1,30,  0,76, 12,71, 
    13,85,  5,80,  2,36, 14,57,  1,96,  8,34,  4,14,  3, 3, 11,90,  6,99,  7, 9, 12,42,  9,95,  0,27, 10,27, 
    14,28, 11,11,  2,66,  5, 2,  8,35, 10,69,  0,61,  4,84,  9,73,  7,56, 13,98,  3,81,  1,72,  6,92, 12,23, 
     8,21, 12, 5,  5,95, 10, 5,  7,22, 11,16,  2,77, 13,85,  0,76, 14,46,  6,36,  9,89,  1,99,  4,44,  3,37, 
     9,49,  7,80, 12,61,  3,87,  6,41,  2, 6, 10,83, 13,79,  1,44,  8,83, 14, 9,  4,84,  0,99,  5,38, 11,68, 
     0,77,  4,51,  5,68,  1,69, 11, 6,  7,26,  6,99,  2, 6, 14,34, 13,27,  8,51,  9,82,  3, 5, 10,90, 12, 1, 
     8,85, 11,64,  7,55,  1,76, 14,89, 13,68, 12,34,  4,14,  6,52,  9,33, 10,91,  0, 4,  5,18,  2,95,  3,76, 
    12,40,  4, 8,  5,36, 13, 5,  6, 1,  0,51,  1,33,  7,80,  9,90,  8,75, 11,47, 10,65, 14,42,  2,16,  3,11, 
     3,38, 14,83,  4,48, 13,74,  5,15,  9,10,  8,89,  0,41,  7,97, 12,97,  6,16,  1,47, 10,21, 11,95,  2,20, 
    10,89,  8,22,  4,11,  1,15,  2,37,  0,65,  7,28, 14,39, 12,88, 13,14,  9,28,  6, 6,  3,24, 11, 4,  5,23, 
     6,14,  2,66,  0, 4, 14,58,  1, 7,  4, 6, 12, 5,  3,48, 10,54,  7,59,  8, 2,  9, 1,  5, 4, 13,82, 11,75, 
    10,24,  2,66,  9, 4, 13,20,  5,79,  0,50,  6,23,  7,15,  1,14, 14,91, 11,86,  4,96, 12,63,  3,16,  8, 3
  };
  // Taillard 15x15 instance 8
  const int tai_15_15_8[] = {
    15, 15, // Number of jobs and machines
     3,91, 13,15, 11,45,  4,26,  2,90,  9,53, 10, 7,  6,78, 12,94,  7, 8,  5,19, 14,56,  8,69,  1,66,  0,98, 
    13,34,  9, 1, 14,40,  0,74,  4,43,  5,73,  6,96, 11,80,  1,87,  7,78,  8,88, 12,90, 10,49,  3,85,  2, 3, 
     1,88, 14,98, 13,82,  8,46, 10,79,  4,69,  0,95, 12,41,  5,39,  2,12, 11, 1,  6,71,  9,27,  7,77,  3,99, 
    14,50,  5, 1,  4,21,  3,72, 10,46,  7,20,  1,62, 11,33, 13,79,  6,56,  9,67, 12,23,  2,56,  8,44,  0,56, 
    14,15,  1,15, 13,16,  6,79, 12, 8,  4,73,  5,86,  2,52,  9,79,  0,62,  3,93,  7,86, 11,44,  8,80, 10,18, 
     9,79, 11,63, 14,94, 10, 9, 13,86,  7,89,  8,12,  2,66,  1,55,  0,70, 12,35,  5,14,  4, 3,  6,54,  3,62, 
     3,42,  7,39, 11,42,  8, 9,  4,37,  9,25,  1,78, 12,76, 10,16,  6,38,  0,30, 14,80,  5,34,  2,92, 13,29, 
    14,96, 13,25,  5,49,  0,67,  9,53,  8,20,  2,52,  3,29,  1,51, 11,35,  6,38, 10,18,  4,43,  7,46, 12,98, 
     3,73,  2,68,  0, 3, 11,98,  1,68,  4, 8,  5,15, 13,88,  7,72, 12,20,  9,89, 10,59,  8,68,  6,63, 14,41, 
    14,30,  9,43, 11,80, 13,64,  1,14,  5, 6,  3,36,  4,88,  0,71, 12,51,  6,63,  2,32,  8,16, 10,63,  7, 7, 
    14,18, 12,90,  2,55,  5,25,  4,72,  1,92, 13,88,  0,69,  8,89, 10,83,  7,58, 11,35,  3,79,  6,43,  9,86, 
     4,50, 13,64,  3,88,  1,57, 11,25,  8,73,  9,18,  7, 4,  0,69,  2,40,  6,28, 10,37,  5,42, 12,82, 14,83, 
    11, 2,  9,41,  1,13,  8,75, 12,31, 14,66,  2,72, 10,66,  7,96,  0,45, 13,29,  6,49,  3,96,  5,50,  4,38, 
     1,80,  4,90,  5,36,  6,50, 11,76,  3,15,  9,31, 10,89,  8,87,  2,55,  7,49, 13,23, 14,19, 12,38,  0,93, 
    13,75,  2,45,  4,75, 12,72,  7,65,  3, 6,  8,16,  0,24, 11,24, 14,44,  9, 4,  6,22,  1,99,  5,10, 10,85
  };
  // Taillard 15x15 instance 9
  const int tai_15_15_9[] = {
    15, 15, // Number of jobs and machines
     8,35,  2,78,  7,79, 14,65, 12,53,  0,14,  4,93,  3,70, 13,14,  5,90,  9,95, 10,49,  6,36,  1,85, 11, 1, 
     2,83,  8,41,  6,22,  4,29, 11,52,  0,71,  9,16,  7,93,  5,54,  3,63,  1,12, 10,85, 13,62, 14,45, 12,30, 
     5,60, 11,43,  8,71, 14, 2, 12,50,  1,37,  4,86,  9,81, 10,60,  6,57, 13,66,  0,24,  2,98,  3,92,  7,69, 
     9,14, 13,59,  8,35,  6, 6, 12,25,  5,57, 10, 1,  2,44,  1,94,  0,30, 14,95, 11,93,  3,51,  4,52,  7,16, 
     8,96, 10,39,  3,75, 13,98, 14, 2,  5,38,  4,69,  0,32, 12,95, 11,63,  9, 4,  6,11,  2,50,  1,95,  7,78, 
     7,73,  2,28,  9,43,  5,47, 10,57,  4,88,  3,33,  1,13, 11, 7,  8,49,  6,23, 14,38, 13,21,  0,99, 12,72, 
     2, 3, 10,80,  1,67, 12,93, 14,91,  3,31,  0,52,  4,64,  9,83,  5, 2, 11,90, 13,64,  7,16,  8,18,  6,25, 
    13,23,  6,30, 11,22, 12,54,  8,68,  7,63, 14,89,  5,95,  3, 5,  4,37,  0, 5, 10,42,  2,17,  1,54,  9,46, 
     8,44,  4,59,  6,87,  7,62,  0,51, 11,55, 13, 3, 12,40,  2,26,  3,18, 10,15,  1,18,  5,72, 14,35,  9,60, 
     2,27,  6,14, 12,77,  9,24,  8,55, 11,67,  1,59,  3,19, 13,29,  4,33, 10,88,  5,30,  0,91,  7,11, 14,11, 
     0,67,  9,94,  4,50,  8, 2, 10,83,  2,19, 11,29, 12,37, 14,58,  6,32,  3,38,  7,99,  5,88,  1,49, 13,70, 
     8,60,  1, 7, 12,81,  5,82,  7,58, 10,83,  9,16,  4, 1, 11,69,  6, 7, 13, 3,  2,84, 14, 8,  0,12,  3,93, 
    13,92, 14,81,  2, 4,  9,78,  7, 9,  8,78, 12,75,  4, 5, 10,50,  6, 8,  1,44,  0, 4,  5,60, 11,94,  3,74, 
     1,32,  0,88, 12,31,  2,68, 13,31,  8,10,  3,45, 14,75,  4,82,  7,51,  6,55,  9,99, 11,44, 10,84,  5,22, 
     3,12, 13,35,  2,64,  5,17,  9,42,  6,46,  7,65,  4,74,  8,96,  0,28, 12,86, 10,95, 14,93,  1,67, 11,56
  };
  // Taillard 20x15 instance 0
  const int tai_20_15_0[] = {
    20, 15, // Number of jobs and machines
     3,25, 11,75, 14,75,  1,76, 10,38,  2,62,  4,38,  7,59,  0,14, 12,13,  5,46,  9,31,  6,57, 13,92,  8, 3, 
     5,67,  0, 5,  3,11,  8,11,  4,40,  1,34, 12,77, 14,42,  6,35,  7,96, 10,22,  2,55,  9,21, 13,29, 11,16, 
     2,22,  3,98, 14, 8,  0,35,  9,59, 12,31,  5,13,  4,46,  7,52, 10,22,  8,18, 11,19, 13,64,  1,29,  6,70, 
     8,99, 10,42,  1, 2, 13,35,  3,11,  4,92, 14,88,  9,97,  2,21,  5,56, 11,17,  7,43,  0,27,  6,19, 12,23, 
    14,50,  8, 5,  1,59,  2,71, 10,47,  9,39, 12,82,  4,35,  6,12,  5, 2,  0,39, 13,42,  3,52, 11,65,  7,35, 
     3,48, 10,57,  1, 5,  5, 2,  6,60,  0,64,  8,86,  7, 3, 11,51, 13,26,  2,34, 14,39, 12,45,  9,63,  4,54, 
     2,40, 10,43,  1,50, 12,71,  8,46,  0,99,  7,67,  6,34, 14, 6, 13,95,  4,67,  3,54,  5,29,  9,30, 11,60, 
     1,59,  0, 3,  2,85,  4, 6,  7,46, 13,49, 11, 5,  3,82, 12,18,  5,71,  6,48, 14,79,  9,62,  8,65, 10,76, 
     4,65,  5,55,  9,81, 10,15,  7,32,  6,52,  2,97,  1,69, 12,82,  3,89, 13,69,  0,87,  8,22, 14,71, 11,63, 
     1,70,  4,74,  3,52, 10,94, 14,14,  0,81,  6,24, 13,14, 11,32,  8,39,  5,67, 12,59,  7,18,  9,77,  2,50, 
     3,18, 10, 6,  1,96,  0,53,  9,35,  8,99, 14,39,  6,18,  4,14,  7,90,  2,64, 12,81,  5,89, 11,48, 13,80, 
     2,44,  7,75,  6,12,  8,13,  3,74,  5,59, 14,71,  4,75,  1,30,  0,93,  9,26, 10,30, 13,84, 11,91, 12,93, 
     0,39,  7,56, 14,13,  8,29, 12,55, 10,69,  9,26,  3, 7,  6,55,  1,48,  4,22,  2,46, 11,50, 13,96,  5,17, 
    12,57,  3,14,  9, 8,  4,13,  1,95,  0,53, 10,78,  6,24,  5,92,  2,90, 14,68, 13,87,  7,43,  8,75, 11,94, 
     3,93, 14,92,  6,18,  5,28, 13,27,  9,40,  1,56,  0,83, 12,51,  7,15,  2,97,  4,48, 10,53,  8,78, 11,39, 
     5,47, 14,34,  6,42, 12,28,  8,11,  2,11,  4,30,  9,14, 11,10, 13, 4,  3,20,  1,92,  7,19,  0,59, 10,28, 
     3,69,  7,82, 10,64, 14,40,  0,27,  8,82,  1,27, 11,43,  5,56, 13,17,  4,18, 12,20,  6,98,  9,43,  2,68, 
    10,84,  8,26,  2,87, 11,61, 13,95,  6,23, 14,88,  3,89,  9,49,  7,84,  4,12,  5,51, 12, 3,  0,44,  1,20, 
     3,43,  2,54, 12,18, 13,72,  1,70,  6,28, 14,20,  5,22,  4,59,  8,36,  9,85, 11,13,  0,73, 10,29,  7,45, 
    11, 7, 14,97,  5, 4,  6,22, 10,74,  9,45, 13,62,  1,95,  4,66,  8,14,  0,40,  3,23, 12,79,  2,34,  7, 8
  };
  // Taillard 20x15 instance 1
  const int tai_20_15_1[] = {
    20, 15, // Number of jobs and machines
     2,55,  5,66,  1,48,  8,59,  3, 8,  4,21, 14,64,  7, 7, 10,80, 13, 5, 11,59,  9, 8, 12,91,  6,11,  0,81, 
    14,86,  8,76, 12,40,  4,76, 11, 9,  3,23,  6,80,  9,51,  0,46, 10,48,  1,68, 13,51,  2,15,  7, 5,  5,82, 
     7,84, 12,97,  1,26,  8,70,  2,33, 10,31,  3,20, 11,39, 13,42, 14,33,  5,70,  6,84,  0,23,  9,54,  4,55, 
     1,60,  8,82,  5,14, 11,36,  7,22,  6,21,  3, 3,  2,11,  4,82,  9,92, 12,52, 13,85,  0,77, 14, 3, 10,89, 
     8,83,  4,33, 12,15,  1,36,  3,96, 14,99,  2,81,  9,24, 13,59,  6,89,  5,11, 10,13, 11,26,  7,91,  0,87, 
     2,51, 14,20, 10,89,  7,99,  3,95,  0,41,  1, 7, 13,67,  9,77,  6,45, 11,74, 12,91,  4,87,  5, 1,  8,55, 
     0,35,  4,71, 13,47,  1,34,  8,77, 10,68, 11,85,  6,27,  9, 2,  2,99,  5, 9, 12,18,  7,28,  3,33, 14,92, 
    12,76,  2,58, 11,37,  9,28,  8,80, 10,96, 13,97,  4,92,  5,84, 14,68,  6, 1,  3,86,  1,33,  7,66,  0,20, 
     7,17,  3,11,  4,18,  5,90, 13,57,  0,95, 11,17, 10,33,  9,61,  1,49,  8,36,  6,38, 12,62, 14,73,  2,25, 
     7,82, 14,84, 12,87,  6,44,  5,96,  9,64, 10,68,  0,57,  3,65,  4,89,  2,42,  1,77,  8,43, 13,76, 11,38, 
     0,54,  9,66, 13, 8,  7,48,  6,84,  3,15, 11,93,  8,94, 10,57,  4,16,  2,64,  1,13, 14,62, 12,63,  5,53, 
    14,21, 10,70,  3,42, 12,29,  5,83,  7, 5,  4,16,  6,76,  1,67,  2,46,  0,67, 13,83,  9,46, 11,29,  8,26, 
    11,96, 10,42,  5,49,  1,54,  3,58, 13, 8,  9,41,  7,14,  8,35, 14, 9,  0,74,  2,16,  6,50, 12,69,  4,45, 
     7,69,  6,90, 13,17, 10,18,  3,45,  1,48,  5,31, 11,29,  4,27,  8,85,  0,71, 12,92,  9,20,  2,11, 14,86, 
     2,41,  4,24, 14,82,  5,50,  0,24,  7,75, 10,34, 12,80,  1,71,  9,54,  3, 5,  8,42,  6, 8, 13,35, 11,93, 
     5,63, 14, 4, 12,85,  7,53,  3,61, 13,54,  0,16,  9,18, 10, 5,  6,43,  1,24,  2,88,  8,67,  4,79, 11,41, 
    14,17,  8,37,  1,56, 10,70, 11,56, 12,24,  7,95,  0,12,  3,96,  2,27,  9,55, 13,36,  5,41,  6,65,  4,23, 
     5,79,  2, 6, 10,89,  3,69, 12,16,  4,56,  6,81, 11,98,  0,12, 13,19,  8,88, 14, 3,  7,36,  1,67,  9,74, 
     0,38,  9,76, 10,47,  4,21,  2,80,  6,97, 13,35,  1,45,  3,74, 14,92,  7,98,  8,54,  5,91, 12,79, 11,46, 
     2,34, 12,56,  9,26,  8,62,  4,82,  6,38, 10,89, 14,33,  7,50,  5,62,  1,39, 11,63,  3,88,  0,13, 13,42
  };
  // Taillard 20x15 instance 2
  const int tai_20_15_2[] = {
    20, 15, // Number of jobs and machines
    12,91, 11,17,  8, 4,  9,63,  7,67, 13,30,  0,87, 10,80,  2,95,  4,14,  5,17,  6,22,  3, 1, 14,85,  1,41, 
     2,77,  5,77,  0, 9, 10,77,  4,24,  1, 8, 13,64, 11, 6,  3,12, 14,13,  6,71,  8,76,  9,95, 12, 8,  7, 6, 
     3,92,  2, 3,  6,12,  9,27,  5,58, 12,66,  0,99, 13,33,  7, 7, 10,78, 14,96,  1,30,  4,54,  8,23, 11,88, 
     9,19, 14,45,  5,65,  7,24, 13,30, 10,30, 12,49,  2,32,  3,78,  8,31,  1, 3,  6,25, 11, 9,  0, 2,  4,22, 
     3,84,  8,61,  6,35,  1,44, 13,37,  0,16,  9,97,  5,85, 14,51,  2,26, 12,13,  7,76,  4,41, 11, 2, 10,96, 
     3,85,  8,55, 13, 2, 11,65, 12,52,  1,97,  4,81, 14, 8,  6,22,  5,59,  9,95,  0,52,  7,85, 10,64,  2,13, 
    11,64,  2,94,  0, 4,  6,13,  4,98,  1,26,  5,32, 12,20,  9,97,  7,28,  3,63,  8, 2, 13,23, 10,14, 14,62, 
    12,56,  3,98,  4,56, 11,28,  8, 1,  1,96,  5,27,  0,38, 13,41,  6,94, 10,77,  9,63,  2,63, 14,81,  7, 6, 
     5,63,  8,98,  7,64,  0,37, 12,89, 13,96,  1,88,  6,13,  4,72, 14,28, 10,57,  9,99,  3,11,  2, 8, 11,96, 
     6,17,  3,71,  9,80,  8,33,  2,87,  1,82, 12,44,  7,14,  5,85, 14, 2,  0,60,  4,72, 11,27, 13,63, 10,66, 
     6,47,  0,42,  4,61, 14,17,  8,65, 13, 5, 12,96, 11,47, 10, 9,  1,20,  9,10,  7,11,  5,86,  3,90,  2,65, 
     0,66,  6,91,  4, 8,  3,37,  8,99,  2,90, 11,16,  1,89,  9,17,  5,98, 13,87, 12, 8, 10,40, 14,33,  7,37, 
     2,99,  9, 2,  5,22, 12,12,  3,13, 14,62,  4,30, 13,44, 11,25,  7,56,  1,10, 10,44,  8,25,  6,39,  0,65, 
    11,35,  7,62, 10,52,  4,84,  8,30, 14, 2,  6,50,  3,69,  9,64,  5,54,  1,45, 13,38,  2,90, 12,70,  0,37, 
     8,73, 13,40, 10,16, 12,21,  0,50,  9,10,  2,46,  6, 2, 11,48,  1,16,  3,58, 14,37,  5,12,  7,30,  4,82, 
    14,76,  7,40, 11,21,  6,91, 10,48,  9, 6,  2,91,  0,75,  1,79, 12,51,  8,51,  3,81,  4,70, 13,65,  5,19, 
     8,49, 13, 5,  7,59,  9,40, 11,74, 12,70,  5,84,  4,47,  2,25,  3,86, 14,75,  6,26,  0,51, 10,32,  1,15, 
     8,11, 14,18,  5, 6, 11,60,  1,83,  0,64,  7,85,  3,21, 12,52,  2,49,  9,30, 10,56, 13,31,  6,25,  4,31, 
     8,83,  6,42,  1,11, 11,64,  7,44, 12,90, 14, 8, 10,35,  0,72,  9,67,  3,72,  4,55,  5,43, 13,88,  2,35, 
    13,19,  1,53,  4,80,  0,89,  5,21,  7,34,  3,56,  6,89, 12,50,  8,28, 11,15,  2,27, 10,74, 14,83,  9,79
  };
  // Taillard 20x15 instance 3
  const int tai_20_15_3[] = {
    20, 15, // Number of jobs and machines
     8,56, 13,25,  3,17,  7,63, 10, 9,  6,30, 14,75, 12,22,  9,42,  2,83,  0,69,  4,90,  5,88, 11,20,  1,30, 
    11,39,  4,20,  6,35,  3,79,  8,35,  9,66, 12,15,  5,56, 13,60,  0,72,  7,52, 10,14, 14, 2,  2,16,  1,59, 
    14, 5,  9,31,  4,55,  0,70,  2,49, 13,70,  6,92,  7,40, 11,13,  1,14,  3,49,  5,30, 10,50, 12,77,  8,81, 
     0,64, 12,63, 10,21,  1,21, 11,29, 14,10,  8,25,  5,60,  9,93, 13,24,  2,48,  6,52,  3, 8,  4,30,  7,37, 
     2, 4,  6,32,  4,10, 13,77,  8,45, 12,37,  3,89, 10,60,  9,59, 11,42,  0,48,  7,30,  1,22,  5,23, 14,15, 
     1,14,  4,10, 13,68,  7,95, 12,42,  8,29,  3,44,  0,23, 14,61,  5,57, 10,45, 11,98,  9,30,  6,27,  2,13, 
     6,50, 12,55,  3,23, 11,25,  0,51,  1,55,  7, 9, 13,87,  4,21,  8,48,  5,55,  9,22, 14,47, 10,50,  2,86, 
     5,11,  7,43, 14,26, 11,31,  4,18,  3,59, 10,84,  0,33,  1,73,  6,20, 13,34, 12,92,  8,65,  9,87,  2,37, 
     3, 9,  2,20,  6,11,  4,21, 11,11, 10,96,  0,94,  8,91, 14,92,  7,97, 13,28,  5,55,  1,89,  9,34, 12,61, 
     3,10, 11,58, 14,86, 10,86,  2,87,  4,18,  1,74, 13,64,  6,12,  9,22,  5,80,  8, 5, 12,95,  7, 6,  0,35, 
     9,47, 10,68,  6,60,  7,20,  4,14, 12, 6,  5,20, 14, 6, 13,46,  1,79,  8,32,  0,82,  2, 7,  3,74, 11,54, 
     7,20,  5,99, 11,55, 14,78,  8,35,  0,26, 13,23, 12,87,  2,86,  9,25, 10,98,  1, 1,  4,16,  3,33,  6,50, 
    11,35,  0,34,  6,66, 12,47,  5,48, 10,52, 13,33,  3,77,  4,38,  1,65,  9,58, 14,71,  2,14,  8,85,  7,13, 
     2,85,  9,86,  4,15,  6,68,  3,32,  7,83, 13,80,  5,81, 12,10, 10,12,  1,31, 11,38,  8,78, 14,44,  0,18, 
     6,60, 14,58,  5,16,  8,24, 13,57,  4, 8,  1,41,  3,39,  0,28,  7,56, 12,37,  2,34, 10,39, 11,69,  9,52, 
    10,76, 14,87,  8,91,  7,13,  6, 4,  5,32,  1,58, 13,62, 11,83,  2,48,  3,41,  9,36, 12,68,  0,28,  4,12, 
     5, 1, 11,67,  1,98,  4,41,  7,84,  6,34, 14,86, 13,75,  8,93, 12,83,  3,66,  2,93,  0,47,  9,58, 10,64, 
     4,61, 14,49,  2,35,  6,92,  0,84, 11,57,  7,31, 13,50,  9,53,  1,11,  5,74,  3, 8,  8,14, 10,12, 12,50, 
     7,19, 14,89, 10,67,  1,10,  5,75,  9,49,  2,75,  4,66,  0,37, 11,77, 13,94,  3,60,  6,38, 12,52,  8,61, 
    11,29, 13,73,  7,62,  8,19,  6,99,  0,95,  5, 2,  4,39, 10,70,  1,90,  3,10,  2,60,  9,21, 12,40, 14,17
  };
  // Taillard 20x15 instance 4
  const int tai_20_15_4[] = {
    20, 15, // Number of jobs and machines
     7,15, 12,89,  6,49,  3,95,  8,40,  5,79,  0,44,  9,59,  1,87, 10,88,  2,48,  4,44, 13,43, 14,11, 11,75, 
     8, 6,  3,46, 12,18,  5, 4,  6,56,  9,44,  1,15, 14,40,  4,44,  2,79, 11, 1,  0,32, 10, 5, 13,92,  7,76, 
     1,78,  0,45,  8,61,  4,49, 11,26, 14,36, 12,94,  6,80, 13,49,  9,53,  2, 4,  5,51,  7,82, 10,36,  3,76, 
    11,58, 13,34, 10,70,  0,19,  4,85,  7,69, 14,87,  5,38,  3, 5,  2,88,  9,66,  1, 3, 12,10,  8,28,  6,18, 
    14,78,  6, 7,  2,83, 10,75, 11,39,  5,24, 12,10,  9,13,  3,42,  1, 2, 13,61,  4,26,  0,11,  7,89,  8,39, 
     7,80,  5,88, 12,13, 13,92,  9,11, 11,62,  1,42,  4, 3,  3, 6,  6,36,  2,49,  8,98,  0,40, 14,59, 10,15, 
    14,83, 13,12,  8,48,  9, 1,  1,76,  0,32, 11, 1,  4,81,  2,53,  3,70, 10,78,  6,75,  7, 7, 12,82,  5,31, 
     7,75, 13,13,  4, 9, 11,11,  0,49, 10,15,  5,57,  2,84,  6,77,  1,80,  8,41, 12,82,  3,68,  9,64, 14,50, 
     5,39, 11,64,  4,88,  1, 9, 12,97, 14,99, 13,27,  7,48,  8,18,  6,49,  9,50,  2,26,  0,54,  3,80, 10,77, 
     9,66,  4,87,  3,27,  8,47, 14,68,  5,75,  6,31, 13,25, 11,49, 10,85, 12,86,  7,12,  1,26,  2,82,  0,78, 
    11,93, 13,87,  6,74,  5,26, 10,60,  3,76, 12, 3,  8,98,  2,72,  4,52,  9,73,  1,75,  0,28, 14, 1,  7,51, 
    11,79,  1,13,  4,14,  7,27, 12,14,  3, 5,  5,58, 10,32, 14,38,  2,67, 13,70,  0,86,  6,28,  9,94,  8,33, 
     1,83,  5,67,  7,18, 12,20, 13, 4,  6,84, 11,22,  4, 8,  8,91,  3,89, 14,25, 10, 8,  0,69,  9,85,  2,46, 
     4,64, 10,18,  7,12,  8,43,  3,78, 13,65,  0,20, 14,53, 11,32, 12,49,  9,25,  6,10,  1,43,  2,30,  5, 3, 
     8,99,  4,29, 11,50, 13,99,  1,53,  9,65,  0,23,  6,49, 12,91,  5, 1,  2,86, 10, 7,  3,68,  7,71, 14,89, 
    13,13,  8,19, 10,31,  5,94,  6,78, 14,43, 11,16,  7,56, 12,76,  0, 1,  1,11,  4,24,  9,13,  2,62,  3,55, 
     5,43,  8,24, 13,85, 11,20,  9, 6, 14,44, 10,49,  1,41, 12,67,  6,47,  4,25,  7,86,  3, 6,  0, 6,  2,30, 
     2,68,  9,92,  4,15,  0,80,  5,29,  7,72,  8,22, 10,41, 12,49, 11,36,  3,97, 13,80,  6,23,  1,77, 14, 4, 
     1,51,  4,34,  8,10, 10,96,  6,74, 11,80,  9,65,  5,75, 13,14,  0,83,  7,13, 12,78,  3,61, 14,43,  2,58, 
     1,69, 10,56, 13,15, 12,89,  5,22,  4,21,  6,89, 14,16, 11,59,  7,83,  8,20,  2,33,  9,11,  0,67,  3,90
  };
  // Taillard 20x15 instance 5
  const int tai_20_15_5[] = {
    20, 15, // Number of jobs and machines
     2,76, 11,17,  0,58, 13,26,  1,90,  8,77,  9,63,  6,87,  4,74,  7,35, 12,60,  3,90, 14,64,  5,68, 10,28, 
     5, 5,  8,79,  9,71,  3,42,  1,71, 13,20, 11,86,  0,88, 14,47,  7,62,  4,37, 12,87, 10,47,  6,97,  2,24, 
     5, 2,  2,67,  8,28, 14,98, 13,66,  1,42,  6,46,  9,23, 12,94,  4,25, 11,89,  0, 3,  7,38,  3,76, 10,76, 
     8,96, 10,79,  4,19,  0,36,  3,87, 11, 6, 13, 9,  6,18,  1,32,  5,37,  2,55,  9, 3, 12,15, 14,12,  7,45, 
     8,71, 11,73,  1,17,  0,41,  5,71, 13,88,  2,43, 14,59, 10,37, 12,22,  9,21,  3,77,  4,66,  6,46,  7,52, 
    11,19,  3,12, 13,87,  9,22, 14,41,  1,29,  0, 6,  7, 4,  4,79,  5,78, 10,21, 12,27,  6,16,  2,54,  8,60, 
    13,96,  3,39, 11,82, 10,15,  5,22, 12,29,  0,64,  4,92, 14,68,  6,60,  7,37,  8,10,  9,47,  2,68,  1,74, 
     5,28,  8, 3,  6,71,  7,59,  2,94,  3,60, 10,98,  4,77,  1, 9, 14,57, 11,21,  9,74, 13,19,  0,74, 12,19, 
    12, 7,  8,38,  9,63,  7,69,  3,13,  6,56, 11,53, 13,58, 10, 2,  0,93,  2,90,  5, 6,  1,66,  4,76, 14,60, 
     5,85, 14,46, 11,75,  4,34, 10,33,  8,94,  9,50,  2,20, 13, 4, 12,28,  7,60,  1,74,  0,90,  3,51,  6,67, 
    10,88,  9,11,  1,35, 12,87,  2,14,  7,85,  3,12,  4,21,  0,23,  5,37,  6,12,  8,88, 13,98, 14,33, 11,76, 
     9,30,  7,89,  5,91,  6, 3,  0,97, 14,71,  1,73,  3,16,  8,15, 11,98,  2,71, 12,19, 10,65, 13,89,  4, 2, 
     2,61, 13,86, 12,71,  3,76,  9,88,  1,32,  5,31, 10,50, 11,25,  6,84,  0,79,  7,34,  8,59, 14,75,  4,78, 
     3, 9,  0,59,  9,93, 13,69,  8,38,  2,65,  6,96,  1,67, 10,74, 12,41,  7,61, 14,68,  4,11,  5,24, 11,25, 
     6,86,  5,77,  0,21, 13,50,  8,72, 14,68,  2,91,  7,72, 12,65,  4,52, 10,45,  3, 5,  1,71,  9,68, 11,25, 
     6,37,  8,27,  0,23,  7,26,  4, 2,  1,36, 11,20, 10,65, 13,61, 14,27, 12,35,  2,50,  9,45,  3,80,  5,19, 
    13, 5,  2,57,  1,70,  8,95,  3,46, 12,36,  6,88, 14,42, 11,49,  9,23,  5,63,  7,77,  4,47, 10,88,  0, 7, 
    13,29,  7,64,  5,23, 11,42,  4,33,  6,65, 10,92, 14,80,  2,49,  9, 3,  0,83,  3,20,  8,63, 12,78,  1,85, 
     9,67,  2,47, 10,48, 11,57,  7,84,  1,63, 14,48,  3,70,  6,85,  8,93,  5, 1,  4,63, 12,87,  0,29, 13,90, 
    13,80,  4,14, 11,41, 12,73,  7,22,  0,93,  5, 6,  1,81,  8,19, 14,62,  9,62,  2,85,  3,25, 10,70,  6,10
  };
  // Taillard 20x15 instance 6
  const int tai_20_15_6[] = {
    20, 15, // Number of jobs and machines
     6,40,  8,57, 11,95,  0,33, 14,72, 13,31,  9,55,  5,36,  3,92, 12,72, 10,80,  2,39,  7, 3,  4,86,  1,29, 
     0,20,  9,56,  1,68,  6,49,  5,35, 13,58, 11,90,  8,52,  3,97,  4,95, 12,94, 14,32,  7,56,  2,71, 10,83, 
     8,98,  3, 5,  9,97,  1,85,  0,31, 10, 5,  5,16, 14,19, 12,75, 13,50,  6,23,  2,63,  7,89, 11,65,  4,24, 
     5,80,  1,58,  7,41, 10,34,  0,94,  2,63, 13, 8, 11,75, 14,60,  3,42,  6,38,  9, 3,  8,73, 12,79,  4,36, 
     2,71,  9,65,  6,26,  7,59,  0,54,  8,69, 13,86,  5,86, 10,43,  3, 7, 12,35,  4,86, 14,99,  1,94, 11,99, 
     5,82,  3,70,  9,53,  2,74,  1,58,  4,70, 10,50,  8,37, 13,90,  0,22, 11, 9, 12,98,  6,30, 14,94,  7,43, 
     8,71,  7,63, 12,65,  9,15,  6,39, 14,93,  4,97, 11,67,  5, 5,  1,61,  3,64, 13,68, 10, 2,  0,31,  2,17, 
    13, 7,  7,10,  6,65, 11,63,  2,92,  0,90, 14,85,  4,81,  3,32,  1,62, 10, 5,  8,21,  9, 5, 12,49,  5,36, 
     1, 9, 14,31,  0,77, 10,49, 11,24,  8,67,  7,66,  5,37,  9,82,  3,69,  4,63,  6, 4, 12,62,  2,52, 13,66, 
    13,67,  1,73,  3,87, 14,28,  5,43,  9,13,  2,18,  0,73, 11,69,  7,20, 12,97,  4,73, 10,64,  6, 8,  8,13, 
    10,85,  5,30,  9,80, 13,64,  6,18,  8,72, 11,66,  4,72, 14,28,  0,13,  7,17,  2,55, 12,17,  1,42,  3,58, 
    13,87,  9,36, 14,87, 10,27,  3,23,  7,72,  2,49,  5,79,  6,30, 11,17,  8,57,  1,56,  0,82, 12, 4,  4,66, 
     5, 6,  9,62,  7,78,  8,78, 10,62, 13,17,  2,43,  6,18,  1,53,  0,16, 12,66, 11,20,  3,69,  4,49, 14, 4, 
     9,34, 11,89,  6,23,  7,69,  2,12,  8,59, 14,50,  3,57,  0,85, 12,16,  4,55, 13,82,  5,61,  1, 5, 10,36, 
    10,71,  2,19,  1,96,  5, 9,  0,85,  3,88, 14, 3, 11,68,  4,52,  8,29,  9,29,  7,22, 12,10,  6, 9, 13,65, 
    12,23, 14,34,  0,73,  2,34, 10,85,  5,40, 13,73,  3,15,  7,51, 11,91,  1, 1,  9,43,  6, 7,  8,63,  4, 7, 
     8,18,  6,62, 12,97,  4,49, 13, 4, 10,71,  5,68,  7,51,  9,42,  0,40,  1,32, 14,92,  3,11,  2,46, 11,99, 
    14, 1,  5,93, 12,46,  4,12,  1,11, 13,82,  6,56,  2,39,  8,84,  7,43, 10,77, 11,22,  9,23,  3,47,  0,43, 
     7,98,  2,38,  6,92,  3,72,  8,78, 14,70,  5,47,  9,32,  4,84, 13,84,  0,63, 11,95, 12,59,  1,26, 10,14, 
    10,80,  7,53, 13,72,  4, 9,  5,89,  3,30,  6,35,  1,34,  8,52,  0,87, 12,97, 11,34,  9,73, 14,68,  2,31
  };
  // Taillard 20x15 instance 7
  const int tai_20_15_7[] = {
    20, 15, // Number of jobs and machines
     1,70,  6, 6, 10,29, 14,55,  7,14,  5,33, 13,66,  4,14,  3, 7,  8,57,  0,55,  9,18, 12,62,  2,46, 11,92, 
     0,30,  9,53,  3,19,  2, 1,  8,98,  5,81, 14,63, 12,62,  6,10, 11,15, 10,73,  7,75,  4,80,  1,84, 13,97, 
     1,42,  6,61,  2, 6, 11,60,  3,24,  4,70, 10,78,  9,11, 12,35,  8,38,  7,61,  5,90,  0,74, 14, 1, 13,60, 
    12,76, 14,84,  8,72,  9,17,  5,27,  3,86,  0,84,  1,71, 13,90, 10,27,  6,13, 11,98,  4, 3,  7,57,  2,66, 
    14,38, 10,58,  8,80,  6,24,  0,50,  4,76,  5, 6,  9,12, 11,26,  3,14,  7,35, 13,38,  1,55, 12,33,  2,42, 
     8,77,  2,87,  9,59, 12,19,  3,84,  0,85, 13,63, 14,51,  5,18, 11,29,  7, 2,  1,13,  4, 1,  6,25, 10,54, 
     5,19,  3,83,  8,71,  7,22,  0, 4, 12,68,  4,68,  2,88, 14,80,  6,55, 10,11, 11,19,  9,39,  1,68, 13,37, 
     5,38,  8,98, 12,11,  1, 3,  7,33,  4,43,  2,19,  9,90,  6,56, 14,83, 13,76,  0,97,  3, 2, 10,76, 11, 1, 
    14,25,  8,65,  7,88, 12,56,  6,75, 10,48,  0,40,  1,19, 11,39,  9,40,  5,43,  4,99,  2,23,  3,74, 13,39, 
     0,97, 14,66,  2,54,  5,29, 10,23,  4, 9,  9,74,  7,46, 11,85,  6,98,  3,74, 13,12,  1,71, 12,65,  8,25, 
     1, 3,  3,40, 11,81,  0,74,  9,67,  5,93,  2,76, 14,16,  6,12,  7,67,  8,52, 12,20, 13,24, 10,71,  4,90, 
    12,13,  8,59,  3,95, 10,79,  2,46,  0,16,  7,67,  9,67, 14,64,  5,85,  4,85,  1,27, 11,26, 13,56,  6, 1, 
     1,64,  6, 1, 14,29,  2,66, 11,32,  4,35,  8, 8,  3,26, 13,94, 10,94,  0,62,  9,42, 12,60,  7,56,  5, 7, 
     1, 3,  4, 7,  9,40,  3,93, 11,55, 14,75,  8,25,  0,21, 13,30, 10,82,  2, 1,  6,58,  5,53,  7,88, 12,19, 
     2,66,  7,88,  3,48,  1,77,  8,38,  4,78, 14,16, 11,41, 12,93,  5,38, 10,25,  0,51, 13,14,  6,98,  9,61, 
    10,33,  2,23,  4, 7,  6,60,  1,74,  9,54,  7, 2, 12,22,  3,32, 11,15, 13,79, 14,83,  5,69,  8,41,  0,19, 
     2,61,  0,26,  5,66, 14,85,  4,34,  6,15, 11,59, 10,75,  8, 3,  7,80, 13,39,  1,69,  3, 6,  9,73, 12,65, 
     3,96,  0, 6, 11,52, 14,22,  5,35, 10,79,  4,16, 13,72,  9,29,  6,26,  8,52,  1,58,  7,57,  2,31, 12,74, 
     1,42,  0,79,  7,84,  5,25,  9,70,  8,90, 14, 8, 13,60,  2,81, 10,88,  4,11,  3,71, 12,61, 11,49,  6,81, 
     1,52, 12, 3, 14,57,  4,66,  7,88,  9,42,  8,23,  3,72,  6,97,  0,91, 10,50,  2,43, 11,82, 13,62,  5,27
  };
  // Taillard 20x15 instance 8
  const int tai_20_15_8[] = {
    20, 15, // Number of jobs and machines
     8,78,  1,22, 10,89,  7,46,  9,42,  5,59,  6,13,  3,90,  2,41, 13,69,  4,71,  0,13, 14,48, 11,97, 12,62, 
     1,87,  9,56,  4,44,  5, 1,  0,74, 11, 3,  6,89,  7,77, 12,29,  2,17, 14,12,  8,60, 13,92, 10,35,  3,24, 
     6,57,  2, 6,  8,73,  9,36,  3,57,  5,25,  4,94, 12,21, 11,46,  7,89, 10,47, 13, 2,  0,57, 14,67,  1,55, 
     4,74,  9,40,  1, 1,  2,37, 13,52,  3,84,  6,50,  0,39, 12,65,  5,80, 10,44,  7,70,  8,25, 11,27, 14,12, 
     6,15,  7,72,  9,25, 13,69, 11, 8,  1,96,  5,14,  0,13, 12,31,  3,74, 14,13,  2,91,  4,39,  8,57, 10,46, 
     2,95, 12, 2,  6,68, 13,22,  8,40,  4,33,  1,36, 14,32,  5,50,  9,32, 10,10,  0,63,  3,85,  7,16, 11, 1, 
    13,15,  2,98, 12,21,  5,10, 11,35,  6,76,  8,29,  4,64, 10,34,  7,25,  1,88,  0,30,  3,52,  9,43, 14,45, 
     9,14,  8,21, 14,86,  7, 2,  3,19, 10,78,  1,92, 12,85,  4,54, 13,61, 11, 6,  6,13,  5,85,  0,87,  2,43, 
    14, 8,  3,58,  6,67,  8,16, 12,99,  9,33,  4,14,  5,47,  1,21,  7,77,  0,64, 10,29,  2,73, 11,10, 13,47, 
    11,55,  4,84, 14,55,  8,26, 13,83, 10, 6,  9,99,  0,51,  5,28,  6,63,  2,93, 12,52,  3,86,  1,68,  7,46, 
     6,43,  2,19,  8,32,  0,36,  3,18,  5,60,  7,97, 10,13, 14,48,  9,36, 11,79, 13,14,  4,69,  1,15, 12,23, 
     9,12,  1,68, 14,36,  0,72, 13,90,  2,68,  7,28,  8,13,  5,18, 11,68,  4,49, 10,52,  6,50,  3,63, 12,10, 
     8,76, 11,75, 12,73,  3,40,  7,58, 13,23,  6, 6,  1,31, 14, 5,  5,16,  9,73,  2,41,  4,47,  0,67, 10,37, 
     8,93, 12,58,  7,58, 11,93,  3,21, 14,90,  6,13, 10,82,  5, 6,  1,62,  2,52,  9,44,  0, 4,  4,29, 13,20, 
    10,98, 13,66, 12,63,  8,63,  3,71, 11, 9,  5,10, 14,94,  0,93,  4,77,  2,47,  6,40,  1,24,  9,96,  7,56, 
     8,33,  6,18, 10,95, 14,80,  1,87, 11, 3,  3,72,  5,18, 12,30,  9,32,  2,93,  4,10,  0,86,  7,58, 13,45, 
    13,69,  2,83,  8,62, 14,77,  7,41,  0,13,  9, 8,  6,87,  3, 3, 11,65, 10,40,  5,11, 12,32,  1,71,  4,86, 
     0,21, 13,77, 12,76,  6,77,  7,61,  2,82, 11,76, 14,42,  8, 6,  3,88,  4,51, 10,50,  1,29,  5,63,  9,18, 
     9,87,  6,16,  2,98, 12,27,  0,58,  8,59, 11,69,  4,95,  5,85,  1,80,  7,97,  3,88, 14,11, 10, 8, 13,42, 
     2,25,  8,16,  6,20, 12,67, 14,85, 10,74, 13,48,  5,44,  0,95,  7,28, 11,66,  9,34,  3,25,  4,94,  1,19
  };
  // Taillard 20x15 instance 9
  const int tai_20_15_9[] = {
    20, 15, // Number of jobs and machines
     7,84,  0,58, 12,71,  4,26,  1,98,  9,36,  2,12, 11,30, 10,87, 14,95,  5,45,  6,28, 13,73,  3,73,  8,45, 
     4,29,  8,22,  7,47,  3,75,  9,94, 13,15, 12, 4,  0,82, 11,14, 10,35,  1,79,  6,34,  5,57, 14,23,  2,56, 
     1,73,  4,36,  7,48, 13,26,  3,49,  8,60, 10,15,  5,66, 12,90, 14,39,  9, 8,  6,74,  2,63,  0,94, 11,91, 
     5, 1, 11,35,  9,23, 12,93,  7,75,  1,50,  6,40, 13,60,  8,41,  2, 7,  0,57, 14,72,  3,40,  4,75, 10, 7, 
     4,13, 11,15, 12,17,  1,14,  0,67,  9,94,  6,18, 13,52,  2,53, 14,16,  5,33, 10,61,  3,47,  8,65,  7,39, 
     2,54,  6,80,  3,87,  8,36, 14,54,  0,72,  4,17, 10,44, 11,37,  1,88,  7,77, 13,84, 12,17,  5,82,  9,90, 
     4, 4, 14,62,  5,33, 10,62,  8,86,  7,30,  6,39,  1,67,  0,42, 12,31,  9,83, 13,39, 11,67,  3,67,  2,31, 
     7,29, 10,29, 11,69, 14,26,  3,55,  2,46,  4,53,  5,65,  1,97, 12,24,  9,69,  6,22, 13,17,  0,39,  8,13, 
    14,12, 11,73,  0,36, 13,70,  3,12,  2,80,  1,99,  8,70,  5,51,  7,14,  4,71, 12,28,  6,35, 10,58,  9,35, 
     0,61,  5,49, 12,74,  1,90, 13,60, 10,88,  9, 3,  4,60,  2,59,  8,94, 14,91, 11,34,  7,26,  6, 4,  3,26, 
     4,89,  3,90,  8,95, 12,32,  9,18, 11,73,  2, 9, 14,19,  5,97,  7,58, 13,36,  6,62, 10,13,  1,16,  0, 1, 
     9,71,  6,47,  1,95,  0, 7, 14,63,  7,49, 13,24, 12,46,  2,72, 11,73,  5,19,  8,96, 10,41,  3,15,  4,81, 
     4,45,  3, 9,  0,97, 14,62, 13,77,  9,78,  7,70,  2,19, 11,86,  8,15, 10,23,  1,46,  6,32, 12, 6,  5,70, 
    12,74, 10,46,  3,98,  6, 1,  4,53,  5,59,  0,86,  7,98,  2,76,  8,12, 13,91, 11,98, 14,98,  9,11,  1,27, 
    14,73,  7,70,  5,14,  8,32, 11,19,  0,57,  2,17, 13,96, 12,56,  4,73,  6,32,  1, 7, 10,79,  9,10,  3,91, 
     6,39, 14,87, 12,11,  2,81,  7, 7,  5,79,  8,24, 13, 9, 11,58,  9,42,  0,67,  3,27,  4,20,  1,19, 10,67, 
     9,76,  5,89, 14,64, 10,14, 12,11,  1,14,  4,99, 13,85,  0,81, 11, 3,  3,46,  2,47,  7,40,  6,81,  8,27, 
     9,55, 12,71,  4, 5, 14,83, 11,16,  8, 4,  0,20,  7,15,  5,60,  3, 8,  1,93, 10,33,  6,63, 13,71,  2,29, 
    12,92,  2,25,  3, 8, 14,86,  5,22,  1,79,  6,23, 11,96, 13,24,  9,94,  7,97, 10,17,  8,48,  0,67,  4,47, 
     3, 5, 12,77, 10,74,  5,59, 14,13,  0,57,  9,62,  8,37, 13,54,  6,69, 11,80,  1,35,  7,88,  2,47,  4,98
  };
  // Taillard 20x20 instance 0
  const int tai_20_20_0[] = {
    20, 20, // Number of jobs and machines
     6,64,  1,57, 15,81,  2,98, 19,59, 13,87, 16,93, 18,62,  3,20, 12,14, 14,85,  5,45, 10,47,  7, 9,  8,94,  9, 9,  0,15, 17,66, 11, 1,  4,94, 
     8,39,  6,96, 10,88,  9,83, 19,77,  1,58,  0,83, 17, 3,  2,78, 11,68,  7,64, 13,97, 18,33, 15,25,  4,47, 14,44,  5, 7,  3,60, 16,42, 12,91, 
     1,96,  3,66,  4,88, 12,60,  0,22, 14,92,  7,62, 19,14, 10,89, 11,39,  5,94, 18,66, 13,10, 15,53, 16,26,  8,15,  9,65,  2,82, 17,10,  6,27, 
    18,93, 15,92, 10,96,  1,70, 19,83,  9,74,  2,31, 12,88,  4,51,  0,57, 13,78, 16, 8, 14, 7, 11,91,  3,79,  5,18,  8,51, 17,18,  6,99,  7,33, 
     2, 4, 10,82, 12,40, 15,86,  7,50, 14,54, 17,21,  5, 6,  8,54,  1,68, 13,82,  0,20,  3,39, 16,35,  4,68,  9,73, 11,23, 18,30,  6,30, 19,53, 
     0,94, 16,58, 10,93,  9,32, 17,91,  8,30,  5,56,  3,27, 19,92, 11, 9, 15,78,  2,23, 14,21,  4,60, 12,36, 13,29,  1,95,  6,99,  7,79, 18,76, 
    11,93,  0,42,  1,52, 19,42,  9,96, 10,29,  8,61, 17,88, 18,70, 16,16,  4,31,  3,65, 12,83,  7,78,  6,26, 15,50,  5,87, 14,62,  2,14, 13,30, 
    16,18,  3,75,  8,20, 10, 4, 18,91,  7,68,  1,19, 14,54, 19,85,  2,73, 12,43,  6,24,  5,37, 11,87, 17,66,  4,32, 13,52,  9, 9, 15,49,  0,61, 
    17,35, 18,99, 15,62, 11, 6, 10,62, 12, 7, 14,80,  3, 3,  1,57,  0, 7, 16,85,  9,30,  6,96, 19,91,  7,13,  8,87,  4,82,  2,83, 13,78,  5,56, 
     9,85,  5, 8,  3,66,  2,88, 11,15,  4, 5, 16,59, 14,30,  7,60, 13,41,  1,17, 18,66,  8,89, 15,78, 12,88,  6,69, 17,45, 19,82,  0, 6, 10,13, 
     5,90,  9,27, 18, 1,  0, 8,  3,91, 16,80,  6,89,  1,49,  2,32, 11,28, 15,90, 19,93,  7, 6,  8,35,  4,73, 10,47, 12,43, 17,75, 14, 8, 13,51, 
    11, 3,  5,84,  9,34,  4,28,  3,60, 15,69, 17,45,  7,67, 18,58, 19,87, 13,65,  1,62,  6,97, 12,20, 10,31,  0,33, 14,33, 16,77,  2,50,  8,80, 
    15,48,  3,90,  4,75,  7,96, 18,44, 13,28, 19,21,  9,51,  2,75, 10,17, 11,89, 14,59,  6,56, 17,63, 12,18, 16,17,  0,30,  8,16,  1, 7,  5,35, 
    13,57, 10,16, 16,42,  8,34,  4,37,  1,26,  2,68, 19,73, 14, 5, 12, 8, 18,12, 17,87,  0,83,  5,20,  9,97,  7,20,  6,85,  3,61, 11, 9, 15,36, 
     0,63,  5,11,  4,45, 19,10, 14,33,  8, 5,  1,41, 16,47, 15, 9, 10,74, 12,33,  2,35, 11,78,  6,12,  7,22, 18,44, 13, 8,  3,97, 17,10,  9,86, 
    11,33, 16,60, 17,21, 10,96, 15,69, 12,34,  0,94,  5,15,  4,23,  8,84,  3,16,  7,55, 13,50,  1, 5, 18,59,  9,35, 19,12,  6,57, 14,11,  2,51, 
     7,72,  8,42,  5, 4, 13,62, 19,15, 16,27, 11,16,  1,34, 14, 8, 18,50, 10,85,  6,12,  3,48, 15, 5,  4,25,  2,40,  0,81,  9,46, 17,67, 12,25, 
    17,83, 10,92, 15,25,  5,40,  4,21, 14, 4,  8,43, 18,38, 13,60,  6,24, 19, 3,  3,28,  1,86,  9,68, 11,55,  2,91, 12,97, 16,19,  7,73,  0,20, 
    14,28,  3,81, 16,46,  0,98, 10,46, 18,29,  4,96,  1,12,  5,71, 19,32, 12,64,  9,39, 11,16, 15,97, 13,99,  7,49, 17,75,  8, 7,  6,79,  2,80, 
    13,71, 10, 9,  3,11, 14, 8,  1, 4,  8,47,  0,93, 16,82, 19, 6,  4,49,  6, 7,  9,24, 11,92,  5,13,  2,86,  7,80, 17,34, 12,75, 15,35, 18,29
  };
  // Taillard 20x20 instance 1
  const int tai_20_20_1[] = {
    20, 20, // Number of jobs and machines
     3,94,  2,61, 19,12, 11,68, 10,40, 13,84, 16,30, 15,16,  1,34,  0,92, 12,53, 17,55, 18,61,  9,67,  5,30,  7,88, 14,12,  4,20,  8,16,  6,51, 
    14,22, 12,75,  4,29, 17,87,  7,47,  2,48, 10,21, 15,46,  8,77,  9,35,  3,10,  6,92, 16, 9, 13,75, 11,40,  1,89,  0,86,  5,33, 19, 2, 18, 1, 
    18,32, 17, 8,  0,99, 13,14,  7,41,  1,53, 11,97, 19,19,  5,39,  3,20,  2,91, 16,54, 15,97,  4,79,  8,21, 14,22,  9,93, 12,67, 10,17,  6,84, 
    17,13, 10,43,  8,97, 12,41,  5, 4, 16,35, 14, 6, 11,93,  6,32,  1,35,  9, 2,  4,54, 19,77,  0, 9, 18,97, 15,10,  3,45,  2,81, 13,76,  7,37, 
     8,26, 12,70,  1,33, 10,58, 13,38, 15,77,  5,86, 17,53,  9,47,  7,20, 18,71,  3,69,  4,95,  0, 4,  2,23, 14,89, 19,87, 11,20, 16,67,  6,65, 
     6,86,  0,73,  9,93, 16,26, 14,98, 18,37, 17,67, 10,87,  2,33, 13, 6, 11,68,  7,16, 19,12,  1, 5,  8,33,  3,87,  4,96, 15,46, 12,87,  5,89, 
    12, 3,  1,34,  6, 2, 14,96, 11,67, 15,37,  3,30, 10,50,  9,84, 19,27,  5,37, 17,89,  2,92,  4,68,  8,20, 18,80,  7,76,  0,74, 13,11, 16,38, 
     5,60, 12,97, 19,42,  1,73,  8,28, 13,69, 18,90,  9,44, 10,27,  2,54, 17,24,  3,36, 15,82,  6,13, 16,33,  7,80,  0,44,  4,99, 11,80, 14,82, 
     2,79,  8,62,  3,31, 10,27, 16,72, 15,12,  0, 4, 17, 4,  7,11, 13,35,  5,83, 14,57, 12,19,  9,80, 19,20,  6,16, 18,96, 11,24,  4,64,  1,93, 
    17,61,  2,86,  7,46, 19,58, 11, 2, 16,19, 13,46, 10,50, 15,79,  1,84,  5,14,  6,16,  8,76,  9,89,  3,85, 12,86, 18,60, 14,44,  0,28,  4,63, 
     7,10, 12,44,  8,26, 11,61, 16,92, 15,30,  4,19,  3,27, 14,22,  9,86, 19,22,  2,62, 13,75, 17,10,  6,78,  1, 3, 10,97, 18,88,  5,10,  0,46, 
     4,21, 17,51, 11, 3, 16,94, 15,82, 18,26, 14,83, 19,57,  6,86,  7,61,  5,80, 10,81, 13,25,  0, 5,  3,75,  9,38,  2,16,  8,20,  1,50, 12,52, 
     8,17, 16,86, 12, 6,  2,49,  5,74, 15,82, 10,86, 17,26,  7,80, 13,46,  4,94,  1, 7,  0,27,  3,26, 19,97,  9,14, 18,27, 14, 3, 11,12,  6,82, 
     1,46,  8,21, 18, 1, 11,99, 17,83,  9,22, 10, 2, 16,42, 19,61,  5,79, 12,17,  4,67,  3,61,  6,72,  7,49,  2,91, 14,38,  0,28, 13,34, 15,14, 
    13,50,  7,49,  4,40,  0,63, 19, 5,  2,80, 14,70,  3, 3, 11,62, 17,43, 16,58, 10,39,  1,52,  9,68, 12,71,  6,86, 15,61,  8,53,  5, 1, 18,97, 
    15,53,  0,51, 18,25, 16,16,  8,91,  4,93,  5,37, 14,61,  7,41, 17,49,  1,20,  3,24, 10,58, 19, 8,  6,72,  2,30, 13,15, 12,86,  9,31, 11,40, 
     3,72, 11,77,  2,34,  9,45, 15,83,  1,85, 10,19,  7, 5, 19,77,  5,75,  8,61, 13,89, 17,77,  6,44,  0,32, 16,86, 14,40, 12,23, 18,35,  4,57, 
    17,33,  6,16, 11,60,  5,70, 16,67,  4,37, 12,42,  9,24, 18,75,  0, 1, 10,22, 14,32,  7,21,  3, 3, 15,69,  1,77,  8,53, 19,64,  2,34, 13,15, 
     5,58,  6,55,  8,68, 12, 5,  2,20,  9,88, 16,91, 13,79, 18,55,  1,16,  7,53, 17,84,  0, 1, 15,66, 19,14,  3,83, 11, 1,  4,96, 14,54, 10,30, 
     3,80, 15,81, 10, 9,  4,49, 18,32,  1,19, 16,92,  9,65, 12,88,  7,64, 11, 4,  0,68,  2,79, 19,21, 13,84, 14,92, 17,66,  5,51,  6,83,  8,96
  };
  // Taillard 20x20 instance 2
  const int tai_20_20_2[] = {
    20, 20, // Number of jobs and machines
     7,33,  4, 8,  0,81, 10,68, 17,28, 18,91, 16,91, 15,74,  3, 7, 11, 7,  5,19,  6,50,  9,65, 19,53, 12, 9,  8,90, 14,69, 13,50,  2,58,  1,13, 
     3,69, 19,10, 17,58, 14,10, 11,91,  1, 5,  2,37,  7, 9, 16,93, 13,94,  9,46,  5,55,  8,99,  0,28, 18,95, 10,94,  6, 4,  4,51, 15,59, 12,10, 
    15,79,  0,70,  4,35,  8,82,  2,35, 14,84, 18,34, 12,87,  7,91,  5,69,  6,12, 16,31, 17,94, 11,65, 10,13, 13,16, 19,39,  9,46,  1, 4,  3,74, 
    17,50,  7,40, 12,81,  9,47,  0,96, 13,67,  1,94, 14,53,  2,22, 16,17, 10,23, 18,24,  8,66,  4,15,  6,56, 15,84, 19,79,  5,25,  3,13, 11,72, 
    19, 7,  6,81,  5,62, 15,50, 13,91,  4,77,  2,32, 18,10,  3,78, 16,78, 11,21, 14,78,  1,21, 17,10,  8,88,  9,23,  7,92, 10,34, 12,88,  0,48, 
    14,66,  0,71,  5,55, 18,25, 11,43,  2,24, 12,87,  7,59,  6,90, 13,63,  4,90, 19,22, 15, 6,  1,50,  3, 9, 10,18, 16,19, 17,52,  9,83,  8,66, 
     8,66, 14,39, 18,10,  7,80,  6,55,  3,38,  1,29, 11,41, 17,63, 10,32, 15,91, 19,27,  4,72,  2,71, 16,61, 13,35,  9,17,  0,26,  5,42, 12,64, 
    17,11, 18,33, 13,84, 15,12,  5,18,  8,57, 19,43, 16,24,  0,77,  2,85,  7,62,  3,49,  1, 5,  9,46, 11,93, 14,85,  6,92, 10,30,  4,64, 12,77, 
    11,38,  0,30,  9,31, 18,25,  1,90, 19,79, 16, 3, 12,52,  6,87, 10,30,  7,87, 14, 4, 15,57,  8,43,  4,55, 13,21, 17,30,  5, 1,  2,72,  3,75, 
     0, 9,  8,49, 18,91,  4,39, 13,40, 14,59,  1,20,  7,27, 19,67, 15,22, 16, 2, 10,47,  3,91,  6,11, 11,70,  5,97, 12,78, 17,69,  9,17,  2,40, 
    16,57,  6,32,  3,67,  8,26, 10,23,  1,55, 19,14, 17,77,  0,77, 13,82,  2,34,  4, 1,  5,64, 12,90,  9,37, 15,47,  7,27, 18,54, 11, 3, 14,94, 
     4,25,  7,33, 16,12, 10,27,  9,32,  0,49, 18,35,  1, 5, 19,73,  8, 3, 14,28,  2,54, 13,45, 11,32,  6,53,  5,99, 12,85, 15,86,  3,13, 17,99, 
    12,64, 13,77,  2,82, 18,32,  9,75,  8,32,  0,68, 10,16,  7,63,  3,81, 15,31, 17,58,  6,73, 16,12, 14,25,  5,64,  4,98, 11,72,  1,47, 19,84, 
    17,17, 18,98,  5,99,  8,39,  2,73,  4,82,  9, 1, 15,43,  7,48, 10,62,  3,44, 12,50, 13,44, 16,72, 14,89,  1,45,  0,44,  6,21, 11,79, 19,60, 
    12,87,  7,63, 10, 8,  2,20, 18,88,  4,88, 19,77, 14,88, 13,46,  3,30,  6,44,  1,42,  5,84, 16,41, 15,74,  8,52,  9,25,  0,87, 11,43, 17,77, 
     0,39,  3,93, 15,44,  1,23, 16,75, 13, 7, 14,60,  7,45, 18,71, 10,49,  5, 3, 11,68,  6,56, 19,20,  2,35, 17, 8,  8,79,  9,21, 12,48,  4,43, 
     3,75, 15,92,  1,83,  4,48,  2, 7, 11,99, 13,43, 17,94, 18, 6, 14,34, 16,48,  0,60,  6,33,  8,16, 12,34,  5,99,  9,83, 19,11,  7,80, 10,43, 
     2,97, 17,80, 10, 2,  1,37, 19,31, 12,37,  6,58,  8,11, 15,24, 14,84,  5,10,  9,30,  3,97, 18,89, 11,47, 13,37,  0,73,  4,11, 16,90,  7,54, 
    11, 1,  3,97, 19,68,  1, 8, 15, 7, 14,72,  8,38,  6,50,  4,42, 16,32,  0,54,  5,94, 13,31, 10,52, 17,76,  2,20, 18,29, 12,56,  7,36,  9,16, 
     2,29, 17,31,  9,49, 10,91,  3, 7,  5,37,  1,86,  0,75, 16,21, 14,46, 15,47, 12, 1, 11,16,  8,29, 18,47,  4,81, 13,52, 19,44,  6,95,  7,79
  };
  // Taillard 20x20 instance 3
  const int tai_20_20_3[] = {
    20, 20, // Number of jobs and machines
     1,30, 18,80,  4,34, 15,92, 16,29, 19,96,  0,25, 10,49,  5,67, 14,53, 13,20,  7,52,  8,29,  6,51,  2,35, 11,38,  3,18,  9,43, 12,46, 17,98, 
     4,73,  2,68,  3, 3, 14,98,  1,68,  0, 8, 13,15, 17,88, 18,72, 16,20,  5,89, 10,59,  9,68, 15,63, 19,41, 11,30,  8,43,  6,80,  7,64, 12,14, 
     1, 6, 16,36,  8,88, 18,71, 13,51, 14,63,  6,32,  0,16,  9,63, 15, 7, 19,18,  3,90, 12,55,  5,25,  4,72, 11,92, 10,88,  7,69,  2,89, 17,83, 
    19,58,  3,35,  4,79,  9,43,  1,86,  2,50, 18,64,  8,88,  6,57, 16,25, 13,73, 14,18, 12, 4,  5,69,  7,40, 11,28, 15,37, 10,42, 17,82,  0,83, 
    15, 2, 12,41,  1,13, 10,75,  0,31, 19,66, 11,72, 13,66,  2,96, 14,45, 17,29,  6,49, 16,96,  3,50,  7,38,  4,80,  8,90,  9,36, 18,50,  5,76, 
     3,15,  7,31,  9,89,  0,87,  5,55,  6,49, 14,23, 16,19,  4,38,  2,93, 19,75, 12,45, 13,75, 18,72,  1,65, 11, 6, 17,16, 10,24,  8,24, 15,44, 
    17, 4,  3,22, 11,99,  9,10,  4,85, 13,79, 16, 2,  8,54,  0,80, 18, 2,  1,58, 19,33, 10,92,  5,93,  6,94, 15,34, 14,36, 12,48,  7,54,  2,12, 
    17,19, 13, 2, 16, 7,  4,60, 11,36,  7,11, 12,97,  6,57,  8,71, 10,60,  2,20, 18,68,  0,53,  9,54, 15,59,  1,16,  3,60,  5,68, 14,65, 19,42, 
     0,57, 11,16,  1,92, 18,99,  2,82, 13,91,  9,12,  7,19,  8,59, 15,43, 16,20, 12,84, 14,24, 10,80,  6,60, 17,82,  3,62,  5,32,  4,29, 19,20, 
     9,76,  3,78,  6,78, 12,42,  0, 3, 13,30,  2, 7,  1,82, 17,62, 16,13, 18,84, 19,22,  4,78, 11,80, 14,58,  7,53, 15, 6,  5,85,  8,23, 10,99, 
    12,83, 10, 9, 16,72,  9,88, 18,84,  7,87,  8,78,  0,65,  6,23,  3, 7, 15,35,  1,94,  5,33,  4,10, 17, 6, 14,85, 13,88, 19,18, 11,94,  2,92, 
     6,28, 18,33,  8,93,  4,11,  7,25, 17,67,  0,44, 14,28, 11,69, 19,67,  3, 9, 10,82,  9,43, 16,53, 12,48,  5,39,  1,52, 13,75,  2,81, 15,44, 
    17,24,  4,44, 16,58, 12,73, 19,30,  1,25,  2,21, 18,14, 11, 6,  3,41, 10,19,  6,21,  5,36,  7,72,  9,96,  0,32,  8, 5, 13,46, 15,61, 14,82, 
    14,91, 11,42,  1,97,  9,65, 12,78,  7,40, 10,93, 19,64,  2, 8, 17,56, 13,10, 16,93,  8,28, 15,77,  5,87,  3,26, 18,33,  0,17,  6, 2,  4,35, 
     4,15, 10,45, 19,96, 18,11, 16,95, 11,39,  5,22, 15,73,  1,79,  7,64,  2,79, 14,88, 13,65,  3,24, 17,38,  0,17, 12, 3,  6,73,  9,59,  8,92, 
     2, 3,  3,28,  7,17, 18,71, 14,91,  6,17, 12,69,  0,69,  9,51, 13,40,  4,93, 16,82, 10,47,  5,42, 19,59, 11, 7, 17,43, 15,83,  8,45,  1,83, 
     3,67,  2, 9, 15,37,  9,62, 18,82, 11,69,  7,34, 17,39, 16,15,  8,84, 19,32, 13,72,  0,68,  6,95,  4,70, 10,80, 14,78,  1,80,  5,30, 12,44, 
     4,13, 10,96,  8,26,  1, 4, 12,89, 18,98, 17,83, 15, 8, 11,70, 19,68,  3,37, 14,20, 13,35,  7,99,  2,27,  9,12,  5,73,  6,92,  0,98, 16,75, 
    13,75, 15, 1,  5,35, 14,73,  3,35, 18, 6, 17,38, 10,34,  2,70, 19,51,  6,16, 12,78, 11,58, 16, 9,  7,97,  0,55,  4,38,  1,65,  9, 1,  8, 8, 
     3,27, 13,36, 18,50,  8,21, 11,32,  9, 6, 17,34, 12,84, 16,50,  0,39,  2, 4, 14,94, 19,49,  7,20, 10,98,  1,64, 15,41,  4,29,  6, 4,  5,90
  };
  // Taillard 20x20 instance 4
  const int tai_20_20_4[] = {
    20, 20, // Number of jobs and machines
     9,14,  6,62,  2,32, 14,81, 18,65, 13,53,  0,31,  1,98, 10,34, 19,27, 17,60, 16,43, 11,30, 15,24,  7,61,  8,40, 12, 7,  4,15,  5,50,  3,10, 
    10,12,  5,42, 17,69, 19,12,  4,84, 11,24,  9,87, 12,69,  0,45,  7,37,  8,38, 15,72,  1,54,  6,66, 13,45, 14, 4,  2,61,  3,20, 16,49, 18,17, 
     6,60,  8,45, 19,34, 10,74, 14,65,  5,75,  4,92, 17,69,  2,40, 11,26, 15,69,  0,30,  7,18,  3,88,  1,49, 13,68,  9,25, 12, 1, 16,95, 18,25, 
    11,77,  4,61, 17,42, 15,65,  8,99, 13,81,  9,84,  6,33, 16, 8, 19,21,  0,26,  7,58,  1,91, 10, 7, 18,95,  3,91,  2,91,  5,14, 12,46, 14,49, 
    11,62, 19,88, 16, 2,  0,12,  8,68,  5,99,  2,46, 10,35, 18,87, 13,53,  9,60,  3,54, 12,99, 15,59,  7,10,  4,34,  1,67, 17,31,  6,52, 14,53, 
    11,21,  9,92, 16,33,  7, 8,  6, 9, 15,51,  1,44, 19, 1, 10,69, 18,83,  8,17, 17,86,  2,51, 14,95,  4,40, 12,32, 13,84,  3,54,  0, 3,  5,31, 
     3,46, 12,87,  2,45,  7,62, 16,10, 14,19, 15, 3,  9,69, 19,51, 18,56,  1,20,  5,51,  0,41, 10,12, 11, 6,  8,45, 13,17,  6, 2, 17,93,  4,39, 
    18,10, 12,82,  0,44,  9,22,  3, 9,  7,55, 16,29,  8, 3,  4, 3, 17,77, 11,78, 10,43,  5, 9,  2,84, 14, 1, 15,11,  6,59, 19,97,  1,23, 13,83, 
     0, 3, 17,89,  8,34, 12, 4,  6,94, 15,10, 13,90,  1,16,  9,18,  5,55, 11,69,  2,39, 18,99,  3,77,  7,65,  4,55, 16,27, 10,84, 19,94, 14, 2, 
    11,85, 18,98,  5, 6,  6,74,  0,24, 10,54,  2,85,  1, 7, 15,60, 14,49,  3,92, 12,59,  4,26, 19,97, 16,87,  8,28, 13,81,  7,46, 17, 4,  9,82, 
    13,49,  7,99,  6,92, 17,55, 15,38, 10,23,  2,97, 19,42, 12,94, 11,95,  1,93, 16,31,  8,91, 14, 3,  3,30,  0,28,  5,56,  4,21,  9,51, 18,22, 
     6,51, 19,65, 12,71, 13,81,  5,56, 10,45,  9,41, 18,26, 14,52, 16,88,  7,97, 11, 3,  0,32,  2,16,  3, 1, 15,13,  4, 8, 17,50,  1,66,  8, 5, 
     6,93,  9,78, 10,90, 14,25, 12,83,  5,40, 11,83,  7,67,  2,59, 17,90, 19,91,  4,50, 15,22,  0, 9,  1,12, 13,28, 16,28,  3,40, 18,43,  8,29, 
    11,65, 19,30,  5,14,  7,33, 10,50,  9,91, 15,19,  4,50,  2,86, 14,83,  6,13, 12,49,  0,30, 13,43, 16,46, 17,67,  1, 6, 18,77,  3,87,  8,64, 
     9,92, 19,96,  5,76, 10,42,  4,39, 11,17,  0,46,  6,61,  2,17,  3,29,  7,69, 13,58,  1,69, 18,98,  8,60, 15,97, 16,76, 14,41, 17,55, 12,32, 
     7,37,  4,38,  6,77,  2, 4,  3,72, 18,31,  0,32,  5,98,  1,44,  8,65, 13,16, 17,84, 11,60, 14,88, 19,20, 16,60, 12,92, 15,91, 10,72,  9,58, 
    15,15, 12,37,  5,51,  2, 9,  8,15,  7,14, 14,73,  9,93,  4,79,  3,63, 13,21,  6,68, 16, 9, 17,51, 19,25,  1,57, 11,41, 10,51, 18,80,  0,20, 
    19,50, 13,50,  9,19,  5,81,  6, 1,  4, 6,  8,15,  3,30, 15,19, 10,36,  2,64, 12,76,  0,40,  1,32, 18,77, 16,62, 14,52, 11, 7,  7,97, 17,40, 
     7,29, 17,35,  5, 7, 12,59,  4, 1, 14,65, 13,92,  2,39, 18,56,  9,93,  1,29, 11,54,  0,41,  6,54, 16, 7, 10,85, 15,74,  8,79, 19,72,  3,79, 
     8,31, 14, 9, 11,76, 18,54, 15,44, 16,39, 19,48, 13,17, 17, 4,  1,13,  9,87,  5,24,  6,68,  0,84,  3,82,  4, 1, 10, 4,  2,60,  7,56, 12,58
  };
  // Taillard 20x20 instance 5
  const int tai_20_20_5[] = {
    20, 20, // Number of jobs and machines
    10,47,  2,61,  9, 7,  3,13,  7,52,  4,33, 18,83, 12,60,  6,57, 14, 7, 15,74,  0,93,  5,59, 17,46,  8, 7, 13,84, 19,56, 11,58, 16,45,  1, 4, 
     0,97, 14,15,  2,18, 11,73,  8,37,  6,94,  7,20, 15,69, 12,13, 18,26,  1,48, 16,71, 13,96, 19, 5, 10,42,  5,15,  4,64,  3,36, 17, 6,  9,74, 
     8,87,  7,89,  1,28, 12,81,  4,47, 18,53, 14,67,  2,78, 15,14, 10,92, 11,94, 16,26,  0,68, 17,36,  9,79,  5,71, 13,94, 19,28,  6,25,  3, 2, 
    10,99, 15,65,  0, 9,  6,52, 18,10, 16,55,  9,20,  2,67, 19,69,  5,16, 11,10, 13,54,  8,47,  7, 4,  4,66, 17,33, 12, 9,  1,53,  3,30, 14,29, 
    10,33, 18,64, 16,17,  4,81,  5,42,  9,60,  8,14,  3,95, 12,36, 14,95, 17,37,  1,85,  0,48, 11,74,  2,76, 19,68, 15,77, 13,14,  7,91,  6,69, 
     3,86, 12,16,  9,34, 11,83, 19,79, 14,89,  2,22,  1,74, 10,58, 13,71,  5,22,  8,36,  7,53, 17,80, 16,53, 18, 1,  0,57, 15,68,  4,26,  6,26, 
     2, 4,  7,83,  6,26, 19,54,  5,16,  9,88, 11,16, 16,61, 10,41,  8,54,  1,98, 18, 3,  4,84,  0,11, 13,55,  3,18, 15,67, 14,62, 12,17, 17,31, 
    12,16,  7,99, 18,46, 19,40,  5,54, 10,27,  8,71, 14,95, 11, 9, 17,46,  0,57,  9,86, 15, 7,  6,16,  1,70,  4,15,  3,71,  2,41, 16,83, 13,14, 
     8,30, 12,24,  7,95,  4,41,  5,53, 10,84,  3,55,  9,54,  0,42,  2,75, 13,55, 11,57,  1,62, 19,23, 14,28, 16, 3, 17,83, 15,88, 18,11,  6,68, 
    17,78, 14,63,  5,21, 10,64, 13,91, 11,75,  9,53,  4,35,  2,77,  7,29,  0,68,  3,92,  6,89,  8,49, 18,47,  1,33, 15, 4, 16,58, 19,18, 12,33, 
     2,25, 17,86,  9,55, 14,68,  1,56,  7,43, 15,23,  3,15,  4,88,  6,28,  5,41,  0,87, 18,75, 11,77, 10,49, 12,52, 16,80,  8,25, 19,94, 13,55, 
    19,40, 10,29,  9,27,  4,70,  1,76,  7,19, 18,67,  2, 9, 15,10, 11, 8,  3,83,  8,49, 13,70, 16,62,  6,70, 12,38, 17,68,  5,46, 14,77,  0, 9, 
     0,72, 16,82,  1,78, 12,12, 17,98, 13,98,  8,46, 19,79,  4,88,  3,11,  7,36,  9,67, 18,97, 15,22, 10,53,  6,21,  2,22, 11,17,  5,43, 14,60, 
     7,60, 12,77, 13,32,  8,51, 17,31,  9,65, 16,18, 10, 3,  6,31,  3,12, 14,35,  4,54, 11,44, 19,10,  5,43,  1,77, 18,40, 15,98,  0,69,  2,33, 
     5,72, 10,42,  1,20,  4, 2,  2,50,  6,67, 14,81,  7,95, 11,39, 18,45,  9,82, 13,50, 15,89,  3,77,  0,63, 19,44, 17,42, 16,40, 12,86,  8,84, 
     4,62, 13, 6, 18,46,  3,40, 19,75, 10,89, 14,11,  2,13, 12,89,  1,71,  7,69, 11,86,  5,60,  8,92, 15,56,  6,88,  9,80,  0,18, 16,75, 17,66, 
     8,51, 15,16, 16,60, 19,38,  5,43,  6,94, 12, 3,  2,53, 10,80, 14,96,  0,70,  3,66,  9,83, 13,82,  1,83,  4,70, 11,22, 17,94, 18,46,  7,57, 
     5, 6, 19,28, 11,71, 12, 9,  6,27,  3,88,  4,90,  8,72,  1,43, 17,16, 18,36,  2,44, 13,41, 14,37, 15,80, 16,84, 10,86,  7,91,  0,24,  9, 3, 
     7,43,  1,27, 10,46, 18,67, 14,89, 16,10,  5,63, 13,33,  4,14, 19,95,  2,61,  6,66,  0,68, 12,46, 11,27, 15, 5,  3,17, 17,64,  8,10,  9,74, 
     0,83,  9,35, 16,39,  4,97,  2,99,  7,77, 15,98, 13,88,  1,51,  6,31, 19,88,  3,24, 10,34,  8,44, 11,29,  5,37, 18,23, 12,15, 17,50, 14,56
  };
  // Taillard 20x20 instance 6
  const int tai_20_20_6[] = {
    20, 20, // Number of jobs and machines
     7,86, 13,43, 17,61,  6,99,  8, 7, 11,70,  4,21,  3, 2, 12,88, 18,38,  9,65,  2,81,  0,38,  1,51, 10,81, 16,37, 15,72, 14,94,  5,44, 19,99, 
     7,80, 17,66, 16,90, 10,83,  0,89, 15, 7, 12,55,  1,17,  2,13,  9,45, 18,28,  5,73,  3,44,  6,65, 19,50, 14,84,  4,70, 11,71,  8,32, 13,91, 
    11,90, 17,43, 19,37,  0,71,  2,64,  4,88,  8,27, 14,30, 10,34,  3,99,  5,10, 12,44, 18,99, 15,94,  1,96, 16,98,  6,44,  7, 7,  9,33, 13,59, 
     2,34,  7,52, 17, 5, 12, 4,  1,84, 16,54, 13, 3,  6,97, 19,39,  3, 9, 18, 9, 11,91,  5,60,  0, 4,  4,63, 14, 3,  8,35, 10,79, 15,66,  9,97, 
     3,52,  5,51, 12,72,  0,24, 10,96, 17,54, 16,51,  2,61,  7,92,  8,81,  9,74, 18,49, 19,24,  4,59, 13, 4, 11,21,  1,78,  6, 2, 15, 3, 14,49, 
     9,42, 13,47,  6,10,  0,27,  7,38, 18,92, 12,88, 17,16, 19, 3, 10,56,  3,80,  4,10, 16,26,  1,78, 15,69,  8,91,  2,82, 11,77, 14,73,  5,96, 
     7,19,  3,38,  5,83, 17,50, 14,31, 19,87,  8,67,  9,99, 13,69, 11,77,  1, 4, 12,31, 16,96,  0,77,  2,80, 18,68, 15,74,  4,86, 10,30,  6,54, 
    15,25, 16,47, 12,10,  5,16,  4,83,  9,62, 18, 3,  3,38,  8,87, 19,19, 17,98,  6, 2, 13,58, 11,30,  0,22,  7,55, 14,80, 10,69,  1,77,  2,40, 
     2,17,  5,98,  6,25, 19,41,  4,62, 18,28,  1,52,  0, 5,  8,25,  9,37,  7,93, 12,63, 13,23, 14,58, 17,92, 15,70, 16,90,  3,29, 10,26, 11,69, 
    19,41,  0,65, 17,34, 14, 4,  7,73, 11,79,  8,58,  6,14, 12,97,  4,71, 10,97,  2,95, 16,58, 13,12,  3,17,  9,66,  1,78, 15,68, 18,69,  5,53, 
    10,27,  4,83, 14,20,  9,12, 19,86,  6,34, 18,36,  0,28, 13,63, 12,37, 16,23,  5,50,  7,90,  8, 5, 17,17,  3,80,  1,35,  2, 4, 15,41, 11,81, 
     4,85, 18,92, 12,90, 15,95,  3,19,  8,59, 19,94,  9,75,  5,75,  6,47, 16, 9, 14, 6, 10,43,  0,30,  2,88,  1,19, 17,10, 13,76, 11,58,  7,29, 
     4,23,  5,87,  6,50,  7,76, 11,26, 10,28,  0,36, 17,35,  2, 4,  9,32, 14,22, 13,74,  1,52, 16,13,  8,14, 19,61, 15,47, 12,87,  3,73, 18,64, 
     5,80,  0,43, 17,45, 14,92,  8,68, 12,66,  2,60,  9,37, 18,60,  6,51, 19,41,  3,61, 13,98,  7,59,  4,95, 15,38, 11,67,  1,12, 10,95, 16,22, 
    10,57,  1,96, 15,11,  5,25,  8,69,  4,59,  9,45, 13,52, 14,85,  2,26, 17,91,  6,57,  3,30, 16,32, 19,58, 11,40,  7,11, 18,19,  0,19, 12,82, 
     1,81,  5,83,  2,77, 16,45, 11,63, 17,95, 14,25,  8,48,  9,27, 18,56,  4,54, 12,82, 15,32, 19,99,  7,41,  0, 1, 13, 2,  6,61, 10,23,  3,26, 
     1,47, 18, 9,  2,90, 14,28,  5,68,  8,23, 10,66,  6,46, 19,75,  4,96, 13,68,  9,60, 16,46,  7,35, 11, 9, 12,89, 15,96,  0,42,  3, 2, 17,86, 
    11,90,  3,52, 14,10,  7,25,  1,59, 13,55, 18,30,  9,33, 19,18, 12,80,  8,73, 15,41,  4, 9,  6,64, 16,79, 17,31,  2,79, 10,44,  0,14,  5,73, 
    10,59,  2,57, 17,67,  7,47,  8,13, 18,35, 13,72,  6,74,  5,56, 16,85,  0,52, 15,25,  1,92,  3,92, 12,81, 11,76,  9,91, 14,93, 19,36,  4,88, 
     8,28, 16,89,  0, 3,  2,75, 11,31, 10,87, 19,66, 17,67,  7,34, 14,19,  3,30,  4,91, 13,53, 15,81,  6,13,  5,15,  1,59,  9,17, 12,85, 18,11
  };
  // Taillard 20x20 instance 7
  const int tai_20_20_7[] = {
    20, 20, // Number of jobs and machines
    17,24,  7, 8,  9,42, 12,87,  4,95,  5,14, 14,30,  8,89,  0,69,  2,32, 18,59,  3,20, 10,26, 11,35, 16,83, 13,25, 19,48, 15,51,  1,58,  6,99, 
    18, 5, 10,34,  6,32,  3,29,  4,44, 16,79,  1,73, 14,13, 15,25, 13, 8, 11,37, 19, 6, 17, 1,  8,31,  0,97,  9, 7,  2,47,  5,91, 12,74,  7,38, 
    13,67, 16,68,  8,44,  7,31,  4,90,  3,29, 15,21, 19,37, 18,82, 17,27,  5,33,  1, 1, 10,73, 14,35, 12,83, 11,79,  6,79,  9,92,  2,44,  0,78, 
    13,13, 18,85,  4,76,  6,84,  5,77, 14,20,  9,63, 19, 1,  1, 5,  3, 5, 10,50,  7,11, 12, 8,  2,14, 15,34, 11,20,  8,58, 17,32, 16,56,  0,74, 
    17,71, 10,12,  8,79, 12,78,  3,26, 14,38, 16,72, 15,83,  2,51,  0, 9,  7,45,  5,13, 13,31, 19,91, 11,40, 18, 5,  6,91,  4,24,  9,96,  1,72, 
     5,83,  0,98, 19,83, 17,22,  8, 8,  7,28, 12,93,  6, 5,  1,82,  3,65, 13,77, 16,56, 15,66,  2,61, 14,82, 10, 9,  9,82, 11,35, 18,83,  4,51, 
    17,38, 14,78,  6,91,  8,21, 18,88,  2,93, 16,15, 12,10,  5,68,  0,75,  4,53, 15,35,  7,11, 10,68,  3,98, 19,56,  1,37, 11,57,  9,15, 13,83, 
    11, 3,  1,98, 15,19, 16,67,  2,33, 13,78,  9,59, 14, 2,  0,32,  6,78, 18,97, 10,77,  7,72,  5,34,  4,45, 17,26,  3,79, 19,28, 12,88,  8,19, 
    17,46, 10,28,  7,99,  2,95, 16,17, 13,84, 11,68,  0,26,  8,32,  4,85, 19,98,  3,59,  1,67, 12,44,  5,80, 18,70,  9,95, 14,70,  6, 9, 15,49, 
    18,27, 15,17, 14, 6, 12,62,  9,90, 19,17, 10,58, 16,94,  7,11, 17,65,  6,96, 11,76,  0,58,  2,60,  4,51,  8,51, 13,98,  5,26,  3,92,  1,66, 
     1,92,  0, 9,  9,71,  6,66, 19,57, 17,56, 11, 8, 18,80, 15,11, 16,78, 14,50,  8,37,  7,92, 13, 5,  3,13, 10,63, 12,21,  4, 6,  5, 2,  2,27, 
    15,70,  2,55, 10,13, 19,50,  9,23,  3,75, 17,24, 16,69, 13,72, 11,53,  4,94,  6,25,  1,21,  7,57, 14,16, 12,17,  5,70, 18,34,  0,42,  8, 6, 
     6,94,  1,80, 19,74, 14,71, 17, 8, 11,51, 10,87,  3,86, 13,37,  2,93, 12,82, 15, 1,  4,76, 16,49,  8,35, 18,44,  5,50,  0,75,  9,63,  7, 4, 
     2,19, 10,40,  1,30, 19,92,  5,10, 12,60,  8,32, 14,71, 17,73, 13,61, 11,31,  4,94, 16,61, 18,85, 15,91,  0,98,  6,35,  7,55,  9,84,  3,93, 
    14,68,  0,13,  8,30,  3,83,  9,46, 10, 8,  2,41, 17,83,  4,33,  6,19, 19,75,  1,37, 16,17,  5,29, 12, 5, 13,62, 15,96,  7, 7, 18,73, 11,39, 
     8,49, 12,19, 13,10, 10,67,  7, 6,  0,42,  4,87, 16,83,  5, 7, 15,51, 18,55,  3,79,  9,24,  2, 2, 11,88, 19,80, 14,37,  6,58,  1,20, 17,45, 
     8,89, 12,33, 19,27, 11,20, 10, 2,  4,26,  2,88,  7,24,  9,62,  6,68,  0,59, 15,53, 13, 7,  1,85, 16,66, 14,14,  5,22,  3,15, 17, 8, 18,58, 
     9,88,  6,88, 16,91,  4,72,  3, 9,  2,41, 14,76,  8,24, 12,77,  7,60, 17,93, 15,39, 19,93, 18,71,  1,13,  0,73,  5,44, 10,15, 13,19, 11,95, 
     9,93, 18,34, 12,36, 10,82, 14,28, 16,52,  1,22, 17,33,  4,77,  7,27,  0,62,  8,59,  2,52, 15, 1, 19,39,  6,85,  5,62,  3,34, 11,77, 13,74, 
     6,15,  2,38, 17,83,  9,32, 19,12, 11,41, 14,81,  7,79,  4,90,  3,12,  8,18, 12,37, 18, 1, 15,91, 16,73,  0, 5,  5,82,  1,64, 10,37, 13,91
  };
  // Taillard 20x20 instance 8
  const int tai_20_20_8[] = {
    20, 20, // Number of jobs and machines
    10,84,  9,45, 16,53, 18,48, 17, 9,  5, 9, 14,39,  2,79, 13,83, 19,50, 12,24,  3,49,  8,81,  4, 5,  1,70, 15,89,  0,91,  6,25, 11,80,  7,36, 
     4,75, 19,48,  5, 6,  6,32,  2,68,  7,23, 16,44, 12,21,  9,42, 11,13,  8,74, 13,31, 14,62,  3,91,  1,65, 15,66, 18,26, 17,96,  0,97, 10,51, 
    10,49,  3,26, 14,35,  0,64, 16,55,  1,78,  2,72,  5,83,  7,59, 15,16, 17,92, 13,68, 19,64,  4, 4, 11,76, 12,82,  9,70, 18,75,  8,65,  6,31, 
     1,55,  8,58, 17,37, 11,32,  0,31, 10,65, 12,65,  5,85, 13,50,  4,94,  6,37,  3,20, 15,94,  7,20, 16,31, 14,30,  9,49,  2, 8, 19,22, 18,47, 
    13,81, 16,68, 18, 2, 10,69, 15,38,  4, 7, 14,81,  5,79, 19,76,  2,94, 17,65,  0,11,  6,98,  7,38,  3,95,  1,93,  9, 9, 12,21, 11,17,  8,79, 
     5,64,  7, 7, 15,94, 19,29, 17,77,  4,75, 12,50,  2,78,  3,57, 18,29,  8,66, 13,93,  0,74,  9,73, 14,80, 10, 8, 11,26,  6,87,  1,69, 16,85, 
    10,49,  3,59, 12,91,  8,59,  9,25, 16,44, 19,50,  6,41, 13,33, 11,89, 17,79,  0, 3, 14,54, 18,82,  1,63,  4,31, 15,15,  5, 2,  7,67,  2,71, 
     4, 4, 14,20, 18,23,  3,33, 16,65,  7,44,  9,57, 10,20, 17,93, 11,23, 15,18,  0, 8,  5,72,  6,54, 19,18, 13,93, 12,43,  1,18,  8,56,  2,21, 
     8,58,  4,25,  7,34,  5,89,  9,54, 19,89,  3,12,  0,51, 13,74, 14,78, 11, 4, 17,72, 16,81, 10,92,  1,69,  2,35, 12,25,  6,35, 18,10, 15,33, 
    11,33, 19,84, 12,75,  4,66, 18,49,  6,77,  8,87, 13,44, 15,37,  2,67,  0,33,  1,75,  3,65, 17,44, 16,66, 10,45,  5,93,  9,98,  7,22, 14,67, 
     0,17, 17,26,  1,54, 18,25, 13,92, 12,34,  6,47,  7,80,  2,24,  5,92, 15,75, 10,68, 11,84,  9,72, 19,84, 16,94,  4,69, 14,96,  3,34,  8,29, 
     0,66, 10,79,  5,74,  8,67,  2,72,  1,22, 15,50,  7,30, 18,47,  3,75, 12,43, 13,44,  9,71, 17,61, 19,54, 11,99, 16,11,  6,97, 14,75,  4,81, 
    16,35, 13,75,  4,99, 19,72, 18,92,  6,90, 10,26,  5,91,  9,70, 17,82,  1,13, 12,45, 14,82,  8,58, 15,38, 11,19,  3,66,  0,23,  7,49,  2,19, 
    17,82, 13,74,  4,40, 12,33,  7, 9,  0,33, 11,26,  3,44,  2,18,  8,73, 16,41, 18,96,  1,39,  6,91, 14,89, 15,11, 10, 1, 19, 2,  5,69,  9,10, 
    12,25, 10,32, 16,41,  5,14,  9,67,  0,25,  6,94, 18,89,  1,21,  2,98, 15,92, 11,72, 14,57,  3, 4,  8, 1,  7, 2, 13,84, 19,91, 17,42,  4,85, 
     7,29,  1,98,  4,41, 13,87, 16,52, 12, 9,  9,22,  3, 2, 14,79, 18,73,  0,16, 10,22,  5,97, 17,13,  8,19,  2,13, 19,50,  6,43, 15,91, 11,34, 
    14,91,  8,41, 18,47, 17,61, 15,66, 19,31,  3,92, 12,42, 16,19,  0,98,  2,36,  1,29, 13, 8,  5,25, 10, 5, 11,90,  9,62,  7,63,  6,17,  4,23, 
     8,69,  9,78, 15,61,  7,52,  5,40,  1,71,  0,40, 18,61, 14,93,  2,37,  6,32, 12,48, 17, 7,  4,37, 10,69, 19, 4, 11,79, 13,81, 16,10,  3,75, 
    16,90,  4,16, 15,68, 14,32,  8,96,  7, 7, 18,42, 19,52, 12,38,  5,68,  6,72,  9,78,  1,10,  2,61, 13,40,  3,31,  0,81, 11,69, 17,84, 10,27, 
     4,91,  8,17,  2,75, 14, 7, 15,44,  6,10, 13,32, 17,78, 12, 9,  9,69,  7,45,  5,87,  3,90,  1,50,  0,42, 11, 2, 19,21, 10,62, 18,93, 16,88
  };
  // Taillard 20x20 instance 9
  const int tai_20_20_9[] = {
    20, 20, // Number of jobs and machines
    18,84, 15, 9,  6,34,  8,62, 14,11, 12,60, 19,43, 11,52,  7,77,  4,37,  9,15, 16,43, 10, 8, 13, 5,  3,36,  5,56,  2,46,  0,51,  1,86, 17,86, 
    18,61, 13,56,  8,60,  3,78,  1,73, 19,12, 14, 8, 16,16,  0,12,  2,63,  9,31, 10,62, 11,97,  4,53,  5, 1, 12, 3,  6,99,  7,65, 15,63, 17,32, 
    10,86,  7,53,  4,59, 17,12, 14,34,  0,27,  8, 2,  1,86, 16,85,  5,21,  3,58, 13,70,  2,55, 15,77,  6,15, 18,20, 19,32, 12,42, 11,17,  9,38, 
     2, 3, 19,13,  5,67, 16,13, 11,63, 15,88, 13,68,  4,21,  0,21,  8,86, 17, 7,  6,91, 18, 8, 10,56,  9,92,  3,58,  1,94,  7,54, 12,57, 14,87, 
    12,29, 15,74,  2,89,  3,18, 11,38,  7,75, 10,18, 17,15,  9,95, 16,11,  0,24, 13, 4,  4,12, 14,17,  1,34, 19,35,  8,62,  6,90,  5,48, 18,21, 
     6,11, 12,14, 13,90,  8,74, 14,67,  0,91,  5,70, 11, 8,  7, 7,  2,49, 19,13,  3,78,  1,75, 18,80,  4,31, 15,22, 10,99, 16,66,  9,80, 17,66, 
    11,97, 15,63, 17,11,  7,71, 18, 1,  9,63, 12,70,  4,33, 16,74,  1,76,  2,86, 10,87,  8, 9,  5,18,  0,51,  3,27, 14,48,  6,31, 13,45, 19,76, 
    18,19, 17,64,  0,94,  7, 4,  4,81, 12, 5,  1,72, 10,30,  2, 2, 15,16, 13,38, 14,93, 19,15,  5,17,  6,61,  3,71,  9,18,  8,22, 11,17, 16,20, 
    15,61, 11,66, 12,62,  7,70,  1,59,  0,80, 14,82,  9, 2, 18,97,  8,76, 13,72,  5,90, 16,74,  3,95, 19,41,  4, 9, 10,46,  6,20, 17,78,  2,32, 
     7,61, 18,90,  4,37, 19,86, 12,15,  9,19, 13,62,  5,82,  2,86, 15,59, 10,92, 14,89,  0,82, 16,48,  1,13,  6,29,  8,28, 17,45, 11,84,  3,62, 
    17, 7, 13,86, 18,79, 14,67, 19,85,  1,68,  6,94, 11,61, 12,47,  4,49, 15,50,  0,55, 16, 3,  3,18, 10,79,  8,32,  2,43,  9,97,  7,53,  5,44, 
    10,20, 14,50, 12,72,  9,90,  2,25,  0,24, 19,43,  5, 4,  4,26, 13,62,  7,42, 11,77,  3, 9, 15,61, 18,19, 16,69,  1, 9,  6,60, 17, 5,  8,54, 
     7,45, 19,73,  1,50, 10,58, 11,94, 14,90,  8,97,  9,42,  4,36,  5,72, 12,84, 15,33, 17,44, 13,59,  3,47,  6,40,  2,81, 18,85,  0,26, 16,28, 
    17,67, 11,46, 13, 9,  1,40,  2,81,  4,97,  7, 7,  0, 2, 10,69,  8, 9,  3,17, 19,81, 14,81,  6,46,  9,26,  5,30, 18,88, 16,73, 12,44, 15,99, 
    11,16,  3,62,  5, 3, 19,30, 10,16,  1,40, 17,62,  7,96,  6,75, 13,69,  2,86, 18,90,  0,93, 15,15, 12,30,  8,46, 14,50, 16,29,  9, 9,  4,97, 
    12, 5,  8,73, 16,54,  0,81, 18,26, 13,36,  7,35, 19,56,  4,62,  9,31, 17, 2,  5,23, 11,60, 14,12, 10,88,  3,38,  6,95, 15,65,  1,86,  2,64, 
     9, 3,  5,99, 19,81,  7,93, 11,82, 12,17, 16, 1, 14, 1, 13,32,  0,36,  8,30,  4,62, 10,90, 18,20,  1,98,  6, 3,  3,66, 17,75, 15,79,  2,67, 
    19,52,  4,76,  6,79,  1,63, 14,52,  2,23,  0,35, 18,22,  7,58, 10,13,  3,26, 12,68, 15,84,  9,16, 13,28,  5,28,  8,54, 17,76, 16,86, 11,47, 
    19,74,  3,34, 15,68,  4,37,  7,26, 12,48, 13,29, 16,24, 18,60, 14,98, 17,54,  5,97,  8,19,  0,99,  2,62, 11,46,  6,25, 10,53,  9,11,  1, 4, 
    11,15, 17,92, 13,41,  4,63,  3,87, 15,67, 18,77, 12,89,  0,65, 10,17,  5,24, 19,67,  9,10,  2,87,  7,91, 14,58,  6,52,  8,26,  1,33, 16, 3
  };
  // Taillard 30x15 instance 0
  const int tai_30_15_0[] = {
    30, 15, // Number of jobs and machines
     3,99, 10,43, 14, 6,  1,99,  5,23,  8,98,  4,84, 11,24, 13,30, 12,53,  2,34,  9,95,  7,50,  0,48,  6,38, 
     6,19,  4,24,  2,65,  3,16, 14,94,  5, 9,  7,60, 13,32,  9,59,  0,85, 11, 9, 12,36,  8,22, 10,25,  1, 5, 
     4,54,  2,62, 10,93,  5,78, 12,59, 13,71,  3,49, 11,88,  9,40,  7,13,  8,17,  6,88, 14,47,  1,30,  0,56, 
     0,60, 13,16,  4,79,  1,84, 14,84,  9,42, 12,59,  3,14,  8,74,  5,60,  2,98,  6,17, 10,42,  7,31, 11,19, 
     6,49,  1,52, 10,46,  4,50,  8, 1,  5,14,  2, 2,  9,56,  7,64,  0,51, 13,75, 11,28,  3, 9, 14,37, 12, 6, 
     5,59,  6,65, 12,85,  3,40,  0,23,  4,39,  2,99,  8,46,  1,17, 13,94, 11, 6,  9,67, 14,69,  7,86, 10, 8, 
    11,10, 13, 7,  1,22,  6,36,  4,31, 12,75, 14,57,  0,49, 10,44,  8,21,  5,77,  7,70,  2,64,  9,46,  3,69, 
     5,53,  2,74,  1,93,  4,26,  9,54, 13,89,  8,82, 10,66, 11,37,  3,63,  7,71,  0,17,  6,58, 12, 4, 14,46, 
     7,76, 13,72, 12,42,  5,17, 10,27,  9,56,  0,78, 11, 5,  8,72,  4,19,  2,90,  1,46, 14,43,  6,56,  3,17, 
     6,18,  7,79, 14,93,  1,71,  9,48, 11,23,  3,20,  5,90, 10,94,  2,87,  8, 6,  0,36, 13,84, 12,25,  4,83, 
    10,52,  0,61,  3,45,  4,60,  5,15, 11,74,  7,49, 12,26, 13,94, 14,54,  8, 1,  1,58,  6,56,  2,54,  9,72, 
     5,63,  0,73,  9,82, 11,84, 12,15,  6,54, 10,52, 14,52,  8,36,  4,21,  7,45,  3,41, 13,21,  1,97,  2,50, 
     8,90,  0,90,  7,77,  4,33,  3,31,  1,26, 13,14,  5,75,  6,92, 12,70, 11,55,  9,56,  2,39, 14,49, 10,23, 
     4,87,  9,47, 13,58, 12,34,  6,29,  2,83,  7,24,  1,48, 11,97, 10,89,  8,84, 14,82,  0,53,  5,99,  3,10, 
     7,35, 14,32, 11,30,  2,93, 10,58, 12,28,  1,88,  3,16, 13,98,  9, 4,  4,82,  8,98,  5,26,  0,29,  6,77, 
    13,18, 12,92,  4,62, 11,59,  1, 3,  0,94, 10,34,  6,56,  5,24,  9,18,  2,66,  7,53,  3,30, 14,41,  8,10, 
     0, 2,  7,26, 12,17, 14,18,  3,60,  2,39,  8,23, 11,95, 13,81,  9,56,  4,34,  1, 8,  5,47,  6,72, 10,56, 
     5, 6,  6,79,  7,65,  4,58, 12,94,  9,45, 11,80,  3, 3, 10,29,  8,80,  1,27,  0,60,  2,94, 14,14, 13,76, 
    12,31,  4,79,  3,87, 13,79, 11,57,  6,48,  5,33,  0,42, 10,93,  1,86,  2,54,  9,32,  7, 8,  8,16, 14,63, 
     0,96,  7, 1,  3,75, 11,42, 10,45,  1,51,  8,10, 12,58,  5,71,  6,92,  2,23, 14,18,  9,63, 13,27,  4,63, 
    14,84,  5,82,  7,16,  1,61, 10,43,  6,75,  9,28,  3,15, 12,19,  0,93, 11,22, 13, 1,  4,62,  2, 9,  8, 5, 
    12,46, 11,29,  6,50,  8,12, 13,72, 10,18,  1,79,  7,73, 14,23,  9, 1,  4,58,  3, 1,  2,95,  0,25,  5,71, 
     8,10,  9,39, 11,49,  3,56,  4,71, 13,40, 10,90,  2,28,  0,89, 12,42,  5, 9,  6,92,  7,52,  1, 6, 14,20, 
    12,70,  8,63,  6,68,  9,97, 11,86,  5,81,  2,38,  7, 7, 14,53,  0,48,  4,43,  1,59,  3,88, 13,29, 10,87, 
    14,81, 11,97,  8,65,  4,60, 10,15,  5,29,  3, 9,  2,80,  6,78,  9,85, 12,95, 13,85,  0,91,  1,28,  7,92, 
     7,39, 14, 6,  4,59,  0,34, 12,34, 10,32,  8,12,  5, 7,  3,35,  1, 4,  6,53,  9,69,  2,89, 11, 3, 13,40, 
    11,98, 12,85,  4,51, 14, 9, 13,24,  1, 7,  5,59,  8,98,  0,50,  7,98, 10,64,  9,31,  2,31,  6,29,  3, 1, 
    14,59,  8,68,  7, 3,  1, 8,  0, 2,  6, 9,  9,69, 12,14,  5,72, 10,84,  4,69, 13,54, 11,45,  2,59,  3, 7, 
     8,92,  7,21, 10,53, 14,64,  5,59, 12,79,  9,52,  2,14, 11,61,  1,86,  3,82,  0,98, 13,83,  6,24,  4,87, 
     2,51, 12,70, 13,94,  3,80,  0,35, 14,56,  6, 8,  5,94, 10,11, 11, 3,  8,60,  9,73,  1,26,  7,21,  4,45
  };
  // Taillard 30x15 instance 1
  const int tai_30_15_1[] = {
    30, 15, // Number of jobs and machines
    13,79,  0,31, 10,42,  2,88, 12,16,  8,99,  5,82,  6,53,  4,29, 14,49,  1, 9, 11,15,  9,92,  3,73,  7,98, 
     7,76,  3,89,  0,48, 12,15, 13,54, 14,37,  8,53,  1,63, 10,44,  4,91, 11,13,  2,73,  6,42,  9,99,  5,41, 
    12,49, 14,52, 10,25,  1,89, 13, 3,  5, 2,  3,40, 11,44,  6,94,  2, 7,  4,68,  7,73,  8,73,  0,30,  9,14, 
    14,28, 13,49,  1,13, 12,87,  7,62,  0,10,  4,29,  5,62,  3,34,  2, 7,  6,47,  8,40, 11,57, 10,80,  9,86, 
     7,39,  5,12,  1,34,  3,91,  8,48, 12,71,  2,45, 13,98,  0,23,  4,91,  6,90, 10,41, 11,90, 14,54,  9,87, 
    11,30,  5,63,  4,57, 14,36, 10,72,  3,54,  0,69,  9, 9,  7,53, 12,72,  6,68,  2,33, 13,61,  8,12,  1,89, 
     5,65,  8,40, 12,34,  9,37,  3,64,  2,62, 14,14,  4,78,  1, 1, 13,65,  7, 2,  0,67, 11,56,  6,75, 10,26, 
     7,22, 14,98,  5,67,  9,56,  3,41,  1,89,  4,25, 10,94, 12,76,  2,37,  6, 8, 13,84, 11,73,  0,65,  8,74, 
    10,44, 14,33,  6,41,  5,52, 13,86, 12,11,  3,60,  8,87,  0,13,  7,40,  2,62,  9,47,  4,39, 11,65,  1,77, 
     6,88,  5,31,  4,63,  3,49, 12,50, 14,77,  7, 6,  9,80,  1,20, 13,30, 11,11,  8,41,  2,43,  0,74, 10,73, 
     5, 7,  1,69,  0,69, 11,53, 13,52,  6,33, 12,19,  7,84,  2,12,  9,36,  3,85,  4,74, 10, 2,  8,97, 14,52, 
    12,33, 13, 8,  0,74,  3,75,  2,51,  5,64, 10,55, 11, 7,  4,81,  1,82,  7,70, 14,33,  9,84,  6,37,  8,48, 
    11,54,  0,97,  9,79, 12,71,  7,70,  2,84, 13,28,  8,14,  5,20,  4,99,  3, 6,  1,30, 14,51,  6,68, 10,41, 
     5,10,  8,90, 13,14, 10,72, 14,30,  7,77,  9,69,  0,56, 12,78,  2,55,  6,98,  4,91, 11,27,  3,36,  1,86, 
     9,92,  3,97, 10,71,  5,13,  2,93,  6,65,  7,44, 11,46,  4,71,  1,69, 12,26, 13,18, 14,31,  8,10,  0,47, 
     1,47,  7, 5,  2,14,  5,47,  6,81,  9,84, 10,62,  8,91, 14, 5, 11,58,  4,77, 12,55,  0,49,  3, 5, 13, 5, 
    13,46, 11,96,  5,61,  2,67,  0, 2,  6, 9,  8,94,  9,38, 10,66,  4,25,  7,67,  1,57, 12,79, 14,74,  3,47, 
     9,74,  8,52,  1,50, 10,43,  3,93,  2,30,  6,85, 11,75,  0,58,  7,47,  5,70, 12,42, 13,62, 14,58,  4,81, 
     5, 5, 12,42,  3,63,  0,42, 13,28, 10,40,  7,36,  9,49,  6,65, 14, 6,  1,14,  4,20,  2,85,  8,41, 11,70, 
     5, 7, 10,36, 11,54,  7,91,  4,98,  6,31,  9,33,  0,72,  8,21, 12,61,  2, 1,  3,30,  1,85, 13,79, 14,32, 
    10,79, 14,82,  3,49,  1,51, 11,43, 13,16,  9,44, 12,62,  6,20,  8,12,  0, 7,  5, 1,  2,64,  7,21,  4,37, 
    14,94, 12,75,  8,56, 13,25,  6,89,  9,72,  5,84,  2,71,  7,74, 10,83,  3, 6,  1,69,  4,87, 11,19,  0,68, 
    11, 7,  8,29,  7,15,  6, 3,  0,62,  9,53, 13,92, 10, 1, 12,27,  5,21,  2,66, 14,92,  1,19,  4,22,  3,48, 
     1,75,  9,12, 12,46,  7,37,  5,72,  8,35, 13, 6,  2,32,  3,50, 14,33,  6,14,  0,34, 10,93, 11,83,  4,11, 
     2,87,  5,56, 13,70,  0,81,  9,80,  3,58,  8,75,  1,48, 12,55, 14,92,  6, 9,  4,16, 10,41, 11,71,  7,63, 
     1,29,  8,66,  7,18, 14,55, 10,53,  3,81,  5,47,  6,86,  4,33, 12,30, 13,75, 11,73,  0,27,  2,51,  9,67, 
     2,60, 14,17,  3,18, 13,61, 10,82,  5,72, 12, 5,  7,92,  1,75,  8,91,  0,89, 11,35,  4,53,  6,68,  9,85, 
    14,82,  4,54,  3,96,  2,19,  9,20,  0,67,  8,27,  6,77,  7,59, 11,87,  1,40, 13, 7, 12,46,  5,32, 10,84, 
     9,69, 12,52,  5,26,  4,65,  2,89,  3,51,  0,79, 13,51,  8,27,  7,91,  6,23, 10,59,  1,99, 11,51, 14,70, 
    11,62,  6,57,  7,30,  8, 5,  5,30, 14,13, 13,39,  3,31, 10,16,  1,68, 12,32,  0,83,  2, 4,  9,27,  4,27
  };
  // Taillard 30x15 instance 2
  const int tai_30_15_2[] = {
    30, 15, // Number of jobs and machines
    10,36, 11,32,  9,40,  8,47,  1,87,  7,55,  6,77,  2,27,  5,89, 13,72,  4,93, 14,15,  0,98, 12,95,  3,32, 
    12, 7,  8,42, 14,84,  3,76,  1,44,  7,66, 13,47,  6,72, 10,24,  5,68,  4, 5,  2,35,  9,13, 11,55,  0,73, 
    12,59,  0, 7,  3,85, 13,57, 14,98, 10,71,  2,61,  6,98,  9, 3,  1,61, 11,12,  4,44,  5, 7,  7,28,  8, 3, 
    14,16,  3, 3,  7,97,  2,27,  6,97,  5,93, 10,19,  8, 9, 11,70,  1,19,  0,92,  9,27, 13,76, 12, 1,  4, 4, 
     6,71,  5,53,  7,36,  4,63,  9,16,  3,35, 13,27, 10,36,  1,79,  0,92, 14,23, 11,60,  8,49, 12,52,  2,19, 
     7,48, 11,88, 12,68,  9, 6,  8,63,  2,25,  3,28,  5,67,  4,62,  1,53, 10,51,  0,65,  6,97, 13,15, 14,79, 
    11,49, 12,65,  1,26,  7,72, 14,60,  6,15,  3,70,  5,26,  8,71,  9,48, 13,79,  4,54, 10,98,  0,81,  2,43, 
     3,35,  9,28, 11,88, 14,58,  2,87, 13,18, 12, 5, 10,74,  6,43,  7,28,  0,82,  1,34,  4,28,  5,98,  8,73, 
     9,83,  2,93,  3,86, 13,62, 10,18, 14,70, 12,67,  1,66,  7,14,  0,62,  6,47,  8,51, 11,90,  4, 2,  5,98, 
     0,28,  7,94,  3, 6, 14,66,  4,79,  8,71, 13,35,  2,57,  1,69,  9,75, 12,84,  5,47,  6,21, 10,66, 11,66, 
     2,20, 12,62,  0,37,  4,71, 14,19, 10,63,  8,90, 13,79,  7,87,  3,40,  6,92,  9,15,  5, 5,  1,76, 11,45, 
     5,71,  2,59,  8,99,  6,70,  4,27, 12,54,  9,82,  1,62, 10, 7,  0, 5, 14,12,  7,90, 13,92, 11,83,  3,71, 
    14,90,  5,79,  0,48,  3,66,  7,86,  1,87,  4, 3,  8,49,  2,84, 12,98, 11,46, 13,58,  9,74, 10,11,  6,21, 
     5,56,  2,49, 14,93,  6,11, 12, 5,  4,32, 10,19,  9,96,  3, 7,  8,80, 13,96,  7,17,  1,22,  0,45, 11,84, 
     4,93,  9,18,  0,25,  6,69,  1,65, 10,40, 13,85,  3,19,  2,88, 12,78,  5,35, 11,53,  7,46,  8,73, 14,16, 
     2,36,  5,18, 12,36,  4,34,  1,64,  7,80,  6,87, 14,40,  3,39,  8,63, 13,42, 10,74,  9,34,  0,87, 11,49, 
     6,84, 10,79,  1,63,  8,15, 12,73,  2, 1, 11,58,  9,27, 14,67,  5,81,  0,18,  7,35, 13,52,  3,34,  4,95, 
     2,64,  0,48,  4,82, 10, 1,  3,11,  5,19,  7,27, 12,93, 14,42, 13,83, 11,12,  9,37,  8,55,  1,66,  6,42, 
     5,77,  6,13,  8,55,  0,15, 10,72, 11,20, 13,71, 14,45,  7,39,  2,61, 12,73,  1,93,  4,34,  9,62,  3,66, 
    13,68,  8,15, 11,97,  7,85,  9,81, 10,53,  3,49, 14,70,  4,96, 12,65,  1,72,  6,76,  2,71,  5,81,  0,77, 
     1,62,  6,84, 14,58,  3,36, 12,63, 10,69,  7,10, 13,51,  5,34,  0,27,  4,19, 11,98,  9,21,  2,16,  8,23, 
     7,60, 11,17,  0,89, 10,87,  1,52,  2,80,  5,17,  4,30,  3,82,  9,50, 14,53,  8,78,  6,69, 12,77, 13,67, 
     6,56,  7,40, 12,32, 13,37, 11,37,  3,12,  8,11,  1,36, 10,85,  9,89,  0,85,  5,32,  2,66, 14,98,  4,79, 
     4,32,  6,56,  1,22, 10,95, 12,55,  9,20, 14,46,  7, 8, 11,68,  0,49,  5,86,  3,92, 13,25,  8,24,  2,13, 
     7,53,  2, 1, 10,92,  9,65,  5,10,  3,92,  1,92, 13,48, 11,39,  8,53,  4,49, 14,26, 12,75,  6,84,  0, 2, 
     3,14,  4,67, 12,84,  0,31,  7,61, 11,63, 10,24,  2,51, 13,22,  5,33,  8,54,  6, 8, 14,38,  9, 7,  1,67, 
    11,68, 12,10,  0,55, 13,30,  6,26,  2,17,  1, 4,  9,98,  5,55,  7,45,  3,27, 10,76,  4,96, 14,65,  8,60, 
     0, 9,  9,24,  8,22, 12,40,  3,47, 14,73, 10,72,  7,70,  2,66,  1,19,  6, 3, 11,97,  4,98,  5,85, 13,51, 
     4,54,  2,19,  7,72, 11,38,  6,18,  3,84,  1,71, 10,80,  8,46,  9,25, 13,29,  0,57, 12,92, 14,41,  5,75, 
    14,16,  6,79,  2,53,  8,98, 10, 8,  4,20, 11, 2, 13,64, 12,61,  7,78,  3,91,  5,35,  1,55,  0,92,  9,78
  };
  // Taillard 30x15 instance 3
  const int tai_30_15_3[] = {
    30, 15, // Number of jobs and machines
     7, 7,  0,11, 12,34,  5,56, 11,14, 10,33,  8,95,  2,64, 13,12,  6,22,  4,87,  3,32,  1,54, 14, 5,  9,55, 
     7,57, 11,11,  6,33, 10,56,  3, 9,  1,71,  4,99,  2,31, 14,52,  8,33, 12,96, 13,46,  9, 1,  5,48,  0,55, 
     1,90,  2,57,  8,80,  5, 8,  4,36, 10, 7, 12,41, 14,31, 13,31,  6,48,  7,68,  9,19, 11,25,  0,38,  3,88, 
     7,87,  5,24,  2, 1, 10,49,  1,63,  3,27, 13,98,  6,22,  8,35, 12,18,  4, 7, 14,55, 11,55,  9,87,  0,29, 
    13,33, 12,36,  0,75,  9,17,  3, 8,  5,55, 10,53, 14,31,  4,95,  8,31,  1,67,  6,80, 11,87,  7, 5,  2,58, 
     8,75,  6,25,  4,76,  3,72,  5,78, 11,22,  0,81, 12,37,  9,27,  1,85, 13,71,  2,16, 14,86,  7,78, 10,14, 
     3,90,  9,54,  5,98, 13,10,  8,75, 14, 4, 12,24, 10,10,  2, 7,  0,15,  1,43,  6,90,  7,81,  4,49, 11,88, 
     6,96,  8,81, 14,92,  3,31, 10, 9, 11,65, 12,35,  4,98,  7,85,  1,37,  9,43, 13,96,  2,91,  5, 1,  0,36, 
    12,40,  8,45,  3,94,  0,21, 14,87,  6,68, 11,35, 10,63, 13,37,  1,53,  7,98,  5,94,  9, 6,  2,25,  4,72, 
    14,35, 12,55, 10,26, 11,98,  3,23,  5,65,  8,88,  2,71,  9,35, 13,59,  0,84,  4,31,  7,76,  1,13,  6,89, 
    11,77, 13,34,  7,60,  9,76, 12,58, 14,63,  2, 2,  5,44,  8,91,  6,42, 10,53,  3,45,  4,45,  1,59,  0,99, 
     9, 6, 10,56, 11,47,  4,95, 13,36,  8,63,  1,85,  2,47, 14,60,  0,35,  5,82, 12,90,  6,30,  3,76,  7,94, 
     9,58,  3, 2,  6,69,  4,19, 10,64,  8,27, 12,17,  5,33,  1,48, 14,81, 11,86, 13,28,  0,94,  2,71,  7, 3, 
    13,93,  7,40,  5,95, 14,36,  0,38,  6,47, 12,24,  9,97, 11,11,  3,55,  2, 7,  1,68,  4, 3, 10,44,  8,47, 
    10,79,  2,33,  9,65,  5,57,  3,55, 14,78, 13,31,  1,60,  4,79,  0,25,  7,76, 12,96, 11, 5,  8, 5,  6,38, 
     1,75,  4,29,  3,77,  9,50, 14,31,  0,50,  5, 5,  7,25,  2,70, 11,38,  8,91, 10,71, 12,84,  6,80, 13,76, 
    13,64,  3,85,  5,96,  9,11,  7,73,  1,41,  4,50, 10,27,  6,40, 11,54,  0,63, 14,74, 12,84,  2,76,  8,58, 
    14,66,  0,75,  1,54,  9, 4,  7,16, 11, 6, 10,89, 13,29,  6, 3, 12,10,  2,93,  5,53,  4, 8,  3,59,  8,22, 
     7,17,  5,76, 11,84, 14,45,  8,70, 13, 5,  3,55,  6, 7,  9,26,  4,59,  1, 2,  2,18, 10,66,  0,58, 12,99, 
     5,57,  1,84,  8,50,  2,54,  6,92,  9,34, 12,58,  7,51,  4,34, 10,60, 13,42,  3,66, 14,18,  0,11, 11,59, 
     8,85,  5,31,  1,29, 11,18, 10,46,  6,29,  7,49,  4,37, 12,42, 13,18,  0,77,  9,67,  3,61, 14,46,  2,91, 
     9, 2,  2,66,  5,75,  4,83,  0,63,  8,62, 14,71, 10,20,  3,42,  1,59,  6, 4, 11,67, 13,95,  7,76, 12,80, 
    14,46,  1,83,  0, 7, 12,37, 10,60, 13,76,  6, 6,  3,84,  8,82, 11,94,  5,36,  4,79,  2,46,  9,90,  7,94, 
    10, 8, 12,60,  1,99,  7,70,  5,22,  8,91, 11,68,  9,87, 14,11,  3,51,  2,66,  6,19,  4,28,  0,47, 13,66, 
    13,91,  2, 2,  1,39,  5,12,  4,11,  8,17, 14,86,  0,68, 11,88, 10,86,  7,78, 12,75,  6,86,  3, 5,  9,79, 
     1,18, 13,90, 10,91,  0,21, 12,45, 11,31,  4,66,  3,49,  7,95,  9,11,  8,57,  5,31, 14,36,  6,57,  2,88, 
     5,56,  7,18, 10,45, 14, 9, 12, 4, 11, 2,  2,96,  0,60,  9,45, 13,57,  4, 5,  6,49,  1,90,  3,31,  8,97, 
    11,95, 10,96,  9,41,  7,75,  8,61,  1,65,  3,19,  6,38,  2,78, 12,85,  0,29, 14,65, 13,77,  4,67,  5,84, 
     2,64,  8,62,  0,52, 10,21,  1,82, 13,27,  5,93, 12,65,  3,32, 11,47,  4,66,  7,39, 14,45,  6,78,  9,26, 
     1,22,  8,52,  5,36,  3,31,  6,41, 13,92, 11,98,  0,68,  4,57,  9,32, 10,82, 12,39,  2,83,  7,48, 14,85
  };
  // Taillard 30x15 instance 4
  const int tai_30_15_4[] = {
    30, 15, // Number of jobs and machines
     3, 4, 11,27, 14,90,  5,76,  8,76,  6,16, 13,38,  0,72,  1,80,  2,94,  9,97, 10, 5,  7,44, 12, 9,  4,23, 
     0,47,  3,48,  4,69,  8,84,  9,25, 10,34,  5, 8,  1,32, 12,62,  7,90, 13, 2, 14,92,  2,55,  6,25, 11,37, 
    12,87, 10,54,  5,76,  8,80,  7,17, 14, 1, 11,26,  2,36,  1,12,  6,56, 13,71,  4, 6,  9,42,  3,89,  0,96, 
     5,25,  0,11,  9,69,  1,38,  8,98, 14,50, 10,98,  7,50, 11,19, 13,76,  3, 6,  4,95, 12,19,  2,37,  6,34, 
    12,10,  6,32,  3,94, 11,22,  2,55,  8,58, 14, 6,  5,78,  0,36,  9,56, 13,16,  4,22,  7,59,  1,41, 10,63, 
     6,12,  7,59, 14,95, 13,93,  0,93,  2, 7,  8,95,  4,10, 11,23,  9,48,  3,84, 12,64, 10,14,  5,90,  1,69, 
     8,43, 12, 1,  9,27,  7,30, 11,25,  5, 3,  6,94, 14,77,  4, 6, 13,42,  0,17,  1,76, 10,29,  2,63,  3,59, 
    12,14,  7,59, 10,27,  1,59,  5,56,  4, 6,  9,48, 13,43,  2,27,  0,27,  3,43,  6,32, 11,11,  8, 5, 14,25, 
     8,14,  7,47, 13,21, 12,32, 10,29,  6,40,  1,63,  3,25,  4,49,  2, 4,  0,67, 14,27,  5, 9,  9,75, 11,15, 
     8,70,  7,97,  6,52,  3,22, 14,87,  1,87,  0,36,  2,86, 12, 2, 11,93, 10, 1,  5,16,  4,70,  9,99, 13,43, 
     2, 5,  8,28, 13,77, 11,23,  1,63,  5,69, 12,35,  3,22,  6,90, 10,46,  7,67,  4,63,  0,63, 14,24,  9,79, 
     1,69,  6,25,  8,65,  4,29,  7,51,  5,88, 13,70,  0,25, 14,58, 11,20, 10,24,  3,38, 12,34,  2,71,  9,66, 
    14, 4, 13, 4,  9,34,  8,21,  7,60, 12,55,  1,70,  4,68, 10,80,  6,56,  2,29,  3,97,  0,84,  5,66, 11,50, 
     9,88,  2,81,  6,50,  1,38,  0,52,  3, 7, 12,33, 14,46,  8,59,  7,38,  4,14,  5,66, 11,72, 13,80, 10,97, 
    11,35, 10,88,  8,98,  3,78,  5,86,  7,13,  2,94, 14,25, 13,50,  6,76,  9,89,  0,41,  4,53,  1,10, 12,99, 
     0,42, 13,16,  8,44,  6,40,  3,35, 10,71,  7,52, 11,35,  2,98, 14,73,  5,92,  9,44,  1,35,  4,79, 12,17, 
     9,46,  5,55,  1,74, 12,80, 11,89,  2,61, 14,34,  7,75,  4,39,  8,47,  3,70,  6,84, 13,26, 10,44,  0,82, 
    13,77, 12,40,  4,43,  2,76,  8,69, 11,42, 14,25, 10,34,  1, 8,  3,77,  6,57,  5,56,  7,80,  0,12,  9,89, 
    12,96, 14,53, 10, 3,  5,49,  2,76,  7,37, 11,50, 13,73,  8,98,  6,44,  3,89,  9, 2,  1, 1,  0,99,  4,89, 
     7, 7, 12,91,  0,32, 10,44, 13, 2,  8,66,  6,62,  5,22,  9,23,  1,92, 14,70,  3,31, 11,10,  4,94,  2,89, 
     6,46, 12,15,  7,23, 11,70, 13,57, 14,67,  3,58,  9,92, 10,66,  4,55,  1,13,  8,33,  2,64,  5,36,  0,21, 
     9,39,  2,35,  3,90,  1,67, 10,70, 11,94,  5,48,  8,76,  6,93, 14,46,  0,34, 13,58,  7,74, 12,49,  4,80, 
     0,99, 14,10,  1,90, 12,60,  5, 5,  8,17, 11,24, 10,83, 13,37,  6,59,  9,17,  2,99,  4,42,  3,72,  7,36, 
     8,94, 10,69, 13,47,  5,96,  7,30,  9,29,  6,22,  0,26, 11,99, 12,13,  1,59, 14,66,  4,89,  3, 1,  2,24, 
     3,91, 10,21,  9,42,  0,79,  5, 8,  2, 9, 12,66,  4, 1, 14,59,  8,36,  6,54, 11,52,  7,87,  1,82, 13,33, 
    10,31,  7,93, 12,68,  3,72,  0,22,  8,85,  6,40, 14,76,  5,48, 11,83,  9,89,  4,83,  2,43,  1,69, 13,67, 
     0,64, 13,59,  2,63, 12,54,  5,21, 11,79,  6,35,  8,95,  4, 7,  9,67,  3,15,  7,89, 10,54,  1,98, 14,26, 
    14,14,  3,93,  0,87,  7,15,  8,40,  9,20, 12,61, 10, 8,  4, 8, 11,57, 13,14,  5,90,  1,16,  2,36,  6,59, 
    13, 2,  1,87,  5, 8,  6, 2,  2,12, 14,35,  8, 6,  7,73,  9,82, 10,37,  3,19, 11,81,  4,19, 12,12,  0,60, 
    10, 4,  7, 9,  1, 7, 14,59,  8,29,  5,39,  2,55, 13,18,  0,70,  4,14,  9,47, 12,75, 11,78,  3,99,  6, 9
  };
  // Taillard 30x15 instance 5
  const int tai_30_15_5[] = {
    30, 15, // Number of jobs and machines
     2,96, 13,86,  9,75,  1, 3,  4,97,  0,88, 14,88, 12,66,  6,16, 11,63,  5,73,  7, 3,  3,63,  8,91, 10,33, 
     3,21, 11,33, 14,38,  1,94,  5,79,  0,36,  8,50, 10,83,  2, 4,  4,83,  6, 7,  9,26, 12,87, 13,15,  7,90, 
     2,88,  8,37,  6,94,  5,65,  4,24,  7,86,  0,96, 14,94, 11,81,  1, 2, 10,93, 12, 5,  3,23, 13,45,  9,11, 
     6,62,  0,61,  8,37,  7, 1,  4,10,  9,21,  2,88, 14,24, 12,61, 10,42, 11,54,  1,92,  3, 4,  5,38, 13, 9, 
    12,52,  3,87,  5,37,  0,27, 10,76, 11,69, 13,76,  6,74,  7,86,  4,46,  8,84,  2,48,  1,16, 14,91,  9,28, 
    11,35,  1,53,  3,46,  0,99,  5,17,  8,78,  7,84, 10,88,  4,60,  2,53,  6,27,  9,33, 12,88, 14,75, 13,13, 
    10,79,  1,72, 11,25,  5,52,  9,24,  4,98, 13, 4,  3,99,  7,17,  0,52,  8,85,  6,48, 14,85, 12,99,  2,72, 
    12,77,  1,80,  4,44,  5,73, 13,46,  9,60,  2,25, 14,67,  7,18,  3,17, 11, 4,  8,73,  6,32, 10,67,  0, 6, 
    10,51, 14,26, 11,29,  9,57,  4,54,  0,16,  3,41,  2, 2,  6,15,  8,88,  5,47, 13,10,  7, 2,  1,75, 12,16, 
    14,27,  2, 1,  3,88,  1,44,  5,17,  9,20, 10,50,  4,40, 11,40,  0,65,  8,10,  7,50,  6,11, 13,36, 12,81, 
     7, 6,  6,36, 12,67,  1,73,  2,30, 11,97,  3,62, 14,11,  4,80, 13,25,  5,60,  0,42,  8,42,  9,40, 10,55, 
    14,59,  3,86, 13,89,  0, 8,  7, 4, 12,16,  6,67,  1,43, 11,74, 10,97,  2, 3,  8,12,  9,55,  4, 3,  5,29, 
     3,22, 11,88, 13,39,  8,91,  2,25,  1,23, 10,38, 14,14,  4,72,  9,87, 12,78,  5,42,  6, 3,  0,31,  7,83, 
     8,74,  0,69, 13,59,  1,74,  6,61, 14,83, 10,82,  4,43,  5,42, 11,43,  2,20,  9,51,  7, 7, 12, 5,  3, 7, 
     5,75, 12,71,  4,45,  6,92, 14, 9,  8,48,  3,20,  7,28, 13,25,  9,14,  1,61, 10,39,  2,65, 11,28,  0,49, 
     2,94,  5,12, 12,33, 11,35,  1,57,  4,33,  7,22, 14,47,  0,87,  9,47,  8,61,  6,42,  3,84, 13,12, 10,58, 
    10,71,  3,35,  1,70,  4,67,  7,86,  5,42,  2,72,  0,52, 14,73, 12,44,  8,96,  6,42, 13,96,  9, 3, 11,94, 
     2,70,  6,30, 13,48,  4,57,  3,66,  8,95,  7,95,  5,17, 14,64, 10,70,  9, 6, 12,99,  1,63, 11,33,  0,27, 
     2,80,  0,93,  6,15, 11,86,  5,33, 12,65,  7,44, 14,22, 13,86,  4,93,  3,92,  1,88, 10,65,  8,39,  9,14, 
     6,91,  5,42,  2,14,  3,17,  0,50,  7,16, 10, 2,  1,36, 14,47,  4,11,  8,34, 13,29,  9,71, 11,78, 12,55, 
     5,76, 13,67,  2,35, 14,93, 11,13,  0,58,  6,24,  4,10,  1, 6,  9,49,  7,40, 10,61, 12,72,  3,97,  8,17, 
    12,89,  6,86,  0,45, 14,59,  9,16, 10,52,  5,39,  4,83,  7,11,  3,56,  8,30, 13,60, 11,80,  1,43,  2, 4, 
     1,49,  5,44, 10, 3,  4,73, 12,49,  3,63,  0,20,  7,68,  8,40, 14,37,  9,17, 13,66, 11,92,  2,82,  6, 5, 
    13,69,  3,57,  8,34,  2,67, 14,73,  6,60, 10,93,  7, 1,  9,43,  1,67,  4,85,  0,80,  5,80, 11,81, 12,98, 
     8,55,  1,27,  3,50, 12,96,  0,42,  2,76,  4,33,  6,82, 14,82,  9,87, 13,93, 11,42,  5,20,  7,97, 10,15, 
     2, 8,  0,79,  7,24,  5,19, 11,73,  8,82, 13,47,  1,90, 14,97,  9,93,  4,69, 10,47,  6,68, 12,44,  3,54, 
     7,52,  6,11,  9,98, 11,44, 10,14, 13,38, 12,57,  0,50,  5,40,  1,89,  4, 2,  3,73,  8,19,  2,40, 14,96, 
     7, 5,  0,52, 14,45, 10,17,  3,94,  2,44, 11, 9,  5,18, 12,37,  1,84,  6,28,  4,78,  8,28, 13,68,  9,64, 
    10,23, 14,63,  5,57,  1,57,  6,22,  4,71, 13,69,  8,15,  2,19, 11,88,  0,25,  9,83, 12,62,  3,54,  7,68, 
    13,47,  1,96,  2,11,  0,99,  6,28, 12, 8, 10,50,  7,18,  9,97,  5,10,  3,54, 11,50,  4,67,  8,16, 14,79
  };
  // Taillard 30x15 instance 6
  const int tai_30_15_6[] = {
    30, 15, // Number of jobs and machines
     4,96, 12,47,  9,40, 11,68,  5,49, 14,91, 10,57,  0,81,  2,87,  1, 6,  7,82,  6,47,  3,97,  8,94, 13,75, 
     0,42,  9,55, 14,82, 12,61,  1,67,  4,79, 11,39, 10,43,  6,62,  3,41,  2,78,  7,36,  8, 8,  5,21, 13,91, 
     0,52,  5,28,  3,48,  8,25,  7, 2, 14,98, 12,95, 13, 7,  9,68,  4,96, 10,72,  2,50, 11,68,  6,54,  1,37, 
     6,81,  5,59,  3,46,  4,61, 14,43,  8,71, 12,24, 10,71,  7,30,  2,87,  1,86,  9,10, 11,10,  0,93, 13,94, 
     8,30, 13,71, 10,65,  0,13,  6,30,  2,22,  7,46, 12,70, 11,88, 14,78,  1,79,  5,57,  3,71,  9,58,  4,36, 
     5,68,  9,32, 13,32,  2,15, 11,98,  0,95,  7,57, 14,66,  4,43,  6,31, 12,34, 10,60,  8,73,  1,56,  3,40, 
     9,27, 10,42,  7,24,  8,12,  1,22,  4,57,  6,93, 13,58, 14,67, 12,64,  0,30,  3,16,  2,21, 11,19,  5,33, 
     7,43,  9,51, 11,53, 13,62, 10,58,  1,38,  5,84, 14,65,  8,87,  2,26,  4,95,  6,61,  0,77, 12,49,  3,49, 
    10,93,  3,81,  2,55, 14,59, 12,70, 13,68,  8,97,  6,57, 11,48,  0,92,  1,82,  9,89,  7,87,  5,13,  4,54, 
    11,60,  3,33, 10,66,  1,96,  0,23, 14,36, 13,28,  2,53,  5,78,  4,78,  7,94,  6,72,  9,47,  8,28, 12,87, 
     5,98,  2,89,  9,27,  8,34,  3,88,  4,15, 10,64, 12, 5,  1, 4, 11,63, 13,69,  7,82, 14,29,  6,53,  0,69, 
    13,97, 14,87,  1,50,  0,68,  9,76,  2,74,  4,89, 11,15,  3, 5,  5, 2, 12,79,  6,59,  8,93, 10,19,  7,86, 
     1,60, 14,47, 12,13,  9,62,  5,95, 11,67,  3,89, 10,11, 13,29,  4,52,  0,62,  2,31,  8,51,  6,55,  7,39, 
    11,76,  4,92, 13,85, 14,20,  7,61,  6,14,  2,62,  9,52,  1, 5, 12,63,  0,29,  5,85,  3,79,  8,52, 10,51, 
     6,61, 13,45,  0,93,  5,51, 11,97,  9,46,  3,88, 12,28,  2,57,  8,45, 10,23,  4,91, 14,66,  1,73,  7,41, 
     8,49,  4,58,  7,32, 13,30,  6,59, 14,57,  9,14,  1,33, 12,14,  5,59,  2,41,  3,59,  0,50, 10,67, 11,53, 
     7,94, 11,52,  2, 7, 12,51, 10, 8,  1,99,  5,97, 14,66,  3,98,  8,58,  6,52,  0,43,  9,80,  4,23, 13,18, 
     6,97,  8,57,  9,72, 13,97, 10,12,  3,70, 14,33, 12,72,  7,14,  1, 2,  4,99,  0,30,  5,18,  2,95, 11, 2, 
    12,64, 10,75,  7,63,  4,14,  1,55, 11,10,  0,89,  6,89,  3,24,  8,32, 14,70,  5,79,  2,71, 13,42,  9,14, 
     9, 1,  5,82, 12,27, 11,22,  2,44,  7,97,  0,76, 13,16, 14,27,  1,24,  6,98,  8,25,  3,82, 10,75,  4,15, 
     7,26,  3, 4, 13,18,  8,51,  6,47, 11,27,  2, 6, 14,84,  4,72,  9,29, 10,91,  1,76,  5,78,  0,36, 12,93, 
     0,35,  1,39,  2,89,  6,53, 14,85,  5, 7,  3,90, 12,16, 10,70, 13,49,  7,73,  4,13,  9,12,  8,89, 11, 9, 
     1,56,  3,40,  6,51,  5,47,  2,77,  8,65,  0,84,  7,93, 10,54, 14,66, 12, 6, 11,36,  9,87, 13,41,  4, 7, 
     6,56, 11, 1,  9,57, 13,45,  3, 3,  0,14,  1,74, 10,29, 12,65,  2,43, 14,13,  4,42,  7,67,  5,45,  8,78, 
     2,81,  3,72,  0,99,  4,52,  9,69,  1,39, 12,74,  5,47, 10,29,  8,73, 13, 6, 14, 5,  6, 2,  7, 8, 11,25, 
     7,17,  4,64,  9,97, 11,94,  3,99,  5,68,  1,36, 10,21, 14,22, 12,61,  8,43,  2,93, 13,82,  6,91,  0,86, 
     9,20, 12,28,  7,98,  5, 7,  2,18, 10,37,  4,60, 14,47,  8,62,  6,75,  1,42,  0,52,  3,97, 11,46, 13,98, 
    10, 9, 14,15, 11,85,  0,55,  4, 7, 13, 6,  1, 3,  9,27,  7,11,  6,31,  5,90, 12,81,  3, 5,  8,86,  2,30, 
    13,53, 14,87,  5,93,  4,62,  6,19,  1,12,  0,53, 12,73, 11, 4,  3, 1, 10,65,  2,35,  9,65,  7,23,  8,40, 
    14,13,  6,22,  8,34,  2, 5,  7,68,  5,81, 11,53, 10,66,  4,96,  0,50,  3,40, 13,70,  1,92, 12,13,  9,43
  };
  // Taillard 30x15 instance 7
  const int tai_30_15_7[] = {
    30, 15, // Number of jobs and machines
     2,81, 13,59,  1, 8,  9,88,  8,14, 12,18,  4,22, 10,52, 11,75,  3,33,  6,23,  7,69, 14,42,  5,26,  0,54, 
     6, 4,  3,79,  0,76, 10,59, 13,42,  7,28,  4,75, 14,60, 11,41,  5,14,  1,99,  8,58, 12,41,  9,66,  2, 1, 
     4,37,  6,63, 12,46, 11,79,  0,38,  7,44, 14,18, 13,45,  5,55,  1,78,  9,79,  8,27, 10, 6,  2,21,  3,70, 
    11,58,  4,63, 14,56,  0,27,  1,37,  9,51,  2,37,  8,31,  5,24, 10,73, 12, 7,  3,72,  7,34, 13,32,  6,27, 
     0,95,  5,33, 11,81,  1,23,  7,26,  4,12, 14,32, 13,60,  2,89,  6,78,  3,20,  9,35,  8,35, 12,34, 10,17, 
    11,64,  5,11,  3,58,  2,70,  0,31,  1,74,  4,82, 12,31,  7,65,  8,90, 13,63, 14,81,  9,80,  6,70, 10,82, 
    11,99,  9,28,  6,63,  7,81,  2,86, 14,10, 12, 7,  5,17,  1,22,  3,45, 10,92, 13, 1,  4,37,  8,37,  0,43, 
     4,86, 11,92,  8,74,  2,93,  5,42,  6,28, 12,59,  7,77, 13,81,  0,41,  9,11,  1,45, 10,62,  3,22, 14,57, 
     1,12,  2,90, 12,70,  7,89,  5,37, 13,56, 10,21,  9,74,  4,63, 14,39,  0,37,  8,83, 11,78,  6,66,  3, 6, 
    11,38, 12,67,  8,27,  7,11, 10,45,  3,21,  6,73,  9,47,  2,31,  1,24,  0,59, 13,91,  4,46,  5,48, 14,42, 
     3,63,  2,17, 14,59,  7,27,  9,81,  6, 7, 10,19,  0,52, 11,74,  1, 9,  5,50,  8,59, 12,41, 13,64,  4,96, 
     1,81,  5,91, 13,10,  6,46,  8,65, 10,73,  3,59,  2,93, 12,75,  0,47,  9,61,  4,86, 14,65,  7,29, 11,21, 
     2,63,  8, 9, 13,81,  5,37,  9,32,  0,62, 12,93,  1,63,  6,53,  3,99,  7,62, 11,10, 14,85,  4,43, 10,25, 
    11,26, 12,46,  9, 7, 13,50, 10,68,  4,81,  5,88,  7,66,  8,90,  3,51,  2,62,  0,29,  1,87, 14,41,  6, 8, 
    11,90, 13, 8, 12,63,  7,57,  6,23,  5, 5,  0,20,  1, 6,  3,31,  9,42,  4,86,  8,76, 14,98, 10,45,  2,86, 
     0,11,  2,94,  1,42,  6,95,  9,43,  3,51, 12,42,  5,39, 13,82,  8, 1,  7,96,  4,36, 14,74, 10,74, 11,74, 
    14,12,  8,77,  1,13,  3,31, 13, 9,  4,39,  0,57,  2,25, 10,55, 11,60, 12,87,  6,55,  7,85,  9,12,  5,78, 
     3,55,  5, 4, 10,12,  1,42,  4,46,  6,89,  8,44, 14,33,  7,15, 11,73, 12,47,  9,72, 13,81,  2,79,  0, 6, 
     0,77, 12,44,  1,62, 13,17,  3,70,  4,19,  9,69, 14,70, 11,30, 10,97,  8,82,  5,36,  2,19,  7,33,  6,50, 
     1,98,  9,42, 13, 4,  7,26,  0,84, 10,34,  2, 3, 11,59, 14,52, 12,70,  8,49,  6,42,  4, 6,  3, 7,  5, 6, 
     4, 2,  2,84,  3, 1, 12,76, 13,10, 10, 2,  6,75,  7,10,  9,97,  8, 3, 14,18, 11,53,  5,31,  0,84,  1,17, 
     8,63, 11, 6,  3,77,  6,85, 12,20,  2,28, 10,81,  9,76,  7,33,  4,76, 13,27, 14,87,  0,13,  5,37,  1,62, 
     4,20,  1,70,  6,89, 10,60,  8,64,  3,39, 11,67, 12,78,  2, 7,  9,46,  0,25,  5,49, 14,27, 13,76,  7,98, 
    13, 3,  9,22,  5, 9, 12,66,  6,39,  8,51,  3,30,  1,92,  7,94,  2, 8, 11,24, 14,27,  4,88, 10, 9,  0,65, 
     3,79, 10,33, 14,62,  5,85, 11,17,  7,64,  8,66, 13, 2,  1,71,  6,88,  4,64,  9, 3, 12,44,  0,60,  2, 6, 
     0,91, 12,24,  6, 5,  1,31,  4,53,  9,53,  7, 8, 10,15, 14,11,  5,53, 13,22, 11,83,  8,50,  3,81,  2,52, 
    10,87,  2,62,  0,84,  5,91,  4,53,  9,17, 13,72, 14,13, 12,92,  8,92,  7,16,  3,13,  1,13,  6,69, 11,44, 
     9,83,  3,62,  8,61, 13,26,  4,14,  6,69, 14,34,  5,61,  2,12, 12, 2,  0,27, 10,51, 11,64,  1,14,  7,82, 
    14,54,  2,82,  6,68, 10,83,  1,71,  5,81, 11, 6,  7,42,  0,22,  9,22, 13,94,  4,25, 12,53,  8, 5,  3,70, 
     6,67,  7,72, 12,47,  5,35,  4,78,  9,34,  1,67, 13,86,  2,89, 10,69,  8,46, 14,57, 11,87,  0,22,  3,87
  };
  // Taillard 30x15 instance 8
  const int tai_30_15_8[] = {
    30, 15, // Number of jobs and machines
     5,20,  3,56, 12,69,  6,15,  9, 6,  1,75, 14,84,  4,24,  2,64, 13,37, 10,79,  0,95,  8,27, 11,60,  7,35, 
     1,27,  7,58,  0,56,  2,30,  4,30, 11,57, 10,55, 14,63,  5,32, 12,43,  8,44,  3,74,  9,46,  6,11, 13,41, 
     9,43,  1,75,  6, 8,  4,71,  0,50, 10,56,  5,13, 13,14,  7,99, 11,57, 14,86,  2,28,  3,37,  8,83, 12,70, 
     5,68,  8,66,  6,27, 14,33,  1,47,  0,73,  3,87, 11,70, 12,21, 10,22,  7,30, 13,10,  4,11,  2,10,  9,17, 
     0, 6, 11,49,  1,11,  5,69,  9,50, 13,50, 14,12,  2,73,  7,84, 12,92,  3, 1,  8,84,  4,88, 10,52,  6,46, 
    12,14,  1, 7, 10,11,  7,79, 14,45,  9,22,  0,85,  2,67,  6,64, 13,75,  8,22,  3,35, 11,65,  5,30,  4,68, 
     8,67, 12,17,  3,58, 11,20,  6,45,  5,55,  2,53,  7,10, 10, 3, 13,66, 14,63,  1,36,  4,93,  0,40,  9,85, 
     8, 8,  4,27, 10,68,  0,39, 14,24,  2,67, 12,32,  1,42,  6,54,  9,18,  3,58, 13,75,  7,37,  5,63, 11,16, 
    12,83,  5,27,  3, 3,  8,25,  4,68, 11,63,  7,33, 14,86,  2,12,  1,22, 13,75,  6,16,  9,44, 10,80,  0,48, 
     0,93,  9,54,  5,81, 14,14,  1,69, 13,66,  6,20, 11, 2,  7, 6, 10,88,  4, 7,  8,73,  2,66,  3,66, 12,81, 
    13,62,  6,81,  4,36,  7,86,  2,95,  8,92, 12,46, 10,10,  5, 6, 11,18,  0,41,  1,70,  3,29,  9,22, 14,15, 
     6,47,  0,38,  7,59,  8,97,  4,62, 13, 9,  2,21,  1,30,  9, 8, 14,23, 12,74, 10,48,  5,14, 11,68,  3,55, 
     6,67,  0,26,  4, 3,  7,83,  2,73, 12,19, 10,12,  8,81, 13,15, 11,34, 14,88,  9,54,  3,35,  5,58,  1,69, 
     3, 7, 12,42,  5,32,  1,93,  6,97,  4, 4,  7,98,  2,80, 11,90,  9,58, 13,40, 14,15,  0,34,  8,58, 10, 3, 
    11,68,  3, 3,  1,39, 13,51,  7,71,  9,77,  8,44, 14,43, 10, 6,  4,38,  6,10,  2,81, 12,42,  0,28,  5,65, 
     7,29, 13,12,  9,64,  4,55, 10,77,  2,20,  0,78,  6,39,  5,88,  3,47,  8,81,  1,41, 14,18, 11, 7, 12,40, 
     7,61,  5,26, 14,24, 10,60, 13,76,  6,57,  3,67,  2,28,  9,61, 12,60,  4, 3,  8,20,  1,47,  0,26, 11,90, 
    13,33,  7,82, 10,36,  1,51,  5,97, 11,19,  8,63,  0,27, 14,35,  6,28,  4,26,  3,13, 12,66,  2,11,  9,26, 
     5,49, 10,71,  7,99, 11,67, 14,77,  1,20, 12,96,  0, 1, 13,88,  2,21,  4,81,  6,84,  3,49,  9,92,  8, 7, 
    10,83,  7,17,  5,92,  2,87, 11,17, 14,61,  3,31,  9, 1,  0,67,  6,80,  4, 8, 12,16, 13,50,  8, 9,  1,69, 
    11,38,  3,73,  6,86,  2,65,  7,83, 10,25,  1,35, 13,22,  0,81,  4,14,  8,19,  5,42, 14,21,  9,30, 12,83, 
    10,67,  9,61,  0,96,  3,44,  4,13,  5,38,  8,51, 11,90,  1,84,  7,30,  6,13, 14,60, 12,20, 13,14,  2,82, 
    10,87,  9,75,  0,24,  4,67,  7,20,  2,96,  1,76, 13,61,  6,44, 14,51, 12,90,  8,40, 11, 4,  3,16,  5,51, 
     6,22,  0,52,  7,35, 13,58,  5, 1,  3,62, 14, 4,  1,68,  9, 8, 12,39,  8,48,  2,76,  4,51, 11,25, 10,37, 
     7,34,  6,51, 11,27,  5,40, 13,11, 12,96,  8,81,  4,88, 14,90,  9,32,  0,62,  3,52,  1,91,  2,54, 10,96, 
     7,40,  5, 1, 10, 3,  6,71, 11,20, 13,52,  9,92,  0,73, 12,17,  2,87,  8,81, 14,35,  1,24,  3,23,  4,93, 
    13,58,  7,65,  2, 1,  9,81,  1,34, 11,48,  0,82,  5,32,  8,23, 10,44, 12,20,  6,80,  3,85, 14,56,  4,90, 
     7,82,  9,61,  4,68, 14,65, 13,48,  2,88, 12, 2,  3,76,  8,37, 10,72,  0,18,  6,11, 11,33,  5,24,  1,65, 
     9,94, 12,14,  7,17, 11,25,  4,57,  5,81,  0, 8,  1,81, 13,59,  8,97,  3,43, 10,34,  2,55,  6,36, 14, 2, 
    10,23, 11,64, 14, 7, 13,89,  5,13,  1,96, 12,84,  9,91,  3,20,  6, 3,  8,45,  2,50,  0, 1,  4,41,  7,57
  };
  // Taillard 30x15 instance 9
  const int tai_30_15_9[] = {
    30, 15, // Number of jobs and machines
     5,76, 11, 4,  1,98,  9, 1,  6,51,  4,92, 13,75,  3,47,  7,35, 10,70, 12,21, 14,20,  2,79,  8,81,  0,63, 
    11,71,  8,85,  4, 3,  9,45,  1,13,  2,57, 12,26,  5,63, 10,38, 13,91,  6,73,  7,59, 14,74,  0,37,  3,65, 
     9,60,  2,74,  0,35, 13,73, 10,49,  6, 1, 11,92,  3, 5,  8,41, 14, 2, 12,95,  5,28,  7,37,  4,78,  1,86, 
    12,95,  1,73, 13,23,  5,77, 14,47,  0,24,  8,29, 11,88,  7,69,  3,49,  4,28,  6,66,  2, 4, 10,41,  9, 3, 
     5,28, 10,26, 12,71,  8,81,  7,36,  2,96, 14,95,  9,45, 13,10,  4,55, 11,87,  0,65,  6,54,  1,26,  3,60, 
     4,40, 11,36,  2, 5, 14,78, 12,63,  5,96, 10,25,  8,86,  1,85,  6,56,  9,25,  0,30, 13,98,  3,78,  7,41, 
     2,90,  3,15,  0,89,  6,87, 14,52, 11,59,  7,22,  5,42,  4,46, 12,60, 13,54,  8,87,  9,22,  1,97, 10, 1, 
    14,51,  5,75,  6, 2,  8,86,  9,19, 10,88,  1,20,  2,88,  4,24,  7,42, 11,90,  3,20, 13,29, 12,20,  0,50, 
    13,11,  2,96, 10,92,  0,94,  6,78,  9,63,  8,44,  7, 8,  4,68, 14,77,  5,52,  1,74,  3,43, 11,10, 12,87, 
     6,75,  1,78, 14,27, 10,27,  7,82,  2,91,  4,88, 11,76,  0,37, 13,43,  9,52,  8,71,  3,45,  5,99, 12,70, 
     4,47,  6, 8,  7,99, 13,85, 11,11,  8,16, 10,24,  5,10,  3,10,  0,12,  9,37,  2,39, 14,38, 12,76,  1,91, 
     5,62, 13,98,  9,68,  2,14,  0,57, 12, 2, 14,52,  7,36,  1,58, 10,54,  3,99,  6,57, 11,52,  8,90,  4,58, 
    12,53,  6, 6,  2,65,  0,68, 10,53,  3,66, 11,15,  4,83, 14,80,  5,73,  7,86,  9,57, 13,23,  8,88,  1,37, 
     3,73, 12,65,  4,54, 10,95,  8,12,  7,69,  5, 4,  1, 7,  6,12, 11,82,  9, 5, 14,22, 13,15,  2, 2,  0,38, 
    10,59,  6,49, 11,29,  5,69, 13,79,  3,57,  1,27, 12,62,  0,57, 14,22,  8,29,  2,42,  7,59,  9,20,  4,86, 
    10,81, 13,24,  1,55,  4,95, 11, 2,  5,94,  6,38,  7,43, 14,15,  3,52,  8,54,  2,66,  0,64, 12,24,  9,29, 
     2,20,  6,25,  5,70, 13, 6,  4, 3, 10, 5, 14,73,  7,25,  0,58,  8,36,  3,91, 12,22, 11,61,  9,38,  1,33, 
    14,61, 13,20,  2,21,  1,22,  4,22,  9,69, 11,98,  0,12,  3,30, 12,98,  8,28,  7, 8,  6, 7,  5,51, 10,66, 
     7,77,  0, 3,  3,11,  8,23,  2,56,  4,30, 10,77,  1,64, 13,52,  5,70,  6, 3, 12,97, 14,93, 11,54,  9,15, 
     0, 1,  1,22, 11,99, 14,34,  5,48,  2,15,  9, 9, 13,67,  8,85,  4,41,  6,13, 10,48, 12, 7,  3,66,  7,55, 
    12,44, 11,94, 13,33, 10,28, 14,23,  4,31,  8,10,  1,15,  9,50,  3,68,  7, 7,  5,50,  0,79,  6,76,  2,89, 
    10,73,  0, 2,  1,76,  4,26, 14,50, 13,93,  7,93,  9,35,  2,64,  3,42, 11,17, 12,26,  8,60,  5,73,  6,57, 
     0,79, 11,56,  8,22,  5,39,  6,27,  9,38, 14,14,  4,55,  2,64, 13,99, 10,28,  7,97, 12, 7,  1,92,  3,71, 
    12, 2,  5, 3,  1,33,  7,74, 13,69,  4,58,  8,99, 11,79,  0,84, 10,92,  6,98, 14,41,  9,37,  2,12,  3,12, 
     5,46,  8,23,  3,48,  4,69, 13,71,  9, 9, 12,94, 10,44,  1, 1,  7,26,  0,93, 11,54,  2,24,  6,77, 14,44, 
     0,83, 14,86,  3, 6, 12,61,  6,39, 10,72,  8, 1,  7, 8,  9,17, 13,60,  2,41,  1,16,  5,21,  4,21, 11, 6, 
     8,28,  4,59, 14,62,  7,97,  2,52, 13,58, 11,49, 12,83,  0,11,  5,49,  6,24,  3,56,  9,43, 10,34,  1,23, 
    12,75,  2,82,  0,75,  3,94,  5,67, 13,15, 14,23,  1,57, 11, 4,  4,51,  8,23,  7,40,  9,63,  6,97, 10,20, 
    10,14,  3,33,  2,16, 13,14,  8,24,  6, 1, 11,20,  9,96,  0,75,  1,36,  4,92,  7,74,  5,13, 14,79, 12,48, 
     5,33, 10,89, 11,89,  4,49,  0,58,  2,32,  3,95,  9,64, 13,11,  8,13, 12,43,  7,98,  6,32, 14,56,  1,62
  };
  // Taillard 30x20 instance 0
  const int tai_30_20_0[] = {
    30, 20, // Number of jobs and machines
     5,59, 13,72,  3,92, 15,35, 19,17,  9,48, 10,57,  6,18, 12,55,  4,51,  2, 8, 14,68,  8,90,  7,39, 16,79, 11,40,  0,66, 17,55, 18,62,  1,66, 
    13,42,  2,60, 15,52, 12,14,  4,83,  9,95,  3,36,  7,28,  5, 4,  0,31,  8,14, 14,23,  6,71, 19,95,  1,69, 10,17, 18,13, 17,23, 16,78, 11,51, 
     8,93,  5,12,  2,34, 18,32, 17,59, 14,73,  0,46,  4,25, 11,82,  3,90, 16,70,  7,27,  6,82,  1,85, 12,40, 15,35, 10,61, 19,92, 13,98,  9,53, 
    13,31,  8,95,  0,36, 11,61,  3,92, 14,24,  7,70,  4,15, 18,76,  6,50, 19,18,  5,30,  2,93,  9,62, 10,83, 15,16, 17,75,  1,29, 12,35, 16,31, 
     8,27,  6,10,  2,93, 13,26, 16,64, 11,70, 15,16, 12,48,  9,46,  4,37, 19,89, 17,83,  5,71,  3,72,  7,45,  1,73, 10,97, 18,12, 14,57,  0,62, 
     1, 9, 13,16, 10,75,  0,21,  2,49, 12,97, 19, 5,  5,20, 17,26, 16,50, 18,26,  4,20, 15, 8,  8,96,  7,50,  6,84, 14, 7, 11,52,  3,73,  9,43, 
     2,20,  3,76, 16, 3, 17,45, 10,53, 15, 6, 13,83, 12,77,  9,21, 19,52,  8,32,  0,27, 18,93, 11,81, 14,78,  1, 6,  5,93,  7,60,  4,12,  6,35, 
    12,41, 10,59, 17,37,  4,89,  3,87, 11,32,  2,98, 19,24,  8,30,  9,84, 13,49, 14,84,  7,44, 18,16, 15,43,  6,65, 16,44,  1,83,  5,71,  0,71, 
    10,46, 14,36,  3,60,  0,59,  7,53, 17,58, 19, 8,  2,33, 11,70, 16,93,  6,38,  4, 5, 18,75,  1,23, 13,98,  5,90, 12,18, 15,62,  8, 4,  9,56, 
     0,27,  2,31,  3,45,  9,57,  8,79, 12,14, 16,82, 13,96,  4, 4, 10,17,  6,46, 19, 3, 15, 7,  1,42,  5,24, 17,86,  7,67, 14,79, 18,43, 11,17, 
     1,72,  4,54,  0,51, 10,87, 15,52, 11, 4, 16,35,  9,62, 19,15, 13,45, 14,84,  8,65,  6,85, 17,49, 18,98, 12, 5,  2,81,  7, 8,  3,72,  5,33, 
     6,31,  5,86,  9,46, 10, 3,  0,63,  2,58,  3,81, 12, 7, 11,54,  7,39, 13,46,  8,92, 19,96, 14,57, 16,40,  4,49, 17,57,  1,86, 18,20, 15,91, 
    13,35, 19, 5, 11,43,  5,84,  2,77, 15,20, 14,84,  4,70,  3,79,  6,52, 10,92,  1,34, 12,39, 18,30,  9,65,  7,11, 16,88, 17,32,  8,80,  0, 2, 
    10,59,  3,36,  4,72,  9,46, 17,48,  8,72,  0,76, 19,48,  2,69, 11,62, 12,30,  1,48, 18, 7, 15,89,  5,37, 16,49,  6,30, 14,52, 13, 1,  7,56, 
     4,18, 14,35,  8,61, 15,23, 11,46,  9,12, 10,38,  1,59, 17,50, 16,75,  5,60, 18,57,  6,63, 13,89, 19,71, 12,52,  7,83,  3,86,  2,81,  0,98, 
     4,33,  9,14, 18,19, 19,84,  3,69, 17,59, 15, 2, 16,83,  5,12,  8,21, 11,73, 14,83,  0,26,  2,94,  1,65, 12,98,  6,83, 10,45, 13,40,  7,89, 
    17,63, 10,72, 13,80, 19, 2,  0,94, 12,11, 14,25, 18,10,  2,90,  5,73, 11,20, 16,92,  7,11,  4,85,  8,63,  1,97, 15,38,  6,13,  9,42,  3,59, 
    19,95, 13, 4,  9,95,  3, 6,  6,67, 17,30,  7,88, 16,26,  5,57, 14,61, 15, 9, 18,35,  0,23,  2,47,  1,46, 12,96,  8,19, 11,54, 10,75,  4,11, 
     9,64, 11,79, 17,87, 13,91,  3, 2,  1,61, 10,31, 16,85,  0,53,  5,77,  7,25,  6,94,  4,43,  2,13, 18,40, 15,59, 14, 3, 19,80,  8, 7, 12,98, 
    17,56,  8,12, 13,74,  7,42,  4,98,  0,75,  6,18,  9,98, 16,20, 18,72, 11,34,  5,74, 10,10, 12,98,  2,12, 19,95, 15,33, 14,69,  3,93,  1,81, 
    17,73,  2,38,  7,25, 16,92,  6,38, 12,91, 14,95,  9, 2,  3,79, 18,41,  0, 3,  4,99,  5,83,  8,18,  1,12, 19,71, 10, 4, 11,66, 15,20, 13,53, 
     0,61,  7,24, 16,24, 12,22,  3,85,  6,56, 19,98,  2, 5, 10,29,  9,73, 18,27,  8,99, 13, 4,  5,99, 11,63,  4,25, 15,61,  1,51, 17,84, 14,30, 
    10, 5, 18,17,  4,40,  5,88, 12,30,  6, 3,  9, 1,  1,96, 11, 9, 13,94,  8,69,  7,72, 17,90,  0,14,  2,41, 14,50, 19,69, 15,38, 16,12,  3, 1, 
    14,55,  0,19,  5,61, 11,61,  9,97, 19,76, 10,38, 15,69,  2,24,  3,62,  4,24, 18,94, 17, 3, 13, 5, 12,84,  7,43,  6,73,  1,76, 16,47,  8,91, 
    11,85,  6,98, 18,68, 14,57, 16,63,  0,58, 17,74, 10,52,  9,59,  2,47,  7,73,  4,79, 19,48,  5,38,  8,88,  1,85, 12, 4, 15,44, 13,37,  3,75, 
    18,44, 13,32, 10,38, 12,93,  1,40,  9,56,  0,80,  7,90,  2,74,  5,82, 16,59,  6,91, 17,40,  8,26, 14,74,  3, 7,  4,49, 11,88, 19,60, 15,35, 
    14,75,  2,73, 19,13, 10, 4, 11,77, 16, 5,  9,57,  7,98, 15,60,  1,99,  5,12, 13,14,  4,25,  8,86, 18,13,  0,93,  3,41, 12, 1,  6,53, 17,54, 
     0,33, 18,75,  8,97,  9,31, 12,84, 17,49, 16,51, 19,30, 15,62, 11,67,  2,84, 13,45,  3,48, 10,62,  5,64,  7,87,  6,14,  4,76,  1,42, 14,71, 
    18,74, 11,98,  9,11, 14,96,  4,39,  0,31, 16,54,  3,49,  8,51,  6,40, 13,21, 15,19,  7,44,  2,76, 10,64, 12,43, 19, 9, 17,30,  5,66,  1,17, 
    16,31,  3,77,  9,92,  6,27,  2,71, 18,82, 11,36,  1,33,  4,48,  0,91,  5,49,  7,39, 12,91, 15,47,  8,74, 14,17, 13,62, 19,28, 10,91, 17,58
  };
  // Taillard 30x20 instance 1
  const int tai_30_20_1[] = {
    30, 20, // Number of jobs and machines
     4,11, 10,45, 12,34,  5,61,  3, 8,  8,97, 19,59, 15,72,  6,82,  0,57, 11,87, 13,61,  1,90, 16, 4, 17,17, 18,69,  2,95, 14,15,  7,97,  9,93, 
     6,57,  1,64,  2,15, 13,19, 11,14,  3,54, 12,71, 14,29, 10,17, 19,43,  7,81, 18,87, 16,65, 17,62, 15,80,  5,75,  0,19,  4,48,  9,33,  8,68, 
    17,71, 15, 1,  8,90, 16,81,  1,84, 10,19, 13,75, 14,83,  6,25, 12,69,  0, 1,  9,80,  5,35, 18,76,  2,37,  4,23,  3,13, 19, 4, 11,81,  7,20, 
     7,16,  1,91,  2,22, 17,28, 16,89,  8,99,  9,69,  4,22, 15,85, 14,25,  6,60, 18,33, 13,17,  3, 6,  0,94, 11,56, 19, 8, 12,77,  5,54, 10,82, 
    10, 3,  1,51,  7,43,  3,21, 17,66,  0,71,  2,17, 18,98, 12,73, 16,76,  6,93, 13,88, 11,61,  8,79, 15, 9, 19,18,  9,31, 14,80,  5, 4,  4,32, 
     4,44,  8,97,  3, 7,  9,54, 12,12,  2,68,  6,26, 18,42,  5,19, 19,92,  1,57, 11,71, 17,67,  0, 2, 13,49, 16,40, 14,51,  7,27, 15,35, 10,22, 
    17, 5,  4,55, 13, 2, 19, 6, 15,65,  3,42,  2,19,  1,64,  7,51, 16, 4,  8,13, 10,46, 12,52,  6,38, 11,15,  9,87, 14,74, 18,64,  5,80,  0,91, 
    10,92,  1,39,  0,24, 17,71, 18,12,  7,37, 16,64,  6,17, 15,95, 12,52,  2, 9, 11, 3,  4,87,  8,46, 14,71,  5,29, 19,22, 13,62,  3,43,  9,51, 
    17,78,  0,91,  9,26,  7,81,  4,43,  2,43,  5,93, 18,35, 11,36, 12,74, 14,18, 13,30, 19,15,  3,64,  8,90, 10,75,  1,37, 15,35,  6,39, 16,87, 
    11,14,  1,21,  9,74, 16,30, 12,62,  3,70,  6,87, 13,29, 10,86, 14,88,  8,24, 19,54,  4,11, 18,15,  0,21,  5,29, 17,57, 15,75,  2,57,  7,43, 
    19,40, 18,34, 14,46, 10,97, 13,67,  5,59,  3,65, 11,47,  8,20,  7,22, 16,15,  0,66,  6,20,  4,40,  2,72, 12,73,  9,50, 15, 4, 17,88,  1,44, 
     5,33, 18, 9,  6,84,  9,70, 17,56, 12,60,  3,16, 14,84, 15,13,  0,47, 19,65,  4,76,  2,51,  1,34, 10,53,  8,63, 16,14, 11,84, 13,78,  7,92, 
     2,67,  0,18,  5,66, 18,37, 19,65,  9,92,  7,30, 10,57, 11, 1,  4,16,  8,89, 15,36, 17,30,  1,49, 14, 7,  6,73, 12,20, 13,26, 16,29,  3,42, 
    10,99, 12,72,  4,22,  8,79, 13,60, 17,28,  2,59, 19,95, 15,84, 16,49,  3,86,  0,37,  6,10,  5,68,  1,70, 11,20, 18,71, 14,23,  7,71,  9,51, 
     1,39, 16,88, 19,82,  0,41, 17,99, 15,45,  2,11,  9,48,  3, 2,  6, 8, 10,88, 18,95,  7,64, 14, 7, 13,62,  8,19, 12,61, 11,60,  4,45,  5,32, 
     2,81, 14,18,  9,77, 16,33,  3,17,  0, 9,  4, 5, 12,76, 13,75, 19,65, 17,11, 15,69,  8,17, 18,66, 11,36,  7,23,  6,75,  1,64,  5,14, 10,42, 
    17,47,  8,51, 19,60,  7,94,  4,15, 18,13, 12, 8, 13,16,  3,61, 11,72,  6,69,  9,17,  1,44,  5,84, 10,97, 15,93,  0,91, 14,60,  2,99, 16,57, 
    13,28,  2,70,  6,42, 14,96, 18,14,  7,81,  8,57,  0,16, 16,45,  1,44,  3,40, 10,11, 19,70,  4,97, 12,20, 11,80,  5,24, 15,27, 17,55,  9,13, 
    15,92, 19, 4, 11,31,  0,76,  4,91, 10,66,  7,59,  1,97,  8,15,  6,27,  9,15, 18,62, 14,82, 13,94,  3,55, 12,52,  2,77,  5,39, 16,38, 17,53, 
    17,17,  8,99,  4,47, 10,82, 12,14,  0, 2, 11,82,  9,69,  7, 6, 16,89, 18,66, 19,39,  1, 9, 13,90,  3,91,  6,63,  2,13, 14,34, 15,36,  5,81, 
     8,99,  1,68, 11,56, 19,70, 16,72,  5,77, 17,51,  7,64,  2,66, 15,57, 12,74,  0, 9,  9,72,  3,94, 13,63,  6,21,  4,39, 10,23, 14,80, 18, 8, 
    16,67, 13,22,  0,59,  1,37, 10, 6, 15,64, 14,17,  8,50, 17,45, 18,30, 19, 7,  2,78,  4,72, 12,36,  7,23,  6,94,  9,25, 11,74,  3, 6,  5,97, 
     7,42,  6,90,  4,28, 17,19, 15, 7, 14,97, 19,82,  8,41, 10,69,  0,47,  3,76, 12,88, 16,11,  5,68, 13,70,  9,31, 18, 8,  2,81,  1, 3, 11,84, 
     9,62,  1,34,  4,98, 11,65, 17,12, 16,66, 12,32, 14,60,  6,12,  2,85, 15,73,  5,55, 10,97,  0,24,  8, 9, 13,26, 18,92,  3, 3,  7,41, 19,83, 
    12,12,  3,93, 14,74, 10,20,  0,33,  4,89, 11,41,  5,96, 15, 4,  9,99,  2,47,  6,23,  8,12, 13,91, 18,25, 17,83,  1,34, 16,83,  7,70, 19,27, 
    13,99,  8,50,  4,17,  6, 9,  3,72,  7,91, 19,37,  2,39,  5,72,  9,31, 18,72, 11,97, 10,40, 16,43,  0,96,  1,51, 14,29, 12,21, 17,18, 15,50, 
    10,55,  0,41,  1, 4, 13,75, 12,86, 11,59,  5,44,  8,73, 19,66,  2,70,  3,79,  7,85,  4,51,  6, 5, 17,35,  9,17, 15,30, 16,35, 14,34, 18,91, 
    16,97, 19,32, 13,41,  3,33, 15,23,  1,39,  8,74, 14,49, 12,69,  2,28,  5,55, 17,60,  0,61,  9,84, 11, 2, 10,84, 18,17,  4,73,  6,26,  7,91, 
    11,21,  4,51,  8,99, 13,79,  5,21,  3,48, 18,44,  1,67, 17,48, 14,96, 12,19,  9,39,  6,56, 19,76, 10,16,  2,40,  0,69,  7,93, 15,15, 16,52, 
    16,45, 11,22, 14,89,  8,42, 19,43,  5,99, 17,91, 12,34,  3,43, 15,68, 13,76, 18,55,  9, 1,  6,73,  1,56,  0,89,  7,13, 10,99,  4,82,  2,72
  };
  // Taillard 30x20 instance 2
  const int tai_30_20_2[] = {
    30, 20, // Number of jobs and machines
     3,86, 17, 5, 14,21, 10,67,  5,87, 12,90, 18,21,  8,87, 15,82,  4,68,  1,25,  7,10,  9,58,  6,65, 16,20,  0,34, 13,12,  2,35, 11,63, 19,41, 
     8,91,  7,80, 12,38, 14,79,  1,66,  4, 6, 17,21, 19,89,  9,50, 15,93,  0,52,  3,33,  2,82,  6,51, 11,90, 16,55, 10,99,  5,75, 18,22, 13,58, 
    18,59, 14,22,  1,10, 11, 1,  0,75,  6, 1, 12,35,  4,15, 15,39,  5,28, 13,29, 17, 8,  9,65, 16,45,  8, 5,  2,90, 19,18,  3,11,  7,39, 10,70, 
    15,20,  1,39,  4, 2, 11,32,  3,44,  2,85, 17,30, 10,68, 14,67, 13,57, 16,14,  7,75, 18,71,  0,41, 12,36,  5,33,  8,72,  9,32,  6,92, 19,17, 
     5,82, 10,71, 15,55, 13,28, 16,73, 19,12, 18,18,  2,41,  4,78,  7,71,  8,26, 17,97, 11,23,  9,65, 14,54,  6,88,  3,94,  0,28, 12,22,  1,95, 
     9, 5, 16,29,  1,73,  5,69,  6,51, 11,70, 13,24, 14,89,  2,21,  0,89,  4,83, 17,14, 15,61, 19,12, 10,97, 18,57,  8,61,  3,61,  7,19, 12, 3, 
     2,43,  6, 4,  7,32, 14, 4,  4,96, 12,34, 15,21, 16, 2, 13,33,  5,77,  1,62, 10,39,  0,89, 17,90,  9,90, 18,42,  3,16, 19,73,  8,75, 11,57, 
     8,78, 14,63, 13,26, 16,48, 10, 9,  7,26,  2,55, 19,93,  0,15,  6,85,  5,39, 12,87,  4,66, 11,54,  1,68,  3,30, 18, 7, 17,52,  9, 2, 15,31, 
     3,55,  0,87, 14,10,  4, 5, 15,48,  6,78,  8,87,  5, 8, 17,70,  9,69, 13,57, 16,85,  1,58,  2,74, 12,92, 10,77, 18,54, 19,43,  7,28, 11, 6, 
     1,42, 19,71,  0,68,  7,77,  2,19,  6,12, 10,59,  4,74, 17,71,  5,22, 12, 7, 13,53, 14,99, 15,71, 18,88, 16,91,  3,22,  8,46,  9,80, 11,55, 
     9,77,  0,17,  1,79, 13, 1,  3,72, 16,88, 14,42,  2,83,  5,84, 12, 8,  7,40,  8,91, 19,66,  4,85, 18,43, 10,51, 11,94,  6,23, 15,84, 17,15, 
     1, 6, 14,41,  4, 5, 11,87,  2,46,  7,75,  3,49, 12, 6, 16, 1,  9,50, 13,88, 17,65, 18,10,  0,88, 10,46, 15,33,  5,47,  8,72,  6,48, 19,12, 
     0,56,  9,75, 10,53,  4,34,  2,73,  3,83,  7,72, 12,15, 11,28, 17,52, 14,49, 15,15, 13,81,  6,88,  8,11, 19,52, 18,48,  1,88, 16,18,  5,46, 
    17,68, 11,36,  5,34,  3,11, 14,63,  7,31,  1,30, 15,59, 10,85, 12,60, 13,78, 16,82,  2, 6, 18,88, 19,43,  0,66,  9,93,  8,82,  4,39,  6,16, 
     3,58, 19,48,  4,97, 10,67,  2, 3,  1,85, 11,36, 15,24,  0, 2,  5,37, 14,72, 17, 2,  8,25, 13,74, 12,46,  6,43,  7,62,  9,27, 18,77, 16,82, 
     9, 5,  0,93,  6,79, 14,40,  3, 4, 11,82,  8,73, 10,71,  2,61, 13,65, 15,74, 19, 2,  4,57, 18,78, 17,12, 12, 1,  1,83,  5,10,  7,85, 16,48, 
    17,75, 12,63, 18,16,  6,15, 14,42, 16,34, 13,27,  2, 3,  9,83, 19, 7,  7,12,  3,63,  8,94, 11,20,  0,35,  4,75,  1,52,  5,25, 15,98, 10,83, 
     3,39, 15,65,  0,21,  2,34,  4,66,  6,27,  9,81, 10,33, 14,29, 16,95, 11, 1,  5,64, 17,82, 13,61, 18,74, 19,51,  8,48,  1,99, 12,23,  7,57, 
     0,88,  6,93, 17,11,  4,90,  1,27,  2,63, 18,20, 12,51, 11,36, 16,76, 10,26, 15,10,  3,71, 13,74,  8,35, 14,48, 19,12,  7,36,  9,24,  5,10, 
     6,93, 19,56,  3,28, 13,57, 18,21,  4,59,  7,48,  1, 6,  9,16, 16,90,  8, 6, 17,49, 10,32, 14,82,  2, 3, 15, 4, 11,31, 12,25,  5, 8,  0,28, 
     8,68, 18,11,  7,99, 14, 3,  0,78, 11, 1,  4,39,  9,65, 13,19,  5,16,  3,11, 12,26, 17,10, 16,54,  2, 2, 15,69, 19,91,  6,39, 10, 1,  1,91, 
    15,10,  0,24,  8,55,  9,71, 13,99,  5,85,  3,58, 16,18, 10,11, 17,90,  1, 7,  7,88, 14,75,  4,97, 18,75,  2,11, 12, 8,  6, 6, 19,45, 11,78, 
    14,68, 17,57, 19,15,  5,36, 16,27,  6,26,  4,66, 10,38, 15,97, 18,55, 12,73, 13,23,  8,68,  2,19,  7,89,  9,46,  1,34,  0,39, 11,23,  3,60, 
    19,28, 13,20,  2,44, 17,81,  9,62,  1,66,  4,44,  0,52,  3,40, 11,89, 10,92,  8,27, 18, 6, 14,75, 16, 6, 12,96, 15,50,  7,73,  5,60,  6,31, 
     6,90, 14,55, 15,41,  7,20,  4,51, 16,44, 11,67,  0, 6,  1,82, 10, 5, 17,10, 19,63, 13,80, 18,39,  3,22, 12,48,  8,24,  5,66,  2,46,  9,91, 
     8,41,  6, 4,  4,34,  7,68, 15,58, 10,71, 18,57,  3,81, 13,62, 19,84, 14,57,  5,23,  0,31,  2,59, 11,18, 16,74, 17,60, 12,38,  9,70,  1,49, 
     4,53,  0, 6,  5,79,  8,84,  9, 3, 18,41, 14,28, 15,61, 10,43, 12,36, 13,68,  7, 8, 11,35,  3,73, 16,81,  2,93,  6, 1,  1,94, 19,96, 17,73, 
    18,92,  7,94,  3,54,  9,17, 14,11,  6,41,  0,55, 15,15,  8,87, 19,81, 11,62, 12,78, 13,28,  5, 8, 10,77,  4,82,  1, 1, 16,68,  2,84, 17,58, 
     3,82, 15,31, 11,12,  9,78, 16,83,  5,33, 12,39, 19,78, 13,33,  0,11, 17,91,  2,54,  8,26,  1,90,  6,71, 14,12, 18,28,  4,57,  7,99, 10,49, 
     7,37, 18,17, 16, 3, 10,57,  4,71,  3,82, 11, 9,  0,29, 17,17, 14,99,  2,96,  5,97,  9,10,  6,26, 19,36, 15,32, 13,14, 12,35,  8,34,  1, 8
  };
  // Taillard 30x20 instance 3
  const int tai_30_20_3[] = {
    30, 20, // Number of jobs and machines
     5,51,  0,93,  6,49, 16, 1,  2,52, 15,26, 19,74, 10,59, 12,44, 13, 8,  4,81,  3,95,  9,68, 17,57, 18,57,  1,40,  7,17,  8,92, 14,88, 11, 6, 
    17,75, 11,22, 16,11, 13,49,  1,31,  7,32,  4, 5, 14,51, 10,14,  8,43,  2,43, 19,24,  3,83, 12,67,  6, 2,  5,45,  0,75, 15,35,  9,50, 18,95, 
    15,80,  9,13, 18,36, 19,51,  1,63, 16,58, 17,30,  8,75,  0,72, 14,92, 13,13,  2,13,  7,92,  3,12, 12,76, 11,29,  5,64,  6,58, 10,26,  4,21, 
    13,91,  1,95, 19,51,  2,75, 10,89,  6,56,  8,74,  3,60,  0,86, 16,70,  9,97,  5,11, 14,61, 17,68, 15,43, 11, 5, 12,17,  4,18, 18,14,  7,93, 
    13,40,  3, 9,  2,80, 19,82,  1,67,  0,33, 15,84,  6,39, 18,48, 14,89,  5,95, 16,60, 17, 4,  9,99, 11,92, 10,52, 12,79,  7, 9,  4,89,  8,54, 
     6,55, 17,70, 14,95, 19,60,  7, 9, 12,82,  3,52, 18,30,  5, 6, 11,27,  8,57,  0,89,  1,63, 15,29, 16,55, 10,37, 13,66,  4,16,  2,87,  9,63, 
     0,44, 10,47, 15,90, 11,35, 17,79, 14,57,  5,58,  6,98,  8,62,  3, 8,  9,31, 16,94, 12,49,  2,90,  1,11, 19,63, 18,22, 13,44,  7,96,  4,86, 
     9,63, 10,80,  8,72, 13,83, 16,25, 18,55, 15,68,  3,42,  6,70,  5,64,  1,24, 11, 7, 14,45,  0,12,  7,17, 17, 8,  2,41, 12,88,  4, 7, 19,83, 
     4,68,  6,99, 19,37,  5,33,  2,72,  9,98, 16,92, 18,28,  7,14,  8,16, 12,99,  1, 9, 15,93, 13,25, 17, 8, 10,64,  0, 4, 14,74,  3,35, 11,37, 
    17,79,  1,34, 12,36,  5,83,  2,48,  3,23,  8, 2,  7, 5,  6,16,  9,76, 19,10, 15,95, 14,12, 10,94,  4,46, 18,53, 11,35, 16,73, 13,78,  0,55, 
    17,31, 15,75, 11,11,  0,92,  7,46,  6,84,  5,39,  9,17,  4,83, 12,87, 10,86,  2,93, 14,68, 16,67, 19,83,  3, 4, 13,96,  8, 3,  1, 7, 18,51, 
    13, 4, 14,50,  2,20,  5,74,  0,37, 11,95, 16,65, 17,83, 15,98,  9,25, 18,64,  6,90, 19,51,  7,61, 12,97,  3,70,  4,14,  1,13, 10,99,  8,83, 
     3,41,  5,81, 13,93,  0,78, 14,53, 12,66, 11,40, 16, 8,  2,63, 19,66,  8, 2,  9,36, 15,24,  4,61,  7,75, 17,27,  6,71, 18,23, 10,18,  1,60, 
    15,87,  5,29, 18,36, 17, 2,  6,18, 16, 2, 13,11, 12,47,  3,94,  2,92,  9,58,  0,93,  1,47, 14,90,  8,28, 10,54, 11,28, 19,84,  4,68,  7, 4, 
    10,23,  6,74, 19,95, 15,64,  4,21, 17,46,  8,86,  1, 8, 12,58, 18,64,  0,99,  9,29,  3,47,  5,64, 13, 6, 11,25,  2,63, 16,59,  7,96, 14,19, 
     3,75,  9,75, 16,76,  6,83,  7,22, 11,98, 14,85,  8,75, 18,11, 12,64,  5,21, 17,94, 19,46, 10,63,  2,78,  1,35,  0, 9, 15,16, 13,39,  4,28, 
    13,57, 18,66,  5,46,  6,84,  8,16,  0,19,  4, 1, 10,29,  7,65, 12,42,  1,87, 15,38,  3,88, 16,83, 19,86,  2,21, 11,38, 17,61,  9,29, 14,74, 
     5,66, 15,74,  1,43,  2,55, 19,86, 18,69, 12,11, 13,12, 16,61, 17,56, 14,56,  9,77,  0,80, 11,16, 10,13,  3,14,  8,14,  4,96,  6,88,  7,20, 
     8,52, 14, 1,  6,82,  3,57, 11,18,  4,94, 12,44, 15,81,  1,25,  0,75, 17,29,  7,74,  5,10, 10,24, 19,63,  2,42, 18,62, 13,98, 16,67,  9,72, 
    10,81,  0,95, 14,46,  2, 6, 16, 5, 19,18, 17,79,  6,43,  3,28,  8,27, 12,84, 11,83,  7,99, 13,60, 15,86,  9,21,  1,13,  5,28,  4,91, 18,20, 
    17,63, 14,56,  1,24,  4,43,  7,30, 16,22,  0,31, 18,64, 19,56, 13,62, 15,25,  8,85,  2,13, 11,76, 10,63,  6,51,  3,87, 12,21,  9,65,  5, 1, 
    14,54, 16, 1, 17,71,  5,76,  4,23,  8,90, 10,19, 12,97,  3,84, 19,27,  2,70,  9,38, 18,62, 13,94, 15,47,  0,22,  7,52,  1,21,  6,11, 11,97, 
     1,91, 14,67,  2,12,  8,75, 13,42,  6,38, 12,63,  3,92,  5,41, 18,14, 17,28, 11,84, 10,39,  0,49,  7,23, 19,58, 15, 9,  4,19, 16,17,  9,46, 
     7,89, 11,44,  3,61,  9,63,  8,95,  4,70, 18,49,  5,99, 14,44,  0,68, 10,86, 13,86,  1,11,  2,13, 15,17, 17,85, 19,62,  6,80, 12,37, 16, 2, 
    19,39,  6,42,  9,19, 16,81, 17,46,  8,87, 14, 7, 11,58,  7,27, 10,97, 18,53,  2,21,  3,69,  0,97,  1,64, 12,47,  4,11,  5,43, 15,67, 13,11, 
     2, 4, 16,13, 17,44,  6,27,  3,23,  4,25, 11,44,  5,39, 18,38, 14,31, 15,38, 19,95,  0,13,  9,19,  7,29, 12,37, 13,44, 10,77,  1,24,  8,39, 
    13,56, 11,91, 16,37, 14,36,  6,86, 15, 2,  1,39, 17,19,  0,90, 12,43,  5,72,  3,87,  2,37,  4,39,  7,90,  8,33, 10,73,  9,88, 18,34, 19,66, 
    10,56,  2,32,  6,48,  0, 6, 19, 9, 14,57,  7,21, 12,56, 18,37, 16,75,  5,40,  9,93, 15,97,  3, 5, 11,67, 13,24,  1,20, 17,15,  4,16,  8,21, 
    15,31, 19,30, 11,88, 17,45, 18,37, 13,38,  4, 3,  6,97,  8,40, 12,29,  3,24, 14,30,  1,29, 10,45, 16,51,  2,58,  5,82,  0,51,  7,85,  9,37, 
     0,38, 18,77, 19, 8,  6,48, 11,46,  4,89,  5,96, 13,50,  2,21, 12,38, 17,57,  3,26,  1,97, 16,70,  8,23, 10,18,  9,33,  7,34, 14,35, 15,69
  };
  // Taillard 30x20 instance 4
  const int tai_30_20_4[] = {
    30, 20, // Number of jobs and machines
    11,38, 18,65, 19,92,  9,13,  1,61, 10,56,  3,95, 13,77,  7,40,  5,23, 15,87,  0,96,  4,95,  6,51,  8,98, 17,44, 16,10,  2,57, 14,44, 12,28, 
     8,81, 15,37, 18,13, 16,48,  6, 7,  0,87,  2,12, 11,23, 13,83,  7,69, 10,26, 19,61,  9,16, 12,60,  3,79, 17,52, 14,84,  4,93,  5,73,  1,92, 
    17,70, 18, 1,  2,72,  4,36, 14,66,  7,65, 10,62, 12,98, 13,22,  0,65, 19,26, 15,89,  5,12, 16,52,  1,73, 11,52,  9,28,  6,60,  8,11,  3,26, 
     2, 4, 17,27,  4,65, 10,39,  9,93,  6,12, 12,92,  8,86,  5, 9, 18,87,  3,65,  7,79, 16,92, 11,41, 19,97, 14,45, 15,84, 13,89,  1,64,  0,37, 
     4,60, 11,89, 18,16,  9,24,  2,49, 12,93, 16,80,  5,35,  7,61,  6,46,  8,36, 15,68,  3,23, 13,13, 14,51, 10,25,  0,76,  1,46, 19,98, 17,58, 
     4,35,  6,18, 16,72, 18,86, 14,99,  2,52,  7,48,  9,98,  1,58, 15, 7, 10,26, 12,15,  5, 3,  8,37, 19,92, 13, 9, 17,63,  3,20,  0,91, 11,86, 
    19,56, 14,10, 11,62,  3, 8,  6,50,  9,19, 15,53,  4,69,  2,67, 12, 8, 17,10, 10,22, 13,40,  8,85,  0,44, 16,22,  7, 1,  1,90,  5,47, 18,59, 
     6,82,  9,83, 17,75, 12,89, 16,72,  5,39,  0,47,  8,39,  1,15,  3, 1, 14,64, 13,66,  7,17,  2,68,  4,43, 15,63, 18,96, 11,37, 10,64, 19,35, 
    10,58, 16,48, 17,19,  5,17, 15,33, 18,29, 14,46,  2,81,  0,11,  1,88,  4,58, 13,70,  7,99, 12,96,  9,90,  6,46,  8,69,  3,92, 19, 4, 11,45, 
     6,74, 11,78, 15,79, 17,44, 14, 2,  9,63,  7,68, 10,57, 16,33, 19,90,  8,69,  1,91,  4,35, 13,80,  5,26,  0,44,  3,91, 12,27, 18, 2,  2,61, 
    10,59, 11,46,  7,81, 14,42,  5,53,  2,44, 19,21, 15,45,  1,91, 12, 4,  8,76,  0,18, 16,72, 13,78,  9,20,  4,44, 17,52,  3,37, 18,68,  6,33, 
    19, 2,  9,63,  0,82,  3,37, 14, 3,  7,53, 13,89,  6,31, 11,63,  8, 6, 15,98, 10, 2,  4,23, 12,38,  1,87,  2,91, 18,60, 17,55,  5,93, 16,38, 
     6,74, 16,85, 10,55, 13,52,  9,87, 18,25, 14,85,  4,33,  1,42,  8,65, 17,59,  5,91,  2,91, 12,16,  3,30, 19,62,  0,70,  7,14, 15,35, 11,19, 
     4,16, 11,23,  5,70,  0,41, 15,12, 12,99, 13,26, 19,43, 14,14,  3,91, 16,50, 10,78,  9, 1,  1, 2, 18, 4,  6,80, 17,14,  8,63,  7,55,  2,14, 
     1,86, 12,32,  3,56, 15,81, 11,52,  2,14,  5, 7,  8,74, 16,33,  9,69, 17,23,  7,68,  4,45, 13,19,  6,38, 14,35,  0,21, 10,42, 19,86, 18,98, 
    19,33, 12,51,  7,96, 14, 5, 13,56, 10,90,  2,50, 11,41,  3,34,  0,93, 16,61, 17,67,  9,60,  1,31, 18, 5, 15,41,  8,85,  5,58,  6,57,  4,10, 
    16,25, 19,92, 12,17,  9,94,  3,67,  5,60,  6,71, 17,28, 13,70,  4,97,  8,56,  7,29,  1,56, 10,41, 14,57,  0,70, 11,26, 15,50,  2, 2, 18,44, 
     7,27,  6,48,  0,85, 19,17,  9, 1,  3,86, 16,88,  8,43, 11,58,  4,82, 12,51,  2,59, 13,38, 17,99, 18, 7, 15,49,  1,88, 14,56,  5,80, 10, 1, 
    12,61,  9,48, 19,90, 14,59,  7,80,  8,44,  0,26, 13,44, 16,86, 11,31,  6,72,  3,29,  1,68,  2,29,  4,49,  5,23, 10,59, 15,61, 18,70, 17,49, 
     1,37,  4,45, 18,24, 11,88,  0,18, 16,33, 12,42,  8, 4, 13, 7,  7,69,  2,68, 19,39,  3,87,  5,61,  9,42, 15,16, 17,43, 14,83, 10, 6,  6,36, 
    10,91, 16,35,  3, 9,  5,98,  4,49,  7,96, 11,68, 19,81, 15,10, 14,58,  9,21,  8,90,  6,26, 18,36, 12,91,  0,52,  1, 9,  2,49, 13,15, 17,80, 
     5,11,  4,78,  7,59,  8,47,  0,11, 11,24,  1,55,  3,87, 17,28, 14, 2, 16,23, 19,38, 15,71, 13,69, 10,97,  6,74, 12,43,  2,57,  9,44, 18,23, 
    13,13, 14,54, 16,19,  5, 3,  0, 4,  7,13, 18,77, 12,74,  1, 2,  3,66, 19,81, 17,60, 11,38,  4,90,  2,67,  9,34, 15,27,  8,57,  6,72, 10, 7, 
    14,29, 16,69, 19,13, 15,96,  7,90, 11,24,  4,90,  9, 3, 10,57,  3,83, 18,78,  6, 4, 13,24, 17,65,  2,44,  0,21,  5,56, 12,73,  1,93,  8,97, 
     8,53, 13,13,  6,18,  5,33,  1,79, 19,45, 14,17, 17,47,  9,45,  0,79, 12, 7, 11,89,  3,51,  4,32,  7,26, 10,32, 15,43, 18,62, 16,31,  2,14, 
     0,63, 19,56, 12,68, 16,49, 10,40,  5,51, 14, 3,  8,87,  7,63,  9,52, 18,95,  1,56, 11,97,  6,30, 17,99, 15,39, 13, 6,  2,76,  4,34,  3,73, 
    12,68, 14,31, 11,59,  6, 6,  0,30,  9,58,  3,73, 13,62,  4,71,  1,96, 18,23, 15,71,  8,20,  5,11,  2,50,  7,92, 10,62, 16,67, 17,10, 19,65, 
    18,98, 13,83,  7,89, 15,64,  1, 4, 11,27,  0,79, 14,25,  2,78,  3,36,  8,52, 10,41,  6,21,  4,62, 12,78, 17,92,  5,92, 19,88, 16,80,  9,64, 
    11,88,  5,78,  7,10, 10,14,  8, 8,  1,18,  2,10,  6,37, 14,49, 12,27, 17,94, 13,95,  0,37,  4,23, 16,15,  9,87,  3,54, 19, 1, 15,74, 18,40, 
     0,21,  1, 3, 19,32, 10,51, 16, 9, 14,76,  5,23,  6,73, 12,53,  3,81,  7,74,  4,92, 18,69, 17,56,  9,93, 15,52,  2,83, 13, 1, 11,17,  8,46
  };
  // Taillard 30x20 instance 5
  const int tai_30_20_5[] = {
    30, 20, // Number of jobs and machines
    19,49, 12,91, 14, 1, 10,37, 15,32,  7,69, 11,56, 17,65,  1,45,  5,66,  8,17,  0,72, 18,38,  2,64,  3,20,  4,68,  9,71, 13,51,  6,17, 16,26, 
    10,59,  5,43, 11,90,  8,51, 16,96,  6,62, 19,35, 15, 6,  0,54, 13,81,  1, 3, 17,80,  3,94,  7,39, 18,37,  4,21,  2,52, 14,51,  9,36, 12,89, 
    15,57, 19,90, 10,34,  5,37,  6,60,  7,51,  3,27,  9,29,  1,53, 16,20, 17,45, 11,16, 14, 2, 12,24,  4,34, 18,18,  2, 2,  8,75, 13,78,  0,46, 
    13,33,  9,15, 14,68, 18,19,  1,43, 11, 7, 19, 2,  2,19,  3,15,  4,58, 10,80,  5,48, 12,49, 17,82,  6,63,  8,26, 16, 4,  0,38, 15,62,  7,41, 
     3,82,  2,63, 10,72,  8,47,  1,56,  4,89,  5,71, 15,91, 12,75, 11,93, 13,59,  7,58,  0,20, 16,84, 17,63,  9,50,  6,48, 19,85, 14,39, 18,45, 
    19,56, 11,32,  6,34,  9,30,  7,40, 18,67, 13,30, 14,49, 15,17,  0,17, 16,15,  8,58, 12,47,  3,15, 10,21,  1,74,  5,85, 17, 7,  2,41,  4,79, 
    15, 5, 10,76,  5,48,  9,58, 19,23,  0,44,  8,63, 18,56, 12,59, 13,72,  6,34,  4,82, 17,86, 14,43,  7,70,  2,41,  1,97, 16,57,  3,38, 11,24, 
    19,59,  5,34, 14,66,  3,20,  4,13, 12,88, 15,95, 13, 6,  6,68, 18,41,  7,51,  9,20, 11,80,  1, 1, 16,43, 10, 6, 17,37,  0,34,  2,72,  8,62, 
    12,55,  5,59, 19,53, 10,74,  8,77, 11,72,  0,76, 17,95,  4,66,  6, 2, 13,26,  9,53, 16,41,  3,28,  2,26, 14,69,  7,74, 15,60,  1,79, 18, 5, 
     9,63, 15,94, 12,86,  5,97,  3,94, 13,82, 19,88,  8,25, 16,10,  4,72, 18,39, 17,49,  7, 5,  2,38,  6,85,  0,42, 10,89,  1,22, 14,34, 11,18, 
     1,62, 19,65, 18,25, 10,74,  6,48,  2,73, 15,92, 14,69,  7, 2, 17,17, 11,79, 13,81,  5,55, 12,37, 16,79,  4,95,  0,94,  9,31,  3,16,  8,44, 
    11,53, 19,14,  2,77, 17,92, 14,32,  7,47, 15,93,  4,41,  5, 6,  0,71,  1,69,  8,70,  3,96, 10,11, 13,39, 16,10, 12,15,  6,39,  9,98, 18,29, 
     6,25,  5,80,  3,38, 11,44, 13,78, 14,39,  9,29, 12,40,  8, 5,  0,47, 19,61,  1,47,  2,63, 18,80,  4,46,  7,76, 15,15, 17,54, 10,21, 16,25, 
     2,53,  6,99,  4,44, 12,54, 17,89, 16,75,  0,26, 10,58,  7,30,  3,17,  5, 3, 18,17,  1,14,  8, 1,  9,60, 19,49, 15,76, 11,83, 14, 9, 13,32, 
     9,22,  5,10,  1,94,  7,54, 11,91,  0,99,  8,91, 12, 8,  2,39, 19,59, 10, 3,  6,55,  4,29, 15,37, 13, 6, 18,64, 14,81, 16,84,  3,29, 17,95, 
    14,72, 11,67,  5,29, 10,57,  4, 9,  3,40,  1,78, 13,99,  7,53, 15,66,  2,85, 17,31,  0,42, 19,83, 18,46,  8,27,  9,47,  6,60, 16,67, 12,47, 
     2,45, 12,44,  5,83, 13, 8, 17,60,  4, 2, 14,10,  7, 3,  6,29, 11, 9, 19,37,  0,29, 16,22, 10,97, 15, 6,  3,41,  9,81, 18,74,  1,62,  8,95, 
     5,92,  4,37,  2,32, 15,28, 10,29,  3,62, 14,93,  7,30, 19,92,  0,45, 11,35, 17,77,  8,46, 12,47, 16,46,  9,81,  1,43, 13,43,  6,30, 18,18, 
     4,49,  9,86, 13,20,  5,90,  8, 4,  6,44,  7,72, 17,22,  0,90, 12, 1,  1,30,  3,71, 16,77, 15,62, 19,48, 10,25,  2,89, 11, 6, 18,95, 14,44, 
    14,62,  3,63, 16,92, 10,16,  6,20,  2,69,  5,65,  0,81, 13,21, 12,54,  9,97,  7,79,  8,37, 19,97, 18,93,  1,55, 17,70, 15,60, 11,36,  4,57, 
    17,76, 13,54, 16,76, 15,36,  5,93,  4,67,  3,35, 11,37,  0,44,  7,88, 10, 3,  2,22, 12,73, 14,65,  1,26,  8, 3, 19,99, 18,78,  9,38,  6,30, 
     2,77,  9,82, 17,66,  4,75,  7,95,  5,72,  0,76, 18,52, 19,72, 13, 4, 11,70,  1,76,  8,61, 15,88, 16,39, 12,36, 10,88,  6,69, 14,58,  3,14, 
    12,65,  4, 8, 18,90,  1,57, 19,73,  5, 2, 14,62,  8,48,  0,76, 10,87, 15,53,  6,23, 17,76,  2,74, 11,99, 16,34,  3,71, 13,27,  9,87,  7,46, 
    13,76,  6,54, 11,75,  5,69, 17,44, 16,26, 19,63, 10,75,  0,78,  4,78,  3,39,  1, 7,  9,73, 18,27,  2,55, 14,23,  7,55,  8,29, 15,56, 12,36, 
    14,17,  9,42, 13,56, 11,84,  2,44,  5,74,  6,62, 17,55,  8,55,  4,31, 12,71,  0,11, 15,16,  1,29, 18,50, 19,72,  3,64,  7,42, 16,28, 10,70, 
     9,76, 18,56,  6,78,  8, 2,  1, 6,  4,71, 16,19,  7,69, 12,30, 10,87, 13,57, 17,33,  5,87,  2,68,  0,24, 11,31, 19,56, 15, 5, 14,19,  3,82, 
     2,64, 19,36, 15,19,  8,90, 14,65,  3,80,  4,26,  1, 2,  6,52, 11,72, 17,17, 12,29, 13,60,  5,16,  9, 6, 16,91, 18,79,  7,43, 10,99,  0,26, 
    19,82,  1,80, 17,60,  6,93, 13,54,  2,24, 12,87,  8,63,  0,59,  9,85, 11,13,  3,32, 10,93,  4,33, 15,15,  7,48, 16,72, 18,23,  5,97, 14,76, 
    17,61, 14, 6,  6,87,  5,74, 18,67, 16,44, 13,63,  0,12, 19,81,  9,61,  2,26,  7,23, 10,76,  8,93,  4,97,  1,75, 12,76, 15,46,  3,66, 11,54, 
    19,77,  7, 6,  8,62,  0,22,  4,81,  3,44, 18,28,  9,97,  5,16,  2, 7, 12,34, 11, 3, 13,93, 17,12, 15,35,  6,88, 14, 9, 10,93,  1,87, 16,51
  };
  // Taillard 30x20 instance 6
  const int tai_30_20_6[] = {
    30, 20, // Number of jobs and machines
    11,66, 19,38, 16,15,  7, 7, 12,93,  1,57, 10,92,  8,56,  6,93, 18,60,  2,40, 13,74, 17,59, 14,72,  0,21,  3,24, 15,24,  4,57,  5,74,  9,69, 
     4,88, 19,70,  8,42, 17,14,  0,66,  5, 8,  1,32,  6,77, 11,11, 12,30, 10,48, 13,97,  2,89,  3,82, 15,81, 18,89, 16,76,  7,87, 14,44,  9,26, 
    19,53, 10,82, 14,37, 11,85,  3,31,  2,81, 13,24,  1,67,  0, 3, 12,12,  9, 8, 18,72,  4,87,  5,69, 16,19, 17,35,  7,97,  6,46,  8,73, 15,12, 
     2,31, 15,50,  6,74, 19,12, 17,52, 14,89, 12,67, 13,52,  1,21, 11,11,  5,31,  4,69,  9,35, 16,99, 18,24, 10,93,  8,87,  7,15,  0,20,  3,66, 
    17,14,  8,90, 10,14, 16,68, 19, 6,  4,79,  2,14,  6,15,  0,17,  3,68,  9,19, 12,46, 11,72,  7,33,  1,20, 15,12, 14,56, 13,97, 18,26,  5,36, 
     5,71,  6,95, 13, 2, 10,81, 19,93, 16,21,  9,98,  8,64, 15,30, 12,40,  4,67,  7,65, 14,16, 11,33, 17,51,  3,49, 18,68,  2,89,  0,92,  1,35, 
     2,28, 19,33,  4,81,  8,94,  9,11,  6,61,  7,36,  5,33, 11,92,  1,83, 13,14, 14,97, 17,36, 18,61, 10,72,  3,65, 12,26, 16,14,  0, 4, 15,80, 
    16,70,  7,96,  1,35,  6,11,  5,99, 12,83,  4,39, 10,43, 14,87, 15,19,  8,14, 18,46,  0,91,  3,17,  9,32, 11,32, 17,38, 13,46, 19,96,  2,22, 
    12,69,  0,36,  2, 8,  4,21,  1, 2,  6,32, 14,75, 16,81, 19,47,  3,64, 17,80,  5,75, 11,49,  8,41,  9,82, 10,25, 13,89, 15,33,  7,29, 18,47, 
     6, 9, 17,36, 13,22, 19,59, 16,32, 18,33, 11,72, 10,27,  3,45,  2,19, 14,49,  8,35,  5,57,  7,87, 15,59,  9,49, 12,83,  4,52,  0,66,  1,61, 
    12,24, 18,53, 11,61,  7,31, 17,14, 10,19,  6,26,  9,91,  3,53, 19,41, 14,77,  1,66,  4,81, 15,32,  0,29,  2,83, 13,13,  5,31,  8, 6, 16,21, 
     0,45, 18,89, 11,29,  3, 7, 15,47, 10,47,  5,25,  4,45,  7,60, 13,28,  8,83, 19,68, 17,12,  2,37, 14,69,  1,46,  6,47, 16,91,  9,20, 12,45, 
     3,23,  4,55,  7,60,  6,52,  5,17, 15,75,  8,54, 13,76, 17,35, 12,61,  9,51, 10,84, 18,38,  2,94, 14,30,  0,14, 11,78,  1,29, 19,99, 16,88, 
     5,14, 12,22, 14,99,  6,59,  3,89, 10,44, 13,98,  7,56,  8,22, 17,33, 15,41, 18,46,  4,65,  0,85,  1,38, 16, 3,  9,19, 11,39,  2, 5, 19,72, 
     7,12,  4,27, 10, 8, 13,13, 11,26, 16,35, 18,33, 12,49,  8,29, 15,39, 19,37,  1, 1,  0,74, 17,22,  2,38,  3,31,  9, 6, 14,98,  6,86,  5,69, 
     0,72, 17,74,  4, 6, 15,58, 11,27,  3,21, 14,19, 13,97, 10, 8,  7,70,  8,49,  1,25,  9,39, 16,95,  5,71, 18,81, 12,88,  6,11, 19,93,  2,71, 
    19,11,  1,82, 11,82, 17,80,  5,74, 18,60,  7,43, 10,75, 12, 4,  2,64,  0,52,  3,73,  4,77, 13,80,  6,89,  8,66, 16,28,  9,62, 15,82, 14,42, 
     3,11, 12,16,  1,12, 15,72,  7,35,  6,83,  8,73,  9,41, 13,23, 16,63, 19,16, 10,37,  4,28, 17,88,  5,75, 18,51, 14,23,  2,40,  0, 4, 11,78, 
    11,53, 10,30, 15,85, 12, 8,  7,67, 19,35,  9,58,  4,29,  8,54,  2,16,  1,58,  5,73,  6,15,  3,82, 17,76, 13,88,  0,71, 16,57, 18,63, 14,13, 
     0,34, 13,17,  9,36,  5,96, 15,84, 14,84, 17,29,  6,56, 11,83,  7,84, 12,52,  2,37, 10,41, 16,93,  1,79, 19,93,  4,37,  8, 1, 18,45,  3,33, 
    14,19,  2,79, 13,43, 16,43,  9,64, 19, 2,  7,14,  6,58, 18,47, 15,23,  4,93, 17,19,  0,57, 12,77,  5,32,  3,61, 11,27,  8,25, 10,52,  1,53, 
    16, 3,  9, 1, 17,73,  8,81,  6,88,  4,56, 19,58, 18,14,  7,88,  2,68, 14,16, 15,78, 12,48,  5,30, 10,68, 13, 5,  3,47,  0,28, 11,71,  1,19, 
     5,39, 19,72,  2,37, 16,33, 10,53,  6,95, 13, 8,  4,13, 11,23,  1,40,  3,15, 17, 6,  9,25,  8, 1, 15,22,  7,30, 18,10, 12, 7, 14,59,  0,14, 
     4,37,  0,98, 10,81,  2,73,  1,58,  8,27, 18,22,  5,39, 13,98,  7,35, 19,98, 14,73,  6,25, 15,73, 17,72, 16,79, 12,54, 11,94,  9,27,  3,30, 
     6,49,  5,63, 10,97, 11,87,  3,86,  7,81,  0,15,  8,92, 15,73,  9,76, 17,53,  4,75,  2,93, 19,70, 16,35, 12,13, 13,85, 18,95,  1,39, 14,57, 
    18,34,  9,42,  0,63, 11,73, 14, 6,  4,71,  1,76,  5,86, 19,97, 12,16, 17,54, 10,44,  6,49,  3,94, 13,92,  2,24, 15,31,  7,72,  8,35, 16,46, 
    17, 4,  0,72, 16,30,  4,47, 18,83,  1,23,  8,88,  5,72, 15,76,  2, 4,  3,10,  7,89, 19,75, 12,75, 11,24, 14,63, 13,76,  9,77, 10,36,  6,88, 
     4,80, 17,68, 13,65,  2,15, 15,36,  7,34, 10,94,  1, 7,  9,99, 16,44, 11,72,  6,12,  8,33, 18,77, 12,24,  0,57,  3,68, 14, 1,  5, 3, 19, 6, 
     6,90, 18, 3,  5,70,  2, 5,  3,72, 17,60, 19,32,  1,91, 14,42,  9,54, 12,18,  0,63, 15,54, 10,83,  4,92, 13,57, 16,96, 11,11,  8,98,  7,47, 
    10,77, 11,33, 17,66,  3,68,  6,99,  7,47,  5,52, 12,88, 14, 4,  1,71,  9,20, 18,29, 15,82,  0,11, 13,16, 19,57,  2, 4,  4,18, 16,29,  8,68
  };
  // Taillard 30x20 instance 7
  const int tai_30_20_7[] = {
    30, 20, // Number of jobs and machines
     6,59,  5,77, 15,73,  8,46, 13,99,  2, 7, 10,11, 17,75, 11,27,  0,22,  9,33,  1,70, 19, 9,  4,17, 16,33,  3,17, 12,40,  7,75, 18,15, 14,80, 
     2,16, 13,25, 11, 8,  4,41, 18,48, 12,88, 16,38, 17,61, 19,27, 14,78,  5,84,  3, 7,  1,16,  7,90,  9,66,  6,41, 15, 3,  0,47,  8,33, 10,57, 
    18,87, 16,14, 14,49, 13,90,  0,87,  7,29,  1,47, 19,68,  3,12, 12,68, 15,66,  6,58,  5,67,  2,89,  8,32,  9,89,  4, 2, 10,63, 17,70, 11,77, 
     9,10, 10,74,  5,56, 14,88, 18,77,  2,79,  8,69, 11,42, 12,12,  3,76,  4,78,  1,74,  6, 1, 19,16, 13,34,  7,60,  0,66, 16,71, 15,77, 17,84, 
     8,95,  3,24,  7,86,  9,61,  5,67,  1, 4, 17,27,  4, 8, 14,13, 15,12, 13,43, 12,64, 16, 6, 10,50, 11,36,  0,46, 19,71,  6,81,  2,42, 18, 4, 
     6,82,  8,99,  9,34,  2, 4, 13,89, 14,84,  1,77,  3,51, 15,12, 19,72,  4,37,  0, 4, 18,18, 10,91, 12,99, 17,16,  5, 6, 16, 4, 11,77,  7,97, 
    16,37,  7,44, 12,81,  2,72, 13,13,  6,66,  5,52,  8,68,  3, 4, 18,14,  9,31, 15,91, 17,71, 11,86, 14, 4,  0,55, 19, 7, 10, 8,  1,89,  4,80, 
     9,34,  5,32,  2,55,  8,66, 10,18, 13,76,  4,32,  1,28, 11, 7, 17,75, 19,77,  3,24, 14,91, 16, 4,  0,72,  7,84, 15,50, 18,45, 12,25,  6, 6, 
    16, 6,  4,97, 15,68,  1,22, 11,82,  8,74,  3,12,  6,80,  9,79, 17,15,  0,48, 18,91, 10,51,  2,19, 12,74, 13,48, 19,68,  5,43, 14,13,  7,31, 
     3,82, 14,19, 15,80, 17,13,  8,35, 10,98,  6,68, 19,12,  0, 1, 18,15,  9,58,  1,94, 16,54,  5,74,  4, 9, 13,50, 11,82, 12,68,  7,23,  2,76, 
     2,79, 15,20,  4,74, 16,43,  7,88,  8,99,  1,46,  6,75, 18,67, 19,81, 10,94, 14, 6,  5,60,  3,93, 17,88, 13,39,  0,32, 11,88, 12,80,  9,30, 
    13,74, 11,53,  5,31,  9, 1, 17,19,  6,18,  7,38, 16,79,  0,46,  8,74, 15,82, 10,84, 18,27,  1,46,  2,11, 19,37,  4,97,  3,88, 14,25, 12,51, 
    16,59,  7,59, 13,55, 12,20,  2,92, 19, 1, 10,31, 14,61, 15,87, 17,10,  5,40,  1,35,  4,15, 11,86,  0,20, 18,43,  3,39,  9, 9,  6,38,  8,28, 
     2,26,  0, 2, 19,81,  8,64, 18, 9, 10,47, 17,28,  3,78, 13,64,  6,77, 14,16, 16,69, 12,50,  7,81,  4,31,  1,87, 11,42, 15,23,  5,46,  9,45, 
     5,61,  1, 7, 14,75,  9,72,  8,83,  3, 8, 11,63, 10,27,  0,81,  7,76, 13,57, 12, 7,  2,88, 16,62, 19, 5, 17,32,  4,25, 15,53, 18,43,  6,75, 
    17,12, 16,48,  4,71,  0,54, 15,49,  5,47,  3,37, 14,72, 12,39,  2,77, 10,94, 18,82,  8,49,  6,42,  1,87, 19, 2, 11,10, 13,58,  9,81,  7,41, 
    10,84,  4,36,  3,98,  1,10, 17,22,  0,53,  5,51,  8,95,  7,62, 12,82, 19,48, 13,10, 15,29,  9,68, 14,60,  2, 5, 16,41, 11,15,  6,84, 18,45, 
     3, 9, 16,40, 15,20,  5,39, 13,83, 11,28, 19,94, 12,68,  8,19,  6,25, 18,13,  7,63, 17,69, 10,17,  0,74,  1,95, 14,91,  2,89,  4,16,  9,35, 
    14,69,  0,80, 11,20,  5,99,  4,23, 12, 8, 18,43,  8,34, 10,35, 13,83, 16,41,  7, 5,  6,86,  1,16,  3,29,  9,92, 15,44, 17,54,  2,21, 19,81, 
     7,82,  4,97, 11, 5,  2,36, 15,40, 14,58,  5, 8, 19,59, 16,78,  1,18,  9,32, 13,34,  3,66,  8,25, 10,10, 12,36,  0,88,  6,50, 17,82, 18,35, 
     8,74,  6,42, 10,86, 15,22,  5,39,  3,45, 18,26,  1,63, 17,65,  9,70, 19,33,  4,39, 16,74, 13,75,  0, 8,  7,26, 11,25, 14,13,  2,72, 12,98, 
    10,25, 17,46,  6,61,  8,74,  7,40, 19,25,  2,42,  0, 5,  3, 2,  5,65,  4, 1,  1,77, 14,13, 16,42,  9,31, 18,45, 12, 7, 11,20, 15,95, 13,75, 
     7,50,  0,78, 14,72,  9,53,  1,67,  6,46, 11,95, 10,29,  2, 3, 17,31, 15, 8,  5,26, 19,60,  8,52, 18,35, 12,57,  4,57, 13,91, 16,91,  3,35, 
    18,26, 15,80, 16,71, 10,64, 12,57,  6,43,  2,72,  1,99, 17,87,  5,81, 13,15,  4,23,  7,73,  8, 7,  9,70, 19,98, 11,66,  3,47,  0,10, 14,73, 
     0,20,  6,55, 12,87,  4,10,  8,16,  1,59,  5,91, 17,82, 15,53,  2,67,  7,60,  9,34, 11,78, 13,66, 16,98,  3,39, 10,14, 18,65, 14,52, 19,54, 
    18, 3,  9,26,  6, 8,  4,42, 11,70, 19,17,  8,56, 10,31,  3,29,  0,88, 13,60, 15,81, 12,23,  2,23, 16,43,  5,29, 17,74,  7,29,  1,30, 14,63, 
     5,67, 10,66,  1,88, 14,78, 11,79, 18,37, 16, 6,  7,35,  9,61, 13, 3, 17,67, 15,51,  2,64, 12,69,  6,65,  3,90,  8,95,  4,11,  0,28, 19,50, 
     5,54,  6,52,  8,16,  3,39, 15,56, 19,51,  4,49,  2,70, 16,59, 14,66, 13,57, 10,74,  1,86,  7,83, 18,82,  9,65,  0,40, 11,89, 12,53, 17, 3, 
    18,68,  8,44,  1,62, 14,25,  4,69,  6,48, 15,68, 10,70,  7,61, 13,51, 17,74,  5,24, 11,54, 16,69,  3,69, 12,33,  2,61,  0,18,  9,36, 19,78, 
     6, 7, 13,26,  5,79,  8,65,  2,16, 18, 3, 17,71, 19,62, 14,42, 10,44,  7,73, 15,79,  0, 9,  9,61, 11,63,  4,12,  1,47,  3,67, 16,34, 12, 5
  };
  // Taillard 30x20 instance 8
  const int tai_30_20_8[] = {
    30, 20, // Number of jobs and machines
     8,17, 10,42,  5, 3, 13,77, 11,53, 17,65, 19,14, 18,14,  9,77, 15,22,  3,26, 16,53,  0,36, 12,66,  7,26,  2,56,  1,14, 14,41,  6,69,  4,85, 
    14,57, 18,93,  1,85,  2,20, 13,94,  9, 3, 16,59,  6,80, 19,40, 17,83,  7,67,  8,55,  3,25, 10,24,  0,74, 11,47, 15,37,  5,98, 12, 9,  4,84, 
     9, 2,  6,62, 13,35, 10,87,  5,37, 15,79,  2, 4,  8,79, 19,61,  1,35,  4,39, 18,26, 11,24,  7,17, 16, 8, 12,88,  0,39,  3,25, 14,92, 17,48, 
    14,51,  3,30, 10,79, 16,27, 18,25,  1,13, 17, 3,  0,23,  6,17,  8,22,  2,45, 11,13, 19,72,  5,52,  7,56, 15,56, 12,84,  9,16,  4,50, 13,64, 
     5,72, 16,80, 11, 4,  9, 7, 17,85, 10,30, 18,75, 15,47,  0,94, 19,11,  6,75,  4,63, 13,58,  2,63,  1, 4, 14,33,  3,47, 12,78,  7, 8,  8,20, 
     7,32,  9,82,  1,45,  2,14,  4,10,  6,60, 10,98, 18,95, 17,61,  8,88,  5,66,  0,79, 19,98, 15,44, 14,48, 13,27, 11,47, 12,31,  3,13, 16,50, 
     0,32, 12,53,  1,33, 14,70, 18,59,  6,41,  8,95, 17,65, 10,91,  2, 7, 19,19,  5,82, 16,93, 11,56,  7,44, 13,47,  9,32,  3,62, 15,52,  4,15, 
    16, 5, 14,44, 18,94, 11,20,  1,35, 10,75,  5,92,  9,30,  7,69,  2, 4, 12,99, 15,71, 17,18,  8, 1,  0,75,  4,44, 19,35,  3,37,  6,53, 13,96, 
    10,60, 19,54, 18,41, 15,45,  8,79,  0,19,  2,53,  9,91, 13, 1,  3,74,  6,16,  7,56, 12,75, 11,95,  1,90,  4,86,  5,58, 16,42, 14,79, 17, 8, 
     9,78, 14,56, 10,24, 19,60,  8,88, 12,47,  7,33,  6,11, 18,92,  2,72, 11,42,  0,88, 13,30, 15,57, 16,97,  1,25, 17,26,  4, 5,  3,62,  5,45, 
     3,95,  4,62, 18,53, 15,69,  6,45,  2,48, 16,49,  7,59,  5,37, 12,23,  9,94, 17,19,  0,79,  8,81,  1, 9, 10,66, 14,32, 11,17, 19,38, 13,59, 
     2,61,  4,73,  1,79, 15,25, 16,75,  3, 5, 17,76,  6,26, 11,69, 12,18,  7,21, 18,21,  8,16, 13,39,  0,15, 14,64, 19,98, 10,70,  9,54,  5,32, 
    16,46, 19,94, 10,33,  9,24, 14,31, 12,57, 18,57,  2, 8, 17,88, 15,55,  6,69,  7,51,  5,94, 11,43,  1,35,  0,61,  4,14,  3,30,  8,84, 13,79, 
    12,97,  3, 7, 17,59,  4,87,  8,57,  9,37,  2, 4, 11, 2, 13,23,  5,45, 18,73, 10,72,  6,98,  7,79,  1,61, 15,15, 16,80, 14,77,  0,15, 19,76, 
     7,53,  0,66, 18,42, 19,59, 15, 6,  2,60,  9,30,  1,59, 10,63,  6,61,  3,83, 11,14, 13,78, 12,90,  8,38,  4,88, 16,20, 17,23,  5,81, 14,64, 
     1,75, 19,38, 14,15,  7,48, 17,37,  0,92, 13,99, 11,37, 16,79, 12,28, 10,68,  9,20,  6, 6,  3,57, 18,79,  8,97, 15,76,  5,11,  4, 6,  2,95, 
    10,74, 17,45,  9,93, 16, 9, 18,58,  4,16,  2,27, 11,19,  5,19, 15,69,  8,82,  3,25,  7,31,  0,51, 12,85,  6,42, 14,10, 19,85, 13,85,  1,27, 
    12,30, 11, 5,  7,54,  9, 3, 19,63, 16,47, 17,59,  6,45, 15,63, 13,40, 10,10,  4,16,  1,42,  8,46,  5,66,  0,34,  2, 1,  3,15, 14,81, 18,69, 
    15,98, 17,89, 10,45,  4,11, 14,12,  1,49,  3,44, 18,98,  8,15, 16,79,  6,98,  2,48,  0,19,  7,90, 11,20, 12,20,  5,13, 13,78, 19,32,  9,39, 
     0,20, 11, 4, 17,65, 10,99, 15,56,  5,61, 12,45,  9,93,  6,32,  3,44,  4,62,  1,94,  7,57, 14,58, 16,44,  2,88,  8, 1, 13,65, 18,73, 19,64, 
    13,15,  6,71,  4,39,  8,31, 18,32, 12,80,  0,54,  5,38,  3,51,  9,50,  1,58, 14,96, 11,96, 16, 9,  2,65, 15,32,  7,19, 19,54, 17, 7, 10,10, 
     8,53,  6,19, 14,68, 12,99,  0,77,  9,12, 10,81,  2,96, 18,46, 19,56, 13,41,  5, 8, 17,93,  1,10, 11,75,  7,75,  4,85, 15,32,  3,80, 16,84, 
    12,96, 16, 9,  8,42,  4,52, 19,66,  9,80, 13,45,  6,91,  3,31,  2,40, 10,12,  5,60, 14,99, 11,57, 15,68,  1,44, 17,16, 18,55,  0, 6,  7,84, 
    10,98, 18,29,  8,75, 15,40,  6,81,  7,73,  2,70,  0,29, 11,85,  5, 3, 17,89, 12,12, 14, 1,  9,46, 13,30,  3,28,  4,82,  1,10, 19,18, 16,97, 
     6,21, 16,47,  4, 2, 15,63,  0,57, 12,25,  7,25, 10,80,  5,70, 13,44, 17, 7,  3,30, 14,62, 18,55,  1,68, 19,56,  8, 1,  2,25,  9, 5, 11,13, 
    13,41, 19, 6,  0, 7,  5,80, 14,93,  8,12, 10,54, 17,12, 15,38, 12,30, 18,68,  3,36, 16,19, 11,46,  6,71,  1,71,  7,94,  2,66,  9,99,  4,57, 
    16,57, 18,55, 11,46, 15,15, 17,61,  4,64,  9,19,  1,14, 10,49,  5,58, 13,54,  3,54,  8,50,  0,32, 14,40,  2,47, 19,70, 12,97,  7,50,  6,65, 
     7,53,  0,32, 18, 2, 16,85,  6,17, 13,94, 17,46,  5,83, 14,63, 11,67,  9,46, 19,84,  3,34, 12,22,  4,24,  8,70, 10,63, 15,14,  1,76,  2,67, 
    17,25, 16,83,  9,87,  1,50,  0,60, 15,63, 11,86,  5, 5,  3,11, 18,27, 12, 8, 14,32, 13,16,  2,49,  7,20, 19,42, 10,59,  8,13,  4,86,  6,38, 
     7,64,  1,20, 16,31, 17,14,  3,50, 13,93,  0,72, 19,74,  6,13, 10,42,  9,18,  8,25, 15,83, 18,33,  5,21,  2,92, 11,48, 14,60, 12, 4,  4,80
  };
  // Taillard 30x20 instance 9
  const int tai_30_20_9[] = {
    30, 20, // Number of jobs and machines
     2,96,  8,26,  6,33,  0,19,  4,43, 15,17, 16,26, 13,66,  5,84, 12,56, 10,83,  7,66, 14,74, 19,24,  1,85,  3,47, 18,88, 17,97,  9,41, 11,77, 
     0,70, 10,46, 13,90,  3,61,  2,24,  7,63,  1,95, 16,34,  9,47, 17,50, 18,62, 15,10, 11,66,  8,52, 19,49,  5, 4,  4,94, 12,38, 14,93,  6,84, 
     0,48, 19,60, 11,15,  9,25, 15,21,  3,99, 13,56, 18,32,  1,31,  5,36,  7,74,  6,72, 10,91,  4,29, 14,34,  8,50, 12,21,  2,36, 16, 1, 17,30, 
     7,50, 19,84, 10,74, 11,35,  9,86, 14,42,  6,31, 12,62, 16,82, 13,66,  5,39, 15,48,  4,98,  3,99, 17,48,  8,77,  1,31, 18,51,  2,44,  0,41, 
     0,90,  6,27, 11,30,  1,68,  3,25, 16,94, 19,66, 12,48, 10,47,  7,16,  5,90,  2,23, 15, 5,  4, 3, 18,10, 14,37,  9,74,  8,28, 13,25, 17,86, 
    17,32,  8,76, 19,29, 16,60,  0,60, 12,21, 13, 2, 14,65,  3,22,  2,36,  1,80, 10,61,  7,55,  9,84, 15,99,  4,25,  6,68, 11,80, 18,67,  5,50, 
    18,90,  1, 9,  9,28, 11,38, 17,36,  0,19,  2, 4,  6,46, 16,84, 10,71,  4,60, 14,23, 19,63, 12,77, 15,72,  7, 2,  3,63,  5,24,  8,60, 13,99, 
    14,96,  9,78, 11,79,  8,90,  2,63, 16,80,  4,10,  1, 2, 19,67,  6,96,  0,69,  7,13, 15,42, 18,54, 12,76, 17,32, 13,75,  3,52,  5,98, 10,16, 
     3,31, 14,80,  9,77,  0,56, 11,85, 10,95,  4,59, 12,46,  5, 4, 16,85,  2,42,  1,14, 13, 4,  7,40, 17,40, 19,48,  6,90, 18,82,  8, 4, 15,87, 
    13, 3,  7,53,  9,33,  0,93,  3,62,  8,17, 11,65,  4,23,  5,10, 14,44, 15,49,  6, 2,  2,54, 17,25,  1,42, 10,57, 19,23, 18,16, 16,76, 12,12, 
     4,68, 17,54,  2,75,  8,29, 11,29, 19,98, 18,17, 13, 4, 12,10,  3,71,  1,26, 10, 3,  5,51, 15,79, 14,30,  9,58, 16,76,  6,81,  7,63,  0,60, 
     6,98,  0, 6, 12,66, 18,53,  1,60, 14,93, 19,52, 16,68, 10,81,  8,51, 17,85, 11,74,  2,12, 13,23,  7,43,  4,98,  5,26, 15,51,  3,22,  9,26, 
     2,90,  7,35, 13,76,  0, 7, 19,67,  4,10,  9,41, 11,41, 16,18,  3,41,  5,35,  6,13, 14,30, 18,28, 12,32, 15,95, 10,92,  1,71, 17,76,  8,78, 
    14,31,  3,64,  6,21,  7,72,  8,78, 12,88, 15, 4,  5,74, 16,26,  4,11,  0,41, 17,93,  1,32, 18,74,  2,18, 19,37, 10,28, 11,47,  9,98, 13,65, 
    18,10, 11,37,  2,99,  3,28,  5,84,  4,92, 15,12, 13,72, 19,84,  6,90,  1,35, 14,40,  0,63, 12,29,  8,89,  9,16, 16, 4,  7,38, 10,22, 17,84, 
    10,41, 13,38, 16,71,  8,65, 17,86, 11,30,  7,57,  5,71, 14,24, 15,10,  6,78,  3,74,  0,16, 19,25, 18, 6,  2,75,  4,68, 12,67,  1,69,  9,56, 
     2,46, 10,79, 19,36,  7,13, 18, 3,  4,57,  6,79,  5,53,  0,11, 11,45, 13,39,  1,87,  9,25, 12,62,  8,32, 16,13, 14,22,  3,93, 15,90, 17,90, 
     1,64, 13,70, 11, 9,  2,92,  3,15, 18,32, 17, 6,  9,96, 16,51,  6,87, 12,49, 15,75,  0,84,  4, 1,  7,10, 14,39,  8, 3,  5,89, 10,13, 19,21, 
    18,45, 10,40, 12,14, 16,69,  1,45, 11,98,  8,90, 19,19,  9,40, 17, 2,  5,47,  2,70, 13,46, 14,70,  7,93,  6,70, 15,93,  0,33,  3, 9,  4,85, 
     7,13,  8,85, 14,32, 11,30, 10,70, 13,61,  6,42, 16,41, 19,92,  2,87, 18,36,  3,58,  5,66,  4,70,  1,21, 12,22, 15,41,  0,88,  9,91, 17,94, 
    11,19,  6,51, 17, 8,  8,94,  4,72, 12,99,  1,18,  0,39, 19,30,  9,61, 16,19, 18,74,  2, 2,  3,77, 10,66, 15,28, 14,23,  7,14,  5,92, 13,90, 
    16,96, 19,92,  4,34,  5,10,  3,68, 18,94, 15,62,  8,83, 13,26,  0,87, 10,29, 14,95, 11,30,  1,49, 12,43,  2,85,  9, 1,  6,60, 17,80,  7,48, 
     3,42,  4,14,  2,55,  9,97,  7,65, 16,63,  0,74,  5,63, 13,67, 11,48,  8,63, 14,81, 18, 8, 10, 7, 17,22,  6,43, 12,53, 15,22,  1,93, 19,89, 
     7,14,  2, 2, 14, 8,  5,22,  6,93,  9,59, 10,15, 15, 9,  3,10, 16,81, 18,85, 12,62, 11,70, 17,64,  0,93,  8,26,  4,30, 13, 6, 19,86,  1,27, 
    17,10, 11,39, 18,56,  7,23, 12,44,  4,93, 10,90,  3,99,  8,80, 13,47,  2,38,  9,15, 15,41, 19,26,  6,48,  1,52, 16,75, 14,65,  5, 4,  0,57, 
     1,46,  4,78, 10,10,  7,13,  0,32,  9,63, 14,71,  5,66,  2,40, 18,13,  6,50,  3,97, 19,41, 16,95, 11,58, 12,57, 15,63, 17,42, 13,56,  8,31, 
    10,88, 14, 2, 12,34,  6,19, 18,86,  2,90, 13,84,  8,40,  9,52, 19,66, 11,76, 15,62, 17,27,  7,28,  0, 5,  5,72, 16,54,  3,46,  1,57,  4,66, 
    14,98, 13,44,  1,33,  5,20, 17,74,  2,30,  4, 4, 18,88,  3,19, 12,85, 19,81,  0,29, 10,72,  9,79, 11,54,  8,37,  7,95, 15,11, 16,11,  6, 2, 
     5,48, 11,34, 16,25, 12,26, 15,53, 10,97,  0,26,  2,23, 14,36,  4,17,  8,65,  1,97, 18, 5,  9,13, 17,71,  7,32, 19,26,  6, 6,  3,47, 13,57, 
    19,22, 14,87,  4,89,  8,41,  0,70,  1,35, 15,95,  9,62,  3,57, 12,52,  6,18, 13,94, 17,60,  7,34, 11,87, 16,22,  5,96,  2,59, 18,81, 10,90
  };
  // Taillard 50x15 instance 0
  const int tai_50_15_0[] = {
    50, 15, // Number of jobs and machines
     9,14, 10,79,  3, 6,  8,35,  5,42,  7,64,  4,51,  0,67, 12,13,  1, 9, 13,46,  6,84, 11,60,  2,10, 14,34, 
     1,45,  7,42,  8,95,  2,97,  9,43, 14,40, 12,25,  4,22,  3,57, 11,15, 13,59,  0,33,  5,83, 10,72,  6,27, 
     2,15, 13,92, 11,82,  4,76, 14,87,  8,93, 10,30,  3,96,  6,21,  5,76,  7,61,  1,62,  9, 7, 12,21,  0,38, 
    10,36, 12,96,  7,77,  1,97,  5,26, 14,13,  4,90,  9,60,  2,91,  3,86,  8,74,  0,64, 11,42, 13,93,  6, 1, 
     5,27,  3,61,  7,87,  0, 2,  9,30,  6,47, 11,58, 10, 5, 12,83,  4,72, 14,71,  2,52,  1,48,  8,54, 13,27, 
     3,44,  0,66,  6, 1,  2,12,  4,21,  1,24,  5,19, 14, 6, 10,31, 13,50, 11,84,  9,34,  7,59,  8,64, 12,53, 
    13,51, 10,48,  9,39,  8,75,  1,13,  6,94, 14, 5,  0,73, 12,38, 11,28,  7,77,  2,40,  3,45,  5,89,  4,89, 
    14, 5, 11,35, 10,87, 13,48, 12,25,  6, 4,  4,76,  0,22,  7,92,  5,77,  2,86,  1,35,  3,43,  8,75,  9,61, 
     7,49,  2,41,  8,80, 10,26,  1,18, 14,30,  5,43,  4,50,  0,26, 12,23,  3,22,  9,70,  6,44, 13,53, 11,41, 
    12,41,  5, 3,  4, 5,  7,30,  3,93,  1,76, 11,86,  8,20, 14,72,  6,66,  9,81,  2,37, 10,37,  0,48, 13,14, 
     9,27, 11, 8,  8,68,  5, 1,  4,76,  6,11,  2,45, 12,80, 14,24,  1,87, 10,48,  7,45,  0,84,  3,34, 13, 7, 
     3,80,  9, 4,  7,84,  5, 5,  4,52, 10,75,  2, 4,  8,93, 14,33, 11,34, 12,77,  6,55, 13,47,  0,83,  1,61, 
     8,63,  4,67, 12,28,  3,94,  2,58,  9,55, 10,24,  6,98,  0,91, 13,91, 14,17,  1,37,  5,40,  7,11, 11,18, 
    14,43,  3, 7,  8, 3, 11,67,  5,35,  7,39, 12,81, 10,99,  2,70,  0,28, 13,78,  6,88,  1,80,  9,41,  4,68, 
     1,47,  4,17, 14,90,  3,47, 10, 6,  6,86,  5,24,  2,57, 11,18,  0,74,  8,64,  7, 6,  9, 5, 13,96, 12,52, 
     4,54,  8,49, 11,67,  2,51, 13,19,  0,66,  7,51, 12,53,  6, 4,  3,95,  9,28,  1,45,  5,27, 10, 2, 14,68, 
    10,46, 12,50,  1,74,  4,65,  8,64,  7,15, 14,74,  9,90,  2,17,  0,98, 13,28,  6,18, 11,56,  5,80,  3,52, 
    13,51, 11,36,  9,98, 12, 8,  0,80,  1,77, 10,61,  4,95,  6,69, 14,13,  7,34,  8,44,  3,17,  2, 1,  5,37, 
    10,75,  2, 6, 14,16,  1,61,  7,45, 13,57,  4,25,  9,14,  5,31,  3,12,  8, 2,  0,44, 11,98,  6,47, 12, 7, 
     0,49, 11,71,  2,34, 10, 5,  6,90,  3,51,  4,18,  5,66, 12,56,  8,49,  7,38, 14,44,  9,21,  1,74, 13,47, 
     1,81,  4, 4,  8,29,  2,96,  3,78,  7,80, 12,65, 13,61,  9,84, 14,26,  0,36,  5,67, 11,60,  6,16, 10,67, 
     7,33, 12,53,  9,51,  5, 6,  1,95,  2,91, 14,11, 10,21,  6,76,  4,32,  8,56,  3,77,  0,41, 13,82, 11,18, 
     2,47,  0,18, 10,80,  7,82,  3,21, 14,24, 11,67,  1,68,  5,81, 12,49,  8,39,  6,29,  4,20,  9,79, 13,38, 
     9,82,  4,70, 14,56,  1,66,  3,16,  2,62,  8,27,  0, 6,  6, 1, 10,88,  7,45,  5,27, 11, 8, 12,87, 13,41, 
     0,78,  8,21,  2,87, 10,88, 13,33,  3,15, 12,68,  1,37,  7,33,  4,30,  9,48,  5,29,  6,16, 14,41, 11,30, 
    13,73, 14,86,  7,19,  6,99, 11,78, 12,76,  0, 8,  1,45, 10,96,  8,43,  4,47,  3, 8,  9,25,  5,57,  2,91, 
     7, 6, 11,89,  0,51,  6,53,  2,86,  8,64, 14,56,  5,81,  4, 6, 12,53, 13,62,  1,52,  9,51,  3,66, 10,22, 
     9,87,  7,96,  6,25,  5,66, 10,92,  1,44, 14,68, 11,50, 12,23,  0,45,  4,72,  3,93,  8, 9,  2,13, 13,87, 
     2,95,  3,16,  8,64,  1,72, 12,32, 13, 4,  7,51, 11,52,  5,35,  0,77,  9,39, 10,72,  4,65, 14,46,  6,67, 
     8,62,  4,30, 12,99, 11,67,  3,77,  7, 9,  0,56, 10,74,  6,86,  1,63, 14,81,  2,82,  5,71,  9,62, 13,56, 
     8, 6,  1,98,  4,48,  6, 3,  7,45, 14,85,  3,31, 10,43,  5,14, 12,70,  0,16, 13,87, 11,25,  9,62,  2,86, 
     7,92, 13,98,  0,91,  8,30,  9,35,  1,29, 10,80, 12,99,  5,25,  3,53,  4,49, 11,97,  2,34,  6,98, 14,13, 
    10,34,  8,66, 14,83,  2,78, 12,10,  0,95,  3,64,  5,43,  1,65,  9,37, 11,73,  7,33, 13,45,  4, 5,  6,18, 
     1,11,  2,21,  5,42,  9,70,  7,43,  4,48,  0,58,  3,54, 14, 9, 12,17, 13,73, 10,42,  6,18, 11,76,  8,29, 
    11,92,  2,89,  4,28, 14, 8,  6,13,  5,92,  7,13, 12,45,  9,47,  3,36,  8,44,  0,67, 10,25, 13,77,  1,43, 
    14,88,  8,36,  5,13,  7,65, 10, 9, 13,45,  1,89,  0,79,  9,99,  4,94,  3,37,  2,76,  6,99, 12,38, 11,79, 
    13,32,  7,65, 12,86, 11,44,  8, 2,  3,55,  9,66,  2,50,  1,31,  5,66, 14,88,  6,10,  0,46, 10,56,  4,36, 
     0,55, 14,78,  5,55,  2,62,  4,65, 10,97,  9, 9,  6,47,  3,56, 11,92, 12,21,  8,66, 13,40,  7,20,  1,97, 
     9,81,  7,43,  0,72,  6,71,  4, 5,  8,56,  1,84,  3,53, 12,98, 10,76,  5,15, 13,84, 11,48, 14,65,  2,19, 
    14,99, 10,23,  6,14,  5, 3,  0,25,  4,95,  8,53, 12,22,  9,31,  2, 3,  7,86,  1,40, 11,66,  3,80, 13,19, 
     3, 8, 11,37,  4,90, 14,98,  5,17,  8,88,  6,35,  2,52,  9, 1, 10,99,  7,36, 13,29,  1,77,  0,18, 12,55, 
     3,76,  0,33, 10,37,  2,81, 12,71,  7,57,  4,88,  8,29,  6,41, 14, 7, 11,43,  9, 7,  1,32, 13,15,  5,16, 
    14,22,  2,38,  6,21,  5,25,  1, 9,  3,50, 11,51, 13,83,  8,73, 12,85,  9,53,  4,21, 10,12,  0,10,  7,34, 
    10,89,  6,84, 14,94, 11,82,  7,42, 13,26,  1,16,  9,40,  8,55,  0,15,  4,31, 12,73,  2,95,  3,39,  5,11, 
     5,52,  2,71, 12,75,  7,11,  9,77, 11,75,  0,68,  1,55,  3,90, 10,21,  6,62,  8,23,  4,95, 14, 8, 13,66, 
     9,91, 11,45,  1,44,  7,23,  0,47, 14,60,  8,36,  5,81, 10,24,  6,60,  2,62, 13,13,  3,88,  4,38, 12,46, 
     7,90, 10,87,  9,49,  3,77, 13,32,  4,28, 12,80,  5,61,  8,75, 14,23,  1, 5,  6,43,  2,31,  0,80, 11,68, 
     4,92, 11,67, 13,78, 14,39,  5,74,  7,47,  2,56,  9,81, 12,51,  1,85,  0,12, 10,25,  3,64,  8,70,  6,49, 
    11,73, 10,73,  8,59,  3,47,  6,36,  9,81, 12,58,  7,38,  4,33,  1,19,  0,15,  2,97,  5,25, 13,67, 14,89, 
     9, 9,  6,58,  4,64,  2,46, 14, 2,  3,24,  8,68, 11, 4, 10,55, 13,95,  5,98,  7,57,  1,63,  0,31, 12,31
  };
  // Taillard 50x15 instance 1
  const int tai_50_15_1[] = {
    50, 15, // Number of jobs and machines
     1,17, 12,55,  2,62,  6,74, 10,38,  0,44, 11,29,  9,47,  4,94,  7,38,  5,64, 13,75, 14,60,  3,78,  8,10, 
     7,18,  1,59,  0,87, 11,40,  4,53,  9,38, 10,44,  2,38,  5, 7,  6, 9, 13,96, 12,67,  8,58,  3,28, 14,64, 
     9,42,  3,11,  5,93, 10,72,  8,58,  6,49, 12,46,  4,21,  7,93,  0,51, 13,13, 14,72, 11,78,  2,43,  1,55, 
    10,93,  7,47,  3,82, 12,64,  8,38,  0,24,  5,17,  6, 7, 11,49,  1, 4, 14,69,  9,39,  2,25,  4,85, 13,52, 
    11,48,  0,80,  9,48,  3, 3,  7, 7, 13,69,  8,53,  6,46,  5, 1,  1,52,  2,37, 12,25, 14,84, 10,85,  4,14, 
     2,49,  4,42, 14,62,  7,86,  1,14,  8,25,  0,62,  6,63,  5,86, 10, 7, 13,83,  3,84,  9,54, 12,23, 11,16, 
     4,56,  3,79,  7,97, 10,34,  9, 3,  8,83,  2,39, 13,44, 14,43, 11,98,  1,99,  6, 2,  5,47,  0,97, 12, 8, 
    13,61, 14,84,  2,96, 12,64,  5,58,  8,64, 10,14,  4,40,  0,94,  3,13,  7,24, 11,64,  1,63,  9,58,  6,74, 
    14,93,  6, 4,  1,28,  3,43,  0,92,  7,55,  4,87,  9,19, 10,23,  8,23, 12,99,  2,89, 11,42, 13,71,  5,96, 
     4,56,  3,31,  7,72,  6,88,  0, 6,  8,50, 10,66,  1,93, 11,26, 12,17, 13,62,  9, 4,  5,13, 14,46,  2,35, 
     1, 7,  3,81, 14,97,  8,52,  2,93,  5,28,  9,74,  6,17, 12,48,  0,45,  7,51, 10,65, 11,74,  4, 2, 13,10, 
    12,85,  2,85,  4,93,  6,35, 11,51,  9, 6,  3,91,  7,99,  8, 9,  5,38, 10, 3, 14,15,  1,39, 13,55,  0,35, 
     6,14, 14,28,  2,49, 11,53,  0,94,  3, 7, 12,14,  5,29,  1,30,  8,47, 13,50,  9,54,  7,25, 10,90,  4,84, 
     5,16, 11,43,  4,82,  0, 2,  9,86, 10,70, 14,49, 12,26,  3,63,  7,34,  1,86,  8, 1,  2,26, 13, 8,  6,11, 
     8,90,  3,19, 14,54, 12,27,  9,38, 10,57,  4,68,  5,70, 13,76,  7,30,  2,55, 11,98,  1, 9,  6,57,  0,81, 
    11,24,  4,95, 13,91,  0,57, 14,71,  5,71,  9,84, 10,49, 12,94,  6,74,  3,18,  2,22,  8,33,  1,73,  7,81, 
    14,86,  0, 5,  5,94,  4, 1, 10,68,  1,50,  8,53,  9,14, 12,82, 11,80,  3,42, 13, 1,  7,72,  6,48,  2,64, 
    14,19, 13,45,  1,50,  9,14,  8, 3, 12,82,  6, 4, 10,55,  0,94, 11,76,  7,64,  4,69,  3,32,  2,20,  5,48, 
    10,53,  0,33, 12,90,  4,13,  7,73,  1,48,  6,52,  5,57,  3,71,  2,13,  9,55,  8,95, 11,49, 13,32, 14, 8, 
     2,72,  8, 1, 10, 8,  0,63, 11, 7, 14, 5,  6,30,  1,71,  4,74,  7,79, 13,36, 12,71,  5,31,  3,79,  9,43, 
     3,93, 14,96, 11,93,  7,88,  0, 4,  9,12, 12,34, 13,11,  4,17,  8,20,  1,74, 10,70,  5,13,  6,52,  2,83, 
     9,87,  8,39,  7,84,  1,69,  0,65,  3,19,  6,82, 14,48,  2,87,  4,87,  5, 1, 10,58, 13,90, 11,22, 12,81, 
    10,57, 14,17,  6,58,  9,27, 13,48,  5,38,  7,77,  0,92, 12,11, 11,21,  8,70,  2,69,  3,47,  1,91,  4,70, 
    12,92,  2,17,  0, 6,  5,58, 13,47,  9,90,  6,33, 14,25,  1,22,  8,97,  3,40,  7,63,  4,95, 10,17, 11,20, 
     4,87,  1,80, 14, 3,  7,97,  6,53,  2,38, 10,28,  0,31, 11,47,  5, 4, 13,46,  3,11,  8,70, 12,54,  9,44, 
     0,82, 14,50, 11,60,  4,15,  6,66,  1,55, 10,25,  8,44,  3,94, 13,73,  9,78, 12,96,  7,22,  2,18,  5, 4, 
     4,91,  3,10,  0,87, 10,65,  6,12,  9,73,  5,17, 14, 6,  7,85,  1,29, 12,54,  2,72, 11,43, 13,48,  8,29, 
     7,48,  9,41,  2,44,  4,99, 14,14, 10, 9,  8,21,  1,70,  3,87, 13,66, 11,37,  0,82,  5,29, 12,56,  6,10, 
     6,28, 10,64, 11,87, 14,51,  9,52,  0,85,  1,85,  2,59,  7,44,  8,80,  5,51,  3,11, 12,63,  4,68, 13,85, 
     8,32, 12,38, 14,90,  7,18, 11, 9,  0,33, 10,43, 13,59,  2,52,  6,91,  3,57,  9,38,  5,15,  4,18,  1,79, 
     9,14,  5,31, 12,96,  7,95, 14,83,  1,68,  0, 7,  6,91,  3,49,  4,32,  2,93,  8,88, 13,11, 10, 2, 11, 2, 
     4,22,  5,39, 10,25,  1,25,  0,84,  2,49,  8,68,  9,18, 14,20, 12, 7,  6,93, 13,93, 11,64,  3,56,  7,61, 
     9,96,  7,13,  0,58, 10,20, 13, 5, 14,26,  8,26, 12, 6,  1,20,  2, 4,  4,60,  6,37, 11, 2,  3,45,  5,52, 
     1,49,  8,36,  0,25, 12,28,  5,46, 11,23,  2,35,  4, 8,  7,67, 14,45,  9,46,  6,13, 10, 4,  3,16, 13, 6, 
    14,12,  8,84,  5,62,  9,79,  6,98,  0,44, 13,25,  3,25,  2,29, 12,17,  7,12,  4,39,  1,58, 11,25, 10,57, 
     5, 3, 12,43,  8, 4, 14,87,  0,64,  1,36, 10,80,  3,22,  9,20,  4,59,  7,26,  2,45, 13,39,  6,99, 11,72, 
     4,39,  0,48, 11,55, 14,75,  5,64,  1,22,  6,43,  7,91,  9, 7, 12,66,  8,22,  3,43, 10,59,  2,38, 13,80, 
     7,50,  2,75, 10,50, 14,68,  6,33,  3,99,  8,32,  0,46,  1,10, 13,81,  4,93, 12,29,  5,13, 11,98,  9,13, 
     8,60,  6,14,  5,54,  2,11,  7,98,  3, 4,  0,56, 13,17, 14,18,  9,28,  1,85, 10,57, 12,82, 11,99,  4, 4, 
     2,79, 11,91, 14,23,  0,21,  6,91,  7,52, 13,48,  5, 1, 12,23,  8,88, 10, 6,  1,73,  4,12,  9, 1,  3, 3, 
     9,36, 12,40,  7,39,  8,14, 11,80, 14,24,  5,49, 10,27, 13,89,  1, 4,  2,68,  0,77,  4,98,  6,14,  3,74, 
    12,61, 10,48,  0,56, 13, 8,  4,76,  8,25,  3,43,  1,67,  7,10,  9,92,  6,67, 14,33, 11,51,  2,45,  5,98, 
    14,45,  7,38,  8,79,  4,35,  6,24, 13, 1,  5,51,  9,88,  3,94,  0,91,  1,48,  2, 2, 12,49, 10, 8, 11,86, 
    14,44,  6, 6,  3,31, 11,49,  1,11,  2,44, 10,98,  5,81,  8,42,  9,98, 12,77,  7, 9,  4,55, 13,29,  0, 9, 
    12,47,  3,87,  0,50, 11,40,  4,85,  2,86,  7,18,  1,48,  6,91, 10,94,  8,98,  5,86, 13,56, 14,75,  9,46, 
     2,44,  7,53,  0,99,  4,95,  5,32, 10,33, 13,68,  1,22, 11,49,  3,96,  9, 8, 12,87,  8,78, 14, 6,  6,62, 
     6,86,  3,97,  0,16,  8,33, 10,47,  9,93,  4,11,  7,82,  2, 7, 13,18, 14,29, 11,17,  1,56, 12,80,  5,82, 
     8,17,  2, 9,  5,17, 10,65,  6,88,  7,37,  0,53, 11,40,  1,35,  9,24,  4,71, 14,52,  3,30, 13,81, 12, 2, 
     5,65, 11,90,  3,38, 12,97,  7,96,  6,14,  2,85,  0,73, 13,95,  9,87, 14,10,  1,18,  4,17, 10, 4,  8,58, 
     3,69, 11,64,  5,77,  6, 3,  1,75,  2,99, 10,74,  8,56, 13,29, 14,96, 12,83,  9,64,  4,19,  0,18,  7,38
  };
  // Taillard 50x15 instance 2
  const int tai_50_15_2[] = {
    50, 15, // Number of jobs and machines
    14,68,  2,21,  5, 7,  1,19,  3,83,  7,74, 10,12,  4,69, 11,39,  8, 9,  0,63,  9,67,  6,58, 13,37, 12,15, 
     1,62,  0,83,  5,32,  2,56,  4,61,  7,67,  3, 9, 10,50, 13,88, 14,99, 12,50, 11,86,  6,42,  8,70,  9,30, 
    13,20, 14,40,  1,28,  4,51,  8,23,  7,34,  0,10,  6,71,  9,41,  2,14, 10,62, 12,41,  5,14,  3,72, 11,48, 
     9,47, 10,32,  3,99,  4,51, 12,85,  6,49,  1,32, 14,89,  0,75,  7,24, 13, 8, 11,49,  5,86,  2,97,  8,86, 
     1,12,  2,65,  0, 3,  3,89,  8,26, 13,67,  4,24,  7,24, 14, 4, 12,43, 11,33, 10,52,  9,40,  5,84,  6,99, 
     8,77,  9, 1,  2,81,  1,61,  7,51,  3,14, 14,78, 10,69, 11,95,  5,18, 12,15,  0,66,  4,74, 13,84,  6, 1, 
    10,23, 14,58,  7,33, 11,52,  4,26,  3,12,  2,97, 13,78,  5,51,  8,82,  9, 5,  0,74,  1,12,  6,25, 12,40, 
    12,68, 14,66, 10,14,  2,95,  1,19,  9,97,  6,58, 11,54, 13,74,  0, 5,  5,83,  7,92,  3, 8,  4,96,  8,80, 
     3,89, 12,76, 11,74,  8,77,  7,59,  0,39, 13,36,  2,39,  4,45,  9,34,  1,48, 10,72,  6,70, 14,75,  5,42, 
    10,38,  4,43,  6, 9, 13,29,  8,82,  0, 4, 14,42,  2,71,  9,92,  3,27,  1,44, 12,77,  7,55, 11,92,  5,90, 
    13, 7,  4,57,  7,20,  5,39,  8,61,  3,10,  6,93,  2,34,  9,85, 11,62,  0,29, 12, 4,  1,51, 10,62, 14,47, 
     4,65,  2,57,  6,76,  5,89,  1, 9, 13,61,  3,64,  0, 2, 14,85,  8,84, 10,27,  9,70, 12, 5,  7,59, 11,69, 
     0,36, 13,33,  4,79, 11, 8,  5,85, 12,76, 10,92,  3, 5,  9,23,  6,70,  2,24, 14, 1,  7,39,  8, 1,  1,71, 
     0,44, 13,48,  3,59,  1,56,  8,77,  6,12, 12,87,  2,41, 14,89,  5,24, 11,24,  4,58,  9,56, 10,17,  7,33, 
    11,52,  0,20,  3,57,  8,96,  9,12,  5,40,  1,60,  4, 7,  7,34, 13,91,  6,21,  2,44, 14,79, 12,54, 10,35, 
    11,12,  9,24,  3,15, 10,66,  5,62,  7, 4,  2,37, 12,33,  0,77,  8,67, 13,76,  4,41,  6,77,  1,51, 14,81, 
     5,63,  0,60,  7,49,  6,76,  2,75, 12,65, 13,26, 11,74,  9,11,  3,44,  1,67,  8,94, 10,90,  4,62, 14,86, 
     5,31,  7, 6, 12,62,  6,81,  8,72,  0,20,  1,18, 14,78,  2, 3,  4,98, 13,94,  9,22, 10, 4, 11,65,  3,72, 
     4,21,  8,44,  2,87, 11,31,  9,91,  3,31,  5,81,  7,10, 13,31, 10,24, 12,38,  1,90,  6,18, 14, 2,  0, 1, 
    10,31, 12,76,  3,62,  5, 1,  1,66, 11,36,  6,36,  8,55, 14,22,  4,86,  7,74,  2, 8,  9,59,  0,37, 13,37, 
    11, 4, 13,71,  1,39,  6,16,  4,33, 10,26,  9,45,  7,87,  5,42, 12,11,  3,18,  2,11,  0,17,  8,76, 14,51, 
     7,34,  9,38, 14,74,  0,54,  5,60,  3,91, 13,81, 12,92,  1,45,  6,51,  2,20,  4,71,  8,14, 10,13, 11,58, 
    12,66,  0,13, 14,21,  1,92,  7, 3,  9, 3,  8,78,  2,47,  4,46,  5,52,  6,87, 10,87, 13,62,  3,70, 11,90, 
     8,85,  9,17, 11,86,  5,96, 10,55, 12,74, 13,18,  7,81,  1,56,  0, 3,  2,31,  4,15,  3,92,  6,47, 14, 3, 
     6,93, 14,33, 12,74,  1,90,  0,52,  7,37, 11,42, 10,28,  8,83, 13,82,  2,72,  5,13,  3, 9,  9,52,  4,21, 
     9,11,  5,61, 13,47, 12,11,  8,41,  1, 7,  3,31,  2,51, 14, 2,  0,81, 11,45, 10,27,  6,52,  7,88,  4,61, 
     0,98,  6,52,  3,41, 10, 5,  5,20,  4,97,  9,48, 12,23,  1,34, 14,28,  7,75,  2,21, 11,60, 13,86,  8,34, 
     5,55,  9,99, 12,49, 14,44, 10,28,  2,37,  7,12,  0,69,  6,86,  4,74,  1,45, 13,95, 11,97,  3,78,  8, 1, 
     4,93,  0,42,  5,25, 11,34, 10,59, 12,10,  9,44,  7,38, 13,80,  3,29,  8,68,  2,71, 14,27,  1,24,  6,46, 
    13,29, 12,16,  3,78, 10,32,  2,30,  4,72,  7,91,  5,77, 14, 5,  0,90,  8,24, 11, 6,  1,70,  6,54,  9,52, 
    11,38, 14,68,  5,52,  7,79, 12, 5,  6,47, 10,42, 13, 4,  9,66,  2,47,  8,71,  1,79,  3,17,  0,64,  4,53, 
     1,51,  6,90,  5,62,  0,97, 11,77, 12,30,  2,17,  9,13,  4,65, 10,60,  7,90, 14,13, 13,78,  8,82,  3,77, 
     5,22,  9,38,  6,94, 14,10,  4,64,  0,22,  3,91, 11,70,  1,22, 13,54,  2,82,  7,49,  8,30, 12,62, 10,66, 
     6,88,  3,79, 13, 9,  2,18,  4,54, 14,20,  0,59, 12,24, 10,52,  5,70,  1,16,  9,32, 11,60,  7,79,  8,92, 
    13,44,  9, 7, 11,78,  4,85,  3,13,  0, 3,  7,58,  1,62,  2,59, 14,79,  5,31,  8,44,  6,12, 10,79, 12, 6, 
     8,72,  3,70,  5,97,  6,25,  2, 8, 12,99,  4,65, 10, 2,  7,92,  1, 3, 13,61, 14,95,  0,42, 11,82,  9,60, 
     2,15,  8,85,  7, 2,  4, 4,  3,69,  6,42, 12,73,  5,73, 13,28, 10,16, 14,37,  9,59,  1,46,  0,64, 11,41, 
    10,55, 14,88, 13,69,  6,56, 11,48,  0,17,  1, 2,  3,66, 12,70,  8,57,  7,67,  2,38,  4,45,  9,14,  5,94, 
     1,59,  8,99, 13,97, 12,14, 11, 3,  7,26,  0, 6,  2,47,  6,35,  3,71,  4,49,  9,91,  5,38, 10,74, 14,42, 
     7,41,  2,40,  0,98,  8,50,  5,54, 11,14,  6,64,  9,54, 12,84, 10,26,  1,56, 13,69, 14,96,  4, 6,  3,42, 
     4,88,  1,43, 14,40,  6,48, 13,46,  9,70,  8, 8, 12,36,  3,16,  5,85,  0,82, 10,50, 11,74,  2,28,  7,87, 
    13, 6,  5,48,  6,70,  9,98,  0,19, 10,24,  4,37,  8,38, 12,85, 11,99,  1,20, 14,76,  7,94,  3,90,  2,14, 
     4,56,  7,14,  3,61,  5,34,  1,25, 10,70,  2,50,  9,15,  8, 6, 13,77,  6,37, 12, 8, 11,63, 14,37,  0,25, 
     9,95,  1,34, 10,65, 12,88,  8,43, 13,42,  0,30,  3,62,  2,86, 11,52, 14,61,  4,16,  5,48,  6,62,  7,53, 
     0,44,  2,92, 12, 4, 10,59, 14, 3,  3,34,  8, 8,  9,78,  1,22,  4,98,  7, 9,  5,63, 13,84,  6,54, 11,53, 
    10,91,  7,14, 14,88, 13,54,  4,29,  1,66, 12,48,  0,58, 11,42,  6,26,  2, 8,  5, 7,  3,99,  8,23,  9,74, 
    14,67,  7,77,  0,32, 13,97, 10,71, 11,47,  5,67,  1,98,  8,43,  3,62,  2,84,  6,44,  4, 2, 12,60,  9,46, 
     9,27,  7,72,  8,62, 13, 7, 10,76,  2, 3,  3,30,  6,37,  4, 9, 12,13,  0,72,  5,99,  1,16, 11,17, 14,40, 
    12,52,  7,97,  8,25, 14,92, 10,54,  0,55, 13,51,  4,92,  6,40,  9,52, 11,62,  5,42,  1, 1,  2,56,  3, 9, 
    13,64, 14,83,  6,31,  9,47,  0,19,  3,62,  8,11,  5,44, 11,55, 12,60, 10,84,  2,64,  7,83,  1, 7,  4,10
  };
  // Taillard 50x15 instance 3
  const int tai_50_15_3[] = {
    50, 15, // Number of jobs and machines
    11,23, 14,58,  9,60,  1,43,  5,17, 13,68,  6,42,  8,53, 10,18,  7,42,  4,96, 12,19,  0,50,  2,62,  3,97, 
    12,29, 11,62, 10,56,  4,33,  6,72, 14,80,  2,64,  0,80,  5, 4,  3,40,  1,88, 13,78,  9,95,  8,30,  7,21, 
     4,34,  0,60, 13,78, 14,55,  7,41,  9, 3, 12,99, 11,32, 10,86,  2,26,  6,89,  1, 4,  5,49,  3,42,  8,78, 
     4,87, 12, 3, 14,27,  3,69,  8, 8,  9,28,  0,40,  6,73,  1, 2,  7,71, 11,50, 13,95,  2,14, 10,65,  5,63, 
    10,46,  4,40,  5,43, 14,48,  9,28, 12,15,  6,59, 13,58,  0,34,  3,57,  8,29,  2,45, 11,44,  1,27,  7,60, 
     8,67,  0,31, 12, 8,  1,21,  7,18,  4,46,  5,64,  3,27,  2,37, 14,95, 10,75,  9,19, 13,38,  6,91, 11,24, 
     9,33,  4,46, 13,59,  2,71, 14,19, 10,76, 12,61,  6,32,  1,29, 11,26,  5,31,  8,27,  7,71,  0,45,  3,42, 
     9,65,  4,27, 12,62, 11,74,  6, 2,  7,73,  0,40,  2,36, 10,98,  3, 6, 14,49, 13,69,  1,50,  8,58,  5,52, 
     8,94, 12,72,  3,48,  5,23,  7,97, 14,87,  1,73, 11,25, 10, 4,  4,40,  0,60,  9,11,  6,13, 13,66,  2,30, 
     8,69, 11,54,  9,14, 13,61,  3,12, 12,75,  5,25,  7,41, 10,96,  2,23,  1,26, 14,68,  6,92,  4,75,  0,13, 
     4,56,  9,43,  2,10, 10,67, 12,99,  6,50,  8,87,  0, 4, 13,28,  5,28, 11, 4, 14,56,  7,55,  1,83,  3,59, 
    10,46,  6,74,  5,12,  4,96, 12,75,  3,16,  9,90, 13,88, 14,12,  8,81,  2, 8,  7,28, 11,90,  1,20,  0,40, 
     5,36,  9,87,  0,96, 12,22,  8,91, 10,38, 13,92, 11,16,  3,28,  7,46, 14,74,  6,35,  1,15,  4,61,  2,50, 
     4,70,  5,52, 12, 5,  2,48,  6,58, 14,51,  0,32,  7,59,  1,89, 11,71, 13,59, 10,11,  8,79,  9,31,  3, 6, 
    14,94, 10,37,  8,50,  5,88,  4,87,  9,64,  7, 8, 13,17,  3,90,  1,14,  2,56,  6,25, 11,42, 12,18,  0, 5, 
     8,66, 12,61, 11,72,  7,25, 10,32,  2,46,  3,39,  6,92,  4,33,  1,54,  9,58,  5,28, 13,78, 14,61,  0,79, 
     1,97,  4,34,  5,47,  6,71,  9,84, 13,78,  3,62,  7,98,  2,64, 14,89, 11,55,  0,93, 10,86, 12,92,  8,94, 
    12,72,  8,40,  3,56, 10,31,  9, 9,  1,13,  7,62,  6,62,  2,55,  4, 2,  0,29, 13,67,  5,92, 14,31, 11,51, 
     5,35, 12,40,  1,32,  2,41,  3,64,  0,91,  7, 2, 13, 9,  6,48, 11,76,  4,45,  8,12, 10,78,  9, 8, 14,89, 
    12,53,  1,93,  8,79, 11,95,  2,19,  7,29,  6,86, 10,64,  4, 4, 13,65, 14,80,  9,41,  5,91,  3,38,  0,54, 
     3,75,  9,74,  8,38,  0,99, 11,44,  1,58, 14,88, 10,33,  4, 7, 13,43,  5,57,  2,43, 12, 6,  7,15,  6,22, 
    11,85,  1,45,  9, 3,  4,15,  3,50,  8,26, 12,92,  0,62,  6, 5,  7,77, 14,96, 10,59, 13,48,  2,12,  5,43, 
     1,25,  7,14,  6,34,  5,33,  9,18, 14,89,  2,49,  4,73,  3,89,  0,68, 13,72, 12,99, 11,49,  8,73, 10,62, 
     2, 9, 14,39,  9,62, 13,78,  7,10,  8,99,  6,54,  5,54,  4,28,  0,22, 12,90, 11, 8,  3,52,  1,50, 10,10, 
     9,88,  4,90, 12,66,  1,10,  6,76, 10,69,  8,94,  7,57,  2,31, 11, 2, 13,59, 14,18,  3, 1,  0,69,  5,98, 
     4,83,  1,25,  9,37,  0,24,  8,48,  2,55, 14,66,  3,34,  5,37,  6,80,  7,20, 13,77, 11,26, 12,72, 10,31, 
     7,22,  8,31,  6,45,  4,12, 13,87,  1,17,  5,62, 14,14,  2,91, 10, 7, 12,83,  0,58,  3,87,  9,30, 11,97, 
     5,36, 12,68, 10,10,  9,16,  1,69,  4,78, 13,46, 11,31, 14,70,  2,93,  7,96,  0,33,  3,45,  8,81,  6,78, 
     1,13, 13,21,  0,14,  5,75,  4,88,  6,14,  8,28, 11,81, 14,16, 12,82,  9,94, 10,55,  7,64,  3,78,  2,23, 
     3,92,  6,12, 10,46,  5, 2,  7, 5,  8,55,  9,76,  0, 4, 14, 5,  1,44, 12,40,  2,96, 11,62, 13,36,  4,25, 
     4,17,  8,86,  6,36,  9,10,  3,94,  2,65,  0, 4,  5,40, 13, 3,  7,12,  1,74, 12,99, 10, 5, 14,68, 11,38, 
     4,52,  0,44, 12,72,  6,24,  1,92,  3,88, 14, 7, 11,93,  7,12,  2,63,  5,71,  8,88, 10,75, 13,18,  9,38, 
     7,37, 10,64,  1,75, 14,40,  6,14, 11,50,  8,20,  4,23, 12,32,  5,18,  0,29, 13,63,  2,91,  9,64,  3,30, 
    12,69, 13,15,  1,39, 10,23,  7,51,  2,64,  9,54, 14,29,  4,91, 11,16,  5,95,  3,15,  6,20,  0,24,  8, 6, 
     0,10,  2,48, 10,63,  1,82, 12,47,  4,56,  5, 8, 11,56,  9,27,  3,82,  8,11,  7,10,  6,67, 13,89, 14,18, 
     0,49, 10,11, 13,50, 12,25,  6,35,  1,76,  8,76,  2, 1,  3,35, 14,69,  9,19,  4, 4,  7,26,  5,47, 11,11, 
    12,10,  2,15, 10,82,  4,50,  9,49,  6,56,  0,62,  1,57,  7,85, 13,26, 11,17,  8,36,  3,84, 14, 8,  5,68, 
     3,25,  1,19, 12,67,  5,28,  6,88,  2,68,  8,29, 14,63,  0, 8, 11, 5,  7, 5, 10,47, 13, 6,  9, 2,  4,97, 
    11,29,  6,62, 14,20,  5,56,  4,64,  3,82,  1,20,  0,11,  7,65, 12,66,  2,45, 13,58,  8,84, 10,73,  9,70, 
     3,52,  2,66, 10, 9,  9,83,  1,22,  5,77, 13,60,  8,28,  7,31,  4,12,  6,87,  0,85, 11, 8, 12,88, 14,74, 
     6,38,  2,35,  9,29,  7,67, 13,83,  8,57,  1,60, 11, 4, 12,13,  5,51, 10,18,  3,87, 14,18,  4,87,  0,37, 
     2,60,  4,21,  7,98, 14,77, 11,66,  8,81,  9, 8, 13,54,  0,62,  1,41,  5,36, 12,73, 10,50,  3, 1,  6, 3, 
    10,17, 12,23,  7,44, 11,62,  0,43, 14,50,  2,52,  1,18,  4,27,  6,16, 13,93,  5,97,  8,46,  3,80,  9,90, 
     0,94,  9,40, 11,46,  1,18, 14,39,  4,55,  3,52,  7,18,  2,46,  5, 5, 12,26, 10,39,  8,49, 13,94,  6,93, 
    10,56,  0,44, 12,91,  9,63,  5,52,  4,54,  7,31,  2,99,  8,42, 13, 6,  1, 1,  6,94, 11,32, 14,93,  3,97, 
     2,35,  8,27,  6,54,  5,67,  7,72, 11,97,  3,79, 14,13, 10,17,  1,56,  0,63,  4,98,  9,15, 13,18, 12, 3, 
     2,20,  5,47,  3,76, 13,58,  0,42, 10,76, 12,38, 14, 7,  6, 4,  7,25,  1,61,  8, 3,  9,62,  4, 8, 11,99, 
     2,71,  5,94, 14,24,  1,74,  7,77, 13,90, 12,69, 10,46,  3,63,  6,81,  9,33,  8,70, 11,40,  4,91,  0,22, 
    12,25,  1,60,  8,40,  3,82, 10, 1,  4,89,  5, 1, 11,13,  6,62, 14,96,  7,10,  9,83,  2,32, 13,55,  0,87, 
     5,31,  2,67, 14,58, 10,47, 11,37,  3,52,  6,89,  1,16,  9,36,  8,80, 12,80,  7,87,  0,24, 13,40,  4,94
  };
  // Taillard 50x15 instance 4
  const int tai_50_15_4[] = {
    50, 15, // Number of jobs and machines
     5,25,  0,10,  2,40, 14,50, 12,45,  4,91,  7, 6, 13,40,  1,19, 10,88, 11,87,  6,67,  9,34,  3, 1,  8,26, 
     7,53,  2,83,  1,52,  8,92, 12,92,  9, 8,  3,75, 11,56, 13,40, 14, 7,  0,20,  6,84,  4,64, 10, 7,  5,23, 
     4,99,  6,51,  5,86, 13,53,  0,86,  7,30, 14,87, 11, 8,  9,53, 10,39, 12,22,  3,55,  8,64,  1,32,  2,64, 
     9,68, 13,19,  3,13, 11,10, 14,64, 12,50,  6, 4,  1,28,  0,69,  4,68, 10,37,  5,78,  2,41,  7,51,  8,34, 
    11,23,  8,50,  1,25,  9,37,  2,93,  5,74,  6,47, 12,50,  7,40, 13,82,  3,29, 10,91,  0,79, 14,40,  4,19, 
     9,77,  3,19,  4,44,  7,79, 11,79,  2,33, 13,12,  5,12,  8,15, 12,32,  6,64, 10,26, 14,90,  0,49,  1,67, 
     1,28,  2,84,  3,95,  5,28, 13,93, 10,67,  6,75,  0, 8,  8,56,  4,79, 12,27, 11,18,  7,45,  9,20, 14,44, 
     1, 2, 14,60, 10,12, 12,35,  4,45,  8,40,  7,24, 13,90,  6, 1,  2,21,  9,75,  3,79,  5,91, 11,32,  0,41, 
     6,61, 13,30,  2,81,  4,70, 12,82, 14,25,  3, 9,  5,29, 10,27,  9,29, 11,68,  0,64,  1,23,  7,51,  8,51, 
    11,87, 13,94,  0,91, 10,14,  6,15,  9,38,  1,86,  2,16, 14,44,  3,63,  5,62,  8,87,  7,77,  4,31, 12,19, 
     9,64, 10,80,  5,92, 12,99,  7, 1,  0,30, 14,21,  6,76,  1,65,  2,13, 11,36,  4, 2,  8,77, 13,13,  3,68, 
    12,28,  5,53,  1,64, 13,24,  2,51,  8,82,  6,99,  4,21,  7,68, 10,41,  0,14,  3, 9, 14,91, 11,57,  9, 5, 
     4,51,  1,93,  8,77, 10,61,  5,22, 12,77,  6,55, 13,96,  7,76,  3,27,  9,12,  0,63, 14,84,  2,46, 11,14, 
    13,51, 12,35,  2,64,  5,79, 11,15,  7,82,  9,58, 14,72,  6,60,  0,99,  8,47, 10,44,  1,19,  3,99,  4,86, 
    11,49,  7,21, 14,37,  2,24, 12,96,  6,32,  4,94,  0,37,  9,28, 10,30,  1,41, 13,66,  5,12,  3,78,  8,82, 
    14,27,  5,63,  9,35, 11,52,  3,71,  0,62, 12,20,  1,16,  4,64,  6,80, 10,57,  8,34,  7,74, 13,13,  2,80, 
     0,72,  9,98,  2,50,  5,45, 13,73,  4,82,  1, 3, 14,53,  6, 4,  3,86, 10,54, 12,76,  8,55,  7,38, 11,53, 
    11,22,  6,30,  0,17,  5,53, 10,50, 12,86,  2,18, 14, 1, 13,35,  1,93,  7,90,  8, 5,  9,88,  3,11,  4,65, 
     7,28, 10, 4,  4,11,  0,87, 12,62, 14,59, 11,36,  9,57,  5,34,  3, 5,  2,76, 13,83,  1,91,  8,46,  6,64, 
     4,67,  9,20, 12,95, 10,52, 14,37,  3,88,  7,66, 11,87,  2,77,  0,38,  8,56,  1,78,  6,55, 13,28,  5,55, 
     3, 6, 10,19, 14,65,  5, 5,  6,68,  7,26,  1,93,  2,46,  4,49, 13,23, 12,83,  9,61,  8,88, 11,68,  0,62, 
    10,52, 12,25, 13,33,  2,14,  1,29,  0,61,  5,17,  6,82, 11,19,  8,37,  9,77,  3,41,  7,47, 14,45,  4,51, 
     5,68,  2,23,  0,18, 13,65,  1,89,  6,10,  4,98,  9,61,  8,38, 11,64, 10,91,  3,36, 14,66,  7,32, 12,24, 
    11,86,  4,90,  6,44, 10,60, 12,22,  8,83,  2,94,  7,14,  9,80, 14,46,  1,20,  0,13, 13,39,  3,67,  5,17, 
    11, 4, 14,21,  9,59, 13,50,  2,75,  0,41,  4,79,  1,36,  8,54, 10,72, 12,94,  6,46,  5,18,  7,81,  3,45, 
    14,77,  0,97,  8,61,  1,61, 11,93, 12,97, 13,86,  2,15,  9,73,  4,28,  7, 1,  6,80,  3,89, 10,52,  5,30, 
     3,15,  1,27, 12,35, 11,47,  4,79,  7,26,  6,72, 10,89,  9,35,  2,52, 13,17,  5,92, 14, 5,  8,20,  0,49, 
    12, 3, 14,93, 10,56,  0,82,  5,58, 13,65,  1,82, 11, 5,  4, 5,  3,92,  6,30,  8,35,  2,17,  9, 4,  7,78, 
     4,30, 10,55, 13,85,  6,50,  0,29, 11,77,  7,67,  9,55, 14,45, 12, 6,  8,48,  1,46,  3, 9,  2,31,  5,41, 
     3,23,  5,67,  2,33,  9,27, 13,78, 11,64, 12, 5,  6,16, 10, 6,  4,44,  8,43,  0,49, 14,12,  1,17,  7,85, 
     1,50,  6,56,  7,80,  5,54, 11, 8,  3,70, 12,83,  9,18,  2,31, 10, 4, 13,90,  4,87, 14, 1,  0, 5,  8,61, 
     5,22,  4,15, 10, 4,  9,40,  0,69,  6,98,  3,44,  1,77,  7,23, 13,14, 12,96, 11,90, 14,90,  8,78,  2,71, 
    11,94, 13,30,  6,51,  5,86,  1,69,  8,52, 14,11,  0,29,  3,37, 12,70,  4,34,  9,13,  7,10, 10,61,  2,48, 
    11, 7,  9,74,  2,14,  1,65, 12,19,  0,17,  8, 4, 13, 5, 10,27,  5,93, 14,91,  6, 9,  4,69,  7,35,  3, 5, 
    12,40,  8,89,  6,73,  4,92, 14,58, 13,68,  0,97,  9,94,  1,77,  3,43,  7,52,  5, 8, 10,41, 11,21,  2,56, 
     0,71,  4,43, 12,11,  6,65, 14,11, 10,15,  5,46,  7,78,  3, 3, 13,27,  1,33,  2,87,  9,97,  8,59, 11,37, 
     6,68, 11,96, 13,30,  5,84,  2, 2, 12,81,  0,57,  4, 7,  1,70, 10,39,  8,62,  3,94,  7,96,  9,38, 14,46, 
     5,96,  6,34, 11,71,  0,88,  2,10, 12,99,  4,48,  8,57,  7,31,  9,93, 13,33, 10,84, 14,28,  3,32,  1,72, 
     2,96,  6,15, 13,31,  7,93,  5,21,  0,40,  9,99,  4,60, 14,63, 10,95,  1,45, 12,33,  8,83, 11,11,  3,75, 
     7,47,  2,71,  8,37,  9,59,  0,72,  6,64,  4,61,  1,52, 11,20, 14,13, 10,11,  3,26,  5,28, 13,91, 12,27, 
     7,31, 11,76, 14, 4, 12,35,  4,18, 13,50,  5,16,  8,52,  2,85, 10,43,  3,44,  9,21,  1,72,  6,24,  0,12, 
     9,71,  7,30, 12,58,  4,71, 10,87,  1,74,  8,33, 13,26, 14, 3,  3,75,  0,87,  2,14, 11,33,  6,52,  5,38, 
     8,42, 14,39,  9, 8, 10,26,  7,26,  6, 9,  4, 1, 12,83,  1,85,  2,11, 11,81,  0,72,  3,87,  5,41, 13,44, 
    14,73,  7,59,  9, 4,  5,25, 10,68,  6, 3,  4,72, 12,69,  2,50, 13,62,  8,22,  0,77,  1, 1, 11, 4,  3,94, 
    14,59,  8,45, 13,39,  4,64,  9,35,  7,42, 10,16,  0,88, 12, 9,  1,88,  5,85,  2,54,  3,63,  6,21, 11,76, 
     8,66, 11,23,  1,28,  4,12,  9,22, 14,65,  0, 9,  3,27,  5,25, 12,75, 10,85,  7,19,  6,41,  2,20, 13,25, 
    10,28, 11,96, 13,37,  3,58,  9,94,  4,40,  2,42, 12,41,  6,20, 14,80,  5,29,  8,12,  1,81,  7, 8,  0,28, 
    14,83, 12,17,  6,26, 10,78,  4,95,  1,45, 13,16, 11,53,  2,12,  5,50,  7, 6,  8,87,  3,44,  0, 5,  9,63, 
     0,13, 14,85,  9,49,  1,73,  4,48, 11,44,  3,84, 13,85,  6, 1,  2,12, 10, 3,  8,39, 12,75,  7,73,  5,45, 
    11, 3,  3,15,  0,40, 13,77,  8,43, 14,91,  2,51,  7,17, 10,71, 12,33,  5,83,  6,61,  9,68,  4,14,  1,97
  };
  // Taillard 50x15 instance 5
  const int tai_50_15_5[] = {
    50, 15, // Number of jobs and machines
     7,34,  8,91,  0,93, 14,88, 11,59,  6,66,  5,50,  9,53, 13,45,  1, 1,  2,68, 12,77,  4,37, 10,61,  3,17, 
    14,19,  0,73,  6,15, 10,72,  1,38, 11,52,  2,14,  9,69,  8,19,  3,29,  4, 3,  5,48, 12,11,  7,54, 13,28, 
    10,59,  6,29,  3,84, 11, 4,  0,19,  5,35,  4,22,  1,50, 13,68,  2,28, 12,96, 14,23,  9,74,  7,90,  8,51, 
    11,14, 14,86,  3, 8,  0,85, 12,49,  9,56, 10,87,  7, 2,  5,85,  6,60,  2,97,  8,51,  4,39, 13,34,  1,89, 
     5,99,  7, 5,  0,39,  3,39, 10, 3,  1,73,  9,16, 11,62,  8,29, 12,68, 13,14, 14,38,  2,90,  6,56,  4,32, 
     6,23, 13,84,  1,34,  7,77, 10,25,  0,44, 11,45,  8,14,  9,79,  5,90, 12,78, 14,56,  4,37,  3,61,  2,96, 
    14,24,  8,15,  3,99,  9,49,  5,66,  0,99,  1,87,  6,11,  2,45,  7,84, 12,20, 10, 9,  4,71, 13,50, 11,54, 
     8,67, 13,11,  0,97,  3,63, 10,64,  1,33,  2,66, 14, 4, 11,89,  7,60,  5,51,  6,13, 12,33,  9,48,  4,70, 
     6,56, 10,66,  1, 8, 11,92,  5,81,  4,94, 12, 5,  9,21,  2,69,  8,61, 13,50, 14,99,  7,49,  0,26,  3,83, 
     4,14,  9,38,  6,82, 10,99,  8,77,  1,17,  7, 9, 14,21, 13,15,  5,43,  2,39, 11,39, 12,80,  0,19,  3,43, 
     4,76,  1,94,  3,34,  7,45, 13, 7,  5,83,  8,88, 10,47, 12,22,  0,90,  6,11, 14, 6, 11,22,  2,40,  9,51, 
     9,72,  7,65, 10, 2,  2,38,  6,96, 12,10,  8,58, 13,65, 14,17,  5,75,  1,65,  0,79,  3,83, 11,45,  4,52, 
     3,23,  2,35, 12,24,  4,67, 11,65,  7,18,  5, 7,  1,68, 14,19, 10,63,  8,18,  9,80, 13,19,  6,23,  0,39, 
    13,47, 14,70,  1,38,  3,14,  2,46, 11,48,  9,14,  8,45,  6,31,  0,35, 12,95, 10,75,  7,61,  5,44,  4,71, 
    10,26,  3,14,  2,46, 11, 1,  5,23,  9,50,  0,27, 12,82,  8,26, 13, 7,  4,55,  7,22, 14,21,  1,85,  6,66, 
     2,11, 13,84, 14,48, 11,49,  1,19,  5,98,  3,92,  4,42,  8,67, 12,57, 10,40,  0,78,  6,19,  9,52,  7,14, 
     6,12, 11,71,  3,17, 10,67,  4,20,  2,41,  0,74, 14,96,  7,87, 13,20,  1,84, 12,77,  9,72,  8,91,  5,37, 
     6,12,  8,12, 10,66, 14, 2,  1,17,  5,33,  3,30,  0,10,  9,72,  4, 6, 12, 6, 11,41, 13,39,  7,71,  2, 4, 
    10, 3,  1,89,  2, 9,  5,24,  7,80, 12, 7, 13,42, 11,85,  0,84,  9,89,  3,40,  8,42,  4,92, 14,91,  6,77, 
    12,98,  4,83, 11,65, 13,94,  9, 6,  8,96,  7,34, 10, 7,  0,49,  2,25,  3,47,  6, 8,  5,93, 14,67,  1,50, 
    11,52,  6,57,  0,73, 12,45, 14,55,  7,63, 10,99,  5,20,  2,59,  4,90,  8,31, 13,23,  3,99,  9,92,  1,53, 
    14,64,  7, 4,  9,25,  1,52,  4,72, 13,41,  5,11,  0,99,  2,35, 12,77, 10,89, 11,98,  6,63,  8,59,  3,99, 
     9,80,  5,93,  1,64, 14,13,  2,48,  3,47,  0,78, 11,59, 12,58, 10,73,  4, 3,  8,28,  7,13, 13,72,  6, 9, 
     9,24, 10,95,  3,93,  8,48,  0,78,  5,64,  6,26,  4,86, 12,83,  2,41, 14,62,  1,53,  7,35, 13,84, 11,45, 
    14,91,  8,86,  9,79,  5, 5, 11,85,  0,29, 12,73, 13, 9,  4,74,  7,69, 10,23,  1,80,  6,82,  3,34,  2,88, 
     6,76, 10,77,  7, 2, 13,28, 12,27,  3,27,  2,87, 11,33,  5,41,  4,99,  1, 2,  0,44,  8,16, 14,83,  9,91, 
    10,96, 11,27,  9,61, 13,42,  3,99,  7,76,  6,87, 12,36,  0,24, 14,21,  1,88,  4,43,  8,89,  5,78,  2,53, 
     5,86,  7,72,  3, 3, 14,91, 13,33, 10, 1,  8,37,  9,39,  1,30, 12,78,  2,52,  0,52,  4,64, 11,88,  6,75, 
     9,98, 10,52,  4,99, 14,11,  8,57,  6,40,  1,52,  2,75, 11,23, 12,49, 13,65,  0, 1,  3,57,  7,56,  5,92, 
    10,82,  1,33,  4,80,  2,23,  3, 7, 12,49,  5,24,  0,50,  9,29, 14,38,  8,47,  7, 3,  6,53, 13,89, 11,70, 
     3,32,  9,62, 11, 9,  5,88,  4,58,  2,70, 14, 9,  0,66, 12,18,  1,40, 10,33, 13,54,  8,60,  7,92,  6,88, 
     6, 2,  2, 5, 12,35, 13,65,  4,67,  0,58, 10,61,  1,72,  5,60,  9,84, 14,88,  7,23,  8,17, 11,71,  3,13, 
     0,65, 14,56, 11, 5,  5,94,  6,82,  7,76,  1,29,  3, 1,  4,93,  9,66, 13,47, 10,32,  8,42,  2,75, 12,13, 
    13,14,  6,86,  4,65, 11,41,  9, 3,  5,10,  2,49, 12,26, 14,10, 10,86,  0, 1,  3,32,  7,38,  8,48,  1,93, 
     0,98,  1,21, 13,61,  2,61,  4,54,  7,71, 12,98,  3,39, 10,14,  8,38, 11,74,  6, 2,  9,12,  5,93, 14,85, 
     7,93,  2, 1,  4,26,  3,57,  6,38,  9,80, 11,43, 13,64, 10,23,  8,88,  1,74, 14, 5,  5,16, 12,50,  0, 1, 
     1,23, 12,55,  2,72,  5,57,  0,46,  7,17, 13,80, 10,44, 14,80,  4,55, 11,75,  6,69,  9,34,  8,44,  3,30, 
    14,64,  4,93,  9,55, 12,78,  2, 9, 13,24,  7,59,  1,72,  5,30,  8,50, 11,81,  0, 7,  3,53,  6,69, 10, 3, 
     7,63, 10,40,  2,81, 13,33,  8,52,  0,86,  9, 2, 12,43,  3,57,  6,36, 11,53,  4,18, 14,22,  5,92,  1,40, 
     5,60, 14,79,  4,43,  2,83,  9,76,  0,79,  7,53,  6,72, 12,40,  3,37, 13,66,  1, 3, 10,52,  8,33, 11, 9, 
     1,28, 13,70,  0, 7, 14,51,  2,33, 12,57,  7,89,  9,60,  8,64,  4,36, 11,75, 10,49,  5,13,  6,36,  3,65, 
    11,74,  1,97,  0,88,  7,27,  6,95, 14,99, 12,17,  2,31,  5,87, 13,34,  8,28, 10,16,  4,16,  9,94,  3,14, 
    10,63,  8,47, 11, 6,  9,43,  4,48,  5,65,  0,83, 12,98,  1,58, 14,60, 13,12,  2,48,  7,93,  3,77,  6,32, 
    12,32, 13,94,  9,71,  5, 3,  1,20,  6,45,  3,10,  2,45,  0, 6, 11,57,  8,35,  4,76,  7,46, 10,87, 14,25, 
    14,45,  8,63,  9,82, 13,23, 11, 1, 10,13,  7,50,  3,64,  4,82,  2,55,  5,42,  0,14,  6,35, 12,15,  1,47, 
     9, 6,  6, 6, 12,28, 10,96,  2, 2,  7,85,  1,97,  4,90,  0,83,  5,76, 11,65,  3,46, 13,71,  8,42, 14,61, 
    12,95,  2,54,  1,46,  9,33,  6,13, 14,71,  5,37,  8,60,  3,50, 13,30, 11,56,  0,10,  7,62, 10,76,  4,57, 
    10,96,  2,64, 11, 6,  5,90,  9, 1,  0,99,  4,86, 13,27,  7,18,  8,56, 14,19,  3,73,  1,76,  6,82, 12,78, 
     6,98,  5,69, 10,68,  9,45,  4,17, 12,29,  3,15, 14,81,  0,31,  2,79, 13,54,  8,50,  7,73, 11, 2,  1,86, 
     8,44,  0,78, 14,31,  6, 8,  4, 8,  5,15, 10,95, 12,83,  9, 3,  7,30, 13,39,  3,92, 11,47,  2,49,  1,45
  };
  // Taillard 50x15 instance 6
  const int tai_50_15_6[] = {
    50, 15, // Number of jobs and machines
    11,30,  3,16, 12,71,  0,30, 14,78,  9,46,  1,18,  6,32,  2,34, 13,88,  7,94,  4,85,  5,83,  8,30, 10,73, 
     2,14,  8,51, 14, 6,  1,33,  0,17, 10,22,  6,63, 12,71,  7,14,  9,87,  3,58,  4,37, 11,55, 13,73,  5,78, 
    13,39,  0,26,  5,79,  6,10, 14,48, 11,48,  4,97,  3,22,  7,89,  9, 1, 12, 3,  8,44,  2, 9, 10,77,  1,40, 
    13,79,  4,66,  9,39, 11,61,  1,57,  6,96, 12,98,  2,54, 10,88,  3,21,  0,92,  7, 3, 14,39,  8,21,  5,73, 
     9, 5,  3,65,  4,93,  7,90, 11,64,  0,30,  8,93, 10,88,  6,91,  5,47, 14,26, 12,79,  1, 3,  2,77, 13,39, 
     2, 6,  0,61,  5,92,  3,22, 12,18,  1,52,  4,82,  6,48,  9,32,  7,73,  8,49, 10,16, 14,76, 13,55, 11,38, 
     6,16,  1,29,  9,93,  2,89,  7,61, 10,47,  4,25, 11,38,  0,28, 13,46, 14,93, 12,68,  3,99,  5,41,  8,59, 
     2,50, 13,77, 14,11,  4,79,  3,98, 10,66,  7,23,  9,15,  6,24,  5,41,  1, 8, 11,57, 12,68,  0,52,  8,30, 
     7,26, 14,36, 12,79,  2,92, 13,93,  8,11,  6,18,  0,71,  1,26,  5,95, 11,14,  9,86,  4,41,  3, 3, 10,47, 
    10,14,  5,16,  7,56,  3,74, 12,92,  6,33,  2,93,  0,68, 13,70,  8,38, 14,64,  9,79, 11, 8,  4,69,  1,74, 
    13,87,  4,74, 14,84,  6,78,  3,49,  2,45,  5,44,  8,53,  9,83, 12,28,  7, 3,  0,48, 11, 6, 10,52,  1,53, 
     9,71, 14, 9,  7,73,  6,90, 11,58, 12,16,  4,90,  5,54, 10,48, 13,64,  3,17,  1,63,  8,64,  0,98,  2,96, 
     8,58, 10,47,  7,95, 11,34, 13,14,  1,11,  2, 2,  3,52, 14,29, 12,65,  9,86,  4,60,  5,13,  6, 5,  0,16, 
     5,64, 10,29,  2,35,  4, 6,  7,90,  9,42, 12,36,  3,29, 13,57,  1,39, 14,52,  6,39,  8,93,  0,21, 11,77, 
    13,85,  1,98, 11,44,  7,85,  3,45,  8,64,  5,33,  4,49,  2,23,  6,84,  0,53, 14,17,  9,48, 12,31, 10,11, 
     3,33,  4,89,  7,48,  9,20,  8,95,  5,57, 11, 8, 14,19, 12,21,  2,36,  6,65, 10,37,  0,93, 13, 4,  1, 2, 
    10,51,  3,57,  9,69, 14,74,  0,95,  7,79, 13,37, 12,82,  6,75, 11,20,  4,49,  8,38,  1,78,  2,97,  5,73, 
     9,68, 12,91, 13, 5, 14,50,  6,32,  2,48,  4,39,  7,81,  0,32,  8,68, 11,92,  3,74, 10,27,  5,60,  1,59, 
     7,82,  3,63,  6,18, 12,32, 13,69, 14,82,  0,76,  5,39,  8,72,  1,90, 11, 4,  2,54, 10,79,  9,81,  4,72, 
     3,98, 11,97, 12,37,  4,95,  6,93,  0,56, 13,46,  8,85,  5, 7,  9,78,  7,71,  1,69, 10,47, 14,41,  2,64, 
     4,65,  2,64,  1,28,  3,46, 13,27, 10,53, 12, 6,  8,71, 14,12,  5,15,  7,61,  6,89, 11,56,  0,35,  9, 9, 
     7,86,  8,86,  5,72,  3,13, 13,69,  0,39, 10,98, 12,28, 11,32,  6,64,  2,21,  1,86,  4,50,  9, 8, 14,90, 
     8,96, 13,82, 14, 2,  5, 4, 12,27, 11,43, 10,35,  9,73,  2,97,  3,21,  7,78,  0,95,  6,76,  1,73,  4,89, 
     0,19,  9,17,  1,55,  8,53,  6,89, 12,40,  5, 3,  7, 3,  4,14,  3,40,  2,69, 13,50, 10,20, 14,41, 11,30, 
     8, 9,  5,75,  7,67,  2, 4,  6, 8, 11,70, 13,38,  4, 1,  9,99,  0,49,  1,43, 14,74, 12,31, 10, 9,  3, 1, 
    10,85, 11,90,  3,94,  8,15,  2,73,  7,50, 14,81,  4,26,  1,91,  5,10,  0,58,  6,32,  9,78, 13, 1, 12, 7, 
    11,58,  0,95,  5,31,  8,99,  9,89,  4,92,  1,18,  6,42,  2,95,  3, 7, 14,81, 10,47, 13,53, 12,94,  7,52, 
    11,13,  0,57,  8,45,  2,71,  1,16,  6,90, 13,25,  9,52, 14,72, 12,11, 10,21,  4,27,  5,34,  3,89,  7,27, 
     2,40, 12,44,  7,17,  4,94, 13,39,  8,49,  0,52,  9,17,  5,79, 11,44,  1,70,  3, 1, 10,67,  6, 1, 14, 8, 
     8,98,  3,38,  6,53,  1,98, 12,41,  7,63, 11, 2,  4,68,  9,28,  2,75, 10,14, 14,21, 13, 8,  5,65,  0, 1, 
     2, 5,  6,40,  7,27, 13,93,  8,65,  3,93,  1, 7, 10,39, 14,42, 11, 8,  9,29,  5,27, 12,57,  4,17,  0,77, 
    13,39,  5,18,  2,17, 12,93,  1, 8,  6,57,  4,66,  0,76,  3,28,  8,21,  7, 2,  9,82, 11,66, 10,77, 14,94, 
     0,75, 13,13,  4,48, 10,13, 14,39,  7,16,  8,69,  1,39,  3,35,  9,75,  6,85,  5,55, 11,45, 12,55,  2,85, 
     4,85, 13,82, 10,13,  5,89,  8,34,  2,10,  1,95,  3,38,  6, 4, 14,10, 12,84,  7,88, 11,65,  9,25,  0,50, 
     9,75, 13,74,  3,84,  5,71, 12,54, 14,53,  6,86,  1,11,  4,72, 10,27,  2,89,  7,60,  8,25, 11,17,  0,86, 
    12,16,  6,66, 11,24,  4, 6,  1,81,  9,26,  8,68,  5,41,  0, 2, 13,87,  2,86, 14,71, 10,32,  3,34,  7,69, 
     3,22, 10,16,  4,45, 13,56,  9, 8,  7,62, 14,20, 12,84, 11,87,  8,59,  2,53,  1,81,  0,43,  5, 3,  6,22, 
    13,28, 12,23,  1,66,  2,27,  8,49,  0,46,  7,49,  4,64, 10,43,  6,12,  9,95,  5,38,  3,31, 11,49, 14,18, 
    13,20,  8,22,  2,90,  7,84, 11,14, 12,36, 10, 5,  9,80,  6,99,  4,93,  1,67,  0,58,  3,37,  5,13, 14,55, 
     6,98, 11,88,  3,38,  4,95,  8,87,  2,69, 10,99, 13,85,  7,75,  5,39,  9,77,  1,57, 14,82,  0,96, 12,52, 
     8, 9,  2,89,  7,82, 13,81,  9,16,  3,40, 14,74, 12,27,  0,33,  1,33, 10,15,  6,78,  5,58, 11,79,  4,28, 
     6,64,  4,92,  8, 8,  9,48,  2,75,  5,29, 13,69,  1,33, 12,83, 11,19, 14,97,  0,74,  7,98, 10, 3,  3,39, 
    13,68,  9,87, 12,88,  3,72, 14,84,  5,26,  8,11,  7,95, 10,94,  4,90, 11, 8,  0,17,  1,53,  2,92,  6, 6, 
     7,97,  3,96, 10,29,  1,68,  8,96,  5,69,  0,95, 11,90,  9,67, 13,53,  2,23,  4,18, 14,54,  6,49, 12,18, 
    11,78, 13,44,  8,69,  1,25, 12,48,  4,77,  2, 1, 10,70,  6,14,  9,25,  3,95, 14,25,  0,53,  7,64,  5,39, 
     1, 3, 11,80, 10,70,  7,59,  5,43,  3,54, 14,54,  2,59, 13,29,  6,62,  4,89,  9, 3,  0,59, 12,79,  8, 8, 
    14,38, 11,15,  1,18,  8,76,  5,21, 13,82,  0,84,  9,53,  4,18, 12,74,  6,59, 10,61,  3,11,  2,58,  7,10, 
    10,22,  5, 7,  7,89,  2,39, 11,44,  4,41,  3,41, 14,83,  9,54,  0,87, 12,86,  6, 7,  1,70, 13,55,  8,73, 
    14, 5, 12,59, 10,22,  6,59,  4,68, 13,99,  8,41,  7,27,  2,62, 11,80,  5,30,  3,37,  1,60,  0,76,  9, 4, 
    12,24,  2,95, 10,67,  3,85,  4, 8,  0,15, 13,73, 14,52,  7,12,  5,39,  6,16,  8,62,  1,61, 11, 9,  9,53
  };
  // Taillard 50x15 instance 7
  const int tai_50_15_7[] = {
    50, 15, // Number of jobs and machines
    11,86,  1,13,  2,65,  8,20,  5,76, 13,82, 10,42, 14,10,  4,50, 12,29,  9,30,  6,53,  3,52,  7,19,  0,24, 
     1,19,  0,76,  3,77,  9,73,  5,76,  4,87, 10,61, 13,51,  2,61,  6,99,  7,38, 12,98,  8,34, 11,34, 14,44, 
     9,29,  7,80,  4,63,  0,15,  2,75,  1,27,  8,98, 10,38,  3,57,  5,80, 12,56, 14,54, 11,55,  6,35, 13,15, 
     0,72, 12,73,  3,67, 11,58, 10,14,  2,59, 13, 6,  7,70, 14,88,  6,66,  8,65,  4,96,  9,95,  5,56,  1,16, 
     3,21,  1,78,  9, 3,  5,76, 10,10,  8,46,  2,98,  0,12, 13,55,  7,92,  4,42,  6,68, 14,67, 11,75, 12,97, 
     5,30,  4,20, 10,80,  8,16,  3,76, 13,45,  1,97,  9,70,  6,54,  2,38, 11,76, 14,84,  0,55, 12,93,  7,67, 
    11,81,  3,53,  9,37,  2,84,  4,33, 13,69,  7,52,  6,11, 10, 2,  0, 7, 14,79, 12,36,  8,78,  1,92,  5,19, 
     7,28,  9,78,  0,62, 12,17, 13,38,  1,66,  3,68, 14, 6,  4,60,  5,93, 11,47,  6,63,  2,26, 10,58,  8,46, 
    14,19, 11, 4,  2,66, 12,51, 13,61,  4,16,  5,72,  9,20,  7,85,  6,95, 10,37,  0,21,  8,94,  1,64,  3, 8, 
    12,45,  1,84, 14,52, 10,50, 11,77,  2,38,  8,60,  3, 2, 13,50,  9,65,  7,71,  0,67,  5,95,  6,71,  4,24, 
     5,32, 14, 6,  2,42, 12,74,  7,56,  3,38,  6,55, 10,84,  1,96, 11,86,  9,47,  4,38,  8, 4, 13,72,  0,91, 
     7,81, 11,49,  1,40,  4,57,  6,16,  2, 7,  8,13,  9,18, 13,96, 10,84,  5,53, 14,70,  0,94, 12,74,  3,89, 
     8,71,  1,66,  3,45, 10,27, 11,79,  7,75,  6,71,  0,88, 13,14,  2,36, 14,88,  4,23, 12,52,  5,74,  9,78, 
    11,46,  6,69, 12,24, 13,20,  4,37,  1,53,  0,82,  9,34,  8,54,  5,47, 10,13,  2,28,  3,78,  7,42, 14,86, 
     8,46,  4,88,  3,37, 13,75,  1,56,  2,77, 12,21,  6, 8,  9,52,  0,53, 14,12,  5,81, 11,72,  7,79, 10,98, 
     8,12,  2,10,  5,98,  3,15,  4,55, 12,48, 14,91,  1,11,  9,28, 10,42,  6,13, 13,85,  0,15,  7,21, 11,24, 
     0,44, 10,46,  4,79,  7,13,  6,48, 14,78, 11,67,  9,72,  2,87,  5,64,  1,21, 13,58, 12,75,  8,86,  3,10, 
     1,32,  8,73,  6,70,  2,30,  9,91,  4,63, 13,33, 11,38, 10,42,  3,82, 14,71,  7,70,  5,78,  0,15, 12,80, 
    12, 6,  5,27, 11,79,  2,59,  7,77,  3,99, 14,27,  1,26,  8,61,  4,11, 13,20,  9,66,  6,96, 10,55,  0,48, 
    14,57,  8,47,  4,84,  5,84,  0,92,  2, 4, 11,62,  9,23,  1,56,  6,99, 13,68, 10, 5,  3,31,  7,83, 12,31, 
     3,24,  4,43, 13,48, 11,79,  7,40, 12,57,  6,90,  9,83, 14, 8,  5,99,  8,29,  1, 8,  0,40, 10,64,  2,57, 
     7,77,  8,53, 14, 1,  5,99,  2,39,  0,81,  1,58,  9,94, 10,41, 12,93,  6,61,  4,24, 13,32,  3,31, 11,48, 
     6,42, 11,39, 14,60,  7,41, 12,40,  9,45,  8,14,  0,27,  1, 8,  2,29,  4,89, 13,92,  3,74, 10,97,  5,16, 
     9,14,  2,28,  3,10, 14, 6,  8,27,  1,57, 10,54,  4,62, 13,57, 11,98,  6,32,  5,32,  7,21, 12,61,  0,66, 
     2, 6, 11,13,  1,33,  9,88,  0,92,  4,20, 12,79,  5,63,  8,29,  6,97,  7,66, 13,59,  3, 2, 10,83, 14,20, 
     1,36, 11,35,  8,70,  0,34, 12,60,  3,63, 10,90, 14,94,  7,56, 13,27,  2,49,  4,93,  6,27,  5,39,  9,44, 
     5,19,  3,13, 11,54, 12,69, 14,56,  2,32, 10,80,  8,30, 13,49,  6,74,  9,79,  0,25,  4,69,  1, 9,  7,51, 
     7,37,  8,92,  2,59,  5,11, 13,41,  4,68,  9, 3,  6, 6, 14, 3, 10,54, 12,98,  0,82,  3,21, 11,61,  1,95, 
     2,79,  0,15, 11,44,  5,91,  7,93, 12,38, 10,90, 13,21,  9,42,  6,40,  1,15,  8,24,  4,97,  3,34, 14,27, 
     7,74, 11,69,  9,81,  0, 7,  6,71,  8, 6,  4,32, 12,15,  2,28,  3, 6, 14,53,  5,73,  1,65, 13,29, 10,37, 
    14,45,  2,87,  8,27, 10,76,  7,64,  4,35,  3, 4,  1,57,  9,43,  0,98, 11,62,  5,49, 13,44, 12,75,  6,38, 
     6,93,  8,78,  7,92, 11,44,  4,20,  2,83,  3,51,  1,68, 10,91, 13, 7,  9,97,  5,69,  0,97, 14,94, 12,58, 
    13,80,  2,80,  1,22, 14,51,  6,71,  0,25, 12,13, 11, 7,  4,88, 10,26,  5,83,  7,73,  3,73,  9,39,  8,58, 
     0,77,  3,19, 14, 9,  7,60,  9,19,  2,87, 10,60,  4,48, 11,86,  6,50,  8, 7,  1,19,  5,14, 12,52, 13,97, 
     4, 4,  3,86, 11,56, 13,86,  7,49,  5,16,  0,46,  8,93,  6,87, 12,39,  2,22,  1, 1, 14,71, 10, 4,  9,84, 
     7,39, 13,84,  4,98,  8,95, 12,22, 14,48, 10,28, 11,27,  0,21,  5,55,  2,80,  9,10,  1,89,  3,87,  6,76, 
    12,69, 10,80,  4,59,  1,98,  8,76,  5,12,  9, 4,  2,58, 11,24,  0,86, 14,45,  6,89,  3,17,  7,30, 13,81, 
     0,22,  5, 5,  4,28, 14,18, 13,46,  1,88,  2,10, 10,90,  9,80,  8,53, 12,41,  6,98, 11,28,  7,12,  3,25, 
     2,93, 11,19,  9,83,  1,58,  7,61, 14, 7,  0,88,  5,17, 12,81,  3,69,  6,76, 13,12,  4,71,  8,61, 10,28, 
    12,21,  3,20, 10,89,  6,38,  9,91,  0,49,  2,42, 11,26,  7,89, 14,80,  8,10,  4,15,  1,49, 13,45,  5,59, 
     5,86, 10, 2, 12,20,  0,17,  8,48,  7,46,  6, 6,  9,43, 11,16,  1,51,  2,74,  4,81, 14,74,  3,64, 13,15, 
     6,47, 13,98,  7,32,  9,35,  3,81,  1,96, 14,42,  4,15, 11,35, 12,92,  2,55, 10,98,  5,61,  8,74,  0,30, 
     4,44,  8, 8,  9,53,  7,45,  6,71,  2,65,  5,87, 13, 4,  3,35, 11, 9, 10,30,  0,56, 14,67, 12,68,  1,90, 
     1,62,  7,31,  8,14,  2,43, 12,21,  9,58, 11,82,  4,85, 14,88, 10,33,  3,39,  6,70,  5,63,  0,82, 13,57, 
     7,71,  4,99,  8,78, 10,83,  3,88, 13, 9,  2,50, 12,38,  0,76,  1,85,  9,97, 14,19,  5,68,  6,51, 11,25, 
     2, 3, 14,57, 12,75,  7,95,  4, 6, 13,31,  5,79,  9,86,  0,95,  3,87,  1,66,  8,35, 10,68,  6,17, 11,18, 
     7,68,  2,71, 11,84, 13,64,  8,53, 10,67,  4,44, 12, 1,  9,63,  0,27,  3,10,  5,21, 14,50,  1,13,  6,76, 
     9,56, 14,77,  1,40,  2,82, 12,75, 11,92,  4,17,  7,72,  5,10, 10,12,  0,48,  3, 5,  6, 3, 13,13,  8,33, 
    12,25,  0,86, 10,32,  4,31,  8,14,  9,58,  7,31, 11,62,  3,41,  2,55,  5,44,  1,13, 14,53,  6,33, 13,63, 
    11, 8,  3,95,  5,44, 10,38,  1, 6,  6,95, 14,87, 13,47, 12,42,  0,72,  4,93,  2,92,  8,38,  9,98,  7,55
  };
  // Taillard 50x15 instance 8
  const int tai_50_15_8[] = {
    50, 15, // Number of jobs and machines
    10,46,  4,43,  0,25,  6,99,  2,90,  3,21, 12,27,  1,17,  5,16, 11,88,  8,64,  7, 9, 14,50, 13,55,  9,22, 
    14, 9,  5,39,  2,58,  6,16,  3,98,  7,58,  9,81,  8,51,  0,10,  1,31, 13,49, 10,65, 12,48, 11,62,  4,51, 
    11,54, 14,46,  2,96,  5,46,  7,16, 13,17, 12,72,  0,51,  3,33,  9,91, 10,18,  4,84,  6,87,  1,31,  8,51, 
     6, 3,  3,94,  4,91,  9, 2,  2,50,  0,89, 12,78,  7, 5,  5,30, 11,10, 10,22, 13,76,  1,50,  8,45, 14,28, 
     1, 5, 10,53,  0,57,  9,14,  5,90,  4, 8,  7,52, 12,76, 11,59,  3,15, 13,39, 14,40,  6,54,  8,57,  2,52, 
     2,31,  0, 2,  8,56,  4,64, 12,55,  9,96,  6, 6, 14,36, 13,29,  5,57,  3,86,  1,69,  7,54, 10,76, 11,89, 
     0,39, 11, 7,  2,32, 13,74,  8,90,  4,66, 10,76, 12,53, 14,46,  7,27,  1,83,  6,49,  3,72,  5,22,  9,53, 
     3,83,  2,18,  4,86, 10,89,  6,93, 12,63,  5,34, 13,97,  8,84,  9,61, 14,32, 11,48,  0,23,  1,81,  7,61, 
    12,32, 10,11,  1,18,  4,54,  7,96,  9,67,  6,73,  2,61,  3,15, 11,67, 14,34,  5,37, 13,65,  0,44,  8,32, 
    12,79,  5,23, 14,51,  7,60, 10, 9,  9,54,  6,85,  4,88,  3,83,  8,55, 11,87,  2,93, 13,80,  0,72,  1, 5, 
    10,54,  5,54, 14,54,  3,59,  2,49, 13,68,  7,56,  4, 9,  9,23, 12,58, 11,88,  6,82,  8,10,  0,87,  1,54, 
     5,72,  0,84, 14,29, 10,59,  9,60,  6,98, 11,41, 12,87,  8,27,  2,31,  1,79, 13,69,  7,64,  3,86,  4,77, 
     1,71, 12,61,  3,33,  5,55,  0,83,  8, 9, 11,87,  9,19,  2,49,  4,68, 13, 4, 14,24,  7,41,  6,49, 10,77, 
     8,36, 11,23, 10,36,  6,41,  5,56,  0,68,  4,81,  1,49, 14,45,  7,67, 12,89,  2,60,  3, 1, 13,58,  9,28, 
     6,43,  7,76,  1,42,  2,59, 10,50, 14, 3, 12,26,  8,41,  9,66,  0,52, 13, 8,  4,33,  3,40,  5,39, 11,50, 
     1,65,  8,30, 10,49,  4,14,  6,64,  7,34, 13,35, 14,66, 12,16,  5,45,  3,36,  0,80,  2, 5,  9, 2, 11,63, 
     1,53,  0, 7,  8,34,  3,53, 12,43,  2,85,  6, 9,  4,64, 14,92, 11,65, 10,15, 13, 1,  7, 6,  9,95,  5,82, 
     2,11,  7, 3, 14,33,  4,62,  9,70, 10, 6,  3, 3,  5,35,  6,57, 13,76, 12,38, 11,28,  8,78,  1, 7,  0,17, 
     6,40,  4,55,  1,21, 12,11,  0,58, 14, 8,  3,38,  8,19,  2,25,  7,55, 13,39, 10,92, 11,30,  5,94,  9,39, 
     8,34,  0,18, 14,99,  3,28,  7, 2,  6,41,  1,35, 13, 6,  5,70, 11, 4, 12,95,  2,59,  9, 7,  4,88, 10,71, 
    11,39, 13,48,  7,27, 14,27,  1,23, 12,80,  4,35,  5,67,  3,22,  9,85,  8,70, 10,36,  0,43,  2,80,  6,60, 
    12,15,  4,22,  1,93, 13,85,  6, 9,  0,38,  5,98,  8,25,  3,64, 10,45, 11,96, 14,36,  7,37,  2,46,  9,89, 
     2,23,  9,20, 10,46,  7,91, 11,45,  4,67,  8, 6,  0,69,  5,82,  3,76,  6, 5, 12,71, 13,82, 14,70,  1,72, 
     5,36,  9,93,  3,23,  1,13,  2,80, 12,44,  0,95,  7,81, 14,44,  4,44, 10,85, 11,58,  6,62, 13,18,  8,94, 
     5,60, 12,68,  4,84, 11,35,  9,92, 14,62,  8,94,  1,89,  3, 1,  2,48, 10,36,  0,35,  7,28,  6,37, 13,41, 
    14,62, 10,35,  2,62,  3,15,  0, 8,  9,18, 11,21, 12,28,  7,72,  6,65,  1,82,  5,16, 13,40,  8,93,  4,41, 
    14,12,  2,14,  9,53,  1,20,  7,99,  5,30,  8,48,  3, 9,  4,51, 12,12,  0,60,  6,51, 11,80, 13,81, 10, 9, 
     8,61, 14,62, 11,33,  7,61,  6,73,  9, 3, 12, 1, 10,19,  0,80,  4,40,  1,16,  5,23,  3, 7, 13,82,  2, 4, 
     2,12, 12,76,  4,95, 13,63, 14,52,  6,60,  9,86,  3,67,  5,26,  1,25,  0,85,  8,12,  7,86, 11,92, 10,73, 
    13,57,  3,56,  1,47,  6,98, 10,55, 11, 3,  9,29, 14,33,  0,24,  7,92,  5,51, 12,66,  4,38,  2,19,  8,59, 
     3,12,  1,54, 11,73,  6,33, 12,23,  7,75, 10,69, 14,93,  5,64, 13,46,  8,44,  0,81,  2, 1,  4,78,  9,98, 
     0,22,  2,95,  4,28, 13, 8,  5,59, 10,63,  3,87, 11,84,  7,22,  1,43, 14,85,  9,99, 12, 9,  6,11,  8,79, 
     9, 2, 10,20, 12,49,  5,32,  6,49, 14,17,  2,71,  0,79,  7,25,  3,78,  4,33,  1,20, 13,84, 11,60,  8,67, 
     4,12,  8,45,  0,81, 11,29,  2,41,  9,87,  7,57, 12,68,  1,79, 10,97,  3,16,  5,61, 13,63, 14,25,  6,51, 
     2,41, 14,33,  1,80, 11,76,  0,74,  6, 3,  4,55,  3,32, 10,20,  5,77, 12,60,  7,62,  9,70,  8,68, 13,91, 
     2,96,  6,13,  9,73,  4,16,  1, 6,  0,23, 14,88,  7,72,  3,37,  8,33, 13,98, 10,14,  5,81, 12,84, 11,95, 
     7,84,  3,47,  8,17, 13,38,  9,11, 10,33, 11,49,  4, 9,  5,51,  1,26, 14,99,  2,18,  6,41, 12,28,  0, 7, 
     9, 1,  7,14,  3,34,  6,49,  4,11,  8,78,  1, 8, 11, 8, 14,68, 13,38, 12,72,  5,70,  0,32,  2,81, 10,86, 
     2,93, 10,34,  0, 6,  5,99,  1, 4,  3,29, 14,24,  4,84, 12,53, 13,17,  8,50,  7,53,  6,24, 11,59,  9,62, 
     4,67, 14,75, 13,89,  0,82,  5,39,  2,82, 10,35,  7,58,  9,63,  1, 4, 11,64, 12, 8,  3,30,  8,53,  6,74, 
    14,44,  3,17,  1,26, 13,73,  5,34,  6,38,  8,45,  4,71,  0,16,  9,96,  2,86, 10,30, 12,46,  7,26, 11, 7, 
     1,45,  9,16,  5,96, 12,68,  7,48,  0,30, 11,79,  3,90, 14,84,  6,48, 10,79,  2,14,  4,42,  8,82, 13,26, 
     2, 1, 10,62,  1,45, 11, 3,  6, 7, 13,15, 12,22,  7,71,  3,19,  8,87,  5,55, 14,12,  9,50,  4,10,  0,36, 
     7,71, 12, 3, 14,61, 11,34,  9,60,  1,72,  5,34, 13,33,  3,69,  8,36,  4,88,  6, 1,  2, 3, 10,98,  0,90, 
     4,84,  0,50,  2,74,  5,16, 11,86, 13,32, 10, 2, 14,22,  6,22,  8,73,  9,16,  7, 8,  3,64, 12,70,  1,83, 
     9,57,  7,22,  6,43, 10, 2, 13,10,  1,37,  8,46,  5,89, 11,31, 14,27, 12,47,  0,85,  3,86,  4,81,  2,38, 
     7,39,  5,14,  9,64, 14,87,  4,34,  2,33,  1,37,  0,78, 12,84, 13,27,  6,46, 10,93,  8,75, 11,70,  3, 9, 
    11,25,  1,84,  0,15,  4,59,  9,85,  2,53,  3,29, 10,70,  5,50,  6,93, 13,23, 14,98, 12, 2,  8,17,  7,87, 
     7,11,  8, 7,  4,70, 14,19,  5,13,  2,23, 10,94,  0, 2, 12,55,  6,93, 13,77,  9,92, 11,39,  1,33,  3,75, 
    11,29,  6,60,  9,27, 13,57,  7,79,  2,67,  0,66,  3,22, 12,27,  4,20, 14, 5,  5,43, 10,79,  1, 9,  8,85
  };
  // Taillard 50x15 instance 9
  const int tai_50_15_9[] = {
    50, 15, // Number of jobs and machines
     2,76, 10,34, 12,28,  8, 8,  9,10,  0,74, 14,92, 13,30,  6,10,  7,82,  4,45, 11,74,  3,24,  5,87,  1,38, 
     3,90,  1,55, 10,16, 12,77,  0,86,  2,83,  9,26,  8,92, 13,23, 11,50,  6,74, 14,81,  5,15,  4,14,  7,31, 
     8,35,  0,56,  2,32,  1,64,  3,70,  7,78, 13,23,  6,46,  4, 8, 10,75, 12,45, 11, 5,  5, 7,  9,62, 14,73, 
    10,74,  4,13,  1,78,  6,88, 12,32,  3,26,  5, 8, 11, 2, 14,27,  2,29, 13,62,  9,48,  8,25,  0,78,  7, 8, 
     2,95,  1,68, 14,65,  8,93, 11,68, 13,75, 12,54,  6, 2,  5,60,  3,99,  7,13,  4, 3,  9,66,  0,57, 10,60, 
    11,43, 12,84,  9, 7,  7,70, 14,43,  6,37,  2,42,  1,92,  4,70,  0,91,  3,30,  8, 5, 10,57, 13,70,  5,80, 
     0,83,  8,97, 12,12,  1,19,  5,50,  4,18,  7,41, 14,66, 10,24,  2,98, 11,11,  9,21, 13,29,  3, 6,  6,86, 
     3,86,  7, 4, 13,94,  9,52, 12,22,  8,76, 10,81, 11,47,  4,92,  2,95,  0,15,  5,33,  1,85,  6,38, 14,54, 
    13,80, 12,56,  9,54,  6,87,  3,22, 14,93,  2,36,  8,83, 10,99, 11,27,  4,15,  1, 7,  5,69,  7,77,  0,50, 
     9,43, 10,49,  8,13, 12,27, 13,94, 11,91,  1,79,  5,80,  2,13,  7,81, 14,34,  6,19,  3,67,  0, 3,  4,67, 
     7,63,  3,56,  2,77,  8,17,  6,17, 10,51,  5, 3,  1, 9, 13, 7,  0,63, 12,87, 11,66, 14,92,  4,64,  9,60, 
     8,33, 12,86,  1,35,  2,69, 14,32,  4,86, 10,26,  5,98,  6,95,  9,31,  0,11, 13,82, 11,85,  7,71,  3,61, 
     9,81, 13,86,  3, 1, 14,18,  5,16,  2,94, 11,84,  0,11,  6,18,  8,41,  4,72, 12,15, 10,50,  7,79,  1,77, 
    12,67,  3,41,  5,99,  8,29,  7,62, 13,80,  6,39,  1, 1, 14,21,  0,38, 11,68,  2,88,  4,88, 10,95,  9, 2, 
     6,76,  4,80,  1,42,  5,65,  3, 4,  9,62,  0,50,  7,93, 14,74, 11,76, 10,10,  8,76, 13,55, 12,95,  2,94, 
     1,76,  8,40,  0,96,  9,89, 10,22, 13, 1,  7,22,  5,49,  4,12,  6,27, 14,17, 11,34, 12,48,  3,28,  2,32, 
     7,90, 13,50,  1,33,  9,53,  6,21, 10,35,  2,11,  8,53, 12,44,  4,58, 11,76, 14,32,  5,62,  3,60,  0,23, 
    13,96,  3,14,  2,67,  4,37,  0, 7,  8,23, 12,76, 11,82,  7,51,  6,68, 10,58,  1,66, 14,13,  9,40,  5,43, 
     4,32,  9,95,  1,70,  6,27,  0,79,  5,37, 13,98,  2,86, 12,85,  3,53, 10,25, 14,88,  7,32,  8,31, 11,26, 
     0,18,  3,31,  2,97, 13,94, 12,74, 10,73,  5,40, 14,34,  1,88,  6,52, 11,48,  8,72,  9,50,  4,20,  7, 6, 
     4,85,  1,90, 13,87,  9,57, 10,87,  0,11,  7,96,  8,69, 14,77,  6,95,  3,60, 11,37,  5,87, 12,83,  2,40, 
    12,76,  6, 1, 10,46,  0,31,  5,21,  3,57, 13,69,  1,96, 11,85,  8,40, 14,30,  9, 4,  2,61,  7,44,  4,29, 
     9,33,  6,48,  3,71,  0,27, 12,67,  2,11,  5,23,  7,97,  8,71, 13,23, 14,54,  4,91, 10,55, 11,12,  1,62, 
     0,65,  3,19,  8, 6, 13,45, 11,94, 12, 4, 14,46,  7,52,  9,93,  6,14, 10,49,  1,70,  2, 1,  4, 3,  5,23, 
     2,14,  5, 3,  0,34, 12,13, 13,46,  9,79,  3,82, 11,76, 10,14,  8, 6,  4,27,  7,34,  6,65,  1,51, 14,85, 
    13, 8,  2,41,  4,74,  6, 9, 12,42,  9,98,  7,65,  1,94, 11,24,  3,83,  8,21, 14,75,  5,26, 10,30,  0,67, 
     0,86, 11,96,  8,60,  4, 6,  7,78,  6,87, 13, 5,  1,26,  5,48,  3,81,  9,64, 10,20,  2,44, 14,91, 12,12, 
    10,75,  5,24,  0,27,  9,14,  1,33, 13,17,  3,93,  7, 5,  4, 5,  6,89, 12,53,  8,66, 14,85, 11,51,  2,96, 
     1,31,  8,63,  4,21, 10,37, 13,68,  3,78, 12,48,  0,66, 14,86,  9,18,  6,77, 11,22,  7,31,  2,87,  5,18, 
     8,23, 13,25,  6,22,  3,40,  1, 5,  7, 9,  9,29,  0,51, 12,61, 14,84,  2,50,  4, 4, 10,87,  5,36, 11,31, 
     4,16,  3,81, 12,18,  1,73, 13,26,  0,19,  6,54,  8,44, 14,92,  2, 8,  7, 6,  9,89, 11, 2, 10,46,  5,21, 
     0,57,  8,48,  1,31,  7,57, 14,11,  5,79,  4,68, 10,99,  9,44, 12,71,  6,59,  2,13, 13,10,  3,48, 11,32, 
     3,42,  6,34, 12,93, 11,63,  0,13,  2,38,  5,93,  1,34, 14,66,  8,62, 13,39,  4,68,  9,43, 10,72,  7,37, 
     5,86,  4,11, 14,33,  7,85,  0, 9,  8,33, 13,80,  2,92, 12,59,  9,21,  1,65,  6,19, 11,96, 10,17,  3,33, 
     6,44,  9,43, 12,78, 11,36,  2, 8,  1,12,  8, 4,  5, 8, 14, 2, 10,78,  4,43,  7,27, 13, 9,  3,16,  0,17, 
    10,81,  2,32,  4,38,  0,83, 14,32, 12,74, 13,76,  1, 6,  8,17,  5,28,  9,76,  6,66,  7,19, 11,27,  3,77, 
    11,49,  4,74,  8,35,  6,11,  2,81,  7,72, 14,76, 12,49,  5,67,  3,29,  0,52,  1,33,  9,72, 13,54, 10,19, 
    14,96,  7,73,  2,39, 11,69,  0,42,  4,77,  9,95,  8, 5,  5,37,  6,56, 10,21,  3,65, 13, 5, 12,40,  1, 8, 
     0,11, 14,44, 11,32,  4,43,  2,10,  6, 5,  5,62, 13,15, 12,92,  1,79, 10,30,  7,29,  8,21,  9,58,  3,29, 
     2,22,  5,83, 13,55,  8,95, 11,42, 12,42,  6,62,  4,12,  9,82, 10,52, 14,41,  7,40,  0,86,  1,28,  3,48, 
     1,64,  9,68,  4,14,  5,70,  2,63,  0,33, 13,82,  7,55,  6,17, 11,51,  3,96, 12,27,  8,79, 10,63, 14,28, 
     6,89,  4,80, 11,98,  8,54, 10,75,  7,97,  5,40, 13,62,  3,98,  1,38, 12,70,  2,39,  9,23, 14,12,  0,94, 
    12,21,  2, 8,  6,80,  5, 2, 14,66, 10,33,  8,22,  0,21,  9,70,  7,14,  1,32,  4,70, 11,78, 13,46,  3,38, 
    14,17,  9,22,  5,57,  1,60,  0,68,  3,86,  6,31,  7,16,  2,75, 13,65, 12,46, 10,56, 11,75,  4,99,  8, 6, 
     9, 4,  4,75,  1, 8, 14,35,  7,67,  6,88,  0,40, 10,90, 12, 9,  5,99, 13,93,  8,39, 11,59,  3,90,  2,69, 
     2,34,  5,61,  8,88, 12,54,  0,95, 10,22,  6,47,  9,91,  4,53,  3, 7,  1,94,  7,14, 14,70, 13,40, 11,31, 
    10,28,  3,90,  9, 5, 14,85, 13,83,  5, 6,  2,69,  0, 6,  4,57,  6,87, 12,93,  7,75, 11,70,  8,86,  1,68, 
     7,25, 10,44,  9,54, 14,94,  5,35, 12,62,  8,63, 11,51,  3,59,  2,68, 13,85,  0,48,  6,64,  4,40,  1,75, 
     7,29,  0,42,  2,56,  3,94, 11, 9, 14,31,  5,80, 12,52,  4,53,  9,82,  1, 8, 13,32,  8,94, 10,94,  6,32, 
     9,39,  2,12,  6,34,  8,24,  7,41, 12,85,  0,74,  3,46, 14,30, 13,89, 10, 2, 11,87,  1,57,  5,84,  4,34
  };
  // Taillard 50x20 instance 0
  const int tai_50_20_0[] = {
    50, 20, // Number of jobs and machines
     8,48, 19,40, 17,54, 15,71,  1,52,  2,70, 10,41,  7,76, 13,52, 18,24,  5, 5,  6,43,  3,68,  4,10, 14,49, 11, 9, 16,81,  0,30,  9,93, 12,17, 
    12,85, 11,18,  3,54, 16,42,  1,41,  2,71,  9,68,  8,82, 18,54,  4,49,  0,21, 19, 1, 17,58, 15, 1,  5,69, 10,58, 13,40, 14,59,  6,66,  7,29, 
     8,33,  6,34, 15,77, 14,42,  3,95,  7, 2, 19,71, 18,73,  1,19, 11,25,  4,45, 12,88, 17,19, 13,40,  0,42,  2,17,  9,81, 10,72, 16,70,  5,67, 
    12,51,  9,41,  5,74, 16,97,  0,26,  2, 4, 13,25, 18,12,  6,17, 11,76,  1, 6, 19,79,  8,49, 14,39,  7, 1,  4,27, 15,44, 10,75,  3, 1, 17,18, 
     1,22,  3,99, 13, 7,  4, 7, 18,72,  5,24,  6,19,  9,81,  7,23,  8,72, 15,50,  0,95, 14,31, 10,67, 12,67, 19,22, 16,12, 17,28,  2,68, 11,88, 
    16,52,  3,51,  4,44, 14,38,  1,64,  2,11, 10,62,  9,20,  5,54,  0,15, 18,83, 19,79,  8,55, 17,48, 12,38, 15,37, 13,42,  6,81,  7,89, 11,60, 
    19,82,  4,43, 15,57,  0, 1, 12,89, 13,11,  1,41,  7,50, 18,68,  5, 2,  9, 4,  3,65, 16,20,  8,56, 11,46,  2,36,  6,33, 14,56, 10,13, 17,50, 
     9,45, 10,11,  8,63,  4,59, 14,69,  5,39, 15,44,  7,61, 18,67,  6,72, 13,74, 19,59, 17,16,  2,26, 16,90, 11,66,  0,56, 12,47,  3,95,  1,39, 
     9,92, 13, 2, 15,88,  7,90, 18,45,  2,88, 11,90, 19,94,  1,34,  8, 1,  0,81,  4,64,  3,70, 12,55,  6, 7, 16,33, 14,21, 17,35, 10,62,  5,61, 
     6,89, 11,21, 17,61,  8,18, 16,77,  7,20,  0,42, 14,59,  4,79, 15,12,  2,56, 13,14, 18,21,  1,43,  9,89, 19,31, 10,71,  5,92,  3,47, 12,71, 
    13,61,  4,84,  7, 3,  6,73, 15,35, 11,36, 10,79,  9,88,  3,54, 17,96, 16,22,  5,70, 12,10,  1, 4,  8,76, 18,40, 14,85,  0,84, 19,93,  2,65, 
     3,68, 10,72, 14,74,  0,97,  7,63, 12,33,  9,96, 19, 4, 11,63,  5,31, 18, 1,  1,98, 13,39, 17,65,  2,72,  6,20,  4, 7, 16,63, 15,33,  8,26, 
     0,41, 10,65,  2,34, 18,71, 14,19, 12,49, 13,87,  1,61,  3,79,  9,61, 17,29, 15,22, 19,74,  4,68,  5,60,  8,23, 16,82,  6,33,  7,94, 11,42, 
     6,17, 11,40,  9,40,  8,28, 15, 6, 17,62,  0,83,  4,95, 14,44, 10,91, 12,79,  2,39, 13,68, 18,79,  5, 1,  1,20, 16,96, 19,62,  3,62,  7,70, 
     1,39,  9,89, 16,37, 17, 7, 15,84,  2,60,  5,61, 10,73,  8,64, 14,73,  7, 3, 11,75, 13, 3,  0,48, 19,74,  3,67,  4,39, 18,32, 12,69,  6,25, 
    11, 9, 17,83,  5,30,  1, 3, 12,31, 18,93, 10,86,  9,49,  2,34, 15,91, 16,56,  6,80,  7,33,  8,77, 14,35,  4,63,  0,72, 19,46, 13,22,  3,73, 
     3,21,  5,46, 13,33, 16,54, 14,22, 11,64, 17,20, 12,76,  7,77, 18,97, 15,28,  8,54,  2,81,  0,95,  9,81, 10,72,  4,80,  6,75, 19,18,  1,81, 
    16,52, 13,30,  8,38, 17,70,  5,22, 10,15, 18,66, 12,26,  1,55,  4,34, 14,13,  9,65,  6,87, 11,38,  3,85,  7,89, 15,77,  2,22,  0,67, 19,44, 
     4,63, 14,95, 15,18, 19,94, 17,73, 18,51,  1,35,  9,57,  8,38,  7,65,  6,69,  5,60,  0,90,  3,68, 16,32, 11,40, 10,11, 12,75, 13,97,  2,51, 
     9,68, 15,37, 13,39,  4,13, 14,76,  8,77,  3, 6,  2, 6,  5,53, 18,41,  7,72, 16,71,  6,46, 11,24, 10,46,  0,50, 17,12, 12,39, 19,92,  1,54, 
    18,93,  2,95, 17, 8, 16,27, 10,53,  8,75, 12, 3, 19,42, 14, 5,  1,24,  6,73,  5,88,  0,57,  7,20, 11,99,  3,39,  4,74, 15,75, 13,44,  9,24, 
     8,83, 17,14, 11,66, 15,96,  3,11,  6,36, 16,20, 13, 5, 12,72,  2,38, 19,79,  9,10, 14,27,  4,27, 18,90,  1, 8,  7,83, 10,10,  5,61,  0,69, 
    11,22, 17,56, 10,54, 19,50, 12,51, 18, 9, 16,15,  5,36, 15,20,  4,79,  1,51, 13,84,  2,40,  7,59,  0,48,  6,27, 14,65,  9,44,  3,40,  8,83, 
    18, 5,  7,75, 15,43,  9,17,  3,10, 19,92, 16,22, 11,36,  5, 7, 13,71, 17,77, 10,70, 12,10,  0,24,  1,78, 14,77,  2,56,  4,42,  6,16,  8,48, 
     4,37, 17,96,  6,81,  2,12, 18,92,  5,86, 12,63,  7,88,  0,28, 14,57, 11,58, 15,23,  1, 4, 19,95, 16,80,  8,12,  3,82,  9,53, 13, 5, 10,75, 
     6,58,  1,59, 15,65,  2,78, 18,68, 11,50,  7,38, 14,97, 10,72,  4,94,  0,59,  3,42,  9, 5, 13,19, 12,27, 19,54, 17,69,  8, 2,  5,56, 16,51, 
    15, 4,  6, 7, 18,36, 17,35,  0,80, 19,95,  1,51, 14,59, 16,93,  9, 5, 13,61,  4, 4,  5,43,  8,30,  2,93, 12,76, 11,42,  3,99,  7,30, 10,46, 
     9,88, 17,75, 10,81,  6,40,  3,61,  0,94, 12,78, 18,24, 16,19,  7,44, 14,96,  4,23, 13,90,  1,94,  8,80, 19,97, 11,24,  5,44,  2,54, 15,52, 
    13, 5,  4,99, 17,60, 14,87,  5,64, 11,36,  8,78,  0,32,  9, 4, 18,18, 12,26, 16,87,  2,74,  6,26, 15,90,  3,45, 10,35,  1,54, 19,27,  7,23, 
     2,93,  4,95, 10,11, 12,14, 17,99,  5,86,  7,41, 11,26, 16,50, 15,74,  3,21,  9, 6,  0,67, 18,87, 19,46,  6,84,  1,11, 13,89,  8,89, 14,66, 
     9,50,  2,71, 15,71,  7, 5, 11,60, 17,29, 14,17,  6,29, 12,98,  3,61, 19,87,  0,58, 10, 6,  1,60, 13,84,  8,92, 16,23,  5,25,  4,23, 18,57, 
    17,75,  4,60, 19,77, 15,48,  0,87,  3,52,  6,98,  2, 8, 12,55, 13,97,  1,55,  8,68, 16,59,  7,90,  5,50, 10,98, 14,57, 18,43,  9,72, 11,35, 
    13,46,  6,22,  4,11, 12,49,  5,34, 10,30, 11,79,  8,72,  2,77, 18,47,  9,55,  3,63, 14,58,  0,89, 17,71,  1,94, 15,95, 16,13, 19,97,  7,46, 
    15,25,  2,98,  3,71,  7,68, 13, 8, 16,72, 12,57, 14,39,  8,83,  4,17,  5,90,  0,31, 17,81, 10, 6,  6,97, 18,98,  9,82, 11,82, 19,52,  1,82, 
    15,42,  8,77, 10,71,  1,19, 18,80, 11,31,  0,66, 17,90,  4,18, 12,15,  3,76, 19,58,  5,92,  2,34, 14,66,  9, 8, 16,65,  7,67,  6,84, 13,42, 
     4,41, 12,42,  3,69, 18,81, 10,95, 19,16, 17,45,  6,52,  2,48,  1,35,  0,72,  5,80,  7,81,  8, 4, 11, 3, 14, 4,  9,96, 16,53, 13,14, 15,80, 
    16, 6, 17, 6,  9,12, 19,86,  7,26,  1,52,  6,70,  8,93,  3,81, 13,31, 15,89, 12,99, 11,99,  2,71, 14,74,  5, 7, 18,43,  4,86,  0, 1, 10,93, 
    12,44,  2,54,  0,36, 13,40,  4,68, 16,49,  7,45,  3,58, 18,44, 15,65,  5,72,  9,65,  6,53, 10,48, 11,90,  1,98, 19,60, 14,71, 17,27,  8,48, 
    15, 9,  1,16,  2,56, 16,27, 12,50, 19,57,  0,55,  8,87,  9,44,  5,47,  7,29, 11,82, 18,80,  4,43, 10,75,  3,10, 13,70, 14,38,  6,28, 17, 2, 
     7,29,  0,91, 12,85, 10,51,  1,86, 18,34,  8,73,  5,12, 19,14,  3,51, 11, 1, 15,38,  2,74, 16,92, 13,60,  6,43, 17,36,  4,23,  9,82, 14,30, 
    11,21,  2,97, 10, 4, 17,85,  7,21,  4,55,  6,34, 19,62, 16,78,  8,11,  9,34,  0,17,  1, 3,  5,43, 12,38, 15,44, 13,45, 18,17, 14, 3,  3,83, 
    15,29,  8, 6,  7,45,  5,15, 19,60, 17,29, 18,97, 14,91,  6,13, 16, 8,  3,50,  2,46, 10,72,  9,86, 13, 7, 12,30,  0,28, 11,13,  4,27,  1,42, 
     4,38,  3,10, 12,93, 19, 6,  7,72, 11,38, 15,73,  0,88, 14,44,  9,66, 10,79, 18,47, 13,61,  5, 6,  2,64,  6,18,  8, 2, 17, 6, 16,91,  1,37, 
     2,21,  7,20,  4,51, 18,96, 17,51,  1,42,  5,52,  8,37, 13,85,  9,18, 15,44,  3,60, 12,68,  6, 3, 11, 6, 16,20,  0,81, 19,96, 14,30, 10, 9, 
    13,16, 14,54,  1,53,  2,57, 16,46,  0,84, 11, 1, 19,76,  6,26,  7, 7,  5,69, 10,88, 15,29, 12,73, 17,32,  9,51,  4, 4, 18,74,  3,75,  8,75, 
     0,27, 16,54,  3,90,  7,25,  2,97, 17,68, 19,14,  4,54, 12,29,  8,14,  5, 8,  6, 1, 14,60,  9,13, 18,16, 10,41, 13,81,  1,35, 11,18, 15,79, 
     6,56, 13, 7, 12,31,  9,55,  2,85, 19,35, 14,82, 18,63,  4,35,  5,54, 10,52,  7,77, 15,82,  8,94,  3,81,  1,25,  0,24, 11,56, 16,23, 17,79, 
     8,33, 14,50,  7,22, 10,70,  9,59,  6,51,  0,80,  2,84, 16,47, 12,88, 13,27,  5,18, 19,34, 17,47,  4, 4, 15,41,  3,56, 11,42, 18,26,  1,66, 
     3,31, 10,83,  7, 9,  0,34,  1,62, 13,83, 18,61, 17,41,  8,58, 14,96, 16,87, 15,18, 11,56, 19, 2,  5,95, 12,21,  4,51,  9,13,  6,31,  2,96, 
    15,62,  5,95, 18, 8, 19, 3, 17,27,  9,19, 12,36, 14,97,  1,87, 11,62,  2,86,  7,21, 10,37,  0,11,  4,11,  6,67, 16,84,  8,34,  3,48, 13,97
  };
  // Taillard 50x20 instance 1
  const int tai_50_20_1[] = {
    50, 20, // Number of jobs and machines
    18,54, 12,96, 17,96,  4,62,  5,71, 11,42, 10,62,  8,93,  9,98, 13,10, 15,54,  1,13, 16,37,  7,61, 14,92, 19,90,  0,59,  6,64,  3,96,  2,64, 
    13,84,  7,93,  2,22,  6, 7,  5,83,  8,56, 12,94,  0,52,  9, 6, 15,85,  1,38, 19,82, 18, 3, 10,94,  4,32, 11,17, 14,66, 16,79, 17, 9,  3,34, 
    10,67,  7,69,  1, 5, 15,14, 18,53,  2,12, 14,17,  9,93, 11,28,  5,57, 19, 9,  3,78,  8,19, 13,62,  6,50, 16,85, 17, 3,  4,57, 12,95,  0,75, 
    10,99, 12,16, 18,84,  2,51,  9,84, 13,18,  8,21,  5,54,  4, 8, 19,38,  3,80,  6, 4,  0,81, 14,26, 16,48, 15,51,  1,93,  7,76, 11,32, 17,50, 
     2, 9,  7, 5, 14, 2, 19,71,  1,60,  5,98,  0, 3, 15,26,  6,60,  4,57, 16,55, 17,47,  8,45,  3,47, 11,79, 13,58, 18,99, 10,90, 12,21,  9,78, 
     6,90, 19,92, 17,96, 10,44,  3,88, 15,79,  2,78, 13, 3, 11,17,  1,11, 18,34,  0,15,  8,46, 16,47,  9,90,  5,58, 12,95,  7,33, 14,57,  4,91, 
     0,25,  2,99,  4,17, 10,64,  3,83,  7,62, 13,46, 15,21, 12,98, 18,50, 17,56, 14,57, 11, 4,  8,66, 19,55, 16, 3,  1,14,  6,10,  9,24,  5,93, 
    16,94,  0,18, 10,70,  6,92,  4,34,  7,29,  9,65, 13,19, 19,85,  5,55,  2,44, 17,87, 12,59, 18,34, 11,86,  3,72,  8,28, 14,62,  1,22, 15,35, 
    19,88,  8,10,  4,40,  9,96, 18,46,  7,48, 10,74,  6,82, 11,91,  1,45,  2,85, 15,53, 16,76,  5,33,  0,67,  3,63, 17,44, 12,82, 14,51, 13,47, 
     1,45, 17,16,  3,63,  5,16, 11,86,  4,74,  9,58, 18,39, 19,50, 16,28, 14,50,  6,68,  8,39,  0, 6, 10,35, 15, 6, 12,13,  7,26,  2,15, 13,56, 
    19,24,  3,83, 18,53,  7,60, 13,67, 16,78, 10,19, 11,51,  0,14,  1,48, 12,57, 15,52,  8,92,  6,49,  9,74,  4,82,  2,32, 14,63, 17,91,  5,68, 
    12, 7,  4,77,  8,97,  1,98, 11,20, 16,56,  5,66, 13,57,  0,54,  9,58, 19,20, 10,30, 15,77, 17,68,  2,63, 18, 6,  6,63, 14,67,  7,23,  3,26, 
    18,76,  6,81,  3,33,  4,35, 14,85,  0,29, 11,10,  5,52, 10,11,  1,21, 12, 1,  9,96, 13,45, 15,31, 17,43,  2,11, 19,47,  8,41, 16,69,  7,53, 
    10, 3,  7,52,  1, 3, 19,85,  9,34,  0,26,  6,75,  3,92, 16,83, 12, 8, 14,79,  4,69,  5,58, 15,67, 17, 1, 18,79, 13,64,  8,49,  2,57, 11, 4, 
     2,30, 15,19,  1,31, 19,44,  9, 2, 10,17, 16,82,  7,14,  3,82, 12,95,  8,25, 18,67, 11,75,  0,41, 14,92,  4, 3, 13, 6, 17,22,  6,34,  5,20, 
     1,16,  9,62,  4,49, 16, 9,  2,45, 11,41,  7,23,  3,43,  0,35,  5,42, 15,88,  8,19, 14, 3, 10, 8,  6,96, 17,27, 13,30, 18,37, 12,19, 19,28, 
    10,19,  2,64,  1,75, 17,20,  8,99,  0,85,  9,56, 16,98, 14,35,  4,70, 12,44,  7,16,  6,25, 11, 6, 15,10,  5,23, 18, 8, 13,98, 19,25,  3,99, 
     8, 1, 11,24, 19,43, 12, 5, 15,31,  9,54, 10, 1, 14,47,  2,67, 18,62, 17,24, 16,36,  7,94,  6,16, 13, 8,  4,56,  1,16,  3,18,  0,49,  5,69, 
    10,97, 19,89, 18,71,  5,87, 14,78,  0,85,  1,18, 11,19, 13,20, 15,96,  9,50, 16,66,  4,53, 12,70,  6,48,  7,20,  3,41,  8,93, 17,91,  2,51, 
     6,90, 10,29,  5,25,  9,68, 11,18,  7,47, 13,82,  1,35, 17,28,  4, 9, 15,45, 12,60, 14,64, 18,32,  2,16, 16,26, 19,47,  0,33,  8,89,  3,39, 
    10,79, 15,62, 12,25,  7,47,  2, 4, 11,14,  8,41,  5, 8, 14,91,  1,70,  9,27, 18,90, 16,73, 19,59,  3,21,  4,67,  6,77, 13,55,  0,54, 17,41, 
    19,39, 13,64,  9,55,  2,81,  6, 6,  7,73, 15,17, 10,44, 11,27,  8,57, 17,15,  4,33,  1,16, 18,38,  3, 1, 14,61,  0,11,  5,56, 12,65, 16,47, 
    12,48,  8,56, 18, 7,  2,34,  1,59, 11,65,  6, 1, 19,65,  7, 8, 16,19,  3,31, 14,57,  4,67,  9,57, 17,94, 13,32,  5,49, 15,31, 10,72,  0,68, 
    18,65,  5,11, 10,82, 14,50,  2,39,  4,56,  9,58, 17,59,  8, 5, 19,33, 12,81,  6,93,  1,46, 11,23,  3,80, 16,24,  0,13, 13,10,  7,36, 15,43, 
    11,60, 19,32, 15,37, 17,13,  3,56, 16, 6,  0,74,  7,83, 10,50,  1,60,  6,12, 13,90, 18,59,  2,32, 14,72,  5,76,  8,87, 12,25,  9,23,  4,64, 
     4,24,  1,78, 12,44,  7, 5, 10,87, 11,60,  9,53, 19,18,  6,91,  2,67, 18,59, 17,81, 14, 8,  0,16,  5,94, 16,94,  8,47, 13,26,  3,73, 15,69, 
    18, 8,  2,74,  8,93,  3, 9, 11,82,  0,87, 14,40, 12, 6,  4,70,  9,83, 17,86,  5,90,  6,77, 10,13, 19,65, 13,21,  7,83, 15,58, 16,95,  1,48, 
    16, 7, 17,93, 13,75,  1,82,  5,34,  7,28, 14, 8, 10,32,  0,63, 19, 5,  6,27,  2,90,  8,32,  9,15, 12,52, 15,63, 18,11,  3,96, 11,25,  4,22, 
     4,73,  1,73, 10,33,  6,73,  8,19,  9,48,  2, 7, 12,74,  7,77, 17,48, 11, 5,  0,47, 14,38, 13,73, 19,83, 16,24,  3,80,  5,80, 15,41, 18,26, 
     9,50, 17,34,  7,95,  8,44,  2,31, 11,80, 14,59, 13,53,  3,24, 15,18, 10,37, 19,72, 18,72,  1,73,  6, 6,  4,86, 16,17, 12,13,  0,89,  5,24, 
     2,95, 12,99, 11,35,  8,55, 18,67, 17,54,  7,15,  6,25,  5, 2,  1,60,  9,35, 13,14, 19,14, 14,37, 16,82, 10,37,  3,47,  0,28,  4,37, 15,21, 
    16,24,  4,23,  1,68, 17,13,  7,98, 11,67, 18,58,  0,81, 14,62,  9,11,  8,99,  6,75, 10,41, 13,23, 15,13, 12,35,  5,73, 19,35,  2,71,  3,28, 
    17,87,  7,39, 14,66,  9,67,  4,91, 13,71,  2,48, 10,17,  8,12, 15,95, 11,86,  6,71,  3,19,  5,49,  0,63, 12,66, 16,69, 18,73, 19,87,  1, 8, 
     6,69,  1, 3, 12,11, 18,76,  7,57, 19,55,  5,36, 10,95, 11,63, 16,78,  0,72,  9,28, 14,53, 15,10, 13,86,  3,13,  2,53,  8,14,  4, 4, 17,52, 
     5,67, 18,59, 19,84, 17,50, 14,91,  4,93,  0,53,  8,56, 10,30,  2,98, 12,53, 16,74,  9,60,  6,46,  7,57,  1,23, 13,27, 11,49, 15,54,  3,47, 
    15,99, 14,82,  9, 3,  8,61, 16,92,  2,67, 18,66, 17,81, 19,62, 12,41,  7,77,  3, 9,  1,56, 11,80,  4,90,  0,68, 10,81,  6,58, 13,86,  5,59, 
    16,76, 15,77, 19,23, 14,29, 18,25,  3,44,  2,15, 10,17,  5,96,  8,64,  7,71, 13,22,  6,87, 17,73,  0,72,  4, 8, 12,67,  1,92, 11,61,  9,97, 
     1,92,  2,47, 12,95, 11,55, 15,78, 19,58,  0,36, 10, 1, 17,23, 16,71, 18,47,  9,76,  6,34,  5,95,  7,25,  4, 4,  3,91,  8,22, 14,51, 13,53, 
     9,57, 19,61,  2,39,  6,22, 11,60,  3,90, 15,54, 16, 2,  4,83, 13,73,  7,36, 12,68,  8,99, 14,68,  0,61, 18,76,  1,88, 10,15, 17,96,  5,80, 
    12, 6, 16,59,  3,99,  5,30,  0,73,  9,56,  2,39,  1, 9, 11,80,  8,87, 10,74, 18, 6,  4,55,  6,39, 14,39,  7,42, 15,78, 13,37, 19,66, 17,37, 
    11,11, 19,83,  3,83, 17,87,  7,34, 18,45, 14,78,  5,13, 16,59,  4,93,  8,16,  6,85, 12,76,  9,54, 13,91, 15,93,  2,13,  1,56,  0,10, 10,99, 
     6,26,  1,45,  8,80, 11,44, 19, 9,  2,28,  5,70, 14,95,  3,40, 12,20,  7,63,  0,44,  9,63,  4,73, 17,59, 18,82, 16,41, 13,87, 15,89, 10,29, 
     7,64, 12,89, 17,62, 19,30,  6,13, 11,64, 15,42, 10,39,  9,89,  3,89,  5,57, 18,62,  8,99, 13,55,  2,40,  1,94,  0,25, 16,34, 14, 4,  4,65, 
    16,58, 11,99, 14,16,  8,46,  4,72,  5,40,  3,48, 15,15,  2,14,  0,15, 17,39,  9,17, 18,52,  6,43, 19, 9,  1,73,  7, 6, 13,65, 10,58, 12,13, 
    16,19,  3,72,  9,80, 17,48, 14,79,  0,71,  6,29,  5,14,  8,19,  4,27, 19,92, 12,97,  2,99,  1,74, 13,69,  7,20, 10,40, 18,41, 15,95, 11,39, 
    11,63,  3,25,  8,74,  9,40,  2,14, 14,98, 17,26,  0,55, 18, 9, 15,92, 10,67,  7,99, 19,48,  6,20,  4,87, 12,55, 16,65,  1,66, 13,10,  5, 4, 
     7, 2,  9,89,  2,99, 11,89, 12,73,  1,12,  6,78,  3,57, 16,38, 13,17, 14,64, 10,80, 17,47, 15,76,  0,99,  8,72, 19,31,  4,52, 18,49,  5,76, 
    13,45, 17,22,  1,11,  3,99,  2,65, 15,96, 12,95,  5,47, 10, 8, 11,57,  6,60, 14,38, 18,71,  0,70,  8,98,  4,57, 16, 4, 19,31,  9,73,  7,56, 
     5,28, 10,26, 16,47, 15,77,  9,89, 11,82, 12,94, 17,41,  7,89,  1,74,  8,95,  4,44,  0,60, 14,88,  3,61,  2,99,  6,36, 13,49, 19,41, 18, 1, 
     1,16,  7,71,  9,49, 13,25,  2,62, 12,98,  6,63,  0,79, 18,29, 19,82, 10,84,  4,76, 17,85, 11,18,  5,78,  3,18,  8,87, 15,65, 14,10, 16,78
  };
  // Taillard 50x20 instance 2
  const int tai_50_20_2[] = {
    50, 20, // Number of jobs and machines
     0,35,  1,73, 11,56, 17,28, 10,81,  7,82,  5, 5, 13,48,  3,36,  4,37, 19, 9,  9, 8, 12, 9, 14,20, 15,78,  2,77, 16,31, 18,44,  8, 9,  6,40, 
     3,41, 16,26,  5,27,  7,31, 10,62, 11,20, 14,17, 18,55, 13,57,  1,21,  8,61,  9,63, 19,17, 12,14,  0,59,  2,91, 15,54,  4,64, 17,21,  6,47, 
     6, 4, 11,92,  7,75,  2,21,  4,21, 12,98, 14,32,  5,41,  0,29, 13,42, 10,71, 18,90, 19,69,  1,87,  8,71, 15,18,  9,41,  3,78, 16,60, 17,85, 
    13,72,  6,21, 19, 8, 16,55,  2,86,  3,17, 10,98,  9,71,  7,18,  1,86,  0,84, 14,88, 12,97,  5,75, 18,70,  4,67,  8,36, 17,11, 15,97, 11,55, 
     8,88,  0,15, 13,29,  7,51, 10,82,  4,66, 16,26,  6,70,  1, 7, 17,87, 15,81,  3,76,  2,44,  9,27, 19,88, 18,34,  5,70, 11,62, 14,44, 12,67, 
     7,26, 12,24,  0,87, 17,48,  3,55, 15,68,  4,54, 13,83, 14,17,  6,50, 16,87, 19,18, 10,83,  1,32, 18,71,  9,72, 11,95,  5,39,  8,37,  2,21, 
    15,80,  7,31,  1,20,  0,51, 18,32,  5,21, 19,12, 10,79, 12, 1,  6,93, 17,80, 14,60,  3,17, 11,78, 13,87,  4,64, 16,47,  2,66,  9,64,  8,47, 
    19,59,  2,10, 16,80, 14,46,  5,62,  6,40, 15,68,  9,26, 17,54, 11,50, 10,61,  3,77, 12,40,  4,94,  0,36,  1,67,  7,59, 13,55,  8,15, 18,71, 
    13,36, 15,72, 12,53, 19,91,  4,65,  0,98,  3,60, 18,60, 10,62,  1,52, 17,39, 14,13,  5,44,  7,69,  6, 3, 11,97,  8,65,  2,16, 16,57,  9,65, 
     5, 8,  0,99,  6,34, 10,43,  1,38,  3,49,  2,86, 11,91, 18,14,  7,87,  4,45, 17,12,  9,45, 15,14, 16,58,  8,27, 13,68, 12, 5, 19,47, 14,61, 
     4,79, 11,51,  9,41,  3,51,  1,41,  2,44,  5,50, 16,17, 10,26,  8, 2,  7,16, 13,25, 18,38, 15,17, 17,89, 14,83,  6,59, 12,45,  0,37, 19,23, 
    11,97, 13,90,  1,92, 10, 3,  0, 2, 12, 9,  3,70, 15,15,  5,38,  9,48, 19,12, 17,10,  4, 9,  8,76, 14,27, 16, 8,  6,44,  7,81, 18, 7,  2,80, 
     7,45, 19,13, 14,50,  3,30, 16,85,  4,81, 11,32, 17,64,  5,11, 15,70, 10, 1,  9,93,  0,54, 18,13,  6,30, 12,17,  1,16,  2, 3, 13, 2,  8,19, 
     9,57,  8,81, 10,19,  2,46,  7,40, 12,39,  5,63,  4,92, 17,60, 14, 8,  3, 7, 16,39, 18, 9,  1,54, 15,68,  6,21, 19,66, 13,52, 11,54,  0,21, 
    14,66,  0,66,  1,48,  8,81,  2,30,  6,81,  3,46, 12,95,  9,22, 16,85,  4,57, 19,83,  5,48, 15,94, 13,11, 18,61, 11,92, 10,49,  7,83, 17,91, 
    16,28,  9,14, 19,65, 12,17,  6,97,  0,57, 17,33,  2,96, 13, 3,  4,32,  7,70, 18,78,  5,30, 11,68,  8,92,  1,48,  3, 9, 14,75, 15,31, 10,75, 
    15,25, 10,32, 11,11, 18,22, 14,72, 17,88,  5,50, 19,19, 12,34,  6,87, 16,80,  1,12,  7,26,  8,78,  3,63,  2, 3,  4,97, 13,27,  9,25,  0,21, 
     6, 1,  9,39, 18,20, 16,62, 12,71,  1,41,  2,70,  7, 8, 19,11, 11,66,  4,75,  0,67,  3,32,  5,74, 10, 8, 14,44, 17,94,  8,61, 15,18, 13,99, 
    18,56,  7,47, 12,11, 17,43, 19,57, 11,27,  5, 3, 15,54,  3,40,  8,86,  0,40,  6,30, 16,55, 13,48,  1,37,  2,14,  9,49,  4,59, 10,15, 14,99, 
    13,72, 15,11, 12,90, 14,18,  5,81, 18,44, 11,79,  6,77,  3,20,  8,86,  2,58, 17,44,  4,32, 16,33,  0,37,  7,92, 10,95,  1,77,  9,97, 19, 8, 
    17, 9,  4,37,  2, 7,  7,38,  1,10,  5, 4, 15,75, 18,54,  0, 2, 11,15, 10,95,  6, 4, 19,37,  8,19, 14,56, 13,44,  9,60,  3,90, 12,46, 16, 7, 
     8,33, 13,58,  1,88,  9,49,  2,50, 10, 3, 14,44,  0, 8,  3,82, 12,72, 16,99, 18,50,  5,57, 17,19,  7,12,  4,84, 19,69, 11,14,  6, 8, 15,10, 
    16,37,  5, 9, 11,91, 12,92, 17,17, 18,68,  8,34, 19,81,  3,26, 10,99, 13,72,  1,15,  4,93,  2,24,  9, 2, 15,73,  6,34,  7,42,  0,12, 14,99, 
    13,78,  1,98, 11, 9,  0,15, 16,97,  3,86,  7,88,  5,22, 14,31, 17,59, 19,70, 18,42, 10,42,  4,65,  6,18, 15,50,  9,28,  2,57, 12,87,  8,57, 
    19,51,  2,34, 14,97,  7,83,  3,15, 17,68,  6,87, 10,78, 15,57,  9,37,  0,61, 16,51,  1,93,  5,35, 18,57,  4,49, 13,42, 11,12, 12,76,  8,17, 
    11,33,  9,65,  5,62, 18,11, 16,36,  1, 4,  2,97, 17,22,  8,76, 12,17, 10,82, 19, 6, 15,96, 14,37,  3,26,  7,89,  0,41,  6,57, 13,23,  4, 9, 
    13, 6, 15,89, 11,61, 14,16, 12,42, 18,20,  1,30,  4,57,  9,66, 10,83, 16, 7, 17,21,  3,96, 19, 7,  7,31,  6,99,  0,14,  2,85,  5,57,  8,15, 
     7,45, 17,79, 16,88,  6,58, 14, 2, 19,13, 18,21,  1, 8,  2,37,  8,71,  5,99,  4,49, 10,57, 11,95,  9,19,  3,73, 15,64, 12,64,  0,55, 13,85, 
    18,51, 15,22, 16,11,  9,82,  6,90,  8,41, 17,88, 19,33,  1,91,  0,99, 11,69,  7, 6, 14,33,  3,25, 12,31, 10, 7,  4,38, 13,46,  5,41,  2, 8, 
     9,20, 12,96,  4,88,  8,49,  6,24,  3,89, 11,24, 14,66,  7,69, 15,42,  1,92,  2,62, 10,48, 13,95, 17,28, 19,43, 16,71,  5, 9, 18,53,  0,31, 
    15,44,  1,99, 17,49, 11,47,  7,60,  3,12, 18,22, 19,49,  4,40, 10,24, 13,51,  2, 2,  5,63,  8,99,  6,75,  0,52, 12,59, 16,16, 14,24,  9,55, 
    14,67, 19,73, 17, 3,  9,72, 18, 8, 11,70,  1,73,  4,59, 16,91,  8,69,  5,46,  7,31,  0, 6, 10,35,  2,37,  3,93, 13,42,  6,89, 15,34, 12,25, 
     9,31, 17,26, 12, 7,  3,67, 11,25,  2,43, 15,23, 10,31,  0,28, 16,57, 14,42,  1,16,  5,10,  8,26, 19,50,  7,69,  4,35,  6,18, 13,18, 18,77, 
     5,95, 16,10,  2, 7,  0,88,  8,78, 12,62, 11,93, 19,23, 15,94,  4,22,  6,85, 14,73,  7,59, 18,12, 17,58,  9,93,  1,47, 10,73, 13,90,  3,18, 
    14,82, 15,93,  3,10,  7,46, 11,13,  0,57, 12,30,  6,20,  1,71,  8,41, 13,35, 19,35,  2,52,  4,90,  5,18, 18,80, 17,29,  9,17, 10,74, 16,90, 
    13,39, 17, 7, 18,15, 14,49, 10,34, 15,50,  5,48, 16,77,  1,26,  3,27,  9,78,  7,38, 11,76, 12,40,  0, 2,  2,40,  4,92,  6,73, 19,86,  8, 6, 
    17,47,  2,28, 19,21, 15,80, 18,46,  5,63,  9,76, 16,20, 13, 5,  0,57,  1, 9,  7,71,  3,34, 14,27, 12,87, 10,24,  6,63,  4, 6,  8,66, 11,65, 
    11,52,  4,25,  5,67, 12,53,  3,97,  2, 8,  6,23, 16,84,  0,74, 10,75,  1,18, 15,53, 19,31, 18,66,  8,49, 13,51,  7,29, 17,52,  9,34, 14,44, 
    19,39,  6,17,  4,48, 17,93,  2,97, 18,79,  3,87, 13,40, 12, 2, 15,97, 14,47,  7,47, 10,45,  8,65,  9,29,  5,96, 11, 8, 16,42,  1,74,  0,18, 
     8,37, 16,83, 15,30, 12,92, 18,87, 17,51,  4,91,  0,39, 11,64, 19,65, 14,48,  6,68,  5,42,  1,10, 13,86,  3,96,  9,98, 10,35,  7,51,  2,48, 
    10,98, 17, 2, 13,60, 11,23,  6,52,  2,84,  9,38, 12, 3, 15, 1,  0,46,  7,44,  5,83, 14,68, 16, 9, 18,32, 19,19,  1,67,  3,10,  8,12,  4,99, 
     0,68,  3,38, 14,90,  1,38,  9,58, 18, 9,  5,88, 11,63,  8, 9,  7,35,  6, 4, 15,13, 16,54, 12,94, 17,89, 10,79, 19,74, 13,31,  2,70,  4,97, 
     8,90, 14,18, 16,91,  4,52, 11,51, 18,84, 12,53, 19, 8,  2,90,  5,87,  9,32, 15,21,  7,67,  0,13,  6,60, 13,75, 17,38,  1,36, 10,19,  3,68, 
     6,46, 15,67,  7,80, 16,62, 14,43,  9,65,  3, 9, 18,31, 11,66, 17,42,  0, 6,  2,43,  1,47, 19, 9, 10,30, 13, 6,  5,73,  4,20, 12, 1,  8,12, 
     9,76, 10,36, 11,91,  6,72,  4,61,  3, 8, 12,78, 13,56,  5,24,  0,20, 18,12, 19,51, 14,61, 17,91,  2,17,  7,13, 16,74, 15,63,  8, 9,  1,84, 
     5,71,  7,11, 17,72, 18,40,  8,73,  1, 9, 12, 7, 16,88, 19,19,  4,15, 10,45,  3,54,  0,86,  9,38, 15, 9, 14, 7,  2,74, 11,80, 13,75,  6,80, 
    13,38, 15,91, 10,72, 18,44, 14,31,  9,89,  7, 4, 19,83,  5,57,  3,63, 16,70,  4, 3, 17,12, 12,44,  8,83,  1, 7,  2,32,  0,36, 11,26,  6,49, 
     7,60, 16,88,  5, 3,  2, 4,  9,56,  8, 1, 15,95,  3,31, 19,54, 18,20, 13,51, 12,88,  4,82, 14,68, 17,69, 11,15,  0,72,  6, 3,  1,59, 10,43, 
    12,92,  9,88,  6,40, 16,47,  3,80,  8,23, 15, 7,  0,98, 11, 2,  5,90, 10,74, 18,23, 17,93, 19,94, 13,41,  7,49, 14, 2,  4, 9,  2,83,  1,84, 
    15,84,  8,68,  5,77,  9,54, 13,45,  1,70,  6,34, 14,64, 18,55, 12,66,  3,16, 19,11, 16, 9,  2,79, 17,54,  7,23,  0,63, 10, 1, 11,91,  4,50
  };
  // Taillard 50x20 instance 3
  const int tai_50_20_3[] = {
    50, 20, // Number of jobs and machines
     9,62,  6, 3,  3,77,  2,45,  7,42,  1,77, 15,42, 17,78,  0,20, 18,81,  4,39, 11,91,  5,13, 13,53, 19,30, 10,95,  8,82, 16,70, 12,37, 14,55, 
     2,56,  6,90, 13,21, 14,43,  8,12, 18,94,  7,81, 11,58,  9,20, 19,83,  1,41, 15,84, 17,16,  5, 6, 12,64, 16,63,  0,16,  4,12, 10,93,  3,39, 
    10,95, 11,15,  4,51, 19,53,  9,67, 12,53, 18,26, 17,40,  2,13, 16,39,  7,59,  3,90, 13,45,  6,36, 15,33,  5,76, 14,13,  0,72,  1,42,  8,56, 
     9,51,  0,82, 13,63,  2,66,  3,21,  7,66,  4,72,  6,35, 16,74, 10,60, 17,92, 15,28,  8,89, 12,58, 19,38, 18,14,  5,89,  1,17, 11,88, 14,14, 
    11,25,  9,38,  5,10,  6,71, 10,80, 19,41, 17,76,  1,92, 15,86, 16,33, 14,42,  4,90,  2,18,  0,17, 12,91, 18,24,  7,96, 13,82,  3,77,  8,83, 
     4,48,  8,21,  9,71,  3,94, 15,64, 19,67, 12,21, 17, 2,  0,58, 13,38,  6,12, 10,11,  5,63, 14,27, 11,92,  2,64, 18, 9,  7,50, 16,55,  1,15, 
     4,33,  2,99, 10,49, 19,66,  1,77, 16,88, 15,42,  8, 8,  0,64,  5, 2,  7,86, 18,72,  9,26, 17,86, 12,51, 14, 1,  3,40, 13,33, 11,74,  6, 6, 
    10,45,  9,83,  2,54,  7,19,  5,70, 11,16,  3,74, 18,27, 12,84, 13,13,  8, 6,  4,97, 19,47, 16,87, 15,31,  6,34, 14,37,  1,76, 17,31,  0,37, 
    16,62,  4,96, 14, 7, 18,84,  6,70, 19,31, 11,35, 15,37,  8,99, 17,64, 12,53,  0,39,  1,67,  9,20,  2,15, 10,53,  3,83,  7,25,  5,65, 13,78, 
    12,96,  6,24,  2,88, 11,61,  3,10,  5,77, 15,46,  7,49, 10,91,  1,41, 18,37,  8,69,  0,37, 19,85,  4,14, 17,34, 16,83,  9,30, 14,37, 13, 4, 
     5,29, 18,44, 12,55, 10,51, 17,49, 14,43,  6, 1,  7,32,  8,99, 16,49,  3,84,  1,53, 13,57,  4,40,  9,10, 11,58, 19,78,  0,27,  2,34, 15,32, 
    16, 5, 14,97,  3,37,  2,63,  7,66, 10,40,  1,95, 13,51, 11, 8, 19,35,  0,63,  9,17,  4,88,  5,15,  6,33, 18,11, 17,10,  8,84, 12,55, 15,28, 
     6,20,  0, 7,  9,23,  5,24, 14,11, 18,38,  3,56,  8,73, 11,22,  2,29,  4,12, 16,86, 12, 1, 19,23, 13, 6, 15,45, 17,70,  7,25,  1, 1, 10,79, 
     1,58, 10,62, 14,55,  7,79,  0,55,  6,27,  5,77, 18,13, 12,53,  2,31, 13,11, 15,81, 16, 7, 11,94,  9,11, 17,84,  4, 5, 19,67,  3,19,  8,24, 
     8,74,  3,26, 19,90, 13,73, 18,28,  5,16, 16,30,  6,69, 11,43,  7,48, 10,67,  2,91,  0, 3, 12, 1, 17,93, 14,52, 15,41,  4,31,  1,54,  9,57, 
     9,58,  6, 1,  4,92,  0,83, 18,99, 14,64,  2, 7, 19,22,  3,29,  5,48, 17,70,  7,69, 13,60,  1,51, 16,59, 11,19,  8,25, 12,67, 10,67, 15,71, 
    15, 5, 10,46,  4,19, 11,67,  0,41, 16, 8,  5,51,  7,11,  2,67, 18,68, 13,46, 19,16,  1,18,  3,12, 12,11, 14,11,  6,67,  9, 2,  8, 5, 17,99, 
    11,47,  6,35,  1,57,  9,69, 15,99,  0,16, 16,91, 10,36,  8,14,  3,58, 13,10,  5,91,  7,64, 17,44, 18,79, 12,66,  2,31,  4,10, 19,56, 14, 7, 
    17,45, 16, 3,  0,57, 14,44,  6,34, 13,27, 18,74,  7,88,  4,32, 19, 4,  1,98,  3,25,  8, 7, 15,73, 12,46, 11,14,  2,66,  9,87,  5,55, 10, 6, 
     5,66,  3,28, 18, 4,  0,69,  7,44,  2,58, 11,86,  6,64,  8,16,  4,19,  1, 9, 14,25, 16,26,  9,64, 12,45, 15,10, 10,95, 17,99, 19,46, 13,79, 
    19,30, 13, 9, 12,37,  2,85, 11,69, 18,22, 17,23, 15,97,  6,50, 16,36, 10,12,  9,10,  7,43,  1, 1,  3,33,  4, 7, 14,15,  8,45,  0,28,  5, 3, 
    14,44,  6,59,  7,92,  1,31, 13,69, 11,53,  2,63,  3,94, 12,74,  4,53,  0,67,  8,24, 16, 9, 17,31,  5,84, 10,50, 19,19, 18,78,  9, 3, 15,39, 
    15,46, 12,11,  5,59,  9,27,  1,79, 13,86, 14,51,  7,47,  4,22,  6,16, 11,24,  0,80,  3, 5, 16,57, 17,79, 19,42, 10,46,  2,99,  8,49, 18,54, 
    14,18,  3,37,  0,18, 18,76, 19,30,  8,88,  4,69,  9,19, 13,29, 11,41, 12,58, 10, 8,  6,37,  1,17,  7,23, 15,94, 17,92,  2, 1, 16,79,  5,34, 
    18,29, 16,85, 10,91,  1,43,  4,65,  2, 6, 19,69,  9, 4,  8,94, 12,72,  0,76,  5,83, 13,21,  6,45, 17,10,  7,84,  3,50, 11,74, 15,39, 14,55, 
     5,67, 17,76, 10,91,  4,69,  0,13,  9,72, 18,98,  8,16, 11,79,  3,38, 16,76, 15,70, 19,30,  7,85, 14,93, 12,39, 13, 3,  1,39,  6,88,  2,87, 
     9,90, 18,78, 19,61,  4,61,  0,34,  8, 4, 17,52, 12,59, 13,20, 10,29, 16, 6, 14,60,  1,93,  6,95,  2,55, 11,12,  3,92,  7,22, 15, 2,  5,91, 
    16,63,  0,85, 12,76,  8,72,  1,40, 13,42, 10, 4,  3,66, 19,63,  6,81,  9, 8, 18,61,  4,33,  2,98,  7,94, 15,98,  5,35, 17,90, 14,59, 11,27, 
     4,95, 12, 5, 14,91,  7, 1, 18,52, 17,87,  0,56,  6,83,  1,54,  9,15,  8,55, 11,10, 19,20,  3,73, 10,59, 13,30,  2,14, 16, 6,  5,48, 15,28, 
     4, 3,  3,93,  8,12,  1,66, 17,19,  9,85, 14,66, 11,96,  5,74, 15,73, 10,21, 16,62, 18,91, 13,97,  2,61,  0,62,  6,95, 19,13,  7,33, 12,62, 
     6,54,  7,68, 11,44, 12, 4,  5,62, 19,86,  9,85, 18,42, 10,55,  1,69,  8,67, 17,71,  3,79,  0,66, 13, 1, 14,12,  4,66,  2,94, 16,41, 15,43, 
    18,23, 15,25, 17,21, 12,15, 16,64, 19, 6, 10,96,  8,68, 14,58,  9,75,  3,66,  1,57,  6,85, 11,56,  2,24,  0,34,  7,64,  5, 1, 13,82,  4,71, 
     3,42, 16,97, 19,65, 13,51, 11, 1,  9,16, 12,74,  4,54,  5,87, 15,38,  2,48, 10,54, 14,44,  8,51,  0,48, 17,74,  6,82,  7,59,  1,46, 18,60, 
     5,60,  2,50, 13,86, 17, 7, 16,10, 12,12, 11,50,  8,67,  9,65,  1,41,  3,47, 10,59, 15,43, 19, 1, 14,97, 18,67,  7,81,  6,34,  4,27,  0,39, 
     2, 7, 14,52,  7,81,  0,58, 11, 4, 18,53,  6,86, 10,32, 16,54,  4,38,  9,71, 19,43, 12,58,  1,56, 15,63, 13,73,  8,54,  3,56, 17,34,  5,35, 
     9,99, 18,31, 17,90, 11,67, 15,73, 16,74,  6,69, 19,29,  1,92,  2,86, 10,90,  5,72, 14, 5, 12,21, 13,11,  4, 3,  3, 3,  8,29,  7,27,  0,39, 
     4,75, 14,71, 18,89,  7,31,  6,39, 13,70,  5, 5,  9,60,  0,13,  3,32, 11,22, 12, 1,  2,56, 17,53,  1,84, 10,47, 15,91, 19,85, 16,14,  8,10, 
     5,56,  8,94, 17,47,  9,81, 10,21, 16,84, 13,98,  7, 5,  2,76,  6, 6, 18,62, 19,40, 15,58,  0,18, 14,97,  4,89, 12,18, 11,48,  1,44,  3,48, 
    18,45,  8,55,  9,13,  3,15, 16,96, 10,19, 11,18,  4, 5, 17,62,  0,76, 12,61,  1,14,  6,22, 15,23,  7, 3, 19,80,  2,92, 14,86, 13,87,  5,23, 
     1,10, 11,70, 15, 5,  7,38, 16,42,  4,64,  3,99,  0,28, 13,30, 10,82,  6,92,  9,64, 14,36,  5,56,  2,11,  8,78, 17, 2, 12,18, 19,32, 18,54, 
    11,88,  6,82, 13,27,  9,53,  7,42,  0,53, 15, 6, 16,80,  8,55,  4,95, 12,83,  5,66, 14,11, 10,69,  1,89,  2,79, 18,50, 17, 7,  3,31, 19,46, 
    13,30, 15, 6,  3,64, 18,33, 14,41,  1,35, 11,92, 16,65,  8,54,  7,68,  9,52,  0,13,  4, 6,  6,36, 12,75, 17,59,  2,41, 10,97, 19,24,  5,77, 
    12,70,  3,46,  9,32,  5,34, 13,67, 19,10,  4,32, 17,32, 18, 5,  6, 4, 14,41, 11,13,  1,24,  8,13,  7,14, 16,85, 15,36,  2,18,  0, 1, 10,23, 
     5,43,  4,33, 17,16,  9,91,  3,87, 16, 5, 10,74,  2,43,  0,81, 13,23, 14,54, 11,83, 12, 5,  6,68,  1,45,  7,85, 18, 7, 15,44,  8,90, 19,97, 
     8,64, 18,98, 16,47, 19,16,  4,76, 10,50, 13,61,  3,62, 14,88, 15,37,  2,89,  5,18,  6,38, 17,10,  1, 1, 11,36,  9,10,  0,41,  7,52, 12,55, 
    14,78,  1,89,  5,76, 17,50, 15,89,  6,68, 12,48, 10, 1,  3,77,  7,99,  9,46, 18,50, 11,81,  4,18, 13,60,  8,65, 16,37,  0, 8, 19,47,  2,31, 
    15,56, 10,65,  9,15,  3,13,  2,40,  8,46, 12,74, 19,34, 17, 1,  0,56, 13, 2,  4,96, 16,12,  6,17,  1,20,  5,19, 14,46,  7,97, 18,75, 11,73, 
    10,11,  1,86,  3,80,  7, 8, 14,72,  0,15,  5, 8, 11,77, 15,24, 12,78,  4,53, 17,29, 16,13,  6,66, 13,64,  9,58, 19,19,  8,18, 18,45,  2, 5, 
    12,97, 17,73, 18,13,  2,34, 11, 5,  9,84, 10,60,  0,22, 15,40,  5, 3, 19, 8,  7,64,  8,23, 16,66,  6, 3, 13,35,  3,61,  1, 7, 14,32,  4,44, 
     0,33,  7,16,  9,52, 18,72, 19,54, 14,67,  6,71,  8,41,  1,55,  4,32, 17,41, 12,27, 10,54, 13,72, 16, 1,  2,14,  5, 5, 11,13,  3,85, 15,20
  };
  // Taillard 50x20 instance 4
  const int tai_50_20_4[] = {
    50, 20, // Number of jobs and machines
     7,32, 15,13, 11,32,  5,51,  9,74, 16,73,  0,48,  8,13,  1, 6,  4,59, 14,33, 18,18, 13,85, 10,13,  3,57, 19,82,  6,71,  2,32, 17,75, 12,50, 
    15, 6,  0,64,  2,34,  5,60, 12,49, 17, 3, 10,59,  4,47, 11,15,  1,77, 18,24,  3,78,  9,71, 14,19, 19,65,  8,88,  6,23, 16, 2,  7,32, 13, 5, 
    15,69, 11,26,  8,30, 17,90,  3,43,  7,17, 12,23, 13,62,  2,17, 16, 4,  4,18, 19,70,  9,19, 14,15,  0,17,  5,84,  1,54, 18,17, 10,55,  6,81, 
     6,23, 16, 7,  1,49,  7,94, 11,75,  5,56, 14,92,  4,58, 17,32,  2,88, 19,39,  3,59, 18,13, 10,14,  9,49,  0,53, 13,18, 15,13,  8,56, 12,35, 
    13,11,  8,59,  2,77,  0,20, 19,60, 11,33,  9,16, 10,13,  7,72,  1,35, 17,36, 12,92,  6,31, 14,92, 16,53,  4,89, 15,70, 18,21,  5,37,  3,12, 
     9,69,  5,55, 14,23, 17,81, 12,43, 11,62,  3,17,  0,95, 13,39, 10,29, 18,21,  1,95,  8,62,  7,41, 16,74, 15,75, 19, 7,  6,99,  2,58,  4, 8, 
    15,11, 12,84,  4,17,  2,87, 14,45,  5,68, 16,10, 18,10, 11,14,  8,86,  7,90, 10,94, 13, 9, 17,76,  0,75, 19,62,  1,61,  6,23,  3,96,  9,99, 
    10,88,  0,84, 18,41,  1,81, 16, 4,  7, 6,  8,72,  3,98, 13,70,  6,27, 15, 9,  9,45, 19,51, 11,84, 14,92, 12,41,  2,20,  4,19,  5,62, 17,29, 
     7,52, 14,25,  0, 6,  6,91, 12,12,  1,79, 11,26, 19,80,  8, 6,  5,16,  3,84, 18,33,  2,13, 10,64, 13,61, 16,41,  4,77,  9,31, 15,74, 17,67, 
     0,60,  7,95,  5,20,  8,99, 14,30,  1,48,  4,11, 15,55, 12, 7,  2,55,  3,17,  9,79, 10,18,  6,59, 18,22, 11,26, 16,35, 19, 1, 13,25, 17,40, 
     6,21, 10,14, 14,63,  7,63, 11,89,  0,19, 19,84, 15,85,  4,26,  9,78,  5,53, 16,98,  8,23,  2,84,  1,53,  3,47, 18, 2, 13,98, 17,58, 12,62, 
    12,17,  4,52,  1,12, 15,60, 19,21, 16,10, 17,18, 11,30,  6,57,  2,65, 13,31,  8,18, 18,95,  3,88,  0,41,  5,92, 14,75,  7,18, 10,87,  9,56, 
     1,36,  5, 6, 10,93,  4,57,  9,28,  2, 9, 16,93, 19,18,  7,38, 14,53,  3,88, 11,99, 17,11, 12,86, 13,75,  8,87, 15,16, 18,29,  0, 9,  6,53, 
    18,70,  2,59,  7,33, 17, 8, 14,80, 15, 8,  4,58,  3,97, 11,96, 19,47,  9,36,  5,29, 12, 1,  6,13,  8,17,  1,34, 16,34, 10,34,  0,65, 13, 7, 
     5,62, 15,33, 11,45, 14, 4, 12,20, 13,14, 18,24,  9,84, 19,58,  2,90, 16,95,  6,46,  4,60,  3,11,  1,29,  0,39,  7,24,  8,22, 17,93, 10,58, 
    16,30, 19,49,  0,93, 12,82, 18,67, 15,25,  1,63,  7,99, 14, 5,  9,93, 11,72, 13,13,  5,17,  2,73,  4, 5, 17,39,  6,20,  8,27, 10,50,  3,67, 
    10,99, 19,22, 16,94,  7,70,  6,69,  4,41, 15,46,  3,88, 13,87, 11,11,  8,55, 17,51, 18,56,  1,32, 14,29,  2, 6,  9,97,  5,54,  0,92, 12,84, 
     1,92,  3,29, 17,58, 18,91,  5,18, 11,15, 14,22,  9,79, 16,18, 12,95, 19,14, 13,66,  2,47,  4,70,  0,90,  6,60,  8,79,  7, 6, 10,60, 15,57, 
     8, 8, 11,64, 15,97,  2,20,  3,17, 10, 2, 18,65,  6,92,  5,29, 17,27, 12,62, 19,49,  7,95, 16, 5,  9,93,  1,38,  0,82,  4,41, 14,43, 13,16, 
    10,15, 18,11,  8,33, 13,83, 15,78, 19,32,  4,19,  9,52,  6,86, 16,20,  0, 8,  5,22,  2,42, 17,80,  1,61, 12,76, 11,15,  7,86, 14,15,  3,73, 
    13,48, 12,28,  7,37,  6,12, 15,61, 16,89, 11,31,  2,90,  9,92, 19,52, 18,99, 17,51, 14,48,  5,98,  0,99,  1,47,  4,98,  3,17,  8,32, 10,70, 
    12,78,  2,32,  1,66,  5,34,  3,58, 14, 6,  8,93, 17,19, 10,97, 13,42,  9,27, 11,22, 19,16, 18,92,  7,41,  4,87,  6,32,  0,49, 15, 1, 16,10, 
    18,99,  5,57, 17,77,  1,48, 12,33, 14,59,  7,51, 10,91,  6,75, 19,24,  4,15,  9,16,  0,56, 16,80, 11,42, 15,69,  3,73,  8,86, 13,85,  2,58, 
    19,72, 15,61,  4,26,  7,62,  8,15,  9,44,  6, 3,  0, 7, 10,78,  3,56, 18,90, 13,84,  1,34, 17,13, 16,95,  2,61, 11,52, 14,76, 12,22,  5,41, 
     5,24, 15,16, 16,13,  9,88, 17,92,  1,17,  7,27, 13,23,  6,10,  0,88, 18,88, 11,43, 12,70,  4,74, 10,84, 19, 5, 14,36,  3,71,  8,68,  2,69, 
    17,58,  8,70,  5,26,  0,59, 13,19, 16,87,  2,55,  1,12, 19,49, 18,41, 14,87,  4,52,  3,85, 12,39, 15,38,  7,21, 10,49,  6,16,  9, 8, 11,85, 
    12,48, 14,40, 19,65,  2,92,  5,11,  9,29, 17,68,  7,70,  3,21,  0,49, 18,42,  1,67, 13,40, 16, 6,  8,39, 10,29, 11,41,  4,82,  6,93, 15,19, 
     5,54,  3,66, 10,18,  1,54, 14,85, 11,42, 16,35, 12,55,  0,58,  4,33, 19,52, 17,28,  6,31,  7,97, 13,51,  8,14,  2,99, 18,50,  9,14, 15,31, 
     3,77,  6,11, 13,61, 18,44,  2,20, 19,39,  5,21, 15,80, 11, 3,  1,44, 14,13, 17,73, 10,96,  4,69, 16, 5,  8, 2,  9,73,  0,74,  7,30, 12,42, 
    14,93, 11,85,  0,73, 12,76, 17,33,  1,93, 19,98,  7,84, 15,83, 13,54, 18,15,  4,17,  3,33,  2,82,  8,52, 10,72,  9,37,  5,95,  6,45, 16,50, 
     7,82,  6,47, 19,93, 12,41,  4,23,  0,98,  8,12, 14,52,  9,78, 10,11,  1, 2, 15,25, 11, 2, 17,39,  5,79, 18,96,  2,33,  3,81, 13,74, 16,40, 
     6,66, 14,36,  5,12,  0,88,  3,83, 17, 4, 12,84, 16,68,  9,27,  2,65, 13,90,  1,73,  8, 1,  4,44,  7,27, 11,96, 19,73, 15,12, 18,27, 10,22, 
    16, 1,  8,41,  4,53,  1,29, 13,75,  0,17, 11,53, 17,83, 12,62,  3,93, 15, 5, 19,94, 18,25, 14,65,  6,68,  2,44,  9,16,  7,48,  5,58, 10, 7, 
     9, 9,  0,15, 16,42, 10,32, 19,51,  3,74,  4,58,  5,26, 12,51,  6,25, 17, 9,  1,52,  2,87,  7,23, 11,70, 18,58, 15,14, 14,49,  8,51, 13,54, 
     9,85,  5,14,  1, 8,  8, 8,  2,50,  0,94, 11,11, 14,87, 19,44,  4,35,  7,69, 18,62, 10,35, 15,55, 12,77, 17,92, 13,89, 16,20,  6,65,  3,13, 
    10,80, 11,79, 14,32,  7,35, 13,67, 15,44,  9,37,  5, 7,  1,93,  2,73,  4, 6, 16,77,  3,77, 19,84,  8,12, 18,48,  0,51, 17,73, 12,89,  6,27, 
    12,65, 16, 1,  9,29,  3,60, 13,55, 18,47,  1,69,  5,88, 10,62,  7,22, 17,44,  2, 3,  8,56,  4,75, 11,80,  0, 1, 15,65,  6,76, 19, 4, 14,66, 
     0, 3, 18, 6, 16,61,  9,62, 13,54,  1,85, 10,26,  7, 4,  3,27,  5,54, 12,84,  2, 3,  6, 2,  4,12, 19,44, 15,89, 11,81,  8,16, 17,79, 14,68, 
     3,15, 11,34, 18,70, 12,90, 15,47, 17,72,  0,25, 19,57,  4,20, 13,80, 16,88,  7,44,  9,78,  2,79,  6,53, 14,42, 10,64,  5,84,  8,15,  1,42, 
    13,29,  6,54, 16,11, 10,93,  1, 2,  9,86,  0,81,  7,23, 18,99,  8,49,  3,98, 11,78, 15,14,  5,25,  2,74, 14,94, 17,91, 12,32,  4, 5, 19,69, 
     3,23,  6,94, 12,61, 15,39, 14, 8,  7,71, 10,93, 13,72, 17,55, 16,95,  1,12,  2,60,  4,82,  0,46,  8,82, 18, 7,  5,55, 11,38,  9,86, 19,35, 
     6,45,  2,56, 19,10,  5,49, 12,77,  9,43, 10, 8, 11,66, 16,31, 17,74, 13,93,  0,49,  1,57, 18,23,  4,26, 14,97,  8,94,  3,71,  7,23, 15,97, 
     3,56, 19,90, 18,71, 10,50,  4,29,  5,63,  0, 1, 17,69,  9,97, 13,85, 16,42,  1,20, 12,20,  8, 3,  7,43,  6,86, 14,97, 15,22,  2,52, 11,21, 
     8,81, 16,12,  9,71,  7,39, 10,99, 15,70,  3,35,  4,84, 18,22, 17,47,  6,64, 19,98,  2, 7, 14,12,  1,75,  5,64, 12,86, 13,27,  0,38, 11,10, 
     9,35,  4, 6,  7,91, 12,16,  6,46, 13,79, 15,55, 17,96,  1,86,  5,45, 11,43,  2, 5, 14,95,  3,14, 19,30,  8, 4,  0,38, 10,91, 18, 9, 16,44, 
     4,20,  1,65,  7,18, 19,21, 17,13,  0,74,  9,44, 18,39, 16,97, 10,24,  3,33, 12,14,  2,43, 14,17,  6,80, 15,73, 13,39, 11, 6,  5,14,  8,43, 
    15,61,  2,83, 19,46, 14,71, 16,25,  9, 8,  1,81, 13,60, 10,14, 18,30, 17,10,  5, 1,  0,61,  4,53, 11,20,  7,19,  3,15,  8,12, 12,10,  6,35, 
    16,36, 14, 8, 10,78, 12,32, 13,93,  7,31,  8,11,  9,41, 18,12, 17,10,  5,49,  4,19, 19,99, 11,73,  2,95,  0,38,  6,83,  3,11,  1,25, 15,37, 
    11,37, 14,90,  0,80,  6,26,  2,42,  9,34, 15,67,  5,59, 12,81, 10,74, 16,17,  3,41,  7,27,  4,72, 19,37, 18,82, 13,78, 17,76,  8,59,  1,14, 
    13,47,  7, 1, 11,10,  0,88,  1,38, 19,83,  9,83, 17,99,  8, 1, 12,28, 18,61,  2,62, 14,76, 16,43,  3,29,  4,83, 15,97, 10,60,  6,29,  5,73
  };
  // Taillard 50x20 instance 5
  const int tai_50_20_5[] = {
    50, 20, // Number of jobs and machines
    10,75,  5,50,  2, 4, 17,34, 14,36, 19,69,  1,52,  4,44,  8,42, 16,12, 11,50,  3,12,  0,71,  6,89,  7,31, 12,14, 13,13, 18,53, 15,43,  9,43, 
     5,27, 13,18,  4,70,  3,84, 19, 8, 18,62, 16,91,  2,24,  0,94, 10,98, 11,78,  7,90,  1, 1, 15,24, 12,96, 14,61,  9,90,  8,67, 17, 7,  6,72, 
    10,56, 15,84, 19,95,  9,32, 16, 8, 12,43,  7,37, 17,25,  8,10,  1,85, 18,78, 13,76,  6,94,  5,60,  4,37,  0,68, 14,11, 11,66,  2,66,  3,83, 
    12,65, 10,95,  8,66,  4, 4, 15,34, 18,55, 11,35, 16,32,  6,78,  9,52,  0,10,  1,58, 19, 9,  5,73,  3,18, 17,52,  2,57, 14,59,  7,27, 13,89, 
     5,31, 15,81,  6,45,  7,21,  3,74, 17, 7,  9,43, 11,35,  1,23, 18,63, 12,12, 13,92,  4,78, 19, 9,  0,30, 10,22, 14,19,  8,70,  2, 4, 16,17, 
    17,53,  9,51,  8,35, 14,11, 10,55, 16,18, 13,89, 12,91, 11,16, 15,82,  2,84,  3, 4,  5, 2,  0,95,  1,17,  4,92,  6,81,  7,22, 18, 7, 19,58, 
    15,92, 19,47, 18,10, 12,47,  2, 4,  3,75,  5,41,  0,51, 14, 2,  4,73,  8,52,  1,38,  7,44, 17,23, 10,31,  9,90, 11,90, 13,81, 16,75,  6,84, 
     6,31,  5,20, 16,32,  4,54, 13,10,  1,96,  9, 6,  7,81, 14,73, 11,75,  0,95,  3,81,  2,31, 10,81, 18,90, 15,33, 19,64, 17,96,  8,21, 12, 1, 
    17,67,  1,61,  3,18,  6,81,  0,77,  9,35, 12,12, 19,28, 16,82,  7,10,  8,71,  4,94,  2,51, 13,54,  5,25, 18,37, 15,34, 11, 2, 14,71, 10,60, 
    12,29, 17,78,  5,33, 16,54,  7,20,  1,75,  8,88,  0,35, 19,70,  6,35,  3,53, 14,36,  2,82, 10,26, 15,24,  4,28, 18,10, 13,98,  9,86, 11, 2, 
     2,30, 18, 2,  0,96, 19,66, 10, 3, 17,81,  1, 4,  8,53,  7,12, 16,36, 15,61, 14,78,  5,25,  4,75,  6,44, 13,12,  3,81, 12,23, 11,41,  9,87, 
     7,98,  2,47, 12,85,  0,90, 16,74, 14,94,  3,24, 15,18, 17, 8,  5,90, 19,55,  4,67, 10,52,  8, 3, 18,28,  1,29, 13,73,  9,96, 11,57,  6,55, 
    17,18,  0,72, 12,88,  4,58,  5, 5,  1,81, 10,93,  8,95, 11,36, 15,51,  3,53, 16,61,  7,72,  6,63, 19,36, 13,48,  9,96, 14,92, 18,21,  2,61, 
     9,55, 15,45,  4,91,  3,24, 18,77,  1,71, 16,12, 14,91, 13,68,  5,55, 19,88,  0,76,  8,89,  7,14, 10,92, 12,64, 17,66, 11,13,  2,48,  6,57, 
     8,92,  5,18,  3,56, 19,69,  1,86,  2,23, 17,33, 13,86,  6,52, 10,71, 12,97, 15, 9, 11,16,  0,38,  9,69, 14,34,  4,43,  7, 1, 16,71, 18,84, 
     1,59, 15,50,  8,11, 13,21,  4,47, 12,52, 17,78, 19,72,  6,86,  9,28,  0,81,  2, 5, 18,29, 14,36, 11, 7,  5,68,  3,28, 16,97, 10,49,  7,93, 
    14,34,  9,20, 18,32,  6,90, 17,59, 10,53, 19,92, 16, 1,  4, 8,  5,10, 12,10, 15,25,  0, 8, 13,53,  1,25, 11,79,  3,85,  8,28,  7,10,  2,33, 
     8,37, 17,51,  5,79, 13, 6,  9,28, 14,40,  7,19, 18,60,  0,14, 10,12,  1,31,  2,25, 15,15, 16,84,  6,83, 11,85,  3,87, 12,34,  4,42, 19,92, 
    14,24,  6, 3,  8,12, 13,39, 16, 5,  0,28,  2,51,  3,68,  9,36, 18, 6, 15,12, 10,54, 11,61,  4,11,  5,99, 19,39,  1,53,  7, 3, 12,33, 17,48, 
    14,38,  8,81,  2,84,  7,12, 19,36,  5,96, 16,67,  6,46,  1,90, 13,78, 18,22, 11,83,  0,85,  4,97, 15,50, 12,78, 10,91,  9,83,  3,49, 17,31, 
     9,10,  5,42, 19,29,  3, 1, 11,88,  4, 7, 12,11,  2,41,  8,51,  1,40, 13,90,  6,20,  0,42, 18,40, 10,25, 17,31, 14, 8, 15,86, 16,84,  7,25, 
    18,12, 12,70,  0,93,  8,77,  2,18,  1,13, 16,70, 15,35, 13,97, 14,50, 11,32,  4,88,  7,98,  5,37,  9,82,  3,53, 10,21, 17,93,  6,60, 19,93, 
    19,14, 15,85,  0,21,  7,25, 12,72,  4,38,  3,43,  6,68, 10,38, 17,18, 14,35, 16,49,  8,99,  2,48,  9,87, 13,11, 18,16, 11,96,  1,36,  5,84, 
    17, 6,  9,23, 10,97,  8,72, 11,32, 16,77, 19,35, 12,62, 14,15,  6,72,  1,48, 15,34,  0,51,  7,24,  4,71,  2,18,  3, 5,  5,37, 13,56, 18,13, 
     1,10, 17,38,  5,81, 18,77,  2,83,  7,40, 16,43, 11,64, 15,91,  4, 1,  0,48, 10,80,  8,15,  3,21, 12,27, 19,16, 14,60, 13,45,  9,65,  6,88, 
     0,20, 17, 4,  9,79, 15,87, 16,27,  1,84,  6,20,  3,46, 12,91, 10, 9,  8,24,  5,98, 13,28,  2, 2, 19,76,  7,22,  4,88, 11,67, 14,32, 18,37, 
     4,23, 12, 7,  2,62,  1,49, 17,98, 14,61,  6,59, 15,38,  0,13,  9, 5,  5,75, 11,74,  7,65, 18,66,  3,60, 10,14, 16,79, 13,45,  8,47, 19,51, 
     1,23,  6,45, 13,96, 19,35, 18,37, 11,34, 17,29,  7,12, 10,89, 15,69,  4,74,  3,52,  9,98,  0,17, 16,86, 12,76,  8,96,  2,66, 14,86,  5,37, 
     2,74,  4,99, 16, 9, 12, 9, 14,74, 15,83,  9, 3,  8,96, 19,44, 10,23, 13, 3,  0,18,  1, 3, 11,45,  5,38,  6,24,  7,91, 17,36,  3,22, 18,15, 
    15,34,  4,23,  6,68, 13,11, 14,53, 19,77,  5,71,  1,65, 17,77, 16,48, 12,43, 11,45, 10,83, 18, 7,  8,93,  2,65,  0,83,  3, 8,  7, 5,  9,74, 
     8,40,  2,15, 15,30, 12,90, 10,62,  3,15, 18,13, 13, 3,  9,49,  0,90,  5,55,  7,65, 19,85, 16,87, 17,24,  1,61, 11,50,  4,48,  6,77, 14,21, 
    19,42,  8,91, 10,70, 16, 8, 18,45,  6,24, 14,63, 13,86, 11,16,  9,68,  2,57,  7,18,  3,60,  4,81,  0, 3,  1,17,  5,68, 15,97, 17,42, 12,54, 
    15,87,  9,95, 16,25, 10,61, 18, 9, 13,30, 11,84, 14,21,  6,88,  3,83,  1,72,  4,86,  8,20, 19,73, 17,39,  7,71,  0,52,  2,37,  5,72, 12,40, 
     1,46, 12,45, 17,87,  2,44,  9,27, 10,44, 15,19, 19,51,  4,83, 16, 2, 18,21, 11,13,  7,50,  8,17, 13,95,  0,83, 14,33,  5,29,  3,92,  6,62, 
     6,22, 19,73,  2,35, 17, 4, 15,22, 12,99, 14,99, 16,65,  4,54,  7,72,  1,59, 11,98,  5,44, 13,19,  9,23,  0,95, 18,87,  3,69,  8,68, 10,57, 
     3,20,  0,79,  6,95,  2, 6, 12,38, 16,36,  5,37,  8,21, 18,62,  1,48, 13,78,  9,18, 11,70, 14,78, 19, 1, 10,21, 17,85,  7,39, 15,34,  4,98, 
    14,56,  7,60,  3,33,  6,80,  9,68,  8,60, 16,41,  1,82, 15,17,  2,89, 17,59, 13,71,  5,49, 12,75, 19,45, 10,22, 18,60, 11,83,  4,71,  0,22, 
    18,72, 13,72, 19,11,  2,15, 10,72,  6,65,  4,56, 14,77, 15,68,  9,17,  7,59, 16,17,  1,68,  0,69, 12,71,  5,60, 11,39, 17,42,  8,78,  3,62, 
    12,12,  1,27, 10,16,  3,23,  0,12, 13,74,  2,72, 18,48, 15,35, 16,53,  9, 9,  8,80,  4,68,  7,15, 19,62,  5,23, 11,14, 14,89,  6,12, 17,67, 
     7,74, 12,53,  2,76, 13,97,  6,71,  4,81, 17,28,  0,70, 15,67, 19,26, 16,97,  3,11,  1,77,  5,56, 14,62, 11,41, 10,50, 18,40,  8,35,  9,79, 
     2,75, 18, 3,  5,32, 12,10,  0,93,  6, 2, 19,63,  9, 4,  1, 4, 15,18, 13,85, 14,28,  3,55, 16,80,  8,59, 17,74, 11,51, 10,74,  4,20,  7,46, 
     4,32,  2,77,  8,49, 11,76,  3, 6, 14,93, 19,57, 10,11,  9,69, 18,35,  6,59,  1,20,  5,22, 13,13, 17,35,  0,99, 15,95, 16,99,  7,74, 12,96, 
     3,55, 16,38, 14,80, 15,25, 12,73, 19,56, 18,87,  6,16,  7, 2,  5,80, 10,43,  2,50,  4,68,  0,12, 11,19,  1,25, 13,17, 17,52,  8,31,  9,31, 
    14,53,  3,69,  9,57, 16,98,  4,48, 17,26,  6,30, 10,20,  0,74, 18,47,  1,99, 15,78,  5,97, 12,94, 11,80,  2,74,  7,42, 19, 2, 13,46,  8,32, 
     9,54, 12,14,  1,96, 14,39, 15, 1,  7,98,  8,43,  2,57,  6,29, 10,76, 18,36,  3,58, 19,93, 11,17, 17,38, 13,81,  4,74, 16,20,  5,39,  0,98, 
     0,80, 19,94, 12,69, 15,69, 13,54,  7,30, 17,86,  6,80,  5, 6, 18,72,  9,65,  2,45, 14,89,  3,67, 16, 6, 11,28,  1,76,  8,28,  4,29, 10,28, 
    14, 1, 11,74,  6, 8,  8,96,  7,20, 12, 7,  5,26,  4,25, 19,18, 18,84, 15,29, 16,92,  2,18,  0,38, 10,93, 13, 8, 17,32,  9,67,  3,81,  1,17, 
    12,36, 11,41, 13,72, 19,31,  9,28, 18,52,  5,14,  6,59,  2,97, 15,71, 14,92,  0,50,  8, 4,  1,96,  3, 6,  7,99, 16, 1, 17,70, 10,58,  4,92, 
     6,24,  1,81,  9,84,  5,57, 15,59, 11,94, 10,31,  7,98,  0,37, 12,64,  2,69,  8,56, 14,71, 17,23, 13,30,  3,97, 16,86, 18,29, 19,16,  4,75, 
     2,33, 13,81,  8,58, 10,81, 18, 2,  4,25,  6,17,  7, 1,  5,72, 11,33, 16,18,  3,22, 17,44, 19,28,  0,69, 14,92, 15,90, 12,43,  1,53,  9,76
  };
  // Taillard 50x20 instance 6
  const int tai_50_20_6[] = {
    50, 20, // Number of jobs and machines
    15,37,  2,64, 17,15, 11,52,  3,71, 19,38,  5,53, 14,70,  7,76, 10,76, 18,61,  1,10, 12,51,  9,59, 13,12,  4,74,  6,61, 16,52,  0,68,  8,19, 
    10,79, 18,71, 14,32,  1,18,  9, 9,  6,99,  5,85, 16,94, 11,41, 19, 1,  0,18,  4,98,  3, 2,  2,47, 15,57, 17,44,  7,25, 13,48,  8,12, 12,24, 
    16,50, 12,55,  8,25,  3,24,  6,43,  9,64, 18,40, 19,37,  4,30, 10,71, 13,64, 11,13,  5,33, 14,26, 15,42,  1,64,  0,55, 17,76,  2,17,  7, 8, 
     8,31, 12,22,  6,38, 19, 9,  4,84,  5,68, 14,35,  2,94, 11,79, 16,79, 18,40, 10,39,  0, 9, 17,36,  9,82, 13,39,  1,33,  7,43, 15,86,  3,74, 
    18,17, 16,73, 17,55,  3,30,  8,28, 14,35, 15,72,  5,30,  1,50,  9, 3, 19,84, 13,72, 11, 4,  0,73,  2,54,  6,15,  4,64, 12,43, 10,10,  7,80, 
     7,55,  3,13, 12,64, 16,94, 10,89, 18,21,  6,31,  4,82,  9,54, 19,16, 15, 8, 11,99,  0,70, 17,22,  2,89,  5,65, 14,56, 13,92,  8,15,  1,77, 
    18,41, 19, 4,  7,42,  5,81, 10,82, 16,56, 15,79,  6,97, 13,47, 17,91,  1,48,  2,86, 14,28, 12,80,  3,89,  9,91,  4,44,  8,67, 11,67,  0,53, 
    15,27, 13,96,  8,43, 19,23,  6,50, 11,78,  3,46,  0,13, 18,54,  9,20, 16,37,  1,22,  2,13, 12,53,  7, 4,  4,53, 14, 7, 10,53,  5,56, 17, 4, 
     1,28,  0,83, 18,63,  6,76, 17, 2, 16,11,  5,16, 13,55, 10,78, 15,55,  9,77, 19,32,  4,27, 12,46, 14,17,  2,45,  3,40,  8,94,  7,10, 11,12, 
    18,59,  2,81, 17,85,  0,87,  5,37,  1,30, 13,32,  9,10, 10,72, 11,99,  7,23,  6,32, 12,27, 14,32,  3,77, 15, 6,  8,60, 16,85,  4,79, 19,66, 
    10,89,  1, 8,  5,85,  3,49, 19,54,  2,13,  4,32, 18,33, 15,53, 13,76,  6,83, 12,75,  9,29,  0,79,  7,65,  8,50, 11,37, 14,18, 17,36, 16,46, 
    11,51, 14, 5,  6, 6,  2,64,  9,33,  4,14,  0,42,  1,12,  8,92,  7,68, 18,94, 13,29, 19,89, 15,40, 16,10, 17,43,  3, 8,  5,82, 12,88, 10,86, 
    16, 7,  0,85, 13,12, 11,56,  2,61,  8, 6,  5,77,  9,64,  4,40,  7,13, 15,86, 14,38, 18,89, 10,98, 12,42, 19,93,  3,86,  6,97,  1,33, 17,22, 
     7,86,  0,45, 13,99,  5,80, 14, 8,  9,76,  3,42, 15,14,  4,81,  8,85, 11,88, 12,16, 19,48, 17,23, 16,27,  2,49,  1,42,  6, 5, 10,61, 18,26, 
     3,36, 11,60, 10,80,  6,34,  8,30,  5,53, 17,91,  9, 2, 14,89, 12,31,  2,61, 16,35, 18,69,  7,28,  1,16, 15,70, 19,88,  4, 1, 13,97,  0,33, 
    13,48, 14,21, 17,64, 11,50, 16,79,  5,26,  2,20,  3,11,  6,16,  1, 3, 18,61,  9,29, 15,97, 12,66,  0,98,  4,51, 19,54,  8,50, 10,96,  7,33, 
     8,61, 13,16, 10,30,  7,30,  9,96, 12,35,  2,20, 14,63,  6,61, 18,15, 11,45,  1,63,  4,66, 19,61, 17,70,  3,75,  0,89, 16,97,  5,17, 15,60, 
     7,78, 16,41,  2, 9,  6, 8,  3,26,  5,69,  1,55,  0,30,  9, 7, 13,27, 14,59, 12,33, 18,18,  4,77, 10,57, 11,90, 15,24, 19,41, 17, 6,  8,71, 
    17,61,  7,27,  1,46, 16,30, 18,46,  9,15, 10,24, 11,99,  6,44,  2, 1, 15,16,  5,11,  3,15, 19,38, 14,54, 12,13,  4,73, 13,68,  8,85,  0,54, 
    12,14,  6,33, 16,65, 11,97,  8,74, 14,55,  0,18, 19,76,  1,74,  2,70, 10,78,  3,15, 18,40, 17,22,  7,56,  9,68, 13,31,  5,53, 15,19,  4,89, 
    13,61,  3,97,  7,92,  1,64,  6,89, 19,51, 16,68, 11,83, 14,21, 17, 5,  2, 5, 18,85,  4,67, 10,94,  8,97, 15,71,  0,39,  5,58,  9,30, 12,82, 
     1,82, 12,20, 18,82,  5,14, 19,71,  2,91, 14,61, 17,19, 10,67,  3,78,  9,53,  4,56, 13,40, 11,51,  0,46,  6,95, 15,38,  7,12,  8, 9, 16,90, 
     6,97,  4,90,  8,34, 11,99, 17,28, 13,84,  5,65, 12,57,  1,29,  9,87, 15,13, 10,23,  2,51,  0,88, 19,36,  3, 7, 16,34, 18,18, 14,59,  7,96, 
     4,19,  7,85,  5,91, 19,30, 12,69,  9, 2, 15,96,  1,21, 17,81,  6,32, 16,79, 18,46, 14,92,  0,88, 13, 3,  3,20, 10,53, 11,21,  2,57,  8,20, 
    10, 9,  2, 5,  0,50, 13,26,  4,67, 16,64, 12,34,  1,73,  7,29, 15,56,  5, 7,  9,70,  3,54,  6,47, 18,82, 14,30, 17,17,  8,92, 11, 2, 19,23, 
    11,41, 14,79,  7,72, 16,88,  3, 1, 10,64,  6,99, 13,32,  4,55,  2,80,  0,28, 15,87,  5,65, 18,36,  1,72,  9, 5, 17,13,  8,56, 12,32, 19,72, 
     4,56, 16,85,  8,52,  3,64,  0,60, 17,81,  5,44, 12,43,  2, 9,  7, 4,  9,61, 18,24, 14,62, 10,56, 13,17, 19, 9, 11,29,  6,45,  1,63, 15, 7, 
    16,64,  5,68,  7,94, 10,46,  8,16, 17,10, 14,81,  0,19, 13,91, 18,75, 15,95, 12,21,  1,50,  6,82, 11, 2, 19,73,  2,55,  4,93,  9,39,  3,35, 
    12,69,  8,65,  7,25, 17,51,  2,28,  4,76,  9, 1, 18, 3,  1, 6,  5,74, 10,11, 13,59, 11,91, 19,10,  0,35, 15, 8, 14,27, 16,35,  6,28,  3,97, 
    15,41,  3,45, 16,53, 19,13,  6,92, 11,56,  8,42,  0,48, 12,67,  5,97,  9,80,  4,57, 18,80,  1,10,  7,90, 13,26,  2,68, 10,35, 17,84, 14,99, 
    13,43,  9,68,  1,28,  0,76,  8,32, 11,20,  5,89, 10,28, 17,46, 18,17, 16,41,  2,32, 14,37, 19,32,  4,48,  3,47,  7,32,  6, 2, 12,26, 15,37, 
    11,83, 16, 8,  4, 5, 17,24, 18,69,  6,69,  3,93, 13,54, 12,90, 19,15, 14,63, 15,71,  1,84,  7,78,  0,62,  5,84,  9,99, 10,82,  8,30,  2,51, 
     1,69,  3,64,  9,75,  0,23,  5,93, 17,48,  8,11,  7,18, 13,89, 11,96, 18,70, 10,99, 16,52,  4,70,  6,23,  2,85, 12,50, 19,81, 15,17, 14, 5, 
    15,87,  0,55, 10,48,  4,85,  2,17,  8,79,  6,73, 12,19, 13,22,  7,37, 18,12,  3,19, 16, 9, 11, 5, 14, 4,  5,85, 19,88, 17,46,  1,10,  9, 4, 
     7,86,  3,36, 13,90,  1,63, 12,48,  2, 4,  9,15, 15,15,  8,15, 14,39,  6,73, 10,89, 11,58,  4,80,  0,71, 18,54,  5,25, 16,41, 17,84, 19,73, 
    18,42,  6,48,  3,88,  9,71, 10,68, 13,25, 12,33,  5,88,  7,62, 19,51, 15,49,  1,76,  8,22, 17,47, 11,63,  4,61,  0,16, 14,10,  2,94, 16,47, 
    15,32, 13,41,  4,99,  0,48,  2,82, 10,52,  3,46,  8,67, 19,63,  9,16, 17,24, 11,32, 18,88,  6,74,  1,13,  7,24,  5,82, 16,28, 12,74, 14,14, 
     7,56, 19,60, 18,70, 16,93,  8,22, 12,62,  4,50,  6, 2,  0,15, 14,99,  9,20,  2,45, 15, 6,  5,81,  3,13,  1,51, 13,12, 10,12, 11,55, 17,35, 
    17,46,  7,12, 19,92, 16,23,  2,99, 13,11, 18,99, 11,88,  0,22,  1,18,  3,29, 10,53, 15,56,  6,56,  9,43,  4,53,  8,10, 12,41, 14,61,  5,12, 
     9,49, 18,48,  2,25,  4,40,  1,20, 10,10, 17,96,  5, 8,  0,48,  8,91,  3,88, 15,30, 12,90,  6,53, 16,25, 11,32, 19,43,  7,50, 14, 3, 13, 4, 
     7,90, 18,42,  1,20,  9,12,  5,61, 13,89, 16, 2, 11,57, 19,26, 14,77,  2,32, 15,41,  3,89, 17,45,  8,55, 12,37,  6,66,  4,11,  0, 1, 10,55, 
     5,22,  4,39, 10,26, 16,85,  7,61,  1,54,  2,27, 11,25,  0,31, 13,47,  8,54, 14,16,  6,77, 19,29,  3,71, 18,24,  9,86, 17,68, 15,21, 12,40, 
     2,63, 13,25, 10,19,  6,97,  1,61, 15,71, 18,76,  7,52, 12,18, 19,27, 11,97,  3,74,  5,16, 16,10,  0,72, 14,61,  8,48, 17,96,  4,83,  9,98, 
     2,14, 13,23, 17,81,  0,53, 19,83,  7,93, 12,86,  6,45, 10,71,  3, 9,  1,94, 18,91,  4,90, 11,34, 16,75,  8, 1, 14,73,  5,83, 15,75,  9,68, 
     7,18,  5,64, 14,22, 16,33,  1, 9, 17,57, 15,42,  6, 1,  8, 9, 12,45,  4,20, 18,24,  2,68, 11,86, 19,59, 10,90,  0,56,  9,41, 13,39,  3,43, 
    11,45, 16,67,  2,45,  7,18, 19,69,  3,26, 14,38,  4, 1,  6,71,  8,64,  5,29, 17,77, 10,50, 15,23, 12,24, 13,67,  9,80,  1,89,  0,96, 18,21, 
     2,39, 15,45,  4,60, 18,65,  3,67, 12,91,  6,99,  9,96, 19, 3,  8,11,  5, 1,  0,14, 13,94, 10, 9,  7,13, 11,82, 14, 8, 16,58, 17,13,  1,76, 
    18,57, 17,50, 19,55,  1,54,  3,46, 14,52, 13,44, 15, 3,  8,71,  0,80,  5, 7,  7,66, 10,25, 12, 5,  4,44, 11,44,  9,76,  6,83,  2,38, 16,94, 
    17,69,  4,32,  6,47, 16,61, 15,71, 11,39, 12,56,  8,69, 10,32,  1,60,  2,22,  3,68,  7,18, 13, 9, 14,76,  5,44,  0,39,  9,22, 18,16, 19,95, 
     7,48, 15,92,  6,62,  3,48, 12,93,  9,27,  8,80,  0,48,  2,85, 18,62, 17,24, 11,67, 10,88, 16,29,  5, 5,  4, 3, 13,77, 14,47,  1,13, 19,60
  };
  // Taillard 50x20 instance 7
  const int tai_50_20_7[] = {
    50, 20, // Number of jobs and machines
     4, 8,  3,41, 18, 4, 17,52, 12,47, 13,67, 14,65,  6,18,  7,73, 11,10,  1,70,  5,66, 16,64,  8,53,  9,34, 15,28, 10,74,  0,40, 19, 8,  2,30, 
    13,37,  5,91, 14,97, 18, 6,  1,48, 19,90, 11,32,  6,12,  3,93,  7,15,  2,33,  8, 5,  4, 2, 10,11, 15,96, 12,16, 17,82,  9,49,  0,48, 16,81, 
     5,11,  3,70, 18, 4, 15,92, 11,18, 19,41, 12,77,  1, 5,  6,49, 17,94,  4,32, 13,67, 14, 2,  0,16,  9,21,  8,69, 10,89,  7,32,  2, 6, 16,33, 
    13,87,  9, 3,  6,82,  0,44,  7,16,  8,54,  1, 9,  3,49, 15,28, 10,70,  5,85, 18,34,  2,53, 16,37,  4,59, 19,66, 11,41, 12,96, 17,84, 14,54, 
     1, 1, 11,31, 19,73, 18,35,  0,81,  8,84,  4,34,  7,53,  5,73,  2,30,  6,63, 13,76, 15,62, 16,14,  9,30, 17,31, 10,89, 14,28, 12,92,  3, 3, 
     5,64,  9,46,  6,81, 13,38,  8,46, 17,69, 10,10, 19,27, 18,36,  4,94, 14,53, 11,31,  3,15, 12,59,  2,31, 16, 6, 15, 1,  1,28,  0,43,  7,92, 
     8,27,  0,78,  4,10, 15,19,  2,89, 14,91, 18,42, 16,13, 11,75, 17, 2,  6,36,  7,14,  5,59,  3,14, 13, 9,  9,34, 10, 3,  1,85, 19,44, 12,94, 
     5, 8, 13,90,  1,38,  6,23, 17,69,  8,34,  0,13,  7,62, 10,38, 16,74, 15,67, 12,45,  2,62, 19,32, 14,86, 18,59, 11,84,  9,66,  4,37,  3,52, 
    16,45, 15,30, 18,23,  2, 7, 14,92,  0,72, 12,34,  6,63,  3,68, 11,36,  9,75, 17,10, 19,27, 13,89,  5,31,  8,88,  7,46,  1,36,  4,71, 10,23, 
    18,72, 12,36,  9, 5,  5,98, 11,38,  6,99, 19,92, 14,92,  1,63,  4,20, 17,42, 16,77,  3,71,  8, 3, 13,80, 15,95, 10,84,  2,32,  7,32,  0,66, 
     2,63,  3,15, 13,66,  0,16,  9,51,  7,26, 19,24, 17,78,  8,54,  1,66, 14,51, 18,30,  6,37, 16,72,  5,77, 15,11, 12,33, 10,30,  4,36, 11,24, 
     7,78, 14,75, 16,35,  5,10, 19,81,  8, 1,  1,28,  3,58, 11,80,  0,61, 17,52, 15,74,  2,17,  9,11, 18,64, 13,69, 10,27, 12,92,  6,79,  4,89, 
    10,25, 17,19, 11,53,  9,36, 19,53,  1,27, 15, 8,  4,23, 18,86, 14,31,  7, 2, 16,95, 12,53,  2,29,  5,35,  0,28, 13, 1,  8,71,  6,57,  3,56, 
     8,11,  2,56, 17,64, 19,45, 10,96, 14,94, 13,48, 16,79, 12,48, 11,58,  6,32, 18,58,  3,13,  9,95,  5,39,  0,21,  4,18,  7,83,  1,45, 15,69, 
    10,88, 11,25,  7, 9, 18,83, 17,12, 14,79, 16,41,  1,89,  9,93,  8,46,  2,24, 12,41,  3,59, 19,56, 15,19,  5,12,  4,34,  0,80, 13,81,  6,51, 
     5,22, 11,49,  9,73, 18,59, 12,48,  8,76,  2,78, 14,69,  1,66, 15,27,  7,73,  6,46, 16,42,  0,53,  4,62, 10,39, 19,15, 17, 4,  3,76, 13,53, 
    12,96,  7,91, 16,71,  5,60,  6,60, 15,60, 17,44,  0,18, 13,82,  8,90, 19,77, 10,93,  2,24,  4, 6, 18,77, 14,56,  9,82,  3,15,  1,85, 11,41, 
     9, 4,  4, 8, 17,10, 14, 4, 10,23,  0,17, 18,33,  2,50, 13,24, 16,12,  6,29, 19,65, 12,43,  8,68,  3,66,  7,82, 11,22,  1,89, 15,58,  5,25, 
     5, 4, 13,14,  1,62, 14,43,  0,49,  6,18, 19,91,  3,83,  7,53, 10,35,  9,79,  4,62, 11,42, 18,17, 17,62,  2,39, 15,76, 16,43,  8, 9, 12,39, 
     4, 1,  0,98, 13,77,  2,28,  1, 3,  3, 8, 15,43, 12,53, 11, 4,  6,80,  9,81, 18,98,  5,61,  8,91, 19,32, 16,65, 17,52, 14,29,  7,49, 10, 1, 
    10,40,  1,89, 15,65, 17,30,  9,23,  6,47, 18,97,  4,28, 19, 3,  7, 5, 13, 4,  5,85,  3,34, 11,24,  0,87, 14,63,  8,54, 12,54,  2,27, 16,95, 
    10,50, 11,24, 13,37,  7,99,  4,14, 17,99,  3,25,  9,64, 19,73, 14,64,  6,24,  2,86, 15,10, 16,76, 12,56, 18,81,  8,62,  5,49,  1,19,  0,78, 
     7,73,  4,76,  5,31, 12, 4,  9,10, 13,24,  3,67, 17,57, 11,25, 16,72,  8,30, 19,31, 10,79, 14,13, 18,41,  6,85, 15,79,  0,61,  2,45,  1, 3, 
    18,72,  6,49, 19,50,  9,95, 17,81, 10,80, 14,50, 15,41, 16,48,  0,68, 11,15,  5,29, 13,68,  7,83,  2,72,  3,25, 12,56,  1,19,  8,80,  4,60, 
     6,68, 15,30,  7,38, 14,23,  5, 5,  8,65,  2, 1,  9,18, 17,61, 11,51, 19,44, 12,64, 10,98,  1,99, 18,64, 16,87, 13,90,  3,66,  0,99,  4, 7, 
     9,94,  4,60,  7,19, 18,40,  5,46,  1, 7, 13, 7, 10,86, 15,32,  3, 3,  2,25, 19,89, 12,59, 11,69, 17,89, 14,65,  0, 9,  6,77, 16,35,  8,42, 
    16,93, 19,83, 13,79, 18,36,  1,15,  3,44,  9,45,  8,11, 12,47, 11, 2, 10,84,  0,51, 15,26,  7,62,  2,54,  5,71,  4,86,  6,64, 17,61, 14,38, 
     7,88,  4,37, 17,37, 12,36, 15,59,  1,14,  3,89,  5,93, 11, 6, 14,47,  8,44, 13, 1, 19,82, 10,84, 18,50,  6,21,  9, 4, 16,20,  2,98,  0,37, 
    16,65,  8, 4, 12,98, 19,29, 18,22,  7, 1,  4,70, 13,89,  6,73, 14, 5, 17,15,  3,33, 10,23,  1,63,  9,20, 11,28,  0,31,  2,62, 15,90,  5,53, 
    14, 5,  4,51, 12,90, 19,91, 17,24,  9,98, 18,31,  8,90,  5, 3, 13,56,  6, 5,  2,41, 10,75, 15,57,  1,49, 11,75,  3, 1,  0,66,  7,65, 16,58, 
    15,85,  8,43, 17,95,  9,42, 19,50, 18,32, 10,37,  0, 8,  5,68,  7,82,  6,78, 13,11, 12,45,  3,32,  4,66, 11,41,  1,53, 14,91, 16,65,  2,88, 
    16,87,  9,16, 12,43, 13,86,  6,67,  5,82, 11,70, 18,65, 17,56,  4,53, 10,22,  0,17,  3,94, 15,61,  1,69,  7,73,  8,33, 14,69, 19,36,  2,64, 
    16,85, 10, 6,  7,31, 15,23,  9,33,  3, 4, 14,69,  5,61,  1,50, 11,27, 12,25, 18,10,  2,26, 19,26,  4,42,  0, 9, 17,72,  6,30,  8,91, 13,83, 
    10,44,  6,77, 18,51, 14,49,  2,37,  7,20, 17,69,  8,95,  5,84,  1,43,  4,86, 15,86, 12,57,  3,29, 11,70, 13,94,  9,38,  0,39, 19,61, 16,60, 
    16,37,  3,22,  2,56, 11,88,  7,95, 14,19,  9,92, 15,64,  1,25,  6,69, 10,37, 18, 9,  0,82, 19,67,  5,90, 13,52,  8,64, 17,25, 12,62,  4,39, 
     4,68, 13,36,  3,85, 15,37, 19,66, 10,31, 18,35, 11,97, 14,76, 16,22,  1,45,  2,80,  9,90,  6,48,  5, 5,  7,56,  8,50, 12,66, 17,54,  0,53, 
     4,86,  3,21, 18,36,  2,42,  0,67, 17,38, 14,28,  8,58, 15,41, 13, 1,  9,67, 16,45,  1,25,  5,18, 19,12, 11,71, 10,49,  7,28, 12,21,  6,52, 
    12,93, 14,97,  5,35,  2,71,  3,62,  9,49,  7,81, 11,60, 13,64, 10,50,  4,33, 18,39,  0, 7, 15,44,  1,53, 16,20,  8,96, 17,49, 19,23,  6,70, 
    13,15,  0,22, 11,40,  8,12, 18,19, 17, 5, 10,32, 19,85, 16,48, 15,46,  6,97,  1, 4,  5,97,  4,95, 14,90,  2, 2, 12,69,  9,95,  3,68,  7,18, 
     3,52,  0,57, 13,67,  8,67,  5,91,  1,82,  7,86,  4,29, 17, 8, 11,35, 10,65, 12,13,  2,92, 19,28, 16,77,  9,99, 14,30,  6,16, 15,31, 18,35, 
     7,85, 19,24, 15,60,  5,60,  3,89,  1,99, 12,88, 11,15,  4,45,  0,60,  8,38, 16,44, 17,38,  2, 4, 10,95, 18,27,  9,27,  6,15, 14,76, 13,53, 
     9,15, 19,64,  8,29,  3,72, 17,98, 10,73, 16,28, 13,25, 11,35, 14,57,  0,26, 15,38,  1,42, 12,19,  7,75,  4, 2,  2,86,  6,46, 18,84,  5, 5, 
    19,57, 13, 4, 11,83,  6,13,  2,80, 12,45,  7, 6, 14,46,  0,63, 15,94,  8,54, 17,69, 16,69, 18,43,  1,62,  3, 6,  5,15,  9,35, 10,62,  4,44, 
     8,57, 10,67, 17,80, 16,80, 18,61,  9,84, 15,90,  1,63,  5,26,  6,98,  2,94,  3,92,  7,84,  0,16, 19,24, 12,67, 11,47, 13,35,  4,79, 14,99, 
    11,63,  8,45, 10,49,  7,38,  0,32, 15,87,  5,41, 17,33, 19,18, 18,40, 16,50,  2,84,  3,36, 14,99,  6,77,  9,16,  1,52, 13,20,  4,60, 12,66, 
    11, 1, 14,24, 13,37,  1,54,  9,39,  5,50,  7,38, 18,79,  4,88,  2,35, 19,58, 15,77,  0,43, 17,98, 12,52,  6,73, 16,45, 10,45,  3,84,  8,80, 
     6,26, 15, 9, 19,92, 16,70,  5,87, 12,33, 11,14,  4,83,  0,34,  2,98,  3, 5,  8,99, 10,93,  7,94,  1,43, 17,36, 14,26, 18,11,  9,28, 13,16, 
    12,19, 15,58, 14,30,  3,72,  1,39,  2,27,  9,18, 11,44, 16,20,  6,87, 10,82, 17,51,  8,78, 18,20,  4,19, 13,36,  0,42,  5,75, 19,85,  7,95, 
     6,41,  9,46, 10,81, 11,17, 12,25, 18,80,  0,41,  4,29,  1,99,  2,14, 13,28,  8,25, 16,58,  7,24,  3,59, 14,45,  5,17, 19,53, 15,16, 17,86, 
     3,30,  2, 3,  8,28, 19,92, 15,87, 13,28,  6,30,  4,69, 14,20, 16,94, 10,97,  5,91, 17, 5,  7,16, 11,88, 18,47,  1,66,  9,67, 12,15,  0,29
  };
  // Taillard 50x20 instance 8
  const int tai_50_20_8[] = {
    50, 20, // Number of jobs and machines
     2,84,  6,26,  0,16, 18,14,  9,43, 12,28,  5,86, 10,92, 19,32, 16,73, 15,61,  7,13,  3,48, 13,70,  8,68,  1,56, 17,84, 14,23,  4,94, 11,30, 
     3,77,  0,32, 13,55, 12,22,  2,83, 18,19,  4,49, 11,80,  1,27, 16,69, 17,46, 10,86, 19,51,  5, 1,  8,88, 15,77,  6,98,  9,48, 14,24,  7,63, 
    17,36,  7,68, 15,42,  2,45, 19,34,  0,73,  6,14,  1,82, 18,15, 13,35,  5,92, 11,10, 14,43,  3,18, 16,73,  4,69, 10,55, 12,63,  9,89,  8,98, 
     3,42,  5,23, 11,29, 15, 8,  7,93, 12,19,  8,64, 17,47, 18,19,  6, 4, 16,84, 14,72,  9, 2,  0,89,  1,77, 19,12,  4,92,  2,67, 13,38, 10,87, 
    19,57, 17,67, 11,99, 14, 9,  0,89,  6,58,  3,16,  1,35, 15,30, 10,58,  7,28, 13,70, 18,82,  2,30,  9,84,  8, 5,  5,13, 16, 3, 12,91,  4, 8, 
    11,34, 16,34,  1,32, 14,17,  9,49,  7,13,  0, 4,  6, 7, 17,38,  5,62,  4,46,  8,29, 19,87,  2,23, 12,44, 18,93, 13,15, 10, 9, 15,56,  3,42, 
    18, 4, 12,71,  3,63, 19,19,  2,18, 15,48,  1,47,  4,50,  8,82,  9,94, 16,22, 17, 7, 14,69, 10,68,  7,34,  5,75,  0,13, 11,55, 13,11,  6,60, 
     6,44, 19,20,  1,86,  0, 2, 16,90,  7,32, 17,54, 10,40, 12,40, 15, 3, 14,20, 11,68,  8,84,  4,40, 18,91, 13,53,  2,77,  9,83,  3,97,  5,63, 
    13,45, 12,72, 19, 8, 17,61, 14,51, 15,96, 11,94,  1,98,  7,83,  2,48, 16, 6, 10,22,  8,50,  4,24,  6,36,  3,21,  5,17,  9,48,  0,54, 18,21, 
     7,24, 18,20,  6,92, 13,47,  2,99, 16,85,  0,20,  3,90,  4, 1, 15,20,  5,36, 11,58,  9, 2,  1,86, 10,42, 19,38, 17,69, 12,79, 14,43,  8,55, 
     3,62,  8,21, 19,95,  4,53,  7,75,  1,90,  0,94, 14,43, 16,72, 12,38, 13,60, 11,30, 15, 6, 10,75,  5,31,  6,87,  2,63,  9,24, 18,16, 17,46, 
     4, 5, 18,48,  3,88, 12,78, 14,84, 13,85,  1, 1, 16,79, 10,95,  9,42, 11,21, 15,69,  2,89, 19,68,  8,56,  7,30,  5,96,  0,98, 17,75,  6,24, 
    17,58,  3,49,  7,53,  5,85, 16,20, 11,15,  6,44, 19,97,  9,24,  0,12, 12,98, 15,53, 10,67, 13,10,  8,91, 14,47,  1,78,  4, 5,  2,28, 18, 5, 
     0,55, 13,30,  8,68, 14,34,  2, 3, 11,58,  1,18, 16,20, 17,33,  7,62, 12,70,  9,87, 15,55,  5,91, 19, 2,  4,33, 18,22,  6,20,  3,26, 10,99, 
    15,64, 11,88,  3,94,  1,34,  9, 4, 13,78, 19,10,  8,67, 12,77,  7,53,  5,67, 14,91,  2,24, 17,30,  6,76, 18,70, 16,56, 10,89,  0,49,  4,74, 
     7,95, 14, 9,  3,29,  6,45, 18,64, 12,73, 19,62,  9,11,  0,31,  1,77, 11,61, 16,20, 15,54,  5,37,  2,17,  4,31, 17,32, 10,98,  8,20, 13,94, 
     9,14, 15,90,  8,73, 13,84,  7,75, 17,89,  4,41,  2,59, 18,58, 14,44, 11,21, 12,61,  0,91,  5,25,  6,48,  3,12, 16,37,  1,80, 19,77, 10,51, 
    14,47,  3,92, 18,11,  7,73, 17, 4,  5, 9, 15,95,  0,22,  9,32, 19,89, 10,64,  4,19,  8,69, 11,83, 13,91,  6,34, 12,80,  1,94, 16,93,  2,82, 
    12,92,  6,79, 11,74, 17, 2,  3,97, 18,68,  4,98, 14,78,  9,22,  1,41,  2,58, 16,99, 13,52,  0,67, 10,48,  5,33, 15,48,  7,58, 19,81,  8,39, 
    11,20,  5,96, 19,64,  0,95, 13, 6,  3,26,  7,39, 16,26, 10,92,  6,12,  9,65, 15,14,  2,71,  4,31, 17,97, 14,24,  1,85, 12,89,  8,11, 18, 5, 
     0,77,  9,82, 15,36,  3,52,  7,94,  1,87,  4, 7, 19,65, 13,40,  5,61, 17,79, 14, 2, 11, 7,  6,71,  2,49, 18,18, 10,61, 12,69,  8,50, 16,85, 
     2,63, 15,50,  4,88, 17,90,  5,35, 10,20, 16,69, 18,88, 14,43,  3,94,  1,51,  0,94, 19,12, 12,90,  6,36, 11, 3,  9,99, 13,37,  7, 8,  8,69, 
    19,43, 15,66, 16,92,  6,61, 11,11,  3,53, 12,54, 18,54,  4,42, 17,87, 14,86,  9,34,  8, 7,  0,60,  1,52,  7,96,  5,25,  2,55, 13,49, 10,56, 
     6,11, 18,71,  4,60,  5,73, 17,91, 16,99,  3,22,  7,74,  9,80,  1,79, 19,97, 12,93, 14,85,  8,72, 10,96, 13,52, 15,70, 11,11,  2,95,  0,85, 
     8,83,  5,39,  3,51, 12,49,  6,31,  7,18, 13,94, 19,88,  0,46, 10,98, 14,66, 11, 7, 16,20, 17,53, 15, 9,  2, 7,  9,14,  4,85, 18,32,  1,88, 
    17,98, 12,91, 11,78, 19,43,  9,55,  5,45,  2,59,  6,77,  3,31, 16,91, 14,60,  1,61, 18,62, 10,59, 13,89, 15,25,  4,18,  7,29,  0,49,  8,53, 
    10,26, 16,50,  1, 7, 12,78, 15,75,  6, 3,  9,28,  0,20, 11,58,  7,95, 18,38, 19,58,  8,70,  4,75,  5, 6, 17,26, 14,26, 13,54,  2,95,  3,12, 
    17,81, 13,71,  5,22, 11,56, 15,17, 16,14, 10,65, 12,90,  1,29, 14,47,  3, 8,  9,39, 19, 9,  8,58,  0,95,  6,25,  2, 1,  4,65, 18,44,  7,66, 
    16,62, 13,79, 18,70,  7,43,  3,95,  2,42,  8, 6, 17,88, 19, 5,  5,12,  6,54,  9,18,  0,83,  4,27, 12,38,  1,49, 15,94, 11,95, 10,78, 14,57, 
     7,18,  6,36, 12,70,  9,10, 16,25,  0,25,  5,72, 18,69, 13,15,  2,17,  3,31, 10,60, 11,69, 15,39,  1,54,  4,56,  8,85, 17,47, 14,40, 19,10, 
    13, 7, 10,14,  9,11, 16,33,  6,49,  0,82, 18,76, 19,11,  2,52,  3,20, 14,35,  5,73,  4,81, 15,42, 11, 4, 12,27,  8,14, 17,73,  7,10,  1,25, 
    11,54, 17,81, 15,52,  1,25,  4,78,  6,23, 13,38,  3,59, 12,22,  2,45,  7,66, 14,94,  5,57,  8,82, 16,51, 19,54, 10,25,  9,97,  0,55, 18,38, 
     8,51, 10,21,  0,36,  7,95, 17,68,  2,90, 16,76,  5,84,  3,37,  9,38, 18,30, 11,22, 13,28, 19,90, 15, 6, 12,91,  1,73,  4,93, 14,55,  6,38, 
    19,78, 17,17, 16,41,  3,69,  8,94,  6,83,  9,24, 10,55,  0,62,  5,27, 18,24,  4,70, 15,50,  7,21, 14,51, 12,19, 13,20, 11,59,  2,45,  1,22, 
    19, 2, 14,85, 10,58, 15,47, 12,66,  0,81,  8,44, 17,41,  6,18,  9,85, 16,56, 11, 2,  4,81,  7, 1,  5,36, 13,51,  3,25,  2,11, 18,21,  1, 1, 
    10,87,  6,65,  3,11,  4,85,  0,37, 11,26, 12,89,  1,27,  8,10,  7,13,  2,62, 17,30, 16,24,  5,79, 15,98, 18,61, 19,65, 14,29,  9,27, 13,14, 
    15,14, 11,47,  6,11, 12,29,  9,18, 18,39,  7,21,  5,80,  1,41,  0,62, 17,72, 19,49, 10,52,  8,83,  4,36,  3,31, 16,51,  2,57, 13,33, 14,47, 
     2, 9, 11,96, 13,42, 10,39, 12, 6,  3,67,  5,59,  1,91, 16,81, 14,90,  8, 7, 18,49, 15,96,  6,51,  9,38,  4,56, 17,47,  0,95, 19,23,  7,18, 
     9,78, 17,96,  8,79, 14,35, 11,98,  0,10,  7, 1,  6,82,  1,56, 19,31, 10,88, 12,52,  5,96, 15,75,  3,54,  4,12, 16,63, 18,44,  2,43, 13,19, 
    11,35, 17,73,  4,40, 18,52, 12,92, 19,77,  9,57, 16,66,  6,36,  8, 7,  1, 6,  0,69, 15,84,  5,54,  7,53,  3,97, 13,38, 14,93,  2,28, 10,66, 
    11,99,  6,88, 10,17,  5,33,  7, 3,  2,58, 19,22,  9,75,  0,57,  8, 5, 14,22,  3,11, 16,76, 13,93, 15,11, 12,63, 18,89,  1,96, 17,15,  4,60, 
     4,48,  5,96, 14,13, 12,45, 11,77,  8, 9, 15,60,  7, 8,  2,87, 16,29,  6,56, 19,39, 17,82, 18,34,  9,20,  0,58, 10,41,  1,48, 13,56,  3,41, 
    17,15,  6,77,  5,47,  8,60, 15,51, 19,51, 12,56, 14,30,  7,50, 11,39,  3,25, 18,90,  2,14, 10,67,  4,13, 16,42, 13,28,  9,36,  1, 7,  0, 2, 
     9,12,  6,68, 15,91,  5,12, 14,73, 10,74, 19,76,  2,59,  3,60, 16,20,  0,83, 17,88, 12,25, 13,77,  7,65, 18,44,  1,30,  8,84,  4,28, 11,63, 
     5,32,  2,11, 12,76,  8,27, 13,12, 11,67,  1,33,  3,17,  0,12, 15,58, 18,56, 16,31,  7,96,  9,89,  6,28, 17,33, 14,75, 19,99, 10,40,  4,74, 
    16,90, 14, 1, 12,68,  7, 4,  2,95,  5, 9,  3,61, 13,45,  4,63, 10,35, 11,81, 17,77, 15, 9,  6,53,  9,44,  0,59, 19,96,  8,76, 18,94,  1,20, 
     1,43, 14,79, 19,60, 12,98,  7, 3,  8, 4, 17,48, 10,72,  0,41,  3,90,  6,94,  2,11, 11,30, 13,10,  5,41, 15,79, 16,66, 18,11,  4,87,  9,68, 
    10,91,  9,65,  3,80, 12,50,  2,66,  8,35, 19,70,  0,98, 15,80, 17,47,  5, 9, 16, 7,  4,67,  6,22, 11,95, 13,11,  1,56, 14,25,  7,64, 18,57, 
    15,23,  3,75,  4,12, 10,51,  1,45, 16,23, 18,52,  5,77, 14,76,  8,48, 13,52,  6,53, 11,53, 17,18, 19, 3, 12,18,  7,56,  0,98,  9,71,  2,25, 
    12,64,  6,20,  8,89, 11,27, 17, 5,  1,47,  4,92, 15,23, 13,78,  5,64,  2,77, 14,12, 18,49, 16,40,  7, 3,  9,60, 10,54,  0,37, 19,15,  3,16
  };
  // Taillard 50x20 instance 9
  const int tai_50_20_9[] = {
    50, 20, // Number of jobs and machines
    10,20,  1,22,  2,38,  7,33, 17,24,  4,72,  3,75, 18,61,  0, 2, 14,17,  6,67, 19,50, 15,65, 16,77, 13,65, 12,35,  5,68, 11,76,  9,98,  8,81, 
    11,73,  3,86,  7,26, 18,42, 12,50,  5,13, 13,92,  6,15,  4,77, 14,74, 10,48,  2,54,  1,46, 16,60, 19,83,  0,78, 15, 1,  9,91,  8,33, 17,60, 
    14,67, 19,63,  5,54, 11,65, 16,29, 12,51,  1,74,  8,16,  6,11,  4,97,  2,87,  9,66, 18, 4, 10,10, 17,52,  0,85, 13,60,  3,64,  7,40, 15,49, 
    10,31, 16,73, 15, 2,  2, 4, 14,87,  1,81, 11,90,  7,92,  5,27, 18,51, 12, 4,  0,42,  4,21,  8,77, 17,71,  6, 5,  9,77,  3,81, 19,39, 13,32, 
    19,18,  8,13,  4,89, 14,45, 12,59, 13,90,  2,86,  9,71,  3, 5,  0,54,  1,42, 10,60, 17,32,  6,16, 18,86, 11,70, 16, 7,  7,16,  5,81, 15, 4, 
     0,59,  9,55, 11, 3, 18,43,  3,26, 15,19,  2,57, 17,75, 10,35,  8,40, 13,17, 12, 3, 14,96,  4,82,  5,26,  1,23,  6,97, 16,23,  7,65, 19,28, 
     0,83,  8,81, 12,19,  5,54, 11,86, 16,94,  7,49,  2,38, 15,38,  3,33, 10,93, 18,63,  6,51, 13,45, 14,68, 19, 4, 17,29,  1,53,  4,85,  9,21, 
    10,46, 15, 8, 19, 5, 17,29,  6,32,  1,34, 14, 3,  0,10, 16,45,  7,70,  4,77, 18, 1, 13,62,  3,79,  2,50, 12, 2, 11,18,  9,89,  8,86,  5,21, 
    11,17,  6,47,  7, 7,  1,20, 17, 9,  9,92, 12,23, 18,76,  0,71,  8,20,  4,21, 15,72, 14,71,  5,92,  3,92, 10,17, 19, 9, 16,38,  2,23, 13,34, 
    13, 6, 18,74,  8,29, 14,99, 11,80, 16,27, 10,43, 15,36,  0,31,  9,63,  1,34,  4,26, 19,98,  7,47,  3,69,  2, 5,  5,55, 12,22, 17,15,  6,19, 
    18,77,  8,12, 14,96,  2,84,  5,22,  1,16,  6,59, 13,94,  0,69, 17,68, 15,81,  3,13, 16,45, 11,61, 10,27, 19,26,  7,12,  4,86,  9,82, 12,85, 
     6,27, 18,81, 16, 2, 12,29,  0,61, 17, 2,  1,40, 11,78, 15,65,  7,68,  4,39,  2,68, 10,39,  8,63, 19,59, 13,79, 14,96,  5,11,  9,76,  3,48, 
    19,95, 13,62, 18,10, 11,68,  6,42,  3,61,  5,73, 14,51, 16,81,  4,75,  7,37, 15,96, 10,65, 17,45, 12,44,  8,43,  1,19,  9,44,  0,94,  2,56, 
     1,23, 15,70, 17,24, 14, 4, 10,86, 13,90,  4,86,  9,83,  0,75, 18,46, 11,92, 12,94, 16,23, 19,29,  8, 6,  2, 3,  7,33,  5,12,  6,51,  3,15, 
     5, 7, 15,55,  3,26, 14,30,  0,79,  4,58, 12,86,  1,70,  9,68,  6,98,  8,26, 11,32, 10,98, 17,35,  2,37, 19,13,  7,85, 13,85, 18,14, 16,34, 
    13,21, 19,68, 18, 1, 12,76, 11,44, 14, 4, 17,48,  1,39,  2,73,  6,81,  0,50, 15,97,  7,41, 10,79,  3,10,  9,73,  5,36,  8,28,  4,64, 16,31, 
    16,76,  5,55, 14,41,  7,46, 17,80,  0,99,  3,99,  1,59,  6,14,  2,86, 12,69,  8,24,  9,54, 11,34, 13,32, 19,98, 10,74,  4,67, 18,24, 15,56, 
    15,14,  1,32, 11,77, 17,81, 19,35,  0,38,  8,38, 18,38,  2,61,  6,87, 14,70, 16,79,  9,25,  5,46,  7,88,  3,18, 12,76,  4,98, 10,75, 13,23, 
     5,61,  1,92, 17, 6,  3,58, 18,26, 10,26, 12,36, 19,89,  7, 9, 15,35,  0,54,  2, 5,  6,72, 11,91,  9, 4, 14,61,  8,75, 13,42,  4,85, 16,45, 
    12,46, 19,89,  6,49, 13,86, 11,14,  5,62, 14,53,  8,59,  7,27,  2,86, 18,10,  0,87,  4,99, 17, 4,  1,84, 15,62, 10,74,  9,30, 16,68,  3,86, 
    12, 1, 13, 3, 11,84,  0,78, 10,42, 15,73,  8,98,  7,91,  3,70,  9,53,  5,57, 14,36, 18,76,  1, 4,  6,76, 19,22, 17,70,  4,67, 16, 6,  2,16, 
    12,80, 18,91, 13,24,  6,36,  2,44, 14,81,  7,78, 10,65,  3, 2, 17,91, 19,62, 15,41,  8,40, 11,96,  1,64,  0, 5,  9,81,  4,71, 16,31,  5,71, 
     9, 3, 14,68,  5,55, 17,13,  7,83, 10,13, 16,12,  1,98,  8,86,  6,10, 11,70, 12,59,  2,89,  0,74,  4,83, 19,30,  3,56, 15,99, 18,68, 13,67, 
     6,35, 19,74, 14,59, 13,17, 11,56,  8,64,  5,67,  4,77, 12,84,  2,10,  9,35,  0,79, 10,12, 16,91, 18,36, 17,84,  7, 1,  1,41,  3,98, 15,81, 
     4,32,  2,10, 11,39, 12,58, 14,24,  8,56, 17,83,  0,77,  9,78, 18,99, 19,95,  3,67,  5,81, 13,15, 16, 5,  6,35,  1,10, 10,24, 15,97,  7,44, 
     8,55,  9,41, 17,99,  2,27, 19,94, 14,12, 13,33,  4, 3,  0,71, 11, 5, 15,88,  6,25,  5,66,  3,80,  1,39, 16,90,  7,79, 12,56, 18,60, 10, 5, 
    16,69, 12,41,  2,25,  0,82,  1,32,  3,70, 13,38,  4,22, 14,95,  9,98,  5, 6, 11,64, 15,52,  8,46, 19,71, 17,41, 18,40,  6,35, 10,22,  7,33, 
    19,14, 14,38,  2,32, 16,38, 17,64,  5,67,  8,13, 12,74,  6,74,  3,67, 13,39, 10,53,  7,55, 11,15,  9,93,  1,37,  0, 7, 15,53,  4,54, 18,39, 
    17,84, 18,77,  7, 6,  1,45,  3,91,  9,77,  6,12, 16,96, 14,24, 12,90, 11,54,  0,52,  5,49,  2,97,  4,80,  8,84, 13,44, 15,37, 19,79, 10, 5, 
     4,69,  9,28, 13,32,  6,68,  5,59,  8,23,  2,86, 16,54,  7,41,  0,80, 12,57, 11,45, 18,19, 17,38, 19,89,  1,21,  3, 5, 14,64, 10,65, 15,16, 
     4,57,  6,47,  9, 1, 11,79,  8, 9, 10,66, 13,84,  7,21,  5,35,  2,97,  0,83,  3,45, 14,18, 12,21, 19,19,  1,37, 16,93, 17,83, 18,46, 15,54, 
     6,46,  0,12,  4,44, 12,75, 19,32, 11,15,  2,49, 16, 4,  1,29, 17,76,  8,65, 15,39, 18,73, 14,54,  9,63,  7,78,  5,18, 10,91,  3, 3, 13,93, 
     9,98, 14, 7,  2,47, 18,56, 15,37,  8, 3, 17,17,  0,94,  5, 9, 16,19, 11,91,  4,58, 10, 8, 13,32,  3,60,  6, 5,  7,64, 12, 3, 19,56,  1,98, 
     2,93,  9,63,  7,40,  6,88, 14,20, 17,11, 11,16, 12,55, 18,61,  8,81,  1,17, 10,16,  4,45, 16,46, 13,85, 15,89, 19, 1,  5,22,  0,59,  3,55, 
     7,76, 18,86,  0,83, 10,26, 17, 4,  2,61, 12,72,  4,81,  3,44, 19,48,  8,17, 13,72,  1,14, 11,46, 14,46,  6,80,  9,74, 16,11, 15,57,  5, 2, 
     1,13, 16,49, 17,76,  8,41,  9, 3, 11,13,  3,95,  2,98,  6,29,  7,48, 18,60,  5,67, 19,28, 15,64,  4,36, 12,47, 14,78, 10,83,  0,32, 13,88, 
     3,58, 10,74, 14,41, 19,75, 12,45, 11,19,  0,51,  4,39,  8,94, 13,41,  7,62,  9,75, 15,36,  1, 5, 16,80,  5,47, 17,36,  6,23,  2, 6, 18, 3, 
    15,92,  1,64,  8, 1,  5,65, 17, 2,  2,87, 11,45, 18,73, 16,30, 19,67, 12,68,  6,33,  3,35, 14,65, 10,50,  9,93,  4,36, 13,18,  7,39,  0,54, 
     5,40,  2,11, 13, 8, 14,29, 15,26, 10,65, 16,26,  8,17, 19,52, 17,24,  1,87,  0,67,  7,88,  4,83,  6,36, 12,30, 11,97,  9,19, 18,97,  3,68, 
    15,64,  0,61,  7,59, 16,65,  9,93, 19,80,  5,83, 12, 5,  2,50,  1,42, 17,49, 13,69, 18,86,  6,14,  3,84, 10,41,  8,31, 11,67,  4,88, 14,20, 
    15,45,  6,22,  3, 2,  2,83,  8,61, 18,55,  5,85, 19,72, 11,37,  9,56,  0,73, 13,65, 16,19,  1,42, 17,51, 10,88, 14, 2, 12, 1,  4, 1,  7,30, 
    10,74, 12,28, 19,87, 18,91,  8,68,  2,27,  1,42,  0,99,  6, 7,  4,23,  5,27, 16,16, 15,86, 14,61, 13,28,  9,62,  7,87, 17,72,  3,93, 11,67, 
    11,77, 16,20, 17,53,  1,52,  0,14,  9,57,  4, 2,  3,78,  6,63, 10,12, 18,10, 14, 1,  7,59,  5, 1,  8,67, 12,53, 15,76,  2,17, 13,80, 19,12, 
     4,74, 13,86, 17,78,  6,55,  8,75, 19,37, 12,36,  0,49,  5,50, 16,93,  1,52, 10,77,  7,83,  9,29, 18,84,  2,60,  3,92, 15,61, 14,31, 11, 3, 
     6,76, 18,26, 10,38, 19,61,  2,67,  0,60, 15,40, 11, 7,  4,20, 12, 7,  8,97,  1,76,  7,18, 14,83, 17,39,  9,64,  5,43,  3,39, 16,79, 13,79, 
     7,61, 19,73,  0,91,  1,42,  3,70, 13,73, 17,34,  2,81,  8,19, 14,64,  4,54, 16,96, 12,89,  5, 3,  9,55, 10,94, 11,93,  6,24, 18,10, 15,99, 
     2,73, 18,10, 19, 6,  0,67, 14,22, 11,50, 13, 4,  4,29,  7,34,  5,15, 15,46, 12,32, 17,66, 10,28,  9,67,  3,63,  1,60,  8,39, 16,65,  6,19, 
     2,94, 12,77, 17,36, 18,97, 16,38,  5, 8,  6,71,  8,83, 15,43,  9,86, 19,33, 13,94, 10,30,  7,33,  4,89,  3,37, 11, 1, 14,35,  0,94,  1,32, 
    10,24,  7,67, 16,61,  5,41, 12,18,  0, 4, 14,91,  3,73,  1,33, 11,96, 13,59, 18,63, 15,40, 17, 5,  9,10,  4,45, 19,27,  8,53,  2,24,  6,81, 
    14,31,  8,99, 12,14, 11,64, 19,89, 17,43,  3,93, 10,32,  2,32,  9,26,  0,22, 13,33, 16,89, 18,41,  5,40,  7,87,  6,26,  1,98, 15,53,  4,98
  };
  // Taillard 100x20 instance 0
  const int tai_100_20_0[] = {
    100, 20, // Number of jobs and machines
    11,83,  7,59, 18,49, 15,84,  0,35,  8,68, 19,58,  6,66, 13,44, 14, 2, 17,63,  2,25,  4,70,  1, 1, 16,84,  3,56,  9,35,  5,46, 12,81, 10,58, 
     0,11, 14,67,  7,45,  1,86, 11,91, 16,60,  6,61,  4, 6,  8,95,  5,18, 13, 7, 18,73,  9, 3, 17,92, 15,30, 12,93, 19, 7, 10,37,  2,14,  3, 9, 
    15,34,  4, 5, 10, 2, 14,72,  5,26, 13,55,  9,24, 19,61,  8,28, 16,98,  7, 3, 12, 1, 11,28,  1,92,  3,39,  6,26,  0,91,  2,41, 18, 6, 17,92, 
     0, 9,  5,77, 11,47,  7,45,  6,82, 10,20,  4,86, 18,88,  3,18,  8,83, 14,22,  9,73, 17,92,  2,84, 19,68, 13,55,  1,65, 16,10, 15,64, 12,60, 
     3,62, 10,75,  1,29, 13,81, 18,89, 19,34,  5,34, 11,24,  6,98, 17,95,  8,60, 14,23,  9,54, 16,72,  4, 3, 12,82,  2,41,  0,49, 15,97,  7,49, 
     3,80,  1,95, 17,51, 16,96,  2,24,  5,15, 14,90, 12,73, 11,99,  7,68, 13,96, 19,67, 15,96, 10,56,  0,23,  6,38, 18,97,  8,44,  9,41,  4,83, 
    17, 8, 13,92, 18,66,  1,59,  9,31,  8,63, 11, 2,  4,13, 16,32,  5,39,  3,53, 10,24,  2,85, 12,25, 14,53,  0,90,  6,49,  7,42, 19,54, 15, 1, 
    19,10, 14,68, 16,86, 17,26,  7,64,  9,30, 11,78,  2,71, 15,95,  3,17, 18,92,  5,30, 12,41,  6,54,  1,12,  4, 4,  8,17, 13,60, 10,54,  0,83, 
    10,24,  3,23,  5,46,  8,39, 14,32,  4,40, 16,52,  2,36, 17,83, 15,23, 18,18,  7,92, 12,95,  9,67, 19,31, 13,25,  0,69, 11,46,  1,51,  6,93, 
    15,54,  2,81,  7,37, 11,52, 12,66,  4, 2, 17,96,  8,95,  0,44, 10,91, 14,83,  5,67,  9,22,  6,44,  3, 1, 19,21, 13,45,  1,37, 18,71, 16,50, 
    16,52,  4,19,  1, 8, 17,85,  5,64, 12,32, 15,22,  0,37, 14,54, 13,96, 18,92,  2,58, 19,16, 11,86,  3,57,  7, 3,  8,68,  9,94, 10,17,  6,30, 
    15,29,  6, 8,  7,89,  3,33, 19,14, 13,99, 14,84,  0,78, 12, 5, 11,76, 17,61,  2,95,  4,21, 16, 9,  1,95, 18,56, 10,27,  8,75,  9,42,  5, 5, 
    10,57,  0,30,  7,52, 13,90,  4,58, 17,10,  2,43, 15, 7, 14,80, 12,16,  5,10,  9,92, 18,56, 16,21, 19,76,  3,15,  1,95,  8,10, 11,64,  6,68, 
     8,46,  2,77,  7,23, 16,33, 18, 4, 12,66, 11, 5, 19,52, 15, 2,  4,34, 14,24,  9,89,  3,46, 17,35,  6,10,  5,24, 10,53,  1,98, 13,19,  0,49, 
    18,91, 11,95, 13, 1, 16,90, 17,75,  6,59,  0,36, 14,57, 12,73,  3,39, 15,82,  2, 7,  8,27, 19, 1,  4,39,  7,21, 10,70,  5,14,  9,12,  1,69, 
    13,33, 12,13,  9,76,  0,33, 17,65, 15,24,  1,50, 19,39,  6,41,  7,70,  5,47, 18,89, 14,32,  4,49, 16,71, 11,31,  2,13, 10,68,  3,65,  8,93, 
    13,55, 18,81,  9,36,  4,28,  1,94,  8,85, 17,20, 16,94,  5,77, 14,20, 19,74, 15,32,  3,68, 10,24,  7, 1,  2,75,  6,16,  0,79, 12,82, 11,35, 
    13,78, 10,89, 12,63,  0,41, 19,19, 14,68, 18,87,  8, 6,  5,51,  3, 1, 11,48,  1,75,  9, 5,  2,47, 16,92, 17,45,  6,52,  7,21, 15,27,  4,84, 
    10,90,  4, 4,  3,70, 17,36, 13,46,  1,78,  2,60,  0,67, 12,39,  6,71,  7,61, 15,75,  8,13, 16,69,  9,76, 11, 4, 18,54,  5,97, 19,29, 14,59, 
    18,44,  6,89,  9,36, 13,25, 19,32, 14,77,  3,72,  5,39, 12,81,  1,58,  4,49, 17,56,  7,22,  8,46,  2,15, 10,58, 16,53, 11,27, 15,56,  0,11, 
    15,25, 13,66,  1, 4,  4,23, 19,78, 14,29, 18,16,  5,69,  8,26, 16,68, 10,95, 12,56,  6,31, 17,10,  7,83, 11,74,  3, 3,  2, 8,  0,24,  9,68, 
     9,19, 17,29,  5,94, 18,24,  8,86, 12,16, 14,64, 13,39,  0,20, 10,57,  6,15, 11,34,  1,68,  7,82,  4,57,  3,13, 19,57, 15,86,  2,72, 16,33, 
     1,46,  7,84, 17,16, 11,12,  9,22, 14,73, 18,31,  2,90, 15,57,  0,94,  4,23, 19,51, 10,17,  5,73, 12,23,  6,34, 16,48,  8,83,  3,32, 13,35, 
    19, 6, 10,32, 13,10, 18,62,  7,74, 12,82, 11,51, 15,51,  3,51, 16,71,  9,28,  4,27,  0,87,  6,22,  2,33, 14,45, 17,44,  5,96,  1,81,  8,53, 
     6,43,  9,42, 17,66,  2,75, 11,65, 16,83,  4,64,  1,21, 13, 6,  0,53, 10, 1, 12,67, 18,80, 15,25,  5,37, 14,71, 19,17,  8,48,  3,43,  7,12, 
    10,90,  1,67, 14,42,  7,71, 15,13,  4,98, 13,24,  2,77,  5,69, 17,90,  0,80,  8,73, 18,54,  6,13, 12,29, 11,25,  9,62, 16,11,  3,44, 19,13, 
     8,73, 12,67, 13,52,  7, 6,  5,30,  6,25, 19,73, 11,86,  3,53,  1,19,  9,84, 15,52, 17,80, 16,63, 10,21,  4, 2, 14,78,  2,29, 18,44,  0,90, 
    17,99, 18, 6,  1,72,  8,67, 16,69,  7,50,  5, 2,  0,53, 11,31,  9,61,  4,81, 15,94, 12,23, 19,89,  2,21,  3,75, 13,99, 14,51,  6,68, 10,97, 
     6,48,  8,70,  7,62,  0,60, 16,74,  5,98, 18,26, 13,96,  9,10,  1,68,  2,36,  3, 6, 14,24, 17, 4, 10,12, 19,29, 15,46, 12,79,  4,28, 11,79, 
    10,54, 15,41,  7,61, 13,56,  9,42,  2,59,  8,95,  6,46,  1,43, 17, 1, 11,49, 19,42,  5, 2, 12,32,  4,55, 14, 2,  3,57, 16,60,  0,76, 18,40, 
    17,79,  1,43,  4,79, 11,50, 13,51, 14,23,  9,12, 19,38,  6,80,  7,65, 15,42, 10,91,  0,76, 18,74,  8,36,  5,27,  3,47,  2,44, 12,10, 16,69, 
    10,33,  7,65, 13,93,  8,44,  9,80,  3,83, 12,54, 15,91,  6,87, 17,37, 19,71, 18, 3,  4,33, 14,38, 16,80,  2,91,  1,79,  0,55, 11,90,  5, 5, 
    14,76,  8,18,  7,19,  5,57, 13,71, 10,86,  6,59,  2,17, 18,21, 16,42, 15, 2,  9,51,  3,84,  4,22, 11, 7, 19,17,  0,52,  1,84, 17,16, 12,28, 
     9,23, 13,48, 16,68,  6,91, 10,76, 19,92, 12,39,  4,12, 17,15,  3,42,  5, 5, 18, 5, 11,85, 15,78,  7,75,  1,81,  0,51,  8,35,  2,70, 14,87, 
     9, 2, 12,37,  6,30,  8,14, 11,44, 10,68,  3,22,  4,24, 15,13,  7,80, 14,50, 17,89,  1,12, 18,45, 19,36,  2,30,  5,28, 16,56, 13,58,  0,60, 
    12,92, 13,34, 11, 2,  1,35, 10,82, 14,60, 19,76,  7, 3,  6,89,  9, 8,  8,97,  2,23,  5,26, 18,49,  0,66, 17,37, 15,55,  3,72,  4,70, 16,63, 
     1,72, 15,41, 12,53, 18,83, 10, 4,  9,68, 13,40,  3,80,  8,17,  7,90,  5,57,  2,81, 19,24,  0,26, 14,35,  6,13,  4,38, 17,59, 16,46, 11,38, 
    14,72, 11,65,  2,50,  9,92, 10,88, 13,11, 15,83, 18,87,  3,42,  7,57, 17,87, 16,83,  5,43,  4,98,  1,47, 12,74,  6,61,  0, 3,  8,81, 19,18, 
    14,13,  1,44, 13,84,  8,19,  6,69, 10,23,  7,32,  0,30,  9,26, 19,64, 16,55,  4,27, 15,52, 17,17,  2,97, 18,21,  3,73, 12,45, 11,31,  5,49, 
     2,38,  5,80, 16,48, 18,54,  0,54,  7,38, 13,39,  3,49,  4,29, 19,98,  8,86, 12,20, 17,23, 15,22, 14,81,  6,38,  1,98, 11,96, 10,90,  9,14, 
     9,70, 12,48,  6,93, 19,86,  2,21, 11,97,  1, 7, 17,68, 13, 5,  8,13,  7,26, 15,79,  4,94, 18,25, 10,50, 16,31,  0,37,  5,83,  3,41, 14, 7, 
    14,93, 11,75,  3,33,  9,46,  6,14, 17,17,  4,70, 13,63, 19,38, 16,63, 10,45,  0,99,  7,41, 15,12, 18,64, 12,34,  5,12,  1,54,  2,66,  8,31, 
    12,60, 18,97,  6,95,  7,41, 13,71,  1,88, 19,91,  0,92, 10,99,  9,52, 15,69, 17,79, 11,30,  8, 3,  5,55,  3,59, 16,88,  2,28, 14,71,  4,73, 
    18,53,  1,97, 10,53,  4,29,  7,64,  2,19, 14,15, 13,79,  3,99, 16,39, 12,72,  5,82,  6,77, 11,25, 19,96, 15,92, 17,98,  8,79,  9,31,  0,19, 
     7,56,  4, 6,  6,63, 16,50, 12,67,  1,80, 18,60,  0,36,  8,10, 17,14, 19,44,  5,81, 13,54,  3,20, 10,67,  2,25, 14,49, 11,78,  9,75, 15, 3, 
    16,83,  4,73,  1,22,  2, 4,  0,30, 17,27,  6,76,  8,54,  9,48,  3,82, 12,89, 10, 8,  7,80, 18,26, 13,98, 11,97,  5,10, 19,66, 14,76, 15,77, 
    17,75,  3,99,  2,70,  4,75,  8,16, 19,69, 16,52,  6,21, 15,23,  1,28, 10,56,  5, 5,  7,78, 13,72, 12,56, 18,23,  0,30, 14,51,  9,27, 11,38, 
    16,96, 17,25,  4,56, 13,67, 18,77, 15,61,  7,55,  5,87,  0,20, 14,60,  8,40,  6,23,  9,17, 10,24,  1,37,  3,52, 12,46, 19,96, 11,19,  2,46, 
     3,34,  8, 9,  7,13, 15,74,  9, 4, 12, 5, 17,41,  4, 3,  2,61,  5,28, 11,48, 14,63,  6,37,  1,58, 13, 6, 10,91,  0,35, 16,95, 18,98, 19,90, 
     3,50,  0,26, 17,10, 10,75,  4,93, 13, 9, 18,92,  7,55,  9,63, 15,51,  2,33, 14,60,  5,91,  6,51,  8,96, 12,18, 19,75, 11,73, 16,50,  1,62, 
    12,28,  8,41,  6,92, 11,57,  3,10, 16, 5, 10,85, 19,41,  1,98,  7,12, 15,62,  9,39,  2,53, 14,51, 13,81,  4,56,  0,39, 17, 5, 18,90,  5,65, 
    17,83,  3,57,  2,47,  7,37,  1,10, 10,13,  6, 1, 14,98, 19,35, 11,17, 13,59,  8,86,  4,16,  0,66,  5, 1, 18,19, 16,10,  9, 1, 15,59, 12,67, 
     1,24,  8,69,  7,87, 11,87, 15,95, 14,44, 10, 8,  6,42,  9,21, 13,39, 17,75,  5,79,  4,73, 16,21, 18, 8,  3,87,  2,66, 19,25, 12,58,  0,91, 
     4,45, 11,29,  8,95, 17,55,  3,62, 13,97,  9,77,  2, 2,  0,43,  1,68,  5,94, 16,20, 15,61, 10,78, 12,65,  6,70, 14,42,  7,69, 18,59, 19,38, 
    18,79,  6,55, 17,65, 11,61,  3,85, 13,36,  9,31, 15,80,  8, 1, 12,62,  5,73, 10,31,  2,62, 19,13, 16,27,  7,28, 14,52,  0,71,  4,76,  1,73, 
    13, 8, 19,75,  7,10,  9,65,  2,39, 11,50, 14,15,  0,46, 16, 6, 15,16,  1,87, 10,31,  4,78,  5,33,  3,81, 17, 1, 18,86,  6,16,  8,64, 12,55, 
    11,45,  8,51, 10,66, 16,28, 12,56,  7,42, 15,93,  4, 5, 14,99, 17,16, 19,76,  1,32,  5,29,  9,33,  2,23,  6,65, 18,52,  3,99, 13,91,  0,12, 
     4,57, 17,91,  6, 8, 10,79, 16,61,  7,54,  2,47, 19,93, 11,39, 13,62,  3, 6,  1,63,  8,28,  5, 4,  0,84, 12,60, 15,70, 18,22, 14,76,  9,61, 
    17,97,  2,40,  7,40,  4,86,  9,97, 15,45, 19,31, 16,56,  5,95, 12,30, 11,87,  3,23,  1,71,  0,61,  8,92,  6, 1, 10, 5, 14,92, 18,26, 13,15, 
    12,24,  4,58, 19,62,  5,41, 17,11,  6,17, 14,45, 11,73,  0, 2, 18,57,  8,65,  2,51, 13,75,  7,59,  1,97, 10,88,  3,52, 15, 8, 16,59,  9,71, 
     7,18, 19,68, 12,70,  3,85, 15, 8, 10,96,  2,82,  5,34,  0,76,  9,45, 18,99, 17,39,  1,26,  8,76,  6,45, 11,77, 16,97, 14, 3, 13, 5,  4,53, 
     7,12,  8,60,  4,53,  3,51, 18,17, 19,41, 11,25, 14,90,  6,21,  0,65, 16,34,  5,51, 17,60,  9,51, 10,67, 12,97, 15,40,  1,24,  2,22, 13,29, 
    17,29, 13,36, 19,91,  6,68,  3,64, 18, 2, 12, 6,  9,65, 16,44,  8,50,  5,21,  1,64,  7, 6, 14,99, 11,44,  4,13, 15,42,  2,12,  0,15, 10,42, 
    16,32,  2,59, 11,29,  7,75, 12,54, 14,93,  9,41, 17,10,  0,63, 10,70,  4,84,  1,23,  6, 9, 13,39, 19, 9,  8,23,  5,68,  3,65, 15, 9, 18,64, 
    16,83,  9,26,  7, 3, 18,37, 11,66,  8,63,  4,10,  3,83,  2,80, 15,45,  1,16,  0,82, 19,12,  5,85, 10,30, 12, 2, 13, 7, 14,13, 17,35,  6,46, 
     4,21,  1,29, 17,50,  6, 5,  8, 6, 13, 6, 19,88,  0,50, 14,50,  9,65,  3,68, 12,71, 10,45,  5,51, 18,52,  7,53, 16,37, 15, 1,  2, 9, 11,41, 
    12,88,  6,55, 16,65,  0,97,  2,94, 19,73,  4,47,  8, 8,  7,74, 14,43,  5,98,  3,13, 18, 8, 11,32, 15,53, 10,70, 13,70, 17,37,  1,52,  9,21, 
    15,41, 18,31, 11,53, 13,34, 19,88,  7,96,  1,69,  2,92, 16,35,  8, 3, 14,53, 17,92,  4,54,  9,21, 12,90, 10,68,  3,23,  6,16,  5,39,  0,25, 
     2,35, 13,49, 11, 2, 12,34,  4,89, 17,36,  7,81, 14,29,  6,99,  8,96,  5, 5,  3,28, 15,97, 16,11, 19,79, 18,91,  9,65,  1, 5, 10,94,  0,94, 
     9,84,  6,34,  7,56,  8,77, 14,31,  2,97,  3,80,  4,88, 18,33, 16,73, 15,71, 12,37,  0,78, 13,81, 10,71, 19,50, 17,46, 11,90,  5,22,  1,25, 
     9,78,  2,93, 12,11, 15,53,  8,57, 13, 3,  1,52, 19, 4,  5,99, 16,24, 14,10,  7,41,  4, 9, 10,27, 11,19, 18,90, 17,55,  6,43,  0, 5,  3, 9, 
     6,20, 18,46, 11,57,  8,63,  4,70,  7,64, 19,55,  9,30,  5,26,  2, 6, 17,70, 15,48,  0,91,  1,97, 16,77, 10,94, 13,88,  3,75, 12,52, 14,77, 
    12,35, 16,41,  8,48, 19,97, 17,73,  0,73, 14,67,  6,19, 18,72,  1,82,  5,79,  4,45,  9,28, 13,64,  7,22, 15,65,  3,79,  2,14, 11,29, 10,36, 
    10,55,  1,54,  2,86,  8,10,  7,73, 12,32,  4,61, 19,50, 16,33,  5,81,  6,57, 14,99,  9,12,  3,49, 18,37, 17,72, 11,90, 15,60,  0, 6, 13,66, 
     7,35, 14,34, 12,97,  5,23, 10,69, 13,56,  3,38, 16,15,  2,67,  1,75,  4,52, 19,91, 15,55,  0,56, 11,73, 18,80,  9,88, 17,25,  6,20,  8,65, 
     1,65, 13,76, 17, 6,  0,39, 19,91, 12,84, 15,14, 16,13, 10,32, 18,29,  4,23,  6,12,  5,33,  2,59, 14,40,  3,21,  8, 8, 11,82,  7,73,  9,77, 
    13,53,  4,21,  7, 5,  9,41,  8,93, 18,28,  2,37, 19,76, 12,43,  6,32, 17,17, 14,11,  0,72, 16,32,  5,47, 15,68, 11,90,  1,65, 10,63,  3,60, 
    14,91,  3,81,  1,76,  4,44, 17,30,  7,84, 16,54,  0,26,  8,19, 11,93, 10,83,  6, 7, 12,44, 18, 8,  5, 5, 13,66,  9,58,  2,98, 15,81, 19,36, 
    12,33, 13,56, 11,85, 18,15,  9,38,  8,64,  2,24,  4,73,  5,19,  0,26, 14,59,  6,12, 10,14, 17,22,  7,38,  1,65,  3,58, 15,92, 16,40, 19,52, 
    18,92,  5,12,  7,82,  3,41, 19,51, 11,46,  1, 7, 13,30,  9,26,  8,89,  6,62,  2,81, 14,82, 12,85,  4,70, 16,34,  0,15, 17,98, 10,97, 15,48, 
     6,11, 16,10, 10,73, 19,50, 13, 3,  0,16, 15,24,  9,88, 12,94,  8,11, 17,58,  7, 4,  4,66, 18,58, 14,42,  5,69,  2,98,  1,50, 11,25,  3,46, 
    17,87, 15,97, 10,84, 13,49, 11,82, 18, 3,  9,76,  1,77,  5,35,  0,41,  7,56,  4,31, 12,50, 16,56, 14,75,  3,42,  2,37,  8,94, 19, 3,  6,14, 
     2,88,  3,77,  8,64,  1,42, 13, 7, 15,84, 19,16,  7,20,  6,56, 10, 7,  5,47, 14, 2,  0,49,  4,53, 11,65, 17,76,  9,82, 12,12, 16,41, 18,94, 
    15,84,  5,99,  1,61, 11,28, 16,59,  0,64,  4,51,  7,77, 13,26, 18,43,  8,72, 17,63, 12,68,  9, 4,  6,86, 10,87,  3,77,  2, 8, 19,47, 14,38, 
     6, 7,  0,40,  3,96, 14, 7, 12,82,  9,61,  8,89, 16,76,  4,35, 18,97, 13,95,  1, 5, 10, 4,  7,11,  5,83, 19,65, 15,86,  2,14, 11,17, 17,34, 
     2,51, 10,72, 19,74, 13,35, 11,92,  0,53, 17,19,  4,90, 12,35,  9,47,  5,49, 18,34,  1,68,  6,46, 14,80,  8,30,  7,71, 16,31,  3,50, 15,70, 
     7,31, 10,71,  4,45,  6,75, 12,40, 15,87, 16,55, 17,21, 11,18,  9,21,  1, 1,  2, 5, 19,17,  8,83, 18,58, 13,68, 14,66,  0,89,  5,35,  3,67, 
     7,85, 12,13,  3,46, 14,96, 10,90,  2,31, 15,75, 18,88, 16,18,  9,80,  5,48,  1,74, 11,55,  8,68, 19,88,  4,85, 17,55,  6, 6, 13,82,  0,82, 
    17,89,  6,52,  8,29, 11,38,  7,90, 13,70,  0, 4,  5,86,  1,48, 10,59, 16,75,  4,38,  9,37,  3,46, 18,40, 15,23, 19,19, 14, 3, 12,35,  2,71, 
    15,64,  1,60,  7,86, 19,14, 10,61,  6,87,  5,47, 17,83,  2,66, 16,78,  8,90, 14,80, 13,80,  3,58,  4, 8,  9,14, 11,43,  0, 4, 18, 1, 12, 3, 
    17, 5,  5,61, 19,23,  4,57, 16,67,  7,49, 13,88, 10,23, 11,12,  2, 3,  8,29, 14,69,  9,52, 15,13, 18,16,  1, 2,  0,13,  6,50,  3,46, 12,73, 
    17,85, 18,86, 19,48,  7,71,  6,83, 13,17, 15,17,  1,18, 16,34,  9, 7,  8, 2,  5,41, 14,34,  3,37, 11, 7, 12,88,  0,59,  4,56,  2,63, 10,50, 
     8,59,  2,49, 13,81,  6,13, 18,29,  3,19, 19, 5,  7,77,  0,71,  4,11,  1,68,  9,90, 10,62,  5,96, 14,70, 17,31, 12,55, 11,80, 15,55, 16,85, 
    14,85,  7,88, 17,97, 18,58,  4,83,  9,47, 12,84, 13,95, 10,62,  5,72,  6,75, 11,40,  0,52,  8,79, 19,48, 15,53,  1, 5,  3,38, 16,44,  2,28, 
    18, 4,  4,16,  1,82, 13,45,  6,65,  3,35, 16,58,  0,31,  8,45, 14,12, 11,58, 19,51,  9,43,  7,12, 17,48,  2,38, 10,72,  5,93, 12,11, 15,94, 
    16,42, 19,49, 13,84, 18,90,  7,16, 10,78, 17,83,  3,82,  9, 7,  6,99,  0,22,  4,14,  8,63,  1,81, 15,78, 14, 7,  5,31, 12,14,  2,59, 11,33, 
    10,14,  0,67,  1,66,  9,24,  3,75, 18,85, 13,62,  7,59,  8,65,  5,74, 15,58,  2,18, 17,90,  6,81, 11,53, 16,24, 12, 8, 14,17, 19,99,  4,62, 
     4,68,  9,93,  3,19, 10,51,  8,36,  6,85, 12,66, 18, 7, 17,51, 16,89,  7,11, 11,70, 15, 2, 13,11, 19,49,  5,41,  0,68, 14,80,  1,51,  2, 2, 
     5,92, 19,16,  0, 6, 13,22, 16,93,  6,89, 17,29, 10,34, 15,62,  1,19,  3,61, 14,18,  2,91,  8,16,  9,27,  7, 4, 12,69, 18, 2,  4, 7, 11,83, 
     4,16,  7,19, 14,32,  8,39, 13,19, 12,51, 11,11,  1,31, 17,23,  9,72, 19,49,  0,71,  2,33, 16,73,  6, 3, 15,54,  3,37, 10,24,  5,17, 18,60
  };
  // Taillard 100x20 instance 1
  const int tai_100_20_1[] = {
    100, 20, // Number of jobs and machines
     8,53, 10,40,  5,82,  0,42,  7,98,  2,86, 14,50, 12,57,  3,28, 15, 7, 18,13,  9,24, 11,61, 16,54,  4,97, 13,92, 19,86, 17, 5,  6,32,  1,11, 
     3,44,  4,50,  6,39, 10,81, 16,51,  5,92, 13,65, 18,20,  1,75,  0,60, 14,95,  9,28, 15,14,  7,28, 17,54, 12,55,  8,91,  2, 3, 11,28, 19,93, 
     0,52,  8,67, 13,64,  5,83,  2,37,  9,21, 18,10,  1,62, 14,74,  6,86, 17,71, 15,43,  3,24, 19, 5, 12,78, 10,10,  7,40,  4,51, 16,89, 11,54, 
    12,74,  9,86, 14,71, 19,80, 16,21,  2,14,  0,49,  6,16,  1,26, 13,34, 17, 2,  8,17,  7,47,  5,68, 10,21, 15, 8,  4, 8, 11,51,  3,21, 18,71, 
     9,89, 17,50, 12,80, 18,88, 13,16,  8,58, 15,20, 10,32,  6,42, 14,89, 19,79,  4,87,  5,73,  2,74,  0,17, 11,53,  7,81,  3,85, 16,55,  1,57, 
    11,73,  5, 5, 18,26,  0,57,  9,45, 16,40, 19,46, 15,15,  4,79,  7,48,  8,20,  3,69, 17,16, 13,29,  2,48,  1,38, 14, 6, 10,18, 12,62,  6,86, 
     7,57,  3,89,  9,91, 10,96, 13,66, 19,49,  6,88, 14,62,  5,86, 16,80,  0,13,  1,58,  2,81, 18,70,  4,48, 17,61,  8,12, 12,69, 15,76, 11,23, 
     4,30,  5,65,  9,26, 18,60, 10,38,  8,66, 11,76,  0,85, 16,39, 13,96, 12,19, 14,75, 19, 5,  7,91, 15,14,  2,46,  1,27, 17,69,  6,95,  3, 3, 
    17, 1,  4,99,  8,97,  3,17,  7,51, 13,63, 12,82, 14,79,  9,60,  0,61,  5,92, 10,58, 15,13, 19, 2,  2, 3,  1,74,  6,43, 16,34, 18, 6, 11, 1, 
     0,18,  8,77, 19,12, 18,36, 13,64,  7,35, 17,66,  3,86, 15,98,  6,54,  2,11, 14,41,  9,15,  4,87, 16,76,  5,33, 11,85, 12,12,  1, 1, 10,62, 
    10,29, 12,17,  1,21,  6,93,  2,39,  5,48,  0,46, 13,60, 16, 9, 17,61,  3,43, 18,47,  8,47, 15,92, 11, 2,  7,77, 14,58,  4,71, 19,16,  9,50, 
     6,91,  7,42,  5,32, 10,96,  1,58,  3,24, 18,56,  2,63, 15,74, 16, 1,  4,42, 14,84,  0,56, 11,44, 13,58,  9, 1,  8, 5, 19,53, 17,44, 12,52, 
    18,48,  2,16,  4,37, 15,60,  7,54,  5,32, 11,69,  3,25, 13,48,  6,72,  0,77,  9,29, 17,64, 16,10,  1,53, 19,90,  8,71, 14,84, 12,82, 10,93, 
    17,23, 13,28, 14,99, 19,49,  0,79,  4, 7,  9,32,  6,89,  5,12,  1,22,  8,54, 12,88, 18,69,  7,65,  3,95, 11,84, 10,32, 16,64, 15,33,  2,55, 
    15,97,  1,49, 13,11,  8,79, 19,86, 17,67,  6,51,  2,80,  9,29,  0,75, 14,64,  7,59,  4,92,  5,85, 16,92, 18, 3, 10,94,  3,69, 11,34, 12,27, 
     8,75, 12,20,  5,87,  2,67, 19,70,  0,23, 15,93, 14,31,  4,72, 18,16, 11,36,  1, 5, 17,59,  3,75,  9,85, 10,24, 16,29,  7, 5, 13,47,  6, 1, 
    14,24,  6,13, 16,27,  9,21, 11,29, 12,19, 13,91,  4,37,  2,93, 15,76, 19,75, 17,15,  5,70, 18,70,  3,91, 10,57,  7,18,  1, 8,  0,29,  8,73, 
    12,16,  2,15, 13,76, 16, 1, 11,93, 18,87, 19,60, 17,67, 15,27,  7,91,  1,45,  8,28,  3, 7,  0,68,  4,97, 14, 6, 10,50,  6,71,  9,52,  5,99, 
    14,81,  6,53,  9,16, 18,88,  3,16, 13, 3,  2,49, 15,62, 19,26, 17,26, 12,43,  5,31,  1,75,  7,35,  0,72, 10,37,  4,79,  8,94, 11,94, 16, 7, 
    14,93, 19,21,  5,92,  3,60, 12,42, 15, 9, 16,93, 13,68,  9,28, 18,29, 10,45,  1,94,  7,97, 17,78,  0, 5,  4,66, 11,85,  2,39,  8,18,  6,80, 
    11,43,  7,33, 14,21, 13,63,  3,56, 17,90,  9,12,  8,12,  0,79,  5,51,  4,99, 19,98,  6,68, 15, 8, 10,61, 16,41,  2,58, 12, 8,  1,42, 18, 9, 
     7,66, 18,83, 17,38,  0,40,  1,57, 16,62, 12,31,  9,21, 14,88,  6,59,  8,82,  3,96,  4,69, 15,11,  2,49, 19, 1, 13,56,  5,97, 11,21, 10,26, 
     1,53,  5,12, 16,91,  3,86, 17,66,  2,85, 15, 2,  6,78,  4,23,  9,28, 11,16,  8,35, 13,55, 10,35, 14,51, 12, 3, 18,25,  0,54,  7, 6, 19,10, 
     1,10,  0,63, 16, 3, 10,67,  8,82, 14,12,  2,99, 17,57,  6,70,  5,67, 11,82, 13,37,  4,16,  9,47, 15,90, 12,71,  7,74, 19,75,  3,31, 18,69, 
    14,86,  0,17,  5, 1, 18,39, 10,42,  7,35, 17,85, 13,35,  2,93, 19,48,  6,22, 15,76,  3,25, 16,42, 11,65,  1, 3, 12,79,  9,95,  4,59,  8,24, 
    10,83,  7,72, 14,50,  6,93, 13, 8, 11, 7, 15,79,  9,57,  4,95,  8,68, 19,67, 12,15, 16,58,  1, 2,  5,34,  3,95,  0,72, 18,96, 17,30,  2,26, 
     0,11,  5,22, 10,81,  2,63,  1,95,  8, 2,  9,22,  4,81, 12, 2,  6,91, 11, 7, 18,36,  3,27,  7,87, 13,54, 16,24, 19, 4, 17,94, 14, 7, 15,26, 
    18,11, 17,21, 16,46,  8,91, 19,30,  6,18, 10,37, 14,35,  2, 4, 15,64,  7, 9,  9,57,  3,51,  4,41,  0,90, 12,24,  1,28, 11,94, 13,80,  5,32, 
    18,17,  7,40,  6,44, 14,72,  5,41,  8,31, 16,86, 19, 7,  3,60,  2,41, 17,11,  4,36,  1,20, 13,23,  0,81, 15,27, 10,53, 12, 8, 11,96,  9,77, 
    19,39,  1,40, 11,37, 17,70,  7,13,  3,43,  4,36,  6,81, 18,55, 16, 4, 15,60,  9,20, 12,31,  5,66,  0, 9,  8,22, 10, 6,  2,84, 13,94, 14,15, 
     2,52, 13,12,  5, 1, 16,32,  0,52, 11, 6,  7, 9, 17, 6,  9,18, 15,97, 18,82,  6,12, 14,62,  3,43, 19,88, 10, 4, 12, 8,  8,89,  1,49,  4,27, 
    10,69,  4,98,  5,43,  0,94,  8,71,  9,82,  1,42,  6,91, 17,20, 13,52,  7,45, 16,58, 11, 1,  3,19, 19, 7, 14, 9, 12,83, 18,93, 15,62,  2,68, 
    17, 6, 10,78, 12,55,  7,62, 19, 1,  2,33, 15,26,  9,20,  0,21, 11,99,  3, 8,  5,91,  8,76, 14,52,  4,33,  1,15, 16,72,  6,34, 18,34, 13,96, 
    15,49,  2,20, 16,54,  6,34,  4,43,  8,28, 14,59,  1,63, 11,95, 13,32, 17,23, 12,28, 18,47,  7,45,  9,28,  0,46, 19,25,  5,53, 10,18,  3,53, 
     6,41,  4,13,  5,43, 18, 8,  7,98,  9,75,  0,71, 15,60, 17,20,  1,15, 11,11, 12,65,  3,56,  2,89, 10,48, 13,83, 16,76, 19,82,  8,52, 14,26, 
     5,40, 14,20,  0,63,  8,10, 11,23,  6,79,  4,71, 15,12, 16,43,  3,15, 13,62,  2,19, 19, 4,  9,46,  7,70, 18,87, 17,45,  1,24, 10,30, 12,76, 
    15,37,  6,58,  2, 5, 12,29,  1,20,  9,24,  4,40, 17,34,  5,53,  3,72, 10,12,  0,26, 18,12, 14,40, 13,74,  8,29, 16,43, 11,42,  7,12, 19,43, 
     6,62,  9,35,  2,62,  0,20, 10,17, 11,44,  8,94, 18, 6, 13,83,  7,85,  3,14, 14,71, 15, 5, 16, 7,  4,53, 17,43, 19, 2, 12,11,  1,18,  5,89, 
     0,68,  1,94,  7,87,  9,34, 12,10,  2,76,  6,29, 16,41,  5,30,  3,58, 19,34, 10,83,  4,15, 13,30,  8,28, 15,24, 17,40, 11, 1, 18,72, 14,82, 
     2,55, 18, 9,  8,85,  0,74,  3, 6,  5,16,  9, 5, 15,24,  7,12, 11,33,  4,30, 16,34, 10,34, 14,17, 12,75,  6,38,  1,49, 17,78, 19,19, 13,35, 
     7,51,  5,40, 11,28,  2,84,  8,78, 15,93, 12,39, 18,14, 14,57, 17,52,  3,94, 16,10, 10,35,  1,97,  0,93, 19,87,  9,47,  6,27,  4,18, 13,24, 
    15,43, 16, 9,  7,63,  3,11,  9,26,  1,42, 17,53,  0,42, 14, 8,  8, 7,  2,77, 10,97, 19,43,  6,52, 11,32, 13,23, 18,32,  4,50, 12,99,  5,83, 
     3,51, 13,16, 16,83, 10,33,  2,90,  0,24, 15,21, 17,95,  4,11,  5,56,  8,21,  7,37,  9,72, 11, 5, 18,94, 19,28, 14,26, 12,67,  1,52,  6,95, 
     7,82,  8,72,  3,62, 19,61,  1,22, 12,18, 11,66,  2,28,  5,88,  0,48, 16,87, 18,41, 14,78, 17,70, 15, 2,  4,15,  6,13,  9,25, 13,44, 10,62, 
     1,28, 19,24, 12,56,  8,77, 10,21, 14,46, 11,30,  9,89,  2,56, 18,71,  0,23,  5,31, 13,26,  7,76,  6,70, 15,93,  4,86, 17,74, 16,79,  3,57, 
    16,40, 14,72, 10,96, 11,52,  9, 4, 17,17, 13,25, 18,92, 12,67,  2,77,  1,62,  4,11,  0, 3,  8,75, 15,21,  5,79,  3,90,  7,70, 19,40,  6,51, 
     7, 7, 15, 7, 11, 2,  1,61, 13,34,  3,46, 14, 7,  9,22,  4,36, 10,36,  6,11,  8,95,  2,11, 18,69, 12, 8, 19,56,  5,33,  0,69, 17,87, 16,58, 
     8,31,  1,11, 10, 5,  3,15, 12,51, 17,76, 15, 1,  7,51, 16,30,  9,36,  4,17,  5,52, 19,61, 11, 9,  2,80,  6,10, 13,75,  0,66, 18,32, 14,14, 
     9,84, 18,94,  4,61, 14,90, 12, 9,  5,72,  6,66,  8, 5, 17,76, 10,41,  2,87, 15,80,  3,50, 19,45,  1,95, 11,12,  7,32,  0,52, 16,28, 13,75, 
     5,60,  8,21, 14,60, 10,52, 12,42,  0,47,  4,77, 11,93,  2,27,  1,62, 13,24, 15,37, 17, 4, 19,75, 16,56,  9,16, 18,76,  6,64,  7,85,  3,11, 
     3,21, 15,10,  9,87,  5,47, 18,40,  7,45,  1,48, 17,27, 12,63,  0,29,  6,36, 19,25, 11,74, 14,19,  4,20,  8,78, 16,51, 13,32, 10,69,  2,23, 
    15,71, 13, 7,  1,64,  7,53,  0,89,  4,39, 17,86,  9, 2, 19,92,  5, 5, 18,52, 11,63, 16,27, 14,75,  8,46,  3, 3,  6,98,  2,82, 12, 6, 10,70, 
    12,51,  9,89,  8,36,  2,84, 18,95,  1,12, 19,97,  4,75, 10,57,  0,79, 13,91, 17,77, 15,17, 16,86,  6,58, 11,43,  3,15, 14,90,  7,28,  5,45, 
    17, 3, 18,31, 14,71,  8,51, 12, 6,  5,37, 11, 4,  2,81,  1,98, 15,97,  7,58, 16,19, 10,84,  6, 3, 13,96,  9,50,  0,21,  3,86,  4,44, 19,76, 
     5,66, 12, 9, 16,32, 11,78,  0,20,  8,69, 10,46,  4, 1,  7,93,  3,81,  2,18, 13,64, 17,40,  1,39, 14,86, 15,92, 18,69, 19,69,  9,17,  6,11, 
    19,98, 11,80,  2, 8,  3,98, 14,56, 10,47,  1,26, 12,30,  9,49,  6,55, 18,75, 13,66,  5,44,  8,12,  7,60, 17,81,  0,82, 15,38, 16,29,  4,72, 
     9,55,  8,18,  4,32,  1,78,  5,95, 12,40, 16,79, 19,35,  3,41, 10,40, 15,65, 14,89,  2,16,  6,20, 11,86, 18,59, 13,49,  0,86,  7,36, 17,25, 
    12, 6, 16,51,  2,26, 18,59,  3,20,  5,65,  4,50, 11,99, 13,96, 14,62, 10,47,  1,89,  9,39,  6,68, 17,28, 15,70,  7,29,  0,71,  8,94, 19,79, 
    17,51,  2,73,  5,20, 11,26, 16,11, 12,46, 14,35,  3,87, 15,84, 13,95,  4,84,  1,97,  6,50,  9,10, 18,99, 10,97,  7,86,  0,83, 19,27,  8,84, 
    18,58, 13,24,  1,99,  3,80,  0,78, 14,10, 12,53,  6,10, 11,99,  8,85, 15,80, 16, 7,  7,24, 19,66,  9,92, 10,74,  4,98,  2, 9, 17,30,  5,28, 
     7, 9,  6,88, 16,56,  0,23,  2,92,  5,38, 19,88, 15,64,  1,71, 10,59,  8,11, 14,32, 18,71,  4,62,  3,27, 13,20,  9,54, 11,43, 12, 2, 17,73, 
    17,69,  8,47, 19,60, 13,75,  9,13, 16,22,  7,16,  0,60,  3,87, 18,80, 10,33,  2,14,  1,59,  6,99, 11,97, 14,55,  4, 3, 15,40,  5,30, 12,36, 
     1,56, 10, 2,  7,31,  0,70, 15,92, 16,87, 17,49,  9,25, 13, 5,  5,42,  2,66,  3,18,  6, 1, 11,43, 12,32, 14,46,  8,48, 18,20, 19,11,  4,23, 
     9,29, 14,22, 17,17, 18,19, 13,35, 12,28,  4,19, 15,29,  7,80,  3,59,  5,86, 19,95,  0,36,  6,79,  1,82, 11,89,  8,72, 16,27,  2,86, 10, 4, 
     1,76,  9,31,  4,93,  5,64,  7,87,  8,84, 15,62, 13,41, 12, 6, 10,36,  3,12,  0,18, 14,68, 19,96,  2,90,  6,34, 16,67, 18,61, 11,73, 17,64, 
     1,41,  8,28, 16,39, 19,34,  9,36,  2,13, 12,95, 17,12,  0,10, 10,30,  5,34,  3,92, 11,14, 18,15, 15,10,  4,98,  6,75, 13,62, 14,12,  7,88, 
    16, 9,  5,83,  6,93,  9,98,  8,33, 15,81,  7,40, 17,18,  1,96, 10,52,  2,51, 14,99,  0,34, 18,46, 12,30, 13,55,  3,44,  4,32, 11,71, 19,10, 
    15,83, 18,66, 16,20, 19,22,  2,73, 14,76,  6,59,  7,74,  5,23, 12,90,  3,53,  0,11, 11,43, 17,88,  1,76,  8,65,  9,44, 10,52, 13,25,  4,54, 
    12,78, 18,91, 15,41, 11,54,  8,68,  7,60,  3,94,  1, 3,  2,38,  5,22, 17,33, 16,37, 10,76, 14,31, 13,24,  9,46,  4,20, 19,69,  0,53,  6,57, 
    12,80, 10,12,  4,46,  2, 5,  5,20,  7,42,  9,66, 11,32, 19,43, 18,58, 14,63, 17,89, 15,54,  3,79,  0,28, 13,42,  8,90,  6, 6,  1,66, 16,29, 
    15,63,  8,56,  4,43, 14,33, 19,10, 13,53,  5, 2, 17,24,  1, 6,  0,61,  9,14,  3,92, 11,27,  6,82, 10,63,  7, 2, 12,27, 18,25, 16,51,  2,91, 
    12,23,  3,62,  6,44, 10,32, 18,69, 14,86, 11,24, 15,42,  0,31, 17,35,  1,24, 13,34,  4,12,  9,35, 19,51,  5,73,  2, 5, 16,12,  7,52,  8,13, 
    14,53,  4,67,  2,91, 10,63, 17,97,  6,83,  0,51,  7,55, 19,14,  1,78, 11,17,  3,74, 16, 9, 15,63,  8,22, 13,71, 12,41,  9,81, 18,54,  5,46, 
    17,28, 18,16,  9,12,  4,30,  5,97,  2,86,  8, 9, 13,65,  6,51, 15,30, 12,15,  3,41, 14,91,  1,46,  0,18,  7,21, 16,89, 11, 2, 10,77, 19,78, 
    12,91, 11,33,  3,84,  1,79,  0, 4, 18, 7,  8,49, 16,45, 14, 9, 19,69, 13,86, 10,94,  9,90,  4,24, 17,21,  5,15,  2,38,  7,28,  6,26, 15,60, 
    17,94, 11,47,  2,96, 14,70, 19,51, 10,93,  3,64,  6,24,  8,45,  9,36, 13,62,  0,91, 15,18,  1,38, 16,47,  5,98,  7,51, 12,12,  4,26, 18,51, 
    18,50, 19,74,  3,34, 17,45,  1,33,  5,50,  4,69, 10,14,  2,89,  7,86, 12,57, 14,17,  9,80, 15,32,  8,72, 11,33, 13,51, 16,31,  6,43,  0,65, 
    11,14,  0, 4, 13,22, 14,27, 19,58,  3,12,  7,92,  4,27,  6,24, 10,13,  2, 8,  5,55,  8,66, 12,81,  9,12, 17,13, 15,57, 16,77, 18,25,  1,99, 
     7,99, 17,84,  3,72,  9,79,  4,72,  8,47, 19,47, 15,92, 14,49,  2,49,  0,43, 11,33, 13,30, 16,16, 10,35,  5, 2, 12,47,  6,59,  1,44, 18,98, 
    11, 1, 17,75,  9, 2,  1,26, 10,20, 12,54,  4,63,  0,31, 13,44,  6,98, 19,73,  5,41,  2,52,  7,81,  3,30, 14,57, 16,25,  8,70, 15,58, 18,83, 
    15,21,  0,15,  2,60,  9,30,  3,50,  7,31,  6,17, 12,34, 17,15,  4,98, 19,77, 14,57, 18,58,  5,40, 11,21,  1,25, 16,41,  8,78, 10,44, 13,26, 
    12,14, 16,31, 10,86, 13,68,  7,69, 19,71,  2,44,  6,10,  1,76, 15,82, 11,54,  0,40,  5,46,  9,47,  4,42, 17,86,  3,62, 18,41,  8,27, 14,12, 
    19,18,  5,46, 10,22, 15,66,  8, 5,  7,12,  6,27,  1,82, 14,24,  9,60, 16,10,  0,93, 11,54, 12,10, 17,60, 18,14,  3,16,  2,48, 13,18,  4,82, 
    10,84, 13,15,  9,59, 14,45, 18,63,  5,71, 19,86, 15, 2,  3,42,  8,46,  6,39,  4, 9,  7, 7,  1,32, 17,78, 11,12, 12,78,  0,68,  2,77, 16,90, 
     2,33, 15, 2, 11,35, 14,91,  8,49, 16,21, 19,29,  7,60,  4,88,  1,71,  0,14, 12, 6,  9,40, 13,53, 18, 2,  6,88,  5,38, 10, 7, 17,43,  3,34, 
     4,16,  2,95,  3, 2, 15,88,  8,45, 11,93, 18,77, 17,10, 16,71, 12,69,  1,33, 13,22, 14,54, 19,56,  5,31,  7,18,  0,63, 10,82,  6,98,  9,70, 
    12,15,  0,42,  4,44,  8,80, 19,15,  6,24,  5,76, 10,71,  9,38, 15,27,  7,48, 18,38,  3,73, 14,42,  2, 8, 13,52, 11,20, 17,40, 16,51,  1,99, 
    13,46, 15, 3, 19,82,  5,20,  4, 1,  7,45, 18,79, 16,70,  3,46, 11,48, 12,63,  2,87,  9,47,  0,43, 10, 1,  1,48, 14,65,  8,11, 17,25,  6, 9, 
    14,12, 13,17, 16,55,  8,75,  6,56, 10,89, 11, 6,  0,46,  9,22, 15,44, 17, 2, 18,14,  7,36,  1,96,  3, 6,  4,37, 19,62,  5,94, 12,77,  2,14, 
     6,37,  3,28, 12,16, 13,80,  2,10, 15,90,  0, 5, 10,17, 19,28, 18,40,  9,76,  1,30,  7,52, 17,77,  4,15,  5,50, 11,99, 16,99,  8,64, 14,63, 
     2,88, 14, 4,  9,26,  6, 9,  4,81, 16,47, 11,82,  8,52, 12,65, 13,63,  1,37, 18,59,  0,78,  7,51, 17,75,  3,24, 15,77,  5,28, 19,97, 10,98, 
    16,79,  8, 7,  9,25, 12,92, 18, 8, 11,90, 13,82,  5, 9,  4,53, 19,95,  6,51,  1,54, 17,29, 15,86,  7, 7,  2,58,  3,66,  0,84, 10,42, 14,10, 
    15, 5, 16,52, 11,70, 18,59, 14,10, 10,88,  5,56,  0,55,  7,73,  3,65,  6,66,  8,17,  9, 5, 12,22,  1,40, 17,42,  2, 1,  4,51, 19,95, 13,28, 
    14,30, 12,62,  6,46,  8,14,  4,62, 16,16,  5,24, 19,17, 15,70, 11,66, 17,57,  1,55,  2,79,  9,99, 13,27, 18,17,  3,75,  7, 6,  0,14, 10,61, 
    10,71, 11,22, 14,68, 12,74,  4,39,  9,68,  5,28, 18, 7, 17,67,  3, 7,  1,92,  7,45, 16,67, 13,35,  6,70,  0,52,  2,65,  8,99, 19,21, 15,51, 
    16, 5,  6,73,  3,10, 15,75,  7,16,  4,70, 12,39,  9,62,  8,65, 13,99,  2,57, 10, 7,  1,54, 19,52, 14,47,  0,43, 18, 1,  5,65, 11,88, 17,36, 
     5,30, 19,82,  8,82,  4,54,  0,94,  1,28, 14,75, 18, 1, 13,84,  7,61, 17,17, 11,45,  2,72,  6,58,  3,78, 10,63, 15,50,  9,77, 16, 8, 12,25, 
     9,17,  6,78, 16,20,  4,92, 19,57,  5,95, 18,25, 11,44, 13, 8, 15,93,  1,21,  2,21,  7,47,  8,38,  3,33, 14,48, 17,39, 12,69,  0,15, 10,70, 
     4, 2,  6, 4,  5,44,  7,38,  8,93,  0,94, 17,93,  9,18, 13,38, 19,66, 12,38, 14,60, 11,87, 16,49,  1,52,  3,72, 10,12,  2, 5, 18,21, 15, 6, 
    17,63, 14,21,  2,21, 12,53,  7,79,  9,10,  8,13,  5,45, 16,63, 18,39,  0,38,  3,50, 13,80, 15,45, 19,84,  4, 2, 11,29,  6,31,  1,27, 10,96
  };
  // Taillard 100x20 instance 2
  const int tai_100_20_2[] = {
    100, 20, // Number of jobs and machines
    14,57,  0,18, 15,44, 16,17,  6,66, 19,34,  4,83, 13,76,  1,66,  8,20, 17,94,  5,67, 10,76, 12, 1, 11,84, 18,31,  9,78,  3,16,  7,15,  2,91, 
     2,56, 13,91, 19,62, 11,32, 16,61,  4,49,  6,27, 17,94,  5,92,  8,27, 10, 7, 12,99, 15,26,  1,80,  0,90,  3,61,  7,40, 18,74, 14,18,  9,38, 
    10,25,  6,61,  2, 5, 16,73,  7, 9,  3,17, 13,25,  9,99, 14,22, 19,24,  4,92,  8,91, 17,19, 11,20,  0,34,  1,82, 18,91,  5,38, 15,87, 12,13, 
    12,30,  9,50, 18,13,  4,77, 19,10, 14,92,  3,85,  6,84, 13,98,  5,25,  1,59, 16,69, 17,68, 10,48,  2,79,  0,90,  7,41, 15,60,  8,58, 11,73, 
    16,70,  2,93,  8,72,  6,17, 14, 2, 12,87,  0,19, 19,44,  3,38, 11,29,  7,62, 10,44, 18,18, 13,52,  5,63, 15,41, 17,99,  4,68,  1,42,  9, 1, 
    19,64,  8,65,  1,34, 13,73, 17,32,  3,17, 10,31,  2,80,  9,63, 12,13,  7, 3,  5,34, 15, 2,  4,60, 14, 6,  6,93, 16,39, 11,31,  0,58, 18, 6, 
    17,91,  2,65, 14,22, 10, 4,  0,72, 19,50,  7,85,  3, 4, 18, 7,  8,58, 13,96, 15,21,  6,62, 11,15,  4,79,  9,36,  5,58, 16,43, 12,21,  1,45, 
     6, 6, 19, 3, 12,21, 11, 1, 13,60, 10,32,  8,31,  7,43,  9,85,  0,59,  4,48,  1,11,  3,70, 15,21, 16,88, 18,92,  5,90,  2, 4, 14,49, 17,42, 
    14,89, 16,99,  6,84,  0,69, 19,35,  5,22,  9,42, 18,13,  2, 5,  3,33, 17,15,  8,22, 10,16,  1,12, 12,22, 15,26, 11,52,  7,11, 13,39,  4,39, 
    13, 1,  5,67, 16,70,  4,74,  6,52, 19,35, 15,83,  1, 2,  9,57, 14,24,  7,58, 11,78,  8,65, 17,44,  2,95, 12, 5,  0,47, 10,69,  3,66, 18,38, 
    10,65,  5,71,  1,34,  2, 6,  6,88, 18,96,  9,80, 11,87,  8,56, 12,15,  3,62, 17,75, 13,61,  7, 3, 14,56, 15,67,  4, 6, 19,37,  0,34, 16, 4, 
     7,23,  5,43, 17,28, 10,78,  3,77,  8,55, 14,27,  4,80, 13,42,  6,51, 16,54,  0, 9, 12,85, 18,93,  2,77, 11,31, 19,76, 15,43,  1,29,  9, 8, 
    19,55,  5,49,  3,22,  0,21,  8,57,  7,25,  2, 2,  1,87,  9,74, 15,94, 17, 7, 16,85, 10,46,  4,75, 18,91, 12,39, 14,21,  6,17, 11,66, 13,83, 
    19,42,  4, 8, 16,25, 17,42,  7,39,  5,12,  2,11, 15,73,  9,25,  8,63,  1,65, 18,57,  6,77, 10,49,  0,18, 14, 1, 12,84,  3,58, 11,67, 13, 8, 
     3,30,  0,26,  8,35, 14,40,  5,34, 16, 1, 19,88,  4,92,  2,53, 11,58, 12,32, 17,70,  9,11, 15,24, 13,64,  7,50,  1,68,  6,99, 18,38, 10,11, 
     5,38, 17,93,  2,50, 10,69,  6,78,  9,62, 15,70,  0,45, 11, 7,  3,87,  4,77,  7,87,  8,86,  1,66, 19,35, 16,42, 13,82, 18,55, 14,28, 12,23, 
    10,82,  4,99, 15,98, 13,50,  9,49, 14,22,  1, 9,  2,52,  3,21, 16,38,  0,50, 19,74, 11,58,  7,44,  8, 5, 18,53, 17,61,  6,21,  5,89, 12,62, 
     2,12,  8,60,  7,27, 11,74,  0,60, 17, 8,  4,26, 13, 3, 19,30, 12, 6,  3,46, 15,63, 16,67,  5,17, 10,75, 18,57,  9,51,  6,52, 14,13,  1,87, 
    19,68,  9,23,  3, 6, 16,20, 10,74, 17,30, 12,14, 13,46,  2,49, 15,67,  6,34,  4,47,  8,83, 18,45,  5,43,  0,75,  7,41,  1,81, 11,80, 14,55, 
     2,43, 14,17, 15,26,  8, 5,  4,22, 10,51,  0, 9, 12,61,  1,16,  5,93, 17,76, 19,34, 13, 5, 11,30,  7,81, 16,36,  6,13,  9,23, 18,76,  3,31, 
     4,25,  9,57, 17,51, 11,51,  5,22,  8,91, 16,32,  1,22, 19, 7,  2,99, 18,61, 15, 7,  7,67, 12,87, 14,95, 13,79, 10,19,  6,37,  3,92,  0,23, 
     0,57,  3,23, 13,99, 11,45,  5,47,  6,59, 14,53,  1,68, 18,68,  2,55, 19,19, 16,76, 15,30,  8,87,  4,55,  7,77, 12,12, 10,40,  9,30, 17,76, 
    16,96,  8,25,  2,83,  4,41, 17,76, 18,45,  7,23, 15,65, 14,73, 12,35,  6, 4,  3,47, 19,60, 13,74, 10,94,  1,51,  0,50, 11,82,  9,84,  5,11, 
     2,89, 12,76, 14,15, 18,68, 11,81,  9,81, 19,55,  7,56,  6,78, 15,46,  5,92,  1,15,  4, 5, 10,12, 16,49,  8,60, 13,94, 17,12,  3,33,  0,47, 
    10,56,  9,14, 16,80,  0,11,  1,50,  7,51, 19,83, 13,65, 14,87,  2,50,  3,78,  6, 6, 12,18, 15,40,  4,43,  8,87, 17,74, 18,76,  5,73, 11,51, 
    15,63,  3,55,  5,49,  6,52, 18,66,  9,27, 10,66,  7, 1, 14,83, 13,23, 17,49,  1,95,  4,48, 11,26, 16,56, 19,20,  0, 7, 12, 6,  2,43,  8,52, 
    15,29, 19,90,  8,83,  4,33, 11,91,  6,45, 17,71,  3,49, 12,90,  7,72, 16,79, 10,56, 13,65,  1,11,  2,74, 18,36,  5,76, 14, 1,  0, 2,  9,74, 
     6,89, 11,18, 13,73,  5,45, 18,37,  3,44,  0,25, 16,86,  7,66,  2,19, 17,76,  1,31, 15,44,  8,12,  4,54, 19,73,  9,42, 14, 1, 10,91, 12,31, 
     1,73,  0,19, 16,97, 12,50,  7,74,  4,30, 18, 4,  9,69, 15,44, 17,98, 10,19,  6, 2, 19,90, 11,34,  3,46,  8,76, 14,81,  5,76, 13,40,  2,50, 
     2, 4, 19,60, 11, 5,  0,19, 18,49, 16,26, 13,18,  5,96,  7,37,  4,55,  8,83,  1,72, 14,76, 15,38,  6,95, 10,98,  3,65, 17,74,  9,80, 12,97, 
     0,16, 16,64,  1,20, 18,58, 10,99, 19, 4,  3, 9,  8,59,  9,29, 11,26,  2,23, 14,10, 15,15, 17,21,  5,19,  7,98,  6,77, 13,80,  4,76, 12,25, 
    13,51, 15,33,  1,14,  5,63, 14,46, 10, 6,  6,53, 12,27,  4,99,  0,87,  8,15,  7,77, 11,66,  2, 3, 19,51, 17, 3,  9, 9, 16,34,  3,77, 18,54, 
     9,67, 12,98, 10,57,  5,74, 16,47,  7,12,  6,92, 19,30,  8,45,  0,39, 13,36,  4,12,  1,86, 14,88, 17,15,  2,89, 11,96, 18,69,  3,43, 15,72, 
    17,84,  7,67, 16,30,  8,69, 18, 6,  9,87,  5,58,  1,37, 19,87, 13,12,  4,90, 14,38, 10,47, 15,99,  0, 8,  2,30,  3,48, 11,30,  6, 7, 12,98, 
     4,92,  3,74, 18, 8, 12,86,  9,36,  6,78, 11, 6, 14, 2, 10,42,  1,14,  7,72, 17,94,  8,83,  5, 4, 16,50,  0,90, 19,80, 15,27, 13,45,  2,71, 
    19,78, 13,41,  9,17,  0,86, 14,83,  8,71, 12,54, 10,80,  5,68,  7,16, 16,88, 17,40, 15,88,  3,11, 11, 9,  6,54,  4, 3, 18,24,  2,81,  1,18, 
    19,72,  7,64,  9,68, 17,46, 13,29,  5,92,  2,74, 15,68,  3,12,  1,68, 14,87, 16,80, 18,81,  0,44, 10,76,  8, 9,  6,26, 11,31,  4,37, 12,82, 
     7,44,  0,53, 17,86, 13,67, 12, 4, 14,14,  1,47,  8,19,  6,50, 18,68,  2,65,  3,22,  9,97,  5,11, 10,34, 15,75, 19,11, 11,14,  4,78, 16,80, 
     9,63,  7,48,  8,63, 19,43, 12, 9,  3,82,  1,13, 14,48, 18, 3, 11,69, 16,47, 13, 3,  4,56,  5,32, 17,41,  0,10,  2,48, 15,16,  6,98, 10,59, 
     6,42,  8,91, 18,11,  7,37, 16,97,  1,40,  5,35, 14,96,  3,95,  9,26, 19,80,  4,61, 11,69,  2,16, 17,59, 12,65, 15, 3,  0, 5, 10,85, 13,48, 
    19, 3,  3,22,  2,12,  8,63,  5,20,  7,83, 14,56, 17,76,  0,47,  1, 9, 13,42, 15,35, 12,23,  4,11,  9,20, 10,28, 18,51, 11,78, 16,35,  6,57, 
     3,13, 12,76,  4,20,  8,67, 10, 6,  1,19, 16,74,  0, 1,  9,13, 17,48, 14,44, 13,12, 19,46, 18,94, 15,26, 11,43,  6,37,  7,73,  2,48,  5,29, 
    13,25, 12,49,  0,51,  5,36,  8,50, 18,15,  7,66,  1,17,  3,43,  4,53, 16, 3, 11,47, 10,12, 15,74,  9, 8, 19,65, 17,29, 14, 8,  2,18,  6,36, 
     4,33, 16,14,  3,95, 19,48,  7,68,  1,24,  0,87, 11,43,  5,10,  6,40, 10,32,  8,43, 17,66,  9,42, 13,29, 12,20,  2,28, 18,39, 15,77, 14,41, 
     4,73, 15,66, 16,67,  8,67,  9,72, 17,63,  5,81, 11,84, 18, 7,  0,52, 14, 9,  6, 9, 10,35,  2,11,  3,37, 13,55, 12,96,  7,84, 19,97,  1,32, 
    15,67,  5,28, 16,85, 12,58,  1,51, 17,41,  0,64, 18,40, 10,54, 19,31,  8,47, 14,16, 11,43, 13,59,  2,67,  9,33,  4,15,  3,91,  7, 9,  6,52, 
     5,29,  4,62, 15,23,  9,60,  2,68,  7,20, 19,20, 14,32,  8,50, 16, 9, 11,22, 12,56,  0,94, 17,27,  6,41, 13,77,  3,19, 18,54,  1,87, 10,96, 
     3,69, 14,66,  5,86, 13,43, 15,52,  0,39,  4,27,  8,63, 19, 5, 16,70,  7, 2,  6,10, 17, 2, 12,13,  1,44, 10,92, 11,71,  2,14,  9, 4, 18,35, 
     2,65, 17,78,  7,26,  0,29, 14,76,  8,20,  1,64, 12,33, 18,91, 13,47, 10,89,  6,49, 15,50,  4,41,  3,61,  5,22,  9,99, 19,32, 16,12, 11,43, 
    18,78,  7,84, 14,81,  2,62,  1,42, 19,11,  6,65,  8,83, 11,75, 13,12, 10,46, 15,46,  3,61,  0,98, 12,49,  4,35, 17,39,  5,27,  9,23, 16,56, 
     2,49,  5,37,  8,37, 19,95,  7,91, 15,68,  4, 8, 16,18, 13,54,  6,23, 12,94, 18,62, 17,66, 14, 3,  0,21, 10,62, 11,72,  3,28,  9,91,  1,83, 
     5,21, 14,73, 18,45, 13,22, 15,89,  0, 4, 12, 4,  7, 1,  8,71,  6,44,  1,35,  3,99,  2,49, 10,19,  9,25, 19,77, 11,14,  4,90, 16,19, 17,85, 
    10,76, 15, 8,  9,68, 14,13, 11,98,  8,88,  7,50,  1,17,  3,73, 17,18, 18,22,  0,63,  5,73,  4,56, 16,61, 19,25,  2,71, 12,15, 13,50,  6,23, 
    13, 1, 14,99,  9,64, 11,51, 19,77,  6,12,  4,26,  7,27,  5,31, 12,23,  0,90, 18,65, 17,16,  8,91,  2,47,  1,35, 16,39,  3, 9, 10,64, 15,91, 
    11, 5, 18,42, 19, 3, 17,15, 14,74,  9,45,  4,34, 16,49,  8,45,  6,54,  0,86,  2,28,  7, 6, 15,77, 12,76, 13,59,  5,63,  1,21, 10,50,  3,93, 
    18,26,  5,94,  4,33,  0,20, 14,27,  1,83, 12,55, 19,93,  3,41, 16,62, 11, 6,  7,33, 17,47, 13,84,  8,25,  2, 5,  9, 8, 10,14, 15,26,  6,96, 
     5,90, 17,99, 14,19, 10,74,  8,15,  6,82, 18,55,  9,91,  0,53, 13, 8,  1,19,  2, 9, 19,60,  4,10,  7, 5, 11,37, 16,95,  3,19, 12,63, 15,57, 
     9,40,  7,19, 13, 3, 16,44,  3,30, 19,84, 14,49,  6,22,  5,15, 11,93,  1, 8, 18,90,  4,48, 12,87,  8,34,  0,42,  2,78, 10,76, 15,82, 17, 7, 
     1,47,  0, 4,  5,35, 19,15, 10,32,  2,64,  7,75,  9,63,  8,97,  4,51, 18,65, 14,41, 17,46, 11,64, 12,21,  6,50, 16, 3,  3,40, 15,35, 13,65, 
     3,89,  6,23,  1, 9,  7, 7,  9, 8, 14,77, 10,94,  0,82,  5,32, 13,93, 19, 4,  4,73, 12,94, 17,66,  8,82, 16,28,  2,38, 18,44, 11,26, 15, 5, 
    10,30,  1,68,  8,69, 18,57,  4,82,  6,75, 13,10, 12,37,  7,35,  0,95,  9,86, 14,25,  3,62, 11,81, 16,75, 19,59,  2,96,  5,84, 15,81, 17,99, 
    17,91,  4,61, 16,44,  7,11, 10,21, 14,14, 19,62, 12,16,  8,36,  1,51, 15,56,  3,77, 13,79, 11,53,  0,37,  6,48,  2,28, 18,61,  9,52,  5,72, 
    14,51, 16,18, 19, 9, 13, 6, 10,53,  8,72,  0,48, 11,72,  4,64,  6,49,  2,57,  7,42,  3,80, 18,92, 17, 9, 15, 6,  9,84, 12,58,  1,50,  5,79, 
     2,67,  8,16, 19, 5,  5,30, 12,12,  3,11, 11,26, 13,74,  9,36, 17,23,  7,50,  4,13,  6,59,  0,37, 15,79, 14,68, 16,20, 10,66,  1,87, 18,52, 
    14,52,  1, 4, 12, 6,  2,27,  0,35,  5,46,  9,82,  7, 2, 17,59, 16,71, 10,84,  4,15,  8,40, 13,77, 11,78, 18, 2, 15,62,  6,72, 19,79,  3,71, 
     1,76, 15,25, 18,40,  8,15, 16,83, 10,39, 14,66,  7,79, 12,78, 13,30,  2,18,  5,29,  9,56, 19,27,  0,44, 11,78,  6, 1,  4,69,  3,34, 17,18, 
     1,51, 19,89,  5,99,  4,54, 15,99,  6,76, 14,11,  8,92, 12, 4,  3,25, 18,66, 13,41, 11,92,  0,36,  2,55, 16,32, 10,47,  7, 1, 17,45,  9,91, 
     4,81, 15,87, 17,28,  6,15, 16,43,  5, 4, 10,67,  7,12, 18,95, 12, 4, 19,66,  9,59, 14,34, 13, 9,  0,25,  3, 2,  8, 6,  2,87, 11,85,  1,35, 
     2, 6, 14,11,  5,50, 11,84, 12,62,  7,94, 16, 2,  9,97, 13,52, 18, 4, 19,92,  3,44,  8,51,  6,23,  4,80, 10,35, 17,16, 15,46,  1, 5,  0,67, 
     6,62, 14,97,  8,52,  5,99, 11,83, 18,53,  2,57,  4, 8,  1,69, 15,37, 13,72,  9,95,  3,61, 16,76, 19,72, 12,54,  7,15,  0,91, 17,50, 10,36, 
    18,43,  5,33,  0,24, 15,84,  3,29,  4,32,  1,30, 17,42,  9,79,  7,58, 14,46, 16, 7,  8,89,  6,71, 11,91,  2, 9, 12,70, 19,40, 13,33, 10,22, 
     0,31,  1,23,  3,36, 18,37, 13,80,  8, 6, 17,57,  4,86,  2,52,  5, 1, 16,95,  6,68,  7,87, 19,18,  9,56, 15,28, 12,66, 10,88, 11,45, 14,20, 
    19,68,  1,14,  3,43, 15,90,  8,44, 13,21, 14,28, 18,97, 11,98,  2,48, 12,95, 17,84, 16,70,  9,38,  4,92, 10,56,  5,55,  6,53,  0,15,  7,21, 
     5,91,  1,56,  9,97,  0,46, 16,18, 10,64,  7,94, 11,99, 18,81,  4,62, 15,56,  3,53, 14,98, 12,32,  8,51, 19,24,  2,26,  6,81, 17,24, 13,26, 
     6,99,  1,46, 19,22,  3,25,  9,12, 17,28, 10,29,  2,87, 12,36,  0,38, 15,42,  8,35, 11,30, 18,57,  7,85, 14,97, 13, 2, 16,49,  5,83,  4,28, 
     0,13,  5,93,  4,59,  2, 3,  3,51, 15,74, 10,84, 19,83, 11,74, 17,89, 13,70, 14,45, 16,59,  6,54,  8, 1, 18,60,  9,78,  7,59, 12,46,  1,91, 
     1,47, 12,35,  7,25, 17,54, 10,50, 16,31,  4,72,  8,84,  6,69, 13,90, 14,55, 18,64,  5,89, 15,10,  0,51, 11,81,  3,58,  2,47,  9,36, 19,13, 
     8,82, 13,84,  3,25, 10,16,  6,91, 18,78, 19,78,  5,48,  4,72, 14,47, 15,60,  1,36, 11,27,  0,42,  7,34, 17,35,  2,85,  9,33, 16,70, 12,57, 
    12, 4, 13,97, 15,59,  8,96, 10,31,  4,72,  1,46,  3,47,  0,56,  9,64,  7,51,  2,77, 16,73, 19,67, 11,81, 14, 2,  5,78,  6,22, 18,48, 17, 9, 
     9,90, 16,21,  8,81,  1,42, 12,63,  5,98, 15,84, 18,29,  7,54,  4,91,  3,75, 14,90,  2, 1, 13,89, 10, 6,  0,42, 11, 2, 17,12, 19,33,  6,66, 
     4,80,  9,88, 16,57, 12,30, 19,94,  5,95, 15,58,  3,89,  0,47,  1,17, 17,24, 10,98, 18,62,  6,91,  2,49, 11,65,  7,34,  8,91, 13,94, 14,13, 
    10,41,  8,94, 14, 9,  9,95,  2,77,  3,87,  4,90,  0,86, 18,21,  1,13, 16,60, 17,36,  6,22,  7,71, 15,18, 12,15,  5,32, 19,14, 13,11, 11,54, 
     2,47, 14,18,  1,93,  0,57,  5,74, 19, 2, 15,58,  4,69,  7,10, 12,41,  3,80, 13, 3, 10,72,  6,60,  9,34,  8,60, 17,34, 16,32, 11,33, 18,89, 
     9,88,  4,31, 19,27, 12,88, 18,48,  6,27, 14, 5,  3,49,  8, 8, 11,67, 13,23,  5,48, 16,24,  7,89, 15,73, 17,76, 10,87,  0,55,  1,17,  2,63, 
    12,10,  0,83, 10,87, 19,46, 14,31, 17,79, 18,28,  3,15,  5,31, 16,83,  6,42,  7,40,  8,43,  9,60,  2, 5,  1,62,  4,48, 13,28, 15,13, 11,74, 
     9,73,  6,77,  0,94, 12,16,  3,89,  4,48, 19,93, 17,25,  5,76, 10, 4, 14,70,  7,66,  1,31, 13,63,  2,70, 18,91,  8,39, 11,67, 15, 3, 16, 5, 
    18,62,  5,93, 13,38,  0,65, 10,81,  8,45, 16,56,  7,69, 12,77, 14, 4, 17, 8, 15,66, 11,16,  3, 6,  6,76,  2,79,  1,24, 19,96,  4,80,  9,38, 
    17,95,  4,26, 18,84,  1,96,  7,91, 16,63, 13,48,  6,39, 19,28,  5,48, 14,83, 15,74, 10,84, 11, 2, 12,76,  0,45,  3,98,  9,70,  8,88,  2,68, 
     3,10, 17,96,  5,66,  9,79, 19,94, 18, 8,  0,19, 15, 9,  8, 8, 13,74, 11, 1,  1,30, 12,93,  4,91,  2,11, 10,57, 16,76,  6,75, 14,87,  7,40, 
     7,17, 13,98, 10,75, 17,57, 14, 1,  0,61,  2,72, 16,82, 18,60, 19,87,  3,94,  5,49, 11,64,  4,83,  9,42, 12,63, 15,29,  6,67,  8,99,  1,76, 
     1, 6,  5,92,  0, 9, 13,60,  4,24,  6,20,  3,78, 12,46,  7,16, 14,52, 16,78,  8,30, 11, 3, 15,63, 17,13,  9,68,  2,73, 10,55, 18,94, 19,65, 
    13,21, 12,93,  3,18, 14,34,  5,82, 19,51, 16,49, 10,70,  2,51,  0,58, 15,57,  8,80,  6,45, 17,69,  7,50,  1,94,  4,10, 11, 2, 18,71,  9,40, 
    16,17, 18,78, 11,56,  4,76,  8,36, 17,26,  3,87, 14,74,  7,35,  1,39, 13,32, 10,82,  0,84, 12,95,  2,41,  6,43,  9,50, 15,41, 19,46,  5,53, 
    12,67,  8,62,  4,71,  6,12,  0,23, 15,81, 19,65,  5,40,  9,59,  1,66,  3,78, 10,21,  2,48, 16,69, 18, 4, 13,95,  7,68, 17,36, 11,19, 14,51, 
    17,97, 14,84,  6,87,  8,95, 11,26, 13,14, 19,72, 12,24,  7,86,  4, 6, 16,45,  2,29, 15,19, 18,92,  3,80,  1,11,  0,52,  9,77, 10,89,  5,75, 
    14,20, 18,85, 13,48,  7,70,  4,31, 15,14,  3,81, 11,21, 19,57,  5,98, 10, 9,  2,23,  1,16,  0,46, 16,44,  6,16,  8,41, 17,17, 12,80,  9,13, 
     7,68, 16,30,  5,86, 13,54, 18,80, 19,78, 11,16,  1,89,  4,71,  8,97,  3,80,  9,69, 15,38,  2,77,  0, 3, 10,30, 12,61, 14,82,  6,88, 17,85, 
    17,97,  2,46,  8,49,  4,77, 19,27,  0,96, 14,82,  9,63, 18,21, 13,83,  5,51,  6,77, 12,80,  7,88,  3, 7, 16,97, 11,73,  1,58, 15,36, 10, 2, 
    10,44,  8,91, 19, 2,  2,94, 11,81,  5,51, 15,88,  9,43,  4,20,  0,79, 12,47,  1,62, 17,66, 18,41,  3,24,  7,60, 13,12,  6, 3, 14,77, 16,81, 
    13,43, 15,65,  4,68, 12,61,  1,69, 17,26, 18,47,  3,87,  2,53,  6,81,  7,59, 16,81, 11,80,  5,63, 14,31,  0,21,  8,46,  9, 3, 10,82, 19,64
  };
  // Taillard 100x20 instance 3
  const int tai_100_20_3[] = {
    100, 20, // Number of jobs and machines
    17,17, 16,25,  7,65,  0,31,  2,80,  5,64, 13,30, 15,36,  9,99, 10,16,  3,32,  1, 3, 19,28, 12,79, 14, 1,  6,50,  4,94, 11,31, 18,87,  8,94, 
    12,71,  3,86, 19,16, 13,79,  2,92,  7,79, 16,63, 17,10,  6,47, 14,64,  9,56,  5, 4,  1,87,  0,16, 18,43,  4,70, 10,15,  8,27, 15,99, 11,37, 
    17,81,  0,32, 18,76, 10,80,  2,19,  1, 6,  6,37,  4,59, 14, 8,  8, 3, 12,41, 15,79, 13, 8,  3,83, 16,68,  5,53, 11,29,  7,61, 19,24,  9,53, 
     8,78, 14,99,  7,97,  0,20, 13, 3, 12, 1,  2,97, 10,92,  3,43,  9,11,  1,25, 17,31, 11,98, 16,73,  4,38, 19,71, 15,69,  6,71,  5,73, 18, 2, 
    13,91,  0,90,  7,97, 16,24,  6, 8, 12,72,  2,54,  4,67,  5,63, 11,39, 18,76, 14,12, 10, 1,  1, 7, 19,46,  8,14,  3,54,  9,66, 17,55, 15,42, 
    11,67,  1,13, 18,74,  6,38, 17,10, 16,67,  0, 6, 19,50,  7,72, 10,93,  3,25,  2,72,  5,66, 13,71,  4,18,  9,77, 14,27, 12,20,  8,97, 15,17, 
    19,84,  2,19,  4, 7, 11,40, 18,73, 14,89, 16,85, 10,78,  5,29,  3,89, 13, 9,  0,88,  7,43,  6,52, 12,36, 15,44, 17,77,  1,44,  9,82,  8,90, 
     4,27, 17,88, 19,59, 11,79, 13,98, 16,66,  0, 9, 10, 1, 18,35,  7,69,  5,29,  9,67,  6,60, 12,43, 15,21, 14,19,  8,76,  2,55,  1,77,  3,15, 
    12,44,  3,43, 11,67,  7,41,  9,90, 17,71, 19,38, 15,39,  4,77, 18,18,  0,12, 14,17,  1,10,  8,77,  2,49,  5,25, 13,85, 10,30,  6,14, 16,92, 
    11,57,  0,41, 15,51, 14,41,  8,17, 17,91, 12,82, 16,68,  9,76, 18,13,  1,93,  7,12,  2,90, 19,58,  6,52, 10,83, 13,68,  4, 3,  5,11,  3,40, 
     6,63,  8,59, 12,18, 15,99, 16,78,  4, 5, 19,15,  2,71, 18,59, 11,21,  0,58, 10,29, 14,59,  3,98,  9, 2,  7,18, 17,87,  5,55, 13,83,  1,85, 
     9,54,  1,57,  3,51, 14,25, 13,57,  7,46,  8,93, 17,58, 19,20, 12, 4,  4,19, 18,91,  5,25,  2,88, 11,94,  6,52, 10,23, 16, 4,  0,27, 15,66, 
    18,73,  1,84,  9,85,  3,50,  4,61,  0,40, 14,93,  2,17, 15,86,  8,19, 16,49, 10,98, 13,74, 17, 6,  5,27,  7,91, 11,58, 19,59, 12,22,  6,15, 
     9,11, 12,56, 10,39, 14,20, 13,79, 17,55, 18,18,  4,40, 11,74,  3,91,  6,95,  1,65, 15,13,  7,26, 19,40,  0,89, 16,25,  5,33,  2, 3,  8,21, 
     3,51,  8,37,  9,49, 10,20,  5,52,  2,57, 19,17,  0,42, 16,50,  6,74, 17,33, 11,38, 15,16,  4,21,  1,35,  7,85, 18, 7, 12,66, 13,68, 14,66, 
     7,47, 16,27, 10,86,  8,19, 13, 9,  3,23,  0,64,  5,32, 11,24, 17,14,  9,47, 15,81,  4,45,  1,84,  6,10, 12,25,  2,74, 19,81, 18,98, 14,79, 
     0,94, 18,46,  9,63,  6,64,  7,72,  3,70,  2,86, 11,10, 16,11,  4,99, 14,93, 17,90, 19, 4,  5,75, 10,87,  8,35, 13,46, 15,27, 12,94,  1,83, 
    16,53,  9,33, 15,56,  5,19,  0,50,  7,82,  8,20, 18,49, 13,73,  2,21, 17,28, 19,40, 10,49,  4,83, 14,82, 12,16,  6,97, 11,86,  1,46,  3,45, 
     8,26, 10,29, 14,35,  7,31,  0,71, 19,78,  3,38,  9,11, 15,26,  5,12, 12,69, 13,64, 18, 1, 16,96, 17,36,  2,93,  6,52, 11,30,  4,22,  1,25, 
    12,12,  9,98,  5,14,  1,38, 10,94, 18,77,  2,52,  7,95,  8,20, 11,77, 14,42,  4,28, 15,69, 17,88,  3,29, 13,18, 16,95, 19,73,  0,16,  6,34, 
     7,22, 15, 5,  8,31, 17,25,  6, 8, 14,38, 19,17, 18,17,  5,13,  9,59, 12,36,  2,88,  0,57,  4,19,  1,57,  3,65, 13,88, 11,23, 10,52, 16,40, 
     4,19, 10,34,  2,49, 13,46, 11, 2, 18,45,  6,82, 19, 7, 16, 7,  8,50, 15,81, 14, 1, 12,99, 17,91,  9,54,  5, 4,  1,87,  3,29,  7,63,  0,45, 
    13,36,  9,38, 16,93, 17,27,  4,28, 10,81,  5, 2, 19,66,  3,28, 14,46,  0,96,  6,55,  8,99, 12,90,  7, 5,  2,37, 11,18, 18,55,  1,78, 15,53, 
     3,89, 16,93, 13,40,  1,76,  6,29,  7,61, 12,13,  9,95, 17,28, 11, 3, 18,89, 14,28, 19,13,  4,63,  8,32,  2,50,  0,24, 15,63,  5,76, 10,47, 
     2,44,  3,48, 13,32, 10,61, 15,85, 14,34, 12,21,  1,52, 17,66,  4,47,  7,30, 11,49,  0,88, 18,95,  6,94, 16,59,  9,77,  8, 5, 19,79,  5,27, 
    12,19, 19,64, 18,27,  1,30, 14,27, 16,57,  0,96, 10,36,  4, 8,  5,77,  3,59,  9,36, 13,13,  8,96,  7,88, 11,47,  2,80,  6,32, 17,43, 15,93, 
     9,73, 11,75, 14,37, 16,70, 13,90,  0,34, 12,87, 10, 6,  4,59,  2,79, 15,11,  5,50, 17,46, 19,12,  6,38,  1,55,  7,15,  3,18, 18,80,  8,98, 
    17,70,  6,90, 16,89,  7, 4, 19,77, 12,31,  0,43, 18,87, 13,52,  2,63,  1,75, 11,21,  8,30, 14,68,  5,81,  3,89,  9,68, 15,44, 10,63,  4,51, 
    12,70, 11, 9,  6,52,  5,55,  7,92, 19,60,  2,39, 17,13,  3,68, 15,72,  9,80, 13,45, 14,28,  8,69, 10,48, 16,29,  1,42,  0,55, 18,44,  4,88, 
     7,91, 12,28, 10,68, 13,49,  5,94, 11,86,  8,43,  0,43,  3,75,  1,98, 19,88,  9,67,  6,63,  2,34, 14,61, 15,85, 18,32,  4,96, 16,45, 17,51, 
     3,90, 12,97,  9,53, 10, 9,  2,63,  0,92,  1,18,  6,68, 17,55, 15,10,  4,78, 11,34, 13,57, 16,13, 18,64,  8,59, 19,56,  7,76, 14,41,  5,56, 
    16, 9, 18,44, 10,59, 17,61, 19, 6,  8,66, 15,56,  7,41, 11,97,  6,41, 14, 1,  4,21,  2,43, 12,76,  1,20,  9,73,  5,88, 13,98,  0,56,  3,26, 
    14,90, 18,60,  1,40, 17,78,  8,52, 12,10, 13,50, 15,61,  5,95,  3,28,  9,38,  7,24,  6,51, 10,96,  2,90, 19,18,  0,77, 16,11,  4,43, 11,93, 
     0,47,  8,30,  2,13, 12,63, 15,93, 16,42,  7,32,  1,12,  4,66,  9,94,  5,89, 11,25, 13,16,  6,96, 18,87, 14,39, 19,58, 17, 8, 10, 2,  3,17, 
    12,50, 11,62,  5,91,  8,25,  2,19, 16,73,  9,98,  4,63, 15,95, 10,57,  7,67,  1, 7, 13,76,  6,79, 14,90, 18,75,  0,42, 19,66, 17,90,  3,41, 
    12,18, 19,99, 10,89, 11,43, 17,49,  4, 8,  5,44, 18,33, 14,91,  0,39, 16,36,  9,72,  1,27,  7,70, 15,66,  6,82,  8,94,  3,46, 13,18,  2,98, 
    13,45,  3,13, 11,26, 16,14,  4,29,  8,90, 17,60,  0,84,  6,83,  2,41,  7, 7, 10,24,  5,73,  9,58, 15,91,  1,47, 12,82, 14,81, 19,67, 18,15, 
    10,52, 13,79, 19,18,  8, 3,  0,29,  9,88,  7,97, 15,55, 18,55, 17,15,  4,87,  1,17, 12,43,  3,58, 11,69, 14,66,  5,31,  6,43, 16, 8,  2, 2, 
    19,87,  8,51, 10,65,  3, 5,  7,34, 15,58, 14, 9,  5,10,  0,30, 11,87,  2,62,  9,89, 17,78,  1,37, 12,94, 16,40,  6,50, 18,83,  4,74, 13,83, 
     2,35, 15,34,  4,44,  0,65, 13,37, 10, 5, 19,51, 18,26, 12,65,  9,16,  7,90,  5,40, 14,76,  1,54,  8,72, 17,27, 11,37, 16,75,  6,77,  3,89, 
    14,15,  8, 1, 17,43, 15, 7, 11,64,  1,50,  5,26, 10,29,  6,13,  9,76, 19, 9,  7, 5,  2,85,  4,19, 18,23, 13,95, 16,76,  3,69,  0,48, 12,26, 
     4,84,  3,42,  5,99,  6,25,  9,75, 18,93, 19,76,  2,56, 11,23, 15,87, 17, 8,  0, 2,  8,60, 16,79, 12,30,  1,16, 13,61, 14,16, 10, 1,  7,31, 
    12,90,  8,41, 17,20, 19,50, 10,38, 13,76,  5,68, 14,66,  7,84,  6,77,  1,30,  2,55, 18,50,  3,40, 15,99, 11, 5,  9,27,  0,10,  4,32, 16,24, 
    18,33,  4,79,  0,55,  8,69, 13,53,  6,50,  3,81,  2,28,  9,91, 17,55,  1,50, 11,29, 15,27, 12, 9, 16,61, 10,27,  5,36,  7,43, 19, 5, 14,56, 
    10,72, 13,36,  7,27,  0,16, 15,50,  6,82, 11, 8,  8,79, 14,80,  2,22,  5,63,  3,61,  9,25, 16,61,  1,71,  4,93, 19,44, 18,65, 17,72, 12,88, 
    12, 7,  5,18, 14,59, 18,44,  8,64,  0,94,  7,55,  2,20, 10,11, 16,77,  9, 3,  6,26,  1, 8, 17,21, 11,73,  4,80, 15,89, 19,53,  3,19, 13,95, 
     5,35,  2, 7, 11,98, 18,66, 12,16, 15,89,  0, 6,  3,24, 17,18, 19,39, 13,52,  9,49,  7,52,  6,26, 16,11, 10,73, 14,91,  1,69,  4,99,  8,79, 
     3,65,  1,24, 10,87,  9,85,  2,66, 15,99, 13, 5, 12,29,  5,98,  0,17,  7, 4, 19,48, 11,45, 17,26,  4,80,  8, 5, 18,56, 14,53,  6,76, 16,41, 
     8,39,  3,34, 18,47,  9,60, 15,21,  0,11, 13,46, 10,14, 11,59, 19,51, 14, 7, 16,58,  7,49,  2,57,  1,71, 12,57,  4,47,  6, 1, 17,85,  5,72, 
    17,93,  2,88, 10,24,  9,32, 14,18, 16,44,  6,48,  1,18, 15,80,  8,67, 13,10,  7, 9,  5,16, 11,35,  0,16,  4,10, 12,29, 18,71, 19,89,  3,87, 
    10,36,  9,29, 12,35,  5,78,  7,17,  4, 7, 19,38,  0,50, 14, 6, 11,15,  2,14,  6,30,  1,36,  3,18, 15,59, 16,63, 13,92, 18,26,  8,46, 17,23, 
     5,90,  9,11, 14,87,  3,34, 12,20, 17, 1,  4,57, 11,30,  2,19, 19,25,  6,22, 15,32, 10,86,  0,31, 18, 4,  7,54,  1,32,  8,17, 16,24, 13,67, 
     2,91, 13,61, 15,53,  4, 1, 10,67,  5,53,  9,86,  0, 8, 17,12, 11,51,  7,90, 18,73,  3,44, 16,12,  8,92, 14,58, 19,57,  6,63, 12,82,  1,68, 
    18,77,  6,48,  5,72, 19,89,  7,36, 16,23, 13,39,  4,45, 15,39, 14,85, 10,54,  8,69, 12,44, 17,92,  0,86, 11,42,  2,83,  9,85,  3,23,  1,58, 
     7,15,  1, 5,  2,67, 17, 9, 16, 7, 10,81,  9, 4,  6,86,  5,74, 15,49, 12,26,  8, 9, 14,27,  3,33,  0,51, 19,95, 13,32, 11,24,  4,31, 18,58, 
    14,30,  8,90, 10,27, 15,17, 17,85,  4,27,  9,92,  7,11,  1,15,  3,61, 19,18,  0,34, 13,96,  2,56, 16,34,  5,44, 11,32,  6, 1, 12,16, 18,55, 
    18,21,  4,95,  5,81,  2, 1, 11,65, 17,69, 19,24, 14,47, 16,92, 15,25,  1,22,  7,60, 13,62,  9,97,  3,78, 10,63,  8,18,  0,35, 12,80,  6,55, 
    13,96, 14,27,  0,66,  8,52, 19,16, 15,20, 16,24,  6,59, 17,75,  4,64, 18,26, 10,88,  9,57,  5,68,  2,60, 11,12, 12,54,  3,99,  1,51,  7,71, 
    11,79, 15, 6, 19,41,  8, 8,  6,93, 12,46,  3,69, 18,81, 13,61,  4,44, 10, 2, 14,69,  5,72,  9,21,  7,55, 17,69,  2,13, 16,69,  1,80,  0,91, 
     1,82, 10,99,  4,92, 13,53, 14, 5,  9,33,  7,59, 19,32,  3,93, 17,13,  0,64,  8,19, 18,96, 11,12,  2,66,  5, 4, 15,83,  6,65, 16, 3, 12,79, 
    18,16,  2,62,  4, 1,  3,41,  5,84, 19,61, 16,31, 10,63,  6,10, 17,10,  8,14, 13,75, 12,14,  0,63,  1,53,  9,61, 15,41, 14, 7, 11,57,  7,15, 
    18, 5,  7,83, 10,25, 11,37,  6,81, 16,42,  5,20,  9,22, 13,50,  4,40,  1,77, 19,76,  3,58, 14,88, 15,77, 17,69,  0,63,  8,56,  2,49, 12,41, 
     9,43,  1,16, 10, 1,  0,56, 11,38,  8,41, 19,78,  7,81, 15, 5,  6,46, 12,10, 13, 6, 16,31,  4,44, 17,22, 18,78,  2,93, 14,42,  3,21,  5,43, 
     5,27,  9,26, 10,32,  7,20,  0,20,  4, 5, 15,43, 13,63, 16,23,  2,29, 19,45,  3,79, 12,68, 11,73, 18, 1, 14,10,  1,61,  8,56, 17,95,  6,36, 
    10,88,  3,21, 15,86, 17,92,  2,89,  6,30, 14,44, 19,25, 12,99,  8,91, 16,21, 13,45,  0,82, 11,41,  4,76,  1,33,  5,77,  9,49, 18,63,  7,37, 
     1,33,  0,54,  7,79, 19,56, 16,54, 17,75,  5,79,  8,99, 18,38, 15,13, 12, 2,  3,53, 11,89,  4,82, 10,53, 13,33,  6,43, 14,73,  2,25,  9,14, 
    16, 7,  2,43,  8,70,  5,22, 14,54,  9,81,  1,44,  4,94, 12,95, 10,29, 15,14, 13,50, 17,98,  7,18,  3,50, 19,96,  0,74,  6,66, 18,38, 11,49, 
    18,79, 12,40,  1,71,  3,39, 14,13,  2,19, 11, 1, 10,82,  0,58, 13,26, 15,44,  8,18,  7,94,  5, 8,  9,68, 19,90, 16,39,  6,47,  4,43, 17,80, 
    12,82, 10, 1, 19,76,  2,22,  9,17, 16,15,  6,64, 17,71,  7,22, 15,79,  3,89,  4,80,  5, 7,  1,78, 14,87, 11,88, 18,22,  0,59, 13,75,  8,24, 
    12,56,  9,93,  8,63,  6,23,  7,31,  0,90,  1,46, 11,83, 10,21, 18, 4,  3,53, 14,99, 13,65, 17,99, 16,58,  5, 5, 15,33,  2,17, 19,26,  4, 7, 
    13,35,  9,44,  8,10, 11, 5, 10,40, 15,66,  0,13, 18,20,  1,25,  5,95,  7,88,  4,32, 17,45,  2,11, 12,20, 16,61, 14,36,  6,45, 19, 5,  3,56, 
     2,41, 12, 6,  6,77,  4,69, 19,83,  7,17, 10,22,  1,32, 16,58, 17,63, 18,59,  3,31, 15,94, 11,90, 13,20,  8,83,  9,14,  0,67, 14,62,  5,62, 
    17,36, 11,81,  3,70, 15,20,  5,60, 13,22, 16, 8,  9,31, 14,53, 10,67,  6,66,  2,75,  0,22, 19,30, 12,47,  8,69,  4,68, 18,77,  7,10,  1, 4, 
    19,21,  6,97,  3,71,  5,13, 16,85, 14,95, 10,27,  4,10,  1,24, 11,43,  7,81,  9,88, 12,72, 17, 5, 15,51, 18,75,  8,44, 13,49,  0,43,  2,26, 
    14,69,  6,93,  4,66,  0,12,  2,81, 12,94, 10,61,  8,56, 15,56,  7,62,  3,25, 16, 2, 19, 5,  1,87, 17,75,  9,14, 13,14,  5,45, 11,30, 18, 8, 
     2,80,  1,21,  6,94,  7,86, 18,54, 16,70, 15,83, 14,39,  4,54, 11,76,  8,50,  9,18, 19,15,  0, 4, 10,34, 13,12,  3, 9,  5,47, 17,31, 12,65, 
     3,77, 11,87, 15,97, 19,90,  7,25,  2,77, 17,88, 18,76,  8,69,  4,15, 14,49,  1,27,  6,75, 10,90, 13,32,  9,26, 16,67,  0,82, 12,59,  5,72, 
     9,85, 19,40,  8,48, 10,64, 17, 8,  6,79,  4,96, 15,70, 13,25,  1,30, 14,75, 16,86, 11,72, 18,49,  5,74,  0,55,  7,87, 12,34,  3,98,  2,46, 
     7,87,  2,75,  1,55,  3,34, 11,62, 15,31,  0,53,  9,13, 14,63, 10,14, 13,20, 16,12, 17,14,  6,48, 19, 4, 12,64,  5,17, 18, 5,  4,85,  8,41, 
    17,55, 13,74,  9,15,  2,39,  3,64,  8,71,  5,18, 10,60, 15,28, 16,82,  6,93,  4,68,  1,75,  7,56, 19, 9, 11, 9,  0,20, 18,61, 14,78, 12, 5, 
     2,23, 13,66, 14,25, 10, 2, 15,13, 18,72,  1,51, 11,81, 16,47, 19, 6,  8,42, 12,44,  7,88,  0,36,  3,93,  5,21,  6, 6,  9,62, 17,18,  4,38, 
     0,84, 17, 1,  5,70,  9,63,  2,70,  8,22,  4,98, 15, 4,  7,85, 14,29,  3,81, 12,26,  6,49,  1,62, 10,49, 13,66, 16,41, 11,31, 18,51, 19,23, 
     8, 9, 11,20,  0,60, 15,22, 13,29, 14,89,  4,36,  7,51, 19,97, 12,39,  1,58,  3,50,  9,48, 10,94, 17,35,  2,95, 18,37, 16,79,  5,71,  6,12, 
     7,78,  8,95, 18,42, 12,60,  6,62, 14,99, 13,31, 16,94,  3,78, 10,27, 15,23,  5,60,  9,10,  1,80,  2,83, 11,54, 19,96, 17,15,  4,50,  0,64, 
    16,32, 15,59, 18,93, 11,95,  2,61, 14,19,  8,46,  4,75,  1,69,  9,76, 19,96,  3,50, 10,10,  7,69,  6,10, 13,98, 17,60,  0, 1,  5,81, 12,79, 
    16,23, 11,64, 19,70, 18,35, 12, 6,  0, 8,  7,97,  4, 7,  6,56, 13,92, 10,11, 15,50,  8,39,  1,72,  2,25,  5,85,  3, 4, 14,59,  9, 2, 17,27, 
     7,46, 15,90,  5,89,  2,66,  6,87, 13,35, 18,83,  0,90,  3,93, 12,54,  8,10,  9,22, 10,18, 17,97,  1,19, 14,94,  4,60, 16,90, 11,83, 19,41, 
     2,54, 17,53,  9, 4,  8,54,  5,73,  4,18, 12,26,  1,58, 18,44, 11, 1,  0,49, 15,95, 16,91, 14,38, 10,93,  3,29,  7,70, 19,14, 13, 6,  6,51, 
    16,57, 19, 4,  0,21,  2, 5, 14,64,  5,71,  9,67, 12,24, 18,39, 13,73,  3,98, 10,12, 17,34, 15,20,  7,31,  6,12, 11,40,  8,75,  1,22,  4,65, 
    14,63, 17,83, 16,29, 18,84,  0,25,  6,12, 13,81,  9,89,  3,44,  4,23, 19,66, 10,31,  1,29, 15,64,  2,67,  8,56, 11,34, 12,97,  7,27,  5,71, 
     6,99, 15,28, 17,73, 11,10,  1,85, 16,56,  5,56,  9,10, 13,30, 10,82,  4, 2,  2,45,  8,16, 12,36,  7,89, 14,27,  3,34, 19,85,  0,16, 18,75, 
     8,53, 19,33, 15,16, 18,81, 16,54, 14,15,  7,67, 17,46,  3,98,  5,72, 13,65,  2,42,  1,13,  9,40,  0,56,  6,43, 10,57, 11,56,  4,77, 12,94, 
    19,38,  8,83, 13,55,  0,80, 18,47, 16,28, 15,82,  5,82, 11,46,  6,89,  9,22, 12,69,  4,44,  2,84,  7,70,  3,32, 10,21, 17,55,  1,52, 14,13, 
    19,40, 13,55, 17,54,  0,73, 16,94, 14,80,  9,61, 12,74, 18,92, 10,23,  5,18,  4,41,  2,46, 15,94,  8,73,  7,31, 11,33,  1,35,  3,32,  6,15, 
    17,71,  4,20, 15,38,  3,72, 16,45, 18,75,  8,28,  9,30, 10,52, 11,57, 14,26,  1,77,  6,72, 13,43,  0,62,  5, 7, 19,41, 12,21,  2,58,  7,21, 
     5,18,  9,56, 15,73, 19,17, 16,31,  1,49,  3,47,  0,66, 12,17,  6,75, 11,25, 17,38, 13,43, 10,95, 18, 4,  7,71,  2,26,  8, 5, 14,26,  4,28, 
     6,33,  3,62, 16,48, 12,21, 15,79,  4,48, 11,93,  8,29,  5,99, 10,98, 18,93,  2,36, 14,49,  9,42, 17,22, 19,63,  7,43,  1,27,  0,10, 13, 3, 
    13,85, 18, 4, 15,41,  2, 8, 12,78, 19,88, 14,82, 10,53,  6,25,  0,80,  1,32,  9,28, 17,75, 11,31,  7,19,  5,11,  3, 4,  8,92,  4,31, 16, 1, 
    11,96,  0,24,  4,47, 10,35,  7,36, 17,83, 16,99, 14,22,  2,91,  3, 1,  5,43, 15,33, 12,97, 18,50,  8,41,  9,78,  6,92, 13,92, 19,40,  1,45, 
     9,97, 19,62,  1,35, 15,42, 18,51, 12,14,  2,64, 13,10, 11,95, 16, 7,  7,38, 14,11, 10,35, 17,25,  4,77,  6,82,  0,79,  8,81,  3,17,  5,33
  };
  // Taillard 100x20 instance 4
  const int tai_100_20_4[] = {
    100, 20, // Number of jobs and machines
     1,91,  0,20, 11,60,  9,13, 19,54,  8,38,  6,69, 14,66, 17,78, 13,32, 15,47,  7,81, 10,96,  2,69,  5,74, 18,91,  4,73, 12,67, 16,89,  3,81, 
    15,64,  1,49, 14,88,  9,17, 17,30, 11,77, 12,97,  3, 5, 10,87,  7,99, 13,22, 19,42,  8,50, 16,27,  6,19,  0,55,  2,77, 18,78,  4,20,  5,56, 
    14,62,  9,62,  2, 5,  0,72,  3,96,  6,25, 18,57,  8, 4, 16,36, 19, 2,  7,51, 12,13,  5,80,  4,82, 10,49, 15,96,  1,27, 13,25, 11,83, 17,42, 
     4,84,  9,31, 11, 2,  8,31,  1,15, 18,63, 13,19, 16,38,  7,75, 12,35, 15,52, 10,37, 17,91, 14,34,  2, 7,  5,63,  3, 7, 19,11,  6,45,  0,68, 
    17,15,  9,75, 18,88, 14,47,  2,61,  0,91, 10, 7,  7,28, 16, 8, 11,96,  6, 4,  4,91, 19,22,  8,60, 12,55, 13,22, 15,36,  1,37,  3,43,  5,13, 
     8, 2, 11,41,  4,28,  7,90,  9,14, 16,71, 18,71, 15,63, 17,90, 19,44,  5,87,  6,72,  3,31,  2,57, 13,42, 12, 1, 10, 6,  0,74, 14,27,  1,86, 
    11,65,  1,56, 16,77,  3,30, 10,24,  0,59,  5,13,  6,47, 17,56, 18,51, 15,55,  7,11, 19,74, 13,85,  4,46, 12,14,  2,57, 14, 8,  9,36,  8,17, 
    13,40, 14,27, 17,70,  2,49,  5,97, 16, 8,  3,20,  6,11,  9,78, 15,47, 18,69,  7,58,  4,35, 11,20, 10,52,  8, 5,  0,56,  1,68, 19,44, 12,74, 
    11,13,  9,47,  7,69, 16,24, 10,89, 18,97, 13,51, 12,41, 17,29,  6,69,  0,60,  4,50, 15,83,  5,64,  2,86,  1,96, 19,58,  8,57,  3,60, 14,47, 
     0,23, 10,40,  7,84, 13,77, 19,60,  9,53,  2,48, 11,58, 15,14, 14,16,  8,20, 12,79, 17,88,  5,25, 18,29,  3,68,  4, 3,  1,85, 16,49,  6, 6, 
    17,14,  2,41, 15,11,  8,36, 12,62,  9,82, 18,55, 16,78, 13,39,  7,99,  6,93, 19,73,  5,93,  1,91,  3,36, 10,11,  4,78,  0,70, 11,70, 14,62, 
     8,84,  2,14,  1,38, 18,36,  4,68, 11,16, 10,92, 17,41, 14, 4,  9,47, 19,50, 13,88,  6,92,  5,29,  0,23, 16,19, 12,10,  3, 9, 15,24,  7,74, 
     2,93, 12, 8, 16,35,  5,11,  9,82, 14, 2, 18,41, 10,34,  1,22,  7,98, 17,72,  4,67, 13,98,  8,19,  6,16,  0, 7,  3,82, 15,67, 19,24, 11,53, 
    10,84,  8, 6, 19,73,  2,99,  1,69, 17,77, 12,25, 18,39, 13,27, 14, 8, 15,67,  4,38,  3,62, 11, 8,  9,35,  6,44,  5,45,  0,56, 16,46,  7,35, 
    18,26, 15,83, 19,13,  9,37,  7,71,  1,24, 12,20,  3,45,  2,33, 11,48, 17,75, 16,15, 10,29,  0,15,  5,44,  4,55, 13, 1,  6,21,  8,67, 14,27, 
     4,98,  8,22,  3,97,  7, 9, 18,55, 16,90, 11,51, 13,30, 10,48,  5,47, 15,48, 17,78, 19,20,  9,14,  2,21,  1,97,  0,69, 14,25,  6,55, 12,52, 
     7,44,  1,51, 17, 7,  0,59,  3,48, 14,86, 15,30, 18,99,  8,51, 13,47, 19, 1,  2,16,  6,75, 16,29,  9,64, 12,65, 11,94,  4,83,  5,61, 10,36, 
     8,23, 15,24,  7,60, 19,59, 18,77, 17,43, 16,20,  6,99, 11,28, 10,65,  3,85, 12,22,  9,94,  0,62,  5,24, 14,56,  1,75,  4,11,  2,48, 13,26, 
    19,88,  7,62, 17,75,  6,83,  1,71,  4,32,  0, 6,  8,89,  3,44, 11,30,  9,10, 12,35, 10,78,  2,40, 15,48, 14,82, 16,77,  5,73, 13,19, 18,86, 
    11,92,  8,76, 16,53, 19,85,  2,46, 10,42,  0,34,  9,85, 14,53, 17,20,  1,24,  3,15, 18,26, 13,11, 12,28,  5,96,  6,49,  4, 7,  7,33, 15,82, 
     5,31, 11,10, 18,19,  2,83, 10,10, 15,77, 16,95,  8,57, 12,49,  1,67,  0,34, 14,21, 19,27,  4,43,  7,56,  6,93, 13,47, 17,80,  3,28,  9,78, 
     1,55, 12,46, 13,33, 14,46,  9,50,  8,24,  7,66,  5,30, 17,88,  0,26, 15,79, 10,32, 18,67,  6,24, 11,20,  4,67, 16, 4,  3, 8,  2, 4, 19,31, 
    13,15,  2,30, 14,96, 17,50,  6,73, 10,42, 11,56,  0,67,  4,16,  7,37,  5,28, 18,14, 16,12, 19,17,  1,12, 15,89,  8,90,  9,92,  3,92, 12,42, 
    14,98, 15, 2,  1,61, 11, 9,  7,48, 13,69, 17,65, 12, 8,  9,82,  3,64, 10,61,  6, 5, 16,21, 18,97,  5,63,  8,85,  0,18,  2,39, 19,91,  4,64, 
    15,70, 12,51,  3,89, 13,76, 18,77,  5, 6, 14,22, 19,29, 17, 5,  1,36,  7,54, 16,31,  9, 6,  2,87, 11,84,  0, 3, 10, 5,  4,88,  8,35,  6,89, 
     3,56,  9,80, 19,14, 17,28, 15,14,  2, 6, 10, 6, 16,79, 12,84, 11,23,  7,76, 14,38, 18,28,  8,98,  1,98, 13,38,  5,57,  4,27,  6,62,  0,94, 
    12,92, 18,26,  8,24, 10,18,  9,30, 13,11, 19,62, 16,38,  4,52,  1, 3,  3,86, 15,17, 11, 2,  5,50, 14,87,  6,10,  0,37,  7,42,  2,30, 17, 5, 
     0,48, 10,89, 11,99,  5,49, 16,54, 15,57,  7,32,  3,86, 18,75,  4,64, 13,99,  1,60,  6,71,  2,52, 12,74,  9,18, 17,13,  8,59, 19,26, 14,59, 
     9,26,  7,38,  0,98,  3,29,  4,29, 15,53, 13,50, 17, 7,  2,81,  6,78, 10,85, 19,26, 11,27,  5,52, 12, 7,  1,94, 14,86,  8,54, 18,51, 16,17, 
     8,95,  3,25,  4,71,  7,16, 11,64,  6,23, 18,77, 14,29, 16,90, 19,55,  2,83,  1,18, 12,42, 15,78, 10,33, 13,12,  5,28, 17,97,  0,61,  9, 7, 
    11, 1, 14,54,  1,42, 15,78,  2,15, 10,71,  4,69, 16,10,  3,67,  9,27,  5,82, 12,59, 18,93,  7,87, 17,55,  8,61, 19,70,  0,58,  6,86, 13, 7, 
    13,42,  8,71, 18,94, 19,73,  6,58,  9,22,  5,42,  1,13, 16,56, 11,74,  0,12,  2,26,  4,70, 14,91, 15,68, 12, 1, 10, 2,  3,12,  7,91, 17,53, 
     0,67, 14, 2,  6,68, 19,89,  1, 4,  3,83, 16,63, 18,58, 10,46,  2,62,  9,99,  8,90, 11,91, 15, 9,  7,83,  4,15,  5,83, 13,47, 17,95, 12,42, 
     2,87,  3,27, 17, 7, 14,33,  5,92, 18,52,  1,82,  0,29,  8,88, 16,21,  7,45, 12,61, 19,34, 11,53,  9,26, 15,23,  4,69, 10,73,  6,87, 13,53, 
    18,46,  9,51, 16,57,  3,88,  2,71, 11,10,  4, 9,  5,45,  0,90, 12,16, 10,55, 15,91,  6,65,  8,36, 14,19,  7,70, 17,92, 19,16,  1,76, 13, 1, 
    18,43,  5,46,  7,63, 10,62, 12,72, 19,12, 16,98, 17,53, 11,57,  3,67,  8,45,  4,90,  0,83, 14,36, 15,54,  9,85,  6,29,  2, 6, 13,36,  1,32, 
    17,28,  7,65, 12, 7,  4,50, 15, 1,  6,61, 18,56,  5,21,  2,39, 16,57, 11,43, 19,34,  8,57, 10,39,  3,22,  1,80, 13,88,  9,66,  0,90, 14,20, 
    10,10,  6, 2, 18,11,  4,82,  9,56, 16,78, 14,75,  2,40,  7,34, 13,42, 11,51, 19,17,  1,62,  8,32,  5,88,  3,70, 12,50, 17,78,  0,39, 15,98, 
     3, 8,  1,26, 18,11,  5,29, 17,99,  4, 9,  2,58, 10,60,  7,52, 14,36, 19,14,  0,47, 13,70, 12,10, 16, 1,  9,66, 15,51, 11,96,  6,41,  8,73, 
    14,75,  4,89,  1,92, 12,16, 10,52,  3,98, 19,21,  7,50,  9,61,  8,22, 11,78, 18,51,  5,70,  2,41, 13,39,  6,19,  0,91, 17,62, 15,46, 16,39, 
    11,52,  3,91,  1,24,  0, 2,  7,43, 12,37, 16,11, 19,55, 14,51,  4,27, 15,28,  5,91, 10,45,  2,78, 17,29,  9,66, 13,87,  8,86, 18,16,  6,20, 
     8, 2, 10,27, 17,80, 13,11,  4,19, 19,60,  6,58,  2,16,  3,34,  5,68,  1,89, 14,83, 11, 5,  7,43, 18,70, 15,10, 16,65,  0,70,  9,12, 12,24, 
    10,96, 15,86,  9,48,  7,74, 16,10, 13, 4,  8,55,  5,53,  2,56, 17, 1,  0,52, 12,52, 14,86, 19, 6,  6,65, 18,58,  1,80,  4,96, 11,38,  3,94, 
    18,68,  3,23, 11,50,  9,80, 10,83,  0,71, 12,33,  7,48,  6,28,  4,60,  2,76,  1,18, 14,32, 17,65, 13,33,  8,98, 19,28,  5,92, 16,95, 15,11, 
    10,74, 12,79, 17,40,  1,53, 11,24,  9,30, 15,52,  6,26, 19,90,  2,53, 16,50, 18,91, 14,70, 13,90,  5,31,  7,35,  3,66,  8,90,  4, 1,  0,21, 
     5,45, 16,17, 11,81,  8,97, 17,81,  4,67, 10,82,  6,24,  3,27, 14,52,  2,59,  7,55, 12,74,  9,25, 15,58,  1,62, 13,29,  0,88, 19,97, 18,80, 
    10, 1, 11,24,  1,11, 16,88,  0,77,  3,64,  7,27, 19,13, 14,52, 17,49,  9,19,  4,62, 18,10,  8,42, 15,97, 12,49, 13,76,  5,59,  6,36,  2,43, 
    15,92, 10,82, 16,21, 11,70,  8,89,  0,26, 19,24,  5, 1, 17,22,  7,12, 14, 6, 12,34,  3,88,  1,28, 13,54,  9, 8, 18,74,  2,41,  4, 1,  6,74, 
    19,29,  2, 7,  9,78, 12,90,  6,78, 11,94,  5, 7, 16,53, 10, 8, 15,92,  8,18,  7,59,  4,59, 13,96,  3,52,  1,69, 18,64, 17,76,  0,82, 14,36, 
    14,18,  4,64, 12,86, 16,82,  0, 6,  9, 2, 17,82,  2,46,  7,22,  6,13, 19,92,  1,38,  5,72,  3,45, 11,66, 13,48, 10,10,  8,94, 18,83, 15, 5, 
     7,27,  0,30,  9,99, 13,72,  4,17, 11,69,  2,59, 10, 3, 19,93,  1, 4, 14,30,  3,18,  8,36,  5,65,  6,93, 12,37, 15,10, 18,45, 16,14, 17,98, 
    16, 9,  7,66,  5,33, 10,35,  9,25, 13,44,  1,13,  3, 8, 14,47, 15,80,  8,99, 12,23, 18,59,  0, 2, 19,89, 11,16,  2,30, 17,45,  4, 3,  6,55, 
    11,74,  3, 7, 14, 3,  2,96,  6, 9,  9,44,  7,15, 19,16,  8,98, 15,19, 10, 8, 12, 1, 13,87, 18, 9,  5,48, 16,76,  1,26,  0,63, 17,52,  4,12, 
     8,90, 10,39,  3,58, 16,30,  0,35,  6,80,  9,69, 11, 7,  7,70,  1,52, 19,88, 17,56, 14, 8,  4,12,  2, 4, 13,48, 18,57,  5,34, 15,70, 12,13, 
    19,91, 11,39,  7,86, 12,47,  3,61, 16,19, 14,72,  6,63,  8,44, 10,95, 15,52,  0,61,  9, 7, 13,94, 18,77, 17,58,  5,11,  4,21,  1,54,  2,80, 
    10,14, 14,62, 15,13, 12,84,  1,15,  8,19,  9,70, 18,32, 11,57,  2,38, 17,90,  5,37,  6,31, 19,64,  3,20,  4,12, 13, 9,  7,75, 16,90,  0,15, 
     3,48,  8,13, 13, 5, 12,13, 18,19, 15,87,  4,80,  7, 6,  6,54, 16,41,  5,56,  9,10, 19,64,  2,26, 10,33, 11,11, 14,20,  0,32,  1,24, 17,27, 
     1,65,  3,89,  2,39,  7,77, 15,18,  0,42,  6,45,  5,83, 12,54,  4,63, 16,82,  9,50, 11, 9, 17,72,  8,46, 18,51, 14,36, 19,27, 13, 9, 10,48, 
    15,34, 18,85,  8, 2,  5,29,  3,17,  4,60, 10,69, 14,55, 16,34,  7,12,  2,17, 19,60,  9, 1, 13,63, 12,62,  0,14, 11,76,  6, 2,  1,85, 17, 9, 
     1,13,  3,44,  9,98,  6,16,  0,63, 16,31, 18,73,  4,75, 10,31, 15,46, 14,85, 19,79,  8,67, 12, 6, 11,25,  2,40,  5,39, 17,16,  7,60, 13,64, 
    17,23,  3,94, 19,55, 13,25, 12,93,  1,30,  6,95, 16,56,  9, 1, 10, 3,  7,77, 18, 1, 11,52,  8,52,  5,21,  2, 5, 15, 1,  0, 9,  4,23, 14,78, 
     2,10,  4,68,  5,56,  0,72,  7,63,  3,80, 16,91, 11,80,  6,22,  8,70, 18,39, 10,38, 17,57, 12,79,  1,60, 14,19, 15,95, 13,35, 19,41,  9, 3, 
    14,55,  5,50,  8, 2,  3,69, 11,44, 15,19,  4,70, 13,71, 16,53,  1,98,  7,65, 12, 4, 19,46,  9,94,  6,48,  2,86, 10, 6,  0,34, 17,97, 18,45, 
    18,85,  0,38, 11,27,  2,93,  1,81,  4,17, 15,14, 16,78, 17,89,  3,90, 10,97,  5,97, 19,12,  9,28,  8,72, 14,93,  6,18, 12,90,  7,53, 13,23, 
     9,83,  0,11, 15,94, 13,44, 12,80, 18,94, 14,24,  6,65, 10,22,  7,74, 16,62,  1,58, 11,86,  5,49,  8,94,  2,29, 19,75,  4,13, 17,26,  3,82, 
    13,31,  7,76, 11, 9,  2,16,  4,28, 10,88,  6,97, 19,43,  8,14,  0,89, 17,38,  1,66, 18,62, 14, 8,  3,41,  9,81, 15,38, 12,16, 16,26,  5,16, 
     7,51,  9, 1, 12,80, 11,63,  3, 1,  2,61, 18,98, 13,58, 10,47,  1,15, 14,83, 16,16,  8,50,  6,36,  0,13,  4,46, 17,97,  5,87, 19, 3, 15,50, 
    13,98, 16,65,  1,22, 19,31, 14,38, 11,45, 15,72,  4,72, 18,37,  5,63, 10,37,  0,50,  9, 6,  7,30,  2,11, 12,34,  6,46,  8,34,  3,37, 17,82, 
    15,31, 10,19, 12,30, 13,80,  5,24, 17,74,  2,67,  6,39, 11,35,  0,79,  3,42,  1,24,  7,45, 19, 5,  8,13, 14,44, 16,93,  4,33,  9,34, 18,28, 
    11,19,  4, 4, 15,52,  8,82, 13,42, 14,71,  2,19,  3,47,  7,17, 10,67,  6,38,  0,23,  5,79, 12,95,  9,21, 16,56, 17,19, 19,52,  1,25, 18,68, 
    10,58,  9,37, 11,46, 19, 4, 12,73,  7,86, 18, 8,  6,51,  8,46, 14,38, 16,33,  0,34,  2,89,  3,90,  1,73,  5,81, 15,37, 17,50, 13,80,  4,63, 
    10,74, 18,26, 15,75, 19,40,  3,29,  1,79, 16,83,  2,40,  5,35, 13,53, 14,57, 12,99,  0,57,  7,94,  8,99, 11,53, 17,93,  9,75,  6,29,  4,79, 
    18,39, 10,21,  2,51,  6,92,  7,92,  1,36,  4,73,  5,53,  0,62, 17,97, 15,62,  3,17, 11,80,  9,29, 14,86, 16,89, 12,26, 13,29,  8, 9, 19,83, 
    14,89, 18,88, 19, 9, 11,63,  6,64, 16,85, 10,95, 15,87,  5,44,  1,15, 13,23,  8,10,  3,93, 12,67, 17,69,  7,13,  9,35,  2,71,  0,51,  4,90, 
     1,53, 14,72,  2,49, 18,11,  6,52,  3,61,  0,36,  4,99, 11,49, 12,83, 19,10, 13,32, 17,39, 16,39,  8,86,  5,13,  9,54,  7,91, 15, 6, 10,51, 
    16,77,  1,59, 11,83, 17,50, 12,88,  9, 8, 14, 9,  0,58,  6,45, 18,25,  7,11,  3,34, 13,68, 19,35,  5,26,  4,48, 15, 1,  8,48,  2,12, 10,56, 
     4,24,  3,60,  0,20,  8,16, 12,65,  2,66, 16,47, 18,43, 14,63, 17, 9, 15,14,  6,70,  5,46, 11,32, 10,54, 13,17, 19,85,  7, 6,  9,12,  1,11, 
    13,89,  9,19,  1,25, 12,62, 11,72, 18,21,  6,32,  8,56,  7,61,  2,23, 16,33,  5,66, 19,65,  3,10, 10,27,  0,39, 15,46,  4,31, 14,23, 17,24, 
    11,15, 19,99,  0,14, 12,33,  5,81, 18,39, 10,49, 17,96,  9,31,  2,62,  3,40,  6,54,  7,53, 16,91,  1,87, 13,36, 14,79,  4,27, 15, 2,  8,34, 
     6,41, 13,15,  7,27, 19,90,  1,91, 14, 2, 15,69,  3,89, 17,30, 11,67,  2,37, 12,22,  9,79,  8,78,  0,73, 10,71, 18,67,  4,48,  5,10, 16,54, 
     4,61,  7, 2, 13,27,  9,20,  5,75,  6, 2,  0,58, 15,36, 17,54, 14,46, 10,85, 19,27, 11,63,  2,42, 16,88,  8,75, 18,30,  1,46,  3,19, 12,12, 
    12,19, 18,59,  3,73, 13,90,  7,20, 10,27,  4,36,  6,16,  9,53,  8,68,  2,10,  5,59, 11,83, 19,22, 16, 6, 17,91,  1,22, 14,74, 15,99,  0,61, 
    18,97, 15,85, 11,29,  7,20, 10,99, 14,29,  6,49, 16,86,  3,96,  2,83,  0,14,  4,95, 13,17,  9,45,  1,65,  8,48, 19,64,  5, 9, 12,26, 17,36, 
     7,59, 18,54,  6,77,  4,99,  1,90,  9,61, 19,65, 17,58, 16,42,  2,86, 15,64,  5, 3, 13,55,  8,79,  3,88, 14,13,  0,63, 12,66, 11,83, 10,85, 
     7,92,  0,29, 11,62, 14,81,  9,81,  2,97, 10,96,  3,66,  4,81,  1,75, 13,93,  8,51, 17,73, 16,76, 15,33, 19,34,  5,95, 18, 4,  6,59, 12,69, 
    13,18, 14,59, 11,15,  7,56, 19,85,  1,32,  6,68, 15,70, 18,24,  4,53,  8,12,  5,69, 10,35,  3,89, 16, 6, 12,41, 17,87,  9,41,  0,85,  2,51, 
     2, 4,  6,70, 10,84,  8,80, 11,17, 15,43, 13,50,  5,17, 19,50, 18,66,  7,24, 12,15,  9,90,  1,83, 14,45,  3,15,  0,72, 17,26, 16,89,  4,83, 
    15,13,  7,52, 14,88,  0,54, 12,50,  3,59,  6,51, 19,36, 13,87,  9,98, 11,26, 10,56,  5,89,  2,38, 18,48, 17,58,  1, 3,  8,72, 16,10,  4,81, 
    19,63,  4,29, 15,64, 13,50, 11,11,  7,38,  0,19,  3, 7, 14,59,  6,40, 12,56, 17, 5,  2,59, 16,83, 18,46,  1,41,  5,90,  9, 4, 10,24,  8,34, 
     4, 9,  0,82, 11,69, 10,14, 15,77,  8,39,  9,27, 16,98,  7, 8,  6,53,  2,15, 19, 1, 14,68, 12,56,  5,72,  1,61,  3,49, 18,35, 13,67, 17,21, 
     1,84,  2,41, 10,78,  4,53,  7,82, 14,32,  9,51, 11,27, 19,56, 18, 4,  8,19,  5,41, 12,80,  0,33, 16,71,  3,18, 15,13, 17, 3, 13,43,  6,95, 
     7,68, 18,59,  2,67, 15,24, 10, 2, 11,69, 13,45, 17,85,  9,51, 19,46, 14,86,  1,11,  4, 2,  6,97, 16,53,  5,44,  8,64, 12,33,  0,32,  3,53, 
     7,24,  8,97, 14,11, 15,69,  1, 6, 10,12, 16,84,  3,32, 13, 1,  0,90,  6,32,  2,98,  5,79, 17,36,  9,56,  4, 1, 19,17, 18,84, 11,80, 12,64, 
    12,47, 17,64,  5,16, 18,64, 16,69,  1,16,  7,45,  2,62,  0,16, 10, 5, 11,26,  3,70, 14,48,  9,58, 19,75, 13,13, 15,11,  4,47,  6,50,  8,29, 
    17,72, 10,51, 19,16,  4,32,  3,43,  8,61,  1,11,  5, 1, 14,74, 12,17,  9,15,  2,72, 13,87, 18,81, 11,26, 16,26,  6,74,  0,30,  7,79, 15,40, 
     5,59, 11,69,  1,98,  6,60, 16,73, 14,37,  9,35, 15,47, 13,17,  3,93, 18,83,  7,27,  0,95,  2,77, 19,67, 17,30, 10,78,  4,26, 12,45,  8,55, 
     1,42,  3,93, 13,88, 17,89, 14,31, 19,89, 11,59,  6,86,  8,28, 10,23, 16, 4, 12,72, 15,43,  7,28,  0,52,  9,18, 18,60,  5,91,  2,86,  4, 6, 
     2,84,  3, 8, 13,84,  4,67, 17,84, 14,11, 12,89, 19,38, 18,12, 15,74,  9,14, 11,50,  5,83, 10,42,  8,77,  0,88,  1,58,  7,58, 16, 8,  6,17, 
    12,28, 14,15, 11,97,  5,31,  1,15,  6,35, 16, 9,  9,59, 18,50, 13,98,  0,86, 10, 6, 17,49,  3,24, 15,89,  4,56,  7,85, 19,14,  2,78,  8,20, 
     1,51, 11,25, 14,56,  0,67, 18,51, 13,44,  4,80, 19,66,  5,23, 12,74,  7,12, 16,52, 17,13, 15, 4,  8,36,  2,69,  3, 5,  6,21,  9,57, 10,79
  };
  // Taillard 100x20 instance 5
  const int tai_100_20_5[] = {
    100, 20, // Number of jobs and machines
     9,53, 19,48,  7,17,  6,42,  2,70, 13,99, 11,23, 18,79, 16,42,  8,88, 14,23,  3,77,  1,59,  4,45,  5,84,  0,58, 15,47, 10,91, 12,29, 17,48, 
     3,52,  2,74,  6,35, 15, 3, 16,45, 18,36,  8,92, 14,20, 10,58, 12,14, 13, 5,  1,93, 17,46,  0,36,  5,94, 11,76,  7,63,  4,95,  9,66, 19,49, 
    12,42, 11,62, 13,83, 16,59,  7,60,  9, 8,  3,15, 19,10, 10, 1, 14,78,  2,27,  0,98, 18,35,  6,22,  1,80, 17,77, 15,86,  5,63,  4,44,  8,39, 
    12,10, 19, 6,  5,62, 11,67, 14,66,  4,38, 13,20,  7,76,  6,94, 15,67, 18,34,  1,59,  0,27,  3,61, 17,10,  2,67, 10,21, 16,90,  8,73,  9,14, 
    12,17,  2,37, 10,21, 11,91,  8, 7, 18,44, 17,22,  6,50,  5,31, 13,82,  9,53, 14,21,  4,89, 16,35, 19,48, 15,16,  3,70,  1,93,  0,41,  7, 5, 
    12,63, 14,68, 18,45,  0,41,  9,78,  3,74, 15,97, 16,14,  2,48, 13,54, 17,91,  7,92, 11,91, 10,64,  5,61, 19, 6,  8, 6,  4,60,  1,65,  6,73, 
     2,91, 18,58,  8,75, 10,11, 17, 7, 12,86, 19,70,  9,26,  7,53,  4, 5, 11,81, 14,66,  1,57,  3,77,  0,89, 16,49, 13, 3, 15,59,  6,93,  5,37, 
     5,33, 11,97,  0,81, 18,35, 16,83,  6,28,  3,47,  7,34, 13,23,  9,96, 10,31, 14,94, 19,63, 15,21, 12, 1,  1,56, 17,36,  8,50,  4,91,  2,88, 
     8,37,  1,70,  7,38, 15,84, 17,25, 12,32, 14,72, 18,37, 16,23,  0,14,  3,44, 13, 3,  9,25,  4,91, 19,97, 11,88, 10,64,  6,81,  5,65,  2,59, 
    11,40, 13,23,  0,52,  4,39,  8,64, 19, 9, 14,65,  2,22, 17,71, 12,51, 18, 7,  6, 7,  3, 7,  5,34, 10,59, 15, 2, 16,45,  1,41,  7,96,  9,20, 
     0,48,  9,63,  2,47,  7,12,  4,56,  3,86, 15,86, 17, 1,  6,20,  1,80, 10,82,  8, 4, 19, 8,  5,55, 16,85, 18,75, 11,22, 14,11, 12,46, 13,48, 
    16,76, 11,56,  6,19, 13, 7, 17,44, 14,90,  2,23,  5,12,  1,57,  4,99,  8,75,  9,22, 15,59, 19,96,  3, 5,  0,67, 18,94,  7,64, 12,88, 10,77, 
    11,87, 14,22, 18,14,  8,19,  1,98,  9,68,  5,47, 10,97,  2,10,  3,71, 16,66,  0,42,  4,21, 17,49, 13,87, 19,49,  6,54, 12,74, 15,92,  7,25, 
     3,22, 19,64, 14,21, 10,44, 16,34,  7,43,  0,14,  1,73, 12,38,  5,58, 11,52,  6,26, 18, 6,  8,56,  4,98,  2, 2, 15,98,  9,49, 13,91, 17,65, 
     6,58,  9,56, 11,73,  4,22, 14,65,  8,94, 10,98, 19,13,  5,25, 12,66, 18,35, 17,50,  3, 8, 15,47,  0,33,  1,24, 16,53, 13,39,  7,43,  2,96, 
     6,99,  1,72,  5,40, 18,88, 13,39, 15,26,  9,57,  3,81,  7,63,  8,71, 16,93, 14,59, 10,12,  4,71, 17,87, 11,52, 12,67,  0,27, 19,70,  2,91, 
    12,63, 16,87,  2,72,  3,44,  0,20, 18,77,  9,48, 10,34, 19,62,  4,64, 13,26, 15,68,  6,92, 17,18,  7,51,  5,43, 11,15,  8,70,  1,23, 14,56, 
     6, 6, 15,39,  0,65,  5,47,  2,69, 12,17, 19,35, 10,94,  3,52,  7,58, 13,63,  4,63, 11,89, 16,56,  8,30,  1,24, 18,37, 14, 3,  9,61, 17,12, 
     4,80,  1,50, 15,35, 19,43,  0,96, 18, 3, 16,81, 14,10, 12,14, 11,32,  3,54,  9,21, 10,57,  8,78,  2,56, 17, 8,  6,60,  5,37,  7,47, 13, 2, 
    12,93, 19,46, 13,47,  8,13, 10,87, 14,60, 17,83,  1,69,  7,32,  3,12,  4, 2, 18,89,  5, 3,  6,12,  2,14, 15,99,  0,69, 11,12, 16,79,  9,72, 
    15,99, 12,55, 11,44, 19,16,  3,49,  0,86, 14,40,  4,40,  1,41, 13,36, 18,93,  8,34, 17,88,  2,90,  7,99,  5,37, 16,54,  6,82, 10, 4,  9,55, 
     4,31,  6,26,  5,12,  7,48,  1,41,  2, 2, 13,25,  3,17,  9,32, 18,77, 16,98, 15, 2, 12,82,  0,92, 11,33, 17,53, 10,53,  8,28, 14,27, 19,86, 
    19,86, 17,59, 18,40, 12,42,  5,46, 15,78,  0,14,  8, 7,  4,49,  1, 6,  6,28, 10,12, 13,73, 16,35, 14,64,  2,57,  7,77, 11,64,  9,63,  3,15, 
    16,17, 15,59, 18,60,  8,37,  1,95,  7,78, 17,61, 10,45,  0,51,  9,67, 12,34, 14,45, 11,47,  5,86, 13,74,  6, 5,  3,67,  4,79,  2,27, 19, 9, 
    12,70, 11,23,  1,29,  0,78,  8,54,  6, 3, 15,27,  3,82, 17,30,  9,90,  7,27, 19,95, 13, 8, 18, 9, 14,58,  4,41, 16,25,  5,87, 10,35,  2,24, 
     9,39,  1,62, 19,80, 16,74,  7,25,  5,43, 17,79, 11,52,  8,12,  0, 6,  2,67,  3,46, 18,37,  4,14, 12,37, 15, 2, 10,82, 14,12, 13,38,  6, 9, 
    10,84,  5,87, 15,40, 16,12,  2, 9,  9,62,  4,27,  0,68,  8,24, 19,79, 14,52, 13,18,  1,57, 12,93, 17,61, 18,15, 11,61,  3,21,  7,93,  6,57, 
     8,54,  5,89,  9,30, 19, 4,  2,37, 11,72, 18, 1,  4,10,  3,65,  7,81, 12,22,  1,17,  6,72, 10,41, 14,51, 15,42, 16,21,  0,39, 17, 1, 13,59, 
     4,65,  6,82, 12,11,  5,85,  9, 8, 15,53,  0,89, 16,29, 11,60,  3,22,  7,46,  8,29, 17,22, 18,71, 13,35, 19, 6,  2,22, 10,77, 14,69,  1,30, 
    16,43, 15,35, 10,84,  3,68,  5,85, 14, 3, 12,11, 18,13, 13,66,  0,74,  1,30,  8,54, 19,12, 17,94,  7,85,  4,86,  2,74, 11,17,  6,88,  9, 6, 
    11,81,  5, 3,  3,69,  4,81,  0,52,  9,59, 16,88, 17,99, 13,63, 12,35, 18,48, 10,26,  2,44,  1,38, 14,32, 19, 4,  7,80, 15,44,  8,86,  6,90, 
    15,35,  2,14, 11,63, 12,25,  5, 7,  1,22, 10,72,  3,38,  7,63, 14,80, 18,65, 19,84, 13, 8,  4,18, 17,79,  8,42,  6,94,  9,89,  0,29, 16,40, 
    16,98, 17,76, 13,87,  2,69,  1,65,  6,64, 14,58,  4, 7, 18,18, 15, 7, 19, 9,  0,36, 12,48,  8,48,  9,83, 10,43,  5,35,  3,84, 11,32,  7,84, 
    14,22,  0,95, 17,92, 19,95, 18,70, 11,84,  4, 3,  3,56, 12,31, 15,10, 10,35, 13,47, 16,94,  9,61,  7,45,  2,47,  1, 4,  5, 1,  6,35,  8,53, 
    16, 1, 15,22, 14,46,  6,91,  4,78,  5,48,  1,32, 19,93,  0,28, 10,91,  2,16, 12,52, 17,48, 13,43,  8,11,  9,68,  3,44,  7,51, 11,11, 18,33, 
    14,26,  3,65,  5,93, 18, 8,  6,44, 16,98,  1,50, 19,36, 10, 5,  2,68, 12, 6,  9,49,  0,46,  4,55, 17, 1,  7,94, 13,13, 11,39, 15,90,  8,40, 
    10,63, 16,30,  7,24, 11,41, 14,97,  5,71, 13,92, 12,91, 17,22,  6,97,  9,49,  2,40,  3,37,  1,36,  8,23, 15,83, 18,53,  0,71, 19,64,  4,76, 
     5,37, 15,60, 13,79, 16,25, 18,83, 19,21,  8,10, 11,78,  4,75,  6, 9,  3,70,  2,36,  0,41, 17, 8,  1, 1, 10,19, 12, 1, 14, 6,  9,67,  7,46, 
    13, 5,  0,29, 11,76,  7,16, 18,81,  5, 9,  6,94,  8,82, 14,71,  4, 5,  9, 3, 10,38, 19,25, 15,85,  1,45,  2,62,  3,30, 12,58, 17,10, 16,20, 
     5,85, 11,99, 13,30,  9,23, 17,91,  3,32, 14,61, 12,42, 19,11,  4,56, 16,33,  1,30, 15,27,  2,19, 18,14,  0,81, 10,21,  8,56,  7,57,  6,68, 
     1, 4,  7,20, 15,37,  9,62, 19,79,  5,62, 17,71,  8,18,  2,82, 11, 7,  3,42, 12,97,  6,10,  0, 6, 14,25, 10,70, 16,27, 13,87, 18,69,  4,53, 
    12,14, 13,19,  6,36, 18,52,  8,88,  2,67, 14, 2,  1,30, 16,83,  4,86,  7,97,  9,33,  0,23, 19, 5,  5,42, 11,77, 10,47,  3,58, 17,23, 15,44, 
     5,82, 13,73,  9,91, 11,78, 10,54, 16, 1,  4,30, 18, 9,  0,37, 17, 3,  8,71,  3,26, 14,98,  2,70,  7,35, 19,55, 12,72,  6,47, 15,35,  1,85, 
    10,36,  1,14, 17,96,  2,61, 19, 3, 14,30,  0,98,  8,75, 15,41, 16,79,  3,96,  9,73, 18,54,  4,72, 12,29,  7, 6,  6,31,  5,32, 11,34, 13,50, 
    19,93, 13,16,  3,96,  7,73, 10,94,  6,36,  9,29,  2,38, 14,63, 11,14, 17, 7, 12, 7,  4,56, 16,54,  5, 7, 15,83, 18,33,  8,60,  0,88,  1,58, 
    16,64, 12,11, 14,13, 19, 4,  9,74,  8,23, 15,84, 18,62,  0, 8,  6,42,  2,96, 11,26, 13,41,  7, 2,  4,28,  3,14,  1,99,  5,14, 17,65, 10,80, 
     4,10,  3,99, 10,20, 15,80, 11,60,  5, 2,  0,98, 12,97, 14, 1,  1, 1,  2,59, 19, 1, 16,26, 18,99,  8,89,  6,38,  7,15, 17,47,  9,74, 13,14, 
     1,52, 19,50,  5,13, 14,73, 12,88, 13,67, 18,78,  9,82,  7,18, 16,86,  0,27,  6,34, 10,26, 15,30, 17,17,  4, 2, 11,87,  2,85,  8,40,  3,77, 
     4,70,  6,98,  3,23, 13,29,  1,88, 10,31,  2, 7,  5,92, 18, 3, 16,80, 17,18,  7,39, 15,57,  8,56,  9, 8, 19, 1,  0,79, 14,90, 11,74, 12,55, 
    19,25,  6,29,  0,51,  3,83,  5,91,  4,93, 12,44,  8,16,  2,23,  7, 7, 17,57, 18,56,  9,72,  1,41, 10,68, 14,25, 13,63, 16,43, 15,87, 11,53, 
     9,35, 18,12, 12,89, 10,41,  1,70,  2,18, 13,70,  6,69,  8, 5, 17,59,  7,30,  4,34, 11,23,  3,42,  0,45, 15,92, 19,92, 16,60, 14,98,  5,41, 
    11,61,  1, 4,  2,30, 15,50, 13,50,  8,39,  4,41, 10,15, 16,22, 14,55, 12,37, 17, 7, 18,88,  6,58,  5,90,  0,64,  3, 7, 19,23,  7,19,  9,37, 
    16, 4, 12,57, 10, 1,  2,80,  6,21, 18,35,  9,32, 17,98,  0,78,  1,50, 15,79,  4,53, 19,40, 11,19,  7,25, 13,84,  8,91,  5,51, 14,95,  3, 4, 
    13,73,  5,92,  8,25, 19,41,  9,58, 15,36,  1,50, 10,90,  4,98, 17,39, 18,94, 14,64,  2,15,  0,29,  7,27,  3,89, 16,50, 12,26, 11,38,  6,11, 
    14,82,  2,37,  3,99,  6,34, 12,94,  5,46, 16,74, 19,45,  4,78,  1,41,  9,58,  7,43,  0,71, 15,59, 11,25, 17,55, 18,84, 13,48, 10,84,  8,57, 
     2,11, 11,53,  0,39, 15,81, 19,66,  6,99,  4,73,  3,76, 17, 7, 14,91,  9,33, 16,47, 18,14,  8,51,  1,25, 13, 4,  5,15,  7,26, 10,79, 12,70, 
     6,79, 15,97,  9, 9,  0,56, 14,50,  8,43, 13,55,  1,32,  4,91,  5,75, 17,83, 18,17, 12,55, 10,43, 19,80, 11,62,  2,60,  7, 3, 16,56,  3,33, 
    13,97,  2,40, 12,32,  3, 7,  5,85,  6,60, 17,19, 19,13,  8,54, 10,62, 16,47,  0,11, 15,32, 11,49, 18,65,  9,69,  7,67,  1,96,  4, 7, 14,71, 
    19, 7,  7,54, 15,19, 14,14, 10,68,  9,74,  4, 1, 17,62, 13,53,  2,51,  8,35,  6,23, 11,88,  1,68, 18,53, 16,39,  3,65,  0,64, 12,93,  5,93, 
    12, 9,  0,28, 17, 6, 18,73,  6,73,  5,71, 11, 7,  3,57,  2,95, 10,93, 15,56,  7,67,  9,23, 13,30,  8,98,  1,37,  4,34, 14,27, 19,45, 16,62, 
     3,32,  0,71, 14,47,  5,16,  4,50, 15,96,  2,31, 17,10, 12,63, 10,10, 16,74,  7,88,  6,32, 11,50,  8,93,  9,41, 19,55, 13, 5, 18,69,  1,83, 
     7, 4,  4, 8, 15,91, 13,54, 11,59,  9,51,  1,58,  8,55,  6,63,  0, 3, 12,64, 18,38, 19,21, 14, 8,  3,69, 16,93, 10,95,  2,61, 17,37,  5,74, 
     7,86,  4,46,  1,71, 19,94,  6,84, 14,72, 13,51, 12,75,  0,46, 17,17, 11,35, 18,22,  5,43, 15,64, 10, 4,  8,32,  9,22,  3,71, 16,26,  2,62, 
     1,44,  9,55,  5,12, 14,38, 17,35,  0, 6,  3,61,  2,93, 18,18, 13,62,  4,42, 11,23, 12, 9,  6,71,  8,79, 19,84,  7,90, 10,67, 16,92, 15,48, 
     1,78, 18,22, 12, 8,  0,85,  5,92, 11, 8,  9,45, 14,38,  2,20, 15,38,  8,73,  6,53,  3,44, 17,19, 10,75, 13,41,  7,71,  4, 6, 19,84, 16,74, 
     8,30, 19,41, 18,20,  7,49,  4,60, 16,59,  6,40, 15,72,  9,31, 12,26,  1,55, 14, 3, 17,61,  2,57, 10,58,  3,87,  0,88, 13,40, 11,94,  5,78, 
     7, 8,  2,15,  1,66,  6,46, 11,22, 12,66, 14,13, 18, 7,  9,30, 15,64,  3,55,  8,31, 17,96, 16,82, 19,60,  0,14, 13,63,  4,56,  5,71, 10,63, 
    16,29,  3,10,  5,78, 10,46, 15,94,  8,97,  6,85, 14,86, 13,63, 19,50, 18,49,  7,27, 17,63, 11,81,  2, 4,  0,80,  4, 9, 12,95,  1, 6,  9,83, 
     5,63, 11,28,  1,37,  0,62, 16,56, 10,73,  6,54,  2,70,  7,53,  8, 7, 12,35, 14,64, 18,22,  4,98, 15,41, 19, 6, 17,88,  9,20, 13, 5,  3,86, 
     8,84,  3,84,  2,21, 14,35,  0,54,  1,98, 16,95,  6,54, 11,63,  9,59,  4,74, 18,90, 19,68, 10,98,  5,39, 17,83, 13, 5,  7,19, 12,74, 15,73, 
     2, 1, 16,41,  9,31,  6,10, 19,99,  3,94,  0, 9,  7,69, 12,55, 17,92, 18,17,  5,89, 14,73, 10,10,  4,98, 13,38, 15,13, 11,52,  1,48,  8,87, 
    11,70,  7,40, 15,18, 14,41,  2,26,  0,65,  1, 7,  4,56, 12,32,  9,37,  3,32, 19,48, 16,77,  5,26, 17,91, 10, 5, 13,33, 18,74,  8,90,  6,97, 
    15, 1, 11,55,  8,80, 14,27,  3,58, 13,92, 18,18,  0,91,  4,23,  6,96,  1,86, 17,40, 19,17, 12,39,  9,49,  5,31,  2,60,  7,53, 16,74, 10,23, 
     6,73, 17,19,  5,89,  0,90,  7,27, 15,84, 18,73, 19,30,  1,51, 12,33,  2,84, 10,21,  4,38,  8,29,  3,34,  9,12, 14,57, 16,46, 13, 9, 11, 8, 
    16,65,  6,39, 17,15,  5,72, 11,65,  9, 6, 13,99, 19,83,  1,65, 14,84,  2,85,  7,90,  8,23, 18,45,  0,74, 15,88,  4,26, 12,41, 10,61,  3,28, 
     3,86,  5,60, 17,48, 15, 8,  6,18, 13,14, 12,71, 16,41, 14,76, 10,57,  0,72, 18,23,  1,81,  7,50,  8,60, 11,15,  4,33, 19,54,  2,67,  9,80, 
    12,25, 15,19, 19,88,  3,68, 10,40, 16,42,  2,60, 18,29, 11,87,  7,57,  9,77,  8,23, 17,91, 13,34,  0,96,  1,22,  4,84,  5,26, 14,66,  6,76, 
     5,41,  6,23, 12,34,  3,31,  4,65, 10,43, 15,51,  0,35, 17,42, 14,56, 19,29,  8,79,  7,22, 16,66,  9,68, 13,32,  1,21, 11,82,  2,42, 18,66, 
     1,29, 17,24, 18,48, 15,13,  0,93, 14,68,  5,17, 11,51,  8,49,  3,76, 16,40,  6,88,  2,85,  9,43, 13,56,  4,31, 12,77,  7,88, 10,53, 19,53, 
     8,17,  6,18,  1,36, 10, 1,  5,54, 12,20,  0,95, 11,20,  2,57,  3,42,  4, 3, 15,55, 17,18, 13,39, 19,85, 18,28,  7,21, 14,49,  9, 7, 16,98, 
     0,89, 14,97, 18,66, 15,17,  5, 2,  7,32, 12,94, 11,71, 10,87, 16,45,  6,45,  9,21, 19,91,  2,30,  3,33,  8,20, 17,97,  4,34, 13,15,  1,24, 
    10,57,  2,89, 18,78, 13,21, 11,58,  9,78, 14,25,  4,51, 15, 7, 12, 1, 19,61, 17,92,  1,13,  3,73,  6,35, 16,46,  0,61,  8, 4,  7,68,  5, 3, 
    10,77,  4,79,  7,61, 18,52,  8,74,  9,31, 17,71, 19,98,  1, 4, 14,62, 16,44, 15,38, 11,25, 13,29,  5,40,  0,30,  2,65,  3,79, 12,57,  6,10, 
     0,50,  3,95,  1,33, 19,34, 15,49,  8,25, 16,22, 11,87, 13,46, 10,13,  5,96,  9,98,  6,43,  7,80, 17,70, 12, 7, 14,97,  4,19, 18,74,  2,47, 
    10,83,  6,93,  8,90,  2,96,  7,75, 15,41, 13,68,  9,43, 18,77, 12,32, 16,75,  1, 1, 17,28, 11,11, 14,90,  5, 5,  4, 4,  3,63, 19,79,  0,92, 
    18,61, 12,65,  6,48, 19, 2, 15,98, 16,44,  1, 4,  2,50,  7,66,  3,97, 17,26,  4,85,  0,71,  9,52, 11,32, 13,98, 14,60, 10,88,  8,75,  5,43, 
     9,97, 15,42,  8,77, 14, 4,  0,80,  7,95,  3,17, 18,50,  4,32, 13,44,  2,93, 12, 2,  6, 5, 19,68,  5,78, 16,21, 11,70, 17,18, 10,49,  1, 5, 
    16,86, 18,18, 15,71,  0,19,  6,13,  2,72, 12,12, 14,64,  3,78, 11,37,  9,69, 13,13,  7,78,  8,60,  5,71, 19,63, 10,77, 17,41,  4,84,  1,71, 
     9,17,  6,80, 12,96, 18,44, 15, 2, 11,92, 17,32,  3,57,  7,74, 14,32, 10,48,  0,61,  4,47, 16,78, 19,81,  8,86,  1,29,  2,64, 13,48,  5,34, 
    16, 8, 13,79, 17,71, 14,87, 12, 1, 15,61, 18,82,  8, 7, 19,53,  6,70,  2,54, 11,62,  5,75, 10,13,  0,53,  3,53,  4,78,  1,97,  9,18,  7,39, 
    16,70,  2,55, 14,92,  3,59, 19,62,  9,16,  6, 4, 17,29, 15,18,  0,20,  7,56, 11,82,  5,33, 12,77, 18,64,  8,25, 10,75,  1,46, 13,54,  4,55, 
    13,71,  9,69,  1, 9, 18,92,  7,69, 12,91, 19,63,  2, 3, 11,96,  6, 9, 17,48,  3,29, 16,14, 14,15, 15,11,  4, 2,  8,43,  0,52,  5,54, 10,96, 
     3,72, 19,65,  9,18, 16,80, 14,55,  5,45,  4,34,  6,67, 15,59, 11, 5,  1,38,  7,99,  8,91, 10,15,  2,42, 13,74,  0,24, 17,23, 18,10, 12,53, 
    11, 3,  7,17, 15,78, 16,72,  3,63,  2,92, 12,35,  5,62, 17,86, 19, 5, 14,55,  6,77,  9,95, 10,49,  8, 6, 18,58,  0,16, 13,78,  1,62,  4,73, 
     8,38, 15,51, 13,28, 14,76, 18,38, 16,96, 19,91,  0,32,  7,90, 17,73, 12,56, 11,67,  4, 4,  1,55,  3,77,  9,20,  6,43,  2,62,  5,79, 10,49, 
    17,37,  8,71,  2,80, 11,33,  9,95,  4,41, 10,15, 15,67,  5,10, 19,94,  0,63, 14,97,  6,56, 16,42, 18,35,  3,63,  7,16, 12,92,  1,13, 13,88, 
     0,14, 18,41, 12,82,  4,47,  8,49, 14,52,  5,64,  6,25, 16,12, 13,56,  2,47,  7,42,  9,77, 15,89, 17,92,  1,41,  3,75, 19,23, 11,40, 10,91, 
     9,99, 15,52, 14,30, 12,27,  7,86,  3,29,  5,80, 19,78,  0,76,  2,13,  1,12,  8,23,  4,66, 16,30,  6,66, 18,52, 10,67, 11,42, 13,91, 17,84, 
    19,94,  4, 7, 10,40, 18,29,  1,87, 17,18,  0,82,  8,75,  5,32,  9,45, 14,19,  6,23, 12,69,  7, 1,  2,92, 15, 9,  3,29, 13,37, 16, 8, 11,78, 
     4,79, 11,39,  9,46, 17,95,  0, 4, 12,55, 14,80,  1,79, 19,35, 13,11,  2, 4,  3,24, 15,63, 16,14,  6,34,  8,14, 10,57,  7,58,  5,14, 18,60
  };
  // Taillard 100x20 instance 6
  const int tai_100_20_6[] = {
    100, 20, // Number of jobs and machines
     3, 1, 10,32, 16,15, 19,15,  7,72,  1,41, 12,49,  2,17, 15,12,  5,39,  0,66, 17,64,  9,10, 13,24, 14,60, 18,76,  6,72,  8,47, 11,99,  4,92, 
     2,28, 18,62,  9,64, 16,95, 14,94,  0,86,  3,87,  6,11,  5,46,  4,64, 15,86, 12,76,  8,11,  1,32, 10,44, 17,31, 11,77, 19,99,  7,16, 13,97, 
     7,78,  2,28, 11, 2, 14, 3,  0,88, 12,69, 13,34,  3,99,  8,33,  1,70, 18,18, 16,22,  5,41, 17,20, 15,21,  9,44,  4,66, 10,18, 19,73,  6,80, 
     1,20, 18,22, 12,76,  6,43,  8,60,  5,91, 19,88, 11,26,  9,12,  3, 8,  2,65, 13,39, 17,49,  4,83, 10,30,  0,78, 15,21, 14,96,  7, 6, 16,56, 
     6,56, 12,52,  8,73, 10,20, 11,76, 19,73,  2,21,  3,21,  4,40, 18,69, 16,19,  5,93,  0,92, 15,74, 13,88, 17,74,  7,95,  9,43,  1,50, 14,77, 
     4,79,  7,57, 17,70,  5,34, 16,28, 15,28, 12,84, 11,40,  0, 6,  6,53, 19,42,  2,99,  3, 7, 18,18,  1,23,  9,12, 14,87, 10,86, 13,13,  8,66, 
     3,67, 16, 2, 19,69,  6,87, 10,56, 17,22,  4,24, 15,67,  1,60,  0, 7,  9, 2,  8,71,  2,63, 12,63,  5,99, 18,79,  7,84, 14, 7, 11,97, 13,84, 
    12,19, 19,98,  5,65,  4,56,  8,21, 15,81,  9,91,  2,52, 16,86, 10,64,  1, 2, 13, 6,  7,81, 11,81, 17, 5, 14,84, 18,88,  3,70,  6,76,  0,72, 
     3,73,  4,73, 13,24,  8,26, 19,22, 18,53, 14,94,  5,81, 12,25, 15,57, 10,47,  1,86,  9,79,  6,92, 11,45,  0,17, 17, 3, 16,12,  7,60,  2,60, 
    13,66, 18,71, 19,69, 17,77, 16,95,  9,30,  6,45, 14,46,  8,35,  0,33, 12,95,  1,20, 11,30, 10,50, 15,92,  3,97,  4,99,  2, 2,  5, 2,  7,24, 
    19,91,  4,85, 17,16,  3,91, 15,40, 18,59, 11,64,  0,30, 10,62,  7,94,  6,67, 14,75, 12,22,  5,46,  8,97, 16,40,  2, 9, 13,38,  9, 7,  1,94, 
     2,99, 10,82, 13,94,  8,20, 11,41, 12,85,  9,21,  4,80, 16,53,  6,50, 15,73,  1,37, 14,89, 19,60,  0,30,  5, 5,  3,10,  7,12, 17,40, 18,29, 
     7,34, 17,27, 11,75,  4,74,  2,82, 12, 9, 15,75,  9,87, 18,81, 16,12,  8,12, 14,26, 10,18,  5,89, 19,84,  0,87,  6,14,  1,93, 13,20,  3,81, 
    11,93,  1,48,  6,61,  2,57,  7,89, 17,62, 10,51,  5,89, 16,43,  4, 9, 13,73, 19,24,  3,17,  8,73,  0,12, 15,76, 18,72, 12,11, 14,34,  9,75, 
    18, 7,  7,62, 11, 2,  3,28,  9,73,  1,57, 12,51,  4,75, 13,86,  5,25, 14,98, 17,63,  8,41,  2,64, 15,24,  6,62,  0,40, 16,21, 10,34, 19,44, 
     4,71,  1,44,  6,66, 18,93,  0,61, 13,66,  3,42,  7,51, 15,32,  5,52,  8,31, 11,30, 12,63, 10,29,  2,90, 19,75, 17,94,  9, 9, 16,40, 14,22, 
    11,14,  4,46, 10,10,  5,52, 14, 7,  8, 1,  6,13,  0,77,  9,37,  2,63, 15,37, 19,59, 13,33,  3,30,  1,78, 17,38,  7,77, 18,12, 16,46, 12,33, 
    17,72,  3,71,  1,84, 15,10, 13,95,  6,24, 12,18, 19,56,  7, 3, 16,49, 11,77, 10,19,  0,70,  4,24,  2,50, 18,19,  5,60, 14,45,  8,77,  9, 6, 
    14,11, 15,20, 12,12, 19,61, 17,99, 18,29, 10,38,  1,76,  6,48, 13,56,  3,98,  9,80,  4,52,  0,30, 11,23, 16,59,  7,66,  2, 4,  8,43,  5,26, 
     5,80,  2,71,  4,50, 10,69, 19,27,  0,54,  3, 4, 18,60,  1,93,  7, 1, 16,76, 12,11, 11,88, 14,87,  9,42, 15,73, 17,87, 13,40,  8,15,  6,72, 
    18,79,  1, 4, 14, 8, 11,65, 19,72, 16,70,  9,69, 17,99,  3, 1, 15,73,  0,57, 13,52, 10,80,  7,85, 12,58,  5, 8,  6,31,  4,91,  2,89,  8,60, 
    10,88,  2,39, 19,70,  6,65,  0,78, 15, 9, 18,65,  5,54, 13,96, 14,14, 12,46, 17,51,  7,64, 11,55,  1,56, 16, 6,  4, 2,  9,15,  8,53,  3,20, 
     4,57, 14,39, 17,78, 16,71, 15,91,  3,57,  5,73,  7,36, 11,81, 19,92, 18,59,  9, 8, 13,24, 12,48,  2,88,  0,69,  6,49,  8,55, 10, 7,  1,82, 
    12,31,  8,56,  3,97, 14,98, 18,18, 19,55, 15,69,  6,33, 11,73, 13, 4, 16,44,  0,97,  1,76, 10,21,  5,39,  2,73, 17,85,  7,30,  9,65,  4,15, 
     8, 2, 16,76, 17,94, 12,62,  1,28, 14,91,  2,37,  6,62,  7,49,  3,34, 10,71, 18,65, 13,56,  0,78,  5,10, 19,52, 15,43, 11,92,  9,34,  4,58, 
     8,28, 13,79,  9,40,  0,44, 10,33, 19, 2,  4,85, 18,53, 17,19,  7,71,  2,16, 15, 8, 12,38, 11,52,  3,98,  1,30,  5,15, 14, 5,  6,16, 16,88, 
     2,89,  1,36, 19, 2, 15,42,  8,74, 11,89,  5,69, 16,13,  7,14, 12,83,  0,46, 18,78, 17,69, 13,48, 10,64,  9,64, 14, 2,  3,34,  6,38,  4,40, 
    13,30,  4,92, 18,48, 11,93, 12,74, 15,71,  3,85, 14,25,  5,98,  8,71, 10, 1,  9,83,  0, 8, 16,73,  6,44,  1,26, 17,38, 19,68,  2, 9,  7,63, 
    19,45, 16,77, 17,11, 18,49, 12,54,  3,93,  6,42,  8,43, 15,57,  9,17,  7,61,  4, 9,  1,65, 13,32,  5,28,  2,53, 11,63, 14,17,  0,66, 10,66, 
     7,57,  5, 4, 13,30, 12,33,  9,99, 19, 4,  1,51,  0,42, 14,76, 10,44, 17,16,  8,90,  6,89, 15,91,  2,61,  3,81, 11,86, 16,92,  4, 7, 18, 7, 
    18,33,  1,58,  8,22,  5,22, 13,63, 12, 7,  7,22, 11,78, 19,84,  4,95, 10,83,  2, 7, 16,66,  3,35, 14, 9,  0,29,  6,43, 17,88,  9,95, 15, 7, 
     8,88, 12,52, 17,18,  7,46, 11, 8, 14, 5, 10,76,  1,20,  5,19, 18,71,  0,30,  9,22, 15,57, 13,53,  3,91,  6,68, 19, 8, 16,47,  2,81,  4,33, 
    15,48, 13,53, 14,34,  2,61, 10,23,  9,11, 12, 5, 19,81,  0,30,  5,25,  8,13, 17,68,  1, 9, 16,38, 18, 6,  3,99, 11,18,  4,19,  7,53,  6,81, 
    18,50,  7, 3,  5,61, 15,88, 12,98,  6,56,  4,92,  0,87, 13,34, 11,29, 17,89,  9,80,  8,96, 16,26,  3,41, 10,97, 19,66,  1,49,  2,19, 14,33, 
    19,59,  4,66,  7,26, 17, 8, 14,41,  3,63, 12,69,  8,64,  6,58, 18, 2,  9,92, 10,26,  2,13, 11,40,  1,88, 16,34,  0, 8, 13,45,  5,94, 15,72, 
    11,46,  4,95,  7,36,  2,26, 15,79,  3,76,  0,37,  8,73, 12,41, 10,94,  5,82, 16,36, 19,48,  6,96, 13,73, 18,79, 17,30,  1,15, 14,87,  9,34, 
    17,30,  5,17, 11,94, 10,82,  3,44, 18,78,  6,97,  0,99, 15,82, 13,87, 16,56, 14,87, 19,42,  9,52, 12,87,  7,15,  4, 1,  8, 2,  2,90,  1,71, 
     4,40,  8,13, 18, 6, 13,43,  3,46,  7,84, 15,66,  6,14,  0,66, 16,16, 19,94, 12,63,  9,16, 11,36, 17,40, 10,49,  5,53,  2,34,  1,60, 14, 8, 
     3, 1,  8,40,  6,59, 11,83, 12,69, 15,76,  4,38, 17,46, 13,65,  0,65, 16,61,  1,73, 10, 2, 14,63, 19,20,  7,74, 18,45,  9,40,  5,76,  2,70, 
    10,37,  8, 4, 12,33,  3,80,  1,41,  7,74, 15,67, 13,27, 16,83, 18, 2,  2,52, 11,53, 17,59,  0,27,  6,15,  4,44, 14,45, 19,17,  5,55,  9,59, 
     0,10, 17, 9, 18,19,  7,60, 10,88,  2,88,  1,29, 16,60, 13,48,  6,85,  5,89, 11,47, 14,98,  8,16,  4, 9, 19,98,  3,52,  9,95, 15,49, 12,96, 
     3,77,  2,96,  4,70, 11,19, 16,40,  8,97, 12,12,  9,63, 15,82, 13, 7, 14,76, 19,93,  5,86,  7,82,  6,46,  1,19, 17,47, 10,90,  0,45, 18,11, 
     6,67,  8,42,  7,17,  5,55, 10,59, 17,50, 12,58,  1,89,  9,90, 14,49, 13,86, 16,20, 15,41, 19,19,  4,53, 11,94,  3,87,  0,63, 18,53,  2,21, 
     2,20, 12,70, 16,20, 11,71,  0,39, 14,35,  4,19, 18,90,  8,60,  7,24,  5,77, 13,59, 10,55,  3,17,  9,35,  6,77, 19,93,  1,33, 17,60, 15,16, 
    17,53, 18,46,  6,12,  7,21,  0,20,  3,22, 15,27,  8,38,  1,43, 10,66,  9,38, 11,98, 14,55,  2,41,  5,99, 19,17, 16,91, 12,73,  4,24, 13,59, 
    12, 5,  9,82,  8,32, 17,28,  2,43,  5,50, 14,85, 13,58, 10,13, 19,50, 18,20,  1,51,  3,17,  4,54, 11,16,  0,20,  6,98, 15,45, 16,87,  7,56, 
     6,74,  2, 8, 13,20,  7,63, 16,93,  9,22,  4,87, 11,66, 12, 9, 14, 4, 15, 7,  8,30, 19,92, 10,36, 18,68, 17,78,  5, 6,  1,48,  0,85,  3,26, 
     0,44, 10, 4, 12,16, 13,72,  6,70,  3,52, 15,85,  4,79, 16,79, 14,76,  9,64, 11,71,  2,83, 18,37,  1,84,  5,11,  7,22,  8,28, 17, 2, 19,57, 
     3,86, 17,45, 15,13, 13, 3, 19,24,  7,47, 12,30, 11,19,  6,17, 18,25,  8,92,  4,75,  0,96,  5,24, 16,16,  9,74, 14,67,  1,70,  2,42, 10,90, 
    16,47, 18, 6, 10,19,  5,38,  4,12,  8,93, 15,55, 14,63,  3,41, 19,14,  0, 3,  6,11,  9,76, 17,32, 12,83,  7,33,  2, 2, 11,76,  1,73, 13,27, 
    10,58,  7, 2, 13,77,  8,72,  6,98,  5,60, 16,38,  2,44, 18,67,  9, 1,  3,57,  0,48,  1,37, 15,89, 12,81, 11,79, 19,81, 17,33,  4,22, 14,33, 
     1,26, 10,15,  7,17,  4, 9, 19,91,  3,40,  5,18,  9, 6, 13,49,  6,90, 15,11, 11,68, 17,26, 14,67,  2,14, 18,94, 16,85,  0,96,  8,11, 12,97, 
    14,15,  8, 3,  5,51, 16,15,  0,69, 19,12,  9,23, 15,33, 18,66, 10,24,  4,44,  1,78, 17,48,  3,50, 11,89,  7, 6, 12,58,  2,20,  6, 5, 13,69, 
    15,62,  2,52,  8,19, 18,92, 13,40,  0, 1,  6,97,  9,56, 17,74,  4,46,  3,33, 12,33, 10,28, 19,84, 14,51, 16,25, 11,59,  5,90,  1,38,  7,59, 
     0,64, 12,37, 15, 2,  1, 9, 10, 6,  3,34,  4, 1,  7,42,  9,92,  6,61, 19,48, 14,61, 17,62, 13,11,  2,78, 18,29,  5,40,  8,15, 16,61, 11,39, 
     9,81, 13, 9, 15, 4,  6,67, 17,35, 10,89,  8, 7, 16, 1,  1,55,  2, 3,  4,11,  0,35, 19,66,  3,19,  5,28,  7,69, 11,22, 14, 3, 12,42, 18,56, 
     4,91,  1,26,  2, 5,  5,98, 18,10,  0,72,  7,78,  8,81, 14,11, 16,51, 13,63,  6,80, 11,29, 12,63,  3,66,  9,80, 15, 3, 17,68, 10,50, 19,16, 
     4,95, 13,43, 17,70,  5,12, 10,73,  3,10,  2,88,  6,85, 14,43,  0,57, 16,70, 12,15,  9,13,  8,54, 15,96, 19,99,  7,18, 11,64,  1,85, 18,53, 
     4,48,  1,16,  3,56, 15, 9,  6,66, 18,83,  9,26,  7,40, 19,28,  5,73, 10,79, 14,47,  2,82, 16,59, 13,64,  0,37,  8,79, 11,27, 17, 6, 12,99, 
    13,99,  0,33, 19,85,  2,27,  5,93,  3, 3,  6,56, 16,11, 12,81, 11,42, 17,10, 10,73,  9,27, 15,59,  8,18,  7, 1, 14,62, 18,55,  1,59,  4,60, 
     0, 6,  5,67, 14,42, 11,39,  1,14,  4,39, 12,49, 10,12, 15,91, 19,67,  8,91, 16,69,  2,38,  3,13, 18,40, 17,39, 13, 4,  9,55,  6, 2,  7,85, 
     8,83, 11,15,  6,18, 12, 9, 18,87,  4,66, 16,24, 13, 2,  0,90,  1,54, 19,28, 17,87,  3,50,  5,76,  2,59,  7,28,  9,53, 10,79, 15, 9, 14,31, 
     6,71,  2,92,  0,38,  4, 6, 14,86,  1,17, 18,22,  3,88,  9,80,  5, 4, 11,13, 13,82, 12,44, 19,71,  7, 7, 16,36, 15,43,  8,10, 10,65, 17,21, 
     1,49, 13,50, 19,60,  2,63, 18,51,  5,62,  7, 4,  3,86,  8,27, 12,32, 15,32,  6,66,  4, 4, 14, 4, 16,23,  9,99, 11,99,  0,78, 10, 2, 17,38, 
     2,47,  0,76,  1, 7, 12,62,  7,32,  3,64,  8,28, 16,45, 14,65, 11,91, 19,36,  9,44,  4,80,  5, 5,  6, 7, 10,20, 15,54, 17,87, 18,85, 13, 5, 
     0, 2, 15,78,  3,78, 11,39, 17,94,  9,94, 16,83, 10,46, 12,97,  4,19,  7,64,  8,96, 18,22,  1,47, 14,32,  2,71, 13,93,  5,92, 19,13,  6, 9, 
    10,51, 13,48,  6,60, 14,99,  2,53, 17,35, 15,19,  5,78, 18,65,  8,72,  9,72,  3,60,  4,92, 16,15, 11,61,  7,29,  1,99, 19,74, 12,53,  0,11, 
    14,41, 10,54, 17,17, 12,91,  5,48,  4,80,  7,95, 11,84, 13,13,  8,91,  0,44,  2,81, 16,74, 15,44, 18,32,  9, 9, 19, 4,  3,13,  6,60,  1,83, 
    17,13,  6, 4, 12,23,  0,84, 16,41,  5,73,  9,77,  4,23,  7,16, 13,56, 11,19, 15,63, 18,72,  8,35,  1,62,  2,45,  3,50, 10,89, 19,38, 14,76, 
     9,17,  0,98,  6,22, 14,86,  2,32,  3,92, 12, 2,  7,27,  5,52, 16,41, 19,11,  1,46, 10,97,  8,45, 18,92, 11,55, 13,58, 17,95,  4,58, 15,20, 
    19,52, 15,90, 12,37, 17,63, 18,25, 14, 2, 13,50,  4,53,  1,67,  0,21,  6,86,  2,90,  9,31,  8,59, 11,45,  7, 5, 16,75,  3,93,  5,28, 10, 8, 
    11,17, 13,90, 10,80,  9,90,  2,72,  8,31,  5, 6,  4,85,  6,30, 18,60, 17,69, 14,91,  7,27, 12,29, 16,21, 19,36,  3,13, 15,74,  0,60,  1,11, 
     8,74,  0,80, 12,93, 10,91,  9,60, 13, 8,  1,96,  3,61,  4,73, 17,27, 19,62, 18,78, 15,45, 11,77,  6,62,  5,83, 14,25,  7,71,  2,11, 16,58, 
    19,98,  8,32,  5,97, 18,26,  2,16, 14,65,  3,16, 15,97, 12, 5,  4, 4, 16,95,  0,10, 11,88, 13,35,  7,77,  1,36,  9,44,  6,76, 10,75, 17,14, 
    11, 4, 16,47,  7,71, 14,32, 15,20, 19,54,  1,87, 13,59,  2, 5, 17,10,  9,43,  3,13,  6,24,  4, 8, 10,27,  0,33,  5,56,  8,13, 18,33, 12,35, 
    11,17,  3,19, 14,71,  0,91, 17,23,  4,25, 15,45, 13,69,  2,86,  8,91, 18,95,  1,36, 12, 9, 19,25,  5,48, 10,99, 16,87,  9,52,  6,19,  7,67, 
    13,72,  4,18, 18,91, 11,69, 15,13,  0,43, 16,80,  3,63, 19,41, 17,82,  1,20,  8,31, 14,83,  5,55, 12,89,  6, 5,  9,68,  2,38, 10,81,  7,41, 
     7,53, 13,63,  4,35, 19,69,  0,31,  8,39, 15,21,  5,97,  1,31, 18,11, 16,76,  3,29, 11,88,  9,68, 12,96, 10,79, 17,37, 14, 9,  2,80,  6,88, 
     8,99, 11, 8,  7,84, 18,70,  4,45,  0,91,  6,10,  9,97,  5,94, 13,73, 17,33, 10,20, 15,78, 12,43, 16,34,  2,92, 14,39, 19,36,  3,49,  1,73, 
    15,19,  3,16,  8,69, 11,96, 17,43, 16, 8,  9,70, 14, 9,  6,18, 10,41,  1,89,  4,40, 18,88, 12,89, 13,67,  0,58,  7,39, 19,44,  2,33,  5,17, 
     5,35,  7,76, 11,19, 18,57, 10,82,  1,99, 16,11, 13,39,  4,31,  9,25,  6,65, 14, 2,  8,77, 19,70,  0,68, 12,25,  2,74,  3,46, 15,31, 17,31, 
    11,45,  9,61,  6,54,  8,72, 18,35,  7,68,  1,89,  4,19, 17,69, 10,10,  3,74, 15,56, 12,64, 19,11, 16,12,  2,42, 13,92,  5,82, 14,60,  0,19, 
    10,23,  3,73,  4,26, 15, 4, 16,25,  1, 6,  2,33, 14,29,  7,11, 11,82, 19,29, 13,53,  0,83, 12,61,  6,26, 17,79, 18,97,  8,93,  5,32,  9,61, 
    17,69,  5,86, 11,43,  2,11, 13,25,  0,76,  7,57, 12,34,  6,64,  9,33,  4,68,  8,90, 14,63, 16,38,  1,44, 18,52, 19, 9, 15,53, 10, 7,  3,77, 
     4,54,  5,62,  0,42, 18,63,  9,87, 16,98, 19,94,  3,70,  1,26,  2,14, 17, 4,  6,85,  8,44, 13,71, 10,21, 11,37, 12,30, 14,46,  7, 2, 15,76, 
    10,13, 13, 7,  5,19,  0, 4,  7,39, 16,57,  4,52, 19,98,  9,27,  2,54, 11,77, 17,82, 14,66, 15,96, 18,43,  3,78,  8, 3,  1,12,  6,61, 12,67, 
     0,51,  4,49,  6,76,  3,30, 15,21,  5,98,  2,22, 10,64, 11,45, 14,14, 13, 1, 17,79, 16,69,  8,14,  9,71, 18,77, 19,74,  1,65,  7,57, 12,63, 
    15,16, 12, 9, 19,30, 13,62, 11,23, 18,47,  4,31, 16,22,  5,55, 17,99,  2,50,  8,42,  7,18, 14,49,  0,72,  9,56, 10,54,  6,95,  1,69,  3,93, 
     6,34,  5,90, 15,86,  2,45,  9, 5,  4,99,  1,79, 19,95, 17,95, 10,82,  0,95, 11,43, 12,34, 14,95,  7,52,  8,46, 16,66,  3,13, 18,43, 13,47, 
    18,72,  7, 3,  4,75, 17,32, 16,51,  9,57,  8,62,  3,51, 12, 2, 14,98,  6,63, 19,60,  2,93, 15,56, 10,53,  0,90,  1,93,  5,47, 13,78, 11,31, 
    10,13,  9,87,  5,26,  1,73, 14,37, 19,65,  0,34, 18,77,  3,46,  7,33, 16,78,  6,51,  4, 5,  2,73, 12,41, 13,71, 15,74,  8,44, 11,48, 17,52, 
    17,20, 15,40, 16,28,  4,58, 13,32,  1,73,  9,76, 10,84, 11,31, 19,38,  0,92,  5,13, 14,42,  8,76, 12,54,  7, 4,  2,76,  3, 7, 18,40,  6,28, 
    19,37, 11,79, 13,70,  6,49,  4,40, 18,25,  1,51, 12,66, 17,27,  9,94,  3,37, 14,35,  0,28,  8,85, 10,84,  7,37,  5,47, 16,53, 15,82,  2,86, 
     7,88,  8,97,  1,99, 15,81, 14,48,  5, 3,  3,67, 11,62,  2,41, 19,53,  4,68,  6,70, 18,48, 12,98, 16,36, 17,29,  9,38, 10, 1, 13,13,  0,83, 
     5,26,  7,82,  4,58, 16,13,  2,92, 19,35, 18,55, 10,88,  0,32,  1,75, 11,85,  8,98, 17,11, 13,39, 14,74, 12,61,  9,57,  3,59,  6,63, 15,53, 
     9,70,  5,28, 18,97, 16,81,  7,54, 15,60,  8,71,  0,15,  3,87,  6,25, 12,94,  1,39, 10,20, 14,74, 13,49, 19,82, 17,47,  4,62, 11, 5,  2,24, 
    15, 6,  8, 8,  9,52, 17,41,  1,33, 14,52,  3,28, 12,61,  5,86, 16,88,  6,66, 11,13, 10,64,  4,94, 13,10, 18, 9,  7,79,  2,56,  0,12, 19,74, 
    12,70,  0,99, 10,99, 11,25,  2, 7,  9,43,  7,88,  5,75, 16,74, 13,44,  6,44, 15,80,  3,41,  8,74, 14,57, 19,84, 18,19,  1,27, 17,25,  4,78, 
    14,64, 15,88,  8,45, 16,54,  5,46, 11,53, 12, 7,  0,96,  9,37,  3,92, 18,11, 17,38, 13,69,  6,93,  4,90, 19,28,  1,49, 10,78,  7,96,  2,45, 
     7,43, 18,86,  0,15, 14, 1, 12,51, 17, 7,  8,95, 10,80, 16,97,  4, 3, 19,74, 13,97,  2,70, 15,89,  6,64,  3,97,  1,40,  9,32, 11,52,  5,64
  };
  // Taillard 100x20 instance 7
  const int tai_100_20_7[] = {
    100, 20, // Number of jobs and machines
    10,63, 17,84, 18, 3,  2,53,  0, 1, 19,35, 15,20,  5,43,  4,43,  9,85, 14,23,  1,21, 13,10,  3,77,  7,83, 16,27,  8,35, 11,18, 12,44,  6,39, 
     6,97, 10,48,  0,63,  3,76, 17,18,  9, 9, 19,75,  5,36,  4,72, 12,79, 14,99, 18,94,  7,46,  8,16, 15,33, 11,42, 13,65,  2,98, 16,30,  1,50, 
     5,64,  1,48, 15,93,  4,47, 13,81, 11,31,  9,54,  6,89, 19,22,  8,63,  0,58, 12,25, 10,64, 17,82, 16,61,  2,64, 18,38,  3,17, 14,27,  7,70, 
    10,32, 19,72, 14,42,  0,83,  2, 2, 12,33, 13,29,  4,90, 11,35,  5,91,  8,26, 15,85,  7,72, 16,19,  1,95,  6, 5,  9,39,  3,75, 18,83, 17,70, 
    12,90, 14,76, 16,27,  1,88, 11,59,  4,95,  7,51, 13,22, 15,79,  8,30, 18,10, 17,91,  9,74, 10, 4,  2,36,  6,98, 19,54,  5,33,  0, 2,  3,22, 
    13,71, 14,99, 10,22, 11,64,  1,30,  2,11, 15,94,  4,14,  3,83,  6,47, 17,48, 19,45, 18,39, 12, 7, 16,32,  0, 2,  8,93,  5,40,  9,14,  7,48, 
     1,80, 10,46, 16, 4,  7,45,  3,64,  2,19, 12,85, 17,39,  5,78,  6,62, 18,69,  9,65, 15,82,  0,75, 11,40, 13,15,  8,68,  4,11, 14,44, 19, 3, 
     9,95, 13,89, 10,98, 14,75,  4,27, 12,74,  2,20, 18,57,  0,53, 11,94,  7,17,  3,78, 19,21,  1,99, 17,31,  8,99, 16,86,  5,20,  6,80, 15,86, 
     2,21,  3,52,  6,56, 15,22, 13,19,  5,84, 11,96, 18,57,  4,31,  7,39,  0,13, 10, 6,  9,58, 17,32, 12,41,  1,47, 14,13, 19,30,  8,44, 16,80, 
     0,71,  5,31, 15,17,  3,53, 18,85,  7,48, 14,52,  9,34, 16,39, 19,84,  2, 2,  6,31, 11,57, 12,63, 13, 1,  4,57,  1,30,  8,61, 10,72, 17,17, 
    14,14, 18,98, 13,44,  2,10,  8,53, 10,72, 19,65, 15,49,  9,21,  3,84,  1,94, 17,99,  5,61,  4,64, 16,29, 12,98,  6,55, 11,71,  7,43,  0,64, 
    11,14, 16,74, 15,57,  4,81,  9,40, 10, 7,  7,85,  5,32,  2,35,  8,34, 13,41, 14,79, 12,80,  6, 1, 19,95,  1,25,  0,43, 18,19,  3,98, 17,48, 
     8,42, 19,71,  5, 9, 12,26, 10, 3, 15, 3,  3,31,  4, 3, 13,40,  9,21, 17,69,  1,89, 16,94,  2,94, 14,59,  0, 9,  6,71, 11,53, 18,45,  7,75, 
     5,72, 10,86, 14,22,  7,71,  3,22, 13, 8, 16,73, 11,15, 15,90,  6,40, 17, 1, 12, 4,  4,81,  8,10,  1,83,  0,32,  9,89, 18, 4, 19,53,  2,38, 
     2,52,  3,45, 15,43, 14, 9, 19,90,  7,40, 11,26,  4,52, 16,22, 10, 9, 17,34,  9,94, 12,69,  1,28,  5,29,  8,62,  0,63,  6,99, 18,97, 13,14, 
    18,81, 12,50,  9, 9, 17,27, 14,91,  2,53,  3,93, 16,64, 15,23,  7,42, 13,77,  4,50,  0,84,  8,13, 11,90, 19,84,  1,81,  6,60,  5,92, 10,72, 
    16,87, 12, 4,  4,56, 18,40,  3,55, 17,29,  7,31,  2,29, 13,39,  5,38,  9,94, 19,40, 14,88, 10, 1,  0, 3,  8,46, 11,36,  1,44,  6,92, 15,34, 
     6,62,  7,95,  8,69, 15,29,  2,45,  3,77, 11,34, 18,59,  0,90,  4,83,  9,83, 17,72, 19,98, 13,53, 12,84, 10,94, 16,71,  1,49, 14,17,  5,28, 
     8,66,  6,24, 17,74, 12,73, 15,77,  5,75,  0,66,  3,14, 16,21,  7, 8,  9, 1, 13,39, 10,76,  4,14, 14,70, 11,20,  1,20, 18,66, 19,23,  2,74, 
     9,54,  5,35,  0,58,  6,72,  3,98, 11,62, 13,68, 15,87,  1,21,  7,67, 14, 9,  2,12, 17,45,  8,36, 16,43, 18, 3, 12,28, 19,24,  4,70, 10,45, 
    15,78,  7,28,  6,60,  9,69, 18,87,  3,34,  0,70, 19, 2, 16,83, 10,94, 12,22, 11,62,  4,37,  2,48,  8,20, 14, 5, 17,13,  1,75, 13,40,  5,27, 
     9,92, 11,78, 10,84,  3,97, 13,77, 17,84,  2,58,  0,85, 12,40,  8,56,  1,55,  6,63,  4,43,  7,36, 19,52, 15,43, 16, 2, 14, 9, 18,74,  5,80, 
     9,53, 18,85, 14,79, 19,79,  0,26,  8, 4, 11,19, 10,11, 12,11,  3,71,  7, 6, 16,67, 17,26,  5, 3, 15,10,  1,74,  6,60,  4,77,  2,34, 13,40, 
     0,23, 11,34,  2, 1,  1,83, 12,95,  5,19, 14,44,  4,40, 16,22, 10,58, 17,72,  9,18,  3,23,  8,16, 13,91,  7,37, 15,25,  6, 4, 19,92, 18,90, 
     9,93,  7,28,  0,48,  2,30,  1,90, 11,23,  3,73, 14,21, 19,29, 12,23, 13,44,  4,94, 17,28, 18,81, 10,53,  6,87,  5,68, 15, 1,  8,39, 16,46, 
    16,90, 15,58, 18, 7,  9,86,  8,88,  4,64, 13, 9,  6,78, 12,74, 10,42, 11,93,  3,15,  5,32,  0,77,  1,42, 17,27, 19, 9,  2, 3, 14,69,  7,16, 
    19,44, 10,60,  5,21,  3,87,  2,65,  0, 8, 13,65, 18,42,  8,31,  4,43,  6,50,  7,54, 15,41,  9,79, 17,80, 14,89, 16,18,  1,45, 11,57, 12,17, 
     3,53, 19,89, 16,59,  8,68,  4,58, 17,58, 11,74,  2,46, 10,54, 13,76,  7,66, 15, 3,  1,79,  6,75,  0,13, 18,85,  5,52, 14,27,  9,61, 12, 2, 
     4,74,  7,28, 16,29, 11,82,  9, 3,  6,31, 14,73,  3,47, 18,16, 10,54, 19,63,  0,27, 13,11,  1,79,  2,41,  8,65, 15,76, 12,61,  5,43, 17,28, 
    10, 3, 15,18, 14,48,  4,20,  8,65, 18,42,  3,55, 13,40, 17,17,  5,12, 12, 9,  7,32,  6,70,  2,26,  9,44, 11,33, 19,82, 16, 6,  1,37,  0, 3, 
    15,78,  7,33,  4,61, 14,81,  1,18, 17,75,  0,16,  9,31, 18,24,  2, 1, 10,36, 16,88,  8,57, 19,37, 11, 7,  5,76, 12,40,  6,79, 13,67,  3,19, 
    17,20, 13,36,  8,67,  9,64, 10,51,  5,56, 19,29,  0,15, 14,49,  6,72,  2,87, 12,77, 11, 5, 18,78, 16,32,  3,18, 15,83,  7,53,  1,84,  4,15, 
     9,55,  8,94,  7,78, 15,85,  1,21,  2, 5, 18,17,  5,96,  4,19,  3,72, 19, 2,  0,62,  6,18, 17,23, 14,64, 13,63, 11,90, 10,52, 12, 9, 16,16, 
    10,82, 19,20,  1,50,  6,21,  4,57, 13, 9, 12,49,  0, 5, 11,14, 14,71,  5,47,  9,35,  2, 8,  7,92,  3,73,  8,67, 18,66, 15,93, 17,48, 16,65, 
     8,82, 19,40,  4,14, 18,51, 12,86, 11, 8, 14,25,  2,76, 10,41,  0,10, 16,60,  9,96,  1,68,  6, 8,  5,79, 17,18,  7,75, 13,35, 15,31,  3,14, 
    19,45,  4, 2, 11,94,  0, 4, 16,27, 12,72, 18,76,  3,62, 15, 9,  1,14, 14, 7,  2,69,  6,48,  9,79, 10,52,  5, 4,  7,55, 17,75, 13,62,  8,93, 
    19,13, 13,63,  4,75,  0,67,  9,26, 10,59,  3,81,  8,55, 14,66, 18,28,  1,49,  2,16, 15,69, 17, 3, 12,13,  6,72,  5,76, 16,96,  7,63, 11,38, 
     5,36,  1,83, 12, 3,  3,10,  0,47, 14,65,  7,26,  9,62, 18,45,  2,55, 19,73,  4,30,  6,86, 13,53, 17,60, 15,41,  8,54, 16,33, 11,40, 10,20, 
    10,61, 12,28,  0,53, 17,79, 16,62,  5,87,  9,44, 14,21, 19,22,  8,67,  6, 8, 13,52,  4,43,  1, 8, 15,84,  2,26,  7,86,  3,62, 11,11, 18,74, 
     8,14,  2, 1, 18,30,  9,74,  6, 2,  4,87, 11,31,  0,84,  5,42, 10,11, 17,90, 16,42,  3,34, 19,14,  7,13, 14,75, 13,50, 12,61,  1,10, 15,76, 
     5,22, 12,58, 19,38,  7,14,  9,96, 14,76, 15,27, 10,16,  0,69, 16,49, 13,35, 18,93,  3,48,  8,43, 17,62,  4,34,  6,44,  1,51, 11,86,  2,50, 
     4,37, 18,48,  7,87, 12,78, 17, 6, 13,77, 19,98,  0,66,  9,33,  8,73,  3,67,  5,29,  2,77, 10,95,  6,40, 14,23, 15,69, 11, 1,  1,27, 16, 8, 
    19,64, 13,87,  6,50,  7,60,  9,50, 18,12, 15,33,  5,45, 16,16, 11,55,  0,88, 17,88,  1,25, 12,33,  3,15,  8, 2,  2,44,  4,75, 10,61, 14,67, 
     0,20, 19,95, 14,27,  2,69, 13,11, 12,23,  3,34, 15, 8, 17,64,  7,63,  4,73, 11,58,  9,33, 10,26,  1,84,  8, 4,  6,82, 18,35, 16,30,  5,51, 
     2,42,  7,63, 10,68,  0,93, 12,46, 16,60,  1,40, 13, 3,  9,73,  8,87, 19,52, 15,70, 14,35, 17,92,  4,19,  3,40,  6,48, 18,41, 11,70,  5,13, 
     7,53, 15,55, 11,32,  6,60, 18,40, 13,16,  2, 5, 12,53, 10,68, 19,43, 17,67,  5,60, 16,38, 14,23,  4, 2,  3,67,  9,42,  1,25,  8,80,  0, 1, 
    11,84,  7,99, 19,77,  5,51,  1,23, 15,77, 13,73, 17, 1,  2,65,  0,36,  9,88,  8,11,  6,80, 12,85,  3,51, 10,26, 16, 5,  4,83, 18,20, 14,60, 
    12,21, 13,12,  2,94,  3, 8, 15,14,  7,34, 11, 4,  8,58,  0,60, 19,51,  5,45, 18,95,  1,21,  6,92, 16,90, 17,77,  4,13, 14,51,  9,94, 10,33, 
    15,75,  0,85,  2,81, 19,81, 13,92,  9,96, 14,86, 11,91,  4,97, 10,12,  7,15, 16,11,  8,84, 17,27,  5,33,  3, 1, 18,87, 12,55,  1,32,  6, 8, 
     4,20, 10,71,  9,64,  0,85,  5,49, 11, 6, 14,52,  3,85, 13,15,  8,47, 17, 5,  1,23, 18,40, 15,46, 12,48,  7,87,  6,92,  2,54, 19,83, 16, 2, 
     3,74,  6,32,  5,15,  0,93, 15,14,  2,41, 13,97,  1,83, 11,29,  4,93, 19,30,  9,98, 18,15, 17,48, 16,31,  8,40, 10,36,  7,53, 12,26, 14,99, 
     7,59, 14,66, 16,28, 19,26, 11,65, 12,95, 15,54,  6,23,  8,25, 18, 3,  5,84,  0,72,  4,56, 13,94, 17,92,  9,15, 10,41,  2,27,  1,46,  3,52, 
     7,99, 15, 7,  8,33, 18,90, 13,82, 17,16, 14,81, 10,80, 19,75,  9,92,  1,93,  5,49,  2,14,  0,16,  4,49, 12,88,  6,51, 11,50, 16,11,  3,34, 
     7,43, 13,35,  4,91,  3,90,  0,34, 10,70, 12,22,  1,26, 16,55, 19,34,  6,55, 14,34,  2,68, 15,99,  8,24, 17,40,  5,25, 18,60, 11,13,  9,82, 
    18,68,  2,48, 14,64, 11,76,  6,15,  9,23,  5,62, 12,26,  1,39, 10,52, 13, 6,  0,47,  4,39, 17,81,  3,47,  8,98,  7,25, 16,58, 19,67, 15,46, 
    10,17,  4,35,  9,85,  1,15, 19,85, 17,46, 18, 5,  7,73, 12,63,  6,97, 15,21,  3,34,  2,59, 13, 2, 16,64,  5,88,  0,22, 11,17, 14,47,  8,77, 
     9,81,  2,60,  5,17, 15,25, 12,46, 17,80, 18,15,  1,31,  8,60, 10,28, 11,41,  0,35,  4,20, 14,81, 19,40,  3,51,  6,14, 13,36, 16,30,  7,75, 
     3,21, 15,93,  9,89, 19,15, 11, 8, 17,92, 10,19,  6,19,  8,45, 16,46,  4,97, 13, 6,  2,42, 12,60, 14,10,  1,37,  5,97,  0, 2,  7,51, 18,56, 
    19,60, 15,82, 18,95,  5,92, 17, 2, 14,78, 16,86,  1,66,  9,92,  0,93,  6,39, 12,58,  3,57, 10, 6, 13,18, 11,98,  7,52,  4,83,  8,36,  2,60, 
    11,55,  5,94, 12,93,  7,65,  4,33,  1,22, 17,38, 18,45,  8,18, 15, 7, 10,49,  2,81,  9,16,  3, 2, 14,67,  6, 8,  0,34, 19,49, 16,69, 13,35, 
    15,28, 17, 2, 18,78,  1,54,  3,14,  6,47, 19,71, 14,72, 16,51, 13,83,  9,24, 11,13,  0,11,  5,21,  4,71,  2,78, 12,68, 10,84,  7,47,  8, 7, 
     5,17, 17,85,  2,94, 13,95,  4,11, 19,58, 18,75,  1,70, 12,64, 16,16, 10,73, 11,22,  8,17,  6,45,  7,74,  3,83,  0,72, 14,13,  9,47, 15,79, 
    12,42,  7,37, 16,72,  9,16,  6,53,  8, 5, 18,62, 14,88,  5,35, 17,85,  4,58, 13,58, 19, 7, 11,81, 10,88,  0,74,  2,75,  1,67, 15,71,  3,58, 
    19,39,  2, 5,  7,92,  3,68,  8,34, 16,92,  9,17, 18,33,  1, 9, 10,55, 11,49,  5,49, 12,12,  0,24,  6,92, 14,70, 13,41, 17,37,  4,15, 15,22, 
     5,75,  7,34,  3,69, 12,48, 14, 7,  8,16,  1,27, 19,71, 17,11, 11,48,  9, 3, 18,39,  2,98,  0, 2, 10,39, 16, 2,  4,11,  6,68, 13,75, 15,49, 
    12,88,  3,16,  0,66,  9,34, 15, 2,  6, 5,  8,73, 16,25, 17,98, 19,57,  7,46, 14,91, 10,82, 18,51, 11, 1, 13,41,  5,57,  2,67,  1,28,  4,67, 
    16,37,  8,46, 18, 1,  3,87, 13,55,  9,25, 10,43,  6,10,  4,27, 11, 6,  5,91, 12, 2, 17,50, 14,94,  7, 1, 19,47,  0,79,  2,24, 15,64,  1,11, 
    13,32,  0,24,  3,84, 14,13,  6,11,  5,98,  8,74, 11,84,  4,82,  9,99, 12, 4,  7,98, 18,65, 16, 7, 17,88,  1,25, 10,68, 19,93,  2,73, 15,32, 
    14,42, 13,76, 18,43,  1,24, 11,92,  8,40,  2,36,  6,52, 15,59, 12,63,  5,15, 19,54, 17,70,  3,86, 16,48,  4,62,  9,20, 10,49,  7,15,  0,15, 
    19,42, 15,31,  5,80, 10,43, 12,80, 13,23,  0,89,  3,59,  6,19, 11,54, 16,15,  9,18, 17,89,  8,47,  1,38, 14,21,  2,87,  7,66,  4,76, 18,62, 
    15,54, 11,53, 12,19, 19,55,  1,83,  7,72, 13,13,  6,83, 17,54, 18,28, 10,22, 14,89,  0,13,  9,73, 16,24,  5,12,  8,82,  2,15,  3,78,  4,94, 
     4,18, 16, 3,  9,84,  6,89, 13,89,  0,73,  7, 5, 18,57, 10,38, 17, 9,  8,77, 15,17, 19,14,  3,32,  2,28, 14,15,  5,33, 12,48, 11,49,  1,40, 
     3,48, 12,33,  4,79,  0,42, 10,25,  2, 9,  7,25,  1, 1, 17,50, 15,55,  6,97, 11,96, 19,18,  8,25,  5,24,  9,77, 13,24, 16,52, 14,37, 18,88, 
     8,57,  0,50, 16,64,  2,89, 19,10,  4,80,  5,63,  6, 6, 15,32,  9,34,  7,34,  1,68, 12, 5, 13,76, 17,77, 11,86,  3,67, 14,76, 10,81, 18,51, 
    10,75, 17,91, 18,97,  7,14,  3,62, 14,40,  5,43,  2,16,  0,93,  1,55,  6, 4,  4,25, 19,29,  9,45,  8,83, 16,46, 15,31, 12,13, 11,57, 13,68, 
     5,64,  3,75,  2,35,  9,71,  1,38,  8,54, 11,36, 13,71,  0,66, 14,72, 10,58, 12,20, 16,67,  7,69,  4,46,  6,68, 18,93, 17,39, 15,48, 19,77, 
    13,59,  0,34, 14, 6,  6,76, 11,13, 12,59,  5,95,  7,78, 18,66, 10,92,  9,89, 19,77, 17,66,  4,16, 16, 7,  3,75,  1,97,  2, 7, 15,81,  8,13, 
     8,10,  2,38,  6,29,  7,38, 19,27, 11, 8,  9,59, 13,60, 10,36,  4,86, 14,39, 18,19,  3,84,  5,50, 15,65, 12,58,  1,62,  0,71, 17,22, 16, 6, 
     5, 6, 18,32, 14,38,  3,53,  0,59, 15,33, 11, 5,  9,37,  6,85,  2,33,  1,47,  4,70,  8, 6, 12,32, 17,86, 13,26, 10,36, 19,64,  7,78, 16,16, 
     6,60, 18, 4, 15,44, 16,14,  9,45, 13,83,  1, 7, 14,75,  3,86, 17,88, 19,25,  0,85, 12,99,  5,80,  8,50,  2,91,  4,14, 11,87, 10,73,  7,72, 
     0,92, 17,25,  6,93, 12,30, 11, 9, 16,86, 18,79,  5,71,  9, 5,  8,47, 13,61,  2,78,  3,76,  7,71, 15,98,  4,34, 14,23, 10,82,  1,53, 19,21, 
    16,91,  9,81,  2,70, 14,36,  1,96, 15,23, 17,55,  7,93,  3,86,  5,15,  4,19, 11,18,  6,66, 18,44,  8,58, 19,62, 10,54, 13,79, 12,11,  0,49, 
     4,62, 10,77,  0, 9, 14, 4,  2,80, 11,25,  1,16,  3,95, 12,30,  9,57, 18,40,  6,81, 15, 3, 13,28,  7,45,  8,59, 19,94,  5,31, 17,91, 16,55, 
    17,85, 14,23, 10,78,  4,68,  9,59,  2, 9,  3,71, 15,92, 11,50,  0,38, 16,35,  1,31,  5,91,  7,57, 13,70,  8,60,  6,73, 18,39, 19,76, 12,60, 
    17,61, 11,77,  0,22,  7,43, 13,66, 10,47,  4,53, 16,97, 15,91,  9,64,  1,93,  3,46,  5,20,  6,90, 12,58, 19,36, 18,98,  2,70,  8,49, 14,92, 
     3,35, 11,56, 10,45, 19,15,  7,79, 15,66,  6,55,  9, 1, 17,89, 13,29, 16,98,  8,31,  2,45, 14,51,  4,83, 18, 7,  1,76, 12, 5,  5,78,  0,77, 
    15, 8, 12,58, 18,24,  7,62, 13,77, 11,38,  2, 9, 14, 6,  5,88, 16,23,  3, 9, 17,12,  9, 9,  1,65,  6,68,  4,57,  0,38, 19,15, 10,98,  8,55, 
    13,96, 17,28, 14,52, 18,91,  5, 9,  8,15, 16,44, 11,69,  3,99,  7,15, 15,65,  2, 9,  9,27,  1,56, 12,70,  4,39,  0,21, 10,59, 19, 2,  6,15, 
     7,98,  4,84,  3,44,  1,10, 18,84, 12,78,  2,19, 13,80,  9,28, 14,19,  8,58,  5,76,  6,49, 16,88, 11,42, 19,78,  0,78, 15,91, 17,83, 10,29, 
     2,18, 19,40, 11,21,  6, 8, 17,31, 15,56,  0,56, 13,78,  7,45,  8,31, 10,79,  3,47, 12,73, 16,66,  4,27,  9,98,  5,73, 14,79,  1,74, 18, 8, 
     8,95,  3, 2, 17,41, 16,46,  1,19, 14,35,  2,41,  0,82,  4,77,  9, 3,  7,52, 18,15, 13,12, 12, 3, 10,30,  5,93,  6,96, 15,68, 19,73, 11,67, 
    17,92, 13,60,  7,45, 12,65, 18, 5,  8,81, 14,21,  6, 2,  3,71,  2,57, 16,18,  9, 2, 11,60,  5,41, 10,43,  0,36, 19,75, 15,55,  1,79,  4,38, 
    15,35, 12, 6,  5, 5, 19, 4, 11,39,  8,43,  6,76,  0,83, 16,38,  9,47, 14, 3,  2,68, 10,58,  1,49,  3,99,  4,20, 17, 9, 18,39,  7,11, 13, 9, 
    11,38,  2,56,  6,65,  5,54, 19,95,  3, 6, 18, 8,  8,53,  0, 9,  7,44, 10,39, 12,18, 15,77, 14, 6,  1,43, 16,26,  4,54, 17,64, 13,43,  9,71, 
     1,75,  4,31, 16,51, 14,95, 13,50,  7,98,  9,80,  2,38,  8,99,  5,78,  3,83,  6,38, 15, 4, 10,68, 11,44,  0,95, 12,77, 17,16, 18,89, 19,52, 
     5,10,  0,41,  3,52,  9,97,  2,55, 17,50, 19,48,  6,87, 14,97, 18, 1, 10,27, 15,69,  4, 4, 13,75,  8,59,  1,50,  7,22, 11,73, 12,73, 16,57, 
    12, 8,  6,62,  3,24,  8,29, 16,87, 13,72,  0,34,  1,23, 18,35,  9, 1, 11, 4, 15,42,  5,90,  2,23,  4,25, 17,62, 10,46, 19,14, 14,79,  7, 1, 
     9,13,  4,96, 10,43,  8,92, 14,11,  0,94, 12, 5, 17,34, 18,38, 19,68, 11,70,  7,65, 13,62,  1, 9, 16,35,  2,94,  5,12,  6,30, 15,91,  3,63, 
     2,33,  7,14, 15,79,  5,24,  9,11,  6, 5,  8,22,  4,61, 12,27,  0,88,  3, 4, 16,78, 11,62, 14,72, 19,56, 13,18, 18,62,  1,47, 10,27, 17,94, 
     1,34,  3, 6, 12,61, 15,60,  8,48,  6, 2, 13,64,  7,27,  5,16, 14,71, 18,71,  4,47,  9,52, 19,73, 11,42, 10,99,  2, 5, 17,72, 16,43,  0,27
  };
  // Taillard 100x20 instance 8
  const int tai_100_20_8[] = {
    100, 20, // Number of jobs and machines
    16,83, 18,46,  5,63, 13,19, 12,28,  9,87, 10,91,  0,61, 17,14,  4,84,  2, 9, 11,91,  8,24,  6,28,  7,60, 15,26,  3,11, 14, 6, 19, 4,  1,96, 
     6,70,  9,72, 17,45, 10,50,  1, 1,  7,46, 11,67, 13,43,  0,75,  5,44, 14,62,  4,91,  8,99,  3,96, 12,34, 18,60, 19,96,  2,19, 15,10, 16,52, 
     3,94, 13,42,  8,82, 18,39,  9,33,  2,48, 15,42, 16,32,  4,69,  1,93, 14,65, 10,74, 12,47,  6, 3, 17,31, 19,55,  0,81,  7,91,  5,71, 11,66, 
    10,49,  4,20, 13,37, 18,95, 19,24, 12, 6,  9,65, 17,34,  3,63,  7,50,  8,12,  6,64, 14,56,  2,31, 11,37,  1,93, 15,89, 16,32,  0,96,  5,47, 
     3,35, 19,15,  9,66,  4,89, 18,72, 15,47,  2,58, 10,34, 16,61, 17,50,  0,17,  6,31,  1,80,  5,84, 11,13,  7,43,  8,96, 12,73, 14,37, 13,97, 
     1,56,  7,64, 13,15, 16,78, 17,35,  5,71,  8,85,  4,63, 12,36, 19,91,  6,48,  3,26, 18,14,  0,55, 11, 5, 14,62,  2,57, 10,94, 15,53,  9, 6, 
    10,97,  6,18, 14,12, 19,65, 16,77,  4,69, 12,27, 17,78,  3,34,  8,59,  1, 2, 15,22, 13,77, 18,51,  9, 6,  2,25,  7, 6,  5,49, 11, 7,  0,97, 
     1,83, 14,27, 13,34, 12,98, 19,41,  7,43, 15,22, 16, 4, 17,45,  0,19, 10,44, 11,62,  6,79,  2,12,  8,31,  4,60, 18,34,  3,93,  9,95,  5, 1, 
     9,39,  5,74, 11,94, 16,68,  3,77, 18,10,  8,29,  7,60, 17,13,  4,38, 10,44,  2,64, 19,61,  6,95,  1,73,  0,37, 13,37, 12, 2, 15,13, 14,32, 
    10,12,  5,60,  6,43, 12,12,  1,40,  4,78,  7,66, 11,25, 13,76, 19,28,  2,68,  3,59, 17,10, 15,77, 14,87,  8,93,  9,45, 18,44, 16,95,  0,23, 
    18,55,  4,61, 16,62,  2,49, 19,62,  8,94, 12, 2,  0,93,  3,35, 10,82,  1,63,  9,25, 13,84, 17,61, 15,60,  6,95, 11,42,  7,19,  5, 1, 14,99, 
    15,13, 11,55,  8,31, 17,34, 12,70,  2,95,  0,86,  5,33,  3,64, 19,10, 16,97, 14,11,  9,79, 10,53,  6,87,  1, 5,  7,97,  4,78, 13,82, 18,58, 
    19,68,  8,25, 13, 8, 12,48,  1,86,  5,26, 14,66, 15,96, 16,27,  3,77,  0,20,  4, 5, 10,10,  2,64, 18,66, 11,57, 17,74,  9,96,  6,11,  7,83, 
     4,33,  6,44,  9,21, 15,31,  1,12, 12,19,  0,85, 14,16, 10,79, 18,98, 17,20, 13,18,  2,21,  8,77, 16,18,  3,45, 11,58,  7,49,  5,94, 19,88, 
    18,71, 19,36, 13,83,  8,48, 14,23, 17,84,  0,18,  9,95, 10,26, 16,94,  2,60,  5,28,  4,81, 15,71,  7,75,  3,63, 11,40, 12,65,  1,34,  6,97, 
     5,13, 16,50,  1,15, 18,85,  0,23, 13,57,  6,93, 12,84,  4,74, 15,55,  9,94, 14,13,  3,99, 17,10,  8,59, 10,60, 19,95, 11,76,  7,69,  2,14, 
    14,44, 17,64, 19,29,  5,69, 10,96,  1,23,  4,27,  2, 4, 11,13,  6, 8,  7,59,  8,29, 15, 3, 12,79,  0,14, 13,45,  3,59,  9,85, 16, 2, 18,75, 
     1,40,  5,33,  6,11, 17,61, 12,16,  8,85, 19,95, 14,83,  9,82,  4,94, 11,37, 13,50, 15,61, 16,82, 10,36,  7, 6, 18,14,  3, 2,  0,99,  2,78, 
     6,73,  9,48,  4, 8, 16,34,  3,80, 15,67, 11,47,  5,13, 10,99,  7,10,  2,31,  0,65, 17,65,  8,26, 18, 3, 13,47,  1,68, 19,11, 12,12, 14,43, 
    10,64, 12,45,  3,18,  6,24, 14, 9,  2,39, 17,98, 11,51,  5,28,  9,18,  8,34,  7, 2, 15,18,  4,24, 18,82,  0,36, 19,48,  1,51, 16, 2, 13,86, 
     9,68, 11,72, 15,54,  2,29, 17,85, 10,11,  4,36, 14,35, 18, 8,  6,47,  8,70,  3,56, 16,32,  7,97, 13,27,  1,32, 19,77,  0,50, 12,15,  5,64, 
     3,57, 17, 4, 19,87,  8,45, 12,72, 11,84,  1,64,  6,13, 14,33,  7,93,  0,20, 18,31,  2,69, 15,96, 10,59,  4,87, 16,82,  9,91, 13,91,  5,15, 
     8,40, 15,98, 18,95, 10,96, 13,28,  7,91,  3,65, 16,31,  0,12, 14,25,  1,11,  2,11,  4,69, 17,77, 11,52,  5,17, 12,44,  9,42, 19,76,  6,89, 
    11,86,  0,26,  6,77,  1,59,  7,54,  9,17, 10, 9, 14,37, 12,29, 15,37, 13,42,  8,26, 19,84,  5,98,  2,53,  4,50, 18,75, 17,37,  3,93, 16,60, 
    10,49,  2,67, 13,35, 11,64,  9,10,  4,17,  3, 1,  5, 6, 18,82, 19,75,  6,32,  1,41, 15,26,  8,93, 17,74,  0,90, 12,33, 16,35, 14,99,  7,50, 
    18,35,  1,71,  9,57,  3,46, 12,11,  6,44, 10,86, 13,53, 17, 4,  5, 1,  0,22,  4, 2, 11,40,  2,82, 15,60, 16,91,  7, 3, 19,45,  8,79, 14,72, 
    12,55, 16,56,  2,96,  8,29,  9,28, 19, 8,  6,29,  0,26,  3,78,  7,27, 14,29, 10,82,  1,31, 15,58,  5, 1, 11,83, 17,55, 18,81, 13,28,  4,99, 
     1,71,  4,42,  8,23, 15,55,  2,59, 14,97,  6,86, 18,20, 13,86, 12,32, 10,57, 16,63,  0,18,  9,95,  7,39,  3,90, 17, 3, 19,37,  5,87, 11,85, 
    12,60, 16,44, 17,77,  1,22,  4,75, 11, 4,  0, 6, 15,68,  9, 6,  3,19,  8,82,  5,95, 13,36, 10,48,  2, 7, 19,88,  6,54, 18, 2, 14,75,  7,13, 
     6, 7, 10,77,  2,77, 18,13,  5,97,  3,22, 13,21, 11,88,  4,90,  7,95, 17,11, 12,30, 19,61,  8,11,  9,39,  0,48,  1,88, 16,58, 14,23, 15,89, 
    17,56,  8,65, 16, 5,  4,89, 14,99, 11,60, 13,73,  7,56, 12,68,  3,63, 10,48,  1,70,  9,51, 15, 7,  2, 8,  5, 7,  6,43,  0,18, 19,18, 18,81, 
     3,52,  5,15,  4,75,  1,66, 15,92, 16,66, 17,16, 12,96,  7,72, 14,35, 11,26, 13,21, 18,69, 10,86, 19,15,  6,60,  0, 6,  9,61,  8, 2,  2, 8, 
    11,92,  3,84, 17,16, 16,27, 10,77,  1,82, 14,67, 18,74,  0,81,  4,92, 13,75,  5,92, 12,50,  8,83,  7,43,  6,42,  2,49, 15,51,  9,36, 19,89, 
    11,42,  3,97,  8, 2,  9,70,  2,59, 15,57,  0,30, 12,23,  7,49, 14,20, 13,68,  4,10, 10,61, 17,84,  6,15, 16,58, 18,28,  1,61,  5,67, 19,10, 
     6,29, 15,57, 14,26, 19,79, 13,71,  1,15, 17,46,  3,74, 16, 6, 12,97,  2,51, 10, 3,  8,63, 18,79,  0,85,  4,86,  9,43,  7,22, 11, 1,  5,39, 
     1,82, 14,35, 16,20,  8,49,  2,97,  3,15,  6,34, 18,92, 12,23,  5,60, 10,13,  7,52, 19,38,  4,34, 13,68,  0,97, 17, 1, 11,18, 15,73,  9,72, 
    11, 4,  6,86, 15, 2,  4,24,  3,42,  2,70, 16,55, 19,45, 12,49,  5,96, 18,78, 14,73,  7, 1,  1,48,  8,17, 13,53, 10,15, 17,48,  0,86,  9, 4, 
    16,87, 14,40,  9,55, 12, 7,  6,33,  2,44,  5,78,  1,21, 11,48,  8,92,  3,60, 15,69, 13,32, 18,75, 19,89, 10,72,  4,62, 17, 7,  7,50,  0,22, 
     0,74,  7,52,  6,82, 13,25, 16,24,  5,93, 15,74, 12,58, 14,83,  4, 2,  8,12,  3,76,  9,97, 19, 1,  2,11, 18,29,  1,57, 10,41, 11,29, 17,78, 
     5,32,  3,83,  2,80,  0,89, 13,99,  4,25, 16, 5,  6,29,  9,77, 10,41,  7, 6, 15,77,  8,71, 19,21, 18,14, 12,73, 14,61, 11,26, 17,54,  1,99, 
    14,19, 13,40,  3,68, 10, 4,  4,99,  5,72, 19,18, 15,45, 16,33,  9,41,  7,38,  0,75,  1,61, 12, 8, 18,73,  8,80,  2,73, 17,64,  6,33, 11,14, 
    14,77, 19,61,  5,21, 11,82,  7,77,  3,24,  9,96,  1,35,  4,11,  2,23, 15,77,  6,86, 12, 8, 17, 5,  0,43, 13,12, 18,34,  8,31, 10,44, 16,15, 
    11,51,  7,63, 19,19,  4,14,  3, 5, 13,50, 17,18, 16, 4, 14,84,  2,50,  1,41, 12,39,  8,98,  5,67,  6,31,  0,59,  9,69, 15,91, 10,67, 18,34, 
     4,92, 15,57,  8,73, 19,80,  1,57, 13,77, 18,83,  2,97, 17,47,  0,95,  5,84, 11, 9,  6,56,  3,51,  7,32, 14,11, 16,67,  9,46, 12,50, 10,69, 
    12,40,  8, 1, 13,51, 11,33,  1,75, 17,63, 19,62, 14,54,  0,36,  4,17,  7,59,  6,96, 10,68,  9,44,  3,57, 15,89,  5,50, 18, 9, 16,11,  2,10, 
    18,45,  1,99, 19,92,  2, 8,  5,77,  8,15, 17,80,  4,13, 11,50,  9,30, 14,66, 12, 9,  7,77,  0,72, 16,26,  6,96, 13,85,  3,58, 15,43, 10,42, 
    12,56, 10,28,  1,81,  3,20, 15,12, 13,14,  2,47,  8,83,  9,64, 11,44, 18,42, 19,68,  5,95,  7,17,  4,55, 16,62, 17,69,  0,71,  6,93, 14,12, 
     7,17,  6,26, 12,98, 10,49,  8,78, 14,36,  9,87,  1,96, 16,32,  5,23,  0,56, 11,84,  3,21,  4,69, 19,98, 17, 9, 13,75, 18,78, 15,32,  2,57, 
     8,33,  5,82, 18,69, 17,32,  7,61, 15,49,  1,61, 10,98, 14,81, 13,61,  3,19,  6,63, 12,46, 19,81, 16,22,  0,80,  4,43, 11,20,  9,57,  2,31, 
     5,97, 13,65,  4,83, 19,61,  7,35, 12,85, 10,98,  2,56,  9,21, 14,96, 17,20,  1,79, 11,70, 15,38,  6,31, 16,57, 18,33,  3,83,  0,58,  8,29, 
     7,37, 11,23, 13,32, 19,94,  9,86,  6,44,  2, 6,  4,61, 14,22, 12,15, 18,42, 17,67,  3,36,  0,83, 16,52, 10,49, 15, 5,  8,85,  5,63,  1,60, 
     5,99,  2,95,  4,66, 18,61,  7, 5, 14, 6, 13,57, 16, 3,  8,37, 19,87, 17,27, 15,11, 11,28,  9,61, 12,93,  3,74,  1, 5, 10,42,  0,45,  6,51, 
     7,18, 10,44, 19, 4, 13,65,  9,82, 12,97, 16,28,  1,62,  5,36, 14,96,  6,76, 18,59, 17,51,  8,16,  2,89,  0,39,  3,55, 11,10, 15,24,  4,62, 
     0,78,  1, 8,  3, 9, 18, 4, 14,48, 10,48,  5,77,  9,65,  4,71,  6, 4, 12,18, 11,93, 15,70,  8,41,  7,27, 13,85, 17,62, 19,20, 16,27,  2,90, 
     7,57,  4, 1, 12,14, 17,11, 19,38, 13,74,  1, 6,  6,72,  3,16, 10,11,  0,25,  5, 5, 15,86,  2,83,  8, 5, 14,41, 16,52, 11,39,  9,80, 18,74, 
     5,76, 16,47, 13,33,  8,31, 18,61,  3,78, 15,27, 12,68, 17,34, 14,99,  1,44,  7,64,  9,13, 10,45,  4,55,  6,19, 19,99, 11,34,  0,84,  2,74, 
    17,38,  7,79, 14, 6, 12, 8,  3,12,  9,72,  5, 4,  8, 4,  0, 8, 10,55, 11,23,  1,77,  6,52, 16,55,  4,54, 15,30, 13,84, 19,79,  2,66, 18,21, 
     5,59, 14,31,  7,83,  9,57, 10,67, 12,17, 15,70, 19,23, 18,14, 13,54,  8,10,  1,24,  0,79, 17,67,  6,77,  4,90,  2, 7,  3,94, 16,34, 11,69, 
     1,36,  9, 7,  8,27, 11,16, 13,16,  5,10,  3,60,  7,78,  6,80, 14, 7, 17,37, 18,76, 10,31, 16,36,  0,26, 12,63, 15,78,  2,78, 19,92,  4,46, 
    19,71, 16,60, 10,74, 17,29, 14,27, 13,57,  4,83,  3, 5,  5,12,  6,68,  2,96,  8,25, 11,50, 15,85,  9,23,  1, 1,  7,77,  0,74, 18,21, 12,33, 
    16,24, 14,21,  6,94, 17, 4,  9, 3,  4, 4,  3,56,  5,23,  2,70, 15,42, 11,68,  7,98, 18,48, 12,48,  1, 9,  8,98,  0,64, 13,69, 10,56, 19,84, 
     7,99, 15,52,  3,52, 12,72,  9,95, 17,10, 13,94, 10,51, 11,77,  1,13, 14,82, 16,61,  6,68,  0,39,  2,60, 19,43,  5,94,  8,28,  4,36, 18,77, 
    19, 4, 10,45,  4,11,  9,16, 13,98,  5,94, 16,20, 12,99,  2,89,  1,63, 17,35,  7,72,  3,88, 15,22, 18,72, 11,71, 14,69,  8,50,  0,77,  6,40, 
     1,67, 10,90,  3,46, 17,10, 11,19,  0,24,  5,36,  6,38, 15,73,  9,74, 16,33,  2,17, 14, 9, 18,15,  4,95,  7,33, 12,46,  8,85, 19,34, 13,51, 
    12, 9, 11, 8, 13,97,  7,64,  4,64, 17,96, 15,33,  6,26,  9,88, 18,67, 14,20,  1,18, 16,67, 19,51,  5,77,  0,43,  2,77,  3,83,  8, 9, 10,20, 
    19,43,  0,21, 16,51, 10,35, 13,11, 18,30,  4,89, 14,48, 17,70, 11,62, 15,56,  7,94,  2,12,  8,25,  9,83,  1,21, 12,91,  6,80,  5,43,  3,75, 
     9,13, 10,35,  8,43,  6,80,  3,53, 19,11,  7,97,  1,29, 18,83, 17, 6, 13,73,  0,10, 14,55, 11,32,  2,49, 16,50, 12,22,  4,86, 15,20,  5,81, 
    13,55,  4,22,  2,91, 19,63,  3,15,  9, 5,  8,96, 12,53, 14,68, 18, 5, 10,59,  0,18,  5,87, 11,76, 17,19, 16,92,  1,18,  7,17,  6,20, 15,29, 
     0, 8, 16, 2,  7,32,  3,12, 13,55, 18,27, 17, 9, 10,60, 15,44, 14,86, 12,66,  6,52,  9,35,  4,21, 19,76,  1,50,  5,58,  8,25,  2,26, 11,22, 
    19,18,  0,94,  5,83, 16,51,  6,91, 18,74, 13, 9, 11,29,  2,93, 15,75, 12,62,  4,46,  3,68, 10,77,  1,34,  7,65, 14,73,  9,73,  8,40, 17,44, 
     6,53,  1,17,  3,56, 19,38, 12,63, 16,65, 10,38,  4,65,  7,48, 15,59,  8,40, 18,33,  5,15, 13,86,  9,66, 17,38, 11,95, 14,80,  2,47,  0,10, 
     4,40,  9,68,  8,53, 14,69,  5,22,  0,97, 10,49,  1,71,  2,82,  6,78,  7, 3, 19,17, 18,20, 12,52, 17, 8, 15, 5, 11,99,  3,64, 13,85, 16,61, 
     4,94,  1,12,  6,38, 10,68, 13,48, 12,33, 19, 8,  0,42,  3,81,  5,54, 14,67, 15,63,  8,45, 11,44,  7,11, 18,48,  2,25,  9,26, 17,56, 16,48, 
     6,59, 10,38,  5,83,  0,43, 18, 8,  9,29, 19,56, 16,54,  8,34, 15,41, 11,51,  3,89, 14,83,  1,13,  2,61,  4,13, 13,33, 12, 5, 17,36,  7,10, 
     9,94,  0,42, 13,54, 16,41,  8,78, 15,80,  4,53,  1,98,  6,10, 14,86, 19,19, 18,72, 17,24,  2,96, 12, 6, 10,14,  3,27,  5,19,  7,19, 11,88, 
    18,63, 14,34,  3,66,  8,80,  6,61,  0,12, 12,30,  9,31, 16,40, 11,94, 19,92, 10,89,  7,58,  4,49, 13,29, 15,93, 17, 1,  2,56,  1,50,  5,99, 
    15,97, 18,72, 14,27,  4,38,  6,72, 13,90,  8,91, 17,51,  9, 9,  1,14, 16,67,  7,65,  0, 4, 12,13,  3,84, 10, 1,  5,20, 11,73,  2,12, 19,62, 
     1,82, 10,84,  0,45, 12,46,  9, 5,  6,25, 13,31,  8,60,  2,12, 11,32, 19,21, 14,50,  4,77,  3,36, 15,86,  7,34, 18,11, 17,12, 16,60,  5, 1, 
     0,41,  4,22, 15,20, 10,76,  1,45,  5,60,  8,97, 16,82, 19,33,  2,59, 14,48, 11,58,  9,95, 18,45, 13,21,  3,85, 12,82, 17,50,  7,18,  6,21, 
    10,21,  5,66, 17,31,  3,15,  4,92,  7,11, 13,34, 16,46,  0,28, 19,96, 14,72,  2,79,  6,85,  1,78, 11,31,  9,76, 15,25, 12, 2, 18,20,  8,67, 
     5,77,  6,39, 18,71, 13,83, 11,70,  9,47, 10,32, 14,11,  2,26,  7, 1,  1,75,  0,17, 17,77,  4,98,  8, 5, 15,10, 19,11, 16,33, 12,73,  3,67, 
    18,16,  9,39,  6,29, 12,27, 10,70,  3,52, 13,11,  1,26,  7,62, 14,19, 17,99,  0,38, 11,95,  4,13, 19, 3, 16,44,  8,30, 15,46,  2,72,  5,89, 
     0,65, 10,97, 17,23, 12,38, 14,57,  3,73,  1,33, 16,11,  7, 9,  4,96,  9, 4, 11,78, 18,38,  6,54, 13,63, 19,98,  2,86,  5,58, 15,49,  8,96, 
    14,95, 12,86,  3,58, 11,46, 10,51, 16,99,  1,59,  2, 4,  0,33,  5, 6, 17,50,  8,49,  6,62, 19,69,  7,37, 15,65,  9,12,  4,56, 13,88, 18,82, 
     3,61, 14,53, 11,33, 13, 5,  8,38, 18,63,  7,35,  0,74, 19,56,  4,54, 16,73,  9,17, 15,61, 10,49,  2, 4, 12,76, 17,11,  5,64,  6,70,  1,50, 
     8,17,  4,35, 17,73, 15,28,  0,81, 11,18, 13,95,  6,26, 12,93,  3,32,  2, 3,  7,39,  5,13,  1,97,  9,94, 16,53, 18,11, 19,80, 14,30, 10,28, 
     3, 1, 18,98, 19,32,  7,56, 15,39,  2,29, 14,33, 12,82, 10,57,  5,17,  0,39, 17,77, 13,73,  8,12,  4,91,  9,67, 11,72, 16,94,  6,14,  1,73, 
     1,36,  3,48, 18,66,  7,23, 16,52,  0,92,  9,90, 13, 1, 12, 1,  6,39,  4,49, 11,25,  8, 4, 14,16,  2,74, 19,36,  5,51, 17,61, 10,16, 15,56, 
     0,90, 11,21, 16,99, 14,29,  4,49,  1,13,  7,94,  5,26,  2,20, 17,73, 10,21, 15,28, 18,54,  8, 3,  3,97, 19,43, 12,48,  9,55,  6,20, 13,70, 
    16,64, 18, 6, 11,72,  3,74, 17,25,  5,43,  4, 8, 19,20, 15,80, 13,89,  7, 6,  0,44, 14, 2,  1, 6,  8,54,  6,51, 12,41,  2,98,  9,90, 10,94, 
    16,91,  8,59, 15,27,  6,65, 11,45, 13,22,  5,97,  9,53, 12,72, 10,47,  3,98,  0,49, 18,76,  1,86, 17,82, 19,52, 14,62,  2,48,  7,37,  4,25, 
    19,97,  0,28,  3,87, 14,56, 11,96, 10,14,  9,78,  4, 5, 16,29,  8,14, 12,73,  7,52, 13, 2,  2,34,  6,19, 18,16, 17,21,  5,79, 15,71,  1, 6, 
    12,93, 16,14,  8,82,  0,81,  5,55,  4,54, 10,51, 13,61,  2,22, 19,28, 14, 3, 18,35, 11,22, 15,46,  6,80,  3,66,  1,92, 17, 2,  9,17,  7,61, 
     4,53,  1, 2, 16,51, 13,65, 10,75, 14,14, 12,13,  7,51,  8,18, 11,79, 15,25, 17,52,  9,49,  3,43,  0,49,  6,83, 19,36,  5,54,  2,43, 18,72, 
     3, 1,  0,32, 17,66,  6,52,  5,90, 12, 8, 13,33, 18,72, 19,80, 14,40,  4,38,  9,98,  2,71,  7,98, 16,14, 11,35,  1,23, 10,22, 15,23,  8,93, 
     2,49, 19,16,  9,85, 14, 9,  3,61,  1,21,  0,86, 16,14,  6,81,  7,59, 15,34, 17,59, 11,19, 13,85, 18,29, 12,67,  4,46,  5,90,  8,42, 10,23, 
    16,25, 18,84,  7, 4, 17,53,  1,91, 10, 1,  8,26, 12,19,  2,98, 11,97,  0, 5, 14,24,  9,76,  4,28,  5,18,  6,81, 15,70, 13,84,  3,11, 19,66, 
    13, 5, 15, 6,  9,81, 12,49,  7,30,  0,77, 16,44, 19, 2,  2,73,  1,78,  8,15, 10,38, 11,39,  6,88, 18,72,  4,69, 14,30,  3, 6, 17,46,  5, 7, 
     9,41,  5,14, 14,85,  7, 1,  3,69,  4, 9, 19,43, 16,88, 17,44, 12,85,  6,80,  1,50, 11, 3, 13,31,  8,74, 10,88, 15,85,  2, 3,  0,72, 18,85, 
    11,78,  4,50,  8,76, 12,48,  3,38,  2,84, 10,21, 13,57, 16,72, 18, 8, 17,55,  0,56,  1,23,  9, 4,  5,57, 15,56, 19,58,  6,27, 14,66,  7,11
  };
  // Taillard 100x20 instance 9
  const int tai_100_20_9[] = {
    100, 20, // Number of jobs and machines
     9,54, 12,87,  4,61,  7,35, 16, 5,  0,48,  1,33, 18,21, 17,65,  5,83, 14,78, 11,14,  8,70, 10,25,  3,36, 15,56, 13,87,  2,32, 19,96,  6,62, 
    17,68, 13,15, 19,22,  6,53, 10,33, 11,61,  1,73,  7,63, 16,96, 18,61, 14,88, 15,86,  5,53,  3, 2,  9,29,  2,14,  0,49,  4,14,  8,22, 12,66, 
    17,68, 10,70,  3,84,  4,19, 19,32,  7,58, 15,87,  0,82, 16, 7, 12,47, 14,68, 18,71,  8, 3, 11,93,  6,24,  2,31,  5,19,  1,56,  9,88, 13,71, 
     9,58, 19,72,  3,51, 10,42,  1,31,  5,63, 16,49, 14,83,  7,28, 17,92, 18,83, 13, 7,  4, 7,  0,30, 11,14, 15,27,  8,58, 12,32,  2,16,  6,67, 
    13,36, 16,51,  4,65, 15,40,  9,79, 10,39,  0,33,  2,77,  3,84, 11,68, 17,71,  5,54, 19,40,  7,94, 18,56,  6,94,  1,55, 12,10, 14,13,  8,13, 
    16,51,  7,27,  9,31,  6,65, 13,26,  5,62, 18,88, 11,69, 17,47, 19,36, 14, 3, 15,90, 10,90,  0,31,  4,24, 12,35,  2,24,  1,68,  3,18,  8,70, 
    14, 8,  5, 6,  1,93, 10,60,  9,68, 13,32, 16,95, 17,17,  2,12, 18,79, 19,78, 12,26, 15,15,  6,83,  0, 8,  3,31,  7, 5,  4, 6, 11,36,  8,75, 
     1,41, 11,95, 10, 4,  3,98, 17,22,  9,64, 14,41, 18,56,  0,23,  4,72, 15,10, 16,35,  6,55, 12,17,  7,10,  5,32, 13,76,  8,49, 19,95,  2,14, 
     2,96, 17,23,  8,44, 19,19, 10,90, 13, 6, 15,67, 12,37, 16,64,  1,80, 18,98,  6,66, 11,74,  0,65, 14, 3,  3,15,  9,50,  7,98,  5,46,  4,80, 
     3, 1, 17,65, 11,36,  0,35,  5,95, 15,99, 13,82, 12,46, 16,26, 10,35,  2,96,  6, 6,  4,28,  9,92, 19,12,  8,42,  1,47,  7,78, 18,10, 14,76, 
     2,78,  8,99, 14,90,  5,46, 15,71, 13,76, 10,45, 19,96, 12,58,  9, 3,  4,70,  0,80,  6,30,  3,85, 18,93,  7,16, 16,26, 11,79,  1,44, 17,21, 
     1,82, 13,16,  8,56,  3,35,  7,81, 14,97,  9, 5,  6,68, 10,60, 15,33, 19,57, 11,42,  4,72, 16,77,  2,53,  0,26, 18,66, 17,81,  5,84, 12,84, 
     5,29,  0, 6,  7,38,  1,96,  4,85,  8,36, 10,71,  3, 5, 13,53,  9,11, 11,87, 17,99, 12,42, 14,69, 15,74,  6,34,  2,25, 19,10, 16,25, 18,32, 
     7,40, 19,73,  5,80,  6,70,  9, 7, 14,35,  8,35,  4,20,  3,68, 15,29,  1, 7, 10,12, 11,70, 12,47,  2,46, 16,78,  0,28, 13,48, 17,50, 18,22, 
     2,94, 18,79,  0, 1, 13,39,  6,33, 16,94,  5,69, 19,19, 14,29,  9,33,  7,72,  3,48,  1,88, 10, 9, 17, 1,  8,99,  4,20, 11,29, 12,83, 15,44, 
    12, 4, 11,18,  1, 9, 17,82,  4,59, 13,64, 16,56, 18,78,  6,23,  7,61,  8,80, 10,91,  2,38, 14,89,  5,85,  3,23,  9,48, 19,90,  0,29, 15,97, 
    11,10,  8, 9, 10,82, 17,28,  3,48, 14,66,  1,22,  9,32, 13,34,  5,43, 19,64,  4,43, 18,24,  6,88, 16,44, 12,15,  7,28,  0,54,  2,94, 15,80, 
     2,50,  7,54, 15,27,  0,69, 17,34, 18, 5, 10,22,  3,29, 16,47, 11,24, 19,52, 13,26,  9,51, 14,58, 12,50,  5,84,  8,15,  1,93,  4, 2,  6,16, 
    16,71, 12,25, 15, 2, 11,75,  5,62,  3,79,  2,35,  8,87,  0,19,  6,50, 10,33,  7,79,  9,63, 18, 9, 17,24, 19,39,  4, 2, 14,20, 13,84,  1,53, 
     1,78, 14,11, 19,42,  0,60, 10,76, 16,57, 15,29,  7,50, 17,79, 18,81,  3,19,  4,24, 13,91,  8,57,  5,80,  9,74,  6,99, 11, 4,  2,62, 12, 2, 
    12, 4,  9,65,  2,42, 15,97, 14,56,  8,92, 17,49,  6,83,  1,18, 11,86, 10,48,  5,24, 16,42, 13,99,  4,87,  3,59,  0,22,  7,34, 18,63, 19,45, 
    11,54, 17,64, 18,80, 12,51, 19,75, 14,42,  8,60, 10,33, 15, 6,  7,90,  2,32,  1,77,  4,11, 16,63, 13,40,  9,30,  0,37,  6,62,  3,94,  5, 8, 
    18, 6, 12,77, 17,76,  8,23,  5,61, 10,90,  6, 6,  9,85, 13,45,  0,86,  2,10, 15,71,  7,13,  4,68, 16,16,  1,33, 14,95, 11,52,  3,88, 19,39, 
     9,47, 12,30,  8,67, 18,99,  5,52,  2,29, 15,23, 11, 8,  0,77,  6,80,  1,46,  4,54, 17,64,  3,45, 13,17,  7,12, 14,35, 19, 3, 10,81, 16,15, 
    18,24, 16,50, 17,47, 11,88,  6,68,  8,42,  1, 2,  7,24, 12, 2, 10,63,  3,88,  9,72, 14,28,  0,47, 19,31,  2,62,  5,59,  4, 6, 15, 9, 13,60, 
    17,68, 15,82,  6,22,  4,44,  7,55,  1,25,  0,45, 13,75,  9,13, 19,84, 18,17,  5,67,  3,21, 10, 6,  2,49, 16,67, 11, 7,  8,74, 14,29, 12,20, 
     3,73, 15, 2,  7,26,  8,15, 10,29,  9,44,  2,26, 17,99, 19,86, 14,59, 16,13,  5,90,  1,13, 18,17, 12,68, 11,88,  0,42,  4,61, 13,65,  6,72, 
     3, 3, 17, 1, 12,40,  9,33,  4,29, 10,42, 15,13, 13,15,  0,78, 11,37,  8,30,  2,92,  1,49,  5,91, 19,42,  7,74, 16,53, 18,59,  6,56, 14,32, 
    19,31, 16,84, 18,29, 13,75,  5,68, 11,12,  8,29,  9,51,  0,76,  2,98, 14,33, 17,99, 10,28,  4,17,  6,89,  1, 4,  3,21, 12,84,  7,90, 15, 4, 
    18, 5,  8,69,  2,19,  6,45, 12,35, 17,89, 19,40, 10,38,  9,30, 15,52,  5,73,  1, 7,  3,45,  7,60, 14,43, 13,55, 11,10,  4,97,  0,93, 16,63, 
    12,76, 13,61,  1,21,  3,41, 18,74, 17,51, 15,36,  6,49,  5,26,  9,31, 11,67, 16,69, 14, 6, 10,54,  0,65,  8, 7,  4,70,  7,45,  2,32, 19,25, 
     7, 1,  8,69, 13,28,  0,25, 16,25, 12,24, 15,74, 17,48,  6, 4,  4,12, 11,80, 18,28, 10,75,  9,82,  2,34, 14,99,  5,19, 19,59,  1,10,  3,11, 
    11,46, 17,81, 19,64,  7,28,  6,89, 12,71, 16,29,  9,27, 13,81,  0,34,  2,78, 15, 7, 10,51,  5,25,  4,47,  1,14, 18,32, 14,47,  3,90,  8,31, 
     6, 4,  8,40,  9,32, 17,52, 16,37,  4,35, 10,85, 14,26, 18,45,  2,58,  7,42, 19,75,  5,13,  0,15,  3,86, 11,74, 13,98,  1,19, 15,45, 12,60, 
    16,44,  8,65,  3, 5,  4,30, 13,51,  1,42,  2,88,  9,79, 10,47,  7,46, 12,62,  6,50, 17,58,  5,82,  0,51, 18,89, 11,89, 19,63, 15,59, 14,84, 
     7,50, 11,61,  2,36, 15,14, 16,65,  4,86, 18,87,  0,28, 17,50, 13, 8, 19,99, 10,73,  9,96, 12,94,  1,87,  6,68, 14,96,  8,69,  3,19,  5,33, 
    12,81,  6,81,  0,29, 17,54,  5,24, 10,55, 13, 5,  8,36,  1,48, 16,41,  4,34,  7,33, 11,48, 19,37, 18,32,  2,34,  9,52, 14,27,  3,80, 15,14, 
     2,36,  8,31,  7, 7, 10,88, 17,99,  6,55, 13,11,  3,65, 19,47, 18,18,  9,46, 12,39, 11,78, 14,46,  1,81, 16,31,  5,80,  4,35, 15,92,  0,51, 
    10,65,  3,46,  1,31, 15, 3, 14,21, 11,55, 13,11,  2, 5, 16,40,  4,52,  8,99, 18,11, 12,36,  9,83,  5,92,  7, 5, 19,19,  0,58, 17,47,  6,34, 
     8,50, 14,56, 19,57,  2,27, 18,20, 17,26, 16,71,  5,59,  6,14, 13,46, 10,22,  3,66,  7,20,  0,33,  4,39, 12,33,  9,86,  1,30, 15,37, 11,77, 
     9, 1,  1,51, 19,77,  6,72,  4,87, 17,50, 13,94,  7,84, 15, 8,  8,73,  0,13,  2,12, 10,97, 16,86, 14,63, 18,44,  5,14,  3,67, 12,19, 11,52, 
     8,22,  7, 5,  4,51, 14,18, 18,23, 16,97, 19,91, 15,86,  2,13, 10,27,  6,68, 12,44,  9,93,  5,82,  0,17,  1,48, 13,98,  3,30, 17,86, 11,92, 
     2, 5,  9,92, 18,10,  7,63, 16,41, 13,26, 14,14, 15,30, 10, 3, 17, 9, 11,99,  3,54,  5,14,  0,98,  8,23, 12,11,  4,66, 19,48,  1,25,  6,79, 
     6,82,  2,50, 16,86, 10,19, 18,70,  0,76, 17,99, 19,34,  3,53,  5,23,  7,89, 14,82,  9,19, 12,55, 15,15,  8,23,  4,99, 13,63,  1, 1, 11,75, 
    10,43,  0,25, 12,40,  1,18,  6,43, 14,86, 18,75, 11,24,  7,82, 16,24,  9,71,  8,89,  4,67, 15,28, 13,96, 19,20,  5,14,  3,85,  2,59, 17,38, 
    14,28,  5, 8,  4,99, 19, 8,  9,53,  8,51,  3,92, 12,61,  1,79,  0,73, 15,80, 18,24, 17,55, 13,73, 10,55,  6, 9, 11,66,  7,22, 16,95,  2,60, 
     2,14, 13,89, 17,24, 11,37,  4,30,  9,88, 15, 1,  1,15,  7,14,  0,36,  5,14, 12,62, 16, 3, 14,27,  8,44, 10,50,  3,63,  6,26, 19,91, 18,85, 
     2,24,  5,74, 14,42, 10,43,  1,58,  7,29,  3,58, 18,54, 19,76,  6,22,  4,42,  8,80, 17,45, 12,28, 15,32,  0,59, 11, 1, 13,81, 16,48,  9,15, 
     4,90, 13,20, 10,88, 15,84, 14,39, 12, 6, 18,12, 11,14,  1,19,  5,44, 17,10,  9,26,  2, 6, 16,75,  0,24,  8,38, 19,53,  6,37,  3,69,  7,46, 
     3,54, 17,78,  4,20, 13,66,  8, 2, 15,52, 19,47,  7,84,  6,28, 11,11, 12,66, 14,45,  1, 8, 10,22,  9,14,  0,31,  5,88, 18,73, 16,21,  2,70, 
    11,36,  8,29,  0,65, 13,32,  5,79,  7, 2, 10,42,  9,95,  2,33,  4, 5,  1,62, 12,47, 17,20,  6, 2, 18, 2, 15,36, 14,22, 19,96,  3,61, 16,85, 
     3,27, 11,22, 15,60,  8,87, 10,30,  6,64,  5,75, 18,26,  2,25,  9,76, 19,28, 16,53, 14,65, 17,59, 12,92,  4,54,  7,92,  1,28, 13,20,  0,48, 
    10,57, 18,13,  3,93,  8,47,  2,40, 12,81, 11,89, 13,52,  6,58, 14,20, 19,19,  1,37, 16,69, 17, 1,  0,13,  7,60,  4,83, 15,35,  9,64,  5,73, 
     3,63, 14,86,  0,36,  4,85,  5,91,  7,12, 13,46,  6,52, 15,70, 17,25, 12,50, 10,41,  1, 4,  9, 9, 11,36,  2,99, 18,57,  8,91, 16,96, 19,43, 
     2,15,  8,84,  7,73,  9,93, 19,51, 16,14, 17,25, 15,75,  6,39,  3,14,  4,43, 13,73, 10,82, 12, 2,  0,72,  5,66, 14,30, 18,64,  1,19, 11,63, 
    18,38, 12,74, 11,59,  7,69, 17,60,  8,99, 13,14, 15,48,  9, 9, 14,50, 16,83,  5,85,  2,74, 10,10, 19,95,  3,10,  1,80,  0,92,  6,92,  4,39, 
     0,48,  7,75,  2,18, 16,65, 17,11,  4,32, 13,61,  1,46,  9,22, 10, 1, 11,38, 14,33, 15,78,  3,39,  5,67,  6,79, 12,66,  8,99, 19,22, 18,66, 
     3,86, 13,95, 18,30,  9,19, 17,90, 12,65, 14,79, 19,23,  7,69, 10,81,  0,30, 11, 9,  5,99,  8,86,  2,66,  4,62, 16,32,  1,97,  6,25, 15,37, 
     7,42, 18,67, 10,84,  5,55,  8,76, 13,48,  2,95, 16,59,  3,69, 14,53,  1,65,  4,30, 19,94,  9,85, 15,15,  0,96, 11,68, 17, 1, 12,30,  6,94, 
     6,28, 12,76,  8, 2,  0,86,  4,58, 16,40,  5,14, 19,32, 11,11,  2,13, 14, 1, 13,56,  7,92, 18,13,  3,85, 10,15,  9,74,  1,51, 17, 4, 15,66, 
     8,52, 17,73, 15,57, 10,13,  6,52,  3,49,  5,38,  1,14,  9,87,  2,63, 13,78, 11,40, 14,13,  7,23, 12,42, 18,99,  0,67,  4,28, 19,65, 16,92, 
     2,90,  7,59, 17,86, 10,30,  5,34, 12,79, 13,77, 18, 9,  0,84, 15,73,  4, 9,  1,44,  9,43,  8,59,  6, 6, 11,90, 19, 3,  3,19, 14, 4, 16,33, 
    15,34,  5,18,  4,25, 19,51,  8,21, 13,93,  3,22,  0,56, 14,80,  1,77, 12,67, 11,89, 10,15, 17,60,  9,15,  2,80, 18,23,  7,90,  6,86, 16,17, 
    10,21, 16,61, 19,25,  6,91,  2,67,  5,84,  0,15,  1,59,  9,35,  4, 5,  8,38, 12, 9,  3,54, 17,58, 14,36,  7,36, 13,69, 15, 7, 11,22, 18, 5, 
    17, 3,  4,73,  3,36, 11,75,  6,95, 12,71, 18,10, 14, 7,  9,13, 19,33,  7,39, 15,30, 10,82,  0,76,  5,68, 13,37,  1,62,  2,44, 16, 6,  8,51, 
    19,87,  1,31,  4,28,  6,68, 14, 7,  2,85,  3,57,  8,82, 16,98, 11,16, 18,12, 13,28, 10, 5, 15,56,  7,78,  9, 7,  5,18, 12, 7,  0, 9, 17,15, 
    16, 8, 17, 2, 11,50,  1,51,  8,97,  6,86,  7,72, 13,92, 18,29,  4,58,  3,10,  0,13, 10,25,  9,42,  2,11, 14,46, 19,74,  5,86, 12,20, 15,31, 
     8,43,  3, 4,  1,31, 14,98, 13,38,  7,13, 19, 9, 10,87,  0,68, 17,54, 12,75,  2,37,  4,11, 16,58, 18,46,  6,49,  5, 6,  9,15, 15,28, 11,86, 
    13,80, 16,90,  4,47, 17,26,  7, 9, 19,10,  6,18,  3,95,  2,19, 12,52, 11,17, 10,55,  1,74, 14,24,  9,85, 15,40,  0,62,  8,60,  5,96, 18,96, 
     6,30, 17,75,  7,59, 14,22,  5, 4,  4,52,  3,97, 10,39,  1,49, 12,36,  8,91, 15,79,  2,17, 18,38, 11, 4,  9,57, 16,44, 13,46, 19,17,  0,66, 
    11, 3,  6,70, 10,95,  4,22,  8,72, 18,39,  0,96, 16,94,  2,47, 17,35,  5,37, 14,59,  1,45, 15,87, 13,99,  7,33,  3,48,  9, 4, 19,92, 12,68, 
     7,18, 17,74, 15,88,  1,60, 12, 8,  9,45,  5, 1, 14,83,  0,71,  2,78,  4,71, 11,52, 13,36, 18,18, 16,12,  3,93, 19,72,  6,37, 10,32,  8,28, 
    11,46, 16,80, 10,12, 17,43, 18,76,  5,83, 13,74, 19,44,  7,97, 14,46, 12,30, 15,56,  4,79,  9,34,  2,56,  3,49,  1, 2,  6,63,  8,41,  0,87, 
     2,53, 13,35, 19,98,  4,19,  6,22,  7,31, 10,89, 18,94, 14,27, 17,92, 12,80, 16,60, 11,22,  8,31, 15,23,  5, 5,  9,40,  0, 5,  1,90,  3,13, 
    16,32, 11,43,  3,75, 10,15, 18,37, 14, 5,  1,64,  7, 4,  6,30, 17,29, 19,14, 15,35,  2,85,  0,75,  8,45, 13,45,  4, 2, 12, 7,  9,29,  5,68, 
     5,95, 13,11,  0, 5,  1,20,  3,49,  6,16, 17,50, 19,10,  4,15,  2,63,  8,97,  9, 9, 16,88,  7,64, 10,12, 11,95, 18,19, 12,16, 14,54, 15, 9, 
    18,52, 17,33,  5,16, 10,10,  8,87,  9,62,  0,76, 11,88, 12,22,  2,63, 19,50, 14,87, 16,16,  1,56,  6,38, 15,57,  4,52,  3,71,  7,15, 13,18, 
     8,89, 15,32,  1,77,  6,66,  2,88, 19, 6, 16,37, 17,35,  0,49, 10,50, 12,89,  5,62,  9,28, 13,31,  4,61, 14,41,  3,71, 11, 2, 18,22,  7, 9, 
     7,32,  8,20,  3,77, 17,70, 14,23,  5,82,  1,51, 11,75,  9,34, 15,55,  4,91, 12,49, 16,46,  6,80, 10, 6,  2,69, 13,70, 19,99, 18,85,  0,45, 
    18,32, 15,27,  8,43, 16,53, 13,70,  6,17, 11,57,  4,77, 10,91,  2,49,  3, 6,  1, 6, 19,47,  7,93, 12, 4,  9,54,  0,93, 14,68, 17,48,  5,93, 
    11,16,  3, 5, 10,39, 17,79, 19,51, 16,39,  5,39,  6,32, 13,38,  9,28,  8,96, 14,35, 12,56, 18,42,  1,45, 15,83,  2,42,  4,40,  7,25,  0, 3, 
    11,77,  8, 1,  5,11, 13,87, 18,21, 16,44,  1,92,  3,77,  7, 9,  6,92,  9,10, 14,31, 10,62,  2,65,  4,44, 19,78, 15,22, 17,13,  0,26, 12,72, 
    17,11, 19,46,  8, 8,  0,77,  4,31,  1,48, 11,37,  3,99, 13,27, 16,99,  9,31, 10,73,  5,60, 14,40,  2,81, 18, 9, 12,20,  7,81, 15,71,  6, 2, 
     6,60,  5,20,  1,62, 18,18,  7,18,  0,33, 19,38, 16,48,  2,37, 12,78, 14,76, 17,28,  3,65, 10,61,  8,40,  4,28, 15,67, 13, 4,  9,17, 11,26, 
     2,54, 17,89,  7,69, 12,93,  0,69, 14,93,  4,54, 19,30, 15,14, 10,14,  8,71,  1,49,  6,10,  3,86, 18,88,  5,67,  9,17, 11, 2, 16, 2, 13,20, 
    16,54, 12,83,  0,59,  2,70, 14,18,  5,34,  6, 7,  3, 2, 17,45, 15, 6, 18,80, 10,21, 11,72,  7,80,  9,89,  1,52,  8,33, 19,41,  4,76, 13, 5, 
     9,53,  3,15, 11,75, 18,10, 15,48,  1,54, 19, 1, 16,43, 13,22, 17,31,  0,63,  5, 1, 14,68, 10,74, 12,23,  4,32,  2,53,  8,71,  6,93,  7,22, 
    16,21, 14,51,  2,56, 11,39,  5,32, 13,17, 17,37, 19,21,  8,42, 15,81,  9,56, 10,29,  1,11, 12,78,  7,40,  4,66,  6,57,  3,92, 18, 5,  0,38, 
     7,30,  9,31, 16,92,  2,26, 14,56,  3,67,  5,88,  6,11, 18,25, 19,24, 13,98,  8, 8, 15,34, 17,18,  0,80, 12,82, 11,28, 10,87,  4,77,  1,14, 
     5,40, 18,43, 13,85, 10,84,  8,76, 14,64,  9, 7, 12,51,  4,51,  2,15,  7,96, 11,31, 19,85,  6,30,  1,85, 17,45,  0,73, 15,73,  3,17, 16,57, 
     6, 3, 11,32,  8,92,  0,97,  1,78,  2,83, 15,37,  7,41, 12, 4, 14,62, 18,16,  5,36, 16, 4, 10,26, 19,28, 17, 2,  4,16,  3,37,  9,93, 13,26, 
     7,64, 10,90, 16,88,  9,32,  5,13, 15,70, 12, 5,  6,30,  3,44,  2,82,  0,98, 19,44, 18,67,  8,24, 11,49,  4,99, 17, 9,  1,28, 13,96, 14,70, 
    15,83, 18,29, 19,27,  0,78, 10,85, 12,10, 14,77,  9,91,  1,24,  3,97, 17,19,  2,54,  8,40,  6,39, 13,46, 16,89,  7,83,  5,93, 11,53,  4,90, 
    13,76, 19,56,  7,40,  4,73,  6,14, 18,74, 12,75,  1,55, 17,90, 16, 8,  2, 9, 14,59,  3,60,  5,27, 15, 1,  0,17, 11, 6,  9,41, 10,41,  8,10, 
     0,23,  3,77,  8, 7, 12,66,  9, 5, 16,85,  2,87,  6, 1, 19,40, 14,69,  5,62, 17,90, 11,20, 15,18,  4,32,  1,36, 18, 4,  7, 6, 10,47, 13,28, 
    11,45,  9,87, 19, 4,  3,17,  1, 6,  7,13,  2,72,  4,66, 18,68,  6,87, 15, 1, 17,79, 16,44, 14, 5, 10,33,  0,32, 12,20,  8,63, 13,73,  5,62, 
    10,81,  5, 3,  9,13,  8,42,  3,22,  1,32,  0,83,  4,56,  7,28, 15,96, 11,34, 19,42, 18,22, 13,86, 14,45, 17,79,  2, 7, 12,43, 16,27,  6,41, 
     6, 4, 10,55,  4,31, 19,22,  2,28, 13,44, 12,15, 11,88,  8,27,  9,66, 17,50,  0,25,  1,27,  7,91, 14,53, 15,71,  3,10, 16,12,  5, 2, 18,61, 
    11,70,  9,69,  8,26, 16,78, 13,42,  7,97, 19,68,  5,88, 10,37,  3,23, 18,46,  2,55, 14,29, 17,81, 12,54,  4,70,  0,71,  6, 2,  1,53, 15,28, 
    11,39, 12,56,  9,87,  7,21, 15, 9, 18,82, 16,44,  8,63, 19, 9,  4,50,  1,34, 17,58, 13,18,  5,87,  0,42, 14,78,  2,98,  6,30, 10,46,  3,21
  };
  
  /*
   * Generated random instances
   *
   * The machine permutations have been chosen uniformly from all
   * possible permutations and the durations are also uniformly
   * randomly distributed in a range from 1 to 100.
   *
   */
  const int r000[] = {
    10, 10, // Number of jobs and machines
    4, 25, 7, 94, 5, 83, 6, 10, 3, 62, 1, 76, 2, 65, 9, 51, 0, 90, 8, 36, 
    2, 39, 1, 62, 8, 25, 6, 25, 3, 33, 0, 20, 5, 55, 7, 38, 9, 67, 4,  6, 
    1, 15, 3, 99, 2, 45, 9, 82, 6, 69, 0, 32, 4, 64, 7, 99, 8, 40, 5, 62, 
    9, 68, 6, 94, 8, 76, 3, 97, 4, 13, 7, 16, 5,  4, 0, 13, 1, 76, 2, 55, 
    9, 25, 2, 71, 7, 95, 0, 61, 3, 19, 5, 58, 6, 72, 8, 26, 4, 27, 1, 83, 
    4, 53, 5, 23, 6, 14, 2, 94, 7, 51, 8, 85, 1, 49, 0, 58, 9, 33, 3, 46, 
    0, 99, 2, 57, 4, 50, 5, 64, 7, 78, 3, 86, 9, 10, 6, 62, 1, 56, 8, 89, 
    8, 22, 9, 12, 3, 99, 0, 26, 6, 13, 5, 96, 2, 85, 7, 71, 1, 30, 4, 77, 
    7, 79, 5, 16, 1, 24, 2, 79, 9, 58, 4,  4, 6, 76, 0, 85, 3, 81, 8, 14, 
    3, 87, 5, 97, 8, 94, 4, 31, 1,  6, 7, 35, 2, 80, 6, 52, 9, 75, 0,  3
  };
  const int r001[] = {
    10, 10, // Number of jobs and machines
    9, 29, 1, 59, 8, 34, 5, 97, 0, 80, 6, 44, 3, 74, 4, 72, 2, 50, 7, 38, 
    1, 36, 7, 75, 9, 72, 8, 23, 4, 64, 0, 80, 5, 18, 6, 62, 2, 89, 3, 60, 
    9, 42, 1, 94, 5, 89, 4, 50, 3, 13, 0, 29, 6,  3, 2, 98, 8, 23, 7, 90, 
    3, 90, 7, 51, 9, 88, 0, 35, 4, 31, 6, 81, 1, 53, 2, 77, 5, 69, 8, 41, 
    5, 79, 8, 25, 6, 96, 1, 14, 0, 71, 2, 38, 7, 23, 3, 84, 9, 16, 4,  3, 
    4, 23, 3, 46, 8, 36, 2, 88, 0, 34, 1, 39, 9, 11, 6, 29, 7, 51, 5, 47, 
    4, 67, 7, 87, 3, 81, 5, 23, 2, 76, 8,  1, 0, 88, 6, 31, 1, 95, 9, 33, 
    6, 32, 8, 85, 1, 31, 5, 82, 9, 28, 2, 22, 4, 26, 3, 56, 0,  1, 7, 16, 
    4, 29, 6, 51, 9, 39, 0, 74, 1,  9, 2, 68, 8, 75, 5, 60, 3, 44, 7, 91, 
    0, 95, 1, 36, 5, 70, 7, 91, 8, 25, 9, 66, 3, 40, 6, 52, 2, 47, 4, 47
  };
  const int r002[] = {
    10, 10, // Number of jobs and machines
    9, 48, 6, 38, 1, 66, 7, 44, 2, 29, 8, 29, 5, 99, 4, 43, 0, 39, 3, 41, 
    0, 85, 3,  4, 2, 62, 5, 32, 9, 94, 7, 30, 8,  9, 1, 12, 6, 51, 4, 79, 
    4, 73, 7, 58, 1, 61, 0, 28, 9, 91, 5,  8, 6, 98, 3, 37, 8, 84, 2, 85, 
    3, 67, 5,  6, 7, 87, 9,  3, 1, 78, 4, 27, 8, 40, 2, 91, 6, 29, 0, 55, 
    4, 48, 0, 43, 9,  6, 3, 10, 7,  2, 1, 85, 8, 39, 5, 81, 2, 88, 6, 90, 
    6,  8, 7, 68, 9,  4, 2, 83, 8, 13, 1, 34, 5, 49, 4, 52, 3, 43, 0, 51, 
    0, 21, 7, 22, 4, 95, 5,  5, 1,  8, 8, 75, 6,  8, 9, 63, 2, 66, 3, 35, 
    0, 53, 7, 72, 4, 89, 5, 80, 9, 92, 3, 69, 6, 38, 8, 62, 2, 87, 1,  9, 
    8, 15, 2, 64, 0, 91, 4,  3, 3, 52, 9, 98, 5, 44, 7, 32, 1, 35, 6, 45, 
    7, 19, 3, 79, 5, 29, 4, 24, 8, 62, 9, 62, 0, 58, 2, 33, 6, 64, 1, 21
  };
  const int r003[] = {
    10, 10, // Number of jobs and machines
    8, 22, 2,  7, 3, 56, 7, 86, 9, 20, 0, 57, 1, 20, 4, 41, 5, 30, 6, 73, 
    3, 63, 5, 84, 9, 47, 4, 87, 2, 13, 7, 52, 0, 59, 8, 46, 1, 28, 6, 38, 
    7, 95, 0, 26, 3, 72, 1, 95, 8,  9, 2, 34, 6, 15, 4, 64, 5, 96, 9, 44, 
    1, 14, 9,  7, 6, 79, 8, 55, 2, 29, 3, 26, 5, 81, 7, 81, 4, 50, 0,  8, 
    6, 82, 3, 93, 8, 50, 2, 52, 9, 18, 7, 69, 4, 19, 5, 84, 0, 41, 1, 19, 
    5,  2, 7, 28, 9, 99, 3, 82, 8, 49, 6, 30, 4, 23, 1, 97, 0, 66, 2, 13, 
    5, 33, 2, 68, 0, 16, 3, 31, 9, 64, 1, 50, 6, 22, 4, 92, 8, 39, 7, 14, 
    3, 22, 1, 88, 5, 35, 6, 27, 2, 34, 8, 48, 4, 10, 9, 74, 7,  9, 0, 15, 
    9, 69, 1, 39, 5, 33, 2, 20, 3, 74, 6,  1, 4, 74, 8, 42, 7, 20, 0, 28, 
    0, 64, 6, 67, 3, 86, 7, 37, 9, 32, 5, 15, 8, 17, 1, 20, 4, 75, 2, 24
  };
  const int r004[] = {
    10, 10, // Number of jobs and machines
    3,  6, 0, 42, 4, 78, 6, 99, 8, 60, 7, 62, 2, 47, 5, 87, 1,  4, 9, 84, 
    5, 85, 6, 23, 0, 58, 7, 70, 4, 41, 2, 16, 1, 67, 8,  1, 3, 75, 9, 23, 
    2, 50, 3, 99, 9, 86, 5, 38, 0, 32, 1, 60, 4, 46, 7, 94, 6, 51, 8, 27, 
    0, 99, 1, 77, 4, 43, 3, 67, 2, 24, 9, 88, 6, 81, 5, 64, 7, 54, 8, 80, 
    4, 17, 8, 56, 9, 50, 2, 70, 5,  1, 7, 51, 6, 50, 0, 72, 1, 32, 3, 22, 
    5, 47, 9, 13, 3, 44, 4, 37, 6, 34, 2, 77, 1, 92, 0, 43, 7,  7, 8, 98, 
    7, 89, 1, 92, 6, 96, 8, 63, 5, 86, 9, 30, 4, 22, 2,  8, 0,  4, 3, 55, 
    5, 75, 8, 40, 4, 61, 0, 18, 7, 77, 3, 92, 9, 20, 1, 49, 2, 97, 6, 62, 
    8, 14, 3, 30, 6, 28, 4, 71, 1, 61, 0, 64, 7, 85, 2, 91, 9, 38, 5, 11, 
    3, 48, 7, 89, 4, 31, 6, 99, 0, 60, 1, 97, 8, 36, 5, 17, 9, 81, 2, 58
  };
  const int r005[] = {
    10, 10, // Number of jobs and machines
    0, 79, 2, 13, 6, 85, 1, 21, 3, 61, 4, 96, 7, 90, 5, 89, 9, 82, 8, 11, 
    6, 90, 3, 44, 7, 22, 5, 23, 8, 64, 1, 93, 9, 95, 0, 85, 2, 83, 4, 11, 
    9, 86, 0, 18, 6, 33, 8, 86, 2, 59, 3, 37, 1,  6, 7, 99, 4, 14, 5, 30, 
    1, 52, 6, 66, 5, 78, 2, 25, 9, 11, 0, 79, 8, 43, 4, 65, 7, 22, 3, 54, 
    9, 97, 2, 21, 1, 40, 7, 53, 0, 25, 4, 50, 8, 74, 3, 54, 5, 42, 6, 41, 
    3,  5, 9,  9, 4, 61, 8, 47, 1, 51, 2, 81, 5, 27, 6, 39, 7,  3, 0, 79, 
    1, 33, 9, 34, 4,  3, 7, 36, 6, 47, 5, 99, 8,  4, 2, 32, 3, 14, 0, 11, 
    4, 86, 8, 79, 9, 30, 3, 25, 7, 38, 0, 81, 1, 27, 2, 33, 5,  9, 6, 22, 
    5, 65, 0, 12, 9, 70, 8, 94, 4, 94, 2, 94, 7, 81, 3, 88, 1, 97, 6, 43, 
    8, 83, 6, 74, 4, 66, 5, 79, 3,  5, 1, 94, 7, 36, 0, 92, 2, 39, 9, 99
  };
  const int r006[] = {
    10, 10, // Number of jobs and machines
    7, 44, 9,  9, 5, 31, 4, 28, 2, 87, 1, 82, 0, 20, 3, 42, 8, 21, 6,  1, 
    5, 96, 9, 49, 1, 56, 8, 34, 7, 85, 6, 75, 3, 13, 4,  4, 0, 96, 2, 34, 
    0, 59, 4, 12, 9, 51, 8, 10, 7, 24, 5, 47, 3, 25, 6, 82, 2, 14, 1, 75, 
    0, 74, 9, 28, 6, 86, 3, 80, 7, 49, 5, 24, 8,  7, 1, 58, 2, 14, 4, 88, 
    5,  8, 9, 69, 4, 46, 6, 88, 0, 52, 3, 44, 2, 11, 1, 39, 8, 22, 7, 23, 
    0, 62, 9, 12, 5, 80, 3, 51, 7, 25, 1, 30, 2,  7, 4,  5, 8, 30, 6, 17, 
    2, 14, 4, 93, 0, 48, 5, 23, 8, 84, 7, 23, 1, 72, 6, 82, 3, 88, 9,  8, 
    8, 63, 5, 82, 6, 24, 1, 19, 0, 19, 3, 34, 7,  2, 4, 46, 9, 42, 2, 64, 
    4, 63, 6, 23, 2,  2, 9, 73, 5, 94, 8, 29, 7, 42, 3, 48, 0, 36, 1, 10, 
    7, 71, 5, 95, 1, 93, 4, 11, 8,  3, 9, 54, 0, 22, 3, 73, 2, 70, 6, 66
  };
  const int r007[] = {
    10, 10, // Number of jobs and machines
    9, 30, 3, 55, 7, 55, 6, 39, 5, 14, 8, 84, 2,  6, 1, 53, 0, 94, 4, 22, 
    9,  4, 4, 42, 7, 33, 5, 34, 8, 32, 6, 12, 0,  8, 3, 73, 2, 26, 1, 90, 
    0, 25, 8, 69, 2, 29, 7, 91, 9, 12, 1, 82, 4, 59, 3, 98, 5, 66, 6, 41, 
    2, 82, 4, 98, 1, 32, 9, 82, 7, 56, 5, 92, 3, 97, 6, 16, 8, 38, 0, 33, 
    0, 66, 6, 90, 1, 52, 8, 92, 9, 35, 4, 40, 2, 30, 5, 33, 3, 60, 7, 47, 
    2, 95, 8, 96, 9, 37, 1, 49, 3, 61, 4, 83, 5, 43, 7,  3, 0,  1, 6, 89, 
    5, 20, 7, 71, 9, 46, 0, 63, 3, 51, 1, 40, 2, 63, 8, 79, 6, 23, 4, 18, 
    4, 74, 3, 52, 0, 43, 1, 18, 9, 76, 6, 21, 8, 46, 5, 46, 2, 24, 7, 13, 
    0, 65, 9, 72, 4, 27, 6,  5, 2, 70, 5, 53, 3, 68, 7, 28, 1,  3, 8, 54, 
    2, 64, 5, 95, 8,  6, 9, 61, 0, 90, 1, 72, 7, 23, 6, 55, 4, 75, 3, 20
  };
  const int r008[] = {
    10, 10, // Number of jobs and machines
    3, 92, 4, 26, 7, 63, 0, 46, 9, 42, 2, 95, 8, 63, 6,  5, 5, 21, 1, 22, 
    1, 50, 3, 69, 4, 36, 8, 61, 0, 68, 7, 48, 9, 77, 2, 54, 6, 96, 5,  9, 
    1, 79, 4, 42, 6, 80, 8, 37, 0, 90, 3, 35, 2, 23, 5, 59, 9,  8, 7, 30, 
    6, 65, 9, 29, 4,  2, 1, 74, 5, 96, 0, 18, 7, 88, 8, 54, 3, 47, 2, 56, 
    0, 35, 9, 75, 1, 42, 6,  8, 5, 83, 7, 90, 4, 39, 8,  8, 3, 72, 2, 94, 
    5, 90, 0, 60, 7, 15, 3, 58, 8, 41, 1, 28, 4, 60, 6, 87, 9, 72, 2, 42, 
    0, 35, 8, 50, 3, 30, 5, 30, 7, 26, 6, 60, 1, 19, 9, 67, 2, 85, 4, 47, 
    9, 21, 7,  4, 6,  4, 2, 12, 1,  8, 3, 99, 5, 19, 0, 63, 8, 10, 4, 41, 
    6, 12, 5, 70, 8,  9, 1, 71, 0, 18, 9,  5, 3, 30, 2, 63, 7,  5, 4, 83, 
    1, 22, 5, 25, 4, 41, 3, 71, 6, 57, 9, 44, 0, 47, 8, 39, 2, 58, 7, 50
  };
  const int r009[] = {
    10, 10, // Number of jobs and machines
    0, 60, 8, 23, 4, 30, 5, 41, 3, 60, 7, 92, 1,  4, 9, 18, 6, 47, 2, 74, 
    9, 58, 1, 80, 0, 67, 2, 59, 5, 91, 8, 91, 7, 91, 6, 14, 4, 49, 3, 15, 
    4,  6, 3, 51, 5, 47, 1, 36, 6, 96, 0, 11, 8, 29, 2, 16, 9, 42, 7,  5, 
    5, 78, 4, 22, 8, 63, 3, 46, 7, 44, 9, 77, 1, 52, 0, 80, 6, 85, 2, 83, 
    4, 86, 5, 62, 2, 81, 3, 23, 1, 81, 6, 12, 8, 95, 9, 10, 0, 79, 7,  7, 
    8, 89, 3, 65, 4,  9, 5, 67, 9, 40, 0, 88, 7, 83, 2, 77, 1, 99, 6, 11, 
    9, 76, 0, 35, 5, 20, 6, 26, 8, 44, 1, 46, 2, 31, 7, 64, 4, 82, 3, 37, 
    3, 78, 4,  5, 0,  2, 7, 28, 8, 76, 1, 26, 2,  4, 6, 19, 9, 42, 5, 71, 
    0, 79, 8, 65, 6, 57, 4, 98, 9, 10, 3, 88, 7, 32, 2, 28, 5, 39, 1, 75, 
    1, 84, 6, 31, 2, 29, 5, 80, 0,  8, 3, 51, 8,  1, 7,  6, 4,  3, 9, 33
  };
  const int r010[] = {
    10, 10, // Number of jobs and machines
    5,  7, 1, 19, 7, 25, 8,  5, 0, 63, 6, 12, 4,  7, 2, 23, 9, 69, 3, 96, 
    7, 58, 9,  7, 5, 85, 4, 27, 8, 14, 0,  4, 2,  3, 1, 22, 3, 49, 6, 81, 
    8, 67, 9, 25, 3,  9, 1, 49, 0, 68, 4,  2, 6, 82, 2, 76, 5, 97, 7, 24, 
    1, 40, 5, 62, 8, 48, 3, 62, 0, 23, 7,  7, 4,  3, 6, 38, 9, 75, 2, 16, 
    3, 78, 5, 26, 6, 32, 7,  3, 9, 60, 8, 65, 1,  9, 2, 96, 4, 14, 0, 24, 
    8, 21, 1, 29, 6, 46, 9, 40, 5, 71, 4, 99, 2, 30, 7,  6, 0, 90, 3, 27, 
    4, 90, 5, 45, 1, 63, 7, 74, 3, 87, 2, 41, 8, 53, 9, 14, 0, 12, 6, 21, 
    9, 61, 3, 92, 5, 63, 0, 29, 8, 97, 6, 77, 1, 65, 4, 63, 7, 44, 2, 14, 
    6,  3, 7, 78, 0, 29, 8, 66, 9, 56, 4, 80, 5, 84, 1, 81, 3, 76, 2, 48, 
    9, 86, 2, 89, 1, 92, 5,  4, 6, 58, 7, 34, 8, 63, 0, 42, 3, 10, 4, 73
  };
  const int r011[] = {
    10, 10, // Number of jobs and machines
    4, 53, 5,  4, 7, 83, 1, 40, 6, 95, 2, 46, 0, 22, 3, 45, 8, 36, 9, 29, 
    3, 69, 1, 88, 9, 57, 6, 13, 0, 10, 7, 52, 4, 77, 2, 47, 8,  7, 5, 49, 
    3, 77, 1, 39, 2, 97, 9, 90, 6, 88, 7, 71, 5, 74, 4, 60, 8, 70, 0, 38, 
    0, 12, 5, 47, 4, 94, 1, 67, 7, 60, 9, 17, 3, 72, 8, 23, 6, 14, 2, 98, 
    7, 19, 9, 31, 3, 64, 1, 78, 4, 22, 0, 39, 5, 64, 2, 74, 6,  8, 8, 38, 
    2, 35, 0, 12, 1, 21, 6, 96, 7, 64, 3, 20, 8, 91, 9, 81, 5, 54, 4, 49, 
    3, 16, 2, 88, 9, 79, 6, 46, 0, 51, 4, 76, 1, 48, 5,  8, 7, 86, 8, 79, 
    2, 93, 6, 54, 7, 69, 4, 61, 8, 27, 0, 50, 5, 50, 9, 66, 3, 16, 1, 77, 
    0, 89, 4, 51, 9, 43, 6, 28, 5, 66, 1, 39, 2, 58, 3, 64, 8, 79, 7, 42, 
    1, 81, 8, 43, 6, 18, 5, 18, 3, 95, 9, 90, 7, 53, 4, 67, 0, 99, 2,  8
  };
  const int r012[] = {
    10, 10, // Number of jobs and machines
    2, 61, 1,  1, 6, 59, 8, 88, 3, 34, 7, 73, 4,  6, 5, 70, 9, 45, 0, 59, 
    3, 97, 6, 35, 4, 94, 1, 82, 2,  6, 5, 53, 9, 22, 7, 24, 0, 17, 8, 87, 
    7, 37, 9, 46, 5, 30, 3,  6, 4, 90, 6, 19, 0, 73, 2, 11, 1, 73, 8, 90, 
    6, 40, 3, 21, 7, 20, 0, 32, 5, 70, 2, 40, 1, 28, 9, 36, 4,  4, 8, 77, 
    4, 13, 5, 24, 7, 22, 6, 87, 0, 59, 1,  3, 8, 50, 9, 84, 2, 48, 3, 58, 
    0, 64, 3,  9, 6, 37, 9, 58, 5, 51, 2, 52, 8, 30, 1, 75, 4, 91, 7, 31, 
    4, 62, 1,  1, 8, 94, 3, 50, 9, 56, 7, 85, 2, 58, 5, 84, 6, 62, 0, 59, 
    1, 58, 7, 47, 3, 35, 4, 39, 2, 30, 5, 65, 8, 88, 9, 90, 6, 62, 0, 85, 
    1, 76, 9, 68, 4, 80, 0, 70, 5, 66, 3, 15, 2, 91, 8, 60, 7, 16, 6, 56, 
    1, 93, 9, 43, 4,  5, 0, 49, 3, 98, 5, 88, 6, 95, 7,  9, 2, 16, 8, 76
  };
  const int r013[] = {
    10, 10, // Number of jobs and machines
    5, 96, 2, 27, 4, 97, 0, 88, 8, 22, 7, 66, 6, 75, 9, 76, 3, 46, 1, 20, 
    8, 15, 3, 41, 6, 57, 2, 27, 4, 64, 5, 95, 0, 27, 9, 31, 7, 77, 1, 26, 
    8, 79, 2, 73, 9, 45, 1, 41, 7, 90, 6, 15, 4, 55, 0, 26, 3,  2, 5, 49, 
    7, 52, 4, 96, 2, 41, 1, 13, 5,  9, 8, 46, 0, 54, 3, 20, 9, 77, 6, 61, 
    5, 93, 1, 52, 8, 52, 6, 20, 2, 77, 7, 91, 0, 51, 3,  8, 4, 11, 9, 40, 
    0, 31, 8, 48, 5, 90, 7, 86, 6, 99, 1,  1, 9, 41, 4, 56, 3, 95, 2, 51, 
    1, 61, 2, 63, 3, 96, 9, 79, 0, 33, 5, 76, 8, 76, 4, 46, 7, 15, 6, 78, 
    7, 45, 8, 42, 4, 21, 2,  5, 0, 61, 3,  3, 9, 41, 1, 58, 6, 13, 5, 67, 
    3, 14, 9, 35, 7, 38, 0, 10, 2, 66, 4, 64, 5, 19, 1, 60, 8, 70, 6, 21, 
    3, 24, 7,  8, 2,  8, 9, 51, 1, 32, 4, 22, 5, 22, 6, 79, 8, 20, 0, 85
  };
  const int r014[] = {
    10, 10, // Number of jobs and machines
    1, 77, 6, 91, 3, 49, 0, 46, 4, 96, 7, 16, 9, 48, 8, 87, 5, 53, 2, 31, 
    3, 85, 7, 18, 4, 71, 5, 61, 6, 21, 1, 74, 0, 48, 9, 82, 2, 74, 8, 94, 
    6, 15, 8, 29, 4, 86, 9, 73, 5, 42, 0, 59, 2, 56, 1, 39, 3, 53, 7, 26, 
    3, 76, 1, 36, 6, 67, 9,  5, 4, 60, 7,  8, 0, 44, 8, 67, 5, 51, 2, 26, 
    6, 85, 7, 88, 1, 16, 2,  2, 8, 78, 4, 98, 0, 55, 5, 32, 3,  5, 9, 81, 
    2, 56, 7, 64, 1, 70, 3, 68, 5, 26, 6, 86, 0, 23, 4, 44, 9, 59, 8, 49, 
    8, 32, 2, 81, 7, 34, 5, 10, 1, 75, 3, 48, 9, 11, 4, 56, 6, 39, 0, 50, 
    6, 85, 4, 83, 9, 90, 1, 98, 8, 58, 2, 59, 7, 13, 3, 81, 0, 58, 5, 97, 
    1, 42, 9, 37, 8,  4, 2, 10, 5, 34, 4, 77, 7, 64, 6, 17, 3, 15, 0, 22, 
    9, 60, 2, 88, 4, 88, 5, 86, 7, 83, 6, 30, 3, 32, 8, 38, 0, 98, 1, 97
  };
  const int r015[] = {
    10, 10, // Number of jobs and machines
    1, 26, 9, 62, 3, 91, 6, 98, 2, 21, 7, 55, 5, 88, 0, 20, 4,  2, 8, 13, 
    9, 34, 4,  1, 3, 11, 0, 98, 7, 25, 5, 91, 8, 44, 2, 56, 1, 49, 6, 26, 
    8, 90, 0, 80, 5, 99, 7, 84, 2, 96, 9, 13, 3, 56, 6, 38, 4, 67, 1, 11, 
    6, 31, 1, 50, 7, 96, 9, 69, 5, 70, 2, 21, 3, 49, 0, 74, 8, 75, 4, 99, 
    5, 36, 6,  3, 1, 79, 3, 93, 4, 41, 9, 40, 2, 39, 7, 21, 8, 35, 0,  4, 
    6, 66, 0, 84, 9, 48, 7, 55, 5, 29, 3, 37, 8, 64, 2, 67, 1, 62, 4, 97, 
    3, 94, 6,  4, 4, 94, 1, 47, 8, 25, 0,  4, 7, 20, 5, 60, 9,  9, 2, 17, 
    8, 76, 0, 89, 3, 46, 7, 38, 6, 12, 9, 48, 2, 76, 4, 48, 1, 30, 5, 71, 
    1, 82, 9,  3, 8, 29, 6, 41, 0, 98, 3,  3, 2, 98, 4, 53, 7, 93, 5, 75, 
    3, 96, 9, 92, 1, 97, 7, 95, 6, 90, 0, 23, 5, 13, 4, 34, 2, 60, 8, 38
  };
  const int r016[] = {
    10, 10, // Number of jobs and machines
    1, 47, 8, 60, 0, 72, 9, 40, 5, 88, 4, 79, 7, 91, 3, 70, 2, 53, 6, 72, 
    1, 37, 9, 46, 8, 42, 6, 96, 0, 79, 2, 24, 4, 45, 5, 89, 7, 30, 3, 71, 
    9, 67, 0, 80, 1, 72, 8, 90, 3, 91, 5, 34, 7, 32, 6, 69, 2, 99, 4, 99, 
    5, 22, 6, 68, 9, 93, 7, 25, 3, 90, 2,  6, 1, 55, 8, 12, 0, 53, 4, 94, 
    6, 29, 3, 87, 1, 11, 9, 93, 2, 41, 5, 51, 0, 63, 8, 44, 4, 56, 7,  5, 
    8, 79, 0,  1, 9, 48, 5, 22, 2, 99, 6, 42, 1, 56, 7,  5, 4, 49, 3, 31, 
    2, 97, 4, 75, 1, 42, 3, 13, 9, 70, 0, 52, 5, 19, 7, 48, 6, 23, 8, 72, 
    2, 46, 3, 78, 1, 94, 0, 25, 9, 14, 4, 83, 5, 61, 7, 93, 6, 86, 8, 66, 
    7, 97, 5, 46, 3, 87, 1, 66, 8, 81, 2, 45, 0, 39, 4,  5, 6, 93, 9, 87, 
    9, 84, 3, 23, 2, 93, 7, 58, 4, 63, 1, 50, 0, 22, 5, 36, 8, 54, 6, 41
  };
  const int r017[] = {
    10, 10, // Number of jobs and machines
    0, 33, 7, 44, 1,  7, 2, 64, 9, 68, 6, 83, 5, 26, 4, 17, 8, 49, 3, 35, 
    6, 58, 0, 30, 9, 71, 5, 34, 2, 77, 3, 64, 1, 53, 4,  7, 7, 31, 8, 48, 
    8, 92, 6, 38, 1, 75, 7, 27, 2, 47, 5, 11, 0, 48, 9,  8, 4, 12, 3, 48, 
    0, 17, 7,  1, 8, 75, 5,  5, 9, 27, 6, 88, 1, 77, 4, 75, 2, 92, 3, 15, 
    2, 29, 0, 15, 5, 95, 9, 10, 4, 26, 7, 59, 3, 43, 1, 59, 6, 26, 8, 82, 
    3, 54, 7, 11, 6, 29, 0, 52, 2, 38, 9,  6, 1, 36, 8,  3, 5, 28, 4, 29, 
    0, 85, 6, 48, 8, 66, 1, 59, 9, 65, 2, 54, 5, 71, 3, 64, 7, 80, 4, 85, 
    3, 79, 4, 34, 9, 87, 6, 60, 8, 46, 1, 15, 0, 45, 7, 10, 5, 65, 2, 94, 
    4, 72, 2, 71, 0, 61, 7, 34, 8, 29, 1, 31, 9, 11, 5, 51, 3, 32, 6, 20, 
    3, 25, 4, 26, 8, 83, 0, 85, 9, 88, 6, 59, 5, 34, 1, 63, 7, 77, 2, 75
  };
  const int r018[] = {
    10, 10, // Number of jobs and machines
    3, 26, 7, 23, 0, 63, 8, 22, 4, 21, 2, 48, 5, 80, 6, 42, 1, 27, 9, 90, 
    2, 77, 7, 51, 0, 45, 6, 81, 4, 81, 1, 49, 5, 23, 3, 74, 8, 93, 9, 79, 
    1, 55, 3, 73, 9, 49, 8, 27, 4, 94, 2,  9, 5, 64, 7, 53, 0, 25, 6, 10, 
    9, 36, 4, 70, 3, 61, 2, 19, 1, 37, 8, 62, 7, 63, 0, 37, 5, 11, 6, 22, 
    4, 86, 8, 68, 6,  1, 3, 44, 5, 64, 0, 38, 7, 56, 2, 18, 9,  8, 1, 98, 
    8, 55, 7, 41, 2, 75, 5, 17, 3, 70, 0, 37, 6,  8, 9, 86, 4,  5, 1, 68, 
    0, 31, 9, 71, 3, 96, 5, 49, 8, 77, 4, 10, 2, 61, 7, 49, 1, 59, 6, 82, 
    4, 37, 7, 16, 2, 42, 5, 41, 1, 75, 9, 87, 0, 95, 6, 57, 3, 74, 8, 23, 
    3, 63, 4, 75, 5, 70, 7, 72, 9, 65, 8, 84, 1, 25, 6, 23, 2, 34, 0, 75, 
    4, 38, 8, 21, 0, 88, 2, 60, 5, 48, 1,  8, 9, 24, 3, 67, 7, 83, 6, 70
  };
  const int r019[] = {
    10, 10, // Number of jobs and machines
    3, 94, 0, 69, 4, 15, 2,  8, 8, 11, 5, 29, 9, 84, 6, 17, 7, 52, 1, 90, 
    6, 60, 8, 45, 2, 90, 3, 37, 7, 81, 0, 13, 9, 68, 1, 91, 4, 69, 5, 60, 
    3, 87, 1, 79, 8,  5, 7, 30, 9, 44, 0, 98, 2, 63, 4, 54, 6, 30, 5, 70, 
    7, 83, 3,  1, 2, 94, 4, 64, 9,  3, 8, 44, 1, 69, 5, 13, 0, 50, 6, 10, 
    1, 43, 7, 27, 5, 23, 9, 41, 2, 37, 8, 14, 6, 57, 4, 20, 3, 16, 0, 90, 
    3, 75, 7, 64, 2, 31, 0, 52, 8, 49, 4, 52, 1, 28, 6, 40, 5, 30, 9, 80, 
    7, 45, 9,  9, 6, 65, 5, 99, 2, 24, 4, 44, 8, 18, 3, 69, 1, 50, 0, 20, 
    1, 36, 5, 41, 0, 37, 8, 48, 4, 68, 6, 37, 2, 50, 7, 41, 9, 56, 3, 12, 
    8,  7, 1, 29, 4, 35, 5, 90, 7, 43, 2, 64, 6, 63, 9, 38, 3, 23, 0, 83, 
    3, 35, 2, 68, 8, 34, 0, 80, 4, 20, 5, 84, 7, 21, 6, 47, 9,  5, 1, 87
  };
  const int r020[] = {
    10, 10, // Number of jobs and machines
    0, 20, 1, 53, 4, 31, 2, 70, 6, 95, 9, 88, 8, 69, 3, 56, 7, 14, 5, 87, 
    3, 37, 6, 35, 1,  1, 4, 16, 0, 23, 2,  3, 8, 55, 5, 35, 9, 10, 7, 17, 
    8, 36, 9, 51, 4, 91, 5, 70, 3, 33, 7, 97, 1, 91, 2,  9, 0, 26, 6, 37, 
    0, 24, 2, 77, 3, 52, 6, 81, 9, 82, 8, 41, 5, 84, 4, 48, 1, 66, 7, 96, 
    7, 69, 1, 73, 6, 99, 5, 12, 8,  9, 2, 36, 3, 49, 0, 10, 9, 81, 4, 96, 
    4, 23, 3, 25, 1, 43, 6, 17, 8, 84, 5, 57, 9, 83, 2, 72, 7, 93, 0, 71, 
    7, 16, 3, 14, 1, 28, 8, 25, 2, 52, 4,  9, 5, 31, 6,  2, 0, 58, 9, 64, 
    6, 69, 9, 67, 4, 11, 2,  5, 0, 62, 8, 69, 1, 13, 3, 60, 5, 16, 7, 98, 
    3,  2, 6, 41, 8, 60, 5, 79, 4, 68, 9, 22, 7, 33, 0, 50, 1, 87, 2,  5, 
    1, 24, 4, 56, 2, 38, 0, 43, 8, 32, 6, 26, 7, 73, 5, 51, 9, 73, 3, 71
  };
  const int r021[] = {
    10, 10, // Number of jobs and machines
    6, 74, 2, 97, 5, 58, 1, 46, 8, 28, 4, 57, 3, 63, 7,  7, 9, 17, 0, 57, 
    5, 80, 6, 87, 2, 79, 3, 71, 1, 19, 0,  7, 8, 19, 7, 94, 4, 96, 9,  3, 
    9, 82, 5, 25, 4, 71, 1, 60, 2,  2, 0, 77, 3, 61, 7, 99, 8, 38, 6, 94, 
    4, 75, 7, 63, 9, 36, 2, 93, 5, 86, 1, 63, 3, 61, 8,  2, 6, 22, 0, 11, 
    5, 67, 1, 12, 9, 99, 8, 93, 4, 17, 3, 53, 2, 76, 6, 88, 7, 92, 0, 24, 
    6, 35, 8, 84, 3, 43, 1, 47, 4, 82, 7, 86, 2, 46, 9, 44, 0, 15, 5, 47, 
    2, 83, 8, 68, 7,  5, 0,  8, 5, 27, 1,  3, 6, 15, 3, 32, 9, 46, 4, 28, 
    7,  6, 1,  4, 3, 97, 5, 74, 4, 95, 2, 11, 6, 62, 9, 53, 0, 39, 8, 97, 
    6, 33, 3,  5, 1, 88, 2, 30, 7, 92, 8, 14, 4, 92, 5, 21, 9,  3, 0,  5, 
    0, 54, 2, 37, 7, 99, 3, 36, 9, 57, 6,  6, 1, 14, 8, 53, 5, 20, 4, 91
  };
  const int r022[] = {
    10, 10, // Number of jobs and machines
    4, 81, 1,  3, 2,  7, 3, 94, 0, 66, 8, 27, 9, 94, 6, 55, 7, 35, 5,  1, 
    2,  2, 0, 13, 5, 35, 8, 61, 3, 42, 9, 83, 4,  3, 6, 20, 1, 76, 7, 55, 
    2, 18, 1, 43, 0, 67, 9, 73, 8, 77, 3, 30, 4, 57, 5, 46, 6, 28, 7, 38, 
    5, 16, 3, 35, 1, 28, 8, 21, 6, 38, 7, 15, 0,  1, 4, 18, 2, 74, 9, 53, 
    3, 16, 5, 90, 7, 40, 4, 64, 1, 36, 2, 50, 8,  4, 6, 87, 9, 45, 0, 56, 
    4,  7, 2, 53, 8, 45, 9, 78, 7, 92, 1, 94, 0, 21, 5, 32, 6, 64, 3, 11, 
    3,  9, 6, 30, 8, 80, 1, 75, 4, 24, 2, 91, 9,  3, 0, 81, 7, 99, 5, 63, 
    3,  6, 0, 25, 2, 48, 6, 38, 7, 80, 8, 59, 9, 26, 4, 33, 5,  5, 1, 37, 
    6, 24, 1, 72, 4,  8, 5, 10, 2, 19, 0, 46, 3, 20, 9, 18, 8, 74, 7, 11, 
    5, 42, 3, 87, 6, 29, 7, 80, 4, 23, 1, 33, 9, 62, 8, 69, 2, 43, 0, 30
  };
  const int r023[] = {
    10, 10, // Number of jobs and machines
    9, 42, 6,  7, 0,  4, 3, 47, 8, 29, 7, 85, 4, 39, 2, 60, 1, 62, 5, 72, 
    9,  4, 8, 61, 2, 11, 4, 81, 3, 19, 7,  7, 6, 15, 5, 74, 1, 45, 0, 79, 
    9, 21, 4, 32, 8, 51, 0, 48, 3, 58, 1, 13, 2, 72, 5, 44, 6,  8, 7, 43, 
    8, 20, 3, 87, 2, 64, 1, 98, 0, 93, 6, 53, 7, 41, 4, 22, 9, 20, 5, 83, 
    1,  8, 3, 31, 2, 44, 7, 36, 9, 11, 5, 70, 4, 63, 6, 48, 8, 52, 0, 48, 
    9, 52, 7, 32, 4, 63, 1, 58, 3, 47, 8, 93, 5, 79, 6, 20, 2, 70, 0, 10, 
    6, 23, 2, 71, 3, 11, 0, 37, 4, 50, 1, 47, 9, 62, 5, 50, 8, 18, 7, 34, 
    2, 86, 6, 25, 7, 98, 9, 74, 1, 53, 5, 62, 8, 61, 3, 42, 4, 39, 0, 40, 
    8, 54, 2,  7, 6, 74, 0, 86, 5, 95, 3, 32, 7, 28, 1,  7, 4, 89, 9, 69, 
    0, 78, 3, 13, 5,  2, 8, 78, 7, 69, 6, 91, 9, 96, 2,  3, 1, 79, 4, 35
  };
  const int r024[] = {
    10, 10, // Number of jobs and machines
    9, 35, 3, 22, 1, 79, 5, 74, 8, 89, 0, 78, 6, 90, 2, 96, 4,  1, 7, 64, 
    0, 84, 5, 33, 9, 71, 7, 72, 3, 24, 2, 35, 1, 58, 8, 99, 6, 36, 4, 13, 
    7, 10, 6, 69, 9, 23, 3, 80, 2, 84, 1, 79, 8, 92, 0, 27, 5, 60, 4,  9, 
    2,  9, 1, 62, 0, 32, 6, 65, 5, 71, 7, 65, 9, 94, 8,  2, 3, 71, 4, 32, 
    4, 10, 7, 62, 1, 78, 0, 22, 2, 29, 9,  2, 5, 33, 6, 81, 3, 15, 8, 40, 
    9, 45, 0, 25, 3, 67, 8, 61, 1,  6, 2, 67, 6, 64, 7, 74, 5, 50, 4, 44, 
    3, 84, 9, 77, 7, 90, 6, 55, 5, 16, 2, 45, 0, 49, 1,  3, 4, 43, 8, 52, 
    3, 64, 6,  3, 8, 63, 1, 65, 5, 39, 0,  9, 2, 57, 4, 33, 9, 74, 7, 76, 
    8, 91, 0, 91, 2, 58, 3, 35, 1, 99, 7, 56, 5, 22, 9, 77, 4, 82, 6, 74, 
    8, 45, 1, 22, 4, 25, 3, 24, 0, 99, 2, 54, 7, 13, 6, 54, 5, 51, 9, 60
  };
  const int r025[] = {
    10, 10, // Number of jobs and machines
    5, 85, 0,  2, 6, 24, 2, 62, 8, 65, 3, 40, 7, 93, 1, 56, 4, 70, 9, 64, 
    1, 78, 8, 71, 9, 54, 3, 90, 7, 49, 2, 26, 0, 68, 5, 52, 4, 23, 6, 28, 
    6, 81, 4, 65, 9, 36, 0, 85, 1, 69, 7, 58, 8, 96, 2, 37, 5, 84, 3, 55, 
    5, 82, 9, 54, 2, 80, 8, 94, 3, 32, 4, 34, 7, 76, 0, 74, 1, 93, 6, 44, 
    8, 20, 1, 19, 2, 30, 7,  5, 4, 60, 0, 95, 9, 99, 3, 16, 5,  4, 6, 61, 
    1, 45, 2, 50, 5, 41, 6, 61, 0, 69, 9, 78, 4,  7, 3, 55, 8, 53, 7, 13, 
    2, 30, 9, 67, 8, 23, 7, 77, 0, 99, 5,  7, 3, 16, 1, 21, 4, 69, 6, 97, 
    2, 61, 1, 84, 6, 46, 9, 45, 3, 81, 8, 73, 0, 43, 4, 86, 5, 59, 7, 58, 
    9, 95, 1, 68, 4, 25, 3, 57, 6, 70, 0, 94, 2, 87, 7, 83, 8,  9, 5, 73, 
    3, 95, 8,  8, 1, 55, 0, 69, 5, 95, 4, 39, 6, 43, 9, 30, 2, 25, 7, 53
  };
  const int r026[] = {
    10, 10, // Number of jobs and machines
    5, 24, 3, 64, 1, 15, 8, 71, 4,  5, 7, 82, 6,  5, 9, 60, 2, 44, 0, 39, 
    0, 21, 2,  1, 3,  1, 9, 21, 5, 76, 8,  8, 7, 26, 1,  2, 4, 67, 6, 94, 
    6,  7, 9, 73, 7, 22, 2, 97, 0, 94, 4, 59, 8, 24, 3, 84, 1, 21, 5, 61, 
    5, 31, 4, 83, 2, 31, 8, 83, 6, 44, 0, 75, 9, 84, 3, 47, 7,  2, 1, 19, 
    7, 47, 6, 76, 1, 77, 3, 92, 8,  7, 2,  7, 5, 33, 4, 72, 0, 46, 9, 63, 
    2, 68, 0, 75, 3, 55, 9,  3, 1, 43, 8, 98, 5, 97, 6, 13, 7, 61, 4, 83, 
    3, 96, 6, 31, 4,  4, 2, 70, 9, 31, 5, 62, 7, 26, 0, 74, 8, 13, 1, 84, 
    8, 14, 4, 89, 7,  5, 5, 87, 3, 86, 6, 75, 2, 81, 1, 15, 0, 83, 9, 88, 
    4, 39, 3, 70, 8, 15, 9, 10, 2, 90, 1, 65, 7, 97, 5, 57, 6, 35, 0, 89, 
    7, 26, 3, 35, 2,  9, 8, 30, 4, 51, 6, 75, 5, 78, 1, 48, 9,  2, 0, 79
  };
  const int r027[] = {
    10, 10, // Number of jobs and machines
    5,  3, 7, 17, 3, 29, 8, 39, 2, 64, 4, 75, 6, 93, 9, 31, 0, 65, 1, 27, 
    5, 66, 6, 33, 9, 66, 1, 17, 4, 36, 7, 55, 2, 28, 8, 52, 0, 51, 3, 89, 
    9, 49, 1,  6, 3, 19, 4, 65, 2,  6, 6, 50, 0, 50, 5, 19, 8, 69, 7, 67, 
    6, 74, 2, 26, 0, 43, 8, 73, 7, 72, 1, 58, 5, 42, 3, 42, 4, 31, 9, 43, 
    5, 24, 1,  8, 7, 82, 3,  1, 9, 59, 8, 38, 6, 31, 2, 24, 4,  2, 0, 26, 
    9, 55, 4, 30, 2, 59, 6, 63, 8, 51, 5, 38, 7,  6, 3, 88, 1, 87, 0, 32, 
    1, 88, 7, 25, 8, 17, 3, 43, 6, 27, 4, 38, 0, 59, 2, 96, 5, 23, 9, 41, 
    6, 93, 3, 57, 1, 74, 5,  9, 0, 73, 9, 56, 7, 35, 2, 17, 8, 29, 4, 18, 
    0, 91, 7, 78, 4,  3, 6, 82, 3, 88, 2, 67, 9, 90, 5, 21, 1, 59, 8,  2, 
    6, 68, 4, 37, 5, 62, 1, 24, 7, 84, 8, 11, 2, 62, 0, 53, 9, 64, 3,  4
  };
  const int r028[] = {
    10, 10, // Number of jobs and machines
    6, 25, 9, 96, 1, 53, 5, 90, 4, 57, 2, 52, 3, 72, 8, 53, 7, 48, 0, 20, 
    5, 82, 1, 27, 0, 32, 7, 36, 8, 84, 9, 58, 4, 52, 2, 68, 6,  2, 3, 43, 
    6, 23, 9, 90, 8, 79, 4, 82, 2, 47, 1, 33, 7, 88, 3, 84, 0, 36, 5, 21, 
    8, 28, 0, 51, 3, 17, 7,  3, 2,  2, 4, 96, 5,  3, 1, 17, 6, 25, 9, 73, 
    1, 37, 4, 23, 2, 67, 0, 62, 6, 44, 8, 85, 7, 16, 9, 94, 5, 13, 3, 92, 
    7, 34, 0, 52, 8, 31, 5,  7, 6, 27, 2, 40, 1, 12, 3, 39, 4, 68, 9, 15, 
    8, 45, 1, 99, 4, 95, 6, 89, 0, 55, 7, 79, 5, 95, 3, 35, 9, 65, 2,  2, 
    6, 87, 5, 69, 9, 77, 8, 11, 1, 94, 4, 37, 2, 66, 7, 65, 0, 51, 3, 29, 
    0, 54, 5, 91, 9, 49, 8, 33, 2, 59, 3, 28, 6, 46, 7, 13, 4,  3, 1, 46, 
    6, 35, 7, 10, 1, 77, 8, 96, 5, 30, 2, 22, 0, 56, 4,  7, 9, 38, 3,  6
  };
  const int r029[] = {
    10, 10, // Number of jobs and machines
    1, 53, 6, 16, 2, 52, 7, 83, 3, 47, 0, 60, 9, 16, 8, 48, 4, 14, 5, 55, 
    8, 18, 7, 26, 0, 71, 4, 83, 5, 48, 1, 45, 2, 26, 9, 85, 6, 50, 3, 69, 
    6, 81, 4, 56, 1, 36, 3, 36, 8, 88, 0, 81, 7, 79, 2, 88, 9, 65, 5, 78, 
    5, 46, 9, 13, 3,  2, 8, 99, 2, 42, 4, 69, 0,  9, 6, 83, 7, 63, 1,  5, 
    3, 88, 8, 11, 2, 80, 4, 24, 9, 30, 6, 22, 7, 23, 0, 36, 5, 73, 1, 24, 
    6,  1, 1, 46, 7, 16, 0, 41, 3, 27, 5, 70, 8, 10, 9, 59, 4, 79, 2, 68, 
    1, 91, 4, 98, 3,  9, 9, 74, 8, 78, 0, 83, 6, 87, 7, 37, 2, 46, 5, 91, 
    9, 23, 0, 85, 6,  2, 2, 88, 5, 51, 4,  3, 1, 92, 8, 16, 7, 71, 3, 85, 
    4, 61, 5, 30, 2, 71, 9, 83, 6, 17, 8,  8, 3, 84, 0, 75, 1, 36, 7, 39, 
    8, 46, 4, 78, 6, 59, 2, 65, 3, 94, 1, 63, 7, 17, 5, 50, 0,  3, 9, 32
  };
  const int r030[] = {
    10, 10, // Number of jobs and machines
    6, 33, 4, 47, 1, 82, 3, 87, 8, 58, 7, 98, 0, 71, 5, 35, 2, 75, 9, 41, 
    4, 99, 8,  7, 1, 41, 2, 84, 6, 83, 9, 61, 3, 80, 0, 26, 7, 73, 5, 62, 
    6, 29, 1, 78, 5, 98, 9, 16, 8, 30, 2, 56, 4, 83, 3, 78, 7, 32, 0, 85, 
    5, 27, 8, 18, 2, 74, 0, 23, 3, 29, 1, 65, 7, 95, 4, 30, 9, 52, 6, 44, 
    6, 25, 7, 24, 3, 12, 5, 43, 8, 92, 1,  9, 2, 75, 9, 63, 0, 89, 4, 21, 
    6, 31, 7, 74, 5, 48, 2, 99, 9, 88, 4, 22, 8, 98, 0, 38, 3, 26, 1, 80, 
    1,  5, 4, 49, 3, 76, 9, 79, 8, 58, 2,  7, 7, 49, 0, 97, 5, 64, 6, 39, 
    5,  9, 2, 69, 4, 72, 7, 32, 8, 59, 6, 90, 3, 30, 9, 19, 0, 82, 1,  5, 
    6, 36, 8, 24, 2, 72, 3, 98, 1, 83, 4, 56, 7, 58, 9,  9, 5, 83, 0, 81, 
    1, 75, 4, 83, 8,  5, 6, 36, 0, 92, 5, 25, 9, 86, 7, 40, 2,  1, 3, 84
  };
  const int r031[] = {
    10, 10, // Number of jobs and machines
    5, 90, 2, 54, 7, 96, 1, 43, 4, 86, 0, 31, 3,  2, 9, 83, 8, 19, 6, 41, 
    1, 36, 8, 71, 5,  3, 9, 30, 7, 95, 4, 32, 2, 69, 6, 67, 3, 45, 0, 36, 
    8, 22, 7, 38, 0, 42, 9, 52, 3,  2, 5, 63, 4,  5, 6, 18, 2, 76, 1,  9, 
    7, 45, 2, 30, 4, 44, 9, 54, 5, 46, 8, 86, 1, 17, 0, 84, 6, 99, 3, 44, 
    2, 76, 3, 29, 9, 59, 1,  4, 0, 28, 7, 64, 8, 44, 6, 48, 4, 41, 5,  4, 
    6, 32, 4, 54, 3, 15, 1, 17, 8, 45, 0, 34, 7, 40, 9, 67, 2, 23, 5,  6, 
    3, 93, 6,  8, 5,  7, 8, 97, 7, 15, 1, 63, 4, 68, 9,  7, 0, 38, 2, 33, 
    1, 82, 8, 59, 6, 90, 9, 77, 0, 35, 2, 31, 5, 16, 3, 20, 7, 75, 4, 37, 
    8, 63, 2,  5, 9, 65, 3, 73, 4, 16, 7, 75, 0, 46, 5, 84, 6, 69, 1, 36, 
    8, 46, 6, 46, 3, 94, 2, 20, 0, 22, 9, 82, 7, 51, 5, 43, 4, 52, 1, 21
  };
  const int r032[] = {
    10, 10, // Number of jobs and machines
    0, 41, 1, 64, 5, 85, 3, 37, 7, 86, 4, 24, 8, 79, 6, 61, 2, 65, 9, 99, 
    5, 94, 8, 72, 3, 56, 6, 21, 7, 23, 0, 79, 4, 80, 9, 21, 1, 63, 2,  1, 
    7, 99, 4, 64, 9, 82, 1, 39, 5, 96, 6, 40, 2, 46, 0, 60, 8, 90, 3, 42, 
    0, 93, 8, 57, 4, 95, 6, 55, 5, 62, 9, 78, 7, 34, 1, 43, 3, 35, 2, 87, 
    0, 96, 1, 80, 8, 22, 3, 70, 6, 10, 4, 34, 5, 89, 2, 82, 7, 73, 9, 99, 
    9, 31, 2, 29, 6, 27, 1, 69, 8, 30, 4, 69, 5,  7, 3, 69, 0, 70, 7, 63, 
    8, 20, 7, 28, 9, 35, 6, 92, 1,  4, 3, 38, 2, 81, 4, 88, 0, 45, 5, 38, 
    6, 34, 9, 45, 4, 34, 1, 68, 8, 25, 5, 16, 0, 47, 3, 90, 2, 45, 7, 93, 
    8,  1, 5, 28, 3, 50, 4, 71, 6, 94, 0, 46, 7,  4, 2, 61, 9, 80, 1, 42, 
    5, 86, 4, 66, 8, 11, 7,  2, 6, 70, 9,  3, 0, 23, 3, 24, 2, 64, 1, 67
  };
  const int r033[] = {
    10, 10, // Number of jobs and machines
    6, 63, 7, 27, 2, 43, 9, 35, 1, 60, 8, 64, 4, 68, 0, 60, 5, 52, 3, 37, 
    3, 93, 6,  5, 9, 18, 7, 64, 4,  3, 2, 31, 0, 24, 8, 44, 5, 46, 1, 68, 
    7, 25, 2, 98, 0, 13, 1, 95, 9, 96, 6, 33, 8, 54, 3, 29, 4, 26, 5, 31, 
    8, 13, 0, 70, 3, 83, 9, 69, 1,  9, 6, 75, 4, 38, 2, 32, 7, 88, 5, 35, 
    2, 66, 3, 78, 0, 48, 7, 92, 8, 43, 9, 70, 6, 77, 5, 86, 4, 46, 1, 74, 
    8, 73, 4, 14, 2, 41, 7, 34, 3, 12, 1, 47, 5, 50, 9, 55, 6, 33, 0, 96, 
    2, 73, 5, 54, 9, 17, 4, 17, 0, 95, 6, 64, 8, 27, 1, 69, 3, 81, 7, 32, 
    3, 92, 5, 38, 8, 73, 9, 88, 1, 87, 0, 55, 7, 57, 6, 77, 2, 85, 4, 28, 
    2, 34, 0, 55, 8, 53, 1, 20, 3, 94, 4,  6, 6, 76, 7, 90, 9, 59, 5, 25, 
    3,  2, 6, 65, 5, 49, 2, 49, 8, 94, 9, 25, 1, 77, 4, 52, 0, 28, 7, 73
  };
  const int r034[] = {
    10, 10, // Number of jobs and machines
    6, 90, 1, 77, 8, 83, 9, 93, 7, 42, 2, 20, 5, 25, 4, 89, 0, 38, 3, 49, 
    4, 69, 2, 70, 7, 34, 5, 76, 3, 23, 6, 93, 1,  1, 0, 79, 8, 20, 9, 67, 
    7, 78, 6,  1, 2,  6, 5,  3, 4, 94, 3, 99, 9, 98, 8, 11, 1, 19, 0, 62, 
    4, 28, 7, 60, 2,  7, 6, 17, 1, 51, 8, 38, 3, 29, 5, 52, 9, 73, 0, 12, 
    1, 58, 5, 85, 9, 64, 8, 72, 7, 36, 0,  3, 2,  2, 4, 28, 3, 43, 6, 32, 
    8, 72, 5, 87, 1, 39, 0, 69, 3, 98, 4, 86, 9, 61, 2,  1, 7, 74, 6, 39, 
    1, 17, 6, 69, 3, 49, 7, 62, 8, 31, 0, 11, 9, 52, 4, 10, 5, 64, 2, 77, 
    6, 69, 1, 58, 4, 64, 5, 89, 2, 36, 9, 85, 8, 70, 0,  5, 3, 38, 7, 58, 
    5,  1, 3, 13, 8, 21, 4, 39, 9, 64, 1, 19, 7, 44, 6, 66, 0,  3, 2, 53, 
    4, 48, 1,  8, 5, 37, 3, 14, 6, 27, 2, 57, 8,  2, 7, 56, 9, 54, 0, 60
  };
  const int r035[] = {
    10, 10, // Number of jobs and machines
    2, 30, 5, 58, 7, 13, 3, 96, 8, 18, 9, 90, 6, 17, 0, 88, 1, 19, 4, 16, 
    6, 30, 7, 93, 8, 35, 2, 38, 9, 52, 3, 25, 4, 21, 0, 54, 5, 39, 1, 41, 
    3, 81, 9, 22, 7, 51, 0, 31, 1, 90, 2, 15, 4, 53, 8, 12, 5, 83, 6, 85, 
    7, 80, 1,  3, 8,  4, 6, 71, 5, 88, 2, 46, 0, 56, 9, 72, 3,  1, 4, 97, 
    3, 79, 9, 10, 6, 62, 0, 36, 4, 51, 2, 64, 1, 51, 7,  5, 5, 57, 8, 90, 
    3, 78, 6, 51, 7, 84, 9, 84, 8, 89, 1, 37, 4, 58, 0, 53, 2, 52, 5, 72, 
    7, 32, 2, 24, 8, 42, 4, 83, 5, 39, 3, 75, 1, 59, 6, 83, 0, 63, 9, 67, 
    6, 93, 3, 88, 1, 81, 4, 79, 8, 59, 9, 35, 2, 60, 5, 52, 7, 11, 0, 39, 
    3,  6, 2, 51, 8, 18, 6, 68, 1, 95, 7, 85, 4, 42, 0, 50, 5, 21, 9, 57, 
    2, 91, 7, 86, 9, 74, 1, 57, 8, 94, 0, 16, 6, 78, 4, 67, 3, 18, 5, 40
  };
  const int r036[] = {
    10, 10, // Number of jobs and machines
    0, 37, 2,  7, 7, 26, 4, 66, 6, 73, 9, 50, 5, 34, 3, 84, 8, 39, 1, 54, 
    1, 20, 7, 84, 8, 19, 3, 12, 9, 23, 2, 12, 4, 73, 5,  8, 0, 75, 6, 31, 
    9, 74, 7, 33, 4, 60, 2, 34, 6, 41, 5, 21, 0, 65, 3, 38, 8, 32, 1, 63, 
    5, 21, 3, 74, 6,  6, 7, 57, 0, 13, 9, 18, 8, 79, 1, 21, 2, 39, 4, 70, 
    2,  9, 3, 27, 8, 45, 6,  6, 0, 81, 4, 16, 1, 52, 7, 88, 5, 47, 9, 27, 
    2, 45, 0, 74, 6, 85, 9, 21, 8, 48, 4, 34, 5, 14, 3, 57, 7, 13, 1, 70, 
    3, 26, 9,  8, 7, 89, 8, 93, 0,  5, 5, 49, 6, 58, 4,  5, 1, 73, 2, 87, 
    3, 51, 6, 28, 8, 92, 1, 67, 9, 58, 7, 86, 0, 31, 4,  7, 5, 90, 2, 75, 
    8, 97, 6, 69, 9, 10, 3, 81, 5, 59, 7,  4, 1, 36, 0,  9, 2, 13, 4, 70, 
    6, 35, 2, 48, 1, 82, 9, 58, 4, 62, 5, 49, 8, 54, 7, 47, 0, 64, 3, 12
  };
  const int r037[] = {
    10, 10, // Number of jobs and machines
    6, 33, 1, 54, 4, 88, 9, 76, 8, 23, 0, 66, 3, 40, 2, 35, 5, 84, 7, 62, 
    5, 66, 6, 77, 0, 42, 7, 11, 3,  1, 9, 10, 8, 89, 4,  8, 2, 90, 1, 23, 
    0, 64, 9, 64, 2, 49, 5, 19, 4, 48, 1,  1, 7, 85, 3, 91, 6,  4, 8, 33, 
    6, 90, 5, 44, 1, 62, 4, 89, 8, 17, 0, 18, 3, 83, 2, 31, 9, 99, 7, 44, 
    6, 78, 9, 57, 4, 45, 5, 23, 0, 61, 3, 77, 1,  7, 2, 83, 7, 53, 8, 75, 
    1,  3, 5, 79, 8, 74, 0, 62, 7, 17, 2, 30, 9, 49, 4, 83, 3, 59, 6, 36, 
    3, 28, 7, 83, 4, 10, 0, 14, 9, 84, 8, 48, 6, 46, 2, 54, 1, 92, 5, 23, 
    8, 19, 1, 34, 2,  1, 3, 47, 4, 57, 0, 27, 7, 68, 6, 69, 5, 82, 9, 21, 
    7, 40, 4, 64, 1, 54, 0, 22, 9, 24, 3, 87, 2, 80, 5,  9, 6, 51, 8, 68, 
    7, 62, 9, 56, 1, 82, 8, 87, 0, 24, 6, 57, 5, 23, 3,  8, 2, 80, 4, 67
  };
  const int r038[] = {
    10, 10, // Number of jobs and machines
    4, 50, 3, 28, 1, 96, 0, 85, 9, 27, 8, 99, 2, 42, 7, 84, 6, 67, 5, 39, 
    1, 83, 8,  5, 9, 66, 7, 55, 4,  5, 2, 66, 3, 43, 0, 57, 6, 13, 5, 46, 
    2, 99, 0, 13, 1, 63, 3, 63, 8, 56, 9,  4, 6, 86, 5, 47, 7, 48, 4, 53, 
    4, 52, 0, 40, 1, 65, 7, 59, 9, 54, 3, 66, 8, 47, 2, 97, 6, 28, 5, 11, 
    7, 29, 0, 95, 2, 54, 1, 60, 4, 97, 3, 36, 6, 82, 8, 52, 5, 75, 9, 80, 
    1, 13, 4, 46, 2, 68, 7, 19, 6,  6, 3,  1, 9, 91, 0,  5, 8, 69, 5, 32, 
    0,  9, 9,  5, 1, 51, 8, 53, 4, 11, 3, 78, 6, 73, 7, 57, 5, 58, 2, 74, 
    2, 23, 8, 30, 5, 17, 7, 59, 3, 97, 0, 85, 9, 62, 6, 58, 4, 62, 1, 51, 
    7, 99, 0, 68, 2, 11, 5, 35, 4, 90, 9,  5, 1, 17, 8, 97, 3, 51, 6, 93, 
    1, 51, 9, 51, 6, 23, 0,  5, 8, 39, 5, 73, 7, 61, 4, 78, 3, 27, 2, 87
  };
  const int r039[] = {
    10, 10, // Number of jobs and machines
    3, 24, 5, 32, 4,  1, 7, 21, 6, 53, 0, 98, 8, 68, 1, 32, 9, 20, 2, 17, 
    3, 62, 6,  2, 4, 35, 2,  5, 1, 37, 8,  5, 7, 68, 5, 97, 9, 68, 0, 79, 
    5, 32, 1,  5, 3, 84, 8, 30, 6, 68, 4, 10, 9, 55, 2, 24, 7, 62, 0,  7, 
    6, 19, 7, 75, 9,  1, 4, 31, 2, 33, 0, 60, 8, 91, 3, 91, 1, 52, 5, 31, 
    2, 98, 9,  8, 7, 77, 5, 33, 8, 56, 1, 52, 6, 50, 0, 17, 4, 97, 3, 88, 
    0,  1, 5,  8, 6, 17, 2, 87, 9, 42, 1, 94, 7, 55, 4, 95, 8, 21, 3, 39, 
    7, 95, 4, 77, 0, 87, 8, 48, 3, 94, 5, 21, 1, 56, 2, 39, 9, 10, 6, 23, 
    2, 12, 5, 98, 9, 42, 1, 60, 6, 45, 4, 88, 3, 60, 0, 62, 7, 65, 8, 62, 
    4, 62, 2, 22, 3, 85, 8, 24, 0, 59, 1, 55, 6, 42, 9, 53, 5, 11, 7, 66, 
    8, 65, 5, 15, 4,  8, 3, 24, 7, 31, 2, 43, 1, 23, 6, 53, 9, 99, 0, 41
  };
  const int r040[] = {
    10, 10, // Number of jobs and machines
    3, 63, 7, 28, 5, 95, 4,  6, 0, 52, 8, 59, 1, 78, 2, 30, 6, 17, 9, 55, 
    1, 45, 4, 69, 7, 19, 0, 93, 9,  7, 5, 67, 8, 48, 6, 29, 2, 63, 3, 38, 
    1, 62, 4, 76, 8, 80, 3, 49, 6, 25, 7, 31, 2, 27, 5, 14, 9, 34, 0,  4, 
    8, 25, 6, 43, 3, 22, 9, 54, 5, 99, 2, 70, 0, 80, 4, 13, 1, 92, 7, 46, 
    5, 25, 2,  2, 4, 60, 7, 11, 9, 28, 8, 10, 3, 11, 0, 73, 1, 26, 6, 96, 
    8,  4, 1, 97, 2, 25, 5, 91, 6, 58, 3, 82, 9, 20, 4, 64, 7, 51, 0, 22, 
    9, 24, 0, 85, 6,  6, 2, 44, 8, 87, 3, 17, 1, 52, 7, 59, 4, 94, 5, 53, 
    1, 59, 3, 72, 2, 53, 7,  1, 0, 90, 8, 18, 4, 81, 6, 40, 5, 58, 9, 23, 
    0, 29, 3, 24, 6, 49, 8, 22, 9, 53, 7,  6, 4, 68, 5, 70, 1,  6, 2, 72, 
    8, 11, 5, 29, 2, 90, 4, 10, 1,  1, 9, 46, 3, 62, 0, 32, 7, 26, 6, 90
  };
  const int r041[] = {
    10, 10, // Number of jobs and machines
    4, 30, 8, 86, 5, 33, 7, 18, 6, 97, 3, 20, 1, 55, 9, 25, 2, 69, 0, 57, 
    2, 26, 7, 75, 9,  1, 6, 12, 3, 94, 0, 21, 1, 67, 8, 77, 5, 71, 4, 44, 
    1, 45, 4,  9, 2, 37, 5, 34, 8, 63, 0, 17, 6,  5, 9, 97, 3, 10, 7, 96, 
    3, 59, 7, 52, 5,  1, 9, 61, 1, 87, 4, 74, 8, 69, 2, 39, 0, 59, 6, 91, 
    8, 18, 9,  3, 6, 97, 2, 42, 1,  1, 0, 21, 3, 84, 4, 87, 7, 99, 5, 10, 
    4, 71, 3,  1, 5, 32, 7, 90, 0, 43, 6, 49, 9, 90, 8,  1, 1, 66, 2, 34, 
    0, 40, 9, 14, 8, 53, 5, 75, 1, 81, 4, 82, 3,  2, 7, 92, 2, 58, 6, 65, 
    9, 38, 2, 86, 3,  8, 5, 35, 4, 47, 7, 72, 1, 60, 0, 42, 8, 42, 6, 48, 
    5, 78, 8, 49, 6, 47, 9, 41, 1, 34, 7, 45, 2, 71, 3, 61, 4, 97, 0, 24, 
    8, 65, 3, 99, 0, 73, 9, 40, 5, 91, 1, 68, 7,  9, 2,  7, 6, 50, 4, 40
  };
  const int r042[] = {
    10, 10, // Number of jobs and machines
    3, 10, 1, 65, 8, 92, 5, 50, 2, 71, 0, 13, 7, 97, 4, 37, 9, 14, 6, 20, 
    1, 61, 9, 21, 4, 29, 7, 25, 6, 25, 0, 17, 3, 68, 5, 47, 8, 91, 2, 40, 
    6,  2, 5, 94, 9,  8, 7, 81, 3, 34, 8,  2, 2, 20, 4, 78, 0, 38, 1, 55, 
    6, 56, 9, 76, 2, 40, 0, 77, 1,  8, 4, 49, 7, 37, 5, 80, 3, 22, 8, 11, 
    7, 32, 9,  4, 8, 48, 6, 70, 5, 97, 2, 88, 3, 37, 1, 14, 4, 85, 0, 14, 
    5, 27, 8, 77, 3, 18, 0, 71, 4, 50, 1, 76, 6, 20, 7, 43, 9, 19, 2, 55, 
    6, 70, 2,  6, 1, 34, 9, 42, 5, 20, 7, 54, 0, 72, 3, 87, 8, 57, 4, 49, 
    5, 67, 1, 92, 6, 15, 8, 20, 9, 26, 3, 20, 2, 91, 7, 24, 0,  7, 4, 46, 
    5, 76, 0,  6, 6, 94, 1, 15, 3, 47, 4, 41, 2, 63, 8, 12, 9, 50, 7, 70, 
    6, 87, 3, 86, 0, 27, 4, 92, 8, 92, 7, 68, 1, 14, 2, 78, 9, 71, 5, 69
  };
  const int r043[] = {
    10, 10, // Number of jobs and machines
    8, 41, 6, 32, 0, 71, 4, 21, 1, 65, 9, 38, 2, 72, 3, 27, 5, 10, 7, 22, 
    4, 79, 3, 36, 5, 92, 1, 70, 7, 60, 0, 40, 8, 50, 6, 13, 9, 31, 2,  1, 
    4, 63, 9, 62, 1, 21, 0, 59, 8, 18, 2, 13, 6, 68, 5, 93, 3, 24, 7, 44, 
    7, 77, 1, 61, 4, 18, 2, 50, 5, 46, 8, 82, 6, 13, 3, 37, 9, 33, 0, 16, 
    5,  8, 2, 42, 3, 91, 1, 62, 7, 92, 4, 16, 9,  2, 0, 75, 6, 13, 8,  6, 
    7, 58, 5, 35, 1, 22, 4, 85, 0,  7, 9,  1, 3, 90, 6, 68, 2, 79, 8, 82, 
    3, 31, 7, 97, 2, 55, 6, 59, 4, 31, 9, 42, 5, 82, 1, 62, 8, 87, 0, 59, 
    3, 39, 6, 45, 2, 29, 8, 17, 5, 21, 4, 90, 7, 82, 0, 11, 1, 77, 9, 55, 
    2, 91, 0, 45, 5, 16, 9, 87, 3, 85, 4, 34, 6, 42, 8, 77, 7, 40, 1, 88, 
    0, 60, 6, 90, 2, 28, 9, 30, 3, 95, 8,  6, 4, 57, 5,  6, 7, 98, 1, 73
  };
  const int r044[] = {
    10, 10, // Number of jobs and machines
    7, 30, 9, 14, 0, 27, 4, 68, 3, 93, 6, 29, 2, 73, 8,  5, 1, 69, 5,  4, 
    2, 47, 0,  1, 9, 43, 6, 22, 8, 24, 4, 92, 7, 53, 1, 17, 5, 47, 3, 67, 
    6,  5, 4, 41, 7, 71, 8, 52, 2, 60, 0, 57, 5, 27, 1, 62, 9, 48, 3, 60, 
    5, 19, 8, 48, 7, 72, 1, 64, 9, 59, 3, 86, 2, 21, 4, 38, 0, 68, 6, 80, 
    0,  4, 4, 67, 7, 71, 6, 46, 8, 74, 5, 74, 2, 30, 3, 56, 9, 14, 1, 76, 
    8, 31, 4, 67, 7, 98, 0, 98, 6, 27, 5, 95, 9,  4, 2, 21, 1,  3, 3,  9, 
    7, 41, 8, 63, 4, 33, 5, 38, 0, 61, 2,  4, 6, 38, 1, 64, 3, 30, 9, 10, 
    6, 11, 4, 88, 9,  6, 8, 93, 0, 67, 3, 54, 7, 47, 1, 75, 2, 30, 5, 44, 
    1, 88, 5, 44, 9, 53, 7, 56, 0, 38, 4, 85, 6, 16, 8, 24, 2, 23, 3, 64, 
    5,  6, 1,  9, 7, 32, 4, 86, 0, 88, 3, 47, 6, 43, 2, 73, 8, 19, 9, 69
  };
  const int r045[] = {
    10, 10, // Number of jobs and machines
    2, 81, 3, 67, 1,  5, 0, 93, 5, 46, 6, 54, 7, 90, 8, 94, 4, 72, 9,  7, 
    5, 77, 8, 25, 1, 93, 0, 86, 6, 34, 3, 97, 9, 12, 7, 40, 2, 14, 4, 78, 
    7, 79, 6, 23, 3,  7, 0, 28, 8, 57, 5, 70, 2, 42, 1, 85, 4, 41, 9, 96, 
    0, 92, 8, 83, 6, 84, 4,  4, 1, 68, 2,  1, 3, 93, 5, 27, 9, 70, 7,  1, 
    8, 70, 7, 31, 2, 18, 9, 41, 5, 86, 4, 97, 1, 12, 6, 64, 0, 36, 3, 64, 
    3, 53, 8, 86, 7, 66, 4,  2, 2, 19, 5, 49, 1, 65, 0, 15, 9, 44, 6, 31, 
    3, 34, 2, 17, 1, 59, 8, 59, 5, 32, 7, 38, 0, 57, 9, 62, 6, 69, 4, 52, 
    7, 94, 1, 20, 6, 93, 0, 96, 9, 53, 5, 25, 4, 39, 2, 33, 8, 29, 3, 25, 
    8, 90, 7, 68, 2, 81, 0, 90, 3, 79, 6, 59, 4,  1, 9,  2, 1, 87, 5, 64, 
    3, 30, 2, 60, 4, 47, 8, 77, 1, 47, 6,  7, 0, 12, 5, 34, 9, 66, 7, 57
  };
  const int r046[] = {
    10, 10, // Number of jobs and machines
    7, 71, 4, 12, 5, 58, 9, 77, 2, 26, 6,  4, 3, 81, 0,  8, 8, 11, 1, 89, 
    9,  6, 0, 19, 6,  5, 5, 90, 7,  9, 8, 97, 3, 66, 2, 48, 1, 58, 4, 96, 
    3, 76, 0, 51, 9, 52, 6, 20, 5, 23, 4, 72, 1, 66, 7, 47, 8, 37, 2, 47, 
    1,  2, 9,  5, 6, 54, 0, 48, 4, 84, 7,  5, 3, 86, 5, 14, 2, 80, 8, 68, 
    7, 20, 8, 29, 1, 78, 0, 78, 5, 73, 9, 19, 4, 63, 3, 43, 6, 22, 2, 87, 
    6, 15, 0, 36, 4, 42, 2, 10, 7, 20, 3, 50, 9,  7, 1, 48, 5, 55, 8, 67, 
    8, 64, 7, 94, 1, 38, 2, 75, 9, 91, 3, 70, 6, 32, 5,  1, 0, 82, 4, 54, 
    8, 89, 7, 67, 4,  2, 5, 66, 2, 74, 6, 46, 9, 66, 0, 13, 1, 64, 3, 46, 
    8, 18, 3, 72, 0, 67, 7, 42, 4, 24, 2, 80, 5, 37, 9, 45, 1, 40, 6, 35, 
    8, 38, 3, 82, 5, 64, 4, 67, 2, 18, 0, 99, 6, 46, 1, 55, 9, 93, 7, 26
  };
  const int r047[] = {
    10, 10, // Number of jobs and machines
    0, 33, 7, 16, 1, 43, 3, 92, 4, 40, 8, 65, 5, 31, 6, 74, 9, 82, 2, 85, 
    9, 52, 7, 80, 0, 20, 8,  5, 2, 97, 3, 15, 6, 67, 5, 38, 1, 81, 4, 90, 
    1, 87, 3, 70, 8, 79, 9,  9, 7, 46, 4,  5, 0, 36, 5,  2, 6, 48, 2, 80, 
    3, 30, 8, 84, 0, 14, 5, 83, 2, 62, 7, 10, 9, 85, 1, 28, 6, 11, 4, 14, 
    9, 30, 3, 92, 4, 35, 7, 94, 5, 98, 8, 86, 0, 70, 2, 19, 6,  9, 1, 40, 
    8, 66, 6, 21, 4,  3, 2, 24, 5, 84, 1, 45, 0,  9, 7, 35, 3, 25, 9, 47, 
    5, 95, 7, 16, 0, 50, 4, 64, 9, 74, 6, 16, 1, 15, 3, 75, 8, 15, 2, 91, 
    5, 86, 6, 46, 2, 77, 1, 96, 3,  2, 9, 11, 0, 57, 8, 66, 7, 88, 4,  7, 
    4,  9, 6, 56, 5, 88, 7, 59, 9, 16, 2, 56, 8, 44, 3, 99, 0, 36, 1, 72, 
    2, 54, 1, 51, 0, 82, 6, 98, 7, 47, 9, 68, 5,  1, 4, 44, 8, 46, 3, 70
  };
  const int r048[] = {
    10, 10, // Number of jobs and machines
    4,  8, 7, 66, 5, 88, 2, 35, 9, 95, 3,  7, 6, 77, 1, 49, 8, 12, 0,  7, 
    0, 80, 5, 18, 8, 26, 2,  7, 7, 31, 4, 59, 1, 26, 3, 13, 6, 92, 9,  6, 
    6, 76, 5, 47, 4, 32, 0, 34, 3,  6, 1, 18, 2, 43, 9, 82, 8, 77, 7, 82, 
    6,  8, 3, 36, 7, 71, 9, 10, 0, 72, 8, 35, 5, 43, 2, 21, 1, 84, 4, 30, 
    2, 91, 0, 26, 6, 55, 1, 40, 5, 89, 4, 75, 9, 41, 8, 54, 3, 89, 7, 55, 
    0, 45, 3, 48, 5, 20, 8, 52, 1, 33, 7,  5, 2, 13, 6, 84, 9, 39, 4, 57, 
    9, 16, 1, 66, 2, 97, 0, 85, 3, 26, 8, 91, 5, 72, 4, 37, 6,  9, 7, 67, 
    4, 82, 6, 78, 3, 96, 1, 13, 0, 34, 5, 87, 9, 75, 7, 82, 2, 74, 8, 68, 
    3, 50, 0,  2, 9, 79, 7, 14, 2, 64, 1, 18, 5,  2, 8, 86, 6, 95, 4, 71, 
    2, 70, 8, 89, 0, 64, 4, 86, 1, 56, 6, 25, 9, 81, 3, 78, 7, 32, 5, 39
  };
  const int r049[] = {
    10, 10, // Number of jobs and machines
    5, 10, 1, 37, 6, 72, 8, 66, 2,  5, 3, 23, 7, 25, 0,  7, 9, 51, 4, 85, 
    2, 61, 8, 24, 4, 88, 3, 91, 1, 56, 0, 18, 6, 46, 9, 72, 7, 95, 5, 69, 
    7, 21, 6, 21, 8, 16, 2, 49, 1, 60, 0, 13, 4, 89, 3, 78, 9, 15, 5,  6, 
    4, 63, 3, 52, 6, 70, 2, 63, 9,  2, 5, 59, 7, 67, 8, 53, 0, 15, 1, 28, 
    4, 69, 7, 70, 1, 59, 0, 29, 3, 94, 2, 90, 5, 29, 6, 87, 8, 29, 9, 18, 
    7, 75, 5, 75, 2, 34, 0, 94, 3, 47, 1, 77, 9, 39, 4, 92, 6, 87, 8, 43, 
    5,  8, 9, 32, 7, 19, 6, 16, 2, 32, 0, 73, 4, 77, 1, 51, 3, 72, 8, 88, 
    3, 99, 7, 73, 1, 66, 4, 66, 2,  8, 8,  9, 6, 60, 5, 23, 0, 19, 9, 44, 
    8, 71, 3, 68, 6, 52, 5, 37, 0, 18, 2, 82, 7, 62, 1, 47, 9, 84, 4, 47, 
    9, 63, 8, 41, 1, 52, 2, 92, 0, 55, 4, 82, 7, 21, 5, 56, 6, 29, 3, 98
  };
  const int r050[] = {
    10, 10, // Number of jobs and machines
    5, 39, 7, 43, 6, 28, 8, 21, 4, 97, 1, 42, 9, 61, 2, 32, 3, 79, 0, 93, 
    7, 15, 3, 58, 0,  5, 6,  5, 8, 94, 2, 99, 5, 90, 4, 10, 1, 92, 9, 42, 
    4, 64, 3, 85, 1, 71, 2, 24, 7, 67, 8, 91, 9, 55, 6, 50, 0, 73, 5, 53, 
    9, 61, 7, 73, 0, 67, 1, 48, 8, 68, 3, 53, 6, 95, 4, 60, 2, 47, 5, 40, 
    4, 34, 9, 61, 3,  4, 5, 34, 1, 83, 8, 86, 6,  4, 7, 27, 0, 76, 2, 77, 
    7, 97, 9, 75, 3, 47, 8,  2, 0, 47, 6, 40, 1, 69, 4,  4, 5, 71, 2, 45, 
    1, 95, 9, 97, 4, 68, 6,  6, 5, 71, 3, 64, 7, 30, 0, 19, 2, 12, 8, 70, 
    8, 36, 5,  1, 6, 49, 4, 72, 3, 94, 9, 16, 7, 36, 0, 11, 1, 39, 2, 17, 
    2, 83, 1, 15, 0, 90, 6, 23, 3, 76, 9, 17, 4,  9, 8, 20, 7, 91, 5, 99, 
    7, 85, 8,  3, 2,  4, 0, 82, 9, 45, 3, 64, 4, 50, 1, 87, 5, 96, 6, 13
  };
  const int r051[] = {
    10, 10, // Number of jobs and machines
    9, 41, 5, 86, 6, 73, 8, 26, 2,  1, 1, 61, 3, 94, 0,  8, 7, 54, 4, 20, 
    2, 63, 6, 81, 0, 63, 4, 35, 3, 10, 8, 32, 7, 16, 5, 53, 1, 85, 9,  2, 
    1, 53, 5, 13, 9, 34, 2, 56, 3, 93, 0, 43, 7, 57, 8, 53, 4, 83, 6, 19, 
    9,  9, 6, 21, 7, 33, 8, 35, 1, 89, 5, 21, 2, 81, 3, 25, 4, 60, 0, 33, 
    3, 75, 8, 34, 4, 19, 9, 83, 7, 54, 0, 62, 6, 83, 2, 28, 1, 75, 5,  5, 
    7, 51, 2, 37, 3, 42, 0, 91, 5, 22, 1, 99, 8, 36, 6, 65, 4, 65, 9, 29, 
    9, 34, 8, 99, 6, 91, 0, 37, 2, 90, 7, 87, 1, 31, 5, 16, 4, 43, 3, 69, 
    5,  1, 8, 52, 3, 98, 9, 92, 0,  1, 4, 78, 1, 78, 7, 43, 2, 36, 6, 73, 
    6, 82, 2, 79, 5, 67, 7, 16, 3, 47, 9, 68, 4, 31, 1, 41, 0, 74, 8, 86, 
    0, 92, 5, 79, 1,  4, 9, 46, 7, 84, 4, 52, 6, 58, 8, 25, 3, 12, 2, 59
  };
  const int r052[] = {
    10, 10, // Number of jobs and machines
    5, 49, 9,  9, 2, 87, 0, 98, 8, 59, 3, 28, 4, 23, 1, 39, 7, 47, 6, 53, 
    0, 40, 3,  9, 1, 33, 2, 78, 6,  7, 9, 22, 5, 65, 4, 85, 7, 64, 8, 52, 
    5, 90, 4, 22, 1, 13, 9, 87, 6, 72, 2, 97, 8, 89, 3, 29, 7, 42, 0,  2, 
    9, 19, 7, 29, 0, 27, 3, 89, 4, 79, 8, 49, 2, 94, 1, 41, 6, 76, 5,  6, 
    5,  8, 4, 55, 9, 97, 6, 41, 7, 97, 8, 45, 2, 83, 0, 23, 1,  6, 3, 47, 
    6,  7, 9, 27, 0, 84, 2, 43, 4, 94, 7, 67, 5, 77, 1,  7, 3, 53, 8, 15, 
    5, 34, 0, 77, 9, 32, 1, 36, 8, 16, 4, 32, 6, 63, 2, 49, 7, 36, 3, 27, 
    3, 88, 0, 17, 7, 40, 6,  8, 4, 53, 1, 57, 8, 25, 5, 28, 2, 99, 9, 27, 
    9, 11, 1, 11, 7, 14, 2, 40, 3,  9, 0, 60, 4, 60, 6, 94, 5, 26, 8, 22, 
    8, 25, 9,  2, 7, 41, 2, 34, 3,  2, 5, 96, 1, 64, 0, 12, 4, 42, 6, 31
  };
  const int r053[] = {
    10, 10, // Number of jobs and machines
    9, 35, 0, 55, 5, 78, 3, 72, 1, 37, 2, 38, 8, 48, 7,  9, 4, 46, 6, 45, 
    7,  4, 2, 90, 9, 92, 8, 87, 1, 50, 0, 49, 5, 29, 4, 77, 6, 10, 3, 77, 
    7, 68, 9, 21, 6, 20, 2, 24, 4, 83, 3, 88, 0, 13, 8, 80, 5, 40, 1, 65, 
    3, 87, 1, 37, 9, 75, 6,  5, 0,  4, 7, 19, 8, 16, 4, 87, 2, 90, 5, 61, 
    6, 16, 7, 21, 3, 47, 0, 39, 9, 94, 8, 62, 5,  3, 2, 56, 1, 78, 4, 77, 
    5, 34, 1, 28, 9, 13, 4, 63, 8, 50, 7, 52, 2,  8, 6, 78, 0, 56, 3, 45, 
    2, 37, 5, 46, 7, 98, 8, 84, 9,  7, 0, 58, 4, 86, 3, 36, 6, 94, 1, 43, 
    3, 14, 1, 17, 9, 12, 4, 94, 0, 96, 5, 82, 8, 90, 2, 35, 6, 69, 7, 52, 
    8, 44, 6, 60, 9, 12, 1, 64, 5, 35, 4, 53, 3, 92, 7, 44, 2, 27, 0, 81, 
    2, 18, 3, 11, 9, 29, 8, 91, 6, 16, 1, 13, 0, 63, 7, 89, 5, 79, 4, 44
  };
  const int r054[] = {
    10, 10, // Number of jobs and machines
    7, 15, 0, 52, 2, 56, 3, 32, 9, 45, 1, 79, 4, 15, 5, 66, 8, 38, 6, 11, 
    9, 26, 2, 21, 3, 23, 5, 22, 0, 15, 8, 14, 1, 61, 7, 56, 6, 12, 4, 26, 
    8, 95, 0, 57, 5, 78, 3, 65, 7, 34, 4, 64, 1, 92, 6, 92, 9, 83, 2, 37, 
    8, 54, 9,  2, 6, 12, 3, 63, 0, 89, 7, 64, 4, 81, 1, 38, 2, 96, 5, 82, 
    5, 36, 8, 38, 0, 61, 2, 14, 4, 48, 1, 96, 6, 84, 3, 73, 7, 54, 9, 17, 
    2, 53, 6,  8, 7, 25, 3,  7, 0, 70, 1, 16, 9, 67, 8, 95, 4, 10, 5, 95, 
    9, 40, 6, 20, 2, 32, 1, 32, 5,  4, 0, 99, 4, 26, 7, 69, 3, 89, 8, 83, 
    3, 35, 7, 91, 0,  2, 8, 29, 6, 58, 1, 53, 2,  8, 5, 82, 4,  4, 9, 79, 
    5, 88, 2, 24, 3, 63, 4, 99, 1, 83, 7, 53, 9, 46, 0, 26, 6,  1, 8,  7, 
    8, 10, 3, 66, 1, 91, 9,  4, 4, 44, 2, 83, 6, 21, 7, 62, 5,  1, 0, 17
  };
  const int r055[] = {
    10, 10, // Number of jobs and machines
    6, 73, 2, 73, 3, 93, 0, 94, 4, 37, 5, 10, 7, 89, 9, 65, 1, 36, 8, 81, 
    3, 65, 8, 95, 9, 66, 2,  7, 1, 17, 5, 83, 4, 18, 7, 19, 6, 76, 0, 81, 
    2, 42, 3, 84, 8, 61, 4, 82, 1, 96, 7, 22, 0,  9, 9, 99, 6, 39, 5, 48, 
    6, 86, 8, 44, 2, 35, 5, 55, 0, 44, 3, 53, 4, 94, 1, 26, 9, 18, 7, 98, 
    5, 78, 7, 48, 8, 60, 0,  3, 3, 75, 1, 32, 6, 12, 9, 79, 2, 69, 4, 39, 
    6,  4, 5, 21, 3, 95, 9,  2, 1, 36, 4, 20, 2, 98, 0, 13, 8, 96, 7, 12, 
    7, 90, 5, 59, 1, 43, 9, 86, 0, 32, 4, 57, 6,  9, 8, 44, 3, 53, 2, 18, 
    5, 88, 8,  1, 9, 83, 2, 15, 7, 89, 0, 59, 3, 33, 1, 77, 4, 90, 6, 27, 
    9,  7, 0, 32, 2, 35, 3, 96, 8, 66, 7, 70, 1, 89, 5, 14, 6, 76, 4, 23, 
    1,  9, 8, 48, 9, 80, 3, 84, 0, 13, 5,  3, 7,  1, 6, 20, 4, 85, 2, 57
  };
  const int r056[] = {
    10, 10, // Number of jobs and machines
    7, 86, 8, 71, 4, 45, 5, 71, 9, 74, 6, 34, 0, 16, 1, 90, 2, 44, 3, 90, 
    9, 76, 0, 57, 3, 52, 5, 10, 6, 48, 8, 44, 7, 79, 4, 64, 1, 67, 2, 22, 
    0, 39, 1, 70, 5, 98, 3, 52, 6,  5, 8, 97, 4, 81, 9, 96, 7, 33, 2, 57, 
    1, 35, 0, 60, 3, 99, 7, 81, 4, 94, 8, 56, 6, 80, 5, 29, 9, 76, 2, 86, 
    2, 84, 6, 71, 4, 36, 3, 94, 8, 69, 1, 35, 9, 86, 5, 35, 0, 81, 7, 30, 
    0, 70, 2, 53, 7, 67, 6, 14, 9, 81, 5, 15, 8, 42, 4, 43, 1, 64, 3, 56, 
    9, 16, 7, 91, 1, 22, 0, 16, 4, 62, 3, 72, 5, 95, 8, 26, 6, 29, 2, 29, 
    3, 47, 5, 37, 1, 95, 8, 16, 9, 11, 6, 11, 2, 19, 4, 21, 7, 32, 0, 48, 
    8, 82, 4,  5, 3, 89, 7, 93, 2, 72, 6, 75, 5,  4, 9, 70, 0, 83, 1, 91, 
    0, 77, 6, 50, 8, 43, 2, 76, 4, 27, 9, 58, 5, 59, 1, 71, 3, 12, 7, 82
  };
  const int r057[] = {
    10, 10, // Number of jobs and machines
    7, 36, 6, 91, 3, 33, 2, 24, 1, 15, 4, 90, 0,  1, 5, 62, 8, 72, 9, 97, 
    0, 48, 7, 40, 8, 75, 1, 10, 4, 16, 2, 86, 6, 37, 5, 90, 3, 59, 9, 67, 
    2, 78, 4, 32, 1, 33, 7, 87, 5, 20, 9, 20, 8, 76, 3, 90, 0,  6, 6, 63, 
    1, 19, 7, 51, 3, 21, 2, 20, 8, 62, 4, 47, 5,  5, 0, 43, 9, 23, 6, 76, 
    3, 93, 8, 91, 4, 37, 5, 49, 1, 56, 7, 79, 6, 23, 9, 16, 0, 95, 2, 93, 
    8, 64, 2, 45, 3, 38, 0, 87, 5, 64, 9,  3, 4, 92, 6, 23, 1, 42, 7, 98, 
    6, 70, 8, 72, 3, 29, 2, 67, 1, 92, 7, 31, 4, 90, 9, 94, 5, 27, 0,  6, 
    1, 30, 5, 51, 4, 19, 3,  4, 6, 93, 2, 83, 7, 14, 8, 34, 9, 92, 0, 88, 
    4,  2, 5, 20, 7, 35, 0, 46, 1, 99, 6, 64, 3, 59, 8, 14, 9,  2, 2, 18, 
    1, 31, 8, 51, 3, 36, 6, 70, 9, 19, 4, 45, 5, 37, 7, 51, 2, 28, 0, 60
  };
  const int r058[] = {
    10, 10, // Number of jobs and machines
    9, 19, 6, 93, 5, 59, 7, 10, 2, 81, 4, 38, 1,  3, 3, 50, 8, 38, 0, 52, 
    9, 49, 4, 17, 2, 55, 5, 73, 0, 80, 7, 11, 1, 80, 6, 61, 3, 93, 8, 59, 
    0, 81, 9, 31, 2, 58, 6, 29, 4, 28, 1, 43, 5, 74, 3, 11, 7,  8, 8,  5, 
    8, 46, 3, 81, 6, 81, 7, 49, 1, 11, 9, 23, 0, 62, 2, 77, 5,  2, 4, 71, 
    1, 37, 4, 23, 0, 95, 2, 88, 3, 41, 8, 26, 9, 65, 5, 54, 7, 28, 6, 25, 
    4, 85, 6, 56, 0, 59, 8, 49, 1, 64, 5, 98, 7, 78, 3, 61, 9, 23, 2, 61, 
    4, 94, 2, 38, 5, 75, 7, 85, 9, 35, 1, 75, 3, 80, 6, 68, 0, 89, 8, 79, 
    7, 31, 2, 65, 1, 70, 9, 20, 4, 19, 0, 51, 6, 82, 5, 36, 8, 60, 3, 59, 
    5, 96, 7, 45, 2, 75, 4, 49, 8, 59, 1, 61, 9, 39, 6, 24, 0, 70, 3,  6, 
    1, 94, 3, 79, 2, 11, 9, 41, 5, 49, 4, 29, 8, 73, 0, 24, 7, 16, 6, 98
  };
  const int r059[] = {
    10, 10, // Number of jobs and machines
    6, 70, 9, 15, 7,  1, 0, 47, 2, 70, 5, 87, 4, 98, 1, 98, 3, 57, 8, 32, 
    3, 40, 0, 93, 2, 90, 5, 98, 9,  2, 7, 88, 1,  8, 8, 16, 4, 97, 6, 43, 
    4, 25, 0,  8, 1, 31, 8,  4, 7, 73, 2, 71, 6, 43, 3, 15, 9, 44, 5, 14, 
    8, 46, 2, 83, 0, 90, 1, 13, 3, 24, 9, 44, 6, 28, 5, 76, 4, 43, 7, 19, 
    4, 68, 2, 39, 6,  5, 7, 73, 8, 63, 1, 34, 5, 88, 3, 80, 0, 94, 9, 61, 
    9, 68, 1, 58, 0, 21, 3,  5, 4, 43, 8, 49, 6, 94, 5, 45, 2, 97, 7, 91, 
    6, 87, 2, 96, 5, 55, 4, 45, 0, 11, 7, 35, 8, 25, 9, 13, 1, 71, 3, 11, 
    8, 38, 9, 45, 7, 13, 0, 92, 2,  1, 5, 73, 3, 11, 1, 95, 6, 84, 4, 46, 
    2, 38, 5, 71, 0, 61, 1, 14, 9, 85, 4,  3, 3, 53, 6, 29, 8, 59, 7, 38, 
    1, 27, 9, 49, 6, 93, 0, 81, 5, 39, 2, 49, 4, 99, 8, 37, 7, 87, 3, 15
  };
  const int r060[] = {
    10, 10, // Number of jobs and machines
    4, 77, 0,  7, 9, 64, 5, 98, 7, 49, 3, 15, 2, 75, 8, 73, 6, 63, 1,  1, 
    0, 36, 2, 41, 3, 65, 1, 79, 7, 46, 8, 83, 9, 40, 6, 14, 5, 53, 4, 30, 
    1, 21, 0, 90, 9, 57, 8,  1, 6, 22, 2, 51, 3, 15, 7, 41, 4, 30, 5,  3, 
    9, 88, 7, 59, 5, 50, 0, 89, 8, 34, 4, 97, 6, 95, 1, 20, 2, 35, 3, 72, 
    1, 63, 9, 37, 3, 72, 8, 65, 6, 21, 7, 40, 4,  1, 0, 30, 5, 91, 2, 45, 
    7, 40, 2, 82, 0, 29, 6,  2, 8, 77, 4, 35, 1, 13, 9, 12, 5, 73, 3, 24, 
    1, 30, 8, 81, 4, 50, 3, 34, 6, 59, 2, 47, 7, 63, 0,  2, 9, 34, 5,  3, 
    5, 46, 6, 41, 2, 44, 1, 64, 9, 24, 3, 52, 7, 13, 0, 50, 8, 67, 4, 47, 
    2, 74, 6, 55, 9, 59, 5, 19, 3, 33, 7, 58, 8, 60, 1, 27, 4, 68, 0, 60, 
    3, 36, 2, 85, 9, 71, 1, 86, 6, 26, 8, 11, 5, 41, 0, 17, 7, 36, 4, 21
  };
  const int r061[] = {
    10, 10, // Number of jobs and machines
    5, 68, 2, 18, 1, 48, 8, 65, 0, 67, 3, 78, 9, 91, 4, 12, 6, 23, 7, 73, 
    4, 96, 3, 88, 1, 85, 2, 85, 6,  1, 8, 47, 7, 82, 5, 85, 9, 14, 0, 19, 
    4, 51, 8, 94, 2, 93, 6, 36, 9, 78, 7, 57, 0,  9, 3,  4, 1, 49, 5, 67, 
    4, 48, 3, 76, 6, 10, 7, 39, 0, 62, 8,  7, 9,  8, 5, 48, 1, 30, 2, 63, 
    6, 85, 2, 81, 8,  2, 0, 81, 1, 81, 9, 60, 5, 11, 4, 35, 7, 88, 3, 93, 
    4, 49, 8, 51, 5, 90, 7, 14, 2, 36, 1,  6, 9, 59, 6, 97, 3, 70, 0, 22, 
    6,  4, 7, 76, 0, 57, 1, 37, 5, 25, 8, 67, 4, 82, 3,  9, 9,  8, 2,  1, 
    9, 79, 3, 49, 0, 81, 1, 66, 4, 19, 6, 54, 5, 63, 7, 65, 2, 26, 8, 24, 
    0, 32, 5, 41, 8, 81, 1, 86, 7, 46, 9, 47, 6, 73, 4, 60, 3, 46, 2, 63, 
    5, 13, 8, 87, 1, 85, 7, 11, 0, 69, 2,  4, 9, 30, 3, 74, 4, 45, 6, 35
  };
  const int r062[] = {
    10, 10, // Number of jobs and machines
    5, 82, 1, 80, 4, 59, 9, 36, 8, 69, 3, 17, 7, 87, 6, 77, 2, 41, 0, 51, 
    6, 79, 5, 52, 9, 57, 8, 63, 0, 72, 4, 66, 2, 66, 7, 97, 1, 99, 3, 60, 
    8, 52, 0, 25, 7, 22, 1, 55, 6,  1, 4, 67, 9, 55, 3, 40, 2, 53, 5, 76, 
    5, 68, 4, 66, 9,  5, 2, 89, 8, 55, 6, 39, 1, 76, 3, 37, 7, 63, 0, 64, 
    1, 85, 0, 31, 7, 58, 6, 23, 2, 83, 5, 29, 8, 81, 4, 30, 3, 24, 9, 74, 
    6, 54, 3,  8, 5, 67, 0, 40, 4, 56, 8, 34, 9,  7, 7, 75, 2, 91, 1, 92, 
    2, 31, 3, 73, 5,  1, 0, 53, 8, 43, 6,  9, 9, 73, 7, 89, 4, 92, 1, 50, 
    0, 28, 5, 32, 7, 93, 6, 89, 8,  9, 9, 87, 3, 29, 4, 78, 1,  4, 2, 47, 
    7, 91, 9, 30, 8, 39, 6, 90, 0, 59, 4, 51, 3, 19, 2, 47, 5, 33, 1, 24, 
    7, 39, 2, 55, 5, 83, 6, 56, 8, 43, 3, 78, 1,  9, 0, 32, 4, 90, 9, 16
  };
  const int r063[] = {
    10, 10, // Number of jobs and machines
    5, 33, 2, 65, 1, 92, 9, 63, 7, 77, 8, 34, 0, 44, 6,  3, 4, 56, 3, 58, 
    3, 23, 2, 92, 7, 93, 0, 87, 9, 20, 8, 25, 5, 98, 6,  3, 4, 42, 1, 54, 
    8, 75, 5, 69, 2, 85, 7, 81, 3, 36, 9,  8, 6, 67, 4, 13, 1, 93, 0, 88, 
    7, 52, 1, 30, 9, 54, 0, 73, 6, 39, 2, 68, 8, 15, 4, 65, 5, 97, 3, 60, 
    7,  3, 4, 86, 9, 76, 0, 92, 3, 85, 8, 39, 2, 85, 5, 16, 6, 74, 1, 16, 
    7,  9, 4,  5, 1, 33, 8, 73, 5, 26, 0, 77, 2, 45, 9, 91, 6, 69, 3, 81, 
    8, 15, 0, 72, 3, 75, 5, 65, 2, 45, 7, 70, 9, 52, 1, 95, 4, 37, 6, 35, 
    6, 19, 7, 34, 8, 16, 0, 80, 9,  9, 2, 16, 3, 52, 5,  9, 4, 39, 1, 22, 
    1, 63, 5, 67, 2, 28, 0,  3, 9, 53, 6,  5, 7, 62, 3, 91, 4,  2, 8, 61, 
    1, 54, 7, 93, 9, 60, 5, 61, 2, 70, 6, 74, 3, 10, 4, 45, 0, 78, 8, 50
  };
  const int r064[] = {
    10, 10, // Number of jobs and machines
    4, 68, 8, 62, 7, 62, 6,  4, 1, 99, 2, 49, 9, 58, 0, 17, 5, 56, 3, 96, 
    6, 27, 8, 49, 3, 20, 7, 36, 9, 33, 1, 44, 4, 36, 0, 98, 5, 18, 2, 53, 
    7, 20, 9, 99, 3, 34, 0, 51, 2, 28, 6, 55, 5, 21, 4, 43, 8,  7, 1, 13, 
    6, 39, 2, 33, 5, 86, 3, 46, 4, 24, 0, 41, 8, 96, 1, 10, 9, 10, 7, 82, 
    5,  2, 0, 28, 9, 45, 8, 50, 7, 28, 1, 59, 4, 45, 3, 40, 2, 59, 6, 50, 
    0, 68, 9, 83, 7, 17, 5, 67, 3, 31, 8, 57, 1, 41, 2, 80, 4, 95, 6, 39, 
    5, 36, 4, 23, 1, 62, 9,  2, 6, 40, 3, 10, 2, 76, 8, 93, 0, 77, 7, 17, 
    1, 11, 6, 90, 3, 32, 8, 55, 4, 62, 2, 48, 0, 80, 7, 36, 9, 73, 5,  3, 
    8, 97, 0, 36, 3, 72, 2,  3, 7, 35, 9,  1, 5, 54, 6, 47, 4, 23, 1, 59, 
    2, 60, 7, 98, 4, 41, 8, 71, 1, 11, 6, 48, 9, 78, 5, 73, 3, 48, 0, 33
  };
  const int r065[] = {
    10, 10, // Number of jobs and machines
    5, 68, 3, 89, 1, 12, 9, 41, 2, 27, 6, 61, 8, 72, 4, 21, 7, 35, 0, 88, 
    8, 66, 3, 26, 5, 44, 1, 44, 7, 28, 0, 51, 4, 14, 2, 25, 9, 90, 6, 94, 
    6, 27, 9,  8, 1, 70, 7, 57, 0, 59, 2, 94, 4, 32, 5, 26, 8, 87, 3, 58, 
    3, 86, 2, 61, 9, 96, 0, 48, 7, 54, 8, 83, 1, 27, 4, 94, 6,  4, 5, 36, 
    4, 36, 0, 48, 6, 36, 7, 87, 9, 88, 1, 26, 3, 44, 5, 20, 8, 86, 2, 89, 
    0, 72, 4, 69, 2, 78, 1, 79, 8,  9, 5, 16, 6, 69, 9, 42, 7, 86, 3, 42, 
    4, 48, 2, 74, 9, 74, 1, 49, 7, 19, 6, 16, 0, 62, 8, 72, 3, 45, 5, 52, 
    8, 45, 7, 88, 5, 64, 9, 21, 4, 60, 0, 59, 6, 89, 1,  8, 2,  9, 3, 86, 
    8, 16, 6, 75, 4, 43, 1, 72, 5, 36, 0, 60, 3,  4, 2, 57, 7, 73, 9, 56, 
    1, 31, 3, 88, 2, 85, 8, 73, 9, 21, 0, 95, 6, 10, 7, 42, 5, 26, 4, 22
  };
  const int r066[] = {
    10, 10, // Number of jobs and machines
    2, 39, 9, 63, 8, 13, 6, 95, 7, 79, 1,  7, 5, 72, 3, 64, 0, 44, 4, 31, 
    4,  8, 3, 99, 1, 71, 8, 23, 0, 61, 6, 32, 9, 28, 7, 90, 5, 35, 2, 60, 
    6,  2, 5, 60, 1, 53, 0, 26, 2, 81, 7, 58, 4, 83, 3, 93, 8, 85, 9, 13, 
    1,  9, 7, 26, 0, 11, 6, 42, 2, 66, 3, 47, 9, 61, 8, 13, 5, 91, 4, 97, 
    8, 77, 9, 68, 5, 64, 4, 11, 1, 96, 3, 70, 0,  4, 6, 84, 2, 44, 7,  7, 
    4, 62, 6, 47, 9, 49, 1, 39, 2, 50, 5, 29, 7, 64, 0, 68, 3, 42, 8, 68, 
    5, 94, 9, 85, 8, 24, 1, 74, 6, 20, 7, 38, 4, 59, 3, 76, 0,  8, 2, 30, 
    1, 73, 8, 72, 7, 26, 9, 78, 4, 64, 5, 52, 2, 16, 0, 99, 6, 17, 3, 40, 
    7, 94, 6,  1, 0,  1, 2, 79, 1, 45, 9, 66, 4, 93, 3, 97, 8, 47, 5, 62, 
    6, 63, 2, 33, 3, 41, 7,  4, 4, 89, 1, 91, 0, 76, 9, 73, 5, 14, 8, 63
  };
  const int r067[] = {
    10, 10, // Number of jobs and machines
    6, 41, 1, 53, 3,  4, 5, 18, 9, 31, 2, 77, 0, 98, 4, 71, 8, 12, 7, 51, 
    4,  7, 8, 75, 7, 70, 9, 43, 6,  2, 3, 25, 0, 62, 5, 36, 1, 64, 2,  5, 
    5, 13, 4, 37, 7, 73, 1, 29, 2, 70, 0, 32, 8, 63, 9, 59, 6, 80, 3,  2, 
    8,  7, 4, 23, 2, 81, 3,  9, 5, 20, 7,  4, 0, 26, 9, 88, 6, 75, 1, 93, 
    7, 21, 5, 88, 1, 56, 6, 91, 2,  1, 3, 63, 0, 62, 9, 23, 8,  2, 4, 54, 
    7, 25, 9, 50, 6, 19, 4, 16, 3, 86, 5, 34, 1, 32, 8, 18, 0, 55, 2, 79, 
    7, 54, 6, 61, 8, 68, 3, 56, 9, 47, 5, 31, 0, 29, 2, 96, 1, 65, 4, 98, 
    6, 50, 4, 64, 2, 17, 0, 91, 7, 43, 8, 45, 5, 10, 1, 21, 9, 92, 3, 46, 
    1, 59, 2, 55, 5, 16, 0, 64, 6, 69, 9, 80, 4,  9, 8, 29, 7,  2, 3, 78, 
    5, 93, 7, 14, 2, 29, 3, 45, 4, 97, 9, 85, 1, 48, 6, 46, 0, 75, 8, 47
  };
  const int r068[] = {
    10, 10, // Number of jobs and machines
    7, 13, 5, 86, 2, 45, 8, 97, 0, 76, 3, 92, 6, 33, 9, 59, 1, 65, 4, 99, 
    8, 55, 5, 23, 3, 77, 6, 43, 1, 10, 9, 66, 7, 40, 4, 95, 0, 91, 2, 69, 
    3, 70, 6, 62, 5, 30, 2, 41, 8, 19, 9, 20, 0, 17, 4, 64, 7, 19, 1, 88, 
    7, 12, 3, 13, 5, 59, 8, 15, 9, 44, 1, 79, 0, 25, 2, 86, 4, 46, 6, 92, 
    3, 27, 6, 40, 0, 43, 5, 84, 8,  9, 2, 39, 9, 52, 1, 18, 4, 79, 7, 60, 
    3,  8, 7, 64, 6, 96, 9, 18, 8,  2, 0, 97, 4, 53, 2, 16, 5, 29, 1, 69, 
    5, 88, 6, 48, 9, 38, 8, 87, 3, 30, 0,  7, 2, 71, 1, 29, 7, 77, 4, 87, 
    2, 69, 0, 66, 1,  8, 6, 93, 8, 29, 5, 68, 7, 88, 3,  9, 4, 78, 9, 39, 
    1, 74, 9, 35, 8, 68, 6, 82, 0, 95, 5, 11, 4, 60, 3, 70, 2, 68, 7, 80, 
    4, 88, 2, 30, 7, 28, 3,  3, 6, 33, 5, 48, 0,  7, 8, 79, 9, 71, 1, 14
  };
  const int r069[] = {
    10, 10, // Number of jobs and machines
    3, 92, 8, 36, 6, 16, 7, 61, 1, 40, 4,  1, 9, 55, 0,  3, 2, 17, 5, 49, 
    2, 67, 1, 24, 9, 44, 7, 70, 5, 27, 3, 23, 0, 68, 4, 93, 6, 72, 8, 36, 
    8, 79, 5,  6, 3, 75, 7, 27, 9, 87, 2, 92, 1, 69, 6, 77, 4, 79, 0, 71, 
    4, 77, 0, 83, 9, 39, 8, 77, 6, 28, 5, 33, 7, 59, 3, 61, 1, 17, 2, 96, 
    8,  7, 9, 10, 3,  3, 7, 71, 1, 83, 0, 34, 2, 98, 4, 72, 6, 62, 5, 64, 
    0, 11, 1, 14, 9, 86, 6,  1, 5, 26, 4,  9, 3, 22, 8, 90, 2, 71, 7, 39, 
    0, 45, 4, 60, 6, 32, 2, 87, 1, 91, 3, 63, 8, 74, 9,  2, 5, 92, 7, 22, 
    4,  3, 5, 85, 8, 74, 7, 43, 6, 75, 3, 88, 0,  2, 9, 91, 2, 21, 1, 59, 
    4, 22, 2, 70, 6, 76, 8, 35, 7, 80, 3, 46, 9,  7, 5, 46, 0, 12, 1, 96, 
    8, 42, 5, 57, 4, 14, 6, 73, 3, 19, 7, 99, 1, 19, 0, 98, 9, 15, 2, 17
  };
  const int r070[] = {
    10, 10, // Number of jobs and machines
    8,  4, 1, 92, 2,  8, 4, 86, 6, 15, 9, 68, 3, 84, 7, 53, 0, 21, 5, 36, 
    0, 58, 2, 17, 5, 33, 4, 21, 3, 28, 1, 52, 6, 62, 9, 42, 7,  4, 8, 76, 
    5, 79, 9, 47, 6, 79, 3,  5, 1, 73, 4, 28, 7, 71, 2, 91, 0, 45, 8, 93, 
    8,  3, 0,  2, 2, 46, 5,  4, 7, 79, 4, 82, 1,  7, 9, 66, 3, 42, 6, 99, 
    1, 69, 8, 57, 0,  9, 4,  8, 6, 82, 3, 64, 7,  2, 9, 14, 5,  3, 2, 85, 
    0, 73, 6, 13, 4, 93, 9, 38, 8, 22, 3,  1, 2,  1, 5,  2, 1,  3, 7, 92, 
    8, 29, 5, 34, 9, 41, 2, 98, 1, 71, 0, 86, 6, 52, 4, 57, 7,  7, 3,  6, 
    0, 98, 6, 45, 7, 71, 8, 65, 2, 93, 5, 71, 9, 32, 3, 94, 1, 82, 4, 45, 
    7, 13, 9, 96, 5, 45, 0, 77, 1, 13, 8, 77, 4, 39, 3, 37, 2, 84, 6, 45, 
    7, 49, 8, 79, 9, 71, 5, 52, 1, 71, 4, 94, 0,  7, 6, 77, 3, 76, 2, 74
  };
  const int r071[] = {
    10, 10, // Number of jobs and machines
    1,  5, 0, 56, 2, 96, 8, 14, 4, 94, 9,  1, 7, 68, 3, 18, 5, 35, 6, 50, 
    4, 91, 1, 65, 6, 85, 2, 49, 8, 66, 3, 86, 5, 37, 7, 58, 9, 35, 0, 71, 
    5, 17, 0, 21, 3, 96, 8, 95, 4, 58, 1, 26, 7, 72, 6, 10, 9, 40, 2, 47, 
    7, 86, 4, 65, 3, 69, 2, 21, 9, 83, 1, 38, 6, 50, 8, 36, 0, 40, 5, 29, 
    1, 16, 2, 91, 5, 97, 4, 64, 8,  6, 9, 65, 7, 11, 0, 15, 6, 26, 3, 94, 
    2, 34, 5, 62, 7, 48, 6, 68, 9, 69, 1, 82, 3, 35, 0, 22, 8, 62, 4, 72, 
    1, 98, 4,  9, 2, 43, 3, 25, 6, 40, 7, 52, 5, 23, 9, 58, 8, 15, 0, 13, 
    9, 52, 8, 36, 2,  7, 4, 80, 6, 79, 1, 82, 7, 20, 5, 75, 3,  9, 0, 73, 
    3, 61, 5,  3, 9, 72, 2,  5, 6, 47, 1, 11, 0, 78, 7, 54, 8,  4, 4, 20, 
    9, 56, 0, 98, 1, 99, 3, 97, 7, 89, 5, 71, 4,  4, 6, 66, 2, 67, 8, 35
  };
  const int r072[] = {
    10, 10, // Number of jobs and machines
    3,  1, 4, 98, 6, 36, 8, 38, 2, 70, 5, 88, 7, 96, 1, 65, 9, 38, 0, 45, 
    3, 96, 9, 15, 0, 96, 4, 90, 1, 54, 7, 30, 6, 57, 8,  2, 2, 75, 5, 46, 
    8,  5, 1, 99, 0, 68, 9, 69, 3, 36, 7,  7, 2, 75, 5, 25, 6, 90, 4, 96, 
    4, 63, 1, 63, 7,  7, 3, 42, 5, 94, 0, 55, 8, 33, 2, 51, 9, 74, 6, 42, 
    6, 15, 3, 23, 9, 44, 5, 28, 1, 96, 4, 17, 0, 50, 8, 95, 2, 36, 7, 17, 
    8,  5, 9, 84, 5, 95, 6, 45, 4, 93, 0, 36, 3, 63, 1, 28, 7,  8, 2, 88, 
    6, 47, 3, 49, 8, 49, 9, 72, 5, 46, 1, 88, 2,  5, 0, 40, 4, 96, 7, 46, 
    2, 60, 4, 76, 9, 52, 8, 10, 5, 17, 1, 40, 6, 49, 7, 58, 3, 49, 0, 18, 
    7, 13, 5, 23, 0, 56, 8, 44, 4, 93, 3, 80, 2, 86, 6,  4, 1,  6, 9, 64, 
    8, 10, 5, 31, 9, 45, 6, 27, 0, 20, 3, 76, 7, 43, 1, 46, 2, 82, 4, 24
  };
  const int r073[] = {
    10, 10, // Number of jobs and machines
    3, 47, 5, 16, 2, 75, 9, 60, 0, 69, 6, 82, 1,  8, 4, 87, 7, 78, 8, 41, 
    1, 92, 2, 36, 5,  7, 0, 80, 3, 22, 9, 64, 6, 25, 7, 53, 4, 85, 8, 95, 
    3, 55, 1, 43, 8, 63, 0, 97, 2, 12, 7, 40, 4, 58, 9,  5, 5, 10, 6,  5, 
    7, 48, 6, 73, 8, 77, 1, 49, 4,  2, 9, 13, 2, 89, 0, 89, 3, 93, 5, 90, 
    2, 73, 5, 72, 3, 69, 8, 68, 7, 16, 0, 28, 6, 22, 9, 82, 4, 84, 1, 23, 
    2,  4, 5,  4, 3, 87, 9, 57, 4, 85, 7,  5, 8, 28, 0, 45, 6,  7, 1, 21, 
    3, 71, 2, 52, 6,  8, 1, 29, 0, 30, 9, 56, 8, 47, 5, 66, 4, 81, 7, 79, 
    9, 78, 5, 22, 0, 85, 1, 91, 2, 38, 4, 22, 7, 59, 8, 85, 3, 16, 6, 82, 
    4, 96, 8, 29, 5, 45, 3, 23, 6, 79, 7, 92, 2, 76, 0,  1, 1, 83, 9, 56, 
    9, 50, 2, 65, 8, 76, 6, 62, 0, 48, 7, 67, 1, 75, 3, 72, 4, 74, 5, 35
  };
  const int r074[] = {
    10, 10, // Number of jobs and machines
    4, 31, 7, 46, 1, 87, 5, 76, 9, 86, 2, 89, 8,  6, 3, 25, 0, 79, 6, 25, 
    5, 49, 4, 60, 1, 67, 7, 51, 9, 51, 3, 77, 2, 37, 8, 69, 6, 91, 0, 16, 
    4, 97, 1, 58, 8, 19, 3, 53, 0, 74, 6, 51, 9, 89, 5, 87, 7, 38, 2, 97, 
    2, 77, 0, 26, 5, 53, 6, 85, 3, 14, 1, 58, 7, 96, 9, 85, 8, 58, 4, 79, 
    5, 32, 0, 22, 1, 19, 8, 55, 2, 12, 6, 94, 9, 70, 7, 27, 4, 78, 3, 78, 
    7, 26, 8, 19, 0, 39, 3, 74, 1, 42, 9, 89, 4, 90, 2, 11, 5, 76, 6,  8, 
    9,  9, 7, 80, 1, 46, 6,  6, 8, 45, 5, 89, 3, 24, 4, 40, 0, 54, 2, 41, 
    2, 49, 4, 27, 6, 59, 1, 93, 9,  4, 7, 34, 8, 91, 5, 33, 0, 32, 3, 97, 
    2, 48, 3, 10, 4,  4, 1, 82, 7, 66, 9, 22, 8, 37, 6, 57, 5, 88, 0, 34, 
    6, 93, 1, 13, 5, 25, 8, 47, 2, 17, 7, 33, 9, 55, 4, 80, 0,  8, 3,  7
  };
  const int r075[] = {
    10, 10, // Number of jobs and machines
    1, 74, 8, 90, 2, 49, 4, 24, 5, 29, 3, 59, 0, 44, 7, 39, 9, 99, 6, 22, 
    6, 73, 8, 32, 7, 89, 0, 45, 5,  6, 4, 30, 2, 18, 3, 21, 9, 27, 1, 98, 
    7, 74, 5, 63, 0, 28, 1, 40, 8, 20, 6, 70, 4, 83, 3, 53, 2, 62, 9, 81, 
    9, 89, 1, 65, 4, 37, 7,  2, 3, 11, 0, 94, 5, 72, 8, 93, 2, 30, 6, 25, 
    0, 25, 5, 43, 6, 19, 3, 88, 9,  5, 4,  4, 7, 25, 1, 87, 8, 21, 2, 45, 
    1, 27, 6, 56, 0, 87, 5, 87, 9, 64, 2, 81, 4,  3, 7, 31, 8, 96, 3,  3, 
    6, 13, 1, 70, 7, 30, 4, 26, 0,  3, 8,  3, 3,  1, 9, 79, 5, 90, 2, 19, 
    4, 27, 8, 42, 6, 23, 2, 60, 0, 29, 1, 14, 3,  8, 5,  4, 9, 28, 7, 69, 
    0, 14, 8, 11, 5, 60, 4, 23, 1, 74, 2, 21, 6, 70, 9, 17, 3,  4, 7, 90, 
    0, 70, 4, 93, 1, 89, 5, 25, 9, 21, 3, 13, 7, 27, 2, 68, 8, 24, 6, 10
  };
  const int r076[] = {
    10, 10, // Number of jobs and machines
    4, 25, 9, 79, 1, 13, 2, 72, 3, 97, 8, 49, 0, 39, 5, 90, 6, 73, 7, 24, 
    6, 79, 4, 58, 0, 16, 9, 35, 8, 75, 2, 37, 1, 45, 3, 12, 7,  4, 5,  2, 
    8, 82, 7, 74, 2, 33, 4, 87, 3, 70, 6,  2, 0,  7, 1,  8, 5, 21, 9,  4, 
    4, 23, 8, 49, 7, 72, 3, 95, 6, 33, 0, 21, 5, 95, 1, 88, 2, 75, 9, 80, 
    7, 55, 1, 96, 0, 41, 4,  7, 9, 46, 5, 44, 8, 82, 3, 86, 6, 22, 2, 37, 
    8, 81, 7, 21, 6, 67, 9, 26, 3, 86, 2, 66, 4,  5, 5, 27, 0, 69, 1,  2, 
    8, 37, 0,  1, 6, 77, 1, 82, 9,  6, 2,  3, 4, 36, 7, 10, 5, 64, 3, 54, 
    2, 92, 1, 69, 0, 80, 7, 63, 3, 17, 8, 57, 4, 42, 6, 76, 5, 51, 9, 20, 
    7,  9, 4, 95, 2, 64, 6, 88, 3, 82, 8, 23, 5,  5, 9, 71, 0, 13, 1, 49, 
    9, 77, 6, 98, 4, 42, 5,  4, 1, 21, 7, 64, 3, 37, 2, 11, 0, 11, 8, 61
  };
  const int r077[] = {
    10, 10, // Number of jobs and machines
    0, 55, 9, 41, 4, 54, 7, 92, 2, 37, 1, 48, 6, 82, 3, 11, 8,  3, 5, 89, 
    2, 95, 1, 24, 4, 55, 0, 17, 9, 14, 3, 78, 6, 68, 8, 87, 5, 62, 7, 57, 
    0, 14, 3, 98, 2, 78, 6, 87, 7, 12, 1, 43, 4, 82, 8, 37, 9, 62, 5, 84, 
    2, 56, 8, 88, 3, 85, 6, 55, 5, 62, 7, 38, 4, 78, 1, 62, 0, 43, 9, 49, 
    5, 99, 8, 85, 3, 63, 1, 69, 6, 32, 9, 74, 0, 26, 7, 51, 4, 81, 2, 86, 
    8, 28, 9, 89, 4, 27, 7, 91, 0, 42, 5, 45, 2, 30, 1, 94, 6, 81, 3,  7, 
    2,  8, 5, 18, 6, 10, 8,  3, 4, 18, 7, 94, 1, 26, 9, 74, 0,  7, 3, 44, 
    5, 34, 6,  8, 0, 94, 2, 72, 1, 69, 4, 44, 8, 53, 3, 50, 7, 86, 9, 19, 
    8, 23, 3, 95, 1, 90, 4,  7, 0, 86, 5, 88, 7, 81, 6, 98, 9, 31, 2, 82, 
    1, 40, 4, 57, 2, 82, 5, 53, 8, 94, 3, 26, 7, 58, 6, 86, 9, 72, 0, 25
  };
  const int r078[] = {
    10, 10, // Number of jobs and machines
    1,  5, 7, 25, 3,  3, 0, 89, 5, 98, 8, 85, 2, 18, 4, 90, 9, 71, 6,  8, 
    0, 33, 7, 55, 8, 60, 6, 55, 4, 90, 5, 64, 1, 26, 3, 70, 2, 74, 9, 55, 
    8, 37, 5, 38, 6, 15, 3, 31, 2, 51, 1, 14, 0,  9, 9, 29, 7, 39, 4, 86, 
    9, 34, 8, 57, 2, 56, 7, 63, 0, 11, 3, 83, 5, 35, 1, 64, 4, 78, 6, 73, 
    6, 50, 2, 37, 8, 13, 7, 59, 0, 44, 1, 28, 5, 84, 3, 73, 9, 64, 4, 50, 
    6, 44, 1, 73, 0, 66, 8, 68, 3, 87, 4, 73, 9, 59, 2, 85, 7, 97, 5, 78, 
    1, 94, 7, 35, 8, 74, 9, 55, 0, 28, 6, 39, 2, 66, 5, 88, 3, 52, 4, 47, 
    2, 98, 4, 19, 3, 65, 9, 13, 1, 44, 0,  4, 8, 37, 7, 23, 5, 75, 6, 79, 
    1, 39, 7, 82, 8, 24, 0, 96, 2, 65, 5, 58, 6, 96, 3, 95, 9, 81, 4, 21, 
    8, 80, 7, 97, 4,  3, 9, 99, 3, 71, 1, 91, 5, 82, 2, 16, 6, 22, 0,  8
  };
  const int r079[] = {
    10, 10, // Number of jobs and machines
    5,  6, 3, 95, 8, 30, 1, 24, 6, 95, 4, 87, 0, 92, 9, 68, 7, 72, 2, 68, 
    5, 14, 4, 30, 1, 66, 2, 59, 3, 11, 6,  6, 7,  1, 8, 92, 0, 86, 9, 22, 
    7, 53, 6, 73, 4, 81, 3, 83, 9,  1, 0, 49, 1, 30, 8, 28, 5, 78, 2, 79, 
    4, 12, 8,  4, 1, 47, 9, 94, 6, 53, 0, 43, 7, 55, 3, 23, 5, 10, 2, 79, 
    7, 40, 8,  1, 3, 17, 9, 20, 0, 52, 1, 52, 6,  1, 4, 14, 2, 60, 5, 25, 
    2,  8, 5, 55, 0, 66, 3, 29, 8, 14, 1, 14, 4, 40, 7, 13, 9, 69, 6, 80, 
    5, 34, 8, 40, 1, 66, 9, 96, 6, 99, 4, 15, 0, 84, 3, 43, 2, 22, 7, 69, 
    2, 42, 0, 89, 5, 29, 6, 89, 8, 85, 9, 74, 3, 70, 4, 13, 1, 53, 7,  2, 
    9, 74, 7, 35, 6, 51, 8, 29, 5, 20, 0, 35, 4, 90, 2, 52, 1, 30, 3, 46, 
    1, 35, 9, 72, 6, 47, 7, 75, 2, 81, 3, 24, 8, 56, 5, 72, 4,  1, 0, 66
  };
  const int r080[] = {
    10, 10, // Number of jobs and machines
    4, 79, 3, 71, 5, 30, 7, 48, 9, 57, 2,  6, 6, 58, 8, 16, 1, 77, 0, 98, 
    5, 93, 2, 66, 4, 88, 6, 11, 1, 80, 7, 27, 3, 30, 0, 76, 8, 87, 9, 10, 
    0, 88, 9, 62, 6, 31, 2, 22, 3, 58, 4, 82, 7, 12, 8, 61, 1, 79, 5, 31, 
    5, 96, 9, 39, 7, 51, 4, 41, 8, 93, 0, 62, 2, 50, 6, 85, 3,  4, 1, 96, 
    0, 69, 8, 51, 3, 83, 2, 50, 5, 88, 9, 94, 6, 99, 4, 87, 7, 64, 1, 19, 
    1, 30, 4, 56, 7, 96, 6,  5, 0,  8, 2, 75, 5, 76, 8, 95, 9, 61, 3,  3, 
    7, 74, 8, 35, 1, 85, 5, 53, 2, 70, 9,  4, 3, 12, 4, 51, 6, 62, 0, 39, 
    4,  6, 0, 38, 3, 57, 6, 38, 8, 39, 7,  5, 2, 25, 1, 75, 5, 45, 9, 42, 
    5, 33, 8, 24, 2, 23, 9,  2, 6, 17, 1, 87, 3, 64, 0, 59, 7,  7, 4,  4, 
    0, 26, 5,  7, 4, 75, 1,  7, 2, 87, 9,  1, 3, 48, 7, 18, 6,  9, 8, 44
  };
  const int r081[] = {
    10, 10, // Number of jobs and machines
    3, 98, 4, 77, 8, 99, 0, 71, 7, 93, 1, 98, 6, 18, 2, 42, 5, 47, 9, 73, 
    1, 98, 8, 53, 9, 75, 6, 14, 0, 18, 7, 62, 3,  5, 4,  9, 5, 40, 2,  8, 
    7, 10, 6, 22, 8, 64, 0, 37, 4, 61, 3, 38, 1, 61, 2, 92, 5, 27, 9,  3, 
    8,  5, 5,  5, 7, 52, 0, 27, 9, 61, 2, 83, 6, 12, 3, 53, 4, 22, 1, 56, 
    9, 98, 3, 24, 5, 15, 8, 44, 6, 54, 7, 94, 0,  1, 4,  3, 2, 11, 1, 37, 
    9, 15, 5, 75, 2, 25, 6, 17, 4, 94, 8,  1, 7, 40, 1, 35, 3, 30, 0,  2, 
    6, 87, 3, 95, 8, 77, 0,  4, 2, 39, 7, 23, 5,  7, 9, 86, 1, 51, 4, 34, 
    1,  3, 3, 87, 2, 53, 8, 37, 7, 34, 6, 89, 9, 31, 4, 82, 0, 71, 5, 98, 
    8, 37, 3, 52, 4, 52, 2, 67, 7, 59, 0, 57, 5, 66, 9, 34, 1, 41, 6, 24, 
    4, 78, 1, 61, 8, 88, 3, 36, 5, 32, 7, 17, 9, 95, 2, 72, 6, 90, 0, 28
  };
  const int r082[] = {
    10, 10, // Number of jobs and machines
    1, 42, 7, 67, 5, 12, 8, 56, 3,  3, 0, 98, 6, 70, 9, 23, 4, 49, 2, 71, 
    3, 17, 0, 63, 6, 35, 7, 20, 4, 17, 5, 94, 8, 81, 1,  9, 9, 69, 2, 46, 
    2, 92, 1, 17, 3, 58, 0, 89, 4, 41, 8, 26, 9, 74, 7, 66, 5, 32, 6, 23, 
    0, 16, 8, 29, 4, 65, 6, 88, 9, 59, 1, 70, 7, 87, 5, 55, 2, 86, 3,  8, 
    6, 42, 0, 70, 9, 68, 5, 90, 7, 79, 2, 31, 1,  2, 4, 41, 8, 49, 3, 82, 
    9, 11, 8, 96, 0,  2, 4, 91, 1, 43, 6,  8, 7, 52, 2, 92, 5, 94, 3, 57, 
    8, 81, 0, 30, 3, 71, 1, 54, 2, 91, 4, 94, 7, 86, 9, 89, 5, 33, 6, 80, 
    4, 24, 0, 40, 3, 81, 6, 99, 2, 70, 1, 87, 7, 92, 9, 59, 5,  9, 8, 15, 
    4, 29, 1, 23, 7, 15, 3, 11, 0, 73, 8, 40, 5, 65, 6, 34, 9, 83, 2, 65, 
    8, 90, 9, 97, 2, 11, 4, 94, 5, 52, 6, 27, 1, 32, 0, 24, 3,  2, 7, 66
  };
  const int r083[] = {
    10, 10, // Number of jobs and machines
    7, 60, 3, 91, 6,  1, 5, 36, 9, 35, 8, 61, 1, 10, 0, 70, 4, 49, 2, 29, 
    1, 37, 5, 64, 6, 11, 4, 78, 2,  2, 3, 90, 8, 96, 9, 12, 7, 26, 0, 18, 
    1, 13, 0, 95, 3, 53, 5, 88, 7, 94, 4, 43, 9, 98, 2, 25, 8, 70, 6, 60, 
    2, 22, 8, 22, 0, 22, 1, 51, 9, 77, 7, 62, 4, 92, 5, 75, 3, 91, 6, 54, 
    1,  8, 5, 46, 0, 65, 7, 62, 3, 39, 8, 92, 2, 31, 4,  1, 6, 28, 9, 65, 
    7, 47, 1, 64, 8, 48, 4, 18, 5, 10, 2,  9, 0, 44, 6, 12, 3, 19, 9, 64, 
    6, 19, 4, 49, 1, 82, 2, 30, 5, 95, 3, 37, 8, 58, 9, 11, 7, 25, 0, 20, 
    4, 96, 8, 30, 0, 63, 1, 43, 5, 98, 9, 73, 3, 41, 7, 41, 6, 84, 2, 54, 
    8, 18, 6, 28, 0, 96, 7, 79, 5, 66, 4, 92, 1, 20, 2,  7, 9, 80, 3, 77, 
    3, 40, 1, 73, 4, 64, 8, 90, 2, 11, 7, 44, 9,  4, 6,  5, 5, 98, 0, 38
  };
  const int r084[] = {
    10, 10, // Number of jobs and machines
    2, 43, 1, 78, 5, 92, 7, 96, 3, 94, 8, 82, 0, 77, 6, 75, 9,  8, 4,  5, 
    9, 43, 0, 23, 1, 62, 8,  4, 3, 51, 7, 93, 2, 70, 4, 81, 6, 80, 5, 21, 
    3, 19, 8, 85, 2, 79, 1, 22, 9, 22, 4, 24, 6, 29, 7, 89, 5, 47, 0, 86, 
    5,  6, 8, 78, 6, 37, 9, 34, 1,  4, 2, 71, 0,  8, 4, 36, 7, 14, 3, 65, 
    8, 17, 0, 91, 2, 58, 7, 83, 5, 30, 6, 89, 9, 44, 4, 60, 1, 73, 3, 83, 
    0, 11, 1, 19, 6, 86, 3,  3, 5, 18, 8, 77, 9,  4, 4, 72, 7, 81, 2,  5, 
    5, 76, 3, 64, 4, 44, 0, 67, 8, 63, 1, 41, 6, 25, 7, 39, 9, 87, 2, 91, 
    1, 59, 0, 78, 9, 81, 7, 15, 2, 52, 5,  6, 4,  5, 8, 42, 3, 53, 6, 95, 
    3, 66, 0, 90, 7, 95, 6,  1, 1, 80, 9, 84, 4, 91, 5, 37, 2, 23, 8, 53, 
    3,  8, 9, 62, 5, 49, 1, 43, 0, 71, 6, 62, 8, 30, 4, 13, 7, 62, 2,  4
  };
  const int r085[] = {
    10, 10, // Number of jobs and machines
    7, 53, 4, 91, 3, 88, 9,  5, 2, 88, 5, 31, 8, 59, 1, 22, 0, 19, 6, 17, 
    5, 64, 6, 95, 0, 73, 2, 51, 1, 39, 7, 57, 9, 21, 8, 68, 4, 30, 3, 88, 
    5, 33, 3,  1, 2, 53, 9, 78, 4, 36, 0, 80, 6, 16, 7,  4, 1, 51, 8, 74, 
    9, 61, 7, 40, 8, 22, 6, 29, 0, 35, 3, 97, 2, 57, 1, 27, 5, 21, 4, 64, 
    2, 53, 3, 47, 4,  8, 5,  9, 7, 32, 6, 46, 0, 49, 1, 49, 9, 29, 8, 42, 
    1, 25, 2, 49, 4, 67, 7, 83, 6, 20, 3, 91, 8, 75, 9, 57, 5, 23, 0,  2, 
    8, 54, 5, 57, 6, 84, 7,  2, 3,  4, 0, 47, 2,  4, 4, 46, 9, 99, 1, 96, 
    0, 23, 8, 56, 1, 28, 4,  9, 9,  2, 3, 58, 7, 67, 6,  2, 5, 12, 2,  8, 
    5, 38, 0,  2, 9, 81, 3, 11, 6, 55, 2, 60, 1, 26, 8, 77, 4, 92, 7, 66, 
    4, 69, 3, 85, 7,  7, 6,  2, 8,  5, 5, 44, 2, 43, 1, 37, 9, 59, 0, 10
  };
  const int r086[] = {
    10, 10, // Number of jobs and machines
    9, 90, 0,  7, 2, 30, 5, 91, 8, 53, 4, 19, 6, 66, 7, 84, 3, 36, 1, 64, 
    0, 90, 3, 17, 1, 77, 9, 40, 2, 13, 6, 92, 5, 47, 4, 17, 7, 66, 8, 47, 
    3, 85, 5, 19, 0, 86, 7,  1, 8,  4, 6, 14, 2, 85, 1, 87, 9, 51, 4, 18, 
    0, 46, 3, 24, 2, 79, 4, 98, 9, 42, 1, 22, 5, 79, 8, 62, 7, 36, 6, 91, 
    6, 79, 5, 12, 0, 23, 8, 64, 3, 69, 2, 27, 7, 70, 9, 52, 4, 55, 1,  6, 
    0, 43, 4,  7, 7, 42, 3, 97, 1, 82, 5, 48, 8, 48, 2, 22, 9, 35, 6, 61, 
    0, 77, 3, 10, 7, 92, 5, 39, 4, 42, 2,  7, 9, 15, 8,  6, 1, 54, 6, 29, 
    3, 27, 7, 29, 8, 42, 6, 11, 2, 62, 4, 69, 1, 54, 0, 70, 5, 32, 9, 54, 
    9, 76, 2, 13, 8, 21, 7, 94, 4, 69, 3, 94, 6, 21, 1, 31, 5, 90, 0, 62, 
    9, 38, 5, 14, 1, 92, 0, 23, 8,  8, 7, 58, 2, 91, 3, 41, 6, 63, 4, 64
  };
  const int r087[] = {
    10, 10, // Number of jobs and machines
    1, 74, 0, 93, 4, 96, 2, 39, 8,  5, 6, 19, 9, 41, 3, 43, 5, 61, 7, 45, 
    6, 39, 5, 42, 0, 52, 7, 49, 9,  6, 2, 81, 1, 92, 4, 26, 8, 94, 3, 77, 
    1, 32, 3, 67, 7, 24, 4, 51, 6,  6, 5, 77, 2, 20, 8, 58, 9, 71, 0, 42, 
    4, 78, 7, 37, 0, 84, 5, 79, 1, 40, 6, 10, 2, 49, 9, 94, 8, 13, 3, 76, 
    4, 23, 7, 87, 5, 87, 8, 93, 6, 46, 3, 85, 0, 28, 2, 87, 9, 51, 1, 97, 
    6, 28, 0, 86, 1, 20, 7, 32, 3, 77, 9, 12, 5,  4, 2, 46, 8, 13, 4, 46, 
    7, 19, 2,  4, 8, 40, 5, 34, 6, 73, 4, 89, 0, 22, 1, 90, 9,  7, 3, 91, 
    8, 66, 2, 44, 0, 69, 5, 21, 4, 58, 6, 76, 9, 93, 1, 17, 3, 87, 7, 14, 
    4, 18, 8, 31, 1, 37, 7, 67, 9, 66, 5, 18, 2, 46, 0, 66, 6, 19, 3, 22, 
    4, 58, 0, 23, 9, 88, 5, 26, 3, 52, 6, 65, 1, 42, 8, 24, 7, 96, 2, 34
  };
  const int r088[] = {
    10, 10, // Number of jobs and machines
    4, 32, 7, 23, 2, 81, 6, 19, 1, 59, 5, 97, 8, 47, 0, 79, 3, 20, 9, 63, 
    8, 28, 0, 11, 5, 12, 9,  6, 3, 55, 2, 26, 7, 58, 1, 39, 4, 32, 6, 53, 
    8, 89, 7,  5, 0,  1, 6, 18, 2, 68, 3, 60, 9, 40, 1, 62, 4,  7, 5, 88, 
    2, 52, 3, 98, 1, 28, 9, 89, 6, 37, 0, 63, 5, 77, 7, 24, 8, 54, 4, 89, 
    1, 99, 2, 30, 5, 88, 3, 37, 6, 98, 0, 83, 8, 18, 7, 45, 4, 87, 9,  9, 
    4, 28, 3,  4, 8, 25, 6, 71, 5, 54, 0,  3, 2, 47, 7, 75, 9, 97, 1, 11, 
    4, 55, 1, 37, 8,  4, 5, 73, 9, 45, 6, 38, 2, 36, 7, 85, 3, 83, 0, 16, 
    2,  7, 9, 71, 1,  3, 0, 92, 3, 86, 8, 98, 4, 56, 6, 52, 7, 81, 5, 19, 
    4, 20, 9, 45, 6, 22, 1, 31, 5, 36, 3, 51, 0, 27, 2, 36, 7, 90, 8, 13, 
    4, 25, 1, 51, 7,  1, 8, 60, 6,  5, 9, 59, 2, 95, 3, 84, 0,  7, 5, 82
  };
  const int r089[] = {
    10, 10, // Number of jobs and machines
    1, 45, 3, 46, 2, 75, 8, 73, 7, 56, 5, 97, 4,  7, 9, 63, 0, 89, 6, 67, 
    0, 42, 4, 65, 8, 74, 2, 29, 9, 78, 1, 34, 3, 90, 7, 96, 5, 79, 6, 38, 
    5, 44, 3, 38, 0,  9, 7,  6, 6,  6, 9, 43, 1, 69, 2, 22, 8, 16, 4, 33, 
    0, 59, 2,  4, 1, 25, 3, 92, 9, 43, 5, 30, 4, 39, 8, 22, 7, 43, 6, 22, 
    2, 51, 8, 40, 9, 84, 5, 26, 6, 52, 7, 47, 1, 69, 0, 19, 3, 84, 4, 38, 
    9, 87, 1, 80, 2, 91, 6,  4, 0,  4, 5, 50, 7, 98, 3, 99, 4, 49, 8, 32, 
    9, 53, 5, 98, 2, 59, 4, 64, 8, 12, 0, 22, 7, 76, 3, 60, 1, 81, 6, 38, 
    7, 27, 0, 26, 8, 76, 3, 68, 5, 33, 9, 90, 2, 82, 4, 30, 1, 55, 6, 44, 
    4, 59, 8, 40, 6, 11, 5, 65, 0, 38, 1, 93, 3, 41, 9, 71, 2, 60, 7, 91, 
    0, 94, 8, 89, 3, 25, 2, 13, 1, 64, 4, 66, 6, 76, 9, 55, 7, 45, 5, 39
  };
  const int r090[] = {
    10, 10, // Number of jobs and machines
    2, 70, 0,  9, 3, 52, 1, 92, 4, 90, 5, 59, 7, 90, 6, 46, 9, 37, 8, 69, 
    7, 56, 4, 64, 0, 34, 2, 21, 3, 52, 5, 53, 9, 60, 6,  3, 8,  7, 1, 39, 
    1, 28, 2, 65, 4, 80, 7, 61, 8, 14, 9,  9, 3, 37, 6, 49, 0, 73, 5, 29, 
    6, 52, 3, 50, 1, 74, 4, 38, 8,  5, 2, 13, 5, 85, 0, 62, 9, 88, 7, 63, 
    6, 46, 5, 98, 7, 84, 3, 20, 1, 83, 0, 74, 2,  8, 4, 83, 9, 21, 8, 25, 
    1, 99, 2, 98, 5, 86, 8, 54, 3, 10, 4, 56, 0, 79, 7, 87, 6, 64, 9,  4, 
    9, 92, 7, 25, 4, 79, 5, 33, 3, 36, 1, 91, 0, 74, 8, 93, 2,  7, 6, 86, 
    8, 28, 1,  7, 5, 25, 2, 39, 6, 85, 0, 86, 9, 10, 7,  8, 3, 17, 4,  7, 
    3, 32, 9, 28, 0, 86, 1, 41, 5, 44, 2, 17, 8, 98, 7, 48, 6, 87, 4, 18, 
    5, 80, 7, 85, 1, 21, 8, 45, 6, 98, 4, 53, 2, 13, 3, 87, 9, 28, 0, 50
  };
  const int r091[] = {
    10, 10, // Number of jobs and machines
    6, 12, 2, 29, 7,  7, 1, 23, 0, 64, 3, 87, 8, 64, 4, 48, 9, 70, 5, 52, 
    9, 79, 7, 45, 4,  6, 0, 17, 6, 68, 1, 35, 8, 15, 5, 31, 2, 61, 3, 30, 
    0, 67, 5, 74, 6, 80, 3, 78, 2, 55, 4, 74, 1, 55, 7, 15, 9, 10, 8, 92, 
    7, 38, 5,  6, 9, 79, 3, 47, 2, 85, 8, 95, 6, 64, 0,  1, 1, 67, 4, 51, 
    8, 22, 6, 57, 0, 65, 7, 11, 4, 60, 3, 95, 9, 85, 1,  3, 2,  3, 5, 36, 
    1,  2, 6, 49, 0, 56, 3, 68, 9, 37, 2, 51, 5,  3, 8, 15, 7, 63, 4, 15, 
    9, 45, 3, 56, 4, 73, 7, 73, 8, 34, 0, 65, 6, 16, 5,  1, 1, 18, 2, 56, 
    5, 50, 4, 71, 8, 35, 2, 51, 7, 69, 0, 93, 6, 84, 3, 61, 9, 95, 1, 85, 
    8, 51, 6,  9, 4, 54, 5, 87, 7, 30, 9, 50, 3, 23, 1, 87, 0, 78, 2, 44, 
    6, 95, 1, 59, 0, 10, 7, 18, 2, 35, 9, 66, 8, 49, 5,  6, 4, 53, 3, 34
  };
  const int r092[] = {
    10, 10, // Number of jobs and machines
    7, 66, 4, 92, 5, 34, 3, 94, 0, 27, 9, 66, 6, 66, 1, 37, 8, 47, 2,  2, 
    1, 12, 8, 61, 5,  4, 6, 18, 9, 11, 0, 95, 2, 42, 4, 77, 3, 25, 7, 86, 
    8, 27, 4, 74, 9, 60, 6, 88, 1, 65, 0, 60, 2, 98, 5,  1, 7, 20, 3, 23, 
    1, 86, 6, 76, 9, 80, 7, 10, 5, 17, 3, 28, 4, 13, 2, 20, 8, 91, 0, 24, 
    9, 36, 7, 83, 2, 89, 0, 84, 5, 38, 3, 46, 6, 68, 1, 18, 4, 78, 8,  7, 
    4, 20, 1, 84, 9,  1, 5, 98, 8,  7, 2,  7, 7, 46, 0, 58, 6, 71, 3, 21, 
    1, 88, 7, 90, 8, 51, 4, 93, 5, 50, 6, 18, 3, 53, 0, 71, 2, 68, 9,  5, 
    8, 75, 1, 10, 5, 61, 6, 68, 4, 39, 2, 68, 9, 86, 0, 80, 7, 49, 3, 60, 
    3, 26, 9, 99, 6, 28, 2, 81, 8, 32, 5, 32, 1, 58, 7, 34, 0, 92, 4, 32, 
    9, 28, 0, 28, 1, 46, 6, 12, 4, 68, 2, 61, 7, 39, 3, 45, 8, 97, 5, 62
  };
  const int r093[] = {
    10, 10, // Number of jobs and machines
    0, 18, 9, 71, 6, 84, 7, 45, 1, 49, 3, 96, 2, 12, 5, 77, 8, 75, 4, 45, 
    9, 50, 2, 26, 8, 10, 0, 49, 4, 76, 7, 67, 1, 30, 5, 69, 6, 98, 3, 48, 
    4, 78, 5, 48, 9, 98, 2,  5, 8, 21, 3,  4, 6, 25, 1, 24, 0, 16, 7, 19, 
    6, 23, 3, 96, 0, 82, 2, 35, 1, 39, 4, 28, 9, 64, 7,  9, 8, 80, 5,  3, 
    8, 83, 1, 80, 0, 76, 7, 59, 5, 41, 2, 34, 3, 46, 9, 81, 4, 89, 6, 10, 
    8, 63, 9, 66, 5, 55, 4, 83, 0, 45, 3, 69, 7, 83, 1,  9, 6, 13, 2, 48, 
    9, 75, 7, 48, 5, 47, 8, 51, 1, 70, 3, 15, 2, 84, 4, 23, 6, 69, 0, 41, 
    3, 63, 7,  8, 0, 24, 8,  5, 5, 61, 6, 54, 2, 50, 4, 95, 1, 50, 9, 71, 
    5, 50, 7, 67, 0, 81, 6, 45, 3, 30, 8, 64, 4, 13, 9, 31, 1, 42, 2, 70, 
    9,  7, 5, 30, 4, 60, 7, 37, 3, 87, 1, 95, 6, 40, 0, 92, 2, 59, 8, 18
  };
  const int r094[] = {
    10, 10, // Number of jobs and machines
    6,  5, 7, 74, 9, 92, 4, 99, 2, 30, 1, 42, 0,  5, 8, 19, 3, 26, 5, 41, 
    4, 56, 7, 70, 9, 81, 2, 16, 1, 93, 0, 53, 6, 65, 3, 62, 8, 81, 5,  9, 
    6, 50, 3, 61, 4, 17, 0, 42, 5, 36, 8, 67, 9, 95, 7, 87, 1, 58, 2, 64, 
    6,  8, 9, 10, 4, 51, 0, 21, 3, 94, 2,  1, 8, 27, 5, 96, 1, 60, 7, 28, 
    4, 62, 9, 53, 3,  3, 1, 55, 5, 66, 0, 48, 6, 17, 7, 72, 8, 25, 2, 41, 
    4, 11, 2, 45, 3,  8, 8, 95, 7, 62, 0, 31, 6, 67, 5, 68, 1, 43, 9, 46, 
    6, 98, 0, 45, 1, 94, 9, 17, 5, 95, 3, 88, 4, 54, 7, 80, 2, 92, 8, 66, 
    3, 68, 9, 47, 0, 39, 2, 72, 1, 32, 7, 85, 8, 29, 6, 87, 4, 16, 5,  1, 
    8, 34, 7, 40, 6, 15, 1, 88, 9, 49, 2, 24, 3, 48, 5, 25, 4, 74, 0, 91, 
    4, 95, 5,  3, 2, 48, 0, 25, 6,  2, 8, 25, 7, 54, 1, 46, 9, 81, 3, 47
  };
  const int r095[] = {
    10, 10, // Number of jobs and machines
    1, 50, 3, 91, 7, 94, 6, 98, 8, 42, 2, 18, 0, 84, 5, 44, 4, 50, 9, 80, 
    3, 94, 6,  7, 5, 70, 1, 83, 2, 83, 0, 33, 8, 70, 9, 97, 7, 81, 4, 74, 
    5, 44, 4, 22, 6, 72, 7, 56, 1, 68, 0, 62, 8, 36, 3, 81, 2, 11, 9,  6, 
    0, 29, 1, 56, 9, 20, 7, 57, 8, 22, 5,  8, 3, 46, 4, 63, 6, 93, 2, 48, 
    1, 42, 4,  5, 2, 98, 5, 28, 7, 26, 3,  8, 8, 19, 0, 77, 9, 68, 6, 44, 
    7, 58, 2, 12, 5, 28, 4, 37, 3, 74, 6, 62, 0,  7, 9, 94, 1, 79, 8, 49, 
    9, 36, 8, 67, 2, 32, 7, 23, 4, 20, 1, 28, 5, 30, 6, 58, 0,  5, 3, 88, 
    7,  3, 0, 75, 4, 60, 9, 18, 1, 14, 6, 63, 3, 89, 5, 71, 8, 13, 2, 43, 
    8, 66, 0,  4, 7, 42, 9, 43, 6, 35, 1, 71, 5, 86, 2, 23, 4, 93, 3,  8, 
    3, 83, 1, 76, 0, 51, 6, 14, 5, 57, 2, 31, 4, 83, 9, 31, 7, 48, 8, 93
  };
  const int r096[] = {
    10, 10, // Number of jobs and machines
    1, 34, 8, 33, 3, 74, 0, 83, 5, 76, 2, 40, 6, 62, 7, 87, 9, 55, 4, 87, 
    4, 83, 2, 72, 7, 48, 6, 65, 1, 14, 0, 37, 8, 91, 5, 12, 3, 32, 9, 89, 
    0, 89, 5, 49, 9, 62, 2, 20, 3, 33, 4, 14, 6, 61, 7, 91, 8, 46, 1, 92, 
    4, 20, 6, 56, 9, 97, 3, 79, 2, 81, 0, 97, 8, 72, 1, 21, 5,  7, 7, 67, 
    7, 87, 4, 26, 2, 72, 3, 76, 6, 74, 0, 29, 9, 11, 1, 48, 8, 19, 5, 12, 
    4, 13, 1,  1, 9, 91, 7,  1, 8, 24, 6, 29, 3, 15, 0, 62, 2, 80, 5, 12, 
    3, 72, 1, 31, 7,  8, 9,  1, 0, 65, 8, 46, 6, 93, 2, 41, 5, 33, 4, 39, 
    5, 57, 2, 77, 3, 10, 9, 50, 1, 44, 0, 25, 8, 45, 6, 63, 7, 30, 4, 15, 
    9, 74, 3, 49, 1, 29, 0, 39, 5, 56, 6, 52, 4, 24, 2, 62, 8, 58, 7, 98, 
    4, 74, 3, 85, 9, 30, 2, 31, 0, 80, 6, 76, 1, 23, 8, 42, 5, 25, 7, 96
  };
  const int r097[] = {
    10, 10, // Number of jobs and machines
    6, 69, 5, 71, 8,  7, 1, 96, 4, 14, 2, 34, 7, 25, 0, 45, 3, 66, 9, 22, 
    2, 98, 3, 91, 1, 39, 9, 52, 5, 95, 4, 10, 0, 56, 8, 77, 7, 49, 6, 47, 
    0, 48, 1, 95, 7, 27, 4, 38, 5, 49, 6,  3, 2, 55, 3, 90, 9, 44, 8, 36, 
    7, 69, 2,  2, 5, 16, 1, 12, 6, 54, 8, 48, 0,  7, 4, 79, 3, 97, 9, 23, 
    5, 86, 6, 42, 0, 33, 4, 59, 9, 99, 8,  3, 7, 84, 3, 80, 2, 71, 1,  8, 
    6, 40, 4, 67, 5, 63, 0, 79, 9, 10, 8, 24, 1, 79, 2, 84, 3, 41, 7, 32, 
    4, 98, 8, 72, 1, 39, 3, 65, 9, 47, 5, 77, 7, 69, 2, 92, 6, 13, 0, 50, 
    8, 24, 9, 87, 4, 42, 3, 85, 2, 57, 5, 21, 1, 36, 0, 99, 6, 58, 7, 75, 
    7, 53, 6, 62, 9, 79, 4, 50, 0, 52, 2, 84, 5, 63, 3, 84, 1, 25, 8, 17, 
    6, 37, 2, 86, 3, 60, 4, 66, 9, 53, 8, 74, 1, 60, 5, 45, 7, 84, 0, 61
  };
  const int r098[] = {
    10, 10, // Number of jobs and machines
    3, 79, 6, 30, 5, 50, 1, 92, 7, 35, 4, 70, 0, 16, 8, 56, 2,  8, 9, 72, 
    6, 90, 9, 20, 1, 21, 3, 69, 2, 68, 5, 97, 0, 29, 4, 60, 8, 70, 7, 23, 
    6, 39, 2, 56, 3, 98, 4, 77, 8, 64, 9, 88, 5, 87, 0, 45, 1, 71, 7, 31, 
    9, 16, 1, 84, 7, 88, 2, 74, 6, 99, 5, 27, 8, 95, 4,  5, 0, 26, 3, 33, 
    4, 56, 2, 29, 6, 60, 9, 11, 1, 82, 5,  5, 0, 37, 3, 36, 7, 77, 8, 28, 
    1, 26, 7, 19, 8, 39, 5, 13, 4, 73, 6, 99, 2, 89, 0, 85, 9, 24, 3, 99, 
    4,  6, 2, 63, 1, 34, 3, 47, 0, 59, 8, 95, 6, 58, 9, 90, 5, 41, 7, 88, 
    8, 17, 7, 41, 4, 28, 5, 53, 1, 43, 2, 62, 9, 98, 0, 61, 6, 81, 3, 37, 
    6, 66, 0, 55, 4, 99, 9, 52, 8, 20, 7, 51, 5,  3, 1, 67, 2, 85, 3,  6, 
    6, 49, 4, 80, 1, 77, 3, 24, 2, 66, 0, 99, 9, 41, 8, 26, 7, 49, 5, 99
  };
  const int r099[] = {
    10, 10, // Number of jobs and machines
    5, 22, 0, 84, 4, 29, 7, 67, 6, 17, 3, 47, 9, 51, 8, 26, 1, 78, 2, 51, 
    7, 32, 4, 73, 5, 99, 0, 22, 1, 45, 8, 59, 9, 84, 6,  3, 3, 72, 2, 36, 
    4, 39, 2, 20, 3, 13, 6, 24, 9,  6, 1, 46, 0, 61, 7, 99, 8, 55, 5, 61, 
    6, 43, 9, 47, 5, 21, 3, 42, 0, 51, 2, 26, 8, 69, 1, 27, 7, 91, 4, 22, 
    6, 23, 8, 68, 7, 79, 3, 39, 2, 31, 0, 38, 5, 11, 9, 36, 4, 18, 1, 48, 
    0, 42, 2, 22, 6, 16, 7, 86, 4, 23, 8, 87, 1, 24, 5, 43, 3, 85, 9, 98, 
    9, 73, 5, 96, 3, 27, 2, 54, 7, 32, 8, 12, 4, 81, 6, 38, 1, 50, 0, 29, 
    8, 54, 0, 13, 2, 81, 5, 78, 3, 99, 9, 84, 1, 55, 7, 78, 4, 74, 6, 66, 
    1, 99, 2,  2, 6, 59, 4, 51, 8, 21, 7, 82, 9, 16, 5, 28, 0, 94, 3, 85, 
    2, 33, 4, 96, 8, 98, 3, 35, 5, 17, 9, 34, 1, 40, 7, 53, 6, 71, 0, 38
  };
  const int r100[] = {
    10, 10, // Number of jobs and machines
    2, 58, 3, 28, 1, 98, 4, 85, 5, 98, 6, 40, 9, 68, 7, 44, 0, 32, 8, 43, 
    2, 58, 0, 20, 5, 59, 9, 61, 8, 96, 4, 58, 3, 95, 6, 59, 7, 13, 1, 65, 
    0, 88, 1, 88, 2, 49, 3, 62, 4, 94, 6, 49, 8, 29, 7, 69, 5, 53, 9, 91, 
    4, 94, 2, 74, 9, 74, 1, 51, 5, 55, 3, 18, 7, 38, 8, 97, 6, 65, 0, 23, 
    6, 94, 5, 57, 9, 57, 0, 37, 8,  7, 7, 41, 1, 85, 4, 48, 2, 29, 3, 22, 
    0, 31, 9, 35, 8, 18, 6, 82, 7, 85, 1,  8, 5, 23, 4, 16, 2, 81, 3, 33, 
    4, 42, 3, 39, 0, 18, 2, 50, 5, 41, 6, 70, 1, 83, 8, 28, 7, 75, 9, 45, 
    4, 93, 6, 82, 7, 18, 5, 33, 3, 24, 2, 90, 0, 39, 1, 75, 8, 84, 9, 51, 
    4, 51, 0, 71, 1, 18, 5, 49, 7, 43, 2, 14, 3, 22, 9, 52, 6, 57, 8, 87, 
    3, 63, 9, 42, 2, 45, 1, 83, 0, 94, 8, 72, 4, 21, 6, 74, 5, 34, 7, 52
  };
  const int r101[] = {
    10, 10, // Number of jobs and machines
    4, 18, 1,  1, 8, 56, 0, 41, 9, 47, 2, 73, 7, 78, 3,  3, 5, 73, 6, 29, 
    9, 62, 1, 58, 3, 10, 2, 68, 6, 97, 4, 48, 5, 22, 8, 23, 0,  1, 7, 69, 
    8, 96, 7, 88, 5, 79, 1,  4, 6, 52, 0, 22, 2, 74, 4, 87, 9, 30, 3, 43, 
    5, 12, 9, 41, 2, 81, 8,  6, 1, 82, 7, 71, 4, 46, 6, 72, 3, 67, 0, 14, 
    2, 84, 4, 95, 5,  8, 0, 53, 8, 34, 9, 65, 7, 79, 3, 70, 6, 74, 1,  6, 
    6, 97, 2, 14, 5, 73, 3, 80, 7, 62, 0, 46, 9, 80, 1, 78, 4, 58, 8, 14, 
    4, 50, 2, 58, 3, 98, 8, 64, 5, 11, 7, 90, 0, 11, 6, 94, 9, 98, 1, 18, 
    3, 31, 1, 23, 0, 75, 8, 90, 6, 24, 9, 57, 4, 68, 7,  3, 2, 62, 5, 92, 
    4, 77, 1,  9, 2, 85, 5, 68, 8, 49, 3, 72, 9, 26, 6, 42, 0, 96, 7, 71, 
    5, 70, 2, 48, 0, 26, 7, 87, 8,  6, 3, 25, 1, 30, 6, 93, 4, 64, 9, 29
  };
  const int r102[] = {
    10, 10, // Number of jobs and machines
    2, 55, 9, 50, 5, 86, 8, 14, 6, 55, 3, 87, 4, 74, 1, 27, 7, 98, 0, 45, 
    5, 67, 1, 30, 6, 31, 3, 86, 9,  7, 7, 79, 2, 88, 0, 39, 8, 12, 4, 73, 
    1, 47, 2, 12, 7,  4, 4, 97, 5, 22, 0, 95, 3, 63, 8, 54, 9, 23, 6, 82, 
    9, 65, 7, 29, 2, 48, 4, 58, 5, 21, 3, 77, 0, 77, 8, 66, 6, 99, 1, 63, 
    2, 34, 8, 40, 1, 30, 9, 47, 4, 73, 6, 46, 7, 57, 5, 55, 3, 15, 0, 61, 
    4, 18, 9, 44, 5, 63, 8, 93, 2,  3, 1, 43, 0, 82, 7, 46, 6, 38, 3, 97, 
    7, 64, 3, 38, 0, 85, 5,  5, 4, 21, 9,  9, 8, 97, 6, 58, 1, 90, 2, 76, 
    3, 58, 5, 59, 1, 68, 2, 33, 4, 18, 8, 66, 6, 97, 9,  5, 0, 91, 7,  2, 
    1, 37, 5, 12, 6, 27, 9, 34, 8, 16, 0, 70, 3, 91, 7, 10, 2, 86, 4, 94, 
    6, 95, 5, 38, 7, 93, 8, 69, 4, 84, 9, 53, 3, 65, 1, 79, 2, 66, 0, 90
  };
  const int r103[] = {
    10, 10, // Number of jobs and machines
    0, 65, 8, 85, 6, 19, 5, 13, 2,  3, 7, 76, 1, 51, 9, 53, 3, 50, 4, 10, 
    9, 13, 1, 70, 2, 56, 6,  3, 4,  5, 5, 58, 7, 10, 8, 69, 3, 84, 0,  3, 
    3, 24, 6, 22, 4, 84, 0, 93, 2, 79, 5, 86, 1, 89, 9,  9, 8, 80, 7, 29, 
    2, 46, 9, 49, 4, 14, 6, 16, 1, 60, 5, 72, 8, 85, 3, 37, 7, 14, 0, 33, 
    5, 74, 3, 94, 2, 95, 4, 19, 1, 36, 8, 92, 7, 14, 9, 61, 6, 75, 0, 66, 
    9, 98, 8, 89, 3, 89, 1, 30, 7, 29, 0, 38, 4, 78, 5, 97, 2, 77, 6, 14, 
    1, 43, 9, 61, 4, 37, 6,  3, 5, 17, 0, 13, 3, 74, 8, 30, 7, 77, 2, 23, 
    4, 46, 1,  8, 7, 62, 8, 21, 9, 70, 2, 69, 3, 28, 6, 77, 5,  9, 0, 91, 
    2,  5, 6, 91, 4, 78, 9, 93, 8, 53, 3, 34, 7, 11, 5, 39, 1, 51, 0, 53, 
    2, 48, 5, 64, 9, 92, 4, 45, 6, 47, 3,  1, 8,  8, 1, 24, 0, 38, 7, 53
  };
  const int r104[] = {
    10, 10, // Number of jobs and machines
    8, 78, 4, 84, 0, 17, 3, 71, 1,  4, 2, 83, 7, 87, 9, 37, 5,  3, 6,  9, 
    6, 34, 7, 92, 0, 99, 5, 96, 3, 43, 1, 97, 8, 11, 4, 98, 9, 33, 2, 74, 
    5, 11, 8, 46, 1, 81, 6, 43, 3, 54, 9, 44, 0, 24, 7, 94, 2, 95, 4, 70, 
    1, 25, 7, 39, 9, 69, 4, 54, 2, 94, 6, 72, 3, 80, 8, 21, 5, 13, 0, 55, 
    9, 55, 4, 55, 6, 29, 5, 95, 8, 94, 3, 17, 7, 19, 2, 66, 0, 54, 1, 37, 
    5, 57, 8, 65, 0, 14, 1, 94, 7, 18, 3, 44, 2, 24, 4, 41, 6, 79, 9,  5, 
    5, 85, 2, 68, 3, 72, 9, 40, 1, 72, 8, 89, 6, 99, 7,  3, 0, 32, 4, 53, 
    4, 17, 0, 19, 7, 76, 2, 92, 6, 64, 3, 28, 1, 55, 8, 83, 5,  5, 9, 87, 
    2,  7, 1, 72, 8, 82, 4, 67, 7, 31, 3, 53, 6,  1, 0, 59, 9, 77, 5,  5, 
    7, 17, 6, 84, 5, 78, 3, 88, 8, 49, 0, 28, 9, 92, 4, 49, 2,  9, 1, 53
  };
  const int r105[] = {
    10, 10, // Number of jobs and machines
    2, 27, 1, 42, 3, 60, 0, 60, 7, 78, 4,  4, 6, 66, 5, 81, 8, 29, 9, 74, 
    5,  6, 9, 74, 0,  4, 3, 12, 2, 53, 1, 66, 4, 63, 7,  5, 8, 82, 6, 32, 
    9, 46, 8, 93, 2, 42, 0, 66, 1, 87, 3, 91, 7, 21, 4, 60, 5, 18, 6, 90, 
    6, 86, 3, 22, 8, 91, 1, 38, 2, 76, 7, 79, 4,  5, 9, 28, 5, 15, 0, 94, 
    7, 61, 5, 60, 8, 18, 3, 26, 0, 75, 9, 20, 1, 48, 2, 39, 4, 72, 6, 91, 
    8, 22, 2, 98, 3, 53, 7, 89, 9, 48, 1, 45, 4, 27, 5, 93, 0, 19, 6, 81, 
    0, 32, 3, 17, 2,  3, 8, 97, 1, 19, 9, 35, 5, 47, 7, 47, 4, 38, 6, 95, 
    2, 14, 7,  7, 5, 28, 9, 54, 0, 14, 1, 45, 4, 72, 8, 93, 3, 18, 6, 80, 
    6, 98, 9,  4, 5, 52, 0, 33, 3,  5, 7, 21, 8, 29, 1, 99, 4, 48, 2, 79, 
    1, 89, 9, 79, 3, 63, 7,  6, 6, 15, 2, 48, 5, 66, 0, 69, 8, 30, 4, 19
  };
  const int r106[] = {
    10, 10, // Number of jobs and machines
    6, 35, 9, 49, 7, 46, 3, 90, 0,  1, 2, 55, 8, 30, 4, 37, 1, 87, 5, 64, 
    1, 15, 5, 33, 6, 38, 3, 52, 2, 82, 4, 17, 0, 57, 8, 62, 7, 22, 9, 58, 
    3, 85, 9, 94, 4, 62, 1, 59, 6, 13, 8, 45, 5,  2, 2, 78, 7, 86, 0,  9, 
    9, 42, 3, 27, 8, 69, 6,  6, 0, 78, 4, 63, 7, 50, 2, 96, 5, 52, 1, 25, 
    7, 56, 2, 45, 8, 86, 4, 84, 6, 65, 9, 28, 3, 89, 1, 68, 5, 38, 0, 37, 
    3, 15, 6,  8, 8, 99, 2,  7, 1, 66, 7, 75, 0, 97, 5, 69, 4, 28, 9, 34, 
    5, 75, 1, 26, 6,  8, 2, 77, 4, 68, 8, 32, 0, 82, 9, 23, 7, 48, 3, 66, 
    3, 82, 2,  9, 0, 10, 8, 35, 9, 16, 7, 39, 6, 31, 4, 18, 5, 49, 1, 75, 
    3, 13, 7, 96, 6, 16, 0, 83, 9,  3, 5, 13, 1, 86, 4, 27, 8, 57, 2, 87, 
    5, 50, 4, 55, 2, 35, 1, 41, 8, 19, 9,  1, 3, 26, 0, 34, 6, 38, 7, 94
  };
  const int r107[] = {
    10, 10, // Number of jobs and machines
    9,  6, 8, 15, 4, 68, 5, 52, 6, 88, 1, 86, 7, 96, 3, 59, 0, 45, 2, 20, 
    6,  2, 3, 26, 7, 95, 1, 88, 4, 27, 8, 76, 5, 12, 9, 67, 2, 39, 0,  6, 
    0, 77, 8, 43, 6, 46, 2,  2, 5, 89, 9, 58, 1, 31, 4,  2, 7, 13, 3, 97, 
    3, 52, 6, 66, 8, 20, 9, 76, 5, 19, 7, 32, 0, 36, 2, 97, 4, 46, 1,  7, 
    2, 13, 5, 32, 7, 87, 8, 33, 0, 21, 1, 28, 4, 53, 3, 86, 6, 62, 9, 80, 
    7, 27, 4,  3, 3, 73, 9, 50, 8, 71, 1, 96, 2, 77, 5, 19, 6, 90, 0, 88, 
    4, 46, 2, 19, 8, 62, 7, 51, 3, 55, 5, 97, 1, 48, 0, 40, 6, 91, 9, 22, 
    8, 21, 7, 10, 5, 40, 2, 32, 6, 41, 0, 31, 4, 79, 3, 28, 1, 17, 9, 29, 
    3, 83, 5,  6, 9, 68, 8, 20, 2, 73, 6, 10, 7,  8, 4, 70, 0, 86, 1, 13, 
    6, 48, 5, 92, 2, 18, 0, 15, 9, 60, 8, 82, 7, 63, 3, 44, 1, 22, 4, 28
  };
  const int r108[] = {
    10, 10, // Number of jobs and machines
    3, 48, 0, 71, 7, 53, 1, 17, 2, 70, 9, 66, 5, 10, 4, 74, 8, 64, 6, 76, 
    4, 35, 7, 44, 2, 32, 5, 14, 0, 61, 3, 15, 9, 81, 1, 45, 6, 47, 8, 29, 
    6,  8, 3, 75, 7, 87, 2, 24, 0, 52, 8, 17, 1, 32, 4, 13, 9, 49, 5, 59, 
    9, 69, 4, 11, 1, 25, 3, 52, 7, 19, 5, 95, 2,  9, 0, 29, 6, 90, 8, 39, 
    9, 81, 8, 19, 7, 48, 0,  5, 3, 88, 4, 30, 5, 39, 2, 50, 6, 21, 1, 17, 
    5, 34, 6, 20, 9, 90, 3, 63, 0, 73, 4, 54, 8,  4, 1,  5, 7, 94, 2, 69, 
    1, 21, 6, 17, 4, 82, 0, 17, 3, 30, 2, 53, 8, 76, 9, 19, 5, 22, 7, 66, 
    7, 39, 8, 79, 5, 27, 9, 79, 4, 10, 3, 71, 6, 29, 0, 69, 2, 58, 1, 31, 
    3, 87, 7, 84, 0, 15, 2, 43, 4, 39, 8, 40, 6, 59, 9, 32, 5, 37, 1, 25, 
    7, 20, 9, 65, 1, 11, 2, 16, 3, 51, 0, 21, 5, 47, 4, 52, 6,  2, 8, 58
  };
  const int r109[] = {
    10, 10, // Number of jobs and machines
    6, 51, 3, 66, 2, 31, 1, 64, 4, 72, 9, 96, 7, 29, 8, 15, 0, 29, 5, 50, 
    1, 34, 6, 99, 5, 99, 2, 96, 7, 63, 0, 64, 8, 99, 4, 16, 9, 31, 3, 65, 
    4, 24, 0, 17, 5, 96, 1, 67, 7, 64, 3, 17, 2, 29, 8, 32, 6, 63, 9, 19, 
    2, 24, 7, 43, 4,  8, 5, 18, 3, 10, 6, 45, 0, 40, 9, 41, 8, 59, 1, 30, 
    7,  5, 8, 82, 3, 96, 2, 69, 4, 34, 5, 90, 6, 39, 1, 93, 0,  7, 9, 63, 
    0, 76, 2, 33, 6,  5, 3, 63, 1, 74, 7, 41, 8,  1, 5, 43, 9, 90, 4, 77, 
    0,  6, 3, 87, 6, 31, 5, 70, 8, 59, 9, 99, 4, 17, 1,  3, 2, 59, 7, 94, 
    9, 29, 4, 39, 5, 85, 2, 86, 1, 98, 0, 93, 7, 69, 8,  6, 6, 35, 3, 18, 
    4, 78, 9, 32, 8, 85, 1, 27, 5, 85, 6, 87, 3, 84, 7, 97, 2, 77, 0, 62, 
    3, 25, 1, 53, 7, 35, 2, 99, 5, 77, 4, 45, 0, 66, 6,  5, 9, 27, 8, 48
  };
  const int r110[] = {
    10, 10, // Number of jobs and machines
    5, 13, 4, 30, 6, 23, 8, 48, 0, 44, 7, 12, 9, 34, 2, 56, 1, 52, 3, 89, 
    4, 79, 8, 82, 0, 36, 3, 67, 6, 54, 9, 53, 5, 68, 7, 40, 1, 16, 2, 56, 
    5, 94, 9, 18, 0, 31, 4, 30, 7, 76, 8,  9, 3,  9, 1, 10, 6, 95, 2, 96, 
    7, 21, 9, 69, 0, 78, 8, 20, 2, 22, 5, 94, 6,  7, 3, 25, 1, 38, 4, 98, 
    3, 53, 4, 14, 0, 98, 5, 53, 6, 17, 1, 83, 9, 66, 8,  2, 2, 43, 7, 67, 
    4, 78, 7, 47, 3, 76, 2, 83, 1, 63, 0, 70, 5, 48, 8, 94, 6, 66, 9, 79, 
    7, 94, 6,  9, 1, 62, 8,  7, 0, 81, 3, 84, 2, 69, 5,  1, 4, 15, 9, 46, 
    4, 34, 0, 15, 6,  2, 5, 21, 9, 66, 1, 28, 7, 95, 3,  5, 2, 35, 8, 83, 
    5, 30, 9, 11, 0, 14, 7, 99, 2, 94, 4, 86, 1, 76, 8, 62, 6, 38, 3, 13, 
    7, 42, 2, 50, 8, 40, 5, 71, 0, 52, 3, 72, 9, 48, 1, 64, 4, 38, 6, 17
  };
  const int r111[] = {
    10, 10, // Number of jobs and machines
    3, 81, 0,  8, 7, 65, 9, 70, 6, 89, 1, 67, 2, 94, 4, 71, 8, 18, 5, 25, 
    5,  9, 7, 98, 1, 61, 6, 28, 9, 21, 0, 42, 4, 62, 2, 11, 8, 41, 3, 36, 
    1, 10, 5,  1, 0, 47, 8, 73, 6, 21, 7, 30, 9, 12, 3, 40, 2, 93, 4, 10, 
    1, 83, 5, 53, 4, 50, 8, 27, 2, 59, 0, 49, 6, 78, 9, 95, 3, 51, 7, 10, 
    4, 38, 0, 32, 9, 75, 6, 60, 2, 10, 1, 72, 7, 87, 5, 85, 3, 13, 8, 67, 
    2, 53, 6, 59, 7, 98, 3, 30, 0, 44, 9, 58, 4, 15, 8, 79, 5, 86, 1, 15, 
    4, 40, 6, 43, 3, 47, 5, 84, 7, 30, 1, 51, 8, 85, 2, 58, 9, 54, 0, 76, 
    3, 96, 2, 11, 4, 95, 8,  3, 1, 20, 9, 68, 0, 60, 5, 60, 7, 76, 6,  8, 
    7, 27, 1, 26, 9, 32, 5, 19, 8, 19, 0, 47, 4, 93, 3, 14, 6, 34, 2,  7, 
    9, 57, 7, 99, 4, 86, 8, 58, 2, 12, 6, 41, 1, 62, 3, 13, 0, 97, 5,  4
  };
  const int r112[] = {
    10, 10, // Number of jobs and machines
    9,  7, 3,  6, 0, 69, 8, 66, 6, 28, 2, 91, 4, 11, 1, 62, 5, 52, 7, 61, 
    6, 91, 9, 19, 0, 75, 4, 28, 3,  9, 8, 10, 2, 35, 7,  9, 5, 52, 1, 37, 
    2, 78, 7, 27, 6, 68, 8, 17, 3, 28, 9, 37, 0,  8, 4, 91, 1, 37, 5, 64, 
    0, 69, 2,  9, 3, 77, 8, 37, 9, 45, 5, 63, 7, 76, 1, 83, 6, 17, 4, 36, 
    3,  3, 9, 48, 2,  4, 7,  6, 8, 95, 1, 75, 0, 31, 5,  3, 6, 85, 4, 30, 
    5, 60, 0, 92, 1, 46, 2, 81, 3, 94, 9, 85, 7, 67, 8, 92, 6, 76, 4, 29, 
    0, 96, 9, 29, 8, 98, 3, 92, 1, 70, 4, 14, 2, 73, 6, 74, 7, 49, 5, 17, 
    2, 61, 7, 81, 8, 35, 1,  2, 6,  7, 4, 51, 3, 88, 5, 74, 9, 61, 0, 76, 
    8, 90, 2, 40, 0,  9, 9, 41, 5, 27, 1, 95, 7, 81, 4, 52, 3, 68, 6,  2, 
    1, 64, 5, 24, 9, 59, 3, 98, 4, 45, 7, 58, 8, 17, 2, 92, 6, 83, 0, 78
  };
  const int r113[] = {
    10, 10, // Number of jobs and machines
    5, 26, 3, 24, 8, 99, 2, 55, 6, 36, 7,  5, 1, 75, 4, 65, 0, 54, 9, 29, 
    6, 28, 7, 48, 4, 41, 2, 81, 0, 42, 3, 43, 5, 73, 1, 71, 8, 62, 9, 93, 
    9, 26, 1, 19, 4, 27, 3,  7, 6, 15, 7, 68, 2, 91, 0, 23, 5, 35, 8, 62, 
    7, 79, 1, 77, 0,  5, 4, 42, 8, 95, 5, 17, 2, 47, 6, 36, 3, 43, 9,  9, 
    6,  4, 8, 35, 2, 47, 5, 59, 3, 54, 1,  7, 0, 66, 9, 74, 7, 78, 4, 65, 
    4, 39, 3,  9, 7,  3, 0, 73, 2, 40, 6, 41, 8, 58, 9, 97, 5, 34, 1,  7, 
    8, 27, 3, 28, 4, 28, 9, 28, 2, 50, 1, 33, 5, 65, 0, 17, 7,  3, 6,  6, 
    2, 27, 7, 23, 8, 60, 6, 60, 4, 39, 1, 29, 9, 84, 0, 25, 5, 54, 3, 23, 
    8, 11, 9, 89, 2, 54, 0, 66, 5, 19, 6, 31, 3, 79, 4, 94, 1, 88, 7, 96, 
    7, 61, 0, 97, 8, 27, 1, 92, 4, 29, 3,  7, 9, 14, 5, 73, 2, 58, 6, 98
  };
  const int r114[] = {
    10, 10, // Number of jobs and machines
    3,  4, 6, 84, 0, 77, 2,  5, 8, 58, 5, 35, 7, 30, 9, 26, 1, 16, 4, 92, 
    9, 46, 8, 79, 2, 28, 6, 52, 4, 60, 5, 40, 7, 36, 1, 26, 3, 21, 0, 57, 
    5, 25, 7, 80, 8, 80, 4, 14, 3, 52, 0, 23, 2, 93, 6, 33, 9, 78, 1, 94, 
    7, 84, 6, 81, 5, 81, 1, 31, 4, 17, 3, 89, 9, 35, 2, 55, 0, 71, 8, 95, 
    1,  3, 6, 44, 8, 91, 2, 38, 9, 46, 4, 91, 5,  4, 0, 16, 3, 11, 7, 53, 
    2, 80, 0, 25, 5, 52, 3, 85, 1, 99, 8, 79, 4, 88, 9, 29, 7, 39, 6, 56, 
    2, 77, 8, 28, 9, 64, 4, 52, 0, 82, 1, 37, 3, 20, 7, 44, 5, 37, 6, 30, 
    1, 11, 5, 26, 6, 33, 9,  1, 3, 45, 7, 89, 2, 47, 0, 21, 8, 14, 4, 59, 
    1, 57, 8, 64, 6, 39, 2, 80, 0, 13, 5, 57, 7, 76, 4, 19, 9, 55, 3, 50, 
    4, 54, 8, 22, 7, 90, 0, 38, 5, 86, 1, 48, 9, 68, 3, 74, 6, 60, 2, 52
  };
  const int r115[] = {
    10, 10, // Number of jobs and machines
    8, 38, 7, 77, 6, 39, 9,  7, 4, 97, 1, 75, 2, 17, 5, 13, 3, 28, 0, 32, 
    1,  1, 6, 36, 0, 87, 8, 13, 3, 55, 5, 73, 4, 74, 2, 39, 9, 85, 7, 38, 
    4, 43, 2, 57, 0, 44, 8, 48, 7, 99, 3, 47, 6, 75, 5, 87, 9, 54, 1, 45, 
    5, 18, 0, 25, 2, 12, 6, 75, 9, 39, 1, 82, 3, 67, 8, 10, 7, 43, 4, 18, 
    1,  1, 3, 42, 8,  2, 7, 58, 2, 62, 5, 41, 0, 85, 9, 68, 4, 65, 6, 77, 
    3, 27, 1, 69, 4,  6, 9, 12, 2, 72, 7, 55, 0, 88, 8, 93, 6, 35, 5, 30, 
    6, 23, 4,  7, 1, 62, 0, 91, 5, 70, 8, 26, 3, 33, 2, 52, 7, 89, 9, 71, 
    9, 72, 5, 75, 7, 34, 8, 41, 0, 74, 4, 52, 6,  6, 2, 45, 1, 55, 3, 37, 
    7, 68, 6, 44, 3, 50, 5,  2, 2, 42, 9, 23, 1, 42, 8, 15, 0, 68, 4, 10, 
    3, 53, 2, 37, 6, 87, 0, 67, 9, 33, 5, 61, 8, 27, 7, 31, 4,  5, 1, 16
  };
  const int r116[] = {
    10, 10, // Number of jobs and machines
    6, 54, 4, 47, 9, 10, 7, 50, 5,  7, 8, 83, 0,  7, 2, 54, 1, 75, 3, 77, 
    7, 21, 5, 41, 4,  6, 8, 71, 6, 88, 0, 45, 9, 94, 3, 78, 2, 32, 1, 13, 
    3, 61, 2, 98, 4, 43, 8, 41, 9, 71, 5, 90, 0,  5, 1, 16, 6, 75, 7, 75, 
    9, 35, 0, 42, 3, 93, 4, 63, 8, 54, 6, 42, 2, 84, 7,  1, 5, 52, 1, 87, 
    9, 12, 4, 81, 0, 25, 7, 69, 1, 98, 2, 88, 6, 80, 8, 78, 3, 34, 5,  5, 
    1, 96, 3, 52, 6, 21, 2, 14, 9, 57, 5, 96, 0,  6, 8, 54, 4, 25, 7, 61, 
    2,  1, 3,  9, 9, 88, 8, 83, 4, 45, 0, 62, 1, 45, 7, 21, 5, 71, 6, 11, 
    4, 85, 0, 34, 1, 46, 6, 52, 7, 26, 5,  5, 3, 24, 2, 80, 9, 55, 8, 47, 
    5, 49, 7, 40, 9, 79, 2, 83, 4, 16, 0, 68, 8, 42, 1, 56, 3, 75, 6, 42, 
    8, 96, 3, 26, 5, 85, 0, 90, 6, 41, 2, 34, 4, 52, 7, 48, 1, 32, 9, 32
  };
  const int r117[] = {
    10, 10, // Number of jobs and machines
    6, 84, 4, 33, 1,  5, 7, 29, 0, 97, 5, 63, 2, 93, 9, 24, 3, 90, 8, 87, 
    0, 80, 9, 73, 8, 74, 3, 79, 1, 14, 5, 87, 6, 81, 7, 50, 4, 24, 2, 30, 
    0, 56, 3,  2, 9, 11, 6, 14, 2, 67, 7, 79, 5, 15, 8, 88, 1, 97, 4,  6, 
    3,  3, 1,  2, 0, 14, 5,  8, 7, 16, 9,  4, 2, 36, 8, 22, 4, 35, 6, 34, 
    4, 66, 3, 48, 9, 92, 7, 50, 5, 49, 6, 47, 1, 32, 8, 28, 0, 97, 2, 80, 
    9, 19, 6, 48, 8, 15, 0, 81, 5, 27, 3, 27, 4, 24, 1,  6, 7,  7, 2, 68, 
    1, 21, 0, 80, 3, 23, 4, 53, 6, 86, 2, 17, 7, 68, 8, 24, 5, 26, 9, 48, 
    2, 29, 6, 88, 4, 29, 9, 42, 7, 99, 3, 49, 5, 49, 8, 30, 0,  4, 1, 42, 
    2, 85, 1, 45, 6, 36, 4, 72, 3, 36, 0, 47, 8, 46, 7, 52, 5, 60, 9, 28, 
    2, 43, 1, 24, 9, 80, 8, 81, 6, 60, 4, 22, 5, 15, 7, 72, 0, 17, 3, 94
  };
  const int r118[] = {
    10, 10, // Number of jobs and machines
    1, 11, 0, 25, 2, 52, 4, 30, 8, 36, 7, 92, 3, 83, 5, 33, 6, 82, 9, 36, 
    9, 43, 4, 20, 0, 15, 6, 88, 8,  3, 2, 63, 1, 57, 3, 88, 7, 93, 5, 99, 
    9, 32, 5, 52, 2, 97, 3, 72, 8, 20, 1,  2, 7, 84, 4,  1, 0, 61, 6, 63, 
    6, 25, 1, 77, 5, 94, 3, 91, 2, 57, 7, 83, 0, 91, 4, 68, 9, 39, 8, 81, 
    1, 82, 2, 92, 4, 49, 9, 11, 6, 22, 5, 13, 0, 57, 3, 84, 7, 95, 8, 15, 
    3, 51, 9, 98, 8, 31, 2, 15, 6, 30, 1, 42, 5, 44, 7, 11, 4, 16, 0, 59, 
    9, 91, 4, 14, 0, 49, 1, 67, 3, 22, 5,  1, 6, 31, 2, 42, 8, 56, 7,  5, 
    9, 57, 2, 19, 7, 18, 3, 83, 4, 52, 5, 62, 8,  1, 1, 83, 6, 57, 0, 84, 
    1, 38, 3, 99, 7, 64, 5, 48, 8, 81, 6, 43, 4, 72, 0, 38, 9, 60, 2, 24, 
    7, 58, 4, 19, 6, 16, 3, 89, 2, 43, 9, 96, 5, 11, 0, 59, 8, 96, 1, 19
  };
  const int r119[] = {
    10, 10, // Number of jobs and machines
    7, 84, 5, 32, 3, 66, 1, 94, 2, 69, 9, 56, 6,  7, 8, 93, 4, 28, 0, 14, 
    0, 57, 8, 34, 7,  5, 2, 44, 9, 54, 4, 12, 6, 39, 3, 78, 5, 79, 1, 76, 
    0, 67, 8, 72, 3, 94, 7, 78, 2, 73, 4, 67, 5, 30, 1, 82, 6, 24, 9, 27, 
    0, 55, 8, 69, 4, 83, 2, 79, 5, 40, 9, 16, 1, 51, 6, 54, 3, 15, 7, 82, 
    8, 89, 9, 73, 0, 87, 2, 73, 6, 89, 1, 56, 5, 61, 7, 26, 4, 51, 3, 82, 
    9, 70, 8, 35, 4, 83, 0, 66, 1, 98, 5, 82, 2, 68, 6, 14, 7, 15, 3, 77, 
    8, 95, 9, 85, 6, 77, 2, 15, 7, 60, 5, 60, 3, 13, 4,  7, 0, 86, 1, 92, 
    4,  6, 9, 86, 0, 66, 2, 23, 6, 55, 3, 55, 7, 86, 1, 29, 5, 22, 8, 51, 
    3, 16, 6, 91, 9, 69, 8,  8, 4, 54, 1, 57, 2, 34, 5, 11, 7, 63, 0,  2, 
    2, 30, 8, 90, 0, 64, 4, 57, 5, 12, 6, 73, 3, 72, 1, 73, 7, 85, 9,  7
  };
  const int r120[] = {
    10, 10, // Number of jobs and machines
    1, 71, 0, 54, 6, 75, 5, 25, 8, 91, 2, 38, 4, 87, 3, 55, 7, 52, 9,  8, 
    5, 48, 2, 94, 3, 87, 9, 78, 6, 94, 8, 53, 1, 28, 7, 56, 0, 30, 4, 51, 
    3, 58, 6,  3, 5, 85, 4, 44, 9, 40, 1, 55, 7, 45, 8, 34, 0, 99, 2, 85, 
    4, 16, 9, 30, 6, 12, 3, 30, 1, 70, 0, 49, 5, 85, 2, 34, 8, 71, 7, 97, 
    2, 16, 8, 56, 1, 72, 3, 66, 9, 68, 0, 42, 5, 86, 7, 43, 4, 32, 6, 59, 
    3, 50, 1, 41, 0, 61, 2, 27, 8, 73, 4, 27, 6, 73, 5, 87, 9, 48, 7, 92, 
    6, 25, 7, 21, 5, 18, 4,  4, 0,  5, 1, 79, 3, 81, 8, 61, 9,  8, 2, 61, 
    8, 78, 5,  3, 3, 47, 9, 96, 7, 11, 6, 55, 1, 89, 2, 34, 0, 83, 4, 67, 
    8, 68, 6, 65, 1, 45, 0, 89, 5,  8, 2, 30, 9, 33, 3,  7, 7, 85, 4, 16, 
    6, 74, 1, 95, 3, 62, 7, 95, 0,  1, 9, 76, 8,  3, 2, 18, 5, 54, 4, 50
  };
  const int r121[] = {
    10, 10, // Number of jobs and machines
    9, 39, 1, 25, 7, 27, 5, 70, 8,  1, 6, 81, 2, 51, 3, 44, 4, 92, 0, 53, 
    4, 19, 6, 57, 0, 60, 1, 75, 9, 70, 8, 15, 2, 26, 3, 97, 5, 78, 7, 96, 
    4,  4, 9, 82, 1, 52, 3, 23, 6, 38, 0, 64, 8, 36, 2, 58, 7, 27, 5,  4, 
    3, 12, 2, 94, 4, 71, 9, 86, 0,  8, 5, 40, 7, 90, 1, 85, 8, 37, 6, 74, 
    0, 78, 9, 52, 5, 23, 3, 17, 8, 23, 1, 92, 7, 16, 4,  5, 2, 16, 6,  5, 
    8, 88, 1, 82, 9, 41, 4, 40, 0, 37, 2, 46, 7, 43, 5, 88, 6, 54, 3, 93, 
    6, 12, 8, 23, 4, 29, 2, 67, 1, 91, 9, 21, 0, 74, 5,  5, 3, 86, 7, 69, 
    8, 84, 9, 42, 0, 22, 2, 89, 6, 52, 1, 78, 7, 10, 5, 10, 4, 48, 3, 96, 
    4, 21, 0,  4, 8, 64, 3, 45, 7, 38, 1, 94, 5, 24, 6, 14, 2, 19, 9, 98, 
    9,  2, 6, 71, 4, 96, 3, 18, 7, 44, 5, 35, 1, 85, 2, 41, 8, 26, 0, 81
  };
  const int r122[] = {
    10, 10, // Number of jobs and machines
    0, 87, 6, 93, 2, 87, 4, 90, 7, 73, 5, 53, 3, 18, 9, 90, 1, 17, 8, 98, 
    8, 42, 7, 82, 5, 64, 0, 93, 4, 66, 9, 24, 1, 51, 2,  7, 6, 84, 3, 21, 
    2, 45, 1, 61, 5, 80, 4, 85, 3, 76, 0, 45, 6, 72, 7, 91, 9, 52, 8, 83, 
    4, 77, 6, 10, 8, 76, 2,  5, 9, 73, 1,  4, 5, 40, 3, 15, 0, 55, 7, 60, 
    5, 93, 2, 30, 8, 92, 4,  3, 3,  5, 6, 48, 9,  8, 7, 72, 0,  9, 1, 23, 
    7, 97, 5, 31, 6, 13, 3, 93, 9, 90, 1, 85, 2, 97, 4, 36, 0, 73, 8, 97, 
    1, 92, 3, 83, 4, 55, 0, 21, 9, 82, 8, 26, 5, 89, 7, 69, 6, 21, 2, 97, 
    7, 76, 2, 57, 8, 88, 0,  3, 9, 13, 6, 61, 5, 40, 3, 17, 4, 19, 1, 87, 
    0,  8, 3, 23, 5, 44, 6, 14, 8, 72, 7, 84, 4,  1, 2, 13, 9,  2, 1, 33, 
    2, 71, 3, 44, 0, 25, 5, 61, 7, 55, 8, 17, 9, 66, 1, 82, 6, 60, 4, 83
  };
  const int r123[] = {
    10, 10, // Number of jobs and machines
    8, 90, 2, 61, 4, 38, 1, 18, 3, 22, 9, 96, 0, 60, 5, 78, 7,  4, 6, 55, 
    9,  2, 1, 63, 6, 45, 4, 92, 5, 18, 0, 75, 8, 51, 3, 55, 2, 94, 7, 45, 
    1, 20, 7, 53, 6, 46, 8, 73, 5, 40, 9, 18, 3, 82, 2, 77, 0, 96, 4, 76, 
    6, 68, 3, 13, 7, 39, 2, 62, 5, 40, 0, 15, 4, 86, 9, 31, 8, 52, 1, 33, 
    7, 81, 8, 38, 5, 94, 6, 63, 3, 95, 4, 90, 0, 67, 1,  3, 2, 76, 9, 87, 
    6, 57, 8, 62, 5, 60, 3, 11, 4,  7, 2, 41, 9, 14, 0, 94, 1, 96, 7,  7, 
    1,  3, 8,  7, 6, 59, 2, 79, 3, 26, 7, 45, 4, 85, 0, 92, 9, 35, 5, 33, 
    9, 27, 7, 49, 2, 19, 0, 27, 1, 83, 6, 26, 3, 78, 4, 26, 8, 67, 5, 49, 
    4, 86, 0, 45, 8, 28, 5, 54, 1, 21, 2, 55, 9, 40, 7, 41, 6,  6, 3, 81, 
    9, 66, 6, 73, 4, 64, 1,  7, 7, 91, 5, 11, 8,  8, 2,  5, 3, 43, 0, 38
  };
  const int r124[] = {
    10, 10, // Number of jobs and machines
    3, 68, 2, 99, 1, 10, 4, 76, 8, 50, 6, 87, 7, 93, 0, 84, 9, 82, 5, 67, 
    1,  2, 4, 35, 5, 27, 9, 67, 0,  2, 2, 96, 8, 60, 3, 76, 7, 51, 6,  1, 
    3, 35, 4, 80, 0, 76, 7, 54, 6,  4, 9, 28, 1, 81, 8, 15, 5, 27, 2, 29, 
    1, 49, 8, 42, 2, 94, 3, 44, 9, 57, 7, 61, 4, 22, 6, 47, 0, 10, 5, 63, 
    6, 89, 0, 94, 9, 27, 3, 28, 5, 10, 7,  4, 1, 29, 4, 51, 8, 23, 2, 64, 
    3, 34, 2, 16, 8, 65, 6, 59, 4, 43, 0, 10, 7, 61, 9, 93, 5, 63, 1,  3, 
    7, 44, 1, 92, 8, 28, 3, 71, 4, 22, 2, 66, 6, 66, 0, 23, 9, 81, 5, 50, 
    5,  1, 7, 20, 2,  9, 3, 59, 6, 85, 0, 91, 4, 88, 1, 98, 8, 18, 9, 98, 
    3, 62, 9,  1, 0, 97, 6, 99, 8, 14, 5, 17, 4, 36, 2, 35, 1, 64, 7, 45, 
    7, 66, 3, 47, 1, 85, 8, 98, 6, 60, 4, 60, 9,  3, 0, 41, 2, 34, 5, 29
  };
  const int r125[] = {
    10, 10, // Number of jobs and machines
    8, 65, 0, 10, 9, 20, 6, 76, 4, 75, 3, 29, 2, 80, 5, 40, 1, 27, 7, 91, 
    9, 31, 0, 10, 5, 61, 4, 19, 2, 57, 1, 69, 3, 75, 6, 93, 8, 95, 7, 45, 
    0, 81, 3, 93, 4, 61, 7, 12, 8, 23, 9, 86, 6, 36, 1, 66, 2,  7, 5, 44, 
    4, 21, 3, 55, 5, 81, 1, 71, 8, 42, 0, 39, 7, 20, 6, 18, 2, 29, 9, 97, 
    0, 94, 7, 83, 1, 45, 4, 69, 9, 23, 3, 51, 6, 68, 2, 90, 5, 81, 8, 67, 
    6,  4, 2, 65, 7, 37, 3, 62, 0, 19, 5, 25, 8,  8, 9,  4, 1, 75, 4,  3, 
    9, 53, 5, 16, 6, 60, 7, 32, 8, 75, 3, 38, 4, 34, 0, 96, 2, 43, 1, 70, 
    8, 52, 9, 60, 5, 91, 4, 12, 6,  7, 3, 54, 1, 86, 2, 67, 7, 54, 0,  6, 
    1, 20, 0, 47, 6, 21, 4, 89, 3, 51, 2, 45, 9, 11, 8, 50, 7, 18, 5, 90, 
    7, 42, 3, 66, 2, 57, 1,  4, 0, 66, 6, 44, 4, 99, 5, 64, 8, 74, 9, 72
  };
  const int r126[] = {
    10, 10, // Number of jobs and machines
    9, 53, 2, 79, 4, 87, 7, 95, 6, 41, 5, 41, 8, 80, 3, 48, 1, 71, 0, 77, 
    0, 76, 7, 60, 3, 63, 5, 79, 1, 61, 9, 55, 4, 15, 2, 90, 6, 85, 8,  5, 
    9, 56, 3, 44, 7, 36, 0, 18, 1, 57, 6, 78, 2, 96, 5, 64, 8, 63, 4, 85, 
    5, 93, 2, 62, 4, 37, 8, 16, 9, 72, 3, 54, 7, 43, 6, 95, 1, 96, 0, 84, 
    6, 31, 5, 31, 1, 32, 8, 13, 4, 12, 7, 93, 9, 75, 3, 58, 2,  3, 0,  2, 
    4, 27, 1, 38, 5, 89, 9, 93, 7,  7, 3, 59, 0, 44, 2, 75, 8, 99, 6, 27, 
    9, 10, 8, 48, 6, 69, 4, 64, 1, 47, 3, 49, 0, 71, 7, 31, 2, 37, 5, 88, 
    8,  5, 5, 92, 3,  6, 2, 34, 1, 69, 4, 76, 9, 65, 6, 71, 7, 85, 0, 89, 
    7, 61, 0, 24, 3, 45, 1, 99, 5, 14, 4, 95, 2,  6, 8, 17, 6, 38, 9, 55, 
    1, 15, 2,  2, 8, 91, 5, 26, 0,  7, 7, 47, 3, 89, 6, 48, 9, 68, 4, 18
  };
  const int r127[] = {
    10, 10, // Number of jobs and machines
    0, 78, 5, 28, 9,  9, 8, 83, 4, 53, 2, 66, 1, 90, 6,  7, 7, 82, 3,  9, 
    1, 77, 5, 70, 9,  4, 4, 90, 3, 77, 8, 37, 2, 11, 7, 85, 0, 18, 6, 46, 
    0, 56, 3, 59, 8, 50, 9, 53, 1, 54, 5, 54, 2, 74, 6, 73, 4, 99, 7, 85, 
    7, 19, 4, 71, 0, 50, 8, 89, 2, 17, 3, 30, 6,  3, 9, 91, 5, 95, 1, 37, 
    3, 90, 0, 74, 7, 58, 6, 12, 4, 18, 8, 25, 9, 24, 5, 38, 2, 43, 1, 17, 
    8, 20, 0, 92, 7, 48, 3, 21, 5, 67, 4, 80, 9, 61, 1, 50, 2, 83, 6, 29, 
    9,  4, 0, 22, 5, 59, 4, 38, 7, 75, 3,  9, 2, 70, 6, 65, 1, 14, 8, 30, 
    6, 99, 7, 29, 3, 24, 2, 45, 9, 92, 8, 39, 0, 60, 4, 14, 5, 47, 1, 35, 
    3, 26, 2, 29, 7, 48, 8, 97, 5, 67, 4, 68, 0, 21, 6, 53, 9, 29, 1, 70, 
    1, 73, 0, 77, 9, 68, 6, 42, 2, 90, 4, 17, 7, 36, 3, 29, 5, 95, 8, 57
  };
  const int r128[] = {
    10, 10, // Number of jobs and machines
    8, 69, 7, 47, 3, 66, 1, 15, 0, 71, 5, 38, 4, 40, 6, 26, 9, 85, 2, 23, 
    2, 64, 4, 83, 3, 97, 5, 28, 9, 90, 1,  4, 7, 25, 8, 10, 6, 15, 0, 60, 
    9, 33, 6, 81, 7, 65, 4,  3, 2, 41, 1, 23, 5, 52, 8, 89, 3, 14, 0, 22, 
    9, 23, 6,  9, 2, 88, 3, 25, 0, 24, 4, 57, 8, 60, 5, 13, 7, 70, 1, 15, 
    5, 96, 1, 38, 9, 40, 4, 35, 0, 73, 2, 97, 6, 12, 7, 66, 8, 36, 3, 27, 
    3, 40, 0, 81, 2, 11, 7, 18, 8, 66, 5, 24, 9, 57, 4, 78, 6, 12, 1, 56, 
    2, 79, 8, 27, 7, 20, 3, 36, 5, 75, 6, 25, 0, 25, 4, 54, 1, 40, 9, 12, 
    3, 51, 2, 51, 5,  8, 6, 47, 0, 16, 8, 38, 7, 33, 9, 77, 4, 65, 1, 85, 
    4, 63, 2, 74, 1, 95, 7, 54, 0, 31, 8, 65, 5, 80, 3, 68, 6, 14, 9, 54, 
    9, 56, 6, 28, 8, 41, 5, 96, 4, 76, 0, 66, 2, 77, 3,  5, 7, 10, 1, 97
  };
  const int r129[] = {
    10, 10, // Number of jobs and machines
    3, 30, 6, 16, 7, 24, 9, 76, 0, 62, 4, 45, 5, 56, 1,  9, 8, 28, 2, 50, 
    4, 47, 2, 79, 7, 58, 0, 26, 8, 78, 6, 27, 3, 72, 5, 73, 1, 29, 9, 62, 
    6, 37, 2, 86, 1, 44, 8, 94, 9, 73, 0, 85, 7, 35, 3, 94, 5, 88, 4, 54, 
    8, 31, 3, 72, 7, 92, 2, 67, 6, 98, 9, 57, 5, 54, 0,  4, 4, 74, 1, 15, 
    5, 66, 2, 70, 8,  3, 0, 17, 9, 44, 4, 34, 1, 54, 3, 25, 6, 71, 7, 14, 
    1, 83, 5, 84, 7, 89, 0, 29, 2, 62, 9, 49, 4, 85, 6, 33, 8, 22, 3, 76, 
    8, 73, 4, 78, 9, 87, 6, 52, 7, 68, 1, 79, 0, 17, 5, 61, 2, 48, 3, 58, 
    4, 23, 7, 30, 1, 94, 0, 58, 3, 70, 8, 80, 9, 35, 5, 91, 6, 61, 2, 58, 
    0, 87, 2, 70, 4,  1, 9, 44, 3, 49, 5,  7, 6, 81, 7, 89, 1, 81, 8, 67, 
    7, 86, 8, 37, 1, 79, 2, 18, 5, 84, 0, 35, 6, 81, 3, 66, 4, 27, 9, 14
  };
  const int r130[] = {
    10, 10, // Number of jobs and machines
    2,  2, 1, 69, 0, 21, 6, 55, 8, 43, 4,  7, 7, 65, 5,  5, 9, 76, 3, 34, 
    3, 97, 7, 72, 4, 18, 8, 26, 9, 47, 0, 54, 6, 17, 2, 26, 5, 33, 1, 26, 
    2, 50, 7, 94, 5, 21, 4, 31, 1, 68, 3, 44, 8, 74, 9, 41, 6, 15, 0, 88, 
    4, 26, 6, 73, 9, 60, 7, 53, 1, 14, 0, 25, 5, 45, 8, 91, 2, 90, 3, 61, 
    4, 67, 5, 60, 2, 20, 9, 75, 1, 48, 0,  6, 8, 36, 6, 13, 7, 95, 3, 96, 
    4, 36, 1, 96, 0, 84, 6, 99, 8,  9, 7, 41, 5, 61, 3, 26, 2,  8, 9, 81, 
    9, 95, 2, 65, 0, 43, 5, 30, 1, 45, 6, 82, 8, 31, 4, 37, 3, 81, 7, 61, 
    7, 46, 6, 60, 4, 87, 8, 33, 5, 35, 0, 76, 2, 57, 1, 57, 9, 73, 3, 89, 
    2, 42, 7,  2, 4, 93, 6, 26, 3, 86, 0,  9, 8, 24, 9,  9, 5, 50, 1, 26, 
    3, 12, 1, 59, 8, 28, 9, 43, 7, 82, 4, 74, 2, 69, 5, 17, 0, 63, 6, 51
  };
  const int r131[] = {
    10, 10, // Number of jobs and machines
    5,  1, 2, 43, 7, 46, 6, 23, 1, 59, 8, 81, 4, 82, 0, 28, 9, 83, 3, 84, 
    3, 92, 1, 93, 4, 57, 7, 51, 5, 44, 8, 52, 6, 46, 0, 46, 9, 90, 2, 97, 
    8,  1, 6, 76, 0, 14, 3, 78, 9, 76, 2, 45, 1, 17, 4,  5, 5, 91, 7, 13, 
    7, 94, 1, 67, 2, 34, 3, 44, 5,  5, 9, 57, 4, 16, 0, 96, 6,  1, 8, 68, 
    8, 48, 7, 88, 2, 15, 5,  6, 9, 51, 6, 50, 4, 24, 3, 62, 0, 33, 1, 11, 
    2, 41, 0, 88, 3, 72, 9, 30, 6, 48, 7, 36, 5, 33, 8, 86, 4, 29, 1, 38, 
    7, 18, 3, 62, 0, 73, 2, 96, 1, 52, 5, 60, 6, 34, 8,  9, 4, 87, 9, 92, 
    3, 80, 6, 62, 0, 98, 2, 58, 4, 91, 8, 44, 9, 66, 1, 76, 7, 75, 5, 82, 
    6, 34, 1, 98, 4, 43, 0, 77, 8,  3, 2, 90, 9, 36, 5, 88, 3, 18, 7, 91, 
    9, 26, 2, 24, 0,  8, 4, 64, 6, 63, 8, 67, 5, 61, 3, 94, 1, 75, 7,  7
  };
  const int r132[] = {
    10, 10, // Number of jobs and machines
    6, 74, 9, 75, 7, 37, 4, 15, 2, 72, 8, 57, 0, 15, 3,  4, 1, 36, 5, 51, 
    4, 56, 7, 16, 6, 69, 1, 69, 9, 48, 2, 38, 0, 77, 5, 11, 8, 97, 3, 48, 
    3, 96, 6, 14, 5, 50, 0, 85, 7, 86, 2, 19, 4, 36, 8, 30, 1, 15, 9, 51, 
    8, 84, 4, 47, 3,  1, 7, 74, 1, 55, 2, 32, 9, 81, 5, 46, 6, 33, 0, 69, 
    1,  8, 3, 88, 6, 26, 4, 14, 7, 67, 0, 77, 2, 21, 5, 44, 8, 13, 9, 15, 
    6, 86, 4, 14, 9, 67, 1, 43, 7, 55, 8, 21, 2,  5, 5,  9, 3, 31, 0, 83, 
    4, 63, 7, 30, 5, 55, 1, 39, 3, 97, 8, 92, 0,  9, 2, 11, 6, 38, 9, 64, 
    4, 27, 7,  3, 9, 21, 3, 13, 0, 87, 8,  9, 1, 59, 2, 93, 6, 72, 5,  2, 
    1, 12, 4, 27, 5, 95, 0, 46, 2, 18, 3, 31, 7, 26, 8, 95, 9, 41, 6, 87, 
    5, 99, 3, 28, 0, 30, 1, 88, 7, 67, 4, 83, 8, 88, 2, 37, 9, 26, 6, 13
  };
  const int r133[] = {
    10, 10, // Number of jobs and machines
    3, 51, 9,  9, 6, 25, 4, 97, 8, 47, 5, 24, 2, 76, 1, 36, 0, 16, 7, 56, 
    4,  1, 2, 89, 5, 32, 8, 39, 7, 20, 9, 56, 0, 25, 1, 66, 3, 44, 6,  5, 
    3, 53, 8, 20, 0,  5, 1, 82, 7, 79, 9, 92, 5,  4, 2, 45, 6, 18, 4, 64, 
    9, 14, 7, 69, 8, 40, 0, 24, 5, 54, 4, 96, 1, 40, 3, 93, 2, 31, 6, 46, 
    7, 23, 6, 53, 8, 91, 5,  3, 9, 71, 2,  3, 3, 84, 0, 19, 4, 33, 1, 24, 
    8, 51, 0, 68, 7, 66, 5, 83, 1, 25, 2, 24, 4, 85, 3, 51, 9,  8, 6, 35, 
    2, 36, 9, 41, 8, 17, 7, 42, 1, 40, 0, 44, 4, 58, 6, 43, 3, 80, 5, 38, 
    9, 50, 8, 69, 5,  5, 6, 44, 1,  1, 2, 49, 3, 99, 4, 25, 0, 15, 7, 52, 
    4, 23, 2, 49, 7,  4, 0, 87, 1, 44, 9, 14, 6, 41, 5, 59, 8,  6, 3, 28, 
    7, 99, 5, 37, 9, 87, 6, 32, 3, 92, 8, 21, 1, 64, 4, 25, 2, 31, 0, 18
  };
  const int r134[] = {
    10, 10, // Number of jobs and machines
    5, 77, 6, 53, 2, 74, 7,  7, 1, 13, 3, 35, 8, 14, 0, 94, 4, 51, 9, 91, 
    0, 41, 9, 83, 2, 28, 8, 19, 1, 53, 4, 34, 6, 52, 5, 92, 3, 77, 7, 93, 
    1, 79, 7, 71, 0, 14, 8, 29, 5,  4, 6,  7, 9, 22, 3, 87, 4, 58, 2, 21, 
    6, 71, 5, 99, 3, 60, 0, 97, 2, 53, 7, 85, 8, 73, 9, 29, 1, 16, 4, 63, 
    3, 37, 7,  8, 6, 27, 9, 15, 0, 68, 8,  5, 4, 69, 1, 98, 2, 64, 5, 84, 
    2, 14, 5, 78, 4, 87, 7, 11, 0, 16, 6, 29, 9, 22, 3, 31, 8, 34, 1, 59, 
    1, 45, 5, 63, 9,  5, 8,  8, 6, 68, 2, 55, 0, 28, 4, 83, 7, 96, 3, 40, 
    4, 82, 8, 89, 9, 19, 3,  8, 0, 72, 6,  9, 7, 20, 5, 59, 2, 52, 1, 94, 
    0, 98, 7, 54, 2, 65, 1, 62, 5, 66, 4, 14, 8, 18, 6, 86, 3, 13, 9, 58, 
    7, 42, 8,  9, 0, 75, 3, 50, 2, 10, 6, 77, 4, 88, 1, 34, 5, 72, 9, 27
  };
  const int r135[] = {
    10, 10, // Number of jobs and machines
    7, 72, 0, 46, 6, 52, 5, 30, 8, 40, 4, 27, 2, 32, 9, 71, 1, 67, 3, 72, 
    7, 90, 0, 40, 6,  9, 5, 54, 1, 83, 2, 68, 9, 48, 8, 77, 3, 81, 4, 69, 
    8, 65, 3, 71, 7, 23, 6, 31, 1, 16, 9, 67, 5, 73, 2, 87, 0, 58, 4, 17, 
    1,  4, 3, 34, 4, 12, 6, 67, 9, 29, 0, 76, 5, 46, 2, 54, 8, 75, 7, 48, 
    5, 88, 7, 94, 4, 69, 0, 48, 1, 92, 8, 12, 3, 92, 9, 51, 6, 65, 2, 41, 
    7,  4, 1,  1, 0, 88, 2, 44, 6,  6, 5, 63, 4, 48, 3, 44, 8, 65, 9, 38, 
    2, 69, 1, 50, 7,  2, 4, 97, 0, 77, 3, 94, 6, 10, 9, 99, 8, 71, 5, 13, 
    7, 81, 4, 93, 6, 13, 8, 84, 3, 49, 2, 50, 1, 90, 5, 95, 0,  2, 9, 99, 
    6, 46, 3, 14, 8, 50, 9, 15, 1, 47, 4, 89, 7, 70, 2, 77, 5, 76, 0, 12, 
    2, 75, 6, 35, 3, 97, 4, 15, 9, 99, 1, 78, 8, 87, 7, 25, 0, 32, 5, 78
  };
  const int r136[] = {
    10, 10, // Number of jobs and machines
    8, 83, 3,  4, 4, 45, 2, 72, 9, 46, 5, 75, 6, 11, 7, 65, 0, 37, 1,  7, 
    5, 30, 7, 71, 0, 43, 4,  3, 9, 22, 6, 97, 2, 50, 1, 51, 3, 21, 8, 13, 
    1, 52, 6, 11, 5, 72, 0, 52, 4, 98, 9, 87, 2, 65, 8, 46, 7, 83, 3, 56, 
    8, 39, 1,  6, 2, 51, 5, 49, 6,  6, 4, 96, 3, 43, 7, 69, 0, 70, 9, 23, 
    0, 70, 3, 85, 7, 53, 4,  6, 9, 47, 2, 36, 5, 69, 1,  8, 6, 52, 8, 57, 
    0, 55, 7, 83, 8, 51, 6, 55, 3, 68, 1,  8, 5, 63, 9, 19, 4, 44, 2, 82, 
    8, 80, 4, 30, 1, 70, 3, 59, 5, 76, 9, 31, 2, 50, 0, 39, 6, 18, 7,  1, 
    3, 88, 8, 56, 0,  3, 5, 30, 1, 71, 2, 19, 4, 11, 6, 29, 7, 98, 9, 39, 
    1, 62, 2, 18, 8, 13, 4, 49, 5, 82, 6, 49, 0, 41, 3, 41, 7, 73, 9,  2, 
    2, 85, 6, 70, 7, 72, 8, 93, 4, 58, 0, 12, 9, 30, 1, 12, 5,  2, 3, 36
  };
  const int r137[] = {
    10, 10, // Number of jobs and machines
    5, 84, 1,  8, 2, 15, 8, 69, 4,  4, 7, 80, 9, 48, 6, 99, 0, 92, 3,  8, 
    7, 73, 8, 41, 2, 37, 9, 73, 1, 47, 6, 36, 0, 66, 3, 24, 4, 22, 5, 13, 
    4, 92, 5,  3, 0, 51, 8, 30, 1, 10, 3, 89, 9, 62, 7, 49, 2,  7, 6,  7, 
    1,  2, 6, 23, 8, 11, 3, 20, 7, 41, 2, 71, 5,  6, 4, 22, 9, 63, 0, 96, 
    6, 79, 0,  3, 7, 51, 3, 23, 4, 17, 9, 78, 1,  3, 2, 12, 5, 10, 8, 77, 
    5,  9, 2, 41, 3, 76, 8, 98, 1, 39, 7,  2, 6,  9, 0,  3, 9, 51, 4, 92, 
    1, 87, 9, 98, 0, 30, 2, 44, 4, 86, 7, 55, 8,  4, 3, 95, 6, 85, 5, 74, 
    3, 15, 6, 71, 9, 88, 0,  3, 2,  2, 8, 45, 5, 22, 4, 97, 1, 90, 7, 54, 
    9, 11, 1, 54, 4,  1, 8, 45, 7, 97, 0, 91, 5, 31, 6, 77, 2, 25, 3, 17, 
    2, 71, 6, 38, 1, 90, 5, 12, 8, 87, 3, 29, 9, 79, 7, 44, 0, 39, 4, 96
  };
  const int r138[] = {
    10, 10, // Number of jobs and machines
    0, 78, 5, 61, 3, 52, 1, 25, 6, 24, 2, 77, 9, 61, 7, 64, 4, 46, 8, 95, 
    2, 71, 1, 69, 5, 68, 8, 31, 0, 93, 7, 61, 3, 58, 6, 24, 9,  5, 4, 76, 
    0, 73, 7,  4, 4, 48, 6,  5, 1, 20, 3, 86, 2, 66, 8, 29, 9, 15, 5, 57, 
    4, 31, 3, 43, 9,  6, 6, 74, 0, 15, 8, 19, 7,  6, 1, 20, 5, 81, 2, 69, 
    8, 92, 7, 11, 4, 49, 3, 26, 1, 98, 0, 74, 5, 54, 9, 80, 2, 30, 6, 35, 
    3, 86, 6, 49, 1, 71, 5, 54, 4, 42, 0, 77, 9, 31, 2,  6, 8, 35, 7, 16, 
    8, 91, 9, 82, 4, 63, 7, 24, 2, 37, 1, 22, 3, 90, 6, 76, 5, 99, 0, 59, 
    2, 70, 4,  1, 9, 29, 0, 74, 5,  2, 3, 95, 7, 80, 8,  2, 1, 27, 6, 83, 
    2, 79, 6, 35, 8, 15, 7, 25, 1, 47, 5, 50, 4, 53, 9, 68, 0, 19, 3, 78, 
    4, 72, 2, 12, 7, 50, 6,  6, 3, 19, 1, 63, 9,  1, 0, 59, 5, 40, 8, 86
  };
  const int r139[] = {
    10, 10, // Number of jobs and machines
    6,  4, 5, 21, 3, 16, 0, 12, 4, 96, 1, 88, 7, 13, 9, 40, 2, 28, 8, 63, 
    3,  1, 2, 21, 7, 37, 6,  2, 0, 85, 4, 56, 5,  1, 9,  5, 1, 14, 8, 20, 
    8, 26, 2, 72, 3, 67, 1, 20, 6, 78, 5, 98, 4, 57, 7, 35, 0, 66, 9, 75, 
    6, 50, 4, 41, 2, 16, 5, 81, 7, 90, 9, 98, 8, 64, 3, 73, 1, 45, 0, 44, 
    4, 79, 1, 97, 5,  7, 3, 59, 6, 75, 8,  4, 0, 40, 7, 88, 9,  9, 2, 85, 
    3, 60, 8,  9, 2, 37, 1, 78, 9, 84, 5, 45, 7, 74, 4, 22, 6, 77, 0, 67, 
    9, 29, 4, 73, 2, 77, 0, 74, 7,  5, 5, 96, 3, 14, 6, 20, 1,  4, 8, 44, 
    5, 74, 4, 76, 3, 39, 1, 53, 9, 32, 7, 55, 2, 97, 0, 83, 8, 39, 6, 83, 
    6, 86, 3, 89, 4, 84, 7, 42, 9, 29, 1, 39, 5, 95, 8, 13, 0, 11, 2, 22, 
    0, 58, 3, 69, 7, 73, 1, 35, 2, 25, 5, 46, 8, 42, 9, 68, 4, 96, 6, 23
  };
  const int r140[] = {
    10, 10, // Number of jobs and machines
    2, 97, 9, 59, 1, 34, 3, 10, 6, 31, 7,  5, 8, 19, 5, 19, 0,  4, 4, 78, 
    7, 90, 0,  2, 3, 65, 5, 77, 8, 59, 4, 98, 9, 85, 1, 69, 6,  4, 2, 76, 
    6, 76, 7, 80, 5, 57, 2, 81, 9, 66, 3, 78, 4, 33, 8, 81, 0, 24, 1, 60, 
    8, 71, 7,  4, 3, 68, 1, 36, 2, 95, 5, 33, 9, 38, 6, 63, 0, 62, 4, 95, 
    7, 54, 2,  4, 5, 27, 6, 21, 8, 57, 4, 28, 1, 54, 3, 72, 9, 58, 0, 71, 
    7,  9, 5, 30, 0, 37, 9, 34, 2,  7, 1, 29, 3, 73, 8, 29, 4, 48, 6, 23, 
    9, 63, 2, 86, 5, 19, 1, 21, 0,  1, 7, 79, 3, 99, 4, 92, 8, 85, 6, 41, 
    1, 21, 0, 76, 8, 55, 4, 48, 3, 96, 7, 50, 9, 91, 2, 55, 6, 97, 5, 73, 
    9, 65, 3, 37, 4,  5, 7, 60, 8, 37, 1, 48, 5, 84, 6, 82, 2, 67, 0,  9, 
    5, 88, 7, 68, 2, 14, 3, 74, 6, 81, 0, 78, 8,  9, 4, 73, 9, 11, 1, 87
  };
  const int r141[] = {
    10, 10, // Number of jobs and machines
    1, 55, 6, 53, 9, 74, 4, 11, 0, 90, 2,  3, 7, 80, 8, 85, 3, 42, 5, 48, 
    6, 73, 5, 72, 1, 61, 0, 83, 2, 38, 7, 47, 8, 38, 3, 25, 4, 72, 9, 75, 
    1, 89, 2, 30, 7, 23, 9, 13, 0, 62, 5, 43, 3, 70, 4, 11, 8, 55, 6, 87, 
    0, 87, 9, 48, 4, 52, 2, 63, 3, 59, 6, 31, 8, 73, 5, 75, 7, 64, 1, 12, 
    2, 78, 9,  5, 7, 51, 5, 34, 3, 43, 6, 48, 8, 75, 4, 59, 1, 70, 0, 61, 
    1, 21, 2, 35, 4, 80, 7, 24, 3, 53, 8, 18, 5, 91, 6, 13, 0, 26, 9, 54, 
    3, 37, 2, 24, 8, 85, 1, 99, 9, 50, 0, 67, 7, 39, 6, 23, 5, 58, 4, 50, 
    8, 22, 3, 43, 4, 50, 6, 58, 1,  7, 2, 90, 9,  5, 5, 48, 0,  7, 7, 46, 
    1, 93, 7, 66, 0, 54, 4,  3, 2, 41, 5, 47, 8, 51, 3, 38, 9, 98, 6, 44, 
    0, 50, 5, 91, 2, 31, 4, 43, 8, 48, 3, 23, 1, 88, 9, 29, 6, 20, 7, 47
  };
  const int r142[] = {
    10, 10, // Number of jobs and machines
    7, 29, 2, 80, 0, 23, 1, 34, 4, 84, 8, 42, 9, 89, 5, 18, 3, 14, 6, 32, 
    3, 95, 0, 87, 5, 54, 8, 81, 1, 20, 4, 86, 7, 11, 2, 45, 6, 93, 9, 89, 
    9, 16, 8, 46, 3, 21, 6, 94, 0, 14, 1, 11, 7, 79, 5, 28, 4,  4, 2, 93, 
    4, 43, 5, 98, 3, 16, 1,  4, 2, 60, 6,  6, 7, 84, 8, 16, 0, 36, 9,  3, 
    6, 69, 7,  3, 2, 94, 5, 91, 3, 51, 8, 82, 9, 83, 4,  3, 0, 20, 1, 33, 
    9,  4, 7, 92, 4,  1, 5, 85, 0, 94, 6, 92, 2,  2, 3, 99, 1, 60, 8, 72, 
    2, 95, 7, 86, 8, 91, 4, 98, 0, 30, 5, 40, 6, 58, 1, 91, 3, 17, 9, 78, 
    3, 84, 5, 18, 9, 56, 0, 29, 7, 35, 8,  6, 6, 34, 1, 92, 2, 13, 4, 64, 
    6, 94, 8, 89, 5, 85, 9, 72, 4, 15, 0, 53, 7,  3, 1, 50, 3, 59, 2, 57, 
    2, 27, 1, 80, 7, 24, 9, 93, 8, 76, 5, 39, 3, 98, 4,  2, 0, 57, 6, 32
  };
  const int r143[] = {
    10, 10, // Number of jobs and machines
    3, 12, 4,  8, 6, 57, 5, 69, 9, 31, 8, 11, 1, 39, 7, 78, 2, 28, 0, 47, 
    9, 73, 0, 10, 8, 67, 3, 30, 7, 90, 5, 67, 1, 56, 6, 61, 4, 89, 2, 36, 
    4, 19, 7,  3, 0, 55, 9, 57, 5, 53, 2, 20, 8, 37, 3, 16, 6, 73, 1, 18, 
    9, 82, 2, 38, 7, 61, 4, 19, 5, 70, 1, 89, 3, 16, 0, 21, 6, 21, 8, 83, 
    2, 13, 1, 34, 9, 95, 5, 80, 0, 10, 6, 26, 7, 14, 4, 19, 3, 61, 8, 17, 
    5, 65, 0, 27, 3,  1, 2, 93, 7, 67, 9, 97, 6, 18, 4,  7, 8, 55, 1,  3, 
    1, 47, 8, 67, 5, 85, 6, 14, 3, 35, 7, 49, 0, 15, 9, 48, 4, 25, 2, 70, 
    1, 10, 4, 60, 9, 71, 8, 97, 5, 14, 0, 76, 3, 19, 7, 74, 2, 12, 6, 98, 
    6, 22, 0,  5, 3, 76, 5, 31, 2, 71, 4,  9, 9, 23, 1, 40, 7, 97, 8, 41, 
    3, 47, 4, 33, 9, 14, 7, 33, 8, 60, 2, 46, 1, 84, 0, 77, 6, 29, 5, 97
  };
  const int r144[] = {
    10, 10, // Number of jobs and machines
    2, 39, 4, 77, 8, 48, 0, 90, 9, 99, 6, 75, 3, 46, 1, 80, 7, 50, 5,  8, 
    1, 38, 0, 48, 8, 30, 9, 13, 2, 88, 6,  3, 7, 62, 3, 10, 4, 20, 5, 91, 
    7, 22, 6, 71, 8,  8, 0, 31, 2, 37, 5, 53, 4, 34, 1,  7, 9, 90, 3, 86, 
    5, 29, 6, 59, 4, 93, 2, 55, 1, 43, 9, 29, 0, 71, 7, 36, 8, 15, 3, 59, 
    8, 52, 0, 40, 1, 40, 7, 15, 3, 10, 6, 14, 4, 71, 9, 11, 5, 30, 2, 63, 
    4, 78, 3, 43, 6, 66, 8, 99, 7, 47, 2, 13, 0, 62, 5, 83, 9, 78, 1,  8, 
    6, 69, 1, 60, 5, 71, 3, 63, 0, 59, 8, 30, 9, 49, 2, 37, 7, 90, 4, 61, 
    5, 29, 0, 61, 8, 24, 9, 45, 1, 73, 2, 45, 7,  4, 3, 12, 6, 99, 4,  3, 
    7, 38, 2, 29, 4, 71, 3, 56, 9, 85, 1, 39, 6, 80, 8, 17, 0, 48, 5, 95, 
    9, 99, 2, 97, 5,  6, 7, 14, 3, 88, 8, 76, 6, 14, 0, 42, 4, 93, 1, 73
  };
  const int r145[] = {
    10, 10, // Number of jobs and machines
    1, 94, 2, 81, 7, 43, 9, 93, 0, 94, 5, 50, 6, 26, 3, 17, 8, 69, 4, 73, 
    9, 78, 6, 89, 7, 97, 8, 13, 2, 42, 0,  4, 4, 80, 3, 21, 5, 84, 1, 29, 
    5, 73, 0, 69, 2, 12, 4, 74, 3, 43, 1, 81, 9, 38, 7, 88, 8, 44, 6, 74, 
    9, 82, 4, 29, 1, 17, 2,  8, 6, 35, 8, 65, 7, 85, 0, 32, 3, 59, 5,  9, 
    7, 98, 2, 46, 3, 76, 8, 78, 1, 27, 5,  7, 0,  8, 9, 63, 4, 12, 6, 49, 
    8, 27, 0, 73, 6, 25, 4, 19, 2, 65, 1, 61, 7, 65, 9, 27, 5, 74, 3, 78, 
    9, 51, 4, 38, 3, 39, 1, 11, 2, 16, 8,  8, 0, 74, 5, 91, 6,  6, 7, 29, 
    1, 11, 6, 22, 7, 17, 8, 99, 5, 80, 0, 31, 3,  4, 9, 68, 4, 88, 2, 68, 
    1, 58, 2, 89, 4, 80, 0, 66, 7, 63, 6, 48, 3, 99, 9, 80, 8,  6, 5, 10, 
    8,  4, 5, 47, 6, 46, 9, 87, 3, 64, 7, 57, 2, 21, 4, 37, 0, 54, 1,  7
  };
  const int r146[] = {
    10, 10, // Number of jobs and machines
    4, 65, 0, 79, 9,  5, 7,  1, 6, 32, 5, 78, 2, 76, 1, 50, 8, 49, 3, 59, 
    5,  7, 7, 29, 9, 21, 0, 69, 8, 65, 6, 99, 4, 47, 2, 20, 3, 10, 1,  6, 
    6, 59, 1,  9, 3, 82, 9, 98, 0, 19, 5, 95, 4, 72, 2, 70, 8, 47, 7, 78, 
    8, 49, 0, 38, 1, 61, 2, 42, 4, 94, 6, 46, 7,  9, 3, 11, 5, 38, 9, 74, 
    3, 74, 8, 65, 5, 85, 6, 91, 7, 87, 0, 61, 1, 38, 9, 45, 4, 21, 2, 78, 
    9, 81, 4, 20, 2, 88, 1, 20, 0, 97, 3, 33, 6, 38, 8, 59, 5, 38, 7, 60, 
    2, 48, 0, 56, 5, 23, 1, 24, 9, 29, 4, 14, 6, 69, 8, 28, 3,  2, 7, 21, 
    1, 21, 3, 84, 7, 95, 9, 24, 5, 41, 4, 92, 6, 48, 8, 43, 0, 16, 2, 80, 
    6, 51, 8, 78, 4, 94, 2,  4, 1, 42, 9, 66, 3, 34, 5, 72, 0, 32, 7, 87, 
    0, 69, 3, 26, 7, 50, 4, 42, 5, 35, 2, 16, 8, 99, 9, 88, 6, 59, 1, 30
  };
  const int r147[] = {
    10, 10, // Number of jobs and machines
    0, 27, 1, 64, 3, 52, 5,  8, 4, 46, 9,  2, 2, 66, 8, 71, 6, 35, 7, 72, 
    0, 18, 4, 86, 1, 17, 3, 95, 5, 66, 9, 92, 6, 44, 8, 85, 7, 30, 2, 53, 
    1, 18, 8, 90, 3, 31, 4, 16, 9, 19, 6, 71, 7, 13, 2, 93, 0,  7, 5, 27, 
    8, 67, 3, 21, 0, 50, 1,  5, 7,  6, 2, 99, 9, 42, 5, 71, 6, 73, 4, 64, 
    1, 43, 9, 42, 8, 17, 2, 95, 7, 33, 5, 77, 4, 12, 6, 48, 3, 73, 0, 44, 
    3, 37, 8, 26, 2, 12, 1,  4, 9, 80, 7, 88, 0, 57, 6,  7, 4, 16, 5, 38, 
    8,  6, 7,  4, 1, 21, 5, 67, 6, 35, 4, 74, 0, 76, 3, 85, 9, 35, 2, 49, 
    6, 33, 1, 35, 8, 71, 7, 33, 5,  9, 4,  1, 0, 85, 9, 45, 3, 59, 2, 51, 
    8, 67, 7,  4, 6, 90, 3, 32, 5, 17, 0, 69, 2,  4, 9, 41, 4,  7, 1, 56, 
    0, 55, 7, 96, 8, 58, 2, 93, 6, 62, 3, 72, 5, 26, 1, 62, 4, 53, 9,  9
  };
  const int r148[] = {
    10, 10, // Number of jobs and machines
    4, 43, 2, 15, 9,  4, 3, 27, 5, 72, 7, 56, 8,  9, 1, 12, 0, 67, 6, 15, 
    5, 77, 9, 93, 6, 60, 7, 10, 3,  4, 0, 92, 1, 16, 2, 30, 4, 48, 8, 14, 
    1, 33, 7, 33, 9, 18, 3, 49, 0, 43, 2, 68, 6, 31, 4, 48, 5, 79, 8, 32, 
    4, 64, 3, 22, 8, 77, 6, 25, 0, 59, 7, 68, 1, 21, 2, 87, 9, 89, 5, 37, 
    4,  7, 9, 70, 1, 38, 5, 33, 2, 74, 8, 78, 0, 25, 3, 71, 6,  7, 7, 98, 
    8, 86, 6, 71, 2, 51, 1, 34, 9, 53, 0, 66, 3, 37, 4, 92, 5, 47, 7,  7, 
    9, 55, 0, 81, 8, 15, 4, 23, 7, 45, 6, 38, 2, 88, 5,  2, 3, 21, 1, 77, 
    2, 62, 7, 97, 9, 99, 4, 80, 1, 96, 5, 15, 0, 35, 3, 90, 6, 71, 8, 52, 
    6, 69, 0, 67, 3,  6, 1, 75, 2, 71, 8,  6, 7, 27, 5, 41, 4, 49, 9, 97, 
    4,  5, 8, 18, 1, 61, 9, 53, 5, 78, 2, 99, 6, 77, 3, 88, 0, 62, 7, 60
  };
  const int r149[] = {
    10, 10, // Number of jobs and machines
    5, 84, 1, 55, 6,  9, 9, 80, 8, 41, 0, 84, 2, 93, 4, 58, 3, 53, 7, 12, 
    4, 21, 1, 93, 7, 51, 0, 64, 2, 80, 6,  7, 8, 15, 3, 10, 5,  6, 9, 72, 
    7, 44, 1,  3, 4, 65, 3, 97, 9, 69, 6, 39, 8, 31, 5, 30, 0, 41, 2, 50, 
    9, 31, 2, 16, 5, 67, 8, 26, 0, 93, 6, 20, 1, 23, 4, 53, 3, 67, 7, 43, 
    9, 97, 8, 40, 1, 94, 2, 43, 4, 14, 3, 41, 0, 13, 5, 58, 6,  7, 7, 86, 
    1, 25, 0, 13, 2, 23, 8, 95, 4, 12, 9, 25, 5,  8, 6, 41, 7, 14, 3, 87, 
    7,  4, 2, 49, 4, 77, 5, 23, 8, 93, 6, 23, 9, 21, 3, 60, 1, 63, 0, 52, 
    9,  7, 7, 96, 1, 97, 6, 43, 8, 49, 3, 96, 4, 55, 0, 78, 2, 94, 5,  8, 
    8,  5, 9, 72, 1,  7, 0, 63, 5, 20, 7, 43, 3, 69, 2, 97, 4, 61, 6, 91, 
    1,  5, 2, 95, 3, 60, 9, 30, 8, 50, 0, 17, 7, 21, 5, 91, 6, 61, 4,  3
  };
  const int r150[] = {
    10, 10, // Number of jobs and machines
    0, 53, 3, 67, 7, 16, 5, 41, 6, 85, 1, 76, 8, 36, 9, 17, 4, 16, 2, 82, 
    0, 52, 7,  4, 1, 85, 6, 56, 3, 30, 2, 35, 5, 43, 4, 52, 9, 69, 8, 52, 
    1, 89, 8, 74, 5, 93, 0, 22, 7, 74, 3,  1, 2, 14, 6, 26, 9, 30, 4, 22, 
    2, 55, 6, 86, 1,  2, 9,  9, 4, 10, 0, 10, 3, 78, 8, 69, 7, 61, 5, 69, 
    3, 44, 5,  7, 7, 94, 6, 77, 2, 92, 1, 58, 9, 18, 0, 59, 8, 17, 4, 23, 
    2, 39, 1, 94, 8, 32, 9, 23, 6, 48, 3, 30, 5, 45, 4, 51, 0,  8, 7, 41, 
    1, 64, 0, 24, 8, 59, 3,  8, 6, 82, 5, 66, 4, 77, 9, 59, 2, 37, 7, 43, 
    2, 86, 6, 71, 0, 85, 3, 13, 4,  8, 7,  8, 8, 17, 9, 85, 5, 11, 1, 60, 
    0, 46, 4, 25, 5, 78, 9, 85, 7, 71, 1, 57, 2, 69, 6, 38, 3,  7, 8, 95, 
    2, 86, 6, 51, 0, 59, 3, 20, 9, 70, 1, 40, 5, 18, 7, 27, 8, 28, 4, 74
  };
  const int r151[] = {
    10, 10, // Number of jobs and machines
    7, 97, 1, 36, 3, 37, 0, 45, 2, 55, 4, 31, 9, 26, 5, 51, 6, 91, 8, 70, 
    8, 46, 9, 72, 7, 27, 6, 91, 1,  2, 2, 90, 5, 36, 4, 16, 0, 81, 3, 18, 
    8, 23, 6, 93, 9,  1, 0, 85, 4, 61, 1, 47, 7, 22, 2, 79, 3,  6, 5, 58, 
    8, 11, 9, 29, 7, 12, 3, 24, 0, 91, 4, 70, 5, 52, 1, 74, 2,  8, 6, 99, 
    4, 74, 5, 55, 7, 59, 9,  4, 1, 43, 8, 60, 0, 52, 6, 38, 2, 30, 3, 34, 
    7, 75, 3, 16, 4, 17, 8, 43, 2, 64, 5, 66, 1, 53, 0, 34, 6, 15, 9, 39, 
    4, 27, 2, 49, 7, 79, 8, 17, 5, 31, 1, 81, 6, 40, 3, 10, 0, 29, 9, 96, 
    5, 45, 8,  8, 9, 43, 6,  4, 1,  4, 2, 71, 4, 93, 7, 88, 3, 76, 0, 84, 
    1, 48, 9, 41, 8, 15, 6, 51, 7, 79, 4, 69, 5, 23, 3, 76, 2, 65, 0, 81, 
    9, 94, 7, 15, 8, 74, 1, 51, 3, 16, 4, 94, 5,  7, 0, 39, 6, 22, 2, 45
  };
  const int r152[] = {
    10, 10, // Number of jobs and machines
    7, 46, 0, 76, 8, 90, 5, 85, 2, 25, 3, 22, 9, 56, 6, 41, 1,  4, 4,  7, 
    1, 95, 7, 96, 4, 82, 8, 62, 3, 88, 2, 44, 6, 60, 5, 51, 9,  5, 0, 45, 
    7, 97, 0, 72, 3, 22, 2, 68, 6, 40, 9, 24, 1, 65, 8, 36, 4, 15, 5, 80, 
    7, 64, 5, 59, 6, 12, 3, 76, 0, 13, 4, 21, 2, 42, 1, 88, 9, 51, 8, 47, 
    5, 55, 6,  7, 3, 27, 8, 20, 2, 57, 4, 68, 0, 79, 9, 36, 1, 36, 7, 55, 
    5, 84, 0,  1, 3, 37, 2,  5, 4,  5, 7, 37, 8, 62, 9, 25, 6, 36, 1, 95, 
    8, 22, 6, 72, 9, 96, 0, 93, 1, 43, 3, 10, 7, 19, 5,  2, 4, 85, 2,  4, 
    0,  9, 1,  7, 4,  2, 2, 19, 6, 83, 5, 11, 7, 77, 9, 51, 8, 86, 3, 62, 
    0, 83, 3, 62, 7, 36, 8,  4, 2,  4, 6, 13, 9, 89, 1, 10, 5, 12, 4, 72, 
    9, 39, 2, 56, 4, 33, 6, 73, 1, 93, 8, 29, 0, 49, 3, 45, 7, 16, 5, 83
  };
  const int r153[] = {
    10, 10, // Number of jobs and machines
    2, 84, 8, 14, 3, 78, 6, 58, 9, 20, 7, 82, 1, 35, 0, 91, 5,  1, 4, 45, 
    5, 28, 3, 17, 6, 64, 2, 40, 8, 94, 7, 92, 9, 15, 0, 37, 4, 79, 1, 59, 
    6, 55, 0,  5, 1, 61, 9, 91, 5, 41, 4, 51, 2,  4, 3, 25, 7, 69, 8, 67, 
    6, 48, 7, 97, 4, 46, 2, 59, 5, 79, 3, 58, 9, 63, 0, 89, 8, 93, 1, 68, 
    7, 46, 5, 83, 1, 28, 9, 33, 3, 64, 4, 77, 6,  5, 0, 29, 8, 91, 2, 58, 
    6, 96, 7, 54, 8, 93, 2, 57, 0, 40, 3, 27, 1, 90, 4, 39, 5, 82, 9, 76, 
    6, 50, 1, 22, 0, 21, 7, 57, 8, 43, 4, 27, 9, 79, 5, 11, 3, 10, 2, 94, 
    5, 75, 1, 22, 8, 39, 2, 88, 4, 78, 9, 97, 0, 66, 3, 76, 7, 21, 6, 92, 
    0, 71, 4, 46, 1, 50, 3, 59, 8, 68, 2, 18, 5, 97, 7, 53, 9, 63, 6, 54, 
    2, 88, 0, 32, 7, 82, 5, 93, 1, 19, 3, 19, 4, 48, 9, 83, 6, 27, 8, 24
  };
  const int r154[] = {
    10, 10, // Number of jobs and machines
    4, 65, 2, 18, 0, 35, 6, 10, 8,  5, 5, 12, 7, 34, 9, 17, 3, 18, 1,  6, 
    6, 83, 0, 68, 2, 94, 4, 44, 3,  3, 5, 92, 1, 60, 8, 13, 7, 32, 9, 93, 
    1, 73, 0, 64, 2, 59, 6, 15, 4, 30, 5, 94, 3, 77, 7, 69, 8, 52, 9, 58, 
    0, 26, 2, 37, 4,  6, 9, 74, 7,  1, 1, 31, 5, 59, 3, 56, 8, 32, 6, 36, 
    6, 60, 1, 61, 0, 69, 4, 17, 3, 77, 7, 95, 2, 44, 9, 69, 5, 64, 8, 60, 
    0, 83, 9, 77, 7, 53, 1, 79, 3, 80, 5, 63, 2, 20, 8, 58, 4, 53, 6, 27, 
    8, 65, 9, 99, 0, 16, 3, 13, 5, 31, 1, 44, 4, 56, 6, 65, 2, 96, 7, 16, 
    4, 91, 3, 63, 8, 26, 2, 65, 0, 96, 9, 20, 1,  9, 5,  2, 6, 96, 7, 80, 
    5, 49, 4, 13, 7, 10, 3, 75, 6, 39, 8, 38, 1, 96, 9, 64, 0,  8, 2, 13, 
    9, 73, 5, 39, 6, 14, 1, 79, 0, 55, 8, 62, 2,  3, 7, 31, 3, 42, 4, 53
  };
  const int r155[] = {
    10, 10, // Number of jobs and machines
    3, 34, 2, 68, 8, 22, 9, 93, 6, 95, 0, 39, 4, 11, 5, 33, 7, 14, 1, 60, 
    4,  8, 2, 60, 3,  1, 5, 36, 8, 75, 1, 88, 9, 25, 6, 63, 0, 49, 7, 66, 
    0, 96, 4, 60, 7, 29, 8, 97, 9, 67, 3,  6, 2, 62, 6, 95, 1, 36, 5, 99, 
    5, 11, 3, 52, 2, 28, 6,  6, 7, 23, 0, 70, 8, 42, 9, 55, 1, 52, 4, 33, 
    0, 52, 8, 10, 2, 29, 6, 88, 7, 28, 4, 93, 5, 39, 9, 16, 3, 95, 1, 38, 
    4, 77, 8, 55, 0, 64, 1,  8, 3, 71, 9,  7, 6, 12, 7, 35, 2, 50, 5, 11, 
    7, 60, 2, 79, 3, 35, 8, 73, 1, 64, 9, 46, 6, 42, 4, 48, 5, 63, 0, 96, 
    0, 70, 5, 94, 1, 25, 2, 61, 6, 22, 7, 70, 8, 28, 9, 51, 3, 68, 4, 25, 
    8, 82, 5, 73, 2, 59, 7, 36, 3, 71, 6, 70, 9, 22, 1, 37, 4, 97, 0, 22, 
    8, 48, 1,  3, 7, 75, 4, 73, 5, 95, 3, 54, 0, 33, 2, 58, 9, 32, 6,  8
  };
  const int r156[] = {
    10, 10, // Number of jobs and machines
    4, 39, 2,  1, 3, 54, 7, 24, 5,  3, 1, 11, 8, 10, 9, 33, 6, 16, 0,  2, 
    0, 57, 1, 31, 6, 53, 2, 94, 4, 13, 5, 16, 8, 18, 9, 37, 3, 36, 7, 95, 
    6, 75, 3, 47, 9, 64, 0, 76, 1, 58, 2, 99, 8, 97, 7, 56, 5, 13, 4,  6, 
    6, 34, 4,  3, 8, 73, 1,  6, 5, 86, 3, 58, 2,  5, 7,  2, 9, 45, 0, 26, 
    0, 92, 1, 49, 2, 30, 4, 28, 5, 12, 3, 82, 8, 72, 6, 71, 7, 12, 9, 45, 
    6, 56, 8, 26, 7,  9, 3, 21, 2, 17, 0, 94, 9, 53, 5,  6, 1, 11, 4, 82, 
    5, 49, 3, 65, 0, 79, 8, 75, 1, 97, 6, 79, 9, 56, 4, 31, 7, 57, 2, 23, 
    4, 63, 0, 18, 3, 34, 9, 14, 5, 80, 8,  2, 1, 33, 2, 40, 6, 21, 7, 32, 
    7, 28, 9, 34, 3, 30, 5, 52, 2, 16, 4, 69, 6, 81, 1, 57, 8, 28, 0, 52, 
    3, 37, 1, 33, 6, 45, 0, 62, 7,  8, 9, 24, 2, 44, 8, 95, 5, 29, 4, 94
  };
  const int r157[] = {
    10, 10, // Number of jobs and machines
    6,  8, 7, 85, 5,  5, 0, 64, 2, 18, 8, 67, 3, 21, 9, 46, 4, 19, 1, 91, 
    1, 24, 3,  8, 9, 79, 7,  5, 8, 15, 0, 93, 4, 89, 6, 14, 2,  1, 5, 66, 
    2, 31, 4, 13, 5, 98, 6, 78, 9, 32, 7, 65, 3, 62, 8, 35, 1, 39, 0, 88, 
    9, 76, 3, 43, 7, 31, 5, 55, 8, 44, 2, 92, 0, 43, 1, 99, 4, 86, 6, 32, 
    0, 97, 3, 15, 6, 27, 8, 53, 9, 25, 5, 18, 4, 63, 1, 78, 7,  7, 2, 57, 
    0, 75, 3, 93, 2,  8, 9, 91, 7, 54, 5, 87, 1, 38, 8, 19, 6, 11, 4,  6, 
    2, 75, 1, 83, 5, 73, 4, 47, 6, 41, 7, 68, 9, 50, 0,  1, 3, 98, 8, 92, 
    8, 85, 0, 19, 1, 73, 6, 23, 2, 33, 9, 39, 5,  6, 4, 22, 3, 41, 7, 37, 
    5, 38, 4, 87, 2, 83, 1, 43, 6, 89, 8, 64, 7, 52, 9, 35, 0, 29, 3, 71, 
    9, 79, 4, 88, 6, 61, 2, 11, 0, 84, 1,  8, 8, 64, 3, 67, 7, 82, 5, 79
  };
  const int r158[] = {
    10, 10, // Number of jobs and machines
    3, 40, 9, 43, 5, 21, 1, 76, 8, 40, 6, 56, 7, 36, 0, 86, 2, 15, 4, 31, 
    6,  7, 4,  4, 2, 25, 5, 44, 1, 61, 3, 20, 8, 39, 7, 76, 9, 48, 0, 92, 
    7, 56, 6, 67, 9,  1, 0, 60, 3, 76, 8, 51, 4, 53, 5, 20, 1, 47, 2, 28, 
    4, 23, 5, 87, 0, 85, 9, 28, 6, 84, 1, 34, 3, 62, 2, 71, 8, 36, 7, 26, 
    4, 95, 8, 12, 3, 22, 7, 52, 0, 60, 2, 92, 6, 41, 9, 57, 1, 64, 5, 80, 
    0, 79, 5, 48, 4, 76, 8, 12, 6, 41, 7, 43, 1, 44, 9,  7, 3, 52, 2, 95, 
    9, 65, 0, 81, 4, 65, 6, 21, 2, 67, 8, 17, 3, 46, 5, 29, 7,  4, 1, 91, 
    2, 19, 9, 61, 1, 10, 6, 28, 0, 42, 7, 21, 5, 38, 3,  2, 4, 24, 8, 16, 
    1, 77, 5, 34, 9, 71, 3, 35, 8, 22, 2, 39, 0, 38, 6, 86, 4, 36, 7, 68, 
    4, 61, 7, 64, 0, 17, 8, 58, 1, 71, 9, 38, 2, 49, 3, 26, 5, 18, 6, 73
  };
  const int r159[] = {
    10, 10, // Number of jobs and machines
    1,  4, 6,  4, 7, 47, 3, 49, 5, 16, 4, 41, 8, 88, 9,  6, 2,  8, 0, 64, 
    3, 85, 1,  2, 6, 78, 8, 26, 2, 62, 9, 37, 4, 31, 5, 41, 7,  2, 0, 35, 
    6, 15, 9, 38, 5, 22, 8, 14, 2, 28, 1, 88, 0,  8, 3, 24, 4, 33, 7, 87, 
    4, 68, 9, 58, 0, 15, 3, 27, 2, 70, 5, 37, 8, 36, 6, 14, 1, 78, 7, 85, 
    4,  4, 6, 94, 0, 85, 3, 48, 2, 16, 5, 79, 1, 69, 7, 77, 8, 85, 9, 36, 
    2, 74, 8, 31, 1,  7, 6, 17, 0, 61, 5, 76, 7, 91, 4, 61, 9, 77, 3, 69, 
    4, 18, 5, 17, 8, 92, 9, 41, 7, 76, 6, 42, 2, 72, 0, 19, 3, 91, 1, 43, 
    5, 69, 0, 80, 8, 96, 2, 75, 7, 89, 1, 13, 6,  6, 3,  5, 4, 29, 9, 13, 
    8, 13, 1,  3, 5, 79, 4, 32, 2, 71, 7, 28, 6, 28, 9,  2, 3, 68, 0, 30, 
    8, 67, 3, 35, 9, 51, 0,  6, 6, 63, 7, 62, 4, 25, 2, 38, 5, 66, 1, 23
  };
  const int r160[] = {
    10, 10, // Number of jobs and machines
    4, 44, 1, 95, 2, 81, 5,  6, 3, 49, 7, 62, 8,  1, 0, 48, 9, 37, 6, 21, 
    7, 93, 9, 78, 0, 29, 6,  4, 4, 27, 2, 47, 5, 77, 8, 74, 3, 87, 1, 64, 
    2, 84, 6, 96, 9, 66, 1, 88, 7, 35, 3, 60, 0, 10, 4, 32, 5, 62, 8, 32, 
    0, 70, 3, 74, 4, 10, 5, 94, 1, 28, 8, 51, 6, 40, 9, 49, 7, 98, 2, 49, 
    8, 43, 7,  3, 9, 59, 5, 48, 6, 33, 2, 12, 3, 45, 0, 43, 1, 43, 4, 61, 
    4, 88, 2, 17, 7, 48, 8, 88, 5, 40, 9, 69, 6, 95, 1, 99, 3, 78, 0, 58, 
    4, 18, 1,  1, 6, 46, 7, 41, 2, 88, 8, 62, 3, 10, 5, 36, 9, 93, 0, 51, 
    9, 97, 7, 65, 4, 53, 2, 73, 6,  5, 5,  3, 1, 47, 8, 83, 0, 99, 3, 42, 
    2, 92, 3,  5, 1, 38, 9, 11, 4, 21, 5,  1, 0, 26, 7, 35, 6, 47, 8, 53, 
    0, 74, 8, 89, 2, 96, 6, 70, 5, 28, 9, 71, 7, 20, 4, 20, 1, 43, 3, 89
  };
  const int r161[] = {
    10, 10, // Number of jobs and machines
    2,  6, 7, 61, 0, 35, 6, 18, 3, 70, 8, 58, 4,  2, 9, 93, 5, 98, 1, 68, 
    5,  5, 0, 10, 3, 51, 4, 68, 2, 69, 6, 40, 7, 76, 8, 97, 1, 48, 9, 35, 
    5,  1, 4, 76, 9, 63, 3, 95, 2,  3, 8, 58, 7,  3, 1, 27, 0, 53, 6,  3, 
    9, 68, 4, 90, 8, 35, 6, 53, 1, 87, 3, 10, 5, 92, 2, 34, 0, 55, 7, 42, 
    1,  2, 7, 79, 8, 71, 5, 56, 9, 34, 2, 57, 6, 45, 0, 39, 4, 90, 3,  1, 
    2, 81, 1, 95, 7, 28, 5, 14, 0, 68, 3, 34, 4, 43, 6, 20, 8, 74, 9, 90, 
    7, 68, 4, 19, 2, 71, 3, 18, 9, 24, 6, 63, 5,  2, 8, 18, 1, 54, 0,  5, 
    3, 79, 4, 27, 1, 81, 8, 49, 6, 71, 0, 52, 7, 79, 9, 34, 5,  6, 2, 99, 
    4, 45, 7, 72, 8, 88, 0, 84, 5, 79, 3,  7, 2, 97, 6, 26, 9, 39, 1, 20, 
    3, 43, 0, 73, 7, 77, 5, 44, 9, 99, 6, 34, 4, 47, 8, 80, 2, 61, 1, 86
  };
  const int r162[] = {
    10, 10, // Number of jobs and machines
    4, 10, 0, 84, 7, 42, 3, 12, 5, 48, 2, 59, 6, 53, 9, 63, 1, 81, 8, 97, 
    8, 65, 1, 15, 7, 10, 5, 49, 6, 76, 4, 61, 2, 94, 9, 41, 0, 64, 3, 56, 
    7, 43, 6, 87, 2, 48, 1,  8, 0, 70, 9, 78, 5, 42, 3,  2, 4,  6, 8, 28, 
    4, 42, 6, 32, 0, 95, 2, 41, 7,  1, 9, 28, 5, 52, 1, 56, 8, 96, 3, 44, 
    5, 51, 6, 49, 2, 48, 3, 80, 1, 19, 4, 18, 8, 75, 7, 93, 9, 63, 0, 62, 
    6, 15, 3, 38, 4, 61, 1, 82, 9, 45, 5, 81, 2, 78, 0, 73, 7, 75, 8, 96, 
    6, 32, 5, 54, 4, 90, 7, 35, 9, 54, 2, 32, 8, 32, 0, 82, 3, 23, 1, 26, 
    5, 52, 0, 31, 4, 51, 3,  2, 6, 96, 9, 47, 1, 60, 8, 43, 7, 93, 2, 48, 
    2, 67, 9, 70, 7, 71, 5, 13, 3, 10, 1, 66, 0, 44, 4, 58, 8, 98, 6, 46, 
    0, 63, 1, 88, 5, 40, 3, 32, 2,  1, 6, 42, 9, 71, 8, 66, 4, 82, 7, 89
  };
  const int r163[] = {
    10, 10, // Number of jobs and machines
    6, 14, 0, 17, 5, 97, 2, 78, 4, 95, 1, 58, 8, 13, 3, 10, 9, 10, 7, 45, 
    3, 13, 0, 56, 1, 61, 5, 48, 4, 31, 2, 80, 8, 91, 6, 49, 9, 47, 7, 26, 
    9, 77, 0, 58, 6, 46, 2, 45, 1, 90, 3, 92, 4, 15, 7, 80, 8, 36, 5, 92, 
    7, 91, 8, 30, 4, 92, 3, 31, 0,  6, 9, 44, 5, 72, 6, 42, 1, 55, 2, 87, 
    1, 41, 0, 79, 7, 70, 6, 55, 2, 16, 4, 80, 5,  8, 9, 68, 8, 11, 3,  7, 
    6,  5, 5,  9, 4, 54, 9, 67, 7, 27, 3, 90, 8, 27, 2, 73, 0, 56, 1, 84, 
    3, 51, 9, 68, 8, 18, 5,  4, 4, 67, 6, 97, 7, 11, 1, 92, 0, 79, 2, 36, 
    5, 94, 2, 63, 3, 32, 4, 49, 9, 91, 8, 46, 6, 49, 7, 94, 1, 63, 0, 81, 
    2, 62, 7, 90, 0, 48, 4, 66, 3, 31, 8, 29, 6, 80, 1, 16, 9, 96, 5, 83, 
    9, 14, 1, 12, 0, 41, 3, 94, 8, 35, 2, 74, 5, 78, 6, 71, 4, 97, 7, 45
  };
  const int r164[] = {
    10, 10, // Number of jobs and machines
    9, 24, 7, 92, 5, 77, 2,  3, 4,  7, 8, 14, 0, 44, 3, 74, 6, 16, 1, 75, 
    9,  6, 1, 72, 6, 87, 0, 54, 7, 14, 2, 33, 4, 44, 5, 66, 8, 87, 3,  9, 
    5, 62, 1, 46, 8, 95, 0, 62, 7, 10, 2, 56, 4, 88, 6,  4, 3, 15, 9,  9, 
    1, 44, 5, 51, 9, 55, 0, 48, 6, 53, 3, 52, 7, 10, 2, 69, 4,  2, 8,  4, 
    3, 56, 0, 82, 5, 40, 1, 72, 8, 40, 9,  2, 4, 27, 6, 25, 2, 25, 7, 62, 
    2, 85, 1, 99, 7, 32, 8, 71, 4, 33, 0,  7, 3, 90, 6, 64, 5, 90, 9, 33, 
    9, 95, 5, 99, 2, 51, 0, 85, 6, 69, 4, 70, 7, 70, 3, 12, 1, 50, 8, 18, 
    8, 95, 5, 66, 9, 13, 4, 54, 3, 31, 2, 27, 6, 66, 0, 53, 7, 41, 1, 76, 
    9, 73, 1,  7, 8, 12, 0, 10, 6, 27, 2, 67, 4, 13, 3, 79, 7, 78, 5, 56, 
    0, 50, 1, 48, 5, 75, 6, 32, 3, 53, 8,  9, 9, 11, 4, 12, 7, 79, 2, 91
  };
  const int r165[] = {
    10, 10, // Number of jobs and machines
    7, 65, 9, 42, 6, 47, 8, 43, 3, 74, 1, 92, 0, 89, 5, 93, 4, 54, 2, 63, 
    4, 31, 3, 10, 7, 39, 9, 28, 0, 50, 2, 25, 6, 50, 1, 58, 8, 31, 5, 94, 
    9, 79, 6, 18, 5, 28, 4, 46, 0, 13, 3, 33, 8, 20, 1, 32, 7, 97, 2, 38, 
    0, 61, 7, 43, 6, 59, 2, 81, 9, 69, 4, 50, 5, 46, 1, 19, 3, 18, 8, 28, 
    4, 94, 7, 89, 6,  7, 3, 46, 9, 28, 2, 92, 5, 88, 8, 54, 1, 43, 0, 33, 
    5, 65, 4, 20, 6, 55, 9, 24, 2, 88, 3, 85, 8, 97, 1, 14, 0, 63, 7, 97, 
    9, 51, 3, 58, 7, 62, 5, 97, 0, 56, 4, 80, 8, 95, 2, 57, 1, 24, 6, 74, 
    3, 30, 2, 77, 6, 47, 4, 89, 1, 55, 9, 64, 8, 98, 0, 60, 5, 88, 7, 33, 
    3, 68, 9,  1, 6, 10, 8, 95, 1, 29, 5,  6, 0,  5, 4, 49, 7, 69, 2, 32, 
    5, 60, 4, 90, 2, 65, 7, 44, 9,  8, 3, 12, 1, 20, 6, 59, 8, 54, 0, 43
  };
  const int r166[] = {
    10, 10, // Number of jobs and machines
    7, 54, 5,  4, 4,  3, 8, 59, 6, 20, 3, 41, 1, 31, 0, 76, 2, 24, 9,  2, 
    0, 45, 4, 28, 9, 44, 5, 16, 3, 66, 8, 51, 7, 17, 2, 47, 6, 27, 1, 80, 
    9, 66, 3, 15, 0, 27, 8, 95, 6, 88, 4, 39, 1, 77, 2, 80, 7, 81, 5, 17, 
    9, 27, 0, 87, 8, 45, 6, 65, 5, 13, 4, 62, 3,  8, 7, 11, 2, 23, 1, 15, 
    1, 75, 0, 79, 9, 13, 7, 36, 5, 97, 4, 61, 8, 69, 6, 94, 3, 80, 2, 90, 
    1, 69, 3, 25, 5, 84, 6, 70, 9, 69, 2, 41, 8,  7, 4, 60, 0,  9, 7, 98, 
    9, 52, 0, 59, 3, 50, 8, 54, 7, 57, 5, 83, 4, 71, 1, 42, 6, 69, 2, 64, 
    5, 97, 4, 89, 6, 34, 9, 37, 1, 81, 3, 37, 0, 26, 2, 76, 8, 64, 7, 38, 
    7, 21, 9, 23, 2, 67, 6, 94, 5,  9, 0, 94, 4, 39, 3, 18, 8, 52, 1, 95, 
    9, 12, 1, 70, 7, 47, 2, 11, 4, 61, 6, 71, 5, 95, 0, 47, 8, 91, 3, 12
  };
  const int r167[] = {
    10, 10, // Number of jobs and machines
    5, 81, 6, 61, 2, 90, 4, 38, 1, 77, 8, 22, 7, 36, 9, 59, 3, 35, 0, 70, 
    7, 54, 9, 39, 5, 23, 2, 38, 4, 92, 0, 16, 6,  1, 3, 56, 1, 15, 8, 32, 
    6,  9, 8, 43, 3, 73, 0, 50, 7, 53, 1, 29, 2, 61, 5, 48, 4, 50, 9, 75, 
    3, 53, 5, 84, 1, 27, 7, 27, 4, 62, 2, 56, 0, 88, 9, 81, 8, 21, 6, 67, 
    2, 91, 0, 17, 1, 12, 5, 24, 9, 80, 6,  8, 4, 36, 8, 70, 7, 36, 3, 59, 
    2,  9, 1, 95, 6, 51, 9, 70, 4, 94, 5, 73, 0, 37, 8, 25, 3, 25, 7, 88, 
    3, 33, 9, 27, 0,  1, 7, 18, 1, 11, 2, 27, 8, 44, 5, 31, 4,  1, 6, 44, 
    9, 13, 3,  6, 4, 45, 1, 82, 2, 88, 8, 80, 5, 72, 6, 63, 7, 18, 0, 20, 
    9, 70, 4, 93, 8, 50, 1, 41, 3, 86, 7, 40, 0, 85, 5, 90, 6, 89, 2, 85, 
    0, 27, 6,  5, 1, 28, 7, 94, 4, 29, 9, 30, 3, 17, 2, 19, 5, 28, 8, 14
  };
  const int r168[] = {
    10, 10, // Number of jobs and machines
    2, 36, 0, 54, 7, 15, 4,  5, 8, 36, 1, 24, 9, 89, 5,  4, 3, 19, 6, 53, 
    3, 31, 2, 90, 7, 48, 0, 90, 9, 56, 1, 77, 6, 33, 8,  8, 4, 70, 5, 93, 
    5, 51, 8,  5, 4,  8, 0, 18, 2,  3, 3, 55, 9, 39, 6,  5, 7, 27, 1, 57, 
    8, 41, 9, 11, 2, 97, 1, 43, 3, 14, 0, 32, 4, 54, 7, 25, 5, 41, 6, 12, 
    6, 87, 9, 61, 5, 75, 1, 30, 7, 88, 8, 92, 3,  5, 0, 90, 4, 58, 2,  9, 
    0, 54, 7, 99, 4, 54, 9, 26, 2, 59, 3, 17, 8, 83, 5, 10, 6, 84, 1, 31, 
    0, 76, 6, 91, 8, 83, 2, 82, 5, 62, 3, 32, 1, 47, 7, 39, 4, 55, 9, 49, 
    6, 65, 9, 30, 0, 28, 7, 34, 2, 13, 1, 22, 5, 95, 3, 23, 8, 12, 4, 14, 
    7, 64, 3, 22, 2, 67, 9, 73, 1, 37, 4, 70, 0, 17, 6, 52, 8, 38, 5, 34, 
    1, 42, 3,  1, 6, 61, 7, 97, 2, 32, 8, 34, 4, 42, 5, 39, 9, 83, 0, 51
  };
  const int r169[] = {
    10, 10, // Number of jobs and machines
    8, 96, 2, 42, 7, 36, 6, 56, 4,  1, 9, 71, 3, 78, 5, 41, 0, 38, 1, 12, 
    6, 29, 3, 88, 0, 81, 5,  7, 2, 72, 7, 15, 4, 81, 9, 53, 8, 24, 1, 26, 
    3, 20, 9, 97, 6, 96, 1, 18, 5, 40, 0, 16, 7, 54, 4, 60, 8, 10, 2, 66, 
    5, 57, 2, 72, 3, 11, 8, 42, 4, 57, 6,  7, 7, 70, 0, 73, 9, 79, 1, 81, 
    1, 48, 7, 28, 2, 14, 6, 75, 0, 92, 3, 44, 5, 42, 8, 64, 9, 33, 4, 63, 
    3, 11, 8, 29, 0, 67, 7, 55, 5, 38, 4,  2, 9, 99, 6, 81, 2, 10, 1, 31, 
    0, 27, 9, 73, 4, 71, 2, 90, 8, 47, 3, 25, 7, 10, 6, 49, 1, 97, 5, 50, 
    9, 52, 3, 56, 2, 45, 7, 95, 6, 35, 8, 41, 1, 39, 5, 17, 0, 19, 4, 76, 
    1, 68, 5,  1, 7, 10, 6, 30, 4, 86, 3, 60, 0, 50, 2, 68, 9, 43, 8, 25, 
    9, 76, 6, 33, 2, 47, 4, 89, 7, 43, 5, 62, 3, 29, 0, 86, 1, 28, 8, 41
  };
  const int r170[] = {
    10, 10, // Number of jobs and machines
    4, 79, 1, 35, 7, 94, 8, 86, 3, 93, 0, 53, 9,  6, 2,  7, 5, 21, 6, 58, 
    7, 56, 0, 59, 1, 30, 2, 90, 5, 60, 9, 70, 4, 20, 3, 44, 6, 38, 8, 53, 
    2, 49, 6, 44, 9, 15, 1, 51, 0, 55, 3, 50, 8, 57, 5, 46, 4, 43, 7, 55, 
    2, 68, 8, 89, 3,  3, 9, 36, 5,  1, 1, 91, 0, 86, 7,  6, 6, 97, 4, 51, 
    4, 34, 9, 42, 6, 89, 5, 45, 3, 21, 8, 83, 7, 61, 1, 11, 2,  4, 0, 24, 
    8, 50, 4, 80, 2, 82, 5, 53, 3, 14, 1,  8, 7, 66, 9, 98, 6, 62, 0, 47, 
    5, 93, 0, 99, 9,  7, 7, 24, 4, 22, 1, 37, 6, 32, 8, 69, 3, 34, 2, 61, 
    3,  3, 7, 74, 4, 19, 8, 67, 2, 45, 1, 20, 5, 22, 6, 18, 9, 50, 0, 47, 
    8, 56, 2, 17, 5, 21, 4, 83, 9, 26, 3, 62, 1, 90, 0, 45, 6, 98, 7, 86, 
    4, 77, 9, 78, 3, 52, 5, 78, 0, 58, 7, 72, 1, 25, 2, 58, 8, 78, 6,  8
  };
  const int r171[] = {
    10, 10, // Number of jobs and machines
    7, 85, 5, 71, 2, 82, 6,  7, 3, 37, 0, 67, 4, 29, 8, 69, 9, 22, 1, 53, 
    8, 68, 7, 46, 6, 67, 1, 87, 5, 40, 3,  7, 0, 55, 4, 97, 2, 95, 9, 74, 
    0, 77, 1, 15, 7, 24, 3, 37, 6, 27, 5, 83, 2, 61, 4, 20, 9, 73, 8,  3, 
    8, 25, 1, 28, 5,  2, 6, 13, 4, 41, 2,  2, 7, 86, 3, 85, 9, 42, 0, 77, 
    9, 54, 8, 63, 2,  3, 0, 89, 4, 85, 5, 31, 6,  2, 1, 47, 3,  5, 7, 55, 
    4, 73, 7, 25, 8, 25, 5, 10, 6, 57, 2, 97, 3, 58, 1,  2, 0, 89, 9, 13, 
    4, 31, 5, 42, 1, 25, 0, 31, 8, 34, 6, 59, 7, 89, 2, 39, 9, 80, 3, 86, 
    2, 69, 0, 46, 9, 60, 7, 64, 3, 33, 5, 89, 4, 55, 1, 80, 8, 51, 6, 93, 
    9, 81, 7, 72, 4, 24, 5, 16, 1, 71, 8, 71, 0, 61, 2, 99, 6, 57, 3, 89, 
    5, 22, 1, 23, 2, 57, 7, 80, 6, 25, 8, 18, 4, 28, 3, 13, 9, 50, 0, 35
  };
  const int r172[] = {
    10, 10, // Number of jobs and machines
    2,  2, 4, 83, 7, 39, 3, 85, 0,  1, 6,  1, 5, 41, 1,  8, 8, 42, 9, 63, 
    7, 80, 8, 59, 2, 31, 6, 63, 5,  5, 4, 92, 0, 23, 9, 65, 1, 42, 3, 22, 
    5, 88, 4, 68, 7,  9, 3, 78, 1, 41, 9, 35, 0, 64, 6, 51, 2, 53, 8, 25, 
    6, 42, 2, 99, 4, 66, 9, 77, 7, 87, 0, 82, 8, 70, 5, 83, 1, 10, 3, 68, 
    4, 53, 5, 53, 7, 62, 6, 79, 8, 28, 2, 72, 3, 84, 1, 98, 0, 49, 9,  5, 
    6, 53, 3, 12, 1, 49, 7, 49, 8, 49, 5, 46, 0,  4, 9, 14, 2, 62, 4, 85, 
    4, 13, 3, 85, 8, 92, 1, 15, 2, 83, 7, 94, 5, 34, 0, 51, 9, 67, 6, 30, 
    6, 80, 4,  4, 5, 11, 3, 70, 8, 64, 0, 13, 2, 56, 7, 62, 1, 94, 9, 69, 
    5, 22, 3, 15, 9, 25, 2, 84, 0, 58, 7, 76, 8, 13, 1, 55, 4, 66, 6,  7, 
    6,  3, 3,  2, 2, 47, 0, 16, 1, 63, 7, 21, 5, 99, 9, 38, 8, 97, 4, 10
  };
  const int r173[] = {
    10, 10, // Number of jobs and machines
    3, 57, 2, 95, 5, 43, 1, 51, 0, 51, 8, 26, 6, 62, 4, 64, 9, 97, 7, 90, 
    8,  7, 0,  4, 9, 97, 2, 31, 1, 41, 5,  9, 3, 24, 7, 45, 4, 57, 6, 19, 
    7, 32, 5, 37, 0,  1, 9, 61, 1,  5, 6, 49, 4, 59, 8, 84, 3, 85, 2, 85, 
    8, 89, 2, 47, 5, 92, 0, 51, 4, 93, 3, 50, 6, 73, 9, 73, 1, 55, 7, 17, 
    7, 97, 2, 31, 3, 24, 9, 52, 8, 85, 0, 20, 4, 74, 5, 20, 1, 89, 6, 15, 
    0, 69, 8, 82, 4, 25, 3, 12, 6, 92, 1, 77, 9, 51, 5, 75, 2, 18, 7, 33, 
    7, 79, 1, 29, 4, 58, 5, 22, 6, 70, 8, 25, 9, 81, 0, 47, 2, 17, 3, 93, 
    2, 79, 6, 95, 5,  8, 1, 98, 7, 58, 4, 52, 9, 21, 8, 40, 0, 37, 3, 72, 
    4, 91, 3, 20, 8, 49, 9, 85, 5,  6, 1, 87, 6, 22, 7, 21, 0, 60, 2, 55, 
    5, 45, 9,  6, 1, 14, 6, 30, 4, 85, 8, 20, 3, 61, 7,  5, 0, 78, 2, 99
  };
  const int r174[] = {
    10, 10, // Number of jobs and machines
    8, 35, 2, 13, 4, 31, 1,  2, 0, 49, 7, 19, 3, 88, 6, 88, 9, 17, 5, 93, 
    7, 71, 5, 59, 3, 87, 0, 87, 8, 90, 6, 54, 2, 79, 9, 44, 4, 71, 1, 34, 
    9, 43, 6, 45, 0, 78, 7, 71, 8, 29, 3, 26, 1, 19, 5, 87, 4, 82, 2, 43, 
    5, 47, 9,  9, 2, 38, 3, 36, 7, 64, 0, 59, 1, 64, 8, 49, 4, 30, 6, 68, 
    3, 28, 8, 63, 6, 26, 9, 70, 4, 53, 5, 73, 7, 85, 0, 44, 2, 35, 1, 29, 
    3, 88, 1, 45, 5,  8, 8, 13, 7, 58, 6, 96, 4, 72, 0, 18, 9, 76, 2, 35, 
    6, 40, 1,  6, 5, 55, 4, 76, 3, 42, 8, 59, 7, 96, 9, 14, 2, 34, 0, 51, 
    4, 27, 7, 67, 9, 45, 0, 64, 3,  5, 6, 80, 1, 11, 2, 16, 8, 48, 5, 28, 
    4, 77, 6, 79, 3, 89, 5, 45, 8,  1, 7, 85, 2, 36, 1, 19, 0,  8, 9, 21, 
    5, 21, 6, 53, 8, 90, 4, 32, 9, 21, 7, 68, 1, 91, 3, 37, 0, 39, 2, 91
  };
  const int r175[] = {
    10, 10, // Number of jobs and machines
    8,  1, 7, 14, 1, 33, 2, 18, 5, 66, 9, 27, 6, 68, 0, 91, 3, 14, 4, 52, 
    9, 71, 0, 45, 4, 36, 3,  5, 2, 66, 5, 84, 6, 92, 1, 71, 8, 41, 7, 17, 
    7, 29, 3, 42, 2, 28, 9,  1, 0, 34, 5, 39, 1, 51, 8, 53, 6,  8, 4, 81, 
    8, 41, 6, 10, 1, 41, 0, 94, 5, 51, 3, 15, 2, 67, 7, 53, 4, 60, 9, 97, 
    1, 26, 4, 80, 9, 13, 6, 83, 2, 33, 3, 49, 7, 75, 5, 24, 8, 42, 0, 60, 
    7, 46, 4, 69, 0, 20, 6, 75, 3, 19, 9, 60, 2, 10, 1, 35, 5, 72, 8, 89, 
    6, 91, 2, 66, 4,  7, 9, 61, 5, 12, 3,  8, 8, 40, 0, 80, 1,  2, 7, 60, 
    1, 15, 2, 99, 7, 16, 5, 97, 4, 48, 8, 46, 0, 58, 3, 87, 9, 61, 6,  3, 
    2, 38, 0,  5, 5, 85, 4, 63, 8, 28, 9, 88, 6, 11, 3, 50, 7,  7, 1, 33, 
    1, 53, 7,  7, 5, 26, 2, 44, 8, 21, 9, 46, 3, 34, 4, 77, 6, 77, 0, 33
  };
  const int r176[] = {
    10, 10, // Number of jobs and machines
    1, 69, 6, 44, 8, 24, 2, 15, 4, 90, 3, 84, 0, 97, 5, 31, 7, 19, 9, 50, 
    4,  2, 7, 74, 1, 25, 8, 67, 5,  9, 2, 95, 3, 17, 6, 73, 9, 20, 0, 39, 
    7, 78, 0, 24, 1, 50, 4, 76, 9, 27, 2,  6, 3, 23, 5,  7, 6, 30, 8, 39, 
    5, 48, 4, 43, 0, 96, 1, 26, 6, 95, 2, 73, 7, 17, 9, 53, 3, 57, 8, 59, 
    7, 70, 2, 42, 3, 43, 1, 66, 0, 44, 4, 42, 6, 79, 8, 58, 5, 73, 9, 67, 
    1, 60, 5,  6, 2, 85, 3, 87, 4, 57, 6, 55, 8, 46, 7, 54, 0, 41, 9,  9, 
    8, 99, 6, 99, 4, 81, 1, 32, 0, 78, 5, 64, 3,  7, 7, 48, 2, 20, 9, 86, 
    1, 34, 7,  2, 5, 63, 6, 43, 9,  8, 4,  3, 0, 64, 8, 19, 3, 92, 2, 99, 
    6, 54, 5, 54, 8, 82, 4, 69, 7,  9, 1, 80, 3, 39, 2, 42, 9, 32, 0, 31, 
    0, 61, 5, 47, 9, 40, 4, 29, 1, 38, 3, 73, 2, 18, 7, 72, 8, 70, 6, 70
  };
  const int r177[] = {
    10, 10, // Number of jobs and machines
    1, 74, 0, 16, 2, 62, 7, 23, 8, 50, 9, 45, 4, 21, 3, 70, 5, 25, 6, 99, 
    6, 74, 0,  8, 7, 46, 3,  8, 8, 73, 9, 17, 5, 37, 1, 13, 2, 56, 4, 82, 
    2, 64, 0, 18, 9, 98, 4, 55, 3,  1, 8, 88, 5, 79, 7, 79, 6, 51, 1, 90, 
    0, 99, 7, 27, 3,  1, 5, 66, 4, 80, 9, 19, 2, 98, 8, 28, 6, 39, 1, 31, 
    9, 25, 3, 87, 2, 40, 5, 12, 7, 75, 4, 11, 8, 86, 1, 46, 0, 57, 6, 99, 
    9, 53, 2, 47, 5, 23, 6, 50, 0, 14, 1, 56, 7, 47, 8, 56, 4, 29, 3, 76, 
    7, 86, 6, 71, 3, 34, 0, 77, 9, 69, 5, 93, 1,  7, 2, 74, 8, 77, 4, 45, 
    8, 93, 7, 83, 0, 24, 9, 46, 5, 34, 4, 13, 2, 93, 3, 28, 6, 79, 1, 96, 
    7, 32, 8, 27, 5, 72, 3, 94, 0, 92, 4, 65, 2, 38, 1, 86, 6, 95, 9, 33, 
    3, 12, 7, 30, 8, 74, 4, 23, 5, 95, 6, 66, 0, 68, 1, 48, 2, 86, 9, 55
  };
  const int r178[] = {
    10, 10, // Number of jobs and machines
    4, 29, 3, 62, 8, 83, 9, 45, 2, 57, 0, 47, 7, 53, 1, 71, 6, 10, 5, 38, 
    0, 62, 4, 44, 1, 70, 7, 45, 9,  3, 6, 84, 3, 78, 2, 57, 5, 51, 8, 35, 
    7, 49, 3, 77, 5, 70, 0, 14, 8, 92, 9,  2, 6, 97, 4,  8, 1, 27, 2, 99, 
    8,  7, 4, 28, 1, 55, 7, 61, 0, 44, 5, 38, 3,  3, 2, 72, 6, 56, 9, 62, 
    9, 34, 0, 13, 1, 39, 5, 79, 3, 35, 8, 26, 6, 74, 4, 54, 7, 97, 2, 37, 
    9, 42, 3, 11, 2, 15, 1,  8, 8, 76, 6,  6, 4, 99, 5, 39, 7, 87, 0, 76, 
    2, 24, 7, 49, 5, 48, 3, 51, 9,  5, 6, 98, 8, 29, 1, 44, 0, 60, 4, 56, 
    8, 17, 6, 51, 4, 12, 9, 32, 7, 95, 5,  6, 2, 44, 0, 15, 3, 71, 1, 47, 
    3, 67, 0, 45, 1, 59, 7, 47, 2, 78, 5, 87, 9, 65, 8, 81, 6, 92, 4, 55, 
    3, 49, 7, 52, 9, 36, 4, 37, 8, 50, 6, 34, 1, 22, 0, 73, 2, 51, 5, 80
  };
  const int r179[] = {
    10, 10, // Number of jobs and machines
    8, 48, 7, 78, 2, 22, 6,  7, 9, 71, 0, 15, 5, 17, 4, 33, 1,  1, 3, 47, 
    2, 93, 9, 15, 4, 37, 6, 22, 0, 32, 8,  4, 7, 21, 5, 59, 1, 89, 3, 87, 
    8, 41, 3, 67, 0, 59, 1,  3, 2, 59, 4, 63, 6, 73, 7, 51, 5, 82, 9, 85, 
    4, 91, 9, 19, 2, 66, 0, 57, 8, 33, 7, 84, 3, 56, 5, 14, 1, 66, 6,  1, 
    0,  9, 6, 60, 7, 60, 1, 81, 8, 82, 4, 12, 5, 65, 9, 16, 3, 89, 2, 19, 
    9, 25, 5,  6, 2, 30, 6, 30, 4, 71, 3, 83, 7,  8, 0,  9, 8, 25, 1, 46, 
    7, 64, 6, 63, 5, 10, 4, 23, 8, 10, 9, 22, 1, 83, 3, 35, 2, 70, 0, 93, 
    6, 22, 5, 86, 1, 67, 2,  4, 3, 57, 0, 91, 4, 33, 9, 11, 8, 25, 7, 42, 
    8, 63, 3, 23, 4,  1, 6,  5, 0, 98, 1, 56, 9, 59, 5, 57, 7, 61, 2, 35, 
    6, 53, 0, 93, 3,  7, 1, 87, 9,  2, 8,  5, 7, 29, 2, 96, 5, 97, 4, 15
  };
  const int r180[] = {
    10, 10, // Number of jobs and machines
    6, 58, 2, 35, 3, 12, 8, 91, 7, 45, 4, 34, 5, 54, 1, 36, 0, 79, 9, 30, 
    7, 45, 0, 10, 5, 56, 1,  4, 2,  3, 4, 15, 3, 10, 8, 55, 6, 20, 9, 96, 
    8, 42, 0, 62, 1, 19, 9, 58, 6, 49, 7,  6, 4, 24, 3,  6, 5, 18, 2, 45, 
    1, 78, 0, 76, 4, 69, 2,  3, 6, 82, 9, 54, 8, 61, 7, 87, 5, 27, 3,  7, 
    9, 74, 3, 74, 6, 49, 1, 73, 4, 97, 5, 78, 7, 19, 0, 26, 2, 86, 8, 51, 
    8, 95, 9, 39, 2, 31, 3, 85, 7,  2, 0, 99, 4, 43, 1, 86, 5, 11, 6, 99, 
    9, 79, 3, 99, 6, 27, 1, 31, 8,  9, 5, 63, 7, 30, 0, 32, 2, 28, 4, 30, 
    4, 75, 0, 51, 2, 92, 5, 22, 6, 87, 9, 11, 8,  3, 3, 95, 1, 71, 7, 87, 
    3, 25, 7, 22, 5, 36, 6, 73, 0,  5, 8, 87, 1, 88, 2, 11, 4, 92, 9, 15, 
    8, 26, 1, 91, 9,  1, 5, 41, 6, 68, 3, 88, 0, 83, 2, 87, 4, 61, 7, 66
  };
  const int r181[] = {
    10, 10, // Number of jobs and machines
    1, 66, 9, 48, 6, 82, 4, 82, 0, 13, 8, 58, 2, 35, 5, 43, 3, 55, 7, 50, 
    7, 43, 0, 45, 9, 26, 3, 96, 4, 78, 2, 97, 6, 81, 5, 64, 1, 19, 8, 42, 
    0, 46, 4, 58, 2, 25, 3,  4, 9, 43, 5, 14, 6, 26, 1, 43, 7, 39, 8, 56, 
    8, 95, 1, 82, 5, 76, 7, 77, 3, 90, 6, 50, 4,  9, 9, 11, 0, 74, 2, 38, 
    9, 71, 2, 28, 7, 71, 1, 91, 0, 11, 4, 78, 3, 79, 5, 12, 8, 65, 6, 91, 
    8, 40, 2, 24, 1, 87, 3, 59, 6, 48, 0, 57, 7, 53, 9, 35, 4, 21, 5, 65, 
    2, 15, 9, 23, 6, 81, 8, 66, 0, 34, 4, 99, 7, 59, 3, 16, 1,  6, 5,  3, 
    6, 90, 1, 67, 3, 30, 2,  2, 4, 99, 7, 59, 8, 35, 9, 73, 0, 63, 5, 75, 
    2, 59, 9, 83, 7,  2, 8, 64, 5, 90, 0,  1, 1, 84, 4,  7, 6,  2, 3, 82, 
    8, 30, 5, 79, 0, 74, 4,  9, 7, 52, 6, 65, 9, 83, 1, 86, 3, 87, 2, 81
  };
  const int r182[] = {
    10, 10, // Number of jobs and machines
    2,  6, 8, 67, 3, 12, 7, 24, 5, 48, 1, 53, 4, 40, 0, 75, 9, 82, 6, 70, 
    8,  1, 5, 40, 0, 73, 9, 30, 7, 67, 2, 84, 6, 51, 3,  7, 1, 75, 4, 85, 
    4, 23, 6, 58, 7, 60, 9, 20, 0, 48, 3, 65, 5, 24, 2, 44, 8, 67, 1, 84, 
    3, 19, 7, 55, 9, 52, 0, 91, 1, 78, 6, 20, 4, 66, 2, 76, 5, 39, 8, 52, 
    2, 65, 0, 52, 4, 85, 5, 27, 7, 42, 9, 25, 1, 52, 8, 95, 6, 29, 3, 23, 
    0, 30, 9, 46, 3, 18, 5, 63, 7, 49, 4, 90, 8, 21, 6, 96, 1, 97, 2, 32, 
    9, 67, 5,  6, 0, 97, 3, 45, 7, 72, 1,  9, 2, 49, 8, 32, 4, 78, 6, 48, 
    3,  1, 6, 29, 2, 92, 1, 23, 9, 83, 4, 24, 5, 32, 0, 49, 8, 38, 7, 63, 
    1, 38, 6,  2, 4, 47, 2,  1, 5, 37, 7, 58, 8, 70, 0, 99, 9, 87, 3, 54, 
    8,  5, 7, 48, 5, 97, 2, 32, 0, 91, 9, 44, 4, 53, 3, 59, 1, 88, 6, 12
  };
  const int r183[] = {
    10, 10, // Number of jobs and machines
    9, 59, 4, 58, 8,  3, 2, 23, 3, 66, 0, 76, 7, 80, 6, 15, 5, 92, 1, 34, 
    5,  4, 6, 33, 8,  8, 2, 99, 0, 87, 7, 26, 1, 65, 4, 92, 3, 67, 9, 24, 
    1, 97, 9, 16, 0,  2, 3, 53, 5, 18, 2, 50, 6, 51, 8, 19, 4, 23, 7, 99, 
    7, 11, 4, 33, 1, 14, 2, 79, 5, 46, 9, 39, 0, 55, 3, 22, 6, 92, 8, 79, 
    0, 57, 6, 27, 7, 47, 1, 71, 4, 85, 2, 34, 9, 15, 8, 71, 5, 95, 3, 22, 
    2, 54, 7, 91, 1, 92, 4, 40, 5, 91, 6, 46, 9, 23, 0, 58, 8, 77, 3, 57, 
    1, 34, 7, 61, 8, 88, 3, 84, 5, 53, 0, 63, 2,  9, 6, 31, 4, 75, 9, 87, 
    6, 35, 7, 86, 8, 19, 1, 56, 3, 46, 9,  8, 2, 58, 5, 26, 4, 53, 0, 82, 
    1, 48, 6, 25, 5, 50, 0,  9, 9, 95, 8, 28, 4, 42, 7, 47, 3, 76, 2, 82, 
    6,  9, 1, 26, 0, 63, 3, 42, 5, 83, 2, 51, 7, 48, 4, 83, 8, 71, 9, 64
  };
  const int r184[] = {
    10, 10, // Number of jobs and machines
    6, 85, 1, 36, 3, 76, 7, 66, 8, 43, 4, 67, 5, 78, 2, 21, 0, 30, 9, 30, 
    7, 62, 3, 16, 4, 62, 6, 88, 8, 37, 1, 68, 9,  4, 2, 46, 0, 43, 5,  7, 
    6, 53, 5, 96, 3, 36, 1, 34, 9, 18, 4, 14, 0,  2, 8, 48, 2,  4, 7, 47, 
    3, 86, 0,  2, 8, 32, 7, 51, 6, 41, 1, 90, 2, 39, 9, 13, 4, 93, 5, 31, 
    3, 59, 0, 24, 5, 75, 9, 81, 7, 10, 8, 75, 1, 66, 4, 79, 6, 46, 2, 88, 
    6,  3, 7, 80, 2, 56, 3, 59, 1, 24, 8, 99, 5, 45, 4, 29, 9, 13, 0, 78, 
    5, 27, 1, 56, 0, 50, 4, 99, 9, 91, 8, 53, 3, 59, 7,  8, 6, 26, 2, 38, 
    6, 62, 2, 42, 5, 64, 4, 74, 3, 11, 1, 55, 8, 38, 7, 48, 9, 47, 0, 93, 
    1, 12, 6, 81, 0, 89, 2, 12, 9, 89, 3, 34, 8, 23, 5, 31, 4, 80, 7, 91, 
    7, 21, 2, 26, 5,  1, 1, 70, 8, 44, 4, 53, 3, 55, 0, 67, 6, 52, 9, 98
  };
  const int r185[] = {
    10, 10, // Number of jobs and machines
    9, 88, 3, 96, 7, 13, 4, 84, 6, 23, 2, 33, 0, 91, 5, 11, 1, 58, 8,  9, 
    8, 52, 4,  6, 5, 59, 9, 48, 7, 53, 2, 52, 3, 82, 1, 99, 0, 29, 6,  9, 
    4, 74, 0, 81, 5, 61, 8, 79, 3, 52, 9, 19, 2,  2, 7, 68, 6,  3, 1, 87, 
    9,  9, 7,  2, 5, 98, 3, 63, 0, 47, 2, 88, 6, 59, 8, 12, 1, 31, 4, 86, 
    1, 93, 3, 53, 6, 36, 2,  6, 9, 86, 5, 75, 7, 98, 8, 60, 0, 60, 4,  6, 
    8, 43, 4,  7, 1, 88, 6, 69, 2, 87, 3, 17, 7, 68, 5, 21, 9,  9, 0, 77, 
    0,  1, 9, 36, 8,  3, 7, 18, 3, 94, 5, 55, 6, 83, 2, 70, 4, 42, 1, 39, 
    2, 55, 5, 88, 0, 20, 4, 57, 1, 68, 7, 67, 9, 50, 8, 59, 3, 77, 6, 21, 
    5, 52, 6, 73, 9, 80, 2, 61, 3, 50, 0,  4, 8, 49, 4, 19, 1, 64, 7, 10, 
    2, 47, 9, 64, 6, 35, 0, 96, 7, 98, 1, 48, 4, 21, 8, 60, 3, 33, 5, 45
  };
  const int r186[] = {
    10, 10, // Number of jobs and machines
    1, 33, 8, 59, 0, 54, 5, 11, 4, 31, 9, 87, 6, 54, 3, 72, 2, 59, 7, 37, 
    6, 63, 7, 26, 4, 78, 8, 50, 9, 22, 3, 94, 2, 82, 0, 72, 5, 29, 1, 64, 
    4, 46, 1, 56, 9,  8, 0, 90, 5, 64, 6, 98, 7, 78, 8, 43, 3, 83, 2, 95, 
    9, 22, 8, 74, 1, 30, 5, 77, 3, 34, 4,  9, 7, 54, 6, 95, 0,  1, 2, 79, 
    6, 99, 7,  7, 0, 53, 1, 53, 4, 89, 3, 63, 9, 56, 2, 38, 5, 59, 8, 46, 
    9, 76, 0, 54, 7, 55, 3, 35, 5, 36, 6, 74, 4, 87, 8, 99, 1, 31, 2, 54, 
    5, 24, 1,  6, 0, 75, 3, 73, 6, 95, 7, 91, 2, 55, 9,  4, 4, 41, 8, 44, 
    5, 89, 4,  6, 9, 62, 6, 70, 0,  4, 2, 86, 8, 88, 1, 93, 7, 30, 3, 50, 
    8, 52, 1, 91, 7, 96, 6, 74, 5, 50, 4, 35, 9, 38, 0, 35, 2, 57, 3, 92, 
    1, 12, 7, 16, 3, 55, 9, 67, 5, 20, 0,  1, 4, 38, 6, 72, 2, 44, 8, 45
  };
  const int r187[] = {
    10, 10, // Number of jobs and machines
    8, 12, 7, 68, 6, 74, 0,  5, 2, 59, 4, 47, 3, 34, 1, 69, 5, 44, 9, 80, 
    4, 24, 9, 95, 7, 68, 6, 87, 0, 34, 3, 29, 8, 58, 2, 51, 5, 51, 1, 20, 
    8, 49, 4, 38, 3, 91, 1, 42, 9, 33, 5, 82, 2, 82, 6, 63, 7, 17, 0,  6, 
    1, 16, 4,  2, 8, 16, 5, 76, 0, 53, 3, 49, 2,  3, 6, 53, 7,  1, 9, 98, 
    4, 35, 2, 12, 1, 50, 0, 35, 9, 38, 5, 35, 7, 97, 6, 35, 8, 30, 3, 76, 
    5, 56, 9, 36, 4, 33, 2, 34, 8, 33, 0, 31, 1, 91, 3, 75, 7, 33, 6, 48, 
    9, 59, 5, 19, 7, 39, 2, 87, 6, 39, 1, 82, 4, 94, 0, 81, 8, 60, 3, 99, 
    7, 38, 9, 25, 5, 70, 3, 57, 6, 45, 8, 95, 2, 25, 4, 66, 0, 97, 1, 40, 
    1, 58, 0, 61, 4,  4, 9, 93, 7, 65, 5, 53, 2, 54, 6, 54, 3, 95, 8, 17, 
    6, 36, 2, 56, 8,  1, 9, 72, 4, 53, 3, 17, 7, 76, 5, 79, 1, 87, 0, 57
  };
  const int r188[] = {
    10, 10, // Number of jobs and machines
    2, 30, 8, 78, 0, 53, 5, 69, 7, 57, 9, 99, 6, 87, 4, 49, 3, 61, 1, 36, 
    9, 86, 3, 40, 1, 11, 6, 64, 5, 12, 8, 56, 0, 54, 4, 65, 7, 87, 2, 25, 
    8, 25, 4, 79, 6, 55, 3, 16, 7, 31, 0, 58, 1, 27, 9, 85, 5, 79, 2, 46, 
    6, 61, 5, 88, 3, 18, 0, 70, 8, 21, 4, 64, 7, 21, 2, 73, 1, 14, 9, 29, 
    7, 52, 0, 27, 6, 49, 8,  5, 2, 16, 3, 90, 1, 57, 9, 29, 4, 73, 5, 16, 
    9, 20, 2, 59, 3, 54, 1, 71, 7, 13, 8, 37, 6, 48, 0, 54, 4,  7, 5, 98, 
    4, 24, 8, 51, 2, 58, 7, 29, 1, 75, 6, 72, 0, 61, 5, 35, 3, 83, 9, 76, 
    0,  4, 1, 98, 6, 98, 4, 30, 8, 43, 5, 30, 2,  6, 9, 81, 3, 82, 7, 92, 
    0, 16, 6, 23, 2, 82, 1, 59, 9, 78, 4,  8, 3, 68, 8, 16, 5, 54, 7, 56, 
    6, 75, 2, 91, 8, 33, 9, 34, 3, 19, 1, 83, 4, 47, 0, 50, 5, 52, 7, 69
  };
  const int r189[] = {
    10, 10, // Number of jobs and machines
    9, 17, 2, 35, 8, 95, 1, 16, 5,  6, 3,  8, 6, 85, 7, 18, 0, 23, 4, 89, 
    6, 18, 7, 20, 0, 83, 1, 46, 2, 17, 3, 64, 8, 37, 4, 32, 5, 29, 9, 93, 
    1, 87, 6,  8, 0, 66, 3, 83, 8, 59, 5, 75, 2, 68, 7, 14, 9, 70, 4, 97, 
    8, 98, 9, 58, 3, 32, 1, 58, 4, 84, 2, 66, 7, 74, 5, 77, 6, 30, 0, 39, 
    4, 48, 9, 82, 7, 83, 6, 73, 8, 82, 3, 39, 0, 68, 1, 61, 2, 69, 5, 29, 
    6, 59, 3, 49, 5, 71, 0, 66, 2, 22, 9, 56, 8, 18, 7, 24, 1,  6, 4, 12, 
    7,  4, 8, 13, 2, 38, 6, 47, 9, 22, 0, 98, 5, 52, 4, 44, 3, 11, 1, 64, 
    2, 62, 0, 88, 9, 98, 7, 63, 4, 40, 3, 30, 6,  3, 5, 77, 8, 11, 1, 30, 
    5, 19, 2, 57, 3,  4, 0, 28, 8, 31, 6, 65, 9, 64, 4, 84, 1, 38, 7, 44, 
    9, 55, 0, 55, 6, 59, 5, 21, 8, 31, 2, 72, 3, 14, 7, 71, 4, 48, 1, 67
  };
  const int r190[] = {
    10, 10, // Number of jobs and machines
    5,  6, 1, 36, 0,  1, 6, 68, 2, 16, 4, 99, 7, 36, 3, 94, 8, 37, 9, 16, 
    8, 72, 6, 89, 1, 52, 5, 11, 9, 98, 3, 30, 2, 76, 0, 68, 4, 12, 7, 41, 
    8, 27, 4, 10, 5, 45, 6, 32, 2, 78, 1, 42, 9,  2, 3, 53, 0, 13, 7,  2, 
    3, 60, 0, 72, 2, 82, 8, 50, 1, 24, 9,  9, 7, 41, 5, 76, 6, 82, 4, 44, 
    1, 58, 3, 63, 6, 97, 0, 12, 7, 63, 4, 48, 5, 85, 2, 66, 9, 89, 8, 88, 
    2, 19, 5, 34, 9, 56, 0, 98, 3, 90, 1, 83, 7, 99, 8, 75, 6, 29, 4, 61, 
    5, 31, 2, 77, 1, 85, 8,  7, 3, 71, 7, 23, 9, 80, 4,  7, 0, 28, 6, 73, 
    2, 90, 1,  9, 4, 78, 7, 61, 5, 46, 8, 16, 3,  9, 9,  1, 6, 64, 0, 44, 
    6, 98, 7, 29, 9,  7, 4, 95, 8, 87, 5, 39, 0, 23, 2, 44, 1, 23, 3, 65, 
    2,  5, 3, 52, 1, 25, 6, 99, 7, 26, 0, 59, 5, 43, 8, 82, 9,  7, 4, 10
  };
  const int r191[] = {
    10, 10, // Number of jobs and machines
    5, 84, 1, 92, 0, 40, 4, 87, 3,  2, 7, 64, 6, 51, 2, 45, 9, 94, 8, 91, 
    5, 47, 4, 77, 6, 22, 8, 67, 0, 91, 2, 81, 9, 65, 3,  4, 1, 32, 7, 58, 
    5, 28, 1, 59, 7, 12, 6, 46, 9,  1, 0, 62, 3, 62, 2, 50, 4, 23, 8, 86, 
    5, 31, 2, 17, 9, 43, 6, 48, 7, 98, 1, 42, 4, 18, 3,  8, 8, 76, 0, 99, 
    0, 33, 8, 82, 4, 59, 1, 69, 2, 91, 3,  5, 9, 68, 7, 54, 6, 79, 5, 31, 
    1, 39, 2, 62, 6,  2, 4, 47, 5, 68, 8, 31, 7, 76, 0, 95, 9, 77, 3, 75, 
    3, 52, 7, 70, 4, 99, 2, 79, 9, 40, 5, 31, 1, 89, 6, 62, 8, 53, 0, 82, 
    8,  2, 9, 70, 6, 12, 7, 48, 3, 89, 1, 57, 4, 22, 0, 10, 2, 82, 5, 54, 
    8, 95, 2,  9, 3, 97, 7, 96, 0, 97, 5,  7, 4, 47, 6, 98, 9, 62, 1, 84, 
    9, 36, 2,  1, 1, 77, 4, 15, 5, 26, 6, 42, 3, 61, 8, 15, 7, 10, 0, 56
  };
  const int r192[] = {
    10, 10, // Number of jobs and machines
    0, 18, 8,  5, 4, 10, 6, 28, 3,  5, 7, 85, 1, 25, 9, 30, 5, 45, 2, 42, 
    3, 56, 4, 99, 8, 44, 2, 75, 5,  7, 7, 71, 6, 49, 1, 83, 0,  7, 9, 26, 
    8, 97, 3, 88, 0, 90, 1, 82, 2, 79, 5, 75, 7, 41, 9,  8, 6, 37, 4, 34, 
    5, 26, 8, 51, 4, 49, 3, 39, 1, 45, 6, 17, 0, 81, 7, 31, 9, 22, 2, 61, 
    8, 62, 1, 45, 4,  7, 0, 34, 9, 16, 2, 48, 5, 36, 7,  4, 3, 50, 6, 60, 
    4, 29, 7, 14, 3, 48, 9, 28, 6, 74, 5,  4, 0, 71, 1, 66, 8, 24, 2, 67, 
    1, 15, 7, 95, 4, 87, 2, 96, 0, 43, 8, 38, 6,  8, 3, 89, 9, 52, 5, 38, 
    3, 35, 0,  7, 5, 80, 8, 30, 7,  5, 1, 18, 4, 42, 2, 82, 9, 70, 6, 98, 
    5, 71, 7, 41, 9, 38, 3, 59, 8, 23, 0, 33, 2, 97, 6, 20, 4, 79, 1, 44, 
    7, 98, 2, 43, 9, 12, 3, 96, 1, 75, 8, 85, 4,  7, 6, 85, 0, 47, 5, 91
  };
  const int r193[] = {
    10, 10, // Number of jobs and machines
    9, 75, 7, 47, 6, 81, 8, 92, 1, 15, 5, 36, 2, 44, 4, 40, 0, 79, 3, 83, 
    9, 65, 5, 26, 2,  8, 8, 70, 6, 30, 3, 24, 0, 94, 4, 92, 7, 14, 1, 71, 
    0, 13, 1, 87, 4, 67, 2, 69, 9, 81, 6, 42, 3, 17, 5, 44, 7, 31, 8, 13, 
    1, 25, 4, 10, 0, 98, 7, 10, 6, 14, 5,  6, 9, 49, 3, 64, 8, 90, 2, 83, 
    6, 23, 8, 76, 9, 21, 7, 36, 2, 70, 1, 16, 3, 86, 4, 24, 0, 79, 5,  8, 
    6, 91, 8, 13, 9, 98, 0, 33, 7, 47, 4, 32, 2, 18, 3, 41, 5, 82, 1,  5, 
    4, 93, 6, 72, 5, 46, 0,  6, 9, 68, 2, 65, 1,  5, 3, 46, 7, 30, 8,  1, 
    7, 63, 4, 40, 9,  9, 1, 34, 0,  5, 5, 72, 3, 75, 2, 89, 8, 75, 6, 59, 
    3, 62, 4, 94, 8, 38, 0, 67, 6, 62, 2, 27, 1, 37, 7, 33, 9, 47, 5, 80, 
    2, 60, 0, 11, 9, 21, 6, 52, 1, 99, 4, 19, 7, 89, 3, 22, 8, 53, 5, 12
  };
  const int r194[] = {
    10, 10, // Number of jobs and machines
    1, 63, 2, 59, 7, 96, 0, 56, 9, 35, 5, 26, 4, 72, 6, 98, 3, 89, 8, 24, 
    5,  5, 4, 47, 3, 64, 0, 64, 7, 86, 9, 41, 2,  6, 1, 99, 8, 96, 6, 40, 
    3, 59, 5, 30, 6, 43, 4, 27, 8, 96, 7, 75, 9, 91, 1, 12, 0, 80, 2, 12, 
    4, 86, 5,  7, 0, 50, 9, 60, 2, 96, 3,  1, 1,  7, 8, 45, 6, 65, 7, 55, 
    4, 55, 2, 91, 8, 52, 9, 65, 6, 37, 5, 72, 1,  3, 3, 59, 0, 98, 7, 41, 
    4, 18, 8, 89, 0, 48, 1, 85, 5, 80, 3, 76, 2, 48, 6,  9, 9, 76, 7,  4, 
    7, 10, 2, 66, 1, 42, 3, 16, 0, 37, 6, 40, 4, 46, 9, 26, 5, 63, 8, 32, 
    0, 66, 1, 38, 4, 11, 9, 82, 7, 86, 8, 14, 6, 90, 2, 92, 5, 22, 3, 61, 
    3, 55, 2, 61, 6, 29, 4, 88, 8,  6, 1, 60, 0,  3, 9,  4, 5,  1, 7, 90, 
    2, 77, 1, 70, 0, 35, 7, 77, 8, 70, 6, 50, 3, 72, 4, 29, 9, 74, 5, 70
  };
  const int r195[] = {
    10, 10, // Number of jobs and machines
    3, 72, 9, 84, 6, 81, 0, 30, 1,  5, 8, 10, 4, 76, 5, 74, 7, 19, 2, 88, 
    2, 29, 4, 20, 9, 17, 1, 43, 7, 88, 8, 25, 0, 71, 5, 10, 6, 54, 3, 89, 
    7, 70, 4, 38, 2,  5, 1, 99, 5, 96, 6,  9, 8, 78, 9, 70, 3, 85, 0, 75, 
    0, 31, 4, 59, 7, 18, 3, 77, 2, 60, 8, 69, 9, 77, 5, 44, 1,  5, 6, 23, 
    5, 95, 8, 48, 7, 38, 6, 95, 4, 80, 3, 29, 2, 31, 1, 24, 9, 94, 0, 83, 
    9, 37, 8, 31, 0, 67, 6, 22, 7, 28, 4, 55, 2, 64, 1, 17, 3, 17, 5, 31, 
    6, 41, 3, 68, 8,  9, 2, 22, 1, 58, 0, 26, 9,  7, 4, 41, 5, 83, 7, 33, 
    6, 97, 3, 74, 8, 89, 9, 76, 1, 57, 7, 74, 2, 59, 5, 72, 0, 42, 4, 27, 
    0, 60, 4, 69, 1, 10, 5, 98, 3, 16, 2,  9, 6, 30, 9, 45, 8, 67, 7, 68, 
    5,  8, 9, 78, 6, 10, 1, 85, 7, 37, 2, 85, 8, 56, 0, 88, 3, 62, 4, 99
  };
  const int r196[] = {
    10, 10, // Number of jobs and machines
    5, 70, 3, 68, 6, 39, 0, 87, 4, 95, 7, 62, 9, 73, 1, 10, 8, 65, 2,  9, 
    2,  1, 4, 23, 7, 67, 0, 50, 5, 30, 9, 25, 3, 67, 1, 72, 6,  5, 8, 45, 
    7, 64, 4, 87, 6, 33, 0,  3, 1, 12, 3, 73, 5, 98, 2, 96, 9, 64, 8, 81, 
    2, 40, 7, 27, 9,  7, 5, 85, 6, 25, 0, 20, 8, 64, 3, 16, 1, 25, 4, 65, 
    8, 38, 9,  4, 4, 13, 3, 51, 5, 50, 7, 54, 0,  1, 6, 36, 2, 26, 1, 48, 
    8, 41, 6,  6, 0, 24, 5, 92, 3, 76, 7, 59, 1, 99, 9, 33, 2, 65, 4, 76, 
    0, 50, 2, 38, 4, 98, 8, 90, 9, 94, 1,  7, 5, 48, 6, 92, 7, 55, 3, 91, 
    0,  1, 2, 76, 8, 69, 7, 73, 1, 44, 6,  5, 4, 28, 9, 55, 3, 24, 5, 92, 
    5, 55, 9, 19, 2, 12, 1, 24, 4, 91, 7, 20, 0, 92, 6, 90, 3, 11, 8, 46, 
    7, 30, 0, 36, 6, 18, 8, 89, 1, 71, 2, 90, 9, 75, 5, 26, 3, 46, 4, 23
  };
  const int r197[] = {
    10, 10, // Number of jobs and machines
    2, 19, 4, 20, 7, 23, 9, 33, 5, 66, 1, 81, 3, 17, 6, 82, 0,  9, 8,  4, 
    2, 52, 1, 99, 4, 44, 5, 45, 9,  6, 0, 89, 6, 42, 8, 37, 7, 95, 3, 11, 
    7,  7, 6, 84, 2, 23, 8, 23, 1, 92, 4, 78, 0, 68, 3, 54, 9, 55, 5, 19, 
    1, 35, 9, 62, 4, 81, 8, 47, 3, 94, 2, 75, 5, 84, 6, 23, 0, 99, 7, 24, 
    3, 75, 9, 20, 5, 91, 1, 96, 7,  6, 6, 29, 8, 35, 4, 15, 2, 10, 0, 99, 
    7, 47, 8, 48, 3, 99, 0, 88, 6, 26, 4, 81, 9, 94, 5, 12, 1, 16, 2,  4, 
    4, 16, 1, 26, 3, 62, 6, 94, 0, 39, 8, 94, 2, 99, 5, 38, 9, 11, 7, 84, 
    0,  9, 3, 66, 5, 11, 1, 69, 7, 87, 9, 61, 4, 53, 2, 50, 8, 95, 6, 29, 
    9, 63, 1, 49, 8, 24, 7, 61, 2, 54, 6, 21, 3, 22, 4, 20, 5, 96, 0, 61, 
    6, 78, 1, 98, 7, 84, 5,  6, 3, 80, 4, 93, 9,  8, 8, 39, 0, 33, 2,  9
  };
  const int r198[] = {
    10, 10, // Number of jobs and machines
    6, 42, 7, 88, 3, 43, 4, 82, 0, 35, 9,  1, 1, 92, 5, 56, 8, 31, 2, 82, 
    5, 17, 6, 48, 0,  3, 4, 34, 1, 50, 3, 59, 8, 91, 7, 37, 2, 27, 9, 93, 
    3, 35, 8, 46, 0, 95, 4, 72, 1, 97, 5, 43, 7, 86, 9, 44, 2, 15, 6, 21, 
    4, 88, 0, 58, 8, 56, 2,  8, 6, 59, 7, 94, 1, 56, 9, 70, 3, 29, 5, 45, 
    3, 13, 9, 64, 0, 81, 1,  1, 8, 46, 7,  3, 6, 48, 2, 81, 4, 26, 5, 97, 
    8, 51, 3, 52, 1, 16, 5,  4, 0, 94, 6, 19, 7, 71, 9, 63, 2, 87, 4,  7, 
    5, 22, 4, 54, 0, 79, 3, 87, 9, 76, 1, 45, 7, 26, 6, 38, 2, 18, 8, 73, 
    7, 98, 6, 45, 3, 85, 0, 12, 4, 72, 2, 75, 9, 59, 5, 36, 8, 64, 1, 82, 
    5, 71, 7, 91, 3, 92, 6, 76, 0, 56, 4, 55, 2, 73, 1, 46, 9, 72, 8, 84, 
    9, 57, 1, 50, 3, 83, 6, 22, 2, 75, 0, 37, 4, 24, 5, 67, 8, 87, 7, 12
  };
  const int r199[] = {
    10, 10, // Number of jobs and machines
    5, 27, 8, 60, 4, 56, 9, 44, 3, 46, 7, 98, 2, 81, 6, 78, 1, 76, 0, 27, 
    7, 26, 5, 84, 0, 65, 1, 46, 3,  2, 9, 88, 2, 87, 4, 11, 6, 56, 8, 19, 
    3, 33, 4, 33, 5, 13, 2, 57, 1, 48, 9, 10, 6, 47, 0, 64, 8, 32, 7, 99, 
    6, 55, 0, 47, 5, 27, 2, 93, 1, 54, 4, 19, 9, 73, 7, 98, 3, 26, 8, 84, 
    5, 62, 2, 93, 8, 23, 0,  5, 3, 46, 6, 46, 9, 29, 7, 57, 4, 71, 1, 39, 
    6, 37, 4, 41, 3, 87, 9, 11, 0, 69, 1, 55, 8, 16, 2, 55, 5, 58, 7, 90, 
    0,  4, 4, 14, 1, 62, 6, 60, 2, 81, 3,  1, 5, 42, 9, 47, 7, 18, 8, 11, 
    5, 58, 4, 16, 2, 37, 6, 46, 7, 41, 3, 60, 8, 10, 9, 26, 1, 15, 0, 71, 
    9, 12, 5, 54, 2, 87, 6,  2, 7,  4, 1, 38, 4, 47, 3, 17, 8, 90, 0, 18, 
    1, 24, 6, 96, 0, 27, 9, 15, 5, 60, 8, 41, 7, 13, 4, 62, 2,  8, 3, 75
  };
  const int r200[] = {
    10, 10, // Number of jobs and machines
    8, 92, 0, 48, 3, 27, 2, 96, 6, 56, 9, 34, 7, 19, 1, 41, 4, 13, 5, 71, 
    8, 69, 3, 72, 0, 43, 5, 51, 2, 29, 4, 24, 7, 12, 1,  5, 9, 64, 6, 67, 
    4, 64, 1, 33, 0, 22, 2, 70, 6, 78, 8, 96, 7, 56, 5, 47, 9, 74, 3, 55, 
    8, 63, 7, 95, 4, 47, 6,  6, 3, 31, 5, 58, 1, 61, 0, 37, 2, 80, 9, 52, 
    4, 35, 0, 77, 2, 71, 8, 34, 1, 84, 6, 77, 3, 63, 7, 44, 5,  8, 9,  1, 
    9, 50, 5, 18, 7, 46, 3, 52, 0, 63, 2, 26, 8, 16, 1, 24, 4,  8, 6, 86, 
    9, 25, 6,  3, 0, 28, 1, 86, 8, 80, 5, 89, 4, 84, 3, 90, 7, 53, 2, 34, 
    2, 90, 3, 29, 5, 94, 1, 38, 8, 68, 4, 19, 0, 88, 9, 97, 7, 69, 6, 32, 
    6, 91, 3, 50, 7, 71, 4,  1, 1, 27, 9, 33, 8, 79, 5, 73, 2, 45, 0, 77, 
    8, 25, 6, 87, 7, 54, 9, 54, 5, 27, 1, 15, 0, 91, 3, 88, 2, 69, 4, 79
  };
  const int r201[] = {
    10, 10, // Number of jobs and machines
    9, 41, 2, 87, 0, 52, 8, 44, 7, 63, 1,  2, 4, 90, 3, 21, 5, 98, 6, 90, 
    2, 70, 5, 26, 8, 89, 1, 90, 0, 83, 9,  3, 6, 30, 7,  7, 4, 56, 3, 54, 
    1, 56, 7, 75, 9, 63, 2, 24, 5, 91, 0, 17, 3, 49, 4,  8, 8, 51, 6, 72, 
    7, 62, 8, 60, 6, 88, 5, 74, 2,  1, 3, 15, 4, 58, 0, 47, 1, 38, 9, 84, 
    8, 41, 3, 70, 5, 92, 9, 65, 0,  8, 2, 31, 7, 88, 6, 53, 1,  2, 4, 13, 
    5, 42, 3, 33, 2, 48, 9, 84, 6, 12, 0, 23, 8, 14, 1, 94, 4, 35, 7, 66, 
    7, 70, 3,  8, 0, 75, 5, 39, 2, 29, 8, 34, 1, 16, 6, 18, 9, 73, 4, 56, 
    3, 57, 7, 36, 9, 85, 0, 37, 1, 76, 6, 67, 5, 42, 4, 43, 2, 77, 8, 20, 
    4, 79, 0, 29, 5, 33, 3, 14, 9, 93, 1, 23, 6, 61, 7, 10, 8, 88, 2, 79, 
    5, 38, 3, 73, 9, 39, 8, 75, 7, 42, 1, 59, 4, 24, 2, 89, 6, 72, 0,  7
  };
  const int r202[] = {
    10, 10, // Number of jobs and machines
    6, 23, 9, 35, 1, 67, 3, 88, 0, 93, 4, 59, 7, 65, 8, 46, 2, 90, 5, 14, 
    4, 51, 2, 85, 6, 32, 5, 53, 3, 70, 1,  7, 7, 78, 9, 15, 0, 54, 8, 17, 
    4, 74, 7, 82, 2, 98, 5, 16, 9, 19, 6, 71, 3, 74, 1, 93, 0, 38, 8, 67, 
    5, 38, 2, 78, 0, 19, 4, 45, 7, 30, 9, 48, 6, 43, 8, 58, 3, 50, 1, 21, 
    1, 60, 3, 85, 2, 14, 4, 90, 8, 68, 6, 67, 5, 75, 7, 90, 9, 10, 0, 57, 
    6, 33, 0, 37, 9,  7, 1, 68, 5, 74, 2, 87, 7, 72, 3, 90, 4, 34, 8, 48, 
    8, 91, 7, 31, 1, 23, 3, 71, 0, 76, 2, 12, 4, 20, 6, 97, 5,  7, 9, 99, 
    6, 26, 9, 47, 5, 73, 7, 76, 4, 72, 0, 29, 1, 30, 2, 98, 3, 71, 8, 44, 
    3, 49, 5, 33, 7, 32, 8,  2, 2, 13, 6, 85, 4, 62, 9,  2, 1, 40, 0, 94, 
    8, 50, 4, 50, 6, 35, 0, 72, 7, 77, 3, 46, 9, 39, 1, 46, 5, 67, 2, 17
  };
  const int r203[] = {
    10, 10, // Number of jobs and machines
    6, 38, 5, 53, 8, 56, 4, 70, 1, 11, 7, 32, 2, 26, 0, 67, 3, 77, 9,  1, 
    6, 93, 9, 35, 1, 27, 7, 39, 4, 93, 5, 62, 8, 50, 0, 96, 3, 72, 2,  4, 
    6, 91, 1, 22, 2, 36, 5, 99, 0, 34, 4, 77, 8, 74, 7, 52, 9, 33, 3, 31, 
    0, 81, 1, 73, 8, 94, 3, 87, 9, 90, 4, 14, 2, 64, 7, 53, 6, 28, 5, 65, 
    8, 38, 2, 22, 4, 40, 6, 42, 0, 26, 9, 91, 3, 98, 5,  8, 7, 27, 1, 35, 
    4, 48, 1,  2, 3, 95, 8, 96, 5, 16, 6, 95, 9,  9, 0, 88, 7, 55, 2, 53, 
    6, 25, 9, 75, 4, 79, 3, 53, 1,  5, 2, 29, 8, 91, 5, 94, 0, 31, 7, 21, 
    6, 44, 7, 66, 4, 78, 3, 44, 9, 58, 0, 37, 5, 86, 8,  8, 2, 32, 1, 39, 
    5, 39, 6, 40, 3, 99, 4, 11, 9, 99, 2, 38, 0, 84, 1, 92, 7, 34, 8, 48, 
    1, 28, 5, 52, 9, 43, 2, 27, 6, 87, 3, 54, 0, 13, 7, 64, 4, 50, 8, 41
  };
  const int r204[] = {
    10, 10, // Number of jobs and machines
    6, 30, 0, 65, 7, 30, 8, 38, 3, 34, 4, 73, 2, 38, 5, 81, 9, 84, 1, 74, 
    5, 58, 6, 68, 9,  9, 1, 59, 8,  6, 2, 18, 3, 67, 7, 17, 0, 48, 4, 99, 
    2,  7, 9, 36, 1, 73, 6, 30, 7, 99, 5, 73, 3, 94, 4, 56, 0, 46, 8, 11, 
    0, 45, 3,  5, 2, 86, 7, 28, 6, 85, 1, 78, 9, 52, 4, 68, 8, 63, 5, 15, 
    5, 80, 0, 28, 6, 77, 8, 42, 3, 37, 1, 23, 7, 69, 4, 48, 9, 69, 2, 41, 
    8, 11, 7,  5, 2, 51, 4, 28, 1, 20, 9, 41, 5, 83, 6, 54, 0, 93, 3, 48, 
    1, 38, 5, 38, 4, 93, 9, 45, 6, 52, 2, 73, 3, 54, 8, 47, 7, 26, 0, 48, 
    4,  1, 3, 31, 5, 74, 2, 53, 6, 95, 7, 20, 9, 17, 8, 66, 0, 50, 1, 64, 
    7, 12, 1, 23, 5, 12, 6, 62, 4, 62, 9,  5, 8, 31, 3, 15, 0, 96, 2, 36, 
    2, 45, 9, 16, 1, 82, 7, 12, 5, 45, 8, 63, 6, 29, 0, 31, 3, 52, 4, 21
  };
  const int r205[] = {
    10, 10, // Number of jobs and machines
    2, 13, 5, 91, 0, 36, 7, 36, 6, 42, 8, 75, 1, 29, 3, 34, 4, 84, 9, 89, 
    4, 94, 3, 93, 9, 99, 5, 10, 8,  4, 6, 84, 1, 53, 2, 35, 0, 79, 7, 83, 
    6, 49, 1, 46, 7, 38, 0, 39, 8, 12, 2, 31, 4, 89, 5,  3, 9, 62, 3, 92, 
    0, 36, 5, 58, 2, 94, 6,  4, 3, 82, 8, 87, 4, 20, 1,  1, 7, 40, 9, 19, 
    9, 92, 0, 21, 7, 21, 8, 50, 4, 81, 2, 50, 6, 43, 3, 15, 1, 41, 5, 14, 
    9,  9, 7, 29, 8, 83, 3, 71, 2, 44, 1, 41, 4, 88, 5, 61, 0, 13, 6, 70, 
    9, 27, 3, 51, 8, 72, 2, 99, 0, 79, 5, 18, 4, 88, 1, 17, 7, 62, 6, 95, 
    9, 26, 4, 84, 6, 56, 8, 59, 2, 20, 3, 18, 0, 47, 7, 26, 5, 33, 1, 44, 
    1, 38, 8, 31, 7, 28, 0, 34, 2, 69, 6, 11, 9, 96, 5, 36, 4, 79, 3, 25, 
    5, 44, 1, 31, 4, 61, 3, 93, 0, 35, 6, 56, 9,  6, 7, 75, 2, 13, 8, 98
  };
  const int r206[] = {
    10, 10, // Number of jobs and machines
    5, 62, 7, 36, 3, 37, 1, 23, 4, 65, 2, 32, 9, 19, 6, 19, 8,  4, 0, 72, 
    9, 63, 7, 72, 1, 27, 6, 17, 3,  3, 8, 64, 4, 16, 0, 82, 5,  8, 2, 44, 
    3,  6, 1, 85, 9, 57, 7, 25, 8, 96, 5, 38, 0, 86, 2, 81, 4, 85, 6, 45, 
    8, 66, 6, 35, 9, 73, 3, 52, 2, 77, 4, 78, 5, 72, 1, 86, 0, 91, 7, 64, 
    8, 78, 3, 33, 5, 71, 0, 94, 9, 80, 2, 59, 1, 86, 6,  1, 4, 28, 7, 45, 
    5, 93, 9, 30, 4, 14, 3, 85, 0, 12, 8, 49, 6, 61, 7, 85, 2, 38, 1, 66, 
    3,  3, 7,  4, 1, 80, 2, 75, 6, 70, 8, 29, 0, 79, 5,  2, 9, 16, 4, 85, 
    6, 35, 3, 68, 0, 34, 8, 56, 2, 20, 9, 93, 7,  7, 1, 17, 5, 73, 4, 95, 
    5, 58, 9, 92, 7, 20, 4, 47, 0, 66, 1,  9, 3, 17, 2, 39, 8, 50, 6, 94, 
    4, 50, 6, 83, 1, 19, 7, 33, 0, 17, 2, 67, 3, 79, 5, 42, 9, 65, 8, 50
  };
  const int r207[] = {
    10, 10, // Number of jobs and machines
    3, 21, 8, 39, 6, 27, 7,  9, 2, 90, 9, 20, 0, 26, 4, 24, 1, 52, 5, 93, 
    8, 24, 1, 91, 9, 10, 0, 46, 2, 21, 6, 84, 4, 38, 3, 85, 5, 38, 7, 89, 
    3, 42, 5, 45, 7,  5, 2, 32, 1, 36, 0, 74, 8, 29, 9, 79, 6, 61, 4, 57, 
    6, 19, 3, 69, 9, 15, 0, 10, 2, 99, 7, 22, 5, 65, 4, 60, 1, 15, 8, 28, 
    4, 85, 9, 99, 8, 87, 5, 86, 1, 51, 6,  4, 3, 63, 7, 44, 2, 15, 0, 71, 
    7, 88, 8, 19, 4, 82, 2, 48, 0, 81, 1,  3, 3, 25, 9, 20, 6, 90, 5, 14, 
    2, 15, 4, 63, 0, 39, 6, 21, 3, 41, 1, 16, 7,  6, 9, 94, 8, 87, 5, 74, 
    0, 40, 2, 62, 1, 11, 9, 86, 3, 75, 4, 35, 7, 20, 8, 66, 6, 34, 5, 30, 
    8, 79, 2,  6, 6, 70, 1, 30, 4, 39, 5, 58, 0, 90, 3, 60, 7, 20, 9,  3, 
    2, 67, 0, 94, 7, 32, 9, 81, 8, 70, 5, 83, 6, 26, 3, 83, 4, 86, 1, 60
  };
  const int r208[] = {
    10, 10, // Number of jobs and machines
    8, 86, 5, 11, 4, 39, 0,  5, 6, 39, 7, 71, 2, 46, 3, 30, 9, 72, 1, 85, 
    4, 75, 9, 57, 2, 18, 3, 32, 8, 49, 7, 47, 0, 19, 5, 22, 6, 44, 1, 35, 
    2, 12, 5,  3, 0,  3, 9, 12, 1, 77, 7,  5, 4, 95, 6, 65, 3, 13, 8, 28, 
    8, 16, 6, 60, 4, 52, 0, 85, 5, 22, 2, 80, 9, 41, 3, 91, 7, 28, 1, 79, 
    6, 68, 8, 98, 2, 23, 7, 63, 0, 26, 1, 18, 3, 88, 5, 90, 4, 28, 9, 24, 
    1, 58, 7, 64, 0, 23, 9, 84, 6, 98, 8, 45, 3, 15, 2, 31, 5, 29, 4, 50, 
    9, 85, 3, 99, 5,  9, 8,  9, 0, 62, 6, 42, 2, 18, 1, 38, 7, 71, 4, 64, 
    5, 97, 0,  7, 6, 30, 8, 60, 3, 57, 7, 96, 4, 29, 9, 49, 1, 67, 2, 52, 
    9, 98, 2, 41, 0, 49, 7, 57, 1, 31, 8, 91, 6, 40, 3, 38, 5, 65, 4, 13, 
    8, 78, 1,  3, 2, 20, 5, 55, 0, 72, 6, 53, 3, 49, 7, 36, 9, 19, 4, 65
  };
  const int r209[] = {
    10, 10, // Number of jobs and machines
    9, 37, 4, 49, 1, 80, 5, 25, 2, 53, 3, 77, 0, 47, 8, 96, 7, 68, 6, 68, 
    5, 26, 4, 91, 9, 73, 1, 61, 7, 61, 3, 10, 6, 20, 8, 78, 0, 95, 2, 90, 
    3, 73, 7, 68, 1, 63, 5, 47, 6,  8, 8, 47, 0, 53, 9, 49, 2,  8, 4, 59, 
    7, 85, 9, 30, 4, 10, 8, 58, 0, 76, 3, 72, 5, 31, 6, 55, 1, 48, 2, 31, 
    7, 38, 9, 80, 8, 82, 1, 29, 4, 52, 0, 82, 2, 68, 6, 63, 3, 62, 5, 36, 
    1,  4, 4, 54, 0, 41, 3, 19, 2, 52, 6, 74, 9, 48, 8,  4, 5, 83, 7, 21, 
    5, 86, 1, 16, 4, 90, 0, 84, 8, 62, 7, 34, 3, 86, 6, 72, 9, 20, 2, 84, 
    2, 77, 3, 68, 9, 91, 1, 86, 6, 45, 7, 39, 0, 40, 8, 25, 5, 68, 4, 30, 
    0, 30, 4, 28, 9, 37, 8, 11, 5, 12, 2, 59, 3, 26, 6, 52, 1, 17, 7, 52, 
    6, 57, 9, 37, 0, 85, 5, 72, 3, 74, 8, 78, 7, 82, 1, 71, 2, 64, 4, 10
  };
  const int r210[] = {
    10, 10, // Number of jobs and machines
    3,  3, 5, 61, 1,  2, 9, 97, 7, 32, 0, 61, 6, 59, 4,  1, 2, 94, 8,  5, 
    8, 83, 6, 90, 1, 48, 2, 71, 3, 49, 0, 63, 9, 24, 4, 56, 5,  3, 7, 99, 
    5, 60, 2, 19, 9, 35, 7, 21, 0, 91, 6, 41, 8, 99, 1, 87, 4, 24, 3, 78, 
    7, 92, 1, 66, 2, 52, 8, 85, 9, 52, 6, 42, 3,  3, 0, 77, 5, 76, 4,  1, 
    5, 26, 4, 90, 3, 74, 6, 52, 2, 12, 1, 51, 7, 54, 0, 42, 9, 13, 8, 78, 
    9, 59, 1, 27, 5,  3, 6, 28, 8, 11, 3, 44, 0, 78, 2,  7, 4, 77, 7, 90, 
    6, 66, 5, 69, 9, 69, 0, 84, 1, 67, 8,  3, 4, 28, 2, 14, 7, 31, 3, 65, 
    2, 68, 7,  9, 8, 18, 0, 19, 1, 55, 6,  2, 9, 76, 3, 52, 4, 17, 5, 98, 
    5, 22, 3, 35, 7, 66, 8,  2, 1, 96, 4, 99, 6, 52, 2, 55, 0, 29, 9, 18, 
    1, 45, 3, 23, 2, 31, 9, 35, 6, 47, 4, 67, 0, 55, 7,  9, 8, 66, 5,  2
  };
  const int r211[] = {
    10, 10, // Number of jobs and machines
    4, 73, 2, 56, 8,  6, 5, 84, 3, 85, 1, 24, 0, 76, 9, 28, 7, 58, 6, 27, 
    1, 67, 9, 41, 8, 80, 6, 81, 0, 76, 2, 52, 5, 13, 7, 44, 3,  7, 4, 57, 
    2,  5, 0, 37, 8, 17, 9, 27, 1, 66, 4, 47, 7, 98, 5,  7, 3, 16, 6, 46, 
    3, 13, 6, 39, 0, 48, 1, 70, 8, 66, 9,  8, 7, 27, 2, 74, 5, 99, 4, 92, 
    8, 37, 4, 22, 3, 76, 7, 95, 1, 95, 0, 47, 9, 11, 5, 22, 2, 46, 6, 33, 
    9,  5, 0, 55, 4,  5, 3, 65, 1, 58, 6, 28, 2, 80, 5, 98, 7, 57, 8, 31, 
    6, 43, 2, 75, 4, 97, 9, 92, 8, 51, 5, 33, 0, 75, 1, 68, 3, 38, 7, 10, 
    6, 36, 8, 22, 4, 12, 0, 27, 1, 12, 5, 53, 3, 87, 2, 31, 9,  2, 7, 25, 
    2, 49, 9,  9, 3, 22, 8, 18, 1,  8, 5, 94, 0, 43, 7, 36, 4, 84, 6, 98, 
    2, 60, 3, 32, 8, 57, 7, 52, 1, 53, 0, 14, 6, 53, 5, 37, 9, 48, 4, 95
  };
  const int r212[] = {
    10, 10, // Number of jobs and machines
    9, 25, 7, 21, 8,  1, 0, 58, 1, 39, 4,  1, 6, 34, 3, 83, 5, 65, 2, 73, 
    3,  3, 4, 86, 8, 14, 7, 25, 5, 33, 9, 48, 2, 50, 6, 11, 1,  4, 0, 10, 
    5, 92, 3, 98, 2, 93, 8, 39, 4, 79, 1, 82, 6, 16, 0, 61, 9, 49, 7, 40, 
    8, 40, 3,  3, 5, 82, 6, 82, 9, 50, 0, 16, 1, 24, 7, 48, 4, 25, 2, 98, 
    4, 89, 2, 93, 1, 52, 7, 89, 9, 20, 0, 48, 3,  4, 5, 84, 8, 51, 6, 65, 
    4, 19, 0,  7, 8, 52, 3, 56, 9, 54, 2,  4, 5, 93, 6, 10, 7, 37, 1,  1, 
    6, 74, 4, 67, 5,  8, 0, 76, 3, 62, 8,  5, 7, 52, 2, 56, 9, 47, 1, 63, 
    4, 44, 0, 63, 2, 99, 8, 99, 3, 15, 9,  6, 5, 42, 7, 42, 1, 90, 6, 94, 
    2, 50, 6, 92, 5, 52, 4, 94, 0, 32, 3, 69, 8, 18, 7, 92, 1, 16, 9, 28, 
    5, 10, 0, 86, 8, 15, 6, 26, 7, 63, 4, 35, 9, 48, 3, 27, 1, 93, 2, 42
  };
  const int r213[] = {
    10, 10, // Number of jobs and machines
    5, 90, 6, 18, 8, 34, 0, 39, 7, 36, 9, 46, 4, 80, 1, 71, 2, 14, 3, 90, 
    2, 79, 9, 90, 1,  6, 6, 60, 3, 44, 7, 84, 4, 43, 8, 61, 0, 42, 5, 41, 
    4, 49, 9, 45, 7,  5, 8, 76, 6, 48, 0, 83, 3, 92, 5,  7, 1, 70, 2, 32, 
    2, 82, 7, 38, 1, 22, 3, 63, 6, 47, 5, 73, 9, 81, 4, 28, 0, 56, 8, 62, 
    9, 51, 5, 66, 7, 70, 4, 40, 8, 25, 6, 86, 3, 96, 0, 29, 1, 90, 2, 52, 
    3,  5, 6, 93, 4, 13, 7, 16, 8, 87, 9, 11, 5, 41, 0, 32, 1, 85, 2, 14, 
    9, 84, 8, 99, 0, 22, 4, 74, 6,  3, 5,  8, 1, 15, 2, 77, 7, 87, 3, 92, 
    0, 18, 1, 67, 5, 10, 7,  8, 2, 94, 9, 97, 8, 27, 6, 61, 3, 50, 4, 44, 
    1, 82, 3, 31, 2, 51, 4, 58, 7, 54, 5, 47, 6, 52, 9, 77, 8, 84, 0, 50, 
    1, 64, 3, 19, 0, 71, 5, 86, 7, 90, 8,  1, 2,  5, 6, 49, 4,  6, 9, 83
  };
  const int r214[] = {
    10, 10, // Number of jobs and machines
    6, 56, 2,  9, 1, 91, 4, 93, 9, 57, 5, 20, 7, 81, 3, 32, 0, 34, 8, 70, 
    3, 82, 0, 56, 6, 63, 1, 94, 8, 47, 7, 29, 9, 81, 5, 59, 2, 86, 4, 76, 
    9, 97, 7, 43, 1, 82, 6, 76, 2, 90, 4, 61, 3, 34, 5, 87, 0, 17, 8, 37, 
    2, 11, 4, 85, 0, 20, 3, 77, 8, 32, 5, 61, 9, 99, 6, 60, 1, 81, 7, 84, 
    2, 70, 9, 68, 6, 33, 8, 67, 3, 47, 4, 30, 1, 74, 5, 44, 0, 92, 7, 77, 
    5, 44, 0, 64, 6,  6, 9, 90, 3, 54, 2, 67, 7, 84, 4, 71, 8, 43, 1, 15, 
    9, 30, 4, 73, 5, 88, 1,  3, 0, 91, 2,  8, 6, 51, 7, 31, 8,  7, 3, 70, 
    1, 67, 3, 57, 5, 73, 9, 48, 8, 84, 4, 86, 7, 77, 0, 51, 6, 27, 2, 92, 
    0, 78, 4, 31, 8, 71, 6, 41, 2, 13, 7,  9, 3, 40, 5, 77, 9, 64, 1, 56, 
    1, 94, 5, 57, 9,  8, 8, 81, 6, 31, 7, 41, 4, 64, 0, 71, 3, 11, 2, 92
  };
  const int r215[] = {
    10, 10, // Number of jobs and machines
    2, 68, 8,  2, 5, 11, 9, 10, 7, 22, 4, 88, 3, 83, 1, 42, 0, 73, 6, 69, 
    9, 32, 5,  5, 1, 30, 4, 40, 2, 88, 0, 96, 3, 19, 7, 43, 6,  7, 8, 87, 
    3, 66, 1, 66, 2, 39, 4, 44, 9, 46, 7, 91, 5, 34, 0, 43, 6, 89, 8, 83, 
    8, 98, 0, 35, 3, 32, 5, 55, 1, 75, 7, 80, 2, 16, 4, 51, 9, 49, 6, 11, 
    8, 97, 2, 87, 9, 14, 0, 95, 3, 25, 5, 16, 4, 97, 7, 10, 1, 77, 6, 81, 
    2, 19, 6, 19, 4, 45, 8, 87, 3, 69, 7, 18, 5, 79, 0, 39, 9, 36, 1, 40, 
    1, 91, 0, 33, 3, 79, 6, 85, 7, 73, 8,  8, 5,  9, 9, 73, 4, 36, 2, 39, 
    0, 19, 3, 36, 7, 73, 9, 53, 1, 30, 6, 14, 2, 97, 4, 55, 8, 11, 5, 47, 
    6, 17, 9, 88, 4, 17, 0, 85, 3, 14, 1, 78, 5, 34, 2, 27, 7, 24, 8, 87, 
    8, 60, 5, 68, 9, 80, 6, 45, 3, 77, 4, 19, 7, 46, 0, 20, 1, 80, 2, 67
  };
  const int r216[] = {
    10, 10, // Number of jobs and machines
    4, 12, 9, 49, 6, 42, 1, 48, 3, 12, 7, 37, 0, 14, 5, 48, 2, 41, 8, 54, 
    4, 35, 1, 42, 3, 72, 9, 16, 2, 97, 8,  8, 0, 71, 6, 17, 7, 67, 5, 62, 
    4, 57, 0,  2, 7, 69, 1, 47, 3, 50, 8, 77, 9, 13, 2, 56, 6,  5, 5, 45, 
    7, 53, 4, 95, 0, 48, 2, 31, 5, 30, 6, 76, 1, 39, 3,  6, 8, 62, 9, 62, 
    4, 17, 0, 10, 9, 53, 7, 94, 2,  1, 5, 78, 3,  4, 8, 49, 6, 56, 1, 51, 
    3, 12, 9, 83, 7, 26, 5, 96, 6, 19, 0, 84, 2, 68, 4, 94, 1, 19, 8, 83, 
    1, 97, 6, 52, 5, 49, 3, 47, 8, 90, 9, 46, 2, 67, 4, 30, 0, 19, 7, 74, 
    7, 20, 9, 35, 6, 66, 5, 46, 3, 52, 1, 85, 8, 33, 4, 98, 2, 68, 0, 65, 
    5, 99, 3,  6, 6, 20, 4, 61, 2, 33, 1, 84, 9, 91, 7, 47, 0, 16, 8, 15, 
    3, 69, 6, 46, 8, 80, 7,  2, 1, 20, 2, 31, 4, 75, 9, 14, 5, 96, 0, 35
  };
  const int r217[] = {
    10, 10, // Number of jobs and machines
    3, 76, 9, 36, 7, 13, 8, 43, 2, 94, 6, 92, 5, 92, 0, 35, 1, 25, 4, 58, 
    6, 14, 1, 47, 9, 73, 0, 55, 3, 57, 2, 95, 5, 55, 7, 50, 8, 56, 4, 45, 
    4, 60, 7, 60, 8,  6, 6, 91, 5, 18, 2, 37, 1, 61, 0, 99, 3, 82, 9, 83, 
    6, 68, 0,  4, 1, 20, 3, 41, 5, 76, 9,  1, 8, 42, 4, 34, 7, 48, 2, 19, 
    9, 11, 4,  8, 5, 95, 6, 74, 2, 37, 8, 75, 7, 26, 1, 67, 3, 69, 0, 68, 
    6,  9, 8, 31, 7,  8, 4, 26, 2, 67, 1, 11, 0, 53, 5, 65, 3, 89, 9, 71, 
    7, 48, 5, 75, 2, 88, 6, 14, 1, 44, 9, 64, 4, 29, 8, 99, 3, 64, 0, 58, 
    2, 30, 7,  9, 0, 51, 8, 30, 5, 60, 1, 72, 4, 21, 3, 60, 9, 59, 6, 60, 
    4, 49, 6, 40, 0, 46, 5, 52, 8, 96, 9, 76, 1, 34, 7, 47, 3, 66, 2, 67, 
    5, 40, 8, 43, 0, 86, 9, 36, 3, 50, 7, 95, 1, 93, 2, 30, 6, 59, 4, 20
  };
  const int r218[] = {
    10, 10, // Number of jobs and machines
    6, 65, 3, 48, 8, 30, 2, 96, 0, 91, 7, 23, 5, 89, 4, 46, 1,  4, 9, 18, 
    7, 94, 2,  4, 3, 95, 0, 27, 5, 58, 9, 34, 6, 97, 4, 90, 8, 75, 1, 55, 
    2, 96, 4, 42, 3, 27, 8, 29, 5, 50, 6, 35, 1, 93, 7, 57, 9, 46, 0, 89, 
    0,  4, 8, 12, 5, 48, 2, 64, 3, 26, 1,  1, 4, 25, 6, 16, 9, 22, 7, 90, 
    1, 61, 3, 28, 5, 60, 7, 10, 0, 94, 4, 24, 9, 64, 6, 73, 8, 62, 2, 47, 
    0, 14, 7, 96, 4, 64, 6, 48, 8, 25, 9,  4, 3, 95, 5, 51, 2, 17, 1, 59, 
    6, 25, 4, 45, 0, 63, 3, 74, 9, 46, 2, 30, 1, 65, 5, 21, 8, 18, 7, 32, 
    8, 72, 0,  4, 2, 94, 4, 21, 3,  2, 5, 15, 1, 19, 7, 91, 9, 21, 6, 33, 
    4, 30, 0, 36, 9, 19, 3, 32, 1, 94, 7, 79, 6, 48, 2, 82, 8, 26, 5, 71, 
    0, 87, 3, 77, 8, 12, 1, 88, 2, 17, 7,  2, 6, 84, 9, 27, 5, 63, 4, 29
  };
  const int r219[] = {
    10, 10, // Number of jobs and machines
    3, 57, 6, 62, 0, 57, 4, 86, 2, 93, 9, 83, 7, 64, 5, 45, 8, 58, 1, 28, 
    8, 64, 4,  7, 0, 14, 9,  8, 3, 27, 5, 32, 6, 25, 7, 10, 1,  9, 2, 47, 
    3, 96, 9, 22, 1, 51, 5, 51, 8, 32, 6, 86, 7, 77, 0, 50, 4, 97, 2, 85, 
    8, 36, 7, 60, 2, 68, 1, 36, 9, 26, 4, 42, 6, 11, 5, 65, 3, 48, 0, 59, 
    0, 68, 5, 48, 8,  1, 6, 95, 9, 76, 7, 38, 2, 60, 3, 47, 1,  2, 4, 17, 
    6, 18, 8, 30, 9, 32, 7, 22, 2, 71, 0, 80, 4,  7, 5, 99, 1, 59, 3, 64, 
    0, 59, 7, 50, 6,  5, 5,  6, 9, 58, 1, 62, 2, 67, 3, 94, 8, 83, 4, 20, 
    9, 14, 8,  9, 6, 55, 2, 42, 0, 80, 1, 15, 5, 14, 3, 62, 7, 84, 4, 82, 
    4, 36, 0, 15, 1, 66, 6, 14, 9, 26, 7, 77, 2, 99, 3, 40, 5, 71, 8, 95, 
    4, 48, 1, 53, 9, 33, 2,  6, 7, 79, 3, 83, 5, 13, 6, 80, 0, 73, 8, 15
  };
  const int r220[] = {
    10, 10, // Number of jobs and machines
    2, 47, 4, 93, 9, 44, 1, 56, 6,  1, 3, 23, 0, 15, 5, 87, 8, 97, 7, 95, 
    0, 89, 7, 38, 4, 75, 8,  4, 3, 12, 5, 57, 6, 46, 9, 22, 1, 26, 2, 21, 
    8, 92, 9, 87, 2, 74, 1, 90, 3,  5, 5, 20, 0, 10, 4, 60, 7, 56, 6, 56, 
    7, 62, 0, 26, 2, 78, 4, 87, 1, 29, 8, 23, 5, 85, 3, 52, 9, 84, 6, 26, 
    3, 23, 8, 97, 9, 13, 6, 86, 4, 68, 7, 78, 2, 49, 0, 82, 1, 74, 5, 37, 
    9, 31, 4, 35, 0, 33, 2, 21, 8, 54, 3, 93, 7, 51, 1, 41, 5, 28, 6, 86, 
    2, 75, 6, 79, 3,  9, 5, 53, 4, 11, 7, 92, 0, 15, 9, 17, 8, 72, 1, 47, 
    8, 35, 2, 27, 7, 52, 9, 40, 6, 90, 3, 82, 0, 80, 1, 98, 5,  2, 4, 22, 
    0, 17, 9, 22, 3, 61, 4, 45, 7, 87, 8, 56, 2, 27, 1, 62, 5, 64, 6, 40, 
    5, 41, 9, 90, 8, 48, 6, 25, 7, 91, 2, 39, 4, 11, 0, 69, 1, 85, 3, 29
  };
  const int r221[] = {
    10, 10, // Number of jobs and machines
    0, 30, 2, 91, 3, 87, 9,  5, 5, 56, 6, 77, 7, 51, 8, 39, 1, 21, 4,  4, 
    1, 36, 2, 17, 3, 36, 4, 43, 5, 81, 6, 13, 8, 88, 0, 69, 7, 49, 9, 87, 
    6, 98, 3, 32, 0, 18, 1, 22, 4, 60, 2, 61, 5, 42, 9, 65, 8, 29, 7, 17, 
    1,  4, 3, 28, 0, 11, 5, 82, 8, 63, 7, 40, 6, 48, 9, 51, 4, 89, 2,  6, 
    7, 58, 0, 51, 9, 45, 3, 59, 6, 43, 5, 55, 4, 55, 8, 52, 1, 23, 2, 76, 
    2, 40, 1, 30, 0, 33, 6, 79, 5, 92, 9, 17, 4,  1, 7,  2, 8, 20, 3, 67, 
    5, 44, 0, 66, 8, 75, 2, 64, 1,  5, 6, 68, 3, 61, 7, 38, 4,  3, 9, 75, 
    6, 23, 4, 59, 1, 89, 2, 82, 7, 82, 9, 24, 3, 14, 8, 75, 0, 49, 5, 50, 
    0, 31, 2, 46, 4, 34, 5, 36, 7, 12, 8, 16, 1, 13, 3, 78, 9, 63, 6, 56, 
    2, 29, 8, 69, 3, 80, 6, 94, 7, 69, 1, 64, 5, 87, 0, 27, 4, 20, 9, 13
  };
  const int r222[] = {
    10, 10, // Number of jobs and machines
    9, 29, 1, 29, 7, 24, 8,  1, 5, 21, 0, 72, 2, 94, 6, 54, 4, 15, 3,  2, 
    1, 84, 2, 36, 5, 74, 7, 30, 6, 41, 9, 71, 8, 92, 3,  1, 0, 45, 4, 79, 
    1,  3, 0,  5, 5, 17, 8, 59, 4, 30, 9, 84, 7, 37, 6, 68, 2, 69, 3, 54, 
    5, 25, 0, 82, 3, 69, 1, 43, 8, 45, 4, 89, 9, 33, 2, 60, 7, 65, 6, 63, 
    8, 91, 6,  3, 5, 90, 4, 33, 7, 48, 1, 96, 0, 50, 3, 48, 2, 76, 9, 47, 
    5, 51, 0, 75, 4, 37, 2, 30, 8, 14, 6, 44, 7, 83, 3, 59, 9, 69, 1, 91, 
    6, 14, 1, 93, 3, 70, 5,  6, 2, 65, 0, 10, 4, 89, 7, 35, 9, 81, 8, 26, 
    7, 98, 9, 31, 6, 20, 2, 65, 1, 12, 4, 55, 8, 47, 3, 23, 5,  8, 0, 82, 
    8, 98, 7, 41, 9, 57, 2, 52, 0, 70, 3, 29, 5, 99, 4, 80, 6, 22, 1, 63, 
    5, 32, 2, 40, 3, 95, 4, 90, 8, 92, 7, 10, 1, 25, 6, 69, 0, 28, 9, 12
  };
  const int r223[] = {
    10, 10, // Number of jobs and machines
    8, 14, 4, 12, 0, 67, 3, 44, 6, 27, 5, 92, 9, 31, 7, 62, 1, 64, 2, 61, 
    3, 95, 5, 42, 7, 81, 2, 73, 0, 23, 4, 45, 9, 27, 1, 67, 8, 78, 6, 71, 
    3, 16, 5, 28, 6, 26, 4, 61, 9, 15, 1, 10, 8, 54, 2, 21, 7, 90, 0, 34, 
    3, 92, 9, 25, 1, 62, 6, 17, 4, 92, 2, 93, 0, 55, 8, 22, 7, 57, 5, 13, 
    5, 48, 4, 38, 7, 28, 8, 80, 1, 42, 0, 45, 6, 61, 3, 65, 9,  9, 2, 83, 
    3, 92, 1, 41, 8, 76, 7, 77, 4, 87, 2, 83, 0, 35, 9, 90, 6, 19, 5, 53, 
    1, 36, 4, 68, 3, 23, 2, 73, 7, 12, 9, 19, 6, 56, 5, 89, 8, 47, 0, 67, 
    3, 94, 5, 93, 1, 26, 8, 88, 6, 65, 9, 90, 7, 96, 4, 63, 0, 42, 2, 64, 
    4, 90, 1, 37, 2,  6, 3, 82, 6, 17, 7, 61, 5, 12, 0, 33, 8, 84, 9, 86, 
    6, 25, 1, 79, 5, 53, 0, 82, 4, 65, 8, 23, 2, 77, 3, 69, 7,  6, 9, 34
  };
  const int r224[] = {
    10, 10, // Number of jobs and machines
    6, 50, 8, 76, 5, 82, 0, 40, 1, 60, 7,  9, 2, 61, 9, 68, 3, 31, 4, 54, 
    7, 45, 6, 68, 1, 36, 4, 58, 0, 32, 3, 95, 9, 64, 2,  2, 5, 16, 8, 25, 
    9, 76, 1, 42, 3, 25, 0, 89, 4, 12, 5, 60, 8, 92, 7, 55, 2,  6, 6, 47, 
    8, 41, 5, 81, 3, 68, 9,  8, 2, 57, 4, 69, 0,  2, 6, 27, 1, 43, 7, 47, 
    7,  1, 0, 53, 9, 97, 4, 73, 3, 39, 2, 76, 5, 84, 1, 45, 6, 34, 8,  3, 
    2, 27, 3, 68, 8, 25, 9, 82, 7, 80, 1, 55, 5, 27, 4, 50, 6, 83, 0, 79, 
    8, 98, 4, 58, 9, 99, 5, 89, 6, 53, 1,  1, 3, 43, 2, 31, 0, 29, 7, 60, 
    9, 41, 4, 22, 6, 47, 2, 35, 3, 98, 5, 80, 0, 63, 1, 55, 7, 49, 8, 59, 
    9, 95, 7, 29, 5, 55, 6, 24, 8, 89, 2, 10, 1, 81, 0,  7, 3, 26, 4, 95, 
    5,  1, 2,  2, 8, 25, 3, 48, 9,  5, 6, 32, 1, 13, 0, 56, 4, 21, 7, 73
  };
  const int r225[] = {
    10, 10, // Number of jobs and machines
    2, 29, 5, 97, 8, 77, 3, 24, 4, 12, 6, 41, 9, 89, 1, 94, 0, 69, 7, 12, 
    7, 26, 9,  8, 4, 56, 8, 55, 1, 63, 3,  1, 0, 12, 2,  3, 6, 69, 5, 93, 
    0, 87, 2,  5, 1, 93, 5, 18, 7, 14, 6, 40, 8, 26, 3, 62, 4, 75, 9, 33, 
    4, 87, 0, 70, 9, 49, 1, 24, 2, 90, 5, 37, 8,  2, 7, 32, 3,  5, 6, 34, 
    8, 40, 3, 75, 1, 12, 0, 42, 2,  7, 5, 67, 4, 56, 6, 11, 9, 62, 7,  2, 
    9, 94, 4, 19, 1, 52, 5, 86, 2, 87, 0,  1, 3, 66, 6, 97, 8, 68, 7, 53, 
    7, 23, 2, 16, 3,  5, 6, 82, 4,  6, 5, 76, 9, 56, 8, 71, 1, 83, 0,  7, 
    3, 95, 9,  5, 8, 48, 2, 20, 6, 68, 4, 13, 7, 76, 0,  5, 5, 79, 1, 13, 
    2, 81, 5, 15, 1, 62, 7, 13, 3, 87, 0, 12, 8,  6, 6, 31, 4, 73, 9, 27, 
    2, 30, 7, 53, 1, 53, 9, 19, 8, 94, 5, 12, 3, 53, 0, 98, 6, 67, 4, 73
  };
  const int r226[] = {
    10, 10, // Number of jobs and machines
    3,  8, 4, 84, 2, 16, 1, 12, 6, 83, 5, 47, 8, 33, 7,  9, 9, 27, 0, 73, 
    6, 99, 8, 85, 0, 89, 5, 63, 7, 93, 3, 77, 9, 67, 1, 88, 4, 78, 2, 70, 
    1, 37, 8, 57, 3, 35, 6, 29, 9, 21, 0, 52, 5, 94, 4, 72, 2, 63, 7,  9, 
    0, 47, 7, 90, 1, 73, 5, 20, 3, 80, 6, 97, 9, 76, 4,  8, 2, 94, 8, 72, 
    5,  6, 0, 55, 3, 79, 8, 13, 4, 66, 9, 73, 2, 74, 7, 98, 1, 46, 6, 18, 
    9, 92, 1, 57, 6, 61, 2, 60, 4, 42, 5, 80, 7, 15, 3, 83, 8, 24, 0, 45, 
    5, 41, 2, 56, 7, 77, 1, 23, 8, 71, 0,  3, 9, 76, 3, 80, 4, 98, 6, 28, 
    5, 58, 9, 73, 7,  9, 6, 67, 2, 66, 1, 13, 8, 16, 4, 57, 3, 43, 0, 70, 
    1, 27, 5, 24, 9, 68, 8, 85, 4, 48, 0, 56, 7, 56, 3, 13, 2, 75, 6,  3, 
    2, 25, 9, 70, 5, 99, 8,  7, 0,  5, 7, 77, 6, 93, 3, 37, 1,  1, 4,  6
  };
  const int r227[] = {
    10, 10, // Number of jobs and machines
    5, 67, 3, 46, 2, 92, 1, 48, 6, 49, 8, 70, 9, 17, 7, 50, 4,  8, 0, 86, 
    2, 19, 6, 70, 4, 42, 1, 12, 0, 67, 3, 97, 5, 76, 7,  1, 9, 72, 8, 82, 
    6, 24, 8, 58, 4, 43, 3, 81, 5, 11, 0,  1, 1, 95, 9, 59, 2, 33, 7, 22, 
    8, 82, 2, 21, 4, 10, 1, 26, 0, 19, 3, 20, 5,  2, 6,  8, 9, 51, 7,  8, 
    6, 63, 3, 17, 8, 88, 0, 83, 2, 15, 5,  9, 7, 39, 9, 40, 1, 53, 4, 53, 
    9, 79, 0, 72, 5, 12, 2,  6, 1, 46, 7, 97, 8,  6, 3, 39, 6, 76, 4, 75, 
    4, 49, 9, 81, 7, 80, 1, 33, 6, 77, 3, 49, 8, 34, 0, 96, 2,  1, 5,  5, 
    9, 46, 3,  4, 0, 14, 6, 35, 8, 25, 7, 21, 1, 93, 4,  2, 5, 73, 2, 83, 
    1, 64, 8, 28, 6, 51, 7,  5, 4, 17, 2, 56, 3, 98, 5, 49, 0, 77, 9, 13, 
    9, 39, 0, 20, 8, 87, 3, 11, 6,  9, 5, 57, 2, 49, 4,  5, 7, 64, 1, 19
  };
  const int r228[] = {
    10, 10, // Number of jobs and machines
    5, 70, 6, 51, 4, 27, 0, 97, 8, 85, 9, 88, 3, 63, 1, 69, 2, 65, 7, 32, 
    4, 34, 0, 30, 6, 99, 5, 73, 8, 76, 7, 68, 9, 39, 1, 72, 2,  9, 3, 55, 
    5, 72, 4, 84, 9, 82, 3, 36, 6, 92, 0, 86, 2, 29, 7, 95, 8, 17, 1,  9, 
    4, 63, 8, 98, 2, 71, 5, 73, 9, 97, 3, 90, 0, 76, 7, 68, 6, 82, 1, 83, 
    6, 64, 7, 97, 0, 16, 8, 29, 4, 17, 3, 22, 5, 68, 2, 48, 1, 16, 9,  1, 
    0, 56, 7, 79, 9, 78, 8, 51, 1, 78, 2, 50, 6, 79, 5, 30, 4, 65, 3,  4, 
    7, 48, 9, 82, 1, 87, 0, 49, 2, 68, 8, 10, 3, 76, 6, 78, 4, 70, 5, 78, 
    3, 41, 7, 52, 8, 84, 6, 78, 0, 13, 1, 10, 2, 22, 5, 25, 9, 12, 4, 58, 
    2, 24, 9, 58, 1, 50, 0, 83, 3, 23, 7, 27, 6, 74, 5, 69, 4, 69, 8, 64, 
    0, 48, 9, 98, 5, 91, 4, 37, 8, 65, 7, 55, 1, 30, 6, 47, 3, 94, 2, 92
  };
  const int r229[] = {
    10, 10, // Number of jobs and machines
    5, 10, 1, 92, 7, 64, 0, 92, 8, 16, 3, 34, 2,  4, 9, 54, 4, 19, 6, 52, 
    1, 72, 7, 49, 8, 70, 2, 41, 3, 62, 4, 85, 0,  6, 6, 66, 9, 61, 5, 20, 
    5, 21, 9,  9, 0, 17, 2, 26, 1, 57, 8, 72, 4, 64, 6, 40, 3, 10, 7, 71, 
    9, 14, 4, 60, 8, 20, 1,  4, 2, 85, 7, 73, 3, 56, 5, 84, 0, 20, 6, 54, 
    7, 28, 1, 39, 3, 20, 6, 15, 5, 88, 4, 44, 0,  5, 2, 30, 8, 76, 9, 87, 
    0, 34, 2,  3, 7, 56, 4, 25, 3, 94, 9, 76, 8, 20, 5, 19, 6, 21, 1, 98, 
    8, 56, 9, 15, 1, 87, 2, 55, 0, 88, 5, 11, 7,  1, 3, 45, 6, 22, 4, 89, 
    0, 45, 4, 12, 8,  1, 6, 69, 1, 61, 9, 78, 5, 98, 2, 97, 7, 57, 3, 89, 
    2, 14, 0, 14, 7, 26, 6, 11, 8, 91, 4, 26, 9, 95, 1, 51, 3,  3, 5, 89, 
    1, 29, 3, 21, 7, 69, 9, 49, 2, 53, 0,  5, 4, 53, 8, 72, 5, 50, 6, 43
  };
  const int r230[] = {
    10, 10, // Number of jobs and machines
    0, 77, 1, 70, 9, 91, 3, 47, 2,  3, 6, 43, 4, 52, 8, 35, 7, 34, 5, 98, 
    3, 85, 2, 15, 1, 16, 6, 98, 5, 95, 7, 72, 0, 36, 9, 91, 8, 65, 4,  2, 
    6, 56, 8, 11, 7, 45, 1, 22, 2, 87, 3, 75, 4, 87, 0, 30, 5, 43, 9, 23, 
    8, 97, 3, 93, 9, 19, 2, 74, 5,  1, 7, 23, 1, 10, 4, 81, 6, 85, 0, 41, 
    6, 10, 5, 60, 8, 79, 4, 71, 7, 44, 3, 71, 0, 27, 1, 52, 9, 27, 2, 30, 
    4, 14, 7, 22, 2, 52, 6, 22, 9, 90, 1, 87, 8, 90, 3, 14, 0, 31, 5, 55, 
    8, 43, 9, 97, 2, 30, 3, 64, 0, 15, 7, 46, 6, 36, 1, 91, 5, 14, 4, 23, 
    6, 51, 3, 87, 8, 17, 4,  3, 5, 99, 9, 48, 2, 70, 0, 66, 7, 87, 1, 45, 
    5, 61, 7, 20, 4,  3, 2, 38, 3, 54, 6,  3, 8, 20, 0, 59, 1, 42, 9, 39, 
    1, 77, 8, 45, 9, 68, 0, 39, 6, 67, 7, 59, 4, 56, 2, 53, 5, 76, 3, 47
  };
  const int r231[] = {
    10, 10, // Number of jobs and machines
    6, 93, 1, 91, 4, 29, 5, 14, 7, 97, 2, 15, 9, 35, 8, 45, 0, 63, 3, 72, 
    6, 69, 3, 53, 2, 56, 1, 68, 9, 54, 8,  2, 7, 95, 5,  2, 0, 87, 4,  8, 
    2, 93, 8, 87, 9, 11, 3, 33, 4, 29, 1,  5, 7, 41, 6,  5, 5, 88, 0, 30, 
    3, 67, 2, 38, 0, 39, 5, 27, 1, 65, 9, 15, 7,  4, 8, 40, 4, 37, 6, 16, 
    3, 98, 5, 54, 7, 73, 4, 96, 2, 52, 0, 15, 1, 56, 6, 44, 9, 27, 8, 37, 
    3, 94, 8, 39, 2, 34, 4, 56, 0, 81, 9, 76, 7, 25, 5, 96, 1, 53, 6,  1, 
    7, 71, 4, 69, 6,  3, 5, 80, 8, 32, 3, 98, 9, 69, 1, 17, 2, 68, 0, 16, 
    7, 28, 8, 81, 5, 62, 1,  1, 4, 87, 9, 78, 0, 28, 3, 55, 2, 16, 6,  9, 
    3, 14, 8, 10, 1, 30, 0,  9, 4, 70, 5, 23, 2, 45, 9, 21, 6, 58, 7, 58, 
    7, 74, 2, 70, 4, 66, 0, 39, 9, 55, 3, 44, 5, 95, 8, 96, 6, 51, 1, 95
  };
  const int r232[] = {
    10, 10, // Number of jobs and machines
    2, 51, 7, 23, 6, 62, 5, 48, 0, 36, 4, 80, 1, 51, 9, 57, 3, 97, 8,  8, 
    0, 43, 8, 10, 1, 99, 3, 98, 7, 14, 2, 28, 5, 18, 4, 81, 6, 28, 9, 14, 
    7, 83, 5, 55, 1, 82, 8, 45, 2, 42, 6, 65, 9, 77, 4, 65, 0, 33, 3, 30, 
    4, 23, 7, 46, 2, 56, 5, 31, 8, 23, 6, 22, 1, 75, 0, 85, 3, 52, 9, 87, 
    8, 20, 4, 17, 3, 71, 5, 89, 2, 40, 7, 29, 0, 16, 6, 20, 1, 96, 9, 60, 
    1, 97, 4, 29, 5,  6, 8, 33, 2, 42, 3, 91, 0,  3, 9, 85, 6, 32, 7, 96, 
    1, 56, 6, 24, 7, 90, 9, 24, 3, 90, 0, 37, 5, 34, 4, 46, 2, 18, 8, 37, 
    1, 47, 6,  7, 7,  3, 0, 51, 4, 33, 2, 38, 9,  4, 3, 33, 8, 32, 5, 40, 
    6, 33, 2, 64, 1, 76, 3, 97, 7,  9, 0, 34, 4, 17, 5, 24, 8, 61, 9, 78, 
    6, 90, 5, 31, 4, 80, 2, 78, 9, 77, 1, 30, 8,  3, 7,  4, 3, 84, 0, 45
  };
  const int r233[] = {
    10, 10, // Number of jobs and machines
    3, 14, 2, 15, 8, 73, 6, 48, 4, 29, 0, 88, 1,  7, 7, 36, 9, 19, 5, 93, 
    2, 86, 9, 56, 1, 70, 5, 27, 6,  5, 7, 50, 0, 35, 4,  8, 8, 58, 3, 65, 
    8, 16, 5, 90, 2, 61, 0, 82, 9, 19, 1, 26, 6,  6, 3, 51, 7, 95, 4, 63, 
    4, 52, 2, 73, 6, 47, 9, 66, 0, 83, 7, 88, 1, 58, 8, 45, 3, 12, 5, 98, 
    3, 44, 0, 10, 6, 41, 8, 19, 9,  5, 1, 40, 5, 72, 7, 16, 2, 11, 4, 23, 
    5, 32, 3, 37, 9, 88, 2, 44, 4, 69, 7, 81, 0, 34, 6,  5, 1,  5, 8, 66, 
    2, 93, 5, 65, 0, 43, 6, 20, 3, 25, 1, 13, 8, 62, 9, 14, 7, 71, 4, 76, 
    9, 71, 7, 31, 5, 27, 8, 94, 4, 46, 0, 75, 3, 75, 1,  3, 2,  5, 6, 82, 
    3, 33, 9, 87, 6,  9, 4,  9, 2, 35, 7, 43, 8, 30, 1, 59, 0, 48, 5, 38, 
    0, 12, 8, 45, 5, 49, 3, 42, 2, 40, 7, 49, 1, 73, 4, 70, 9, 27, 6, 18
  };
  const int r234[] = {
    10, 10, // Number of jobs and machines
    4, 62, 3,  6, 1, 46, 0,  8, 2, 96, 6, 18, 8, 25, 5, 66, 9, 75, 7, 93, 
    3, 75, 2, 22, 7, 46, 5, 96, 1, 88, 0, 88, 8, 86, 6, 10, 9, 51, 4,  8, 
    3, 22, 6, 53, 2, 74, 9, 83, 4,  6, 8, 94, 0, 13, 5, 21, 1, 44, 7, 24, 
    9, 24, 2, 41, 0,  7, 3,  9, 6, 64, 8, 49, 7, 65, 1, 43, 5, 65, 4, 18, 
    3, 17, 2, 34, 7, 50, 0, 84, 8, 41, 1, 84, 5, 14, 6, 61, 9, 27, 4, 25, 
    6, 16, 5, 37, 2, 56, 9, 25, 7, 85, 1, 51, 8, 88, 3, 49, 4, 47, 0, 52, 
    7, 28, 0, 11, 6, 75, 4, 12, 8, 67, 3, 54, 5, 90, 2, 25, 1, 89, 9, 26, 
    8, 72, 0, 22, 6, 74, 9, 43, 1, 68, 5, 94, 3, 43, 7, 69, 2, 58, 4, 33, 
    6, 74, 4, 86, 7, 16, 0, 66, 9, 18, 1, 20, 3, 94, 8, 37, 2, 63, 5, 44, 
    4, 38, 0, 55, 9, 74, 2,  9, 5, 35, 1,  5, 7, 89, 6, 14, 3, 41, 8,  6
  };
  const int r235[] = {
    10, 10, // Number of jobs and machines
    0, 80, 6, 68, 5, 61, 7, 57, 9, 16, 1, 73, 3, 96, 8,  1, 4, 35, 2, 21, 
    4, 24, 9, 85, 3, 71, 6,  9, 0, 14, 8, 15, 5, 77, 1,  5, 2, 76, 7, 34, 
    4, 25, 6, 33, 5,  3, 0, 86, 9, 37, 8, 46, 2, 74, 1, 24, 3, 97, 7, 90, 
    8, 21, 9, 83, 6, 10, 2,  1, 3, 40, 0,  9, 7, 78, 1, 49, 4, 79, 5, 24, 
    9, 39, 3, 39, 4, 11, 0, 43, 7, 97, 1, 18, 6, 35, 8, 94, 2, 57, 5, 33, 
    1, 96, 2, 30, 6, 19, 4, 91, 5, 96, 0, 65, 3, 76, 7, 74, 9, 84, 8, 91, 
    9, 34, 4, 37, 2, 91, 3, 64, 1, 13, 7, 43, 0, 60, 8, 18, 6, 10, 5, 80, 
    6, 49, 1, 58, 4, 72, 9, 35, 5, 43, 2, 85, 0, 71, 3, 84, 8, 83, 7, 25, 
    2, 14, 4, 13, 5, 63, 9, 12, 1, 21, 0, 64, 3, 94, 6, 40, 7, 96, 8, 49, 
    2, 71, 5, 46, 4, 77, 9, 28, 8, 75, 3, 48, 7, 15, 1, 74, 0, 63, 6, 45
  };
  const int r236[] = {
    10, 10, // Number of jobs and machines
    4, 69, 8, 92, 9, 13, 2, 80, 5, 28, 0, 70, 6, 56, 7, 11, 3,  2, 1, 28, 
    0, 18, 2, 15, 7, 97, 8, 10, 9, 48, 5, 47, 3, 45, 1, 49, 6, 78, 4, 45, 
    6,  2, 8, 13, 9,  1, 0, 15, 3, 63, 4, 47, 5, 22, 1, 13, 7, 12, 2, 22, 
    5, 75, 4, 49, 0, 79, 2, 89, 1, 55, 8, 94, 7, 68, 6, 15, 3, 94, 9,  8, 
    9, 15, 0, 55, 6, 44, 1, 61, 2, 67, 3,  2, 8, 76, 7, 77, 5,  4, 4,  5, 
    3, 26, 8, 42, 9, 77, 6, 43, 5, 99, 0, 63, 1, 91, 7, 74, 4, 18, 2, 32, 
    2, 18, 7, 55, 0, 84, 6,  3, 1, 93, 8, 13, 3, 46, 9, 63, 4, 89, 5, 39, 
    7, 99, 5, 52, 9, 49, 6, 60, 8, 70, 1, 26, 0, 49, 3, 54, 4,  4, 2, 78, 
    8, 74, 4, 88, 9, 72, 0, 69, 6,  3, 7, 52, 2, 82, 3,  7, 1, 68, 5, 72, 
    5, 76, 9, 40, 3, 57, 1, 19, 8, 46, 2,  4, 7, 18, 0, 31, 6, 36, 4, 42
  };
  const int r237[] = {
    10, 10, // Number of jobs and machines
    8, 93, 6, 90, 0, 37, 9, 64, 2, 62, 1, 86, 4, 99, 3, 60, 7, 37, 5, 51, 
    4,  5, 2, 24, 5, 11, 3, 26, 1, 85, 0, 63, 9, 81, 7, 11, 8, 33, 6, 63, 
    1, 39, 4, 28, 0, 55, 2,  3, 9, 72, 7, 10, 6, 42, 3, 86, 8, 30, 5, 18, 
    4, 53, 9, 33, 3, 25, 5,  5, 1, 79, 2, 19, 6, 99, 7, 23, 8, 87, 0, 79, 
    8, 78, 4, 29, 1, 54, 9, 37, 6, 67, 3, 92, 0, 38, 2, 65, 7, 99, 5, 53, 
    9, 27, 8, 68, 6, 54, 0, 10, 5, 83, 4, 38, 2, 83, 1, 18, 3, 38, 7, 66, 
    0, 70, 4, 46, 7, 85, 9, 32, 2, 45, 5, 19, 3, 94, 1, 50, 8, 82, 6, 47, 
    0, 19, 3, 84, 8, 21, 2, 56, 4,  8, 6, 38, 5, 35, 1, 73, 9,  7, 7,  2, 
    0,  9, 1, 50, 8, 89, 9, 10, 2, 91, 7, 90, 3, 32, 5, 41, 4, 63, 6, 66, 
    2, 76, 9, 47, 0, 78, 1, 64, 8, 12, 5, 41, 7, 47, 4,  7, 3, 74, 6, 35
  };
  const int r238[] = {
    10, 10, // Number of jobs and machines
    7, 19, 9, 85, 3, 79, 6, 81, 5, 99, 8, 82, 2, 90, 0, 57, 1, 46, 4, 59, 
    9, 53, 5,  9, 0, 81, 8, 77, 7, 37, 1, 73, 3, 12, 2, 67, 4, 75, 6, 26, 
    8, 57, 6, 25, 1, 85, 9, 48, 0, 95, 5, 82, 7, 94, 3, 28, 2, 42, 4, 93, 
    5, 93, 2, 76, 3, 67, 0, 49, 9,  1, 7, 51, 6, 81, 4, 85, 8, 20, 1, 17, 
    9, 15, 4, 24, 5, 39, 0, 74, 7, 40, 1, 97, 3, 88, 2, 66, 6, 93, 8, 94, 
    1, 31, 6, 30, 9,  1, 3, 68, 8, 99, 7,  4, 5, 95, 2,  7, 4, 87, 0, 37, 
    0, 22, 5, 94, 6, 17, 1, 96, 4, 11, 2,  6, 3, 23, 9, 17, 7, 26, 8, 20, 
    9, 81, 3, 13, 6, 54, 1, 34, 0, 89, 5, 18, 4, 22, 8, 36, 2, 13, 7, 91, 
    1, 72, 9, 27, 0, 51, 3, 49, 6, 76, 7, 77, 5, 11, 2,  4, 4, 17, 8, 32, 
    2, 31, 6, 60, 9, 19, 4, 36, 5,  7, 8, 64, 0, 27, 7, 83, 3, 42, 1, 39
  };
  const int r239[] = {
    10, 10, // Number of jobs and machines
    2, 51, 0, 81, 3, 94, 4,  7, 8, 70, 5, 26, 1,  6, 9, 55, 7, 94, 6, 35, 
    6, 98, 3,  7, 1, 75, 4, 84, 8, 47, 2, 22, 7, 36, 5, 82, 9, 36, 0,  1, 
    2, 46, 5, 19, 7, 90, 9, 65, 4, 19, 3, 98, 0, 14, 6, 17, 8, 41, 1, 33, 
    1, 48, 2, 70, 4, 29, 9, 76, 7, 93, 6, 83, 0, 31, 5, 53, 8,  9, 3, 60, 
    5, 14, 2, 11, 3, 99, 8, 27, 7, 66, 6, 70, 9, 59, 1, 25, 4, 33, 0, 79, 
    6, 28, 3, 12, 4, 37, 0, 70, 7, 19, 8, 79, 2, 89, 1, 47, 5, 68, 9, 15, 
    5, 79, 0, 17, 8, 16, 6, 53, 9, 69, 1, 39, 4, 77, 7, 90, 3, 22, 2, 31, 
    9, 26, 5, 84, 1, 74, 8, 28, 3, 41, 0, 85, 7, 40, 6, 85, 4, 97, 2, 74, 
    8, 84, 2, 72, 4, 87, 6, 30, 9, 67, 7, 41, 0, 82, 5, 45, 3, 61, 1, 38, 
    0, 56, 3, 40, 2, 70, 9, 91, 6, 54, 1,  4, 5,  8, 8,  3, 4, 30, 7, 84
  };
  const int r240[] = {
    10, 10, // Number of jobs and machines
    7, 91, 6, 76, 0, 72, 3, 19, 2, 39, 5, 31, 4, 13, 1, 28, 9, 45, 8, 23, 
    6, 70, 2, 22, 9, 44, 1, 56, 8, 65, 3, 76, 7, 81, 0, 45, 4, 31, 5, 82, 
    5,  4, 1, 95, 3, 48, 2, 33, 0,  1, 7, 97, 6, 12, 4, 48, 8, 40, 9, 93, 
    8, 24, 7, 44, 9, 71, 0, 89, 2, 21, 3, 97, 4, 75, 6, 41, 1, 79, 5, 92, 
    0, 78, 4,  9, 3, 46, 7, 94, 8, 12, 9, 30, 6, 11, 2, 72, 1, 63, 5, 89, 
    2, 58, 1, 89, 9, 24, 0, 47, 5, 78, 4, 15, 6, 46, 8, 59, 7, 92, 3, 27, 
    9, 99, 2, 43, 6,  3, 5, 92, 4, 52, 8, 92, 3, 16, 7, 42, 0, 85, 1, 42, 
    9, 46, 8, 38, 3, 62, 4, 76, 1, 35, 2,  2, 5,  6, 6, 61, 0, 10, 7, 69, 
    2, 48, 1, 93, 9, 85, 0, 89, 5, 15, 6,  3, 8, 34, 4, 58, 7, 45, 3, 90, 
    9, 63, 3,  9, 1, 23, 2, 60, 0, 95, 6, 61, 7, 60, 4,  3, 8, 67, 5, 57
  };
  const int r241[] = {
    10, 10, // Number of jobs and machines
    9, 86, 7, 79, 5, 17, 4, 93, 3, 37, 2, 75, 0, 55, 6, 86, 1, 90, 8, 84, 
    6, 53, 9, 90, 4, 61, 5,  1, 7, 23, 2, 80, 8, 83, 3, 65, 0, 35, 1, 53, 
    9, 99, 0, 48, 3, 45, 4, 71, 1, 39, 5, 43, 8, 36, 2, 17, 7, 24, 6, 90, 
    2, 77, 5, 82, 9, 64, 6, 58, 1, 47, 4, 20, 7,  4, 8,  9, 3, 28, 0, 80, 
    8, 60, 1, 44, 3, 62, 6, 77, 7, 94, 0, 62, 4, 56, 2, 71, 5, 19, 9,  2, 
    0, 42, 2, 57, 3,  7, 7, 73, 4, 61, 9, 31, 8, 54, 5, 75, 1, 70, 6, 26, 
    0, 27, 6, 47, 4, 43, 1, 49, 8, 65, 5, 61, 3, 30, 9, 57, 2, 16, 7, 27, 
    5, 99, 0, 74, 9, 11, 7, 73, 8, 95, 1, 33, 3, 41, 4, 20, 2, 57, 6, 56, 
    0, 93, 9, 61, 5, 46, 7, 35, 1, 81, 3, 39, 6, 44, 2, 97, 4, 42, 8, 56, 
    1, 24, 0,  1, 4, 40, 7, 81, 8, 54, 3, 72, 5,  3, 2, 88, 6, 61, 9, 35
  };
  const int r242[] = {
    10, 10, // Number of jobs and machines
    7, 80, 5, 40, 2, 67, 4, 20, 8, 92, 9, 89, 0, 49, 6, 96, 1,  6, 3, 27, 
    6, 40, 8,  8, 3, 84, 9, 21, 1, 94, 4,  4, 7, 21, 5, 79, 2, 19, 0, 44, 
    6, 98, 4, 21, 0,  4, 1, 15, 2, 24, 7, 91, 9, 93, 3, 40, 8, 57, 5, 94, 
    9, 99, 0,  3, 4, 88, 3, 26, 6,  9, 1, 47, 7, 81, 5, 31, 8, 72, 2, 71, 
    9, 56, 8, 39, 1, 45, 0, 51, 3, 42, 2, 81, 5, 21, 4, 33, 7, 31, 6, 34, 
    8, 68, 4, 38, 7, 33, 2, 47, 0, 93, 6, 83, 1, 28, 3, 27, 5, 39, 9, 67, 
    5, 82, 4, 35, 9, 31, 2, 30, 3, 51, 0, 34, 7, 33, 8, 44, 6, 78, 1, 32, 
    3, 65, 1, 39, 7,  7, 9, 93, 6, 33, 2, 23, 0, 11, 5, 51, 4, 72, 8,  9, 
    3, 56, 7, 40, 4, 10, 2, 50, 6, 31, 5, 92, 1, 14, 0, 50, 8, 66, 9, 17, 
    7, 65, 6, 60, 4, 82, 1, 11, 5, 31, 2, 98, 3, 48, 9, 58, 0, 80, 8, 87
  };
  const int r243[] = {
    10, 10, // Number of jobs and machines
    9, 41, 0, 84, 1, 55, 3, 25, 4, 37, 2, 32, 6, 23, 5, 18, 8, 55, 7, 44, 
    0, 99, 4,  7, 1, 58, 9, 78, 2, 96, 8, 70, 6, 55, 7, 17, 3, 90, 5, 14, 
    8, 32, 6,  9, 5, 54, 4, 51, 2, 53, 7, 67, 9, 42, 0,  7, 1, 86, 3, 65, 
    5, 94, 7, 61, 4, 81, 0, 81, 8, 91, 2, 19, 1, 15, 3, 26, 6, 19, 9, 97, 
    3, 16, 5, 13, 2, 27, 6, 83, 1, 58, 7, 86, 0, 90, 8, 88, 4,  9, 9, 90, 
    6, 99, 4, 30, 0, 79, 5, 30, 9, 92, 8, 87, 3, 76, 7,  3, 1, 78, 2, 54, 
    3, 28, 6, 37, 1, 83, 0, 86, 9, 92, 7,  7, 4, 59, 5, 72, 2, 57, 8, 90, 
    0, 36, 6,  4, 2, 99, 7, 87, 9, 18, 3, 28, 5, 38, 8, 23, 1, 23, 4, 25, 
    9, 83, 2,  2, 1, 53, 0,  9, 6, 92, 4,  3, 3, 11, 7, 47, 8, 67, 5, 61, 
    4, 37, 3, 14, 1, 56, 6, 58, 2, 22, 5, 84, 9, 24, 8, 66, 7, 70, 0, 54
  };
  const int r244[] = {
    10, 10, // Number of jobs and machines
    9,  3, 0, 53, 7, 44, 1, 97, 2,  6, 6, 74, 3, 20, 4, 46, 8, 30, 5, 74, 
    1, 49, 3, 66, 7, 33, 9, 10, 8, 53, 4, 73, 6, 98, 2, 51, 5, 62, 0, 78, 
    2,  8, 1, 11, 9, 73, 5, 50, 3, 45, 7, 49, 4, 25, 6, 11, 0,  3, 8, 41, 
    9, 12, 1, 18, 5, 48, 4, 37, 6, 89, 8, 89, 2,  3, 7,  3, 0, 22, 3, 42, 
    2, 84, 7, 69, 9, 81, 8, 77, 5, 79, 6, 53, 3, 73, 4, 39, 0, 53, 1, 73, 
    6, 16, 8, 61, 9, 75, 0, 98, 5, 37, 4, 26, 7, 88, 3, 88, 2, 71, 1, 71, 
    7, 48, 2, 82, 4, 52, 1, 81, 8, 95, 3, 85, 0, 17, 6, 51, 5, 35, 9, 99, 
    9, 93, 8, 64, 3, 52, 4, 26, 0, 81, 7, 86, 1, 59, 6, 33, 5, 18, 2, 44, 
    1, 20, 6, 75, 8, 30, 4, 66, 5, 16, 0, 64, 3, 37, 9, 72, 2, 73, 7, 32, 
    1, 49, 6, 96, 0, 60, 7, 54, 4, 63, 8,  3, 9, 41, 2, 33, 5, 27, 3, 55
  };
  const int r245[] = {
    10, 10, // Number of jobs and machines
    7, 20, 0, 37, 8, 84, 3, 67, 4,  7, 6,  3, 1, 19, 5, 66, 2, 70, 9,  8, 
    6, 87, 9, 81, 0, 73, 1,  1, 8, 14, 3, 30, 2,  2, 5, 52, 4, 59, 7, 49, 
    4, 70, 3, 37, 5, 38, 6, 41, 2, 56, 9,  5, 1, 41, 7, 59, 8, 86, 0, 19, 
    5, 55, 8, 31, 0, 27, 3, 19, 6, 27, 2, 22, 7, 50, 4, 56, 9, 39, 1, 74, 
    3, 30, 1, 46, 6, 75, 7, 30, 0, 38, 8, 18, 9, 31, 5, 75, 2, 64, 4, 68, 
    9, 82, 0, 33, 7, 68, 8, 28, 6,  1, 3, 56, 2, 49, 1, 68, 5, 48, 4, 90, 
    6,  1, 5,  7, 7, 18, 4, 57, 9,  8, 1, 54, 2, 23, 0, 73, 8, 71, 3,  9, 
    6, 58, 7, 32, 3, 93, 1, 90, 9, 96, 5, 29, 0, 71, 8, 49, 2, 32, 4, 25, 
    3, 97, 4, 11, 8, 62, 7, 69, 1, 30, 5, 89, 2, 25, 9, 39, 0, 91, 6, 48, 
    8, 80, 1, 23, 3, 59, 6, 82, 5,  5, 9, 89, 7, 60, 2,  1, 4, 20, 0, 44
  };
  const int r246[] = {
    10, 10, // Number of jobs and machines
    4,  3, 3, 87, 2, 42, 0, 41, 7, 76, 5, 30, 6,  8, 8, 46, 1, 46, 9, 72, 
    1, 98, 7, 56, 9, 18, 5,  2, 4, 87, 3, 97, 2, 56, 8, 24, 6, 65, 0, 92, 
    7, 76, 4, 86, 2, 48, 6, 54, 9, 52, 1, 76, 3, 76, 8, 88, 5, 59, 0, 82, 
    4,  1, 1,  6, 2, 52, 7, 78, 5,  9, 0, 94, 8,  1, 9, 36, 6, 85, 3, 16, 
    0,  7, 7, 56, 4, 20, 2, 16, 6, 88, 3, 88, 1, 43, 9, 74, 8, 26, 5, 24, 
    8, 54, 7, 65, 1, 52, 5, 30, 3, 24, 0, 97, 6,  6, 4, 37, 9, 40, 2, 69, 
    9, 13, 7, 96, 0, 21, 5, 13, 8, 78, 2, 84, 4, 55, 3, 85, 6, 40, 1, 67, 
    3, 96, 5, 68, 0, 77, 2, 44, 6, 41, 9, 31, 7, 38, 8, 68, 4, 62, 1, 41, 
    1, 84, 5, 25, 4, 72, 7, 83, 9,  7, 2, 43, 0, 29, 8, 61, 6, 53, 3, 99, 
    8, 10, 3, 54, 7, 79, 6, 97, 5, 45, 9, 41, 2, 41, 0, 46, 4, 46, 1,  5
  };
  const int r247[] = {
    10, 10, // Number of jobs and machines
    8, 49, 1, 18, 6, 58, 5, 62, 3, 13, 9, 66, 0, 87, 2, 21, 7, 57, 4, 47, 
    2, 24, 1, 11, 3, 38, 7, 32, 4, 97, 5, 10, 9,  4, 8, 72, 6, 77, 0, 89, 
    8,  6, 1, 81, 5,  5, 3, 92, 0,  7, 6, 70, 2, 86, 4, 42, 7,  7, 9, 52, 
    0, 61, 3, 22, 6, 53, 1, 49, 9, 62, 7, 72, 4, 28, 2, 66, 8, 56, 5, 62, 
    8, 68, 3,  7, 7, 31, 0, 66, 6, 98, 1, 43, 9, 93, 2, 43, 5, 11, 4, 39, 
    9, 48, 1, 45, 0, 62, 7, 55, 3, 43, 6, 61, 2, 33, 8, 40, 5, 93, 4, 44, 
    4,  5, 6, 66, 1, 39, 5, 51, 0, 67, 2, 27, 8, 13, 9, 36, 7, 12, 3, 91, 
    8, 29, 6, 66, 9, 25, 7, 70, 3, 52, 4, 92, 1, 48, 2, 95, 0, 48, 5, 75, 
    9, 56, 6, 14, 3, 60, 5, 76, 8, 53, 4, 84, 7, 12, 2, 50, 1, 77, 0,  6, 
    8, 39, 6, 45, 7, 96, 0, 30, 5, 74, 1, 36, 9, 72, 4, 30, 2, 99, 3, 22
  };
  const int r248[] = {
    10, 10, // Number of jobs and machines
    1, 33, 2, 57, 5, 95, 6, 32, 3, 82, 9, 43, 4, 72, 0, 40, 8, 93, 7, 40, 
    9, 27, 8, 74, 5, 38, 0, 28, 3, 60, 6, 59, 7, 68, 4, 36, 2, 47, 1, 64, 
    3, 96, 7, 98, 6, 68, 1, 41, 2, 42, 0, 17, 5,  5, 8, 12, 4, 82, 9, 26, 
    1, 71, 5, 57, 9,  8, 8,  6, 3, 49, 4, 60, 0, 75, 2, 74, 7, 34, 6, 42, 
    6, 17, 1, 88, 4, 24, 9, 97, 0,  1, 7, 59, 3, 98, 2,  3, 5, 63, 8, 13, 
    6, 76, 7, 43, 1, 55, 9, 56, 8, 78, 0, 44, 4, 70, 3, 31, 2, 96, 5, 56, 
    3, 74, 5, 51, 2,  5, 0, 28, 7, 53, 1, 75, 9, 72, 4, 89, 6, 56, 8, 20, 
    1, 29, 3, 36, 0, 47, 9, 41, 8, 54, 4, 56, 6, 81, 2, 66, 7,  5, 5, 30, 
    7, 53, 9, 18, 8, 27, 0, 59, 3, 74, 1, 46, 5, 24, 4, 56, 6, 35, 2, 63, 
    9, 22, 7,  1, 2,  1, 5, 22, 0, 46, 4, 77, 8, 36, 3, 38, 6, 67, 1, 22
  };
  const int r249[] = {
    10, 10, // Number of jobs and machines
    9, 85, 6, 38, 1, 43, 7, 48, 5, 52, 0, 54, 4, 14, 2, 75, 8, 16, 3,  5, 
    1, 35, 4, 26, 7, 49, 3, 71, 0, 50, 6, 84, 5, 18, 8, 27, 9, 74, 2,  9, 
    3, 72, 1, 15, 0, 91, 4, 12, 2, 50, 8, 29, 7,  5, 5, 16, 9, 22, 6, 67, 
    4, 87, 6, 47, 0, 30, 9, 35, 3, 88, 1, 34, 7, 24, 5, 66, 8, 72, 2, 89, 
    6,  1, 5, 23, 0, 57, 1, 54, 4, 67, 9, 41, 8, 20, 7, 50, 3,  3, 2, 48, 
    3, 70, 6, 32, 5, 38, 9, 21, 1, 88, 8, 11, 7, 35, 2, 22, 4, 34, 0, 58, 
    9, 64, 5, 23, 6, 67, 7, 73, 3, 66, 0, 97, 1,  5, 4, 42, 8, 33, 2,  8, 
    1, 10, 3,  6, 6, 72, 9, 96, 4, 73, 2, 78, 7, 21, 5, 39, 0, 13, 8,  8, 
    8, 73, 7, 94, 9, 79, 0, 42, 1, 15, 3, 40, 6, 87, 2, 25, 4, 41, 5, 46, 
    9, 17, 8, 38, 6, 54, 3, 37, 5, 26, 7,  8, 4, 67, 1, 21, 2, 46, 0, 73
  };
  const int r250[] = {
    10, 10, // Number of jobs and machines
    5, 54, 6, 14, 0, 99, 2, 61, 4, 16, 8, 83, 9, 11, 7, 87, 1, 64, 3, 11, 
    0, 31, 3, 46, 2, 75, 7, 95, 8, 17, 6, 67, 9, 35, 4, 52, 1, 19, 5, 18, 
    7,  8, 5, 94, 0, 93, 1, 61, 8, 65, 6, 42, 3, 34, 4, 66, 9, 62, 2, 80, 
    4, 75, 7, 10, 9, 18, 1,  7, 6, 10, 2, 41, 5, 32, 8, 17, 0, 22, 3, 51, 
    5, 78, 8, 80, 9, 80, 3, 44, 4, 64, 1, 85, 7, 57, 6, 24, 0, 95, 2, 90, 
    4,  6, 9, 64, 8, 47, 6,  5, 1, 60, 0, 32, 2, 52, 3, 91, 7, 13, 5, 26, 
    6,  6, 2, 72, 4, 16, 1, 92, 0, 96, 7, 91, 9, 41, 8, 28, 3, 36, 5, 27, 
    6, 42, 8, 54, 9, 11, 7, 31, 4, 49, 1, 60, 5, 49, 2, 20, 0, 58, 3, 31, 
    0, 29, 5, 45, 4, 97, 8, 74, 3, 57, 2, 19, 9, 12, 6, 11, 7, 50, 1, 93, 
    2, 58, 9, 89, 7, 80, 8, 31, 4, 73, 0, 35, 5, 91, 3,  1, 1, 86, 6,  8
  };
  const int r251[] = {
    10, 10, // Number of jobs and machines
    5, 41, 2,  6, 0,  9, 6, 26, 9, 74, 8, 37, 7, 74, 1, 19, 3, 32, 4, 69, 
    4, 38, 8,  5, 6, 17, 3, 76, 2, 81, 1, 89, 9, 81, 5, 22, 0, 71, 7, 89, 
    4, 24, 5, 87, 1, 31, 6, 96, 8, 92, 0, 80, 7,  7, 9, 40, 2, 51, 3,  1, 
    9, 21, 6, 37, 4, 68, 2,  7, 3, 78, 5, 41, 7, 27, 1, 76, 0, 84, 8,  3, 
    9,  9, 5,  2, 6, 39, 1, 98, 7,  5, 0, 37, 4, 82, 3, 71, 8, 75, 2, 21, 
    2, 11, 5, 86, 8, 26, 7, 80, 9, 76, 3, 73, 0, 32, 6, 45, 4,  4, 1, 27, 
    7, 92, 1, 10, 6, 28, 8,  4, 4, 52, 0, 67, 2, 81, 3, 97, 5, 31, 9, 54, 
    7, 76, 6, 29, 5, 92, 1, 34, 4, 11, 3, 34, 8, 35, 0, 66, 9, 94, 2, 98, 
    3, 90, 5, 90, 8,  5, 9,  2, 1, 98, 0, 85, 4, 98, 6,  5, 7, 38, 2,  5, 
    8, 92, 4, 85, 3, 88, 0, 75, 5, 10, 9, 25, 1,  9, 7, 67, 6, 43, 2, 22
  };
  const int r252[] = {
    10, 10, // Number of jobs and machines
    2, 76, 5, 90, 0, 65, 8, 12, 7, 29, 6, 82, 4, 51, 9, 98, 1, 39, 3, 79, 
    1, 33, 3, 60, 5,  3, 9, 25, 8, 76, 6, 61, 0,  3, 4, 14, 2, 72, 7, 52, 
    7, 43, 9, 71, 2, 14, 0, 68, 1, 54, 8, 14, 4, 94, 6, 66, 3, 43, 5, 91, 
    2, 23, 7, 77, 0,  8, 9, 16, 8, 97, 1, 65, 5, 80, 4, 90, 6, 53, 3, 27, 
    4, 73, 5, 62, 3, 17, 8, 54, 6, 84, 7, 15, 0, 63, 1, 41, 9, 47, 2, 64, 
    4, 14, 5, 58, 0, 24, 6, 29, 7, 96, 3, 93, 8, 69, 1, 93, 2, 99, 9, 71, 
    5, 32, 2, 49, 3, 19, 4, 12, 7, 96, 6,  2, 0, 28, 9, 69, 8, 40, 1, 41, 
    7, 96, 9, 31, 0, 24, 6, 23, 2, 47, 5, 11, 4, 61, 1, 28, 3, 45, 8, 12, 
    9, 77, 6, 26, 0, 29, 4,  9, 5, 63, 2, 75, 7, 48, 1, 98, 8, 95, 3,  1, 
    4,  5, 3, 77, 5, 49, 6, 24, 9, 95, 7, 65, 0, 97, 8, 23, 1, 93, 2, 23
  };
  const int r253[] = {
    10, 10, // Number of jobs and machines
    8, 87, 7,  6, 5, 14, 3, 52, 4, 19, 6, 69, 1,  4, 9, 33, 0,  1, 2, 23, 
    7, 59, 5, 36, 8,  9, 0, 75, 3,  9, 4, 23, 6, 44, 9, 33, 2, 92, 1, 12, 
    1, 28, 7, 62, 4, 56, 3, 51, 0, 28, 6, 20, 5, 68, 9, 92, 8, 94, 2, 84, 
    9,  8, 1, 52, 3, 75, 6, 82, 7, 63, 4, 93, 0, 18, 5, 73, 8, 51, 2, 44, 
    6, 84, 0, 11, 7, 78, 4, 90, 2, 55, 9, 11, 5,  4, 3, 86, 8, 70, 1, 42, 
    4, 63, 2, 73, 0, 10, 9, 63, 6, 42, 3, 69, 1, 28, 7, 90, 5, 12, 8,  9, 
    5, 12, 7, 47, 6, 15, 2, 84, 3, 69, 8, 86, 9, 74, 0, 74, 1, 17, 4, 16, 
    8, 10, 0, 10, 3, 73, 4, 52, 5, 42, 1, 35, 2,  4, 7, 49, 9, 13, 6, 44, 
    8, 54, 1, 82, 9, 97, 6, 13, 3, 37, 7, 79, 2, 88, 0, 23, 4, 58, 5, 49, 
    0, 41, 5, 29, 3, 66, 4, 63, 6, 55, 2, 90, 9, 71, 8, 20, 1, 11, 7, 84
  };
  const int r254[] = {
    10, 10, // Number of jobs and machines
    5, 69, 2, 48, 0,  6, 3, 20, 7, 29, 8, 81, 6, 62, 9, 32, 1, 64, 4, 76, 
    6, 58, 2, 54, 3, 65, 1, 89, 0, 90, 5, 61, 9, 42, 7, 60, 4, 63, 8, 25, 
    9, 76, 0, 45, 4, 42, 7, 54, 8, 64, 5, 96, 2, 44, 6, 10, 3, 58, 1, 67, 
    3, 14, 6, 26, 9,  7, 5, 43, 2, 99, 1, 77, 8, 83, 0, 78, 4, 43, 7, 96, 
    4, 59, 0, 89, 2, 22, 1, 29, 3, 12, 6, 24, 8, 25, 9, 53, 5, 79, 7, 82, 
    0, 71, 4,  2, 6, 95, 1, 10, 5, 96, 9, 99, 8, 40, 2, 73, 7, 99, 3, 78, 
    4, 50, 8, 58, 0, 34, 6, 80, 2, 70, 5, 89, 9, 70, 3, 92, 7, 63, 1, 32, 
    1, 87, 6, 29, 8, 93, 2, 73, 7,  9, 9, 32, 5,  8, 3, 54, 0, 80, 4, 34, 
    0, 28, 7, 88, 2, 51, 4, 47, 6, 70, 1, 21, 5, 63, 8, 98, 9, 14, 3, 56, 
    1,  2, 9, 32, 3, 53, 5, 75, 7, 30, 6, 90, 0, 31, 2, 47, 4, 53, 8, 99
  };
  const int r255[] = {
    10, 10, // Number of jobs and machines
    0, 42, 1, 32, 8, 67, 3, 29, 5, 17, 7, 81, 9, 98, 2, 23, 4, 87, 6, 35, 
    4, 19, 3, 30, 6, 97, 8, 46, 7, 74, 9, 83, 5,  9, 2,  3, 0,  7, 1, 97, 
    2, 35, 9, 21, 3, 20, 6, 74, 0, 54, 1, 37, 7, 92, 5, 62, 8, 77, 4, 55, 
    2, 31, 1, 98, 8, 26, 5, 75, 6, 83, 4, 99, 3, 19, 7, 19, 9, 85, 0, 83, 
    0, 67, 9,  9, 7, 59, 1, 50, 8, 19, 6,  8, 4, 44, 5, 50, 2,  8, 3, 43, 
    4, 34, 2, 92, 6, 76, 1,  3, 5, 24, 9,  5, 7, 75, 8, 29, 3,  7, 0, 64, 
    8, 41, 2, 13, 1, 52, 7, 18, 9, 39, 5,  6, 0, 89, 4, 34, 6, 62, 3, 28, 
    9, 86, 4,  9, 0, 35, 7, 37, 5, 44, 6, 73, 2, 63, 8, 51, 1, 94, 3, 37, 
    0, 57, 7, 48, 8,  8, 2, 34, 5, 51, 6, 26, 9, 46, 4,  6, 1, 95, 3, 63, 
    0, 53, 1, 16, 4, 70, 5, 90, 8, 31, 3,  4, 9, 17, 7, 45, 2, 55, 6, 77
  };
  const int r256[] = {
    10, 10, // Number of jobs and machines
    1, 92, 0, 70, 9, 69, 5, 64, 3, 40, 4, 50, 2, 25, 8, 10, 6, 77, 7, 34, 
    2, 31, 3, 49, 4, 80, 1, 87, 7, 75, 6, 77, 5, 29, 8,  1, 9, 64, 0, 45, 
    2, 62, 5, 14, 9, 60, 4, 56, 1, 19, 8,  2, 0, 23, 3, 72, 6, 63, 7, 81, 
    3, 21, 2, 70, 1, 52, 8, 37, 5, 32, 6, 46, 9, 36, 7, 15, 4, 33, 0, 63, 
    1, 89, 7, 69, 5, 49, 4, 33, 3, 51, 2, 78, 6, 74, 9, 33, 8, 72, 0, 17, 
    2, 10, 1, 31, 7, 18, 3, 15, 9, 29, 0, 44, 4, 24, 6, 19, 8, 47, 5, 88, 
    9, 41, 2, 85, 1, 50, 4, 41, 8, 55, 3, 49, 7, 87, 5, 22, 0, 15, 6, 54, 
    4, 47, 9, 98, 7, 10, 3, 77, 2, 78, 1, 72, 0, 18, 6, 89, 5, 49, 8, 61, 
    3, 37, 2, 84, 5, 12, 6, 78, 4,  5, 7, 98, 8, 11, 1, 40, 9, 81, 0, 19, 
    2, 11, 0, 62, 1, 25, 6, 55, 7, 46, 4, 40, 8, 67, 9, 58, 5,  7, 3, 87
  };
  const int r257[] = {
    10, 10, // Number of jobs and machines
    5, 80, 6,  6, 9, 93, 7, 33, 2, 74, 4, 28, 0, 82, 8, 89, 3,  6, 1, 56, 
    2, 73, 8, 92, 6, 79, 7, 87, 9, 38, 3, 18, 0, 50, 5, 74, 1, 76, 4, 12, 
    4, 79, 2, 91, 7, 58, 6, 26, 9, 39, 8, 44, 5, 87, 1, 75, 3, 69, 0, 34, 
    9, 61, 3, 55, 4, 39, 2, 69, 6,  1, 5, 94, 0, 54, 8, 55, 1,  2, 7, 91, 
    9, 87, 7, 12, 6, 65, 2, 40, 5, 46, 3, 54, 0, 15, 1, 95, 4, 60, 8,  5, 
    7,  6, 6, 81, 4, 61, 2, 17, 8, 99, 9, 17, 5, 13, 0, 16, 1, 88, 3, 77, 
    7, 40, 1, 29, 0, 59, 2, 61, 8, 83, 9, 59, 6, 26, 3, 96, 4, 93, 5, 16, 
    2,  3, 8, 18, 0, 87, 3, 87, 6, 84, 9, 71, 7, 97, 4, 96, 5, 65, 1,  1, 
    4, 21, 2, 95, 1, 29, 0, 27, 7, 23, 5, 89, 8,  8, 6, 63, 9, 39, 3, 78, 
    9, 34, 3,  5, 5, 29, 4, 39, 7, 19, 1, 37, 8, 96, 2, 97, 6,  9, 0, 56
  };
  const int r258[] = {
    10, 10, // Number of jobs and machines
    9, 11, 8, 37, 4, 52, 2, 72, 5, 94, 0, 34, 7, 97, 6, 48, 3,  1, 1, 33, 
    3, 50, 4, 98, 9,  2, 0, 73, 8, 33, 7, 38, 6, 13, 5, 89, 1, 68, 2, 56, 
    7, 57, 0, 92, 1, 88, 2, 22, 4, 18, 5, 46, 8, 80, 3,  9, 6, 97, 9, 69, 
    5, 13, 8, 83, 2, 37, 1, 30, 9, 98, 3, 27, 4, 93, 6,  5, 0, 96, 7, 40, 
    5, 69, 6, 73, 2, 21, 0, 34, 7, 14, 4, 10, 3, 85, 1, 65, 8, 70, 9, 38, 
    1, 62, 4, 74, 3, 35, 8, 94, 6, 11, 2, 62, 0, 55, 5, 78, 7, 16, 9, 11, 
    8,  4, 9, 76, 2, 89, 4, 55, 5, 72, 7, 29, 1, 40, 3,  8, 6, 23, 0, 43, 
    4, 60, 6, 97, 1, 24, 8, 78, 3, 95, 7, 98, 0, 21, 9, 79, 5, 55, 2, 67, 
    8, 68, 4, 17, 0,  1, 6, 82, 1, 21, 2, 28, 3, 54, 9, 39, 7, 51, 5, 27, 
    1, 82, 0, 81, 7, 50, 2, 55, 4, 97, 5, 91, 3, 70, 6, 74, 8, 83, 9, 97
  };
  const int r259[] = {
    10, 10, // Number of jobs and machines
    3, 65, 6,  3, 4, 25, 1, 76, 0, 61, 8, 70, 2,  9, 5,  8, 9, 25, 7, 52, 
    3, 76, 7, 65, 2, 37, 4, 78, 9, 38, 6, 80, 0, 31, 1, 34, 8, 23, 5, 56, 
    7, 46, 8, 52, 9, 44, 2, 92, 4, 60, 5, 37, 1, 63, 3, 68, 0,  1, 6, 41, 
    0,  6, 2, 21, 1, 92, 7, 57, 6, 33, 8, 79, 4, 63, 3, 12, 5,  8, 9, 15, 
    5, 26, 4, 36, 6, 18, 0, 47, 7, 73, 8, 95, 1, 53, 2, 86, 3,  6, 9, 42, 
    9,  2, 1, 25, 7, 34, 4, 66, 6, 34, 5, 44, 3, 13, 8, 14, 2, 86, 0, 56, 
    5, 73, 7, 59, 3, 17, 2, 90, 9, 68, 1, 90, 4, 96, 0, 48, 6, 27, 8,  3, 
    0,  9, 7, 37, 2, 56, 4,  1, 3, 87, 1, 46, 8, 34, 6, 90, 9, 85, 5, 21, 
    2,  6, 7, 66, 8, 41, 5, 44, 4, 18, 3, 97, 0,  3, 1, 33, 6,  3, 9, 64, 
    6, 69, 0, 95, 3, 51, 1, 55, 9, 42, 4,  6, 5, 28, 2, 71, 8,  2, 7, 12
  };
  const int r260[] = {
    10, 10, // Number of jobs and machines
    3, 89, 9, 64, 7, 56, 6, 71, 4, 15, 1, 73, 0, 43, 5, 65, 2, 65, 8, 20, 
    6, 21, 3, 23, 2, 22, 1, 41, 8, 10, 5, 76, 9, 81, 0, 24, 7, 81, 4, 74, 
    9,  6, 7, 49, 3, 15, 2, 70, 0,  4, 8, 21, 6, 14, 1, 94, 4, 17, 5, 88, 
    7, 19, 9, 15, 3, 93, 5,  4, 6, 50, 2, 87, 8, 89, 4, 11, 1, 64, 0, 99, 
    4, 82, 0, 83, 6, 33, 8, 33, 9, 14, 7, 16, 3, 44, 1, 67, 5, 75, 2, 17, 
    8, 28, 4, 82, 7, 33, 3, 39, 9, 29, 6, 68, 5, 88, 1, 46, 0,  8, 2, 91, 
    2, 19, 1, 87, 9, 23, 4, 56, 3, 42, 8, 86, 0, 55, 7, 43, 5, 26, 6, 20, 
    9, 67, 7, 77, 5, 48, 8, 59, 4, 90, 0, 86, 3, 50, 6, 89, 2, 79, 1, 37, 
    7, 78, 2, 34, 3, 41, 4, 74, 6, 42, 8,  7, 9,  7, 0, 31, 5, 55, 1, 16, 
    5, 20, 3, 23, 1, 73, 2, 36, 6, 61, 0, 82, 9, 26, 4, 16, 8, 42, 7,  6
  };
  const int r261[] = {
    10, 10, // Number of jobs and machines
    9, 35, 5, 13, 6, 59, 2, 67, 1, 83, 4, 36, 0, 84, 7, 87, 3, 48, 8, 42, 
    7, 19, 4,  2, 2, 17, 5, 11, 9, 28, 1, 21, 6, 49, 0, 70, 3, 89, 8, 47, 
    6, 12, 1,  5, 5, 46, 2, 60, 3, 16, 0, 38, 8, 90, 7, 34, 4,  6, 9, 52, 
    3, 69, 8, 26, 6, 71, 5,  1, 4, 53, 1, 35, 7, 10, 2, 34, 0, 43, 9, 56, 
    3, 51, 1, 94, 4, 31, 8, 82, 5, 82, 2, 75, 9, 67, 6, 81, 7, 36, 0, 15, 
    9, 95, 5, 81, 6, 47, 4, 85, 2, 16, 8, 44, 7, 34, 3,  3, 1,  2, 0, 41, 
    3, 18, 1,  1, 9, 30, 6, 95, 7, 36, 0,  8, 5, 74, 2, 97, 8, 35, 4, 39, 
    4, 20, 0, 14, 2, 42, 6, 87, 1, 28, 9, 55, 7, 93, 5, 42, 3,  3, 8, 85, 
    0, 81, 1, 32, 8, 86, 5,  3, 2, 35, 3, 60, 4, 38, 6,  5, 7, 24, 9, 29, 
    8, 63, 0, 94, 9, 16, 6, 89, 2, 89, 1, 93, 3, 10, 7, 94, 4,  2, 5, 52
  };
  const int r262[] = {
    10, 10, // Number of jobs and machines
    3, 98, 8, 40, 6, 15, 9, 49, 1, 23, 5, 13, 4, 45, 2, 29, 0, 56, 7, 70, 
    7, 15, 2, 96, 0, 95, 3, 74, 6,  1, 8, 82, 5, 99, 4, 60, 9, 24, 1, 52, 
    5, 36, 3, 85, 9, 63, 0,  5, 6, 13, 8, 76, 4, 60, 2, 55, 7, 98, 1, 60, 
    5, 66, 7, 47, 0, 86, 6, 84, 8, 45, 2, 58, 4, 35, 1, 59, 9, 95, 3, 12, 
    6, 99, 7,  5, 2,  3, 1,  5, 3, 91, 9, 30, 4, 77, 0, 28, 5, 24, 8, 42, 
    4, 67, 7, 74, 9, 81, 5, 43, 6, 79, 3, 50, 8, 92, 0, 99, 1, 87, 2, 83, 
    5, 55, 1, 83, 0, 72, 7,  8, 8, 63, 4, 64, 6, 46, 2, 85, 9, 48, 3, 39, 
    7, 32, 5, 42, 0, 94, 4, 47, 9, 51, 6, 68, 3, 23, 8, 74, 2, 16, 1, 30, 
    3, 22, 8, 48, 2, 55, 1, 35, 4, 47, 7, 16, 0, 87, 5, 63, 6, 83, 9,  8, 
    0, 97, 4, 70, 2,  7, 6, 65, 1, 54, 7, 51, 9, 55, 8, 34, 3, 28, 5, 54
  };
  const int r263[] = {
    10, 10, // Number of jobs and machines
    1, 48, 6, 48, 9, 71, 5, 91, 4, 73, 3, 45, 8, 38, 7, 11, 0, 93, 2, 48, 
    1, 17, 7, 80, 9,  5, 3, 31, 2, 82, 5, 52, 4, 38, 6, 28, 8, 73, 0,  2, 
    4, 74, 0, 91, 1, 82, 3, 27, 2, 83, 7, 46, 8, 40, 9, 29, 6, 38, 5, 23, 
    6, 28, 0,  4, 4, 13, 9, 30, 3, 15, 8, 85, 5,  7, 1, 11, 2, 56, 7, 81, 
    4, 20, 7, 93, 9, 73, 8, 13, 1,  9, 5, 11, 6, 26, 0, 69, 2, 98, 3, 92, 
    7,  8, 8,  4, 0, 93, 4, 79, 2, 59, 5,  3, 9,  2, 3, 17, 6, 67, 1, 68, 
    9, 22, 3, 50, 1, 62, 0, 57, 5, 66, 2, 21, 4, 55, 7, 78, 6, 48, 8, 62, 
    1,  2, 0, 74, 5,  7, 4,  5, 7, 62, 3, 85, 8, 21, 6, 49, 2, 87, 9, 21, 
    3, 30, 5,  1, 6, 69, 8, 57, 2, 78, 1, 36, 9, 14, 0, 37, 4, 34, 7, 51, 
    8, 26, 3, 48, 5, 21, 7, 93, 4, 60, 6, 69, 0, 69, 9, 47, 1, 72, 2, 89
  };
  const int r264[] = {
    10, 10, // Number of jobs and machines
    7, 47, 6, 93, 3,  6, 5, 45, 1, 87, 2, 91, 8, 15, 9, 51, 4, 68, 0, 34, 
    5, 40, 1, 26, 2, 21, 8, 83, 0, 33, 3, 72, 6, 23, 9,  3, 4, 49, 7, 64, 
    8, 54, 1, 15, 5, 66, 7, 25, 2, 51, 3, 31, 6, 95, 9, 98, 0, 82, 4, 74, 
    4, 42, 8, 27, 7, 11, 9,  2, 0, 80, 3, 82, 6, 90, 1,  8, 5, 40, 2, 16, 
    0,  5, 4, 89, 7, 71, 1, 33, 8, 91, 2, 84, 3, 24, 5, 19, 6, 51, 9, 23, 
    4, 98, 1, 86, 2, 55, 5, 96, 9, 10, 0, 93, 7, 87, 8, 23, 6, 41, 3, 60, 
    9, 90, 1,  5, 5, 47, 0, 63, 8, 66, 3, 16, 4, 71, 6, 86, 2, 80, 7, 43, 
    7, 35, 0, 73, 4,  5, 9, 81, 1, 12, 2, 17, 6, 78, 5, 72, 8, 28, 3, 18, 
    8, 20, 1, 74, 3, 39, 5, 67, 7, 61, 6, 80, 2, 93, 9, 71, 4, 25, 0, 40, 
    0, 67, 8, 55, 7, 71, 5, 31, 9, 52, 6, 54, 2, 78, 1, 37, 3, 86, 4, 46
  };
  const int r265[] = {
    10, 10, // Number of jobs and machines
    3, 45, 2, 28, 7, 86, 5, 27, 9, 15, 8, 87, 0, 65, 1, 58, 6, 66, 4, 79, 
    2, 45, 4, 24, 0, 75, 1, 78, 8, 68, 5, 52, 9, 32, 7,  3, 3, 27, 6, 54, 
    2, 28, 5,  2, 1,  6, 6, 38, 4, 96, 9,  8, 8, 85, 0, 42, 3, 83, 7, 79, 
    5, 16, 8, 56, 0, 92, 1, 77, 6, 63, 4, 98, 7,  7, 3, 70, 9, 13, 2, 52, 
    4, 56, 7, 83, 6, 96, 2, 51, 3, 48, 5, 71, 1, 66, 8, 78, 0,  5, 9, 68, 
    2, 43, 0, 50, 9, 53, 5,  7, 4, 73, 3, 79, 1, 84, 7, 61, 6, 77, 8, 46, 
    0, 56, 9, 22, 6,  8, 5, 15, 2,  5, 4, 93, 1, 10, 8, 44, 7, 64, 3, 11, 
    6, 73, 8, 95, 7, 86, 3, 10, 4, 73, 9, 36, 0, 21, 5, 26, 1, 45, 2,  2, 
    0, 74, 2, 14, 7, 15, 5, 35, 8, 78, 1, 56, 3, 66, 9, 37, 6, 36, 4,  6, 
    0, 91, 5, 22, 6, 97, 2,  9, 8, 77, 3, 64, 4, 97, 7, 15, 1, 65, 9,  4
  };
  const int r266[] = {
    10, 10, // Number of jobs and machines
    0, 72, 5, 92, 1, 25, 8, 49, 9, 75, 4, 80, 3, 99, 2, 46, 6, 18, 7, 54, 
    7, 89, 2, 47, 4, 44, 8, 50, 0, 50, 5, 88, 6, 90, 3, 32, 9, 76, 1, 58, 
    0, 19, 5, 96, 1, 75, 2, 32, 4, 97, 9, 90, 7, 45, 8, 11, 6,  6, 3, 45, 
    1, 42, 7,  4, 5,  2, 6, 74, 2, 80, 4, 76, 8, 38, 3, 87, 0, 29, 9, 54, 
    2,  3, 8, 26, 6,  1, 4, 56, 9, 69, 7, 85, 5, 98, 3, 74, 1, 19, 0,  8, 
    0, 83, 8,  8, 4, 75, 3, 52, 7, 85, 5, 83, 2,  7, 6, 77, 9, 48, 1, 36, 
    4, 79, 7, 25, 5, 77, 1, 56, 2, 54, 9, 59, 6, 48, 8, 84, 0, 25, 3, 38, 
    3, 78, 6,  6, 8, 97, 9, 98, 4, 40, 1, 11, 7, 16, 5,  1, 0, 17, 2, 21, 
    5, 23, 1, 18, 7, 97, 9, 79, 2, 85, 3,  4, 0, 67, 6, 59, 8, 92, 4, 65, 
    7, 78, 4, 68, 3, 71, 2, 62, 8, 75, 9, 94, 6, 22, 0, 25, 1, 59, 5, 59
  };
  const int r267[] = {
    10, 10, // Number of jobs and machines
    9, 43, 0, 85, 3, 46, 2, 19, 5, 73, 1, 53, 6, 96, 4, 67, 8, 79, 7, 24, 
    6, 36, 2, 91, 4, 14, 3, 22, 9, 88, 1, 91, 8, 62, 0, 43, 7, 23, 5,  3, 
    6, 56, 3, 58, 8, 84, 0, 26, 4, 56, 5, 65, 2, 78, 1, 63, 7, 41, 9, 26, 
    8, 69, 3, 46, 0, 44, 4,  2, 7, 65, 1, 98, 2, 76, 5, 81, 9, 76, 6, 17, 
    2, 61, 1, 92, 6, 66, 3, 11, 0, 94, 7, 60, 8, 39, 4, 13, 9, 99, 5, 61, 
    6, 96, 4, 45, 3, 51, 0, 75, 8,  1, 2, 32, 7, 41, 9, 75, 5, 64, 1, 16, 
    5, 99, 3, 85, 0, 19, 7, 61, 9, 41, 4, 49, 8, 34, 2, 16, 1, 82, 6, 52, 
    7,  9, 6, 28, 5, 78, 0, 75, 4, 36, 3, 16, 9, 64, 8, 71, 2, 78, 1, 78, 
    8, 81, 6, 30, 5, 68, 3, 32, 1, 54, 2, 37, 4, 43, 9, 81, 0, 56, 7, 61, 
    3, 40, 9, 97, 8, 59, 5, 56, 2, 23, 6, 38, 1, 77, 4, 11, 7, 12, 0, 35
  };
  const int r268[] = {
    10, 10, // Number of jobs and machines
    7, 78, 1, 87, 8, 72, 4, 11, 3, 81, 6, 10, 5, 59, 2, 33, 0, 22, 9, 65, 
    5,  3, 6, 95, 0, 13, 8, 99, 7,  3, 2, 33, 4, 83, 1, 60, 9, 31, 3,  3, 
    5,  3, 3, 99, 1, 98, 6, 41, 4, 81, 2, 80, 9, 58, 8, 22, 0, 41, 7, 71, 
    5, 21, 4, 79, 7, 20, 0, 79, 3, 54, 1, 68, 9, 90, 8,  9, 2, 74, 6,  1, 
    8, 70, 0, 70, 4, 17, 9, 64, 2, 24, 6, 98, 5, 39, 7, 40, 1, 26, 3, 97, 
    1, 24, 5, 67, 2,  1, 0, 65, 4, 81, 8, 97, 3,  7, 9, 86, 6, 42, 7, 38, 
    1, 79, 7, 31, 8, 31, 5, 85, 6, 77, 4,  6, 0,  6, 3, 81, 2, 39, 9, 74, 
    9, 33, 5, 59, 0, 86, 4, 38, 8, 80, 2, 29, 6, 13, 3, 92, 7, 61, 1, 49, 
    0, 79, 3, 98, 2, 92, 7, 49, 4, 68, 5, 58, 9, 47, 6, 83, 1, 12, 8, 96, 
    5, 51, 2, 63, 7, 50, 9, 30, 1, 61, 6, 73, 3, 56, 0, 69, 4, 18, 8,  5
  };
  const int r269[] = {
    10, 10, // Number of jobs and machines
    1, 45, 9,  1, 4, 83, 6, 47, 0, 28, 5, 29, 2,  5, 8, 33, 3, 32, 7, 39, 
    8, 69, 2, 88, 9, 58, 7, 80, 6, 83, 5, 99, 3, 50, 1, 27, 0, 85, 4, 26, 
    5, 97, 4, 89, 1, 86, 2, 98, 3, 64, 7, 26, 9, 54, 0, 43, 8, 43, 6, 47, 
    6, 42, 7, 34, 9, 94, 4, 58, 2,  7, 5, 14, 3,  6, 0, 70, 8, 97, 1, 70, 
    9, 75, 1, 76, 7, 89, 3, 38, 8, 98, 2, 33, 0, 31, 5, 27, 6, 67, 4, 97, 
    2, 65, 6, 46, 7,  6, 5, 78, 3, 61, 0, 62, 9, 61, 8, 52, 4, 71, 1, 45, 
    8, 95, 6, 61, 5,  3, 0, 55, 2, 69, 9, 85, 4, 52, 3, 62, 1, 26, 7, 52, 
    8, 71, 5,  8, 9, 91, 6, 56, 7, 20, 3, 34, 4, 24, 0, 68, 2,  4, 1, 41, 
    7, 90, 2, 39, 5, 89, 9, 93, 4, 95, 8, 57, 6, 58, 3, 23, 1, 59, 0, 62, 
    7,  5, 5, 92, 9, 42, 8, 69, 6, 90, 4, 31, 2, 67, 1, 97, 3, 11, 0, 27
  };
  const int r270[] = {
    10, 10, // Number of jobs and machines
    0, 73, 7, 26, 1, 16, 6, 74, 2, 61, 5, 84, 8, 38, 9, 17, 3, 28, 4, 38, 
    8, 40, 6, 28, 2, 48, 9, 80, 3, 30, 1, 82, 7, 60, 0, 97, 4, 21, 5, 65, 
    5, 54, 2, 80, 1, 59, 6, 64, 3, 36, 4, 44, 8, 76, 7, 11, 9, 96, 0, 21, 
    6, 44, 0, 86, 7, 28, 1, 91, 3,  2, 9, 35, 2, 47, 8,  1, 4, 96, 5,  4, 
    5, 68, 0, 25, 9, 97, 1, 74, 6, 93, 8, 94, 4, 10, 7, 54, 2, 28, 3, 62, 
    1, 93, 6, 22, 7,  9, 9, 56, 8,  5, 3, 31, 4, 66, 0, 68, 2,  4, 5, 79, 
    0,  5, 1, 15, 2, 28, 6, 92, 9, 56, 7, 56, 4,  9, 5, 55, 8, 37, 3, 81, 
    9, 41, 1, 26, 7, 56, 0,  4, 4, 21, 3, 40, 5, 54, 6, 70, 8, 90, 2, 45, 
    0, 54, 3, 51, 8, 24, 9, 72, 4, 70, 1, 29, 5, 67, 6, 92, 2, 65, 7, 55, 
    3, 55, 4, 75, 9, 88, 2, 14, 1, 63, 0, 85, 6, 40, 5, 20, 8, 26, 7,  3
  };
  const int r271[] = {
    10, 10, // Number of jobs and machines
    4, 32, 5, 81, 6, 81, 2, 95, 3, 67, 1, 49, 8, 56, 0, 14, 9, 99, 7,  9, 
    6, 48, 9, 23, 4, 10, 8, 47, 1, 63, 2, 23, 0, 37, 5,  3, 3, 31, 7, 73, 
    1, 47, 9, 37, 5, 41, 2, 16, 6, 55, 3, 50, 0, 32, 4, 42, 8, 18, 7, 58, 
    4, 58, 1, 66, 3, 15, 5, 47, 7, 75, 0, 22, 2, 59, 8, 15, 6, 40, 9, 11, 
    1, 64, 8, 84, 9, 81, 2, 56, 4, 63, 7, 12, 0, 42, 5, 28, 3, 18, 6, 50, 
    2, 68, 9, 72, 8, 43, 3, 39, 7, 92, 6, 59, 0, 43, 4, 42, 5,  7, 1,  3, 
    5, 55, 6, 87, 1, 17, 8, 13, 0,  9, 9, 52, 2, 44, 3, 49, 7,  7, 4, 35, 
    2, 18, 8, 61, 5, 32, 7, 80, 6, 20, 3, 24, 0, 91, 4, 28, 1, 15, 9, 48, 
    2, 60, 7, 65, 1, 90, 9, 92, 4, 21, 0, 78, 8, 97, 3,  6, 5, 67, 6, 29, 
    6, 69, 8, 46, 5, 91, 3, 14, 2, 69, 7, 93, 9, 13, 1, 35, 0, 91, 4, 89
  };
  const int r272[] = {
    10, 10, // Number of jobs and machines
    5, 79, 0, 72, 4, 45, 6, 57, 1, 70, 3, 35, 2, 81, 7, 37, 8, 71, 9, 12, 
    6, 85, 7, 15, 0, 77, 8, 59, 3, 21, 2, 80, 1,  9, 9, 58, 4, 18, 5, 47, 
    3, 49, 7,  1, 8, 41, 6, 43, 0, 32, 5, 82, 1, 68, 2, 64, 4, 66, 9,  2, 
    5,  2, 6, 65, 2, 76, 3, 49, 1, 10, 4, 39, 9, 87, 8, 27, 7, 74, 0, 17, 
    5, 83, 9, 96, 6,  8, 7, 25, 8, 90, 2, 87, 0, 52, 3, 66, 1, 38, 4, 25, 
    8, 23, 5, 65, 9,  1, 3, 78, 2, 31, 6, 65, 7, 12, 4, 70, 1, 87, 0, 94, 
    8, 17, 6, 24, 0, 31, 9, 27, 7,  1, 1, 94, 4, 25, 3, 17, 2, 53, 5, 36, 
    3, 51, 6, 48, 7, 10, 0, 87, 4, 38, 9, 27, 5, 34, 1, 93, 8, 13, 2, 22, 
    0, 72, 6, 99, 1, 64, 8,  7, 5, 60, 7, 77, 2, 92, 4,  2, 9, 44, 3, 83, 
    2, 45, 0, 14, 3, 29, 1, 40, 8, 16, 7, 19, 9,  9, 4, 50, 5, 52, 6, 52
  };
  const int r273[] = {
    10, 10, // Number of jobs and machines
    3, 94, 5, 94, 7, 64, 6, 92, 2, 15, 9, 29, 8, 32, 0, 41, 4, 93, 1, 64, 
    2, 28, 9, 67, 0, 22, 8, 16, 4, 43, 6, 20, 7, 14, 3,  3, 1, 30, 5, 70, 
    3, 33, 5, 92, 9, 43, 7, 39, 6, 67, 4, 87, 2, 59, 0, 55, 1, 71, 8, 71, 
    7, 20, 6, 89, 0, 88, 1, 68, 9,  9, 3,  2, 2, 21, 8,  4, 4, 93, 5, 12, 
    4,  8, 9, 54, 3,  4, 2, 48, 7,  3, 8, 14, 1, 40, 5, 31, 6, 69, 0, 79, 
    8, 18, 0, 52, 5, 39, 1, 71, 3, 17, 9, 36, 2, 26, 7, 48, 6, 14, 4, 13, 
    1, 20, 3, 93, 9, 33, 7,  5, 6, 69, 8, 20, 4, 26, 5, 19, 2, 51, 0, 34, 
    9, 71, 4, 38, 2, 45, 0, 60, 1, 65, 8, 24, 6, 27, 5, 51, 7, 46, 3,  5, 
    0, 25, 5, 52, 1, 86, 3, 46, 7, 20, 9, 10, 8, 36, 4, 12, 2, 17, 6, 26, 
    1, 54, 5, 38, 6, 79, 0, 64, 2, 80, 9, 72, 3, 49, 4, 46, 7,  7, 8, 16
  };
  const int r274[] = {
    10, 10, // Number of jobs and machines
    0, 63, 1, 19, 3,  5, 6, 58, 4, 56, 8, 28, 7, 20, 9, 34, 5,  2, 2, 32, 
    5,  4, 2,  5, 1, 14, 4, 89, 0, 87, 6, 77, 7, 37, 9, 58, 8, 23, 3, 49, 
    0, 42, 9, 37, 8, 29, 4, 39, 6, 78, 5,  7, 3, 34, 7, 88, 2, 49, 1, 42, 
    9, 22, 8, 91, 4, 64, 2, 59, 5, 85, 3, 92, 1, 91, 6, 58, 0, 59, 7, 67, 
    1, 88, 3, 37, 0, 71, 2, 33, 8, 61, 4, 54, 9, 88, 6, 50, 7, 44, 5, 32, 
    8, 95, 2,  8, 6, 95, 5, 48, 9, 83, 1, 88, 3, 99, 7, 13, 4, 82, 0, 53, 
    8, 52, 6, 52, 0, 20, 7, 23, 1,  7, 9, 42, 3,  9, 2, 14, 5, 98, 4, 43, 
    5, 24, 9, 32, 7, 94, 3, 43, 2, 90, 0, 14, 6, 85, 8, 96, 4, 83, 1, 42, 
    8, 46, 1, 58, 4, 20, 0, 49, 3, 80, 6, 39, 9, 44, 2, 93, 7, 45, 5, 91, 
    1, 73, 2, 17, 8, 91, 3, 21, 5, 63, 7, 56, 4, 32, 9, 25, 0, 41, 6, 20
  };
  const int r275[] = {
    10, 10, // Number of jobs and machines
    0, 23, 7, 70, 4, 88, 3, 53, 1, 36, 5, 32, 6, 79, 8, 82, 2, 57, 9, 15, 
    9, 19, 7, 70, 1, 43, 2, 35, 0, 47, 6,  6, 8, 74, 4, 62, 5, 74, 3, 87, 
    8, 19, 0,  9, 3, 10, 7, 48, 6, 81, 5, 42, 4, 41, 9, 85, 1, 90, 2, 28, 
    1, 40, 8, 94, 6, 97, 2, 80, 3, 76, 7, 94, 4, 57, 5, 37, 0, 27, 9, 30, 
    8, 63, 6, 98, 3, 62, 0, 83, 5, 22, 7, 70, 9, 11, 4, 16, 1, 54, 2, 98, 
    0, 78, 9, 48, 7, 34, 5, 80, 6, 26, 8, 21, 4, 43, 2, 74, 1, 93, 3, 72, 
    9, 95, 4, 91, 7, 43, 1, 51, 3,  1, 8, 65, 2, 92, 6, 38, 5, 83, 0, 87, 
    0, 34, 3, 53, 6,  1, 9, 89, 2, 64, 7, 58, 5, 35, 8, 42, 4, 12, 1, 98, 
    0, 14, 3, 41, 2,  9, 5, 74, 1, 95, 6,  1, 7,  2, 4,  1, 8, 24, 9, 95, 
    9, 70, 3, 56, 8, 97, 4, 23, 0, 12, 5, 86, 7, 42, 6, 41, 2, 14, 1, 19
  };
  const int r276[] = {
    10, 10, // Number of jobs and machines
    1, 64, 2, 54, 0, 45, 7, 31, 4, 98, 5, 58, 8, 33, 6, 43, 3, 19, 9, 12, 
    8, 44, 3,  4, 6, 67, 2, 51, 1, 86, 9,  8, 5,  4, 0, 50, 7, 23, 4, 87, 
    2, 28, 3,  1, 9, 73, 7, 60, 5, 94, 1, 45, 0, 89, 6, 74, 8, 34, 4, 93, 
    1, 47, 7, 72, 6, 27, 4,  6, 3, 86, 5,  1, 8, 45, 9, 62, 2, 52, 0, 31, 
    4,  9, 7, 26, 1, 53, 9, 71, 6,  1, 2, 92, 0, 87, 5, 66, 8, 51, 3, 21, 
    0, 93, 9, 14, 1, 41, 5,  4, 7, 79, 6, 15, 4, 80, 3, 93, 2, 26, 8, 71, 
    9, 88, 6, 95, 3, 14, 8, 79, 2, 40, 5, 43, 7, 29, 4, 86, 0, 36, 1, 45, 
    6, 27, 4, 31, 1, 68, 5,  5, 9, 17, 0, 34, 8,  4, 3, 59, 7, 56, 2, 29, 
    8, 37, 9, 78, 1, 22, 7, 81, 2, 17, 0, 75, 6, 71, 4, 28, 5, 67, 3, 71, 
    9,  6, 1,  7, 2, 98, 8, 14, 3, 32, 0,  2, 7, 68, 6, 18, 4, 60, 5, 69
  };
  const int r277[] = {
    10, 10, // Number of jobs and machines
    3,  4, 4, 27, 9, 52, 5,  7, 1, 34, 0, 67, 7, 36, 8, 69, 6, 88, 2, 96, 
    5, 53, 4,  4, 6, 87, 1, 25, 7, 33, 0, 72, 9, 22, 2, 68, 3, 22, 8, 73, 
    6, 38, 8, 57, 4, 29, 5, 15, 7, 70, 0, 31, 2, 48, 3, 74, 9, 22, 1, 12, 
    4, 72, 1, 65, 0, 52, 6, 23, 7,  3, 2, 95, 8, 16, 3, 89, 9, 36, 5, 61, 
    9, 83, 4, 16, 7,  5, 5,  2, 0, 83, 1, 59, 2, 77, 6, 28, 3, 24, 8, 32, 
    4, 41, 6, 37, 1, 79, 9, 79, 0, 55, 3, 16, 2, 53, 5, 57, 7, 34, 8, 40, 
    3, 89, 1, 78, 8,  9, 5, 49, 0, 89, 7, 34, 6,  1, 2, 93, 4, 70, 9, 75, 
    9, 51, 4,  7, 7, 58, 6, 10, 0,  3, 2,  7, 8, 36, 1, 75, 3, 35, 5, 86, 
    2, 10, 3, 66, 4, 41, 7, 15, 8, 69, 9, 26, 5, 23, 0, 17, 6, 36, 1, 91, 
    4, 11, 1, 91, 6, 48, 9, 28, 7, 48, 3, 27, 8, 67, 5, 88, 2, 90, 0, 21
  };
  const int r278[] = {
    10, 10, // Number of jobs and machines
    9, 46, 7, 79, 3, 78, 5, 53, 1, 70, 6, 58, 2, 62, 0, 49, 4, 66, 8, 80, 
    6, 72, 1, 16, 9, 42, 8,  8, 4, 78, 2, 13, 7, 99, 3, 81, 0,  6, 5,  8, 
    1, 88, 5, 43, 3, 63, 9, 46, 8, 47, 6, 57, 4,  2, 7, 11, 0, 51, 2, 79, 
    1,  5, 9, 50, 8, 55, 4, 15, 3, 13, 0, 94, 7, 64, 5, 66, 2, 79, 6, 63, 
    2, 41, 3, 39, 9, 79, 8, 27, 4, 36, 7, 19, 6, 83, 1, 46, 5, 25, 0, 49, 
    8, 49, 7, 66, 1, 17, 2,  2, 3, 79, 0, 56, 5, 44, 4, 32, 9, 53, 6, 83, 
    7, 72, 9, 37, 2, 76, 4, 95, 8, 63, 0, 37, 6, 77, 5, 64, 1, 19, 3, 44, 
    1, 36, 3, 83, 5, 47, 8, 21, 2, 52, 6, 32, 0, 57, 7,  1, 4, 18, 9, 28, 
    1,  2, 6, 19, 0,  3, 4, 35, 7, 14, 3, 48, 8, 54, 5, 69, 9, 15, 2, 45, 
    5,  4, 6, 23, 4, 64, 2, 27, 1, 52, 3, 89, 8, 40, 9, 59, 7, 52, 0,  2
  };
  const int r279[] = {
    10, 10, // Number of jobs and machines
    3, 41, 9, 72, 4, 29, 6, 53, 5, 46, 1, 18, 0, 83, 8, 15, 2, 93, 7, 37, 
    8, 35, 9, 41, 3, 87, 5,  4, 4, 67, 6, 91, 1, 78, 0, 62, 2, 85, 7, 33, 
    0, 28, 7, 36, 6, 16, 1, 50, 2, 26, 4, 86, 5, 97, 9, 41, 8, 97, 3, 46, 
    1, 46, 2,  2, 9, 12, 5, 49, 0, 80, 7, 30, 3, 13, 8,  8, 6, 51, 4,  5, 
    5, 44, 3, 12, 0, 48, 7, 74, 1, 41, 2, 62, 8, 99, 4, 60, 6, 29, 9, 45, 
    3,  4, 9,  1, 2, 31, 6, 91, 8, 17, 0, 54, 4, 17, 1, 68, 7,  5, 5, 12, 
    1, 50, 4,  5, 0, 32, 8, 76, 3, 76, 5,  1, 6, 61, 9, 86, 7, 42, 2, 31, 
    0, 78, 3, 63, 6, 87, 7, 50, 2, 70, 1, 98, 5, 44, 8, 41, 4, 58, 9, 78, 
    1, 20, 6, 72, 9, 39, 8, 29, 5, 71, 4, 38, 7, 33, 0, 60, 2, 78, 3, 14, 
    1, 33, 3, 79, 8, 32, 4,  7, 0, 56, 6, 78, 9, 51, 7, 62, 5, 16, 2, 83
  };
  const int r280[] = {
    10, 10, // Number of jobs and machines
    0, 53, 9, 57, 8, 26, 3, 62, 6, 41, 7,  2, 4, 60, 1, 11, 2, 57, 5, 64, 
    0, 20, 6, 18, 2, 68, 9, 95, 8, 29, 3, 84, 7, 22, 4, 27, 5, 90, 1, 51, 
    0, 87, 9, 67, 7, 42, 1, 81, 2, 40, 8, 89, 3, 76, 5, 77, 4, 22, 6, 39, 
    1, 72, 9, 77, 0, 90, 4, 39, 7, 50, 8, 32, 2,  8, 3, 67, 5, 58, 6, 35, 
    0, 33, 2, 53, 3, 19, 1, 40, 6, 73, 4, 38, 7, 70, 9,  6, 8, 62, 5, 17, 
    8, 91, 5, 28, 3, 77, 1, 76, 0, 19, 7,  3, 4, 82, 2, 45, 9, 14, 6, 60, 
    1,  5, 8, 28, 7, 38, 4, 34, 3,  5, 5, 55, 6, 80, 2, 66, 0, 33, 9, 52, 
    9, 96, 1, 20, 3, 50, 5, 37, 4, 81, 2, 96, 7, 47, 6, 36, 0, 11, 8, 91, 
    7,  5, 6, 50, 9, 47, 3, 29, 2, 82, 1, 64, 0, 96, 5, 63, 4, 26, 8, 86, 
    1, 72, 4, 95, 2, 34, 5, 58, 6, 82, 9, 69, 3, 21, 8, 24, 0, 48, 7, 33
  };
  const int r281[] = {
    10, 10, // Number of jobs and machines
    1, 72, 6, 22, 7, 82, 4, 75, 2, 97, 0, 41, 8, 64, 3, 42, 9, 58, 5, 93, 
    1, 64, 0,  3, 5, 15, 2, 65, 3, 52, 8, 90, 6, 32, 9, 85, 7, 68, 4, 90, 
    8, 77, 4, 31, 0, 53, 7, 48, 6, 63, 9, 14, 5,  7, 2, 65, 3, 90, 1, 75, 
    9, 98, 3, 73, 6, 90, 5, 85, 4, 37, 1, 13, 2, 46, 7, 58, 8, 72, 0, 77, 
    5, 96, 9, 63, 3, 79, 0, 10, 6, 53, 2,  1, 7, 91, 1, 99, 4, 63, 8, 34, 
    6, 95, 2, 20, 4, 53, 5, 75, 0, 34, 7,  9, 8, 56, 3, 78, 1, 20, 9, 55, 
    6, 11, 0, 26, 8,  9, 5, 80, 2,  7, 7,  3, 3, 56, 1, 17, 4, 12, 9, 68, 
    2, 76, 9, 89, 6, 25, 7, 44, 5, 60, 1, 48, 8, 54, 4, 38, 3, 86, 0, 14, 
    4, 11, 8, 15, 9, 61, 1, 85, 5, 69, 3, 37, 6, 23, 2, 71, 0, 26, 7, 26, 
    5, 48, 9, 93, 6, 27, 7, 41, 4, 55, 8, 97, 0, 58, 3, 71, 1,  4, 2, 92
  };
  const int r282[] = {
    10, 10, // Number of jobs and machines
    9, 53, 4, 40, 5, 69, 0, 99, 6, 97, 8, 63, 3, 92, 7, 30, 1, 72, 2, 47, 
    6, 63, 1, 32, 8, 26, 9, 26, 3, 44, 5, 78, 4, 62, 0, 44, 7, 57, 2, 70, 
    6, 53, 9, 63, 0, 75, 3, 66, 5, 96, 1,  4, 4,  8, 2, 56, 8, 27, 7, 83, 
    5, 19, 3, 34, 0, 13, 1, 54, 2, 41, 6, 17, 9, 64, 8, 77, 7, 41, 4, 50, 
    1, 74, 9, 42, 4, 10, 7, 15, 3, 25, 8, 33, 6, 49, 5, 23, 2, 84, 0, 68, 
    0, 75, 4, 55, 8, 42, 7, 52, 5, 32, 9, 30, 3, 48, 6, 44, 1, 49, 2, 64, 
    0, 42, 7,  1, 1, 23, 6, 93, 5, 35, 8, 16, 9, 34, 4, 17, 2, 54, 3, 47, 
    1, 67, 5, 45, 8, 77, 2, 62, 9, 60, 4, 21, 7, 79, 3, 11, 0, 36, 6, 13, 
    5, 59, 4, 37, 7, 94, 3, 57, 1, 95, 2, 34, 8, 76, 9, 72, 6, 48, 0, 89, 
    1, 42, 0, 25, 3, 83, 2, 70, 6, 49, 4, 84, 9, 62, 8, 51, 7, 10, 5,  8
  };
  const int r283[] = {
    10, 10, // Number of jobs and machines
    6, 58, 3, 94, 2, 17, 7, 38, 0, 99, 5, 55, 4, 27, 8, 58, 9,  3, 1, 25, 
    2, 29, 6, 51, 8, 14, 3, 39, 0, 94, 7, 25, 5, 26, 1, 17, 9, 45, 4,  3, 
    5, 51, 4,  6, 8, 79, 3, 22, 2, 27, 0, 41, 6, 95, 9, 55, 7, 88, 1, 87, 
    9, 78, 3, 20, 2, 77, 8, 10, 4, 14, 6, 75, 7, 58, 0, 49, 1, 12, 5, 23, 
    6, 46, 0, 12, 5,  5, 3, 68, 4, 88, 9,  1, 7, 61, 2, 98, 8, 29, 1,  4, 
    2, 81, 7, 78, 5, 75, 8, 93, 4, 48, 3, 24, 0, 41, 1, 13, 9, 10, 6, 28, 
    9, 80, 7, 39, 0, 49, 1, 80, 3, 15, 4, 40, 2, 27, 6, 57, 8, 11, 5, 52, 
    1, 32, 3, 86, 2, 90, 6, 71, 9, 44, 4, 61, 0, 24, 5, 53, 7, 65, 8, 28, 
    7, 35, 0, 80, 3, 59, 8, 61, 6, 69, 1, 17, 9, 62, 2,  4, 4, 12, 5, 14, 
    4, 30, 1, 66, 8, 74, 6, 83, 7, 81, 9, 57, 2, 10, 5,  4, 3, 26, 0, 23
  };
  const int r284[] = {
    10, 10, // Number of jobs and machines
    2, 71, 4,  4, 0, 79, 7, 23, 5, 60, 9, 18, 8, 41, 6, 55, 1, 12, 3, 94, 
    8, 84, 9, 64, 5, 74, 4, 83, 3, 84, 2, 92, 7, 96, 0, 87, 6, 34, 1, 82, 
    7, 39, 3, 76, 2, 76, 0, 27, 9, 52, 8, 72, 6, 20, 1, 15, 4, 23, 5, 41, 
    4, 56, 3, 24, 7, 11, 8, 28, 2, 91, 6, 14, 0, 38, 1, 65, 9, 74, 5, 57, 
    4, 17, 7, 65, 1, 46, 8, 44, 0, 85, 3, 55, 6, 39, 5, 66, 2, 78, 9,  9, 
    3, 56, 5, 39, 7, 94, 8, 18, 0, 44, 2, 95, 4, 43, 1, 27, 6, 88, 9, 10, 
    9, 78, 1, 52, 0,  9, 7,  6, 8, 46, 6, 17, 5, 99, 2, 95, 3, 45, 4,  5, 
    1, 49, 8, 60, 0, 21, 7, 34, 4, 88, 6, 59, 2, 55, 9, 74, 3, 52, 5, 52, 
    0, 35, 7, 13, 9, 48, 8, 42, 3, 24, 1, 65, 5, 53, 2, 95, 6, 98, 4, 86, 
    3, 54, 1, 73, 4, 83, 7, 28, 5, 72, 2, 57, 6, 77, 0, 69, 9, 45, 8, 18
  };
  const int r285[] = {
    10, 10, // Number of jobs and machines
    8,  9, 5, 28, 1, 99, 0, 80, 6, 71, 9, 20, 3, 59, 7, 52, 4, 52, 2, 56, 
    7, 89, 8, 65, 1, 64, 3, 43, 4, 49, 6, 10, 0, 73, 2, 15, 5, 81, 9, 50, 
    7, 31, 3, 43, 6, 97, 0, 39, 4, 20, 5, 48, 8, 79, 1, 85, 9, 47, 2, 41, 
    2, 80, 6, 97, 9, 35, 3, 71, 8, 32, 0, 80, 7, 88, 4, 34, 5, 12, 1, 71, 
    0, 60, 5, 69, 9, 31, 7, 81, 8,  5, 6, 24, 4, 71, 2, 69, 3, 16, 1, 20, 
    5, 77, 6, 85, 2, 52, 3, 54, 1, 24, 8, 60, 0, 29, 4, 74, 9, 52, 7, 28, 
    7, 89, 5, 14, 0, 71, 6, 90, 2, 45, 9, 47, 3, 91, 4, 52, 8, 81, 1, 35, 
    5, 35, 0, 56, 6, 95, 7, 71, 2, 10, 8, 48, 9, 99, 1,  2, 4, 86, 3, 43, 
    4, 48, 0, 45, 7, 43, 2, 28, 1, 33, 8, 58, 6, 80, 5, 81, 3,  1, 9, 17, 
    9, 39, 5, 66, 4, 35, 0, 77, 1,  4, 7, 35, 3, 60, 6, 15, 2, 48, 8, 29
  };
  const int r286[] = {
    10, 10, // Number of jobs and machines
    2, 85, 7, 96, 0,  7, 8, 97, 5, 46, 4, 12, 1, 13, 9, 16, 6, 64, 3, 69, 
    1, 89, 5, 51, 8, 71, 6, 19, 9,  8, 4, 39, 0, 71, 2, 49, 7,  5, 3, 10, 
    4, 38, 6, 32, 8,  1, 0, 83, 9, 72, 3, 51, 5, 47, 2, 66, 1, 34, 7, 40, 
    4,  7, 8, 92, 5, 80, 1, 74, 6, 86, 0, 82, 9, 66, 3, 84, 2, 44, 7, 35, 
    1, 35, 7, 80, 5, 48, 4, 76, 6,  3, 2, 57, 8, 10, 0, 51, 3, 97, 9, 19, 
    1, 47, 5, 92, 2, 11, 8, 74, 7, 95, 0, 28, 9, 78, 4, 99, 3, 90, 6, 51, 
    9, 42, 6, 59, 2, 68, 5, 26, 3, 85, 1, 98, 8, 66, 4, 84, 7,  9, 0, 97, 
    0, 12, 9, 31, 7, 77, 8, 29, 5, 96, 6, 95, 2, 17, 3, 47, 1,  6, 4, 31, 
    0, 12, 6, 45, 4, 71, 5, 68, 8, 24, 9, 10, 2, 10, 7, 77, 3, 57, 1,  2, 
    5, 19, 1, 72, 0, 13, 3, 93, 9,  5, 8,  6, 2, 28, 6, 49, 7, 25, 4, 95
  };
  const int r287[] = {
    10, 10, // Number of jobs and machines
    2, 55, 8, 95, 6, 91, 3, 58, 5, 29, 0, 37, 7, 30, 1, 30, 4, 67, 9, 28, 
    8, 63, 2, 93, 0, 64, 7, 39, 6, 11, 3, 80, 1, 40, 5,  8, 9, 70, 4, 96, 
    9, 30, 2,  8, 3, 96, 6,  2, 4, 23, 7, 58, 8, 30, 5, 39, 1, 36, 0, 21, 
    8, 27, 5, 77, 4,  1, 3, 77, 2, 39, 9, 18, 1, 27, 6, 58, 7,  1, 0, 83, 
    0, 58, 9, 93, 7, 94, 5, 53, 3, 97, 6, 84, 8, 50, 1, 70, 2, 14, 4, 38, 
    6, 19, 7, 63, 0, 17, 2,  2, 3, 30, 8, 58, 4, 90, 9, 59, 1, 90, 5, 29, 
    6, 29, 1, 37, 3, 26, 2, 58, 9, 63, 7, 57, 0, 35, 8, 96, 4, 73, 5, 83, 
    4, 31, 7, 83, 6, 41, 1, 93, 2, 86, 8,  6, 5, 21, 9, 24, 0, 50, 3, 23, 
    1, 72, 7, 89, 2, 39, 5,  1, 0, 16, 4, 46, 3, 48, 9, 66, 6, 44, 8, 66, 
    7, 21, 4, 46, 2, 37, 3, 48, 6, 39, 9, 34, 0, 65, 1, 36, 5, 21, 8, 97
  };
  const int r288[] = {
    10, 10, // Number of jobs and machines
    9, 49, 8, 26, 6, 75, 2, 52, 5, 65, 0, 99, 1, 81, 7, 72, 3, 45, 4, 95, 
    0, 49, 1, 11, 7, 27, 9, 16, 3, 68, 6, 87, 8, 90, 2, 90, 4, 18, 5, 46, 
    1, 92, 2, 16, 7, 90, 0, 87, 8,  1, 5, 85, 9, 78, 3,  5, 6, 61, 4, 14, 
    3, 59, 2, 32, 9, 72, 8, 43, 6, 64, 4, 51, 7, 12, 1, 70, 5, 22, 0, 90, 
    7,  7, 5, 13, 1, 90, 4, 76, 8, 66, 3, 68, 9, 73, 2, 79, 6, 14, 0, 72, 
    1, 97, 7, 54, 6, 10, 0, 40, 8, 19, 2, 71, 5, 74, 4, 60, 3, 78, 9, 98, 
    3, 36, 5,  7, 8, 66, 4, 24, 6, 23, 7, 23, 2, 74, 0, 12, 1, 92, 9, 58, 
    2, 12, 7, 61, 1, 55, 5, 63, 0, 45, 4, 45, 8, 90, 6, 89, 9, 78, 3, 20, 
    7, 17, 4, 15, 8, 93, 2, 88, 0, 72, 3, 18, 6, 58, 9, 98, 5, 95, 1, 72, 
    6, 78, 0, 22, 7, 31, 5, 66, 9, 92, 8,  1, 2, 91, 4, 44, 1,  2, 3, 90
  };
  const int r289[] = {
    10, 10, // Number of jobs and machines
    2, 54, 6, 46, 0, 37, 3, 81, 8, 13, 5, 16, 4, 71, 1, 51, 9,  8, 7, 86, 
    8, 55, 1, 83, 2, 97, 5, 35, 9, 97, 0, 72, 7, 58, 6, 91, 3, 27, 4,  4, 
    8, 50, 5, 44, 9, 16, 0, 74, 2, 81, 6, 92, 1, 74, 7, 82, 4, 48, 3, 50, 
    4, 17, 9,  1, 5, 46, 3, 48, 1, 20, 6, 14, 8, 27, 7, 11, 2, 26, 0, 31, 
    6, 87, 4, 39, 8, 37, 2, 44, 1, 69, 0, 67, 9, 12, 3, 71, 7, 12, 5, 30, 
    5, 95, 6, 27, 0, 53, 8, 78, 4, 13, 3, 35, 7, 19, 9, 29, 1, 68, 2, 44, 
    2, 38, 3, 98, 6, 25, 8, 66, 0, 89, 4, 11, 7, 56, 9, 33, 1, 97, 5,  7, 
    0, 61, 1, 73, 9, 66, 3, 36, 4, 75, 8, 61, 5, 73, 6, 64, 2, 80, 7, 13, 
    4, 56, 2, 41, 5,  5, 7, 60, 3, 80, 1, 45, 6, 91, 8, 44, 0, 49, 9, 10, 
    2, 42, 9, 27, 6, 32, 5, 64, 8, 45, 3, 29, 4, 48, 1, 25, 7, 85, 0, 74
  };
  const int r290[] = {
    10, 10, // Number of jobs and machines
    1, 75, 3, 91, 6, 58, 8, 74, 9, 17, 0, 90, 5, 62, 7,  6, 4, 81, 2, 49, 
    9, 49, 7, 39, 4, 53, 2, 69, 5, 79, 3, 85, 1, 71, 0, 15, 6, 56, 8, 31, 
    7, 15, 9, 61, 5,  1, 2, 23, 6, 40, 4, 51, 3, 57, 1, 37, 0, 60, 8,  7, 
    0, 39, 4, 37, 1, 88, 8, 17, 5, 35, 7, 46, 3, 69, 6, 90, 9, 14, 2, 57, 
    1, 10, 2, 68, 7, 93, 8, 41, 5, 69, 6, 17, 0, 18, 4, 13, 9, 99, 3, 33, 
    6, 61, 9, 34, 4, 95, 7, 98, 5, 56, 8, 88, 2, 29, 1, 67, 0, 71, 3, 45, 
    9, 43, 6, 87, 7, 61, 2, 87, 1, 18, 8, 47, 0, 54, 4, 84, 5, 77, 3, 27, 
    7, 54, 3, 77, 9, 29, 6, 59, 0, 75, 5, 57, 8, 62, 2, 55, 1, 28, 4, 65, 
    8, 22, 2, 11, 6, 60, 0, 13, 5,  4, 3, 48, 7, 23, 1, 45, 9, 26, 4, 88, 
    7, 99, 8, 41, 3, 56, 6, 63, 5, 81, 9,  8, 1, 59, 2, 78, 0, 73, 4, 40
  };
  const int r291[] = {
    10, 10, // Number of jobs and machines
    5,  4, 0, 18, 3, 63, 7, 41, 8, 38, 1, 97, 9, 33, 2, 10, 6, 22, 4, 16, 
    6, 60, 8, 72, 3, 97, 0, 65, 7, 94, 9, 91, 1, 98, 5, 82, 4, 95, 2, 77, 
    2, 18, 4, 31, 7,  6, 3, 31, 5, 26, 1, 26, 9, 25, 6, 85, 8, 15, 0,  4, 
    0, 80, 6, 79, 5,  3, 7, 69, 8, 47, 9, 71, 2, 42, 1, 62, 4, 26, 3, 80, 
    5, 76, 0, 50, 4, 28, 1, 63, 7, 34, 8, 55, 6, 40, 3,  2, 9, 79, 2, 80, 
    1, 15, 9, 93, 8, 63, 0, 78, 3, 84, 7, 11, 5, 53, 2, 68, 6, 40, 4, 46, 
    9, 59, 3, 50, 1, 64, 4, 95, 7, 31, 2, 12, 5, 59, 8, 55, 0, 55, 6, 68, 
    1, 20, 8, 49, 5, 57, 2, 65, 9, 87, 0, 81, 6, 11, 4, 43, 3, 47, 7, 62, 
    5, 91, 8, 50, 9, 50, 6, 88, 3, 99, 7, 97, 0, 61, 2, 83, 4, 42, 1,  4, 
    3, 93, 9,  6, 2, 71, 1, 73, 5, 74, 7, 21, 4, 45, 8, 53, 0, 28, 6, 84
  };
  const int r292[] = {
    10, 10, // Number of jobs and machines
    4, 60, 0, 46, 1, 19, 8, 57, 9, 17, 5, 89, 7, 83, 6, 78, 2, 58, 3, 26, 
    1, 76, 8, 40, 3, 14, 7, 17, 2, 60, 4, 30, 6, 73, 0,  9, 5, 72, 9, 94, 
    6, 17, 2, 23, 7, 24, 4, 77, 9, 69, 3, 26, 5, 89, 1, 43, 8, 20, 0, 88, 
    4,  3, 2, 65, 6, 98, 8, 75, 9, 97, 7,  9, 5, 82, 1, 37, 0,  8, 3, 30, 
    3, 75, 2, 88, 0, 46, 6,  1, 9, 75, 7, 19, 8, 74, 4, 89, 5, 46, 1, 13, 
    6, 54, 4,  9, 3, 83, 8, 48, 7, 81, 1, 57, 9, 23, 5, 30, 2, 73, 0, 22, 
    2, 12, 7, 71, 3, 59, 9, 85, 5, 74, 6, 48, 8, 51, 4, 34, 1, 56, 0, 68, 
    2, 93, 3, 88, 1,  3, 5, 20, 0, 46, 6, 10, 9, 71, 8, 20, 7, 41, 4, 89, 
    0, 84, 3, 25, 1, 75, 9, 25, 2, 41, 8, 91, 6, 16, 7, 27, 4, 55, 5,  3, 
    5, 85, 2, 89, 3, 56, 8, 23, 0, 36, 1, 98, 9, 87, 7, 83, 6, 50, 4, 76
  };
  const int r293[] = {
    10, 10, // Number of jobs and machines
    8, 98, 3, 99, 0, 95, 1, 88, 2, 96, 6, 88, 7, 72, 9, 62, 4, 35, 5, 68, 
    5,  2, 4, 45, 7, 19, 6, 95, 9, 81, 0, 32, 2, 73, 1, 11, 3,  8, 8, 75, 
    8, 96, 1, 83, 2, 84, 0, 36, 3, 58, 9, 73, 6, 77, 7, 95, 4, 77, 5, 67, 
    9, 59, 8, 23, 7, 22, 0, 19, 3, 96, 2, 12, 6, 78, 5, 10, 4, 55, 1, 99, 
    3, 61, 9, 41, 0, 91, 1, 94, 4, 92, 7, 19, 8, 92, 5, 40, 2, 96, 6, 98, 
    6, 80, 4, 16, 3, 76, 1, 58, 9,  8, 8, 78, 7, 13, 0,  5, 5, 13, 2, 57, 
    8, 89, 0, 94, 2, 39, 4, 14, 7, 68, 1, 85, 9,  7, 6, 66, 5, 45, 3, 11, 
    7, 49, 4, 88, 8, 22, 2, 19, 0,  6, 9, 39, 1, 32, 5, 28, 6, 20, 3, 29, 
    1, 89, 3,  9, 6, 86, 2, 78, 0, 96, 4, 82, 5, 34, 8, 74, 7, 98, 9, 54, 
    2, 61, 1, 44, 4, 21, 6, 70, 0,  1, 8, 75, 3, 43, 7, 11, 5, 27, 9, 56
  };
  const int r294[] = {
    10, 10, // Number of jobs and machines
    4,  8, 7, 14, 3, 70, 2, 99, 9, 99, 6, 55, 0, 99, 1, 54, 8, 55, 5, 82, 
    4, 93, 5, 92, 1, 36, 7, 99, 2, 26, 8, 73, 3, 57, 0, 16, 9,  3, 6, 27, 
    2, 49, 5, 34, 8, 99, 1,  1, 3, 11, 0, 59, 7, 68, 6, 55, 4, 23, 9, 68, 
    4, 50, 1, 20, 5, 76, 3, 82, 6, 15, 0, 25, 9, 47, 7, 73, 2, 67, 8, 84, 
    8, 41, 2, 70, 9, 68, 7, 45, 1, 31, 4, 33, 6, 22, 0, 30, 5, 76, 3,  5, 
    2, 84, 1, 55, 4, 42, 8, 11, 3, 13, 7, 31, 5, 15, 0, 94, 6, 77, 9, 87, 
    7, 67, 4, 16, 2, 22, 6, 92, 9, 20, 8, 68, 0, 20, 5, 58, 1, 92, 3, 58, 
    0, 34, 8, 43, 3, 80, 4, 91, 1, 91, 5,  6, 6, 45, 9, 25, 7, 63, 2, 75, 
    7, 81, 2, 87, 1, 20, 4, 62, 8, 78, 5, 37, 3, 57, 6, 42, 0, 58, 9, 31, 
    6, 51, 0, 40, 5, 50, 7, 61, 8,  5, 2, 63, 9, 64, 4, 24, 3, 50, 1,  1
  };
  const int r295[] = {
    10, 10, // Number of jobs and machines
    6,  8, 4, 53, 0, 81, 7, 33, 5,  8, 9, 25, 2, 63, 8, 90, 1, 60, 3, 58, 
    2, 36, 0, 62, 7, 73, 9, 44, 1,  7, 5, 53, 8, 73, 4, 41, 3, 57, 6, 13, 
    5, 69, 1, 54, 2, 36, 8, 85, 6, 23, 3, 33, 7, 73, 0, 86, 4, 79, 9, 62, 
    9, 82, 0, 87, 3, 49, 5, 58, 2, 87, 1, 45, 6,  3, 8, 35, 4, 88, 7, 48, 
    9, 77, 7, 65, 1, 10, 4, 38, 3, 38, 2, 30, 5, 28, 6, 44, 0, 57, 8, 76, 
    4, 94, 2, 20, 0, 63, 9,  3, 3, 91, 6,  5, 7,  9, 1, 77, 5, 27, 8,  2, 
    7, 51, 2, 27, 3, 45, 6, 79, 9,  3, 4, 59, 0, 34, 5, 41, 1, 11, 8,  5, 
    1, 58, 7, 89, 3, 39, 9, 19, 5, 31, 4, 28, 8, 76, 2, 29, 0, 94, 6, 77, 
    4, 98, 9, 85, 1,  8, 8, 10, 5, 35, 7, 93, 0, 14, 6, 27, 3,  4, 2, 11, 
    9, 48, 1, 89, 0, 99, 3, 79, 4, 39, 2, 64, 8, 94, 6, 45, 7, 33, 5,  5
  };
  const int r296[] = {
    10, 10, // Number of jobs and machines
    1,  7, 5, 11, 2, 68, 6, 77, 7, 77, 9, 48, 0,  7, 8, 89, 3, 66, 4, 69, 
    7, 19, 6, 80, 2, 42, 1, 50, 5, 99, 3, 83, 9, 32, 0, 53, 8, 12, 4, 49, 
    9, 90, 6, 20, 1, 89, 7,  9, 3, 72, 5, 21, 4, 89, 0, 90, 8, 31, 2,  4, 
    1, 68, 7, 33, 3, 16, 0, 36, 4, 13, 2, 12, 9, 40, 8, 67, 5, 79, 6, 36, 
    9, 59, 1,  1, 7, 85, 8, 91, 3, 96, 4, 85, 0, 36, 6, 27, 2, 26, 5, 53, 
    0, 72, 3, 34, 6, 22, 8, 38, 4, 65, 1,  8, 9, 89, 5,  5, 7, 66, 2, 85, 
    6, 86, 1, 27, 9, 64, 2, 71, 3, 74, 7, 64, 0, 86, 5, 33, 4, 26, 8, 14, 
    5, 47, 6, 25, 8, 96, 4, 64, 9, 17, 2, 63, 3, 24, 0, 94, 1, 50, 7, 95, 
    4, 38, 5, 14, 1, 65, 0,  2, 2, 61, 6,  3, 8, 44, 3, 79, 7, 70, 9, 43, 
    0, 97, 9, 88, 3, 70, 7, 77, 5, 46, 8, 38, 6, 46, 1, 93, 4, 95, 2, 27
  };
  const int r297[] = {
    10, 10, // Number of jobs and machines
    2, 44, 3, 35, 6, 67, 9, 49, 8, 87, 4, 49, 0,  4, 7, 74, 1, 37, 5, 96, 
    8, 42, 1, 17, 5,  5, 2, 78, 6,  5, 7,  5, 4, 19, 0, 67, 3, 82, 9, 26, 
    6, 88, 7, 65, 8, 43, 4, 21, 2, 65, 0, 33, 9, 83, 3, 51, 5, 99, 1, 31, 
    6, 75, 1, 45, 5, 45, 8, 91, 9, 87, 7,  9, 3, 33, 0, 32, 4, 73, 2,  8, 
    9, 81, 5, 72, 8, 50, 1, 23, 0, 18, 2, 77, 6, 25, 3, 96, 7, 97, 4, 39, 
    7, 23, 2, 18, 5, 86, 9, 12, 1, 33, 0, 28, 8, 29, 4, 19, 6, 37, 3, 37, 
    4, 77, 9, 35, 0, 96, 5, 26, 8, 23, 2, 85, 6, 59, 1, 47, 7, 41, 3, 65, 
    9, 86, 8, 96, 0, 88, 3, 72, 1, 30, 4, 75, 6, 76, 7, 38, 2, 60, 5, 57, 
    1, 84, 4, 49, 7,  8, 9, 53, 5, 83, 6, 36, 8, 58, 3,  6, 0, 97, 2, 35, 
    0, 60, 7, 83, 4, 72, 9, 22, 3, 98, 2, 47, 8, 90, 1, 87, 5, 72, 6,  6
  };
  const int r298[] = {
    10, 10, // Number of jobs and machines
    7, 82, 3, 74, 9, 23, 8, 91, 6, 89, 2, 60, 0, 29, 4, 72, 5,  7, 1, 35, 
    6, 17, 8, 25, 4,  3, 9, 72, 2, 37, 5, 42, 7, 36, 0, 46, 3, 27, 1,  8, 
    2, 42, 0, 18, 3, 27, 5, 96, 4, 81, 6, 49, 9, 37, 7, 46, 8, 64, 1,  8, 
    1, 24, 9, 49, 7, 96, 4, 51, 0,  4, 3, 68, 6, 85, 8, 93, 5, 77, 2, 88, 
    1, 42, 6, 40, 2, 49, 4, 96, 8,  3, 5, 50, 0, 96, 7,  2, 3, 88, 9, 42, 
    0, 52, 7, 75, 4, 91, 5, 99, 9, 81, 2, 80, 8, 12, 3, 52, 1, 27, 6, 37, 
    5, 16, 2, 12, 7, 27, 4, 60, 9,  7, 6, 28, 3, 84, 1, 16, 0, 73, 8, 55, 
    7, 69, 0, 59, 8, 15, 2, 86, 9, 91, 1, 49, 6, 24, 5, 50, 4, 35, 3, 68, 
    8, 98, 1,  6, 9, 31, 2, 79, 0, 88, 3, 58, 5, 15, 7, 38, 6, 59, 4, 35, 
    8, 10, 4, 39, 1, 56, 5, 39, 6, 70, 9, 98, 0, 79, 2, 64, 7, 21, 3,  1
  };
  const int r299[] = {
    10, 10, // Number of jobs and machines
    8, 51, 0, 50, 7, 48, 5, 63, 2, 90, 4, 37, 1, 52, 6, 61, 3, 79, 9, 70, 
    8, 90, 7, 14, 4, 63, 1, 47, 5, 22, 2, 37, 3, 50, 0, 15, 6, 21, 9, 28, 
    3, 91, 5, 29, 1, 19, 8, 23, 6, 33, 2, 10, 0, 90, 7, 44, 4, 10, 9, 20, 
    6,  5, 8, 61, 0, 32, 4, 40, 7,  4, 2, 75, 9, 66, 5, 70, 3,  9, 1, 75, 
    4, 78, 7,  1, 5, 52, 3,  9, 0, 72, 9, 36, 8, 20, 2, 39, 1, 20, 6, 88, 
    7,  4, 2, 17, 3,  2, 8, 15, 9, 55, 4, 21, 0, 53, 5, 97, 6, 68, 1, 75, 
    7, 33, 3, 10, 9,  6, 4, 31, 6,  9, 8, 34, 2, 39, 1, 17, 5, 49, 0, 69, 
    9, 71, 4, 83, 1,  1, 0, 87, 7, 63, 6, 44, 8, 58, 3, 98, 5, 51, 2, 51, 
    1,  8, 0, 75, 8, 52, 9,  5, 3, 38, 7, 43, 4, 21, 6, 27, 2, 29, 5, 88, 
    3, 70, 5, 27, 2, 56, 8, 96, 9, 12, 7, 64, 0, 33, 4, 46, 6, 49, 1, 84
  };
  const int r300[] = {
    10, 10, // Number of jobs and machines
    8, 28, 3, 64, 5,  6, 9, 53, 6, 70, 2, 65, 0, 41, 7, 80, 1, 28, 4, 19, 
    8,  3, 5, 53, 0,  2, 4, 93, 2, 16, 3, 67, 7,  1, 1, 13, 6, 76, 9, 36, 
    4, 38, 2, 39, 3,  4, 1, 51, 8, 13, 6, 31, 0, 44, 9, 17, 5, 58, 7, 65, 
    1, 35, 9, 67, 6, 43, 8, 16, 5, 73, 4, 67, 2, 53, 0, 73, 7, 19, 3, 49, 
    2, 79, 6, 90, 1, 27, 5, 82, 3, 19, 0, 37, 8, 49, 9, 67, 7, 62, 4, 56, 
    4, 61, 0,  9, 3, 21, 1, 14, 8, 67, 9, 20, 5, 85, 7,  4, 6, 12, 2, 34, 
    1, 88, 7, 91, 2, 34, 5, 91, 0, 98, 4, 82, 3, 29, 6, 99, 9,  5, 8, 52, 
    0, 55, 4, 30, 8,  5, 6, 33, 3, 94, 1, 91, 2,  1, 9, 81, 5,  4, 7,  8, 
    9, 15, 4, 69, 5, 61, 2, 23, 1, 53, 0, 50, 8, 41, 7, 35, 3, 53, 6, 12, 
    8, 84, 7,  6, 3, 18, 0, 97, 4,  4, 1, 93, 5, 16, 2, 26, 6, 91, 9, 19
  };
  const int r301[] = {
    10, 10, // Number of jobs and machines
    7, 10, 2, 87, 9,  4, 4, 61, 3, 88, 8, 30, 1, 94, 0,  8, 6, 97, 5,  1, 
    2, 73, 8, 47, 4, 79, 5, 53, 7, 66, 9, 96, 6,  3, 3, 32, 1, 81, 0, 20, 
    3, 12, 8, 68, 6, 61, 0, 86, 4,  3, 2, 93, 5, 41, 7, 98, 1, 49, 9, 34, 
    8, 35, 1, 20, 4, 41, 7, 32, 9, 51, 6, 89, 3, 53, 5, 27, 0, 63, 2, 12, 
    7, 19, 0, 64, 3, 16, 5, 62, 2, 91, 6, 65, 4, 63, 9, 12, 1, 64, 8, 33, 
    0, 75, 8, 77, 6, 62, 4, 97, 1, 55, 9, 89, 5, 25, 3, 37, 2, 78, 7, 26, 
    1, 53, 5, 65, 4, 22, 2, 85, 8, 57, 7, 45, 6, 20, 3, 14, 0, 13, 9, 31, 
    2, 18, 3, 46, 5, 43, 4, 38, 7, 38, 8, 64, 9, 75, 6, 65, 0, 47, 1, 24, 
    4, 55, 2, 77, 6, 65, 1, 78, 3, 72, 9, 75, 8, 91, 7, 56, 0, 55, 5, 38, 
    3, 72, 4, 47, 2, 95, 5, 55, 0, 18, 8, 97, 6, 19, 7, 81, 1, 40, 9, 20
  };
  const int r302[] = {
    10, 10, // Number of jobs and machines
    2, 16, 3, 53, 1, 25, 6, 39, 0, 72, 9, 97, 7, 45, 5,  9, 4, 79, 8, 69, 
    8, 89, 3, 19, 9,  7, 1, 66, 6, 23, 4, 88, 5, 92, 0,  9, 7, 75, 2, 66, 
    4, 90, 5, 24, 2,  9, 8,  9, 6, 70, 7, 78, 3, 55, 9, 81, 0, 54, 1, 98, 
    6, 97, 0, 40, 1, 69, 3, 34, 2, 65, 7,  9, 9, 39, 8, 21, 4, 10, 5, 90, 
    7, 55, 8, 53, 2, 14, 6, 30, 1, 75, 9, 15, 5, 77, 0, 27, 4, 64, 3, 54, 
    9, 62, 4, 84, 3, 75, 7, 42, 1, 74, 8, 60, 0, 83, 5, 43, 6, 63, 2, 55, 
    0, 76, 8, 74, 5,  5, 7, 12, 3, 24, 6, 31, 4,  3, 9, 68, 2, 19, 1, 96, 
    4, 60, 0, 39, 1, 81, 9, 36, 2, 85, 3, 31, 7, 41, 5, 20, 8,  7, 6, 17, 
    7, 97, 8, 46, 6, 16, 3,  1, 1, 55, 0,  7, 2, 90, 4, 35, 9, 96, 5, 57, 
    9, 83, 6, 83, 1, 83, 8, 73, 7, 62, 3,  8, 0, 46, 5, 76, 4, 62, 2, 45
  };
  const int r303[] = {
    10, 10, // Number of jobs and machines
    5, 46, 0, 92, 1, 70, 4, 43, 3, 90, 7, 92, 9, 44, 2, 51, 6, 86, 8,  8, 
    8, 48, 0, 78, 4,  4, 3, 46, 6, 43, 9, 73, 5, 18, 2, 34, 7,  9, 1, 63, 
    3, 41, 7, 13, 1, 96, 9, 99, 5, 40, 6, 77, 4, 34, 8, 18, 0, 57, 2, 74, 
    5, 26, 7, 27, 6, 74, 2, 26, 8, 14, 3, 79, 4, 66, 0, 94, 9, 33, 1, 18, 
    8, 36, 0, 70, 6, 36, 7, 65, 4, 63, 1, 44, 9, 34, 3, 28, 5, 62, 2, 83, 
    2, 52, 6, 89, 9, 55, 8, 88, 1, 79, 0, 55, 3, 82, 7, 13, 5, 25, 4, 18, 
    3, 18, 5, 50, 0, 88, 4, 54, 8, 68, 1, 64, 2, 52, 9, 14, 7,  3, 6, 82, 
    4, 27, 3, 58, 6, 25, 2, 36, 7, 77, 5, 30, 9, 88, 0, 24, 8, 66, 1, 39, 
    3, 84, 8, 30, 6, 10, 4, 14, 1, 11, 2, 28, 0, 26, 7, 11, 9, 95, 5, 66, 
    7, 37, 6, 48, 3, 36, 4, 86, 0, 88, 8, 66, 5, 95, 1, 80, 2, 65, 9, 84
  };
  const int r304[] = {
    10, 10, // Number of jobs and machines
    9, 54, 5, 51, 3,  9, 8,  4, 7, 66, 0,  8, 4, 25, 1, 21, 2, 69, 6, 14, 
    6, 81, 1, 16, 3, 90, 0, 26, 5, 21, 8, 93, 2, 46, 7,  9, 9, 63, 4, 27, 
    0, 98, 1, 21, 4, 32, 5, 97, 8, 20, 7, 35, 3, 41, 9, 50, 6, 60, 2, 53, 
    8, 59, 0,  7, 3, 30, 1,  1, 9, 84, 4, 83, 7, 79, 2, 52, 6, 84, 5, 11, 
    3, 63, 8, 68, 0, 96, 7, 25, 1, 67, 5, 73, 4,  8, 6, 21, 9, 20, 2, 69, 
    9, 20, 6, 64, 7, 95, 8, 91, 1, 45, 5, 29, 3, 47, 4, 17, 2, 60, 0, 53, 
    1, 72, 3, 73, 8, 77, 7, 20, 5, 22, 4, 55, 6,  7, 2, 51, 0, 79, 9, 97, 
    4, 13, 2, 24, 1, 59, 3, 50, 0, 45, 8, 68, 7, 94, 9, 12, 6, 40, 5, 25, 
    3, 38, 1, 63, 0, 67, 4, 73, 6, 28, 8, 10, 2, 73, 9, 95, 7, 69, 5, 31, 
    4, 50, 6, 68, 7, 10, 5, 82, 0, 55, 2, 78, 3, 45, 8, 88, 9, 56, 1, 34
  };
  const int r305[] = {
    10, 10, // Number of jobs and machines
    7, 11, 2, 47, 1, 42, 5, 33, 9, 87, 6, 71, 4, 29, 0, 89, 3, 69, 8, 20, 
    8, 59, 4, 92, 9, 60, 0, 95, 1, 31, 3, 37, 6, 16, 7, 14, 5, 86, 2, 36, 
    2, 88, 1, 75, 6, 58, 7, 26, 3, 54, 4, 10, 5, 26, 9, 53, 0, 90, 8, 81, 
    8, 80, 9, 19, 1, 18, 6, 53, 5, 83, 2, 87, 3, 62, 0, 21, 4, 68, 7, 60, 
    2, 62, 9, 48, 4, 97, 7, 57, 1, 92, 0, 37, 5, 90, 3, 37, 8, 64, 6, 24, 
    3, 82, 2,  6, 4, 98, 6, 11, 8, 79, 7,  4, 0, 80, 5, 87, 9, 30, 1, 60, 
    6, 40, 0, 42, 9, 95, 4, 60, 2, 35, 5,  1, 3, 10, 8, 37, 1, 56, 7, 82, 
    8, 87, 6, 63, 4, 94, 1, 83, 0, 63, 2, 70, 9, 26, 7,  9, 5, 51, 3, 33, 
    0, 46, 1, 65, 6, 10, 2, 49, 8, 43, 3, 35, 4, 63, 7, 73, 9, 56, 5, 10, 
    4, 53, 7, 18, 3, 85, 8, 72, 0, 74, 9, 10, 1, 87, 5, 40, 6, 75, 2, 69
  };
  const int r306[] = {
    10, 10, // Number of jobs and machines
    8, 68, 6, 95, 3,  4, 2, 98, 4, 79, 0, 92, 1, 77, 9, 26, 7, 33, 5, 35, 
    4, 15, 5, 26, 6, 21, 8, 74, 3, 74, 9, 43, 7, 21, 0, 32, 1, 49, 2, 76, 
    9, 39, 8, 57, 3, 51, 7, 75, 2, 34, 6, 58, 0, 97, 5, 83, 1, 19, 4, 51, 
    4, 80, 1, 33, 9, 22, 7, 74, 6, 58, 5, 93, 8, 26, 0, 89, 2, 94, 3, 91, 
    8, 81, 9, 26, 4, 27, 1, 41, 5, 34, 7, 86, 6, 91, 3, 43, 0, 42, 2, 99, 
    0,  5, 6, 87, 1, 66, 2, 92, 4, 45, 8, 42, 7, 52, 9, 54, 5, 76, 3, 93, 
    0, 79, 6, 17, 9, 25, 1, 41, 8, 57, 2, 97, 3, 84, 7, 19, 4, 91, 5, 58, 
    5, 21, 6,  4, 4, 53, 9, 38, 0,  5, 2, 62, 7, 24, 1, 39, 8, 28, 3, 98, 
    7,  1, 1, 16, 3, 24, 8, 30, 5, 34, 0, 18, 2, 53, 6, 11, 9, 54, 4, 29, 
    1, 88, 6, 60, 7, 16, 2, 60, 4, 14, 9,  8, 8, 51, 5, 24, 3, 63, 0, 41
  };
  const int r307[] = {
    10, 10, // Number of jobs and machines
    9, 85, 1, 97, 7, 83, 0, 70, 5, 34, 4, 86, 2, 67, 6, 47, 3, 13, 8, 92, 
    9, 57, 0, 56, 8, 50, 5,  3, 2, 81, 1, 32, 7, 28, 4, 36, 3, 99, 6, 39, 
    4, 83, 3, 50, 2, 57, 0,  9, 8, 83, 6, 74, 5, 39, 7, 10, 1, 82, 9, 12, 
    1, 88, 7, 49, 3, 84, 8, 63, 0, 85, 6, 78, 2, 26, 5, 80, 9, 21, 4, 36, 
    3, 46, 4, 72, 1, 51, 0, 20, 7,  9, 5, 37, 9, 35, 6, 53, 8, 13, 2, 96, 
    1, 12, 8,  6, 0, 28, 3, 81, 5, 93, 6, 67, 9, 27, 2, 75, 7, 25, 4, 18, 
    1, 48, 5, 50, 2, 35, 9, 58, 6, 58, 0, 48, 4, 82, 8, 95, 7, 69, 3, 93, 
    1, 77, 9, 27, 8, 40, 4, 22, 2, 15, 7, 11, 0, 88, 6, 84, 5, 48, 3, 75, 
    2, 96, 4, 25, 8, 99, 5, 23, 7, 67, 6, 58, 1, 55, 3, 26, 0, 24, 9, 41, 
    6,  1, 4, 44, 5,  5, 7, 66, 1, 66, 8, 88, 0, 14, 3, 59, 2, 47, 9, 38
  };
  const int r308[] = {
    10, 10, // Number of jobs and machines
    9, 52, 0, 33, 2, 16, 4, 45, 5,  7, 6,  8, 1, 45, 7, 78, 3, 46, 8, 52, 
    2, 79, 4, 80, 3, 98, 5, 58, 8, 49, 0,  1, 1, 38, 6, 12, 7, 50, 9, 53, 
    2, 17, 8, 92, 0, 52, 4, 20, 6, 69, 1, 33, 3, 43, 9, 20, 7, 20, 5, 43, 
    0, 79, 9, 87, 8, 87, 7, 10, 2, 17, 1, 32, 3, 99, 5, 65, 4, 77, 6, 68, 
    3, 35, 2, 74, 0, 48, 6, 69, 5, 63, 7, 84, 4, 65, 8, 60, 1, 46, 9, 38, 
    4, 67, 0, 21, 2,  6, 3, 94, 6, 38, 8, 40, 9, 73, 7,  1, 5, 93, 1, 40, 
    7, 57, 8, 16, 4, 94, 0, 76, 1, 68, 6, 18, 9,  3, 5, 74, 2, 72, 3, 13, 
    3, 16, 5, 74, 7, 81, 6, 63, 9,  2, 0, 13, 1, 13, 2, 58, 4, 82, 8, 80, 
    6, 58, 4, 38, 8, 36, 1, 89, 3, 69, 7, 78, 9, 94, 5, 91, 0, 28, 2, 63, 
    8, 62, 4, 25, 3, 56, 9, 36, 7,  6, 1,  4, 5, 68, 6, 67, 2, 97, 0,  2
  };
  const int r309[] = {
    10, 10, // Number of jobs and machines
    5, 89, 4,  8, 8, 50, 2, 81, 6, 73, 9,  6, 3, 86, 0, 98, 1, 81, 7, 72, 
    5, 32, 2, 35, 6, 89, 3, 38, 0, 65, 7, 71, 9, 18, 1, 45, 8, 82, 4, 78, 
    5,  2, 2, 29, 3,  5, 9, 46, 7, 58, 0,  9, 8, 38, 4,  9, 6, 27, 1, 70, 
    8, 87, 0, 65, 5, 82, 9, 30, 4, 86, 3, 78, 6, 89, 2, 45, 7, 16, 1, 90, 
    3, 11, 7, 19, 1, 90, 8, 75, 0, 98, 6, 54, 4, 83, 2, 82, 9, 85, 5, 73, 
    5, 19, 2,  5, 8, 48, 1, 16, 0, 83, 6, 23, 4, 30, 3, 79, 9, 83, 7, 65, 
    9, 26, 4, 12, 5, 21, 2, 26, 3, 15, 6, 90, 1, 24, 0, 30, 7, 60, 8, 29, 
    3, 74, 0, 11, 2, 69, 5, 90, 6, 90, 1, 19, 8, 76, 7, 90, 9, 82, 4, 67, 
    6, 48, 4, 94, 9, 73, 0, 53, 7, 59, 2, 22, 3, 87, 8, 53, 1, 51, 5, 27, 
    0, 58, 7, 53, 2, 61, 3, 40, 6, 32, 1, 17, 4, 22, 9, 76, 5, 82, 8, 58
  };
  const int r310[] = {
    10, 10, // Number of jobs and machines
    5, 83, 2, 43, 6, 53, 3, 14, 1, 55, 0, 90, 8, 13, 7,  3, 4, 66, 9, 17, 
    9, 60, 0, 70, 1,  2, 2, 57, 7, 51, 4, 48, 8, 50, 6, 49, 3, 93, 5, 59, 
    5, 15, 8, 86, 3, 13, 7, 45, 9, 12, 6, 36, 4, 96, 1, 19, 0, 26, 2, 93, 
    3, 58, 4, 12, 1, 52, 5, 28, 9, 69, 6, 65, 2,  9, 0, 46, 8, 69, 7, 74, 
    7, 67, 0, 24, 1, 69, 8, 73, 3, 84, 5, 66, 2, 57, 9, 81, 6, 79, 4, 55, 
    3, 40, 4, 99, 7, 61, 2, 38, 1, 77, 0, 33, 9,  4, 6, 65, 8, 93, 5, 46, 
    7,  2, 4, 18, 8, 31, 5, 25, 6, 21, 0, 80, 2, 18, 3, 27, 9, 84, 1, 18, 
    8, 27, 0, 88, 2, 33, 3, 95, 1, 31, 7, 50, 6, 49, 5, 83, 9,  5, 4, 55, 
    3, 46, 0, 97, 1, 84, 8, 29, 6,  4, 5, 95, 4, 73, 9, 19, 7, 61, 2, 45, 
    9, 80, 0, 87, 4, 95, 5, 53, 3, 28, 6, 62, 2, 77, 8, 12, 1, 14, 7, 91
  };
  const int r311[] = {
    10, 10, // Number of jobs and machines
    1, 83, 9,  9, 3, 51, 4, 18, 6, 51, 7, 73, 8, 59, 2, 40, 0, 79, 5, 16, 
    9, 75, 8, 13, 5, 33, 4, 17, 0, 28, 7, 39, 1, 21, 3, 16, 6, 29, 2, 76, 
    9, 13, 3,  2, 0, 97, 7, 42, 2, 31, 4, 76, 1, 50, 8, 40, 6, 10, 5, 68, 
    9,  9, 1, 24, 6, 19, 4, 19, 8, 43, 0, 63, 2, 40, 7, 90, 5, 78, 3, 34, 
    6,  8, 5,  8, 9, 88, 7, 99, 4, 53, 2, 11, 0, 92, 3, 63, 8, 75, 1, 84, 
    0, 51, 5, 17, 7, 26, 3, 14, 8, 23, 6, 58, 1, 29, 2, 28, 4, 83, 9, 41, 
    4, 47, 2, 27, 5, 80, 9, 89, 7, 26, 0, 91, 8,  9, 1, 62, 3, 42, 6,  1, 
    7, 17, 4, 44, 8, 97, 3, 26, 2, 69, 0, 10, 1, 85, 6, 76, 9,  4, 5, 92, 
    9, 31, 8, 33, 4, 56, 3, 67, 0, 98, 1, 75, 2, 87, 5,  6, 6, 61, 7, 47, 
    7, 69, 2, 93, 1, 25, 6, 13, 0, 73, 8, 32, 5, 76, 9, 41, 4, 37, 3,  3
  };
  const int r312[] = {
    10, 10, // Number of jobs and machines
    0, 26, 3, 43, 9, 28, 1, 59, 8, 92, 4, 12, 7, 78, 6, 63, 2, 86, 5,  4, 
    3, 41, 6, 11, 9, 73, 1, 57, 0, 40, 8, 92, 2, 70, 4, 16, 5, 75, 7, 33, 
    0, 96, 7, 89, 2, 29, 8, 42, 4, 81, 1,  6, 3, 18, 6,  4, 9,  7, 5, 64, 
    1,  3, 7, 33, 6, 66, 5, 94, 0,  7, 8, 46, 3, 27, 9, 59, 4, 13, 2, 53, 
    1, 20, 6, 72, 3, 51, 9, 34, 5, 27, 2, 74, 7, 25, 0, 75, 8, 53, 4, 17, 
    4, 22, 8, 41, 0, 65, 3, 29, 6, 37, 1, 74, 9,  5, 5, 45, 2, 99, 7, 23, 
    6, 44, 8, 96, 7, 53, 4, 32, 3, 58, 1, 81, 0, 62, 9,  7, 5, 14, 2, 36, 
    7, 27, 3, 34, 0, 51, 6, 74, 9, 30, 5, 89, 4,  1, 2,  8, 1, 55, 8, 68, 
    0,  2, 7, 27, 6, 98, 4, 54, 9, 99, 3, 76, 8, 54, 2, 88, 1, 18, 5, 86, 
    6, 74, 1, 75, 3,  1, 0, 38, 4, 19, 9, 32, 2, 41, 5, 86, 8, 96, 7, 34
  };
  const int r313[] = {
    10, 10, // Number of jobs and machines
    3, 79, 2, 75, 9,  6, 8, 26, 1, 65, 7, 66, 0, 62, 6, 83, 4, 11, 5, 77, 
    4, 33, 0, 52, 9, 60, 5, 68, 3, 29, 6, 22, 1, 98, 7, 81, 8, 58, 2, 93, 
    8, 55, 1, 19, 0, 44, 2, 34, 6, 92, 4,  3, 5, 40, 9, 48, 7, 98, 3, 12, 
    4, 19, 6, 99, 0, 22, 3, 92, 8,  1, 1, 80, 7, 57, 9, 63, 5, 62, 2,  1, 
    3, 12, 4,  3, 6,  6, 5, 18, 9, 18, 7, 81, 8, 20, 2, 92, 0, 26, 1,  2, 
    4,  5, 2,  7, 9, 88, 8, 79, 1, 96, 6, 58, 7, 61, 5, 51, 3, 46, 0, 21, 
    8, 40, 0, 58, 2, 52, 6, 61, 3, 48, 7,  5, 9, 76, 4, 19, 1, 35, 5, 79, 
    6, 22, 3, 60, 8,  7, 5, 24, 1, 52, 7, 88, 4, 66, 9, 26, 2, 11, 0, 31, 
    8,  6, 9, 33, 0, 20, 6,  7, 1, 11, 3, 32, 2, 86, 7, 99, 4, 76, 5, 56, 
    3, 76, 4,  6, 0, 66, 9, 90, 2, 34, 1, 80, 6, 87, 7, 27, 5, 10, 8, 23
  };
  const int r314[] = {
    10, 10, // Number of jobs and machines
    0, 74, 7, 58, 9, 17, 5, 69, 8, 19, 3, 39, 1, 33, 6,  3, 2,  2, 4,  8, 
    1, 85, 6, 28, 3,  7, 4, 96, 5, 30, 9, 13, 2, 59, 8, 44, 0, 60, 7, 44, 
    6, 79, 1, 80, 7, 86, 2, 70, 4, 45, 3,  6, 9, 39, 0, 81, 5, 92, 8, 15, 
    4,  9, 0,  6, 2, 65, 1, 18, 8, 62, 3,  7, 7,  6, 9, 20, 5, 79, 6, 67, 
    0, 63, 1, 32, 3, 31, 4, 65, 8, 59, 5, 98, 7, 77, 6, 28, 2, 66, 9, 89, 
    9, 99, 5,  5, 2, 28, 8, 68, 0, 37, 6, 78, 1, 32, 3, 25, 4, 34, 7, 49, 
    2, 73, 8, 28, 3, 17, 0, 69, 9, 26, 7, 90, 6, 83, 5, 61, 4, 26, 1,  2, 
    3, 38, 2, 48, 8, 18, 1, 24, 7, 99, 9, 58, 6, 69, 5, 46, 4, 88, 0, 25, 
    3, 66, 1, 87, 4, 32, 7, 70, 9, 49, 2, 95, 0, 96, 8, 92, 5, 25, 6, 24, 
    4, 20, 2, 43, 8, 70, 3, 55, 9, 92, 0, 85, 1, 83, 7, 30, 6, 22, 5, 12
  };
  const int r315[] = {
    10, 10, // Number of jobs and machines
    3, 79, 6, 97, 9, 81, 7,  6, 4, 24, 0, 60, 8, 94, 5, 73, 2, 71, 1, 96, 
    3, 26, 4, 22, 9, 81, 7,  8, 5, 30, 1, 12, 0, 11, 8, 16, 2, 50, 6, 33, 
    5, 12, 6, 47, 7, 69, 1, 40, 4, 26, 2, 89, 9, 38, 3, 96, 8,  7, 0, 91, 
    0, 38, 6, 29, 8, 48, 3, 63, 7, 13, 4, 58, 2, 84, 9,  2, 5, 80, 1, 53, 
    8, 22, 0, 21, 3, 41, 4, 55, 9, 12, 2, 62, 5, 76, 1, 84, 6,  4, 7, 80, 
    0, 56, 2, 53, 4, 36, 1, 58, 3, 56, 9, 51, 5, 26, 6, 80, 8, 31, 7, 96, 
    7, 95, 8, 50, 0, 55, 9, 64, 1, 92, 5, 20, 6,  4, 2, 69, 3, 61, 4,  3, 
    6, 38, 9, 43, 7,  8, 1,  8, 0, 87, 4, 83, 2, 32, 8, 14, 5, 21, 3, 77, 
    2, 49, 8, 20, 9, 30, 1, 71, 0, 45, 6, 26, 3, 58, 7, 54, 5, 83, 4, 38, 
    6, 66, 3, 88, 4, 47, 7,  6, 0, 83, 5, 59, 1, 28, 2, 63, 9, 61, 8, 11
  };
  const int r316[] = {
    10, 10, // Number of jobs and machines
    7, 45, 9, 62, 0, 90, 8, 98, 6, 12, 3,  6, 4,  9, 2, 74, 1, 38, 5, 50, 
    7,  8, 1,  6, 4, 38, 2, 54, 3,  6, 6, 31, 0, 17, 5, 22, 9, 70, 8, 33, 
    9, 20, 3, 54, 4, 72, 0, 67, 8, 45, 5, 88, 1, 26, 7, 97, 2, 41, 6, 72, 
    5, 78, 3, 64, 2, 50, 7, 28, 4, 32, 6, 13, 8, 98, 9, 36, 0, 50, 1, 47, 
    6, 35, 7, 53, 8, 87, 0, 19, 2, 29, 3, 60, 5, 28, 9, 42, 1, 67, 4, 26, 
    6, 77, 9, 87, 4, 42, 3, 26, 8, 32, 1,  1, 7, 63, 5, 70, 2,  7, 0, 47, 
    0, 37, 4, 42, 9,  8, 1, 15, 7, 58, 2, 40, 5, 73, 8, 77, 3, 70, 6, 46, 
    0, 79, 6,  8, 2, 72, 5, 78, 3, 11, 4, 12, 7, 89, 9,  1, 1, 11, 8, 14, 
    6, 70, 8, 65, 3, 31, 1, 94, 2, 11, 0, 71, 5, 24, 9, 18, 4, 75, 7, 45, 
    3, 22, 0, 23, 9, 60, 2, 76, 4, 98, 1,  9, 8, 67, 7, 26, 5,  2, 6, 82
  };
  const int r317[] = {
    10, 10, // Number of jobs and machines
    7, 59, 5, 29, 0, 70, 3, 10, 1, 69, 6, 69, 9, 34, 2, 72, 4, 11, 8, 94, 
    1, 58, 3, 29, 8, 16, 0, 25, 5, 86, 2, 57, 7, 50, 9, 47, 4, 59, 6,  4, 
    4,  6, 5, 60, 2, 31, 8, 45, 1, 60, 9, 66, 0, 62, 7,  5, 6, 91, 3, 93, 
    0,  7, 4, 72, 8, 51, 9, 64, 3, 72, 7, 59, 5, 88, 1, 49, 2,  6, 6, 96, 
    1, 83, 2, 37, 4, 77, 5, 51, 6, 77, 3, 18, 7, 69, 8, 19, 0, 36, 9,  7, 
    4, 80, 8, 12, 0, 76, 2, 13, 3, 79, 7, 45, 1, 36, 5, 82, 9, 75, 6, 90, 
    9, 71, 0, 27, 5, 85, 3, 42, 1, 56, 4, 70, 7, 68, 6, 77, 8,  5, 2, 93, 
    2, 61, 8, 54, 9, 26, 5, 13, 7, 67, 3,  1, 4, 14, 1, 19, 6, 92, 0, 94, 
    0, 87, 5, 87, 6, 12, 9, 36, 8, 32, 7, 15, 3, 21, 1, 45, 2, 17, 4, 28, 
    6, 17, 5, 81, 3, 36, 2, 36, 1, 92, 9, 17, 4, 85, 8, 90, 0, 24, 7, 76
  };
  const int r318[] = {
    10, 10, // Number of jobs and machines
    8, 59, 3, 46, 4, 60, 1, 15, 7,  5, 2, 65, 5, 36, 9, 18, 0, 95, 6, 50, 
    3, 27, 2, 11, 0, 99, 4, 28, 1, 67, 9, 60, 6,  3, 7, 39, 5, 16, 8, 80, 
    6, 26, 7, 48, 2, 32, 9, 20, 3, 51, 4, 62, 1,  3, 5, 57, 8, 11, 0, 34, 
    2, 79, 1, 67, 0, 46, 8, 22, 6, 69, 9, 59, 4, 33, 5,  4, 7, 32, 3, 20, 
    4, 98, 7, 53, 1, 69, 3, 80, 9, 23, 8,  7, 5, 14, 6, 24, 2, 18, 0, 19, 
    3, 89, 9, 71, 1, 13, 7, 22, 0,  1, 4, 62, 6, 38, 2, 97, 8, 28, 5, 13, 
    1, 96, 2, 33, 3, 69, 4, 81, 7, 96, 8,  2, 5, 96, 0, 77, 9, 66, 6, 96, 
    6, 35, 5, 78, 0, 23, 3,  4, 2, 20, 4, 51, 7, 68, 8, 80, 9, 96, 1, 18, 
    6, 70, 7, 97, 4, 90, 5, 35, 8,  8, 9, 42, 0, 78, 1, 87, 2, 43, 3, 75, 
    7, 22, 5, 29, 8, 43, 4, 15, 1, 32, 6, 86, 9, 44, 2, 77, 3, 40, 0, 89
  };
  const int r319[] = {
    10, 10, // Number of jobs and machines
    3, 97, 5, 11, 1, 81, 8,  5, 7, 13, 9, 92, 4, 39, 0, 59, 6, 97, 2,  7, 
    4, 66, 6, 89, 9, 75, 2, 41, 1, 46, 7, 95, 8,  9, 5, 31, 0, 87, 3, 91, 
    7, 53, 0, 28, 5, 24, 4,  5, 6,  9, 1, 72, 9, 22, 3, 16, 8, 26, 2,  6, 
    9, 18, 3, 26, 2, 88, 4, 70, 7,  5, 5, 45, 6, 47, 8, 41, 0, 39, 1, 25, 
    9,  8, 2, 24, 4, 83, 5,  7, 8, 56, 3, 34, 1, 56, 6, 87, 7, 16, 0, 43, 
    2, 26, 8, 45, 9, 58, 7, 25, 0, 11, 5, 92, 4, 82, 6, 26, 3,  1, 1, 84, 
    4, 85, 7, 75, 8, 45, 1, 84, 2, 74, 6,  8, 9, 13, 5, 31, 3, 18, 0, 30, 
    0, 64, 6, 37, 5, 49, 1, 37, 7, 79, 2,  7, 4, 40, 8, 44, 3, 80, 9, 12, 
    9, 26, 3, 41, 1, 46, 2, 71, 8, 79, 7, 75, 0,  9, 4,  7, 5, 80, 6,  4, 
    9, 95, 7, 43, 0, 34, 4, 72, 1, 26, 5, 94, 3, 75, 8, 91, 2, 62, 6,  4
  };
  const int r320[] = {
    10, 10, // Number of jobs and machines
    9,  3, 3, 13, 1, 11, 2, 24, 6, 72, 0, 74, 5, 76, 4, 23, 7,  6, 8, 56, 
    4, 42, 2, 19, 9, 57, 0, 18, 5, 36, 1, 28, 8,  6, 6, 61, 3, 44, 7, 44, 
    2, 45, 6, 40, 9, 58, 0, 87, 1, 71, 7,  6, 3, 33, 4, 83, 5,  3, 8, 77, 
    2, 59, 0, 12, 6,  1, 9, 59, 1, 93, 3, 56, 7, 10, 4, 80, 8, 54, 5, 75, 
    7, 45, 3,  2, 6, 99, 2, 89, 8,  5, 5, 86, 0, 21, 1, 84, 9, 32, 4, 56, 
    2, 25, 1, 11, 5, 72, 7, 11, 8, 89, 3, 86, 9, 70, 6, 62, 0, 79, 4, 13, 
    3, 99, 6,  4, 8, 72, 4, 10, 5, 92, 2, 50, 0, 78, 1, 55, 7, 16, 9, 32, 
    4, 34, 3, 86, 7, 59, 1, 89, 2, 71, 5, 81, 8, 53, 9, 99, 0, 17, 6, 84, 
    5,  6, 3, 14, 0, 33, 6, 33, 9, 41, 7, 64, 2, 49, 8, 42, 4, 63, 1, 24, 
    4, 46, 5, 57, 0, 56, 2, 17, 7, 48, 8, 96, 1, 23, 6,  3, 9,  1, 3, 88
  };
  const int r321[] = {
    10, 10, // Number of jobs and machines
    8,  9, 3, 77, 7, 81, 6, 29, 9, 10, 2, 48, 4, 89, 5, 93, 1, 80, 0, 55, 
    7, 96, 1, 28, 4, 35, 3, 26, 2, 20, 5, 62, 0,  6, 6, 51, 8, 17, 9, 54, 
    6, 36, 4, 11, 3, 25, 1,  3, 7, 65, 8, 61, 9, 90, 2, 82, 0, 82, 5, 68, 
    8, 44, 9, 11, 2, 60, 7, 46, 4, 39, 6, 42, 1, 39, 5, 60, 0, 28, 3, 30, 
    2, 18, 4,  5, 5, 79, 0, 38, 3, 71, 9, 26, 1, 24, 7, 62, 8, 80, 6, 74, 
    3, 25, 0, 92, 6,  5, 5, 85, 9, 50, 1, 54, 2,  1, 4, 55, 8, 47, 7, 60, 
    8, 62, 9, 23, 3, 53, 7, 94, 5, 99, 6, 46, 1, 32, 0,  9, 2,  5, 4, 68, 
    9, 30, 2, 44, 0, 95, 4, 97, 7, 90, 1, 98, 5, 26, 8, 76, 3, 96, 6, 91, 
    1, 63, 0, 12, 8, 75, 4, 33, 2, 34, 6, 72, 7,  9, 9, 35, 3, 88, 5, 63, 
    3, 37, 6, 86, 2, 48, 4, 62, 1, 77, 0, 44, 9,  9, 5, 27, 8, 65, 7, 30
  };
  const int r322[] = {
    10, 10, // Number of jobs and machines
    6, 10, 8, 47, 4, 22, 7, 43, 0, 91, 5, 51, 3, 93, 9, 72, 1, 39, 2, 37, 
    6, 73, 8, 57, 4, 55, 3, 40, 0,  6, 1, 56, 7, 72, 9, 50, 2, 57, 5, 15, 
    2, 81, 7, 79, 9,  6, 3, 53, 5, 22, 6,  8, 8, 36, 0, 67, 1, 79, 4, 10, 
    3, 84, 7, 47, 5, 60, 8, 35, 4, 51, 6, 80, 1, 18, 2, 60, 0, 45, 9, 20, 
    8,  4, 4, 84, 0, 39, 6, 40, 3, 56, 1,  1, 7, 10, 5, 39, 2, 58, 9, 64, 
    9, 57, 0,  6, 1, 36, 5, 74, 2, 44, 4, 47, 3, 97, 7, 83, 6, 71, 8, 18, 
    5, 41, 3, 60, 8, 97, 4, 56, 0, 24, 1,  7, 2, 25, 6, 63, 7, 76, 9, 51, 
    2, 48, 3, 78, 1, 77, 6, 57, 5, 46, 8, 43, 7, 56, 0, 71, 9, 40, 4, 63, 
    4, 33, 3, 85, 1,  8, 9, 22, 5, 98, 2, 39, 6, 63, 8, 26, 7, 67, 0, 75, 
    9, 40, 3, 27, 2, 85, 7, 78, 0, 45, 1, 30, 6, 15, 5, 16, 4,  5, 8,  5
  };
  const int r323[] = {
    10, 10, // Number of jobs and machines
    4,  3, 7, 54, 2,  2, 5, 80, 9, 90, 6, 37, 8,  9, 0, 58, 3, 98, 1, 25, 
    8, 98, 4,  6, 0, 12, 7, 60, 2, 51, 3, 11, 6, 79, 1, 56, 9, 65, 5, 73, 
    0, 94, 5, 34, 4, 65, 7, 89, 1, 98, 3, 26, 2, 85, 8, 11, 6, 45, 9, 36, 
    0, 70, 3, 68, 7, 48, 6, 55, 1, 99, 9, 25, 5, 60, 2, 49, 8, 39, 4, 31, 
    5, 80, 3, 18, 7, 66, 9, 44, 4, 76, 2, 73, 1, 84, 8, 75, 0, 27, 6, 16, 
    0, 57, 5, 23, 4, 17, 8, 96, 3, 35, 2, 59, 7, 55, 1,  8, 9, 74, 6, 86, 
    2, 12, 8, 25, 3, 54, 9, 28, 4, 69, 6, 84, 7, 96, 0, 80, 5, 28, 1, 30, 
    9, 17, 8, 58, 2, 54, 3, 47, 1,  9, 6, 79, 5, 80, 4, 22, 0, 60, 7, 70, 
    7, 55, 6, 58, 2,  2, 8, 91, 5, 18, 1, 44, 4,  5, 0,  9, 9, 25, 3, 53, 
    3, 25, 5, 17, 4, 12, 1, 38, 6, 77, 7, 97, 8, 26, 0, 76, 9, 88, 2, 21
  };
  const int r324[] = {
    10, 10, // Number of jobs and machines
    1, 55, 7, 67, 2, 35, 4, 11, 8, 88, 6, 45, 9, 33, 3, 85, 0, 90, 5, 53, 
    2, 58, 1, 88, 3, 79, 8, 13, 7,  1, 4, 77, 5, 99, 0, 26, 9, 41, 6, 62, 
    4, 88, 3, 50, 6, 42, 0, 49, 8, 97, 1, 16, 9, 88, 5, 39, 2, 94, 7,  2, 
    1,  2, 5, 32, 3, 80, 6, 43, 7, 17, 8, 61, 4,  6, 2, 55, 0, 67, 9, 41, 
    1, 18, 4, 85, 6, 60, 7, 25, 0, 61, 2, 27, 5, 83, 3, 30, 9, 87, 8, 68, 
    4, 32, 0, 96, 8, 76, 2, 43, 1, 90, 6, 10, 5, 38, 9, 67, 3, 20, 7, 33, 
    9, 39, 5, 44, 0, 36, 2, 34, 3, 66, 6, 26, 1, 75, 7, 33, 8, 57, 4, 46, 
    8, 80, 0, 17, 2, 65, 7, 45, 3, 62, 1, 37, 9, 14, 4, 40, 5, 95, 6, 28, 
    3, 96, 2, 79, 6, 35, 5, 10, 1, 76, 0,  1, 4, 95, 8, 61, 9, 58, 7, 86, 
    1, 21, 7, 89, 0, 81, 2, 64, 4, 64, 8, 34, 3,  6, 9, 55, 6, 52, 5, 70
  };
  const int r325[] = {
    10, 10, // Number of jobs and machines
    9, 70, 4,  5, 0,  5, 2, 85, 5, 54, 1, 32, 3,  9, 6, 33, 7, 30, 8, 22, 
    8, 78, 4,  7, 2, 54, 1, 76, 9, 60, 3, 50, 0, 82, 6, 11, 5, 25, 7, 77, 
    1, 63, 6, 73, 0, 89, 9, 16, 3, 94, 7, 65, 4, 74, 5, 44, 8, 10, 2, 86, 
    2, 36, 0, 83, 7, 45, 5, 55, 3, 90, 1, 90, 6, 97, 8, 65, 9, 25, 4, 51, 
    9,  2, 2, 75, 0, 42, 7, 53, 5, 34, 8, 76, 4, 95, 1, 90, 3, 24, 6, 56, 
    1, 80, 5, 29, 2, 88, 6, 13, 3, 88, 7, 94, 4, 89, 8, 64, 9, 92, 0, 98, 
    9, 34, 0, 81, 1, 17, 7, 97, 5, 18, 2, 45, 3, 55, 8,  2, 4, 82, 6, 89, 
    0, 43, 1, 26, 9, 83, 3, 97, 2, 52, 6, 55, 4, 76, 7,  9, 5, 21, 8, 26, 
    2, 82, 1, 85, 5, 55, 8, 17, 9, 26, 6, 67, 0, 38, 4, 98, 7, 13, 3, 83, 
    1, 49, 4, 80, 6, 61, 7, 40, 0, 30, 9, 48, 3, 13, 8, 33, 2, 75, 5, 16
  };
  const int r326[] = {
    10, 10, // Number of jobs and machines
    2, 73, 7, 52, 8,  6, 5, 73, 0, 81, 9, 53, 1, 74, 4, 24, 6,  9, 3, 48, 
    3, 21, 5,  1, 1, 17, 8, 52, 9, 29, 0, 19, 2, 55, 6, 27, 7, 33, 4,  1, 
    0, 32, 5, 82, 3,  5, 1, 36, 6, 17, 4, 37, 8, 81, 2, 54, 9, 75, 7, 56, 
    3, 90, 2, 97, 0, 91, 7, 90, 1, 51, 9, 55, 8,  8, 5, 30, 6, 10, 4, 65, 
    3,  2, 7, 46, 0, 76, 4, 32, 5, 72, 2, 88, 1, 93, 9, 48, 8, 43, 6, 38, 
    1, 96, 0, 86, 8, 30, 4, 84, 5, 26, 3, 36, 7,  9, 2,  3, 6, 14, 9, 34, 
    2, 46, 6, 32, 9, 12, 3, 80, 7, 57, 4, 74, 1, 43, 8, 56, 0, 11, 5, 99, 
    8, 62, 4, 72, 7, 23, 1, 21, 9, 82, 3, 52, 0, 36, 6, 54, 2, 42, 5, 71, 
    5, 10, 4, 79, 8, 25, 6, 23, 2, 44, 1, 99, 7, 56, 0, 87, 9, 18, 3, 99, 
    8, 52, 3, 11, 2, 61, 4, 35, 5, 99, 9, 82, 6, 11, 7,  9, 1, 70, 0, 66
  };
  const int r327[] = {
    10, 10, // Number of jobs and machines
    4, 20, 8, 38, 2,  9, 9, 53, 7, 48, 3, 34, 0, 30, 1, 19, 5, 11, 6, 85, 
    2, 57, 7, 49, 6, 27, 5, 60, 0, 41, 4, 68, 3, 29, 8, 79, 9, 11, 1,  5, 
    0, 23, 9, 53, 8, 33, 2, 45, 5, 14, 6, 43, 3, 91, 7, 96, 1,  3, 4, 68, 
    4, 47, 3, 55, 7, 17, 2, 73, 8, 80, 6, 85, 1, 76, 5, 15, 0, 80, 9, 51, 
    9, 39, 5, 57, 0, 35, 4, 42, 8, 97, 1, 45, 7, 29, 6, 27, 3, 64, 2, 13, 
    1, 83, 6, 86, 9, 47, 8, 37, 0, 37, 4, 71, 3, 61, 2,  7, 7, 16, 5, 14, 
    2, 30, 9, 79, 7, 40, 6, 84, 4, 69, 0, 97, 8, 70, 3, 52, 1, 29, 5, 76, 
    9, 24, 2, 52, 1, 91, 3, 35, 0, 25, 6,  5, 4, 19, 8, 61, 5,  5, 7, 24, 
    9, 53, 3, 25, 6, 41, 8, 53, 1, 94, 4, 91, 7, 72, 5, 30, 0, 47, 2, 62, 
    4, 17, 7, 43, 5, 75, 9, 41, 0, 76, 2, 93, 8, 75, 3, 94, 6, 94, 1, 30
  };
  const int r328[] = {
    10, 10, // Number of jobs and machines
    4, 47, 0, 12, 8, 32, 6, 91, 3, 27, 5, 57, 2, 92, 1, 23, 9, 77, 7, 35, 
    1,  5, 2, 44, 8, 96, 9, 89, 6, 28, 4, 68, 0, 26, 3, 75, 7,  9, 5, 72, 
    4, 54, 7, 26, 1, 47, 5, 66, 9, 65, 2, 17, 3, 25, 6, 59, 8, 99, 0,  8, 
    2, 79, 4, 57, 9, 29, 7, 77, 8, 64, 0, 46, 6,  4, 3,  8, 5, 11, 1, 38, 
    2, 69, 4, 20, 5, 17, 9, 25, 3, 34, 7, 42, 1, 89, 8, 43, 0, 91, 6,  2, 
    6, 80, 4, 11, 0, 39, 3, 27, 9, 95, 7, 95, 5, 31, 2, 53, 8, 20, 1, 58, 
    3, 70, 7,  5, 8, 11, 4, 10, 0, 25, 5, 27, 2, 19, 6, 42, 9,  2, 1, 63, 
    1, 34, 9, 44, 0, 30, 2, 69, 7, 33, 3, 16, 5, 54, 8, 34, 6, 28, 4, 91, 
    2, 27, 4, 22, 0, 67, 8, 54, 7, 65, 1, 24, 3,  6, 6, 38, 5, 61, 9, 62, 
    4, 15, 6, 81, 7, 60, 9, 54, 5, 71, 3, 45, 2, 86, 0, 69, 1, 82, 8, 14
  };
  const int r329[] = {
    10, 10, // Number of jobs and machines
    9, 69, 1, 66, 2, 99, 4, 72, 7, 51, 0, 24, 3, 38, 5, 92, 8, 89, 6, 73, 
    3, 78, 6, 15, 7,  4, 5, 84, 4, 57, 2, 47, 1, 47, 9, 61, 8, 40, 0, 85, 
    3, 42, 8, 49, 6, 89, 4, 35, 5,  8, 0,  8, 2, 89, 9, 86, 7, 60, 1, 64, 
    1, 18, 6, 69, 3,  3, 9, 16, 0, 67, 8, 99, 5, 53, 2, 31, 4, 63, 7, 20, 
    3, 73, 5, 87, 4, 86, 0, 91, 7, 93, 9, 96, 1, 82, 8, 51, 6, 94, 2, 19, 
    8, 23, 3, 61, 5, 25, 2, 38, 9, 27, 6, 32, 1, 78, 4, 60, 7, 54, 0, 75, 
    6, 38, 5, 12, 8, 19, 4, 43, 1, 42, 7, 77, 3, 26, 0, 16, 2, 60, 9, 77, 
    4, 19, 2, 83, 7,  1, 9, 38, 3, 54, 1, 90, 0, 47, 5, 18, 8,  1, 6, 57, 
    8, 70, 5, 82, 7, 83, 2, 78, 0, 51, 3, 44, 4, 18, 1, 31, 9, 93, 6, 94, 
    1, 10, 6, 46, 4, 84, 8, 30, 9,  8, 7, 45, 2,  5, 3, 68, 5, 76, 0, 37
  };
  const int r330[] = {
    10, 10, // Number of jobs and machines
    6, 13, 4, 83, 7, 44, 9, 37, 2, 91, 1,  6, 8,  3, 3, 55, 5, 68, 0, 68, 
    7, 30, 3,  2, 5, 75, 9, 63, 6,  4, 0, 81, 2, 77, 8, 96, 1, 15, 4, 26, 
    5, 13, 9, 40, 0, 13, 1, 51, 3, 24, 8, 38, 4, 11, 2, 95, 7, 74, 6, 24, 
    1, 95, 0, 94, 6, 92, 2, 64, 9, 70, 3, 56, 8, 34, 5, 99, 4, 15, 7, 53, 
    4, 96, 3, 41, 6, 61, 8, 87, 0, 71, 7, 90, 2, 76, 5, 26, 9,  7, 1, 52, 
    6, 31, 3, 12, 7, 76, 2, 82, 1, 20, 4, 22, 5, 27, 8, 57, 9, 26, 0, 90, 
    6, 51, 7, 65, 1, 34, 5, 23, 2, 25, 4, 57, 8, 47, 0, 39, 9,  9, 3, 57, 
    0, 89, 2, 44, 8, 87, 6, 62, 4, 11, 3, 53, 7, 79, 9, 40, 1, 50, 5, 61, 
    3,  7, 6, 44, 4, 29, 0, 69, 5,  4, 8, 80, 7, 28, 2, 30, 1, 84, 9, 32, 
    2, 30, 5, 20, 8, 19, 1, 74, 7, 79, 3, 67, 6, 20, 4, 57, 9, 63, 0,  6
  };
  const int r331[] = {
    10, 10, // Number of jobs and machines
    5, 72, 8, 30, 3, 88, 2, 14, 6, 63, 1, 92, 9, 47, 0, 11, 4, 20, 7, 71, 
    9, 12, 7, 33, 6, 71, 0, 44, 4, 47, 1, 59, 3, 38, 8, 33, 5, 26, 2, 58, 
    2,  2, 5, 93, 1, 49, 9, 58, 8, 16, 7, 33, 0, 54, 3, 91, 4, 21, 6, 73, 
    2, 55, 1, 51, 5, 36, 8,  3, 6,  4, 9, 24, 7, 24, 0, 86, 4, 50, 3, 71, 
    2, 28, 8, 76, 6, 85, 5, 79, 0,  5, 1, 81, 9, 64, 3, 45, 4, 88, 7, 25, 
    9, 67, 4, 98, 6, 91, 2, 51, 3, 93, 5, 99, 0, 98, 7, 60, 1, 50, 8, 30, 
    7, 67, 4, 23, 0, 53, 1, 24, 3, 74, 9, 52, 8,  2, 2,  4, 6, 66, 5, 83, 
    1, 67, 8, 39, 0, 49, 4, 31, 7, 89, 5, 82, 6, 68, 9, 85, 3, 80, 2, 55, 
    4, 25, 3, 50, 8, 98, 0, 76, 9,  7, 2, 48, 6, 44, 5, 53, 7, 56, 1, 42, 
    6, 24, 8, 20, 5, 30, 1, 72, 0, 88, 9, 95, 2, 11, 4, 99, 3, 20, 7, 21
  };
  const int r332[] = {
    10, 10, // Number of jobs and machines
    1, 21, 3, 76, 4, 75, 6, 53, 2, 73, 0, 93, 7, 92, 9, 63, 5, 98, 8, 95, 
    9,  2, 8, 40, 5, 47, 7, 28, 4, 31, 3, 74, 6,  9, 0,  3, 2, 12, 1, 65, 
    3, 55, 1, 10, 4, 94, 8, 78, 9, 55, 2, 40, 7, 81, 0, 45, 6, 12, 5, 76, 
    4, 17, 0, 47, 3, 12, 9, 22, 7, 49, 6, 30, 2, 56, 5, 15, 1, 91, 8, 36, 
    7, 65, 3, 21, 1, 75, 8, 14, 0, 31, 4, 47, 9, 53, 5, 27, 2, 10, 6, 82, 
    2, 62, 8, 32, 0, 40, 4, 19, 9, 40, 3, 38, 1, 56, 6, 96, 5, 18, 7, 91, 
    3, 43, 2, 42, 9, 47, 6,  5, 0, 77, 1, 37, 7, 49, 8, 48, 4, 73, 5, 65, 
    4, 25, 3,  8, 9, 13, 8, 48, 1, 21, 6, 98, 7, 39, 5, 67, 0, 79, 2, 83, 
    3, 97, 8, 62, 7, 46, 2, 10, 9, 82, 5, 73, 6, 23, 1, 88, 0, 68, 4, 54, 
    4, 14, 2,  6, 7, 34, 9, 43, 1, 46, 5, 50, 3, 75, 6, 98, 8, 49, 0, 57
  };
  const int r333[] = {
    10, 10, // Number of jobs and machines
    2,  9, 8, 73, 0, 65, 6, 66, 1, 59, 7, 51, 4, 49, 9, 59, 3, 99, 5, 14, 
    4, 72, 9, 25, 2, 68, 7, 35, 6, 26, 5, 44, 1, 87, 8, 19, 3, 26, 0, 20, 
    5, 35, 9, 59, 2, 82, 1, 19, 4, 99, 3,  7, 8, 38, 6, 95, 7, 86, 0, 76, 
    8, 72, 3, 66, 7, 57, 5, 35, 6, 86, 1, 72, 4, 40, 2, 82, 0, 60, 9, 93, 
    0, 76, 6, 75, 8, 97, 7, 96, 3, 74, 5, 11, 4, 81, 2, 10, 1, 67, 9, 92, 
    0, 92, 8, 72, 4, 56, 7, 11, 6, 96, 5, 65, 1, 93, 9, 65, 2, 15, 3, 80, 
    1, 52, 0, 67, 5, 54, 6, 11, 4, 11, 9, 40, 7, 66, 2, 72, 3, 38, 8, 93, 
    0, 33, 9, 10, 3, 98, 1, 88, 4, 96, 6, 23, 7, 43, 2,  8, 8, 30, 5, 29, 
    9,  8, 3, 64, 5, 42, 1, 29, 4, 58, 6,  6, 7, 19, 2, 55, 0, 48, 8, 27, 
    0, 17, 7, 16, 8, 63, 6, 43, 2, 28, 5, 44, 4, 51, 3, 54, 1, 28, 9, 50
  };
  const int r334[] = {
    10, 10, // Number of jobs and machines
    2, 92, 3,  3, 0, 84, 6, 76, 4, 62, 8, 43, 1, 55, 7, 20, 5, 78, 9,  3, 
    8, 64, 9, 66, 7, 10, 0,  4, 4, 73, 5, 91, 6, 83, 2, 67, 1, 92, 3, 98, 
    4, 49, 5, 52, 1, 26, 0, 63, 8, 80, 9, 13, 2, 86, 3, 74, 6, 72, 7, 35, 
    6, 83, 7, 92, 4, 48, 5, 28, 3, 31, 2, 74, 9, 86, 8,  4, 0, 28, 1, 13, 
    6, 61, 2, 26, 4, 79, 7,  3, 5, 71, 8,  5, 9, 82, 3, 28, 0, 53, 1, 45, 
    1, 86, 7, 98, 0, 27, 4, 77, 6, 82, 3,  7, 2, 13, 9, 63, 8, 48, 5, 56, 
    2, 82, 5, 75, 4,  9, 1, 69, 7, 15, 0, 15, 8, 76, 9, 54, 6, 67, 3,  5, 
    1, 51, 4, 50, 5, 39, 7, 88, 8, 77, 0, 65, 2,  3, 3, 62, 6, 55, 9, 43, 
    5, 42, 4, 77, 9, 25, 7, 53, 8, 21, 0, 68, 1, 32, 6, 91, 2, 75, 3, 54, 
    4, 18, 1, 54, 9, 30, 3, 50, 8, 67, 0, 27, 5, 62, 6, 27, 2, 47, 7, 46
  };
  const int r335[] = {
    10, 10, // Number of jobs and machines
    6, 27, 7, 62, 5,  2, 4,  9, 2, 60, 3, 62, 1, 53, 9, 33, 8, 22, 0, 73, 
    1,  7, 9,  8, 3, 34, 8, 33, 4, 91, 0, 95, 7, 29, 6, 76, 2,  8, 5, 84, 
    4, 66, 7, 58, 6, 42, 3, 79, 5, 22, 0, 70, 1, 69, 9, 27, 8, 41, 2, 39, 
    2, 58, 8, 96, 3, 21, 0, 25, 4, 18, 5, 48, 7, 32, 9, 98, 1, 58, 6, 75, 
    3, 24, 2, 89, 4, 83, 7, 69, 9, 51, 0, 87, 8, 44, 5, 37, 6, 11, 1,  3, 
    0, 66, 5, 75, 1, 42, 9, 25, 4, 84, 3, 22, 2, 81, 8,  5, 6, 31, 7, 22, 
    9, 97, 4, 60, 5, 73, 3, 80, 1, 47, 8, 18, 7, 73, 2, 42, 6, 60, 0, 99, 
    1, 13, 5, 15, 3, 32, 0, 11, 4, 37, 2, 60, 9,  7, 6, 70, 7, 73, 8, 79, 
    3, 91, 4, 33, 8,  8, 1, 92, 5, 38, 0, 43, 2, 12, 6, 27, 9, 42, 7,  2, 
    4, 66, 6, 56, 3, 44, 0,  7, 1, 89, 2, 66, 9, 30, 7, 55, 5, 58, 8, 44
  };
  const int r336[] = {
    10, 10, // Number of jobs and machines
    1, 60, 8, 21, 9,  3, 3, 30, 7, 93, 6, 77, 2, 61, 4, 53, 0, 18, 5, 88, 
    4, 93, 0, 33, 7, 47, 3, 79, 6, 31, 2, 19, 9, 76, 5, 87, 8, 50, 1, 19, 
    8, 89, 4, 78, 6, 78, 0, 94, 7, 64, 5, 58, 2, 13, 3, 46, 9,  8, 1, 47, 
    5, 41, 6, 74, 9, 12, 4, 41, 0, 42, 7, 66, 2, 43, 3,  7, 8, 55, 1, 25, 
    5, 49, 4,  3, 6, 85, 2, 23, 7, 27, 8, 93, 1,  8, 3, 65, 0, 76, 9, 99, 
    3, 24, 1, 12, 5, 88, 4,  7, 0, 34, 7, 50, 2, 80, 8, 63, 6, 13, 9, 33, 
    0, 72, 4,  2, 7, 59, 5, 51, 1, 56, 2, 92, 6, 29, 8, 61, 9, 70, 3, 45, 
    3, 80, 0, 90, 6, 25, 7, 96, 8, 65, 2, 79, 1, 34, 4, 11, 5, 47, 9, 39, 
    0, 53, 2, 61, 1, 26, 9,  1, 4, 52, 6, 41, 5, 27, 8, 57, 3, 11, 7, 93, 
    2,  6, 0, 61, 9, 68, 4, 50, 3, 29, 5, 59, 1, 75, 6, 50, 7, 31, 8, 64
  };
  const int r337[] = {
    10, 10, // Number of jobs and machines
    2, 70, 6, 72, 9, 45, 7, 28, 3, 94, 1, 50, 0, 34, 5, 22, 8, 55, 4,  9, 
    8, 40, 0, 18, 4, 85, 6, 12, 5, 58, 3, 31, 7, 29, 9, 47, 2, 79, 1, 45, 
    8,  8, 2, 27, 5, 78, 4, 78, 7, 75, 1, 38, 0,  1, 9,  6, 6, 29, 3, 70, 
    2, 64, 7, 62, 3, 62, 8, 52, 6, 61, 4, 89, 1, 13, 5, 53, 0,  8, 9, 68, 
    5, 77, 8, 26, 6, 14, 4, 46, 1, 32, 3, 41, 9, 65, 0,  6, 7, 56, 2, 62, 
    6, 18, 4, 84, 9, 51, 1, 23, 7, 29, 8,  3, 2, 73, 5, 53, 3, 92, 0, 22, 
    4, 29, 8, 61, 3,  4, 1, 90, 7, 62, 2, 64, 6, 69, 5, 55, 0, 26, 9, 36, 
    5, 91, 3,  1, 0, 59, 9, 69, 2, 45, 4, 63, 1, 45, 8, 27, 7,  9, 6, 86, 
    2, 90, 9, 90, 5, 24, 3, 26, 1, 45, 0, 66, 6, 21, 4, 24, 8, 20, 7, 42, 
    8, 18, 9, 38, 6, 33, 1, 74, 2, 31, 4, 20, 5, 54, 0, 78, 7, 90, 3, 12
  };
  const int r338[] = {
    10, 10, // Number of jobs and machines
    2, 30, 9, 90, 7, 81, 6, 64, 3, 25, 0,  5, 1, 54, 4, 35, 8, 67, 5, 91, 
    1, 67, 3, 44, 7, 37, 9, 91, 5, 45, 6, 28, 2, 99, 0, 30, 4, 83, 8, 69, 
    9, 48, 8,  6, 2, 26, 0, 53, 3, 15, 6, 70, 7, 70, 1, 92, 4, 13, 5, 72, 
    1, 78, 4, 15, 6, 64, 7, 70, 9, 49, 0, 89, 3, 72, 5, 75, 2, 31, 8, 57, 
    7, 82, 5, 85, 3, 86, 8, 63, 4, 10, 2, 84, 1, 26, 9, 45, 6,  5, 0,  3, 
    6,  3, 2, 99, 8, 38, 5, 63, 9, 63, 7, 41, 1, 78, 3, 47, 4,  7, 0, 70, 
    1, 30, 4, 88, 7,  7, 0, 32, 5,  7, 2, 58, 9,  3, 3, 64, 6, 92, 8, 79, 
    3, 65, 2, 76, 7, 83, 4, 62, 0, 50, 1, 76, 5, 65, 6, 89, 8, 15, 9, 31, 
    3, 23, 6, 97, 8, 76, 4, 66, 7, 57, 0, 50, 5, 32, 1, 30, 2, 22, 9, 66, 
    7, 28, 4, 75, 2, 64, 5,  6, 1, 69, 6, 60, 0, 64, 9, 19, 3, 85, 8, 16
  };
  const int r339[] = {
    10, 10, // Number of jobs and machines
    1, 53, 5, 52, 4,  8, 3, 96, 0, 60, 6, 44, 7, 80, 2,  2, 9, 75, 8, 71, 
    1, 62, 5, 34, 9, 40, 0, 45, 6, 68, 2, 38, 8, 48, 3,  9, 7, 43, 4, 97, 
    5, 42, 1, 40, 8,  7, 3, 45, 6, 65, 7, 41, 0, 82, 9, 19, 4, 54, 2, 33, 
    6, 48, 8, 44, 7, 31, 9, 76, 0, 11, 5, 91, 1, 42, 2, 80, 4, 27, 3, 23, 
    1, 11, 8, 24, 9, 26, 7, 19, 4, 69, 6, 22, 5, 14, 3, 77, 2, 76, 0, 32, 
    6, 93, 4, 87, 0, 29, 5, 78, 7, 42, 3, 51, 9, 96, 2, 91, 1,  8, 8,  4, 
    9, 70, 8, 65, 4, 71, 0,  8, 6, 52, 5,  3, 1,  1, 7, 18, 3, 40, 2, 58, 
    9, 81, 0, 50, 2, 64, 4, 69, 3, 30, 5, 52, 6, 72, 1, 21, 7, 17, 8, 14, 
    2,  6, 5, 96, 0, 68, 4, 44, 3,  3, 6, 35, 7, 80, 1,  3, 9, 99, 8, 77, 
    5, 87, 9, 18, 1, 90, 6, 28, 4,  4, 0, 84, 7, 15, 2, 63, 8, 57, 3, 71
  };
  const int r340[] = {
    10, 10, // Number of jobs and machines
    6, 77, 4, 10, 0, 37, 1, 96, 9, 16, 7, 67, 5, 57, 8, 45, 3, 38, 2, 61, 
    8, 61, 6, 19, 3, 15, 7, 11, 5, 98, 2,  5, 9, 85, 4, 78, 1, 74, 0, 57, 
    7,  6, 4, 13, 8, 93, 1, 90, 2, 60, 0, 26, 5, 40, 9, 25, 6, 83, 3, 35, 
    1, 83, 8, 72, 7, 57, 3, 17, 2, 69, 4, 67, 9, 97, 5, 15, 0, 30, 6, 15, 
    5, 77, 3, 96, 8, 76, 6, 37, 4, 99, 7, 14, 1, 36, 9, 54, 0, 58, 2, 41, 
    7, 80, 8, 95, 4, 21, 2,  7, 9, 99, 3,  5, 6, 73, 1,  1, 5, 94, 0, 88, 
    6, 14, 1, 14, 8, 29, 7, 72, 4, 13, 9, 87, 5, 79, 3, 21, 2, 79, 0, 26, 
    3, 43, 2, 67, 5, 67, 7, 89, 1, 71, 8, 26, 4, 34, 9,  1, 6, 13, 0, 30, 
    3, 89, 9, 16, 4, 54, 0, 85, 1, 62, 5, 19, 7, 33, 2, 36, 6, 41, 8, 40, 
    5, 51, 7, 75, 6, 60, 9, 71, 8, 93, 2, 34, 1, 61, 4, 21, 0, 73, 3, 95
  };
  const int r341[] = {
    10, 10, // Number of jobs and machines
    5, 94, 8, 51, 4,  7, 1, 17, 2, 33, 9, 22, 0, 98, 3, 20, 6, 66, 7, 40, 
    4, 82, 8, 76, 0, 95, 1, 79, 2, 84, 6,  6, 9, 66, 5, 23, 3, 26, 7, 43, 
    4, 79, 3,  8, 8, 40, 6, 30, 9, 27, 0, 92, 5, 41, 7, 77, 1, 65, 2,  4, 
    8, 37, 7,  6, 5, 73, 4, 11, 6, 63, 0, 44, 1,  3, 2, 41, 3, 87, 9, 66, 
    1, 58, 8, 51, 0, 13, 3, 15, 9, 41, 6, 75, 2,  7, 7, 95, 5, 66, 4, 77, 
    9, 62, 3,  7, 8, 61, 2, 70, 1, 98, 5, 32, 0, 83, 4, 60, 7, 57, 6, 20, 
    6,  4, 1, 54, 5,  6, 7,  8, 2, 73, 3, 17, 8, 43, 4, 20, 0, 42, 9, 93, 
    3, 98, 4,  3, 7, 53, 5, 10, 2, 65, 6, 66, 8, 95, 9, 26, 1, 43, 0, 88, 
    6,  8, 1, 31, 4, 90, 8, 79, 0, 67, 2,  1, 3, 16, 7, 23, 9, 66, 5, 15, 
    5, 36, 7, 45, 0, 53, 3, 57, 1, 45, 8,  5, 9, 30, 4, 94, 6, 92, 2, 59
  };
  const int r342[] = {
    10, 10, // Number of jobs and machines
    3, 48, 1, 59, 2,  6, 9, 41, 0, 60, 4, 96, 6, 51, 7, 88, 8, 96, 5, 70, 
    3, 45, 2,  7, 4, 47, 1, 87, 6, 79, 8, 30, 7, 16, 5, 58, 0, 95, 9, 79, 
    2, 21, 7, 92, 8, 34, 3, 48, 1, 21, 4, 14, 0, 23, 9, 47, 5, 42, 6, 55, 
    7, 41, 1, 39, 5, 40, 4, 51, 9, 80, 2, 96, 0, 29, 6, 81, 3, 79, 8, 73, 
    2, 96, 7, 64, 1, 78, 6, 40, 3, 72, 5, 23, 4, 65, 8,  8, 0, 52, 9, 65, 
    5,  5, 4, 90, 9, 34, 6, 96, 3, 96, 8,  6, 1, 28, 2,  6, 7, 61, 0, 56, 
    8, 86, 1, 84, 0, 86, 9,  8, 4, 33, 3, 75, 6, 43, 5, 79, 2, 58, 7, 23, 
    6,  7, 1, 76, 7, 77, 9, 83, 5, 69, 8,  6, 4, 61, 0, 78, 2, 36, 3, 28, 
    9, 14, 0, 48, 8, 98, 2, 14, 7, 60, 1,  4, 5, 54, 6, 26, 3, 53, 4, 84, 
    4, 13, 2, 12, 5, 12, 9, 89, 8, 28, 1, 95, 7, 15, 6, 71, 3, 98, 0, 23
  };
  const int r343[] = {
    10, 10, // Number of jobs and machines
    2, 14, 4, 13, 5,  9, 1, 57, 9, 32, 7, 56, 6, 41, 0, 95, 8, 61, 3, 77, 
    3, 22, 1, 53, 0, 15, 5, 75, 8, 14, 4,  8, 9, 88, 6, 13, 2, 71, 7, 83, 
    0, 42, 7, 51, 1, 65, 8, 63, 5, 80, 6, 95, 3, 40, 9, 91, 2, 75, 4, 45, 
    9,  4, 1, 21, 2, 15, 8, 15, 6, 23, 0, 63, 4, 33, 3, 64, 5, 20, 7, 16, 
    7, 53, 6, 24, 5, 42, 0,  6, 4, 81, 1, 13, 2, 35, 9, 86, 3, 15, 8,  9, 
    0, 89, 2, 20, 1, 19, 3, 47, 9, 63, 7, 26, 8, 78, 4, 88, 5,  1, 6, 75, 
    5, 56, 1, 80, 8, 10, 9, 62, 0, 56, 7, 85, 4, 74, 2, 18, 3, 41, 6, 27, 
    4, 21, 8, 37, 3, 13, 5, 45, 6, 31, 9, 99, 1, 48, 2, 91, 7, 76, 0,  4, 
    9, 16, 0, 26, 1, 94, 8, 99, 7, 97, 3, 14, 2, 15, 6, 89, 5, 36, 4, 60, 
    2,  7, 1, 31, 0,  5, 3, 44, 7, 51, 4, 80, 9, 28, 5, 22, 8, 51, 6, 38
  };
  const int r344[] = {
    10, 10, // Number of jobs and machines
    7, 20, 0, 27, 5, 61, 8, 71, 9, 24, 2, 68, 6,  7, 3, 97, 4, 67, 1, 51, 
    7, 35, 5, 97, 1, 74, 8, 69, 4, 10, 0, 77, 6, 68, 2, 90, 3, 43, 9,  3, 
    4, 41, 9, 46, 5, 57, 7, 37, 3, 21, 8, 65, 0, 12, 6, 28, 2,  9, 1, 35, 
    8, 68, 3, 78, 2, 85, 4, 50, 5, 78, 6, 75, 1, 48, 9, 78, 7,  1, 0, 17, 
    0, 10, 9, 56, 5, 42, 8, 95, 6, 57, 1, 11, 4, 91, 2, 92, 3, 11, 7, 36, 
    7, 18, 9, 29, 5, 47, 4,  2, 8, 19, 2, 97, 0, 47, 1,  5, 6, 89, 3, 46, 
    2, 69, 6, 40, 0, 30, 3, 71, 4, 99, 7, 91, 5, 36, 1, 28, 8, 98, 9, 69, 
    2, 49, 6, 68, 1, 67, 0, 16, 7,  5, 3, 62, 4, 26, 5, 83, 8,  8, 9, 37, 
    0, 97, 2,  8, 8, 79, 6, 67, 1, 76, 3, 91, 5,  3, 9, 63, 4, 49, 7,  9, 
    0,  5, 4, 74, 9, 51, 5, 52, 7, 29, 8, 45, 1, 15, 2,  8, 6, 53, 3, 19
  };
  const int r345[] = {
    10, 10, // Number of jobs and machines
    0, 89, 7, 24, 9, 73, 3, 48, 6, 33, 5, 92, 1, 72, 4, 72, 8, 70, 2,  9, 
    3,  7, 4, 15, 0, 77, 5, 48, 6, 12, 8, 92, 1, 54, 9, 53, 7, 95, 2, 96, 
    5, 38, 8, 78, 9, 62, 1, 13, 3, 43, 2, 50, 7, 20, 4, 24, 6,  6, 0, 75, 
    2, 65, 5, 41, 9, 39, 1, 11, 6, 65, 0,  2, 7,  3, 4, 20, 8,  6, 3, 75, 
    5,  1, 2, 33, 1, 14, 4, 50, 9, 16, 0,  2, 3, 53, 6, 40, 8, 45, 7, 39, 
    7, 62, 0, 55, 3, 56, 8, 25, 6, 35, 2,  9, 4, 91, 1, 18, 5, 20, 9,  4, 
    8, 36, 7, 94, 5, 69, 6, 31, 1, 94, 4, 80, 2, 55, 0, 56, 3, 55, 9, 48, 
    4, 81, 9, 37, 5, 63, 2, 51, 3, 45, 6, 92, 1, 69, 0, 66, 8, 86, 7, 94, 
    6, 47, 1,  7, 2,  9, 7, 65, 5, 75, 8, 71, 0, 84, 3, 90, 9, 12, 4, 70, 
    4, 76, 9, 12, 5, 55, 2, 17, 7, 66, 1, 51, 3,  7, 0, 74, 8, 18, 6, 33
  };
  const int r346[] = {
    10, 10, // Number of jobs and machines
    7, 20, 4, 80, 0, 92, 9, 23, 2, 73, 6, 16, 1, 96, 8, 97, 3, 69, 5, 98, 
    3, 69, 2, 24, 7, 46, 8, 69, 1, 35, 4, 83, 5, 57, 9, 98, 6, 65, 0, 32, 
    1, 20, 5, 88, 6, 38, 3, 87, 8, 73, 9, 30, 0, 86, 2, 85, 4, 24, 7, 85, 
    2, 61, 3, 67, 0, 49, 6,  3, 7, 54, 9, 97, 1, 80, 5, 42, 8, 21, 4, 11, 
    4, 33, 8, 84, 2, 63, 5, 66, 9, 82, 6, 20, 7, 81, 1, 16, 0, 33, 3, 88, 
    0,  3, 9, 42, 3, 19, 4, 23, 7, 98, 8, 23, 5, 25, 2, 10, 6, 51, 1, 24, 
    6, 57, 0, 26, 2, 34, 1, 96, 7, 58, 5, 86, 8, 34, 4, 70, 3, 45, 9, 58, 
    6, 23, 2, 59, 4, 96, 8, 47, 3, 45, 9,  6, 7, 71, 5, 75, 1, 23, 0, 57, 
    5, 10, 9, 76, 8, 69, 3, 41, 7, 82, 6, 91, 4, 21, 1, 10, 2, 26, 0, 70, 
    1, 46, 4, 83, 7, 45, 0, 66, 8, 48, 6, 26, 9, 69, 3,  5, 5, 53, 2, 91
  };
  const int r347[] = {
    10, 10, // Number of jobs and machines
    5, 66, 2, 73, 3, 54, 7, 96, 1, 13, 6, 66, 9, 27, 8, 81, 4, 37, 0, 91, 
    8, 97, 5, 33, 9, 97, 7, 21, 3, 35, 4,  3, 6, 67, 1, 64, 0, 47, 2, 64, 
    4, 40, 6, 12, 1, 53, 2, 73, 5, 70, 0, 29, 7,  9, 9, 22, 8, 85, 3, 17, 
    0, 90, 9, 88, 1, 79, 4,  4, 7, 20, 5, 69, 2, 30, 8, 92, 3, 11, 6, 33, 
    0, 90, 4, 20, 3, 96, 1, 81, 9, 96, 8, 48, 2, 75, 5, 69, 7, 43, 6,  2, 
    0, 24, 7, 90, 1, 74, 4, 88, 6, 57, 3, 20, 9, 26, 5, 47, 8, 94, 2, 65, 
    9, 52, 4, 54, 3, 64, 6, 61, 0, 17, 7, 39, 5, 14, 2, 27, 1, 77, 8, 86, 
    5, 78, 8, 73, 3, 98, 1, 57, 0, 89, 9, 92, 6, 27, 2, 50, 7, 16, 4, 33, 
    2, 27, 7, 32, 8, 31, 1, 16, 9, 35, 0, 96, 5,  6, 4, 24, 3, 24, 6, 18, 
    8, 78, 2, 25, 5, 14, 1, 65, 4,  7, 9, 20, 7, 76, 6, 43, 0, 98, 3, 62
  };
  const int r348[] = {
    10, 10, // Number of jobs and machines
    4, 52, 9, 95, 7, 10, 1, 65, 8, 78, 0, 27, 5, 58, 2,  6, 6, 63, 3, 69, 
    5, 51, 3, 68, 6,  7, 8, 83, 9,  4, 7, 24, 0, 57, 1, 54, 2, 53, 4,  4, 
    8, 29, 1, 71, 6, 32, 3, 72, 9, 11, 7, 25, 2, 31, 4,  5, 5, 69, 0, 78, 
    0, 84, 1, 55, 6, 83, 3, 42, 8, 63, 2,  9, 4, 63, 9, 89, 5, 86, 7, 19, 
    8, 68, 2, 26, 7, 46, 9,  8, 5, 80, 4, 96, 6, 82, 1, 20, 0, 77, 3, 50, 
    8, 46, 4, 31, 9, 43, 6, 81, 3, 56, 1, 75, 0, 85, 2, 83, 7,  5, 5, 29, 
    4, 60, 5, 68, 8, 42, 2, 33, 7, 87, 3,  1, 0, 36, 9, 50, 1, 48, 6, 34, 
    8, 78, 3, 53, 7, 48, 9, 33, 6, 11, 2, 72, 5, 58, 1, 10, 0, 84, 4, 97, 
    6, 21, 8, 91, 4, 28, 1, 33, 7, 52, 3, 53, 9, 74, 2, 40, 0, 95, 5, 24, 
    4, 65, 9, 64, 8, 97, 2, 57, 5, 70, 6, 51, 1, 21, 0, 61, 3, 30, 7, 68
  };
  const int r349[] = {
    10, 10, // Number of jobs and machines
    4, 11, 8,  7, 2, 27, 9, 76, 0,  6, 1, 12, 5, 68, 6, 81, 7,  3, 3, 83, 
    1, 18, 3, 63, 4, 63, 5,  4, 6, 49, 7, 41, 0, 12, 2, 48, 8, 69, 9, 23, 
    0, 76, 7,  7, 3, 39, 9, 29, 5, 88, 1, 88, 2, 57, 4, 20, 6, 99, 8, 96, 
    5, 52, 4, 84, 2, 71, 7, 19, 8, 56, 1, 74, 9, 23, 0, 84, 3, 88, 6, 98, 
    0, 19, 9, 74, 1,  1, 6, 20, 7, 72, 2, 37, 8, 38, 4, 60, 3, 46, 5,  7, 
    5, 43, 1, 57, 2, 18, 3, 49, 6,  2, 9, 95, 8, 19, 0, 27, 4, 10, 7,  1, 
    1, 44, 5,  8, 2, 96, 4, 76, 3, 43, 9, 22, 0, 47, 6, 33, 8, 83, 7, 29, 
    1, 19, 6, 89, 5,  1, 9, 27, 4, 24, 3, 81, 7, 59, 0,  8, 2, 50, 8, 18, 
    4, 85, 7, 37, 9,  4, 3, 38, 8, 57, 6, 12, 0, 40, 5, 82, 2, 91, 1, 71, 
    9, 17, 6,  4, 1,  9, 2, 20, 3, 83, 5, 50, 0, 85, 7, 69, 4, 59, 8, 94
  };
  const int r350[] = {
    10, 10, // Number of jobs and machines
    3, 11, 9,  8, 7, 23, 0, 35, 6,  1, 2, 26, 8, 98, 4, 68, 5, 87, 1, 16, 
    3, 36, 7, 75, 9, 49, 8, 97, 5, 35, 0, 94, 4, 47, 6, 46, 1, 70, 2, 73, 
    8, 74, 6, 20, 1, 42, 4, 91, 2, 27, 7, 70, 9, 36, 5,  4, 3, 60, 0, 71, 
    4, 75, 0, 92, 1, 63, 7, 14, 2, 49, 9, 77, 6, 78, 5, 85, 3, 45, 8, 11, 
    2, 33, 4, 77, 0, 83, 6, 52, 3, 82, 5, 56, 7, 97, 9,  9, 8, 86, 1, 63, 
    7, 99, 1,  5, 3, 26, 6, 76, 0, 82, 2, 36, 9, 46, 5, 43, 8, 82, 4, 14, 
    4, 65, 0, 43, 1,  2, 9, 30, 7, 19, 8, 31, 6, 54, 2, 65, 3, 85, 5, 39, 
    9, 19, 4, 35, 3, 41, 6, 40, 0, 94, 1, 28, 8, 97, 7, 67, 2, 31, 5, 29, 
    3, 29, 8, 79, 0, 86, 6, 84, 1, 47, 5, 44, 9, 45, 4, 40, 2, 77, 7, 24, 
    1, 62, 8, 37, 4, 41, 0,  7, 7, 31, 5, 43, 6, 11, 2, 32, 9, 90, 3,  3
  };
  const int r351[] = {
    10, 10, // Number of jobs and machines
    0, 35, 9, 84, 5, 70, 6, 26, 7, 49, 8, 18, 1, 78, 3, 82, 4, 74, 2,  5, 
    9, 36, 0, 97, 7, 30, 6, 58, 3, 57, 2, 70, 1, 34, 8, 93, 4, 49, 5, 80, 
    6, 21, 7,  1, 5, 91, 9, 20, 2, 53, 8,  7, 0, 91, 4, 29, 1, 84, 3, 28, 
    6, 32, 0, 39, 9, 33, 5, 21, 2, 22, 8, 89, 4, 98, 7, 82, 1, 47, 3, 40, 
    5, 96, 8, 14, 4, 53, 9, 29, 2, 27, 6,  7, 1, 59, 0, 34, 7, 96, 3, 13, 
    1,  7, 9, 70, 4, 85, 8, 87, 3, 75, 0, 19, 2, 79, 5, 69, 7,  8, 6, 13, 
    7, 24, 8, 47, 5, 91, 2, 82, 9, 64, 1, 97, 6, 86, 4, 47, 3, 47, 0, 98, 
    4, 75, 3, 28, 8,  6, 0, 28, 6, 46, 1, 60, 5, 47, 7, 64, 2,  4, 9, 67, 
    2, 32, 4, 62, 9, 33, 1,  4, 0, 20, 8, 79, 5, 58, 3, 32, 7, 76, 6, 68, 
    5, 40, 0, 76, 2, 81, 8,  2, 4, 80, 6, 79, 3, 82, 9, 14, 7, 19, 1, 86
  };
  const int r352[] = {
    10, 10, // Number of jobs and machines
    0, 35, 3, 90, 8, 89, 6, 76, 9, 79, 1, 69, 2, 49, 7, 84, 5, 71, 4, 71, 
    3, 81, 1,  3, 4,  4, 8, 87, 6, 44, 0,  8, 5, 74, 2, 49, 7, 43, 9, 25, 
    5, 91, 8, 24, 0, 45, 7, 52, 4, 42, 1,  5, 9, 93, 2, 96, 3, 10, 6, 68, 
    3, 74, 1, 37, 6, 17, 5, 68, 8, 22, 0, 76, 7, 22, 9, 43, 2, 35, 4, 47, 
    1,  8, 3, 49, 8, 45, 2, 14, 7, 14, 0, 30, 6, 99, 9, 29, 4, 37, 5, 66, 
    6, 74, 2, 83, 7, 77, 5, 87, 9, 66, 8, 44, 0, 99, 4, 11, 3, 76, 1, 45, 
    7, 10, 2, 85, 5, 54, 0, 82, 1, 85, 6,  4, 4, 51, 9, 10, 8,  8, 3, 30, 
    8, 73, 0, 20, 3, 34, 4, 25, 5, 73, 2, 89, 9, 97, 1, 13, 6, 49, 7, 30, 
    2, 94, 3, 50, 9,  3, 7, 40, 6, 96, 4, 95, 5, 45, 1, 91, 8, 70, 0, 88, 
    0, 56, 5, 75, 3, 56, 2, 47, 1, 15, 6, 56, 4, 81, 9, 46, 7,  7, 8, 85
  };
  const int r353[] = {
    10, 10, // Number of jobs and machines
    1,  6, 5, 11, 8, 86, 7, 54, 4, 89, 9, 62, 3, 45, 6, 39, 0, 46, 2, 50, 
    5, 81, 3, 96, 2, 70, 6, 96, 8, 46, 9, 77, 0,  3, 7,  7, 1, 57, 4, 43, 
    5, 51, 1,  1, 6, 14, 7, 88, 2, 26, 8, 80, 9, 16, 3, 22, 0, 72, 4, 10, 
    4, 74, 0, 24, 6, 60, 8, 33, 9,  6, 3, 18, 5, 39, 7, 14, 1, 54, 2,  9, 
    2, 63, 6,  5, 9,  8, 1, 82, 7, 66, 4, 23, 0, 56, 8, 65, 5, 61, 3, 46, 
    0, 36, 1, 25, 6, 72, 3, 95, 4,  1, 2, 37, 8, 81, 7, 90, 9, 18, 5, 56, 
    9, 57, 6,  6, 4, 55, 3, 36, 5, 72, 1, 83, 7, 15, 8, 22, 2, 61, 0, 38, 
    3, 69, 9, 35, 0, 20, 6, 69, 4, 14, 7, 77, 2,  9, 8, 65, 5, 50, 1, 48, 
    7, 31, 1, 40, 2, 31, 8, 26, 6,  1, 9, 94, 3, 28, 5, 76, 0, 59, 4, 61, 
    7, 96, 2, 98, 8, 39, 0, 48, 9, 79, 6, 42, 5, 63, 1, 78, 3, 68, 4, 94
  };
  const int r354[] = {
    10, 10, // Number of jobs and machines
    9, 37, 1, 16, 7, 47, 5, 70, 3, 28, 2,  2, 4, 49, 6, 61, 0, 11, 8, 71, 
    7, 80, 8, 87, 3, 75, 2, 63, 1, 52, 4, 73, 9, 39, 6, 30, 0, 18, 5, 36, 
    1, 92, 5, 85, 9, 40, 7, 10, 0, 57, 2, 12, 6, 48, 3, 35, 4, 18, 8, 56, 
    3, 72, 2, 34, 9,  8, 7, 96, 8, 99, 4, 11, 5, 85, 0, 41, 6, 97, 1, 12, 
    8, 99, 2, 90, 1, 70, 3, 32, 6, 74, 7, 86, 4, 23, 5, 49, 9, 82, 0, 72, 
    2, 14, 8, 49, 1, 38, 3, 10, 7,  3, 4, 73, 5, 52, 9, 37, 6, 59, 0, 32, 
    9, 98, 2, 74, 3,  9, 5, 90, 8, 22, 1, 34, 7, 61, 0, 83, 4, 32, 6, 32, 
    6, 22, 2, 60, 0,  8, 7,  7, 3, 82, 5, 45, 9, 18, 8, 73, 1, 29, 4, 34, 
    9, 66, 6, 72, 5, 34, 7, 28, 4, 62, 8, 90, 1, 32, 2, 39, 0, 28, 3, 28, 
    6, 45, 1, 61, 5, 86, 0, 62, 3, 34, 2, 69, 7, 73, 8, 44, 9, 37, 4, 66
  };
  const int r355[] = {
    10, 10, // Number of jobs and machines
    0, 45, 8, 93, 4, 76, 6, 24, 1, 69, 7, 48, 9, 43, 3,  8, 5, 18, 2, 45, 
    3, 23, 8, 98, 7,  6, 4, 60, 2, 76, 9, 65, 1, 72, 0, 55, 5, 83, 6, 56, 
    1, 92, 7, 94, 2, 23, 0, 85, 9, 64, 8, 40, 5, 43, 4, 18, 6,  7, 3, 59, 
    1, 21, 9, 12, 3, 78, 8, 52, 7, 78, 5, 22, 6, 68, 2, 48, 4, 58, 0, 18, 
    2, 53, 0, 78, 7, 13, 3, 55, 1, 57, 8, 86, 4, 20, 6, 71, 5, 32, 9, 16, 
    6, 43, 3, 26, 5, 99, 8, 49, 1, 17, 0, 71, 9, 10, 2, 17, 7, 94, 4, 74, 
    6, 70, 3, 73, 2, 26, 9, 51, 8, 38, 1,  6, 5, 33, 7, 26, 0, 96, 4, 65, 
    5, 64, 2, 17, 6, 38, 1, 42, 9, 87, 7, 16, 4, 99, 3, 66, 8, 68, 0, 82, 
    1, 40, 4, 87, 6, 45, 8, 89, 9, 33, 5, 33, 0, 62, 3, 65, 7, 35, 2, 29, 
    9, 16, 4, 88, 2, 11, 6,  9, 8, 29, 7, 18, 0, 65, 5, 43, 1, 76, 3, 50
  };
  const int r356[] = {
    10, 10, // Number of jobs and machines
    6, 74, 5, 69, 4,  2, 0, 60, 3, 36, 2, 77, 8, 17, 1,  2, 9, 89, 7, 86, 
    4, 72, 5, 91, 6, 17, 2, 51, 0, 87, 7, 61, 1, 68, 9, 49, 3, 61, 8, 26, 
    1, 48, 0, 22, 8, 78, 7, 13, 6, 10, 2, 84, 3, 12, 4, 52, 5, 53, 9,  1, 
    0,  5, 7, 54, 3, 35, 5, 89, 4, 29, 9, 89, 2, 23, 6,  2, 8,  2, 1, 25, 
    8, 62, 7,  1, 6, 55, 3, 66, 2, 22, 9, 91, 0, 19, 5, 78, 4, 75, 1, 18, 
    5,  5, 0, 56, 8, 88, 1, 76, 7, 59, 9, 97, 6, 52, 4, 78, 2, 21, 3,  6, 
    7, 92, 8, 80, 4, 39, 3, 78, 1,  6, 5, 35, 9, 81, 2, 33, 0, 70, 6, 85, 
    6, 83, 8, 93, 2, 95, 4, 85, 1, 27, 9, 84, 5, 31, 7, 79, 0, 72, 3, 75, 
    7, 62, 4, 70, 8, 67, 2, 36, 0, 27, 6, 27, 5, 41, 9, 51, 3, 22, 1, 16, 
    4, 12, 1, 26, 9, 72, 2, 54, 5, 37, 6, 39, 0, 63, 7, 91, 8, 34, 3, 22
  };
  const int r357[] = {
    10, 10, // Number of jobs and machines
    0, 30, 4, 34, 7, 88, 5, 20, 2, 56, 6, 53, 3, 40, 9, 43, 1, 62, 8, 28, 
    9, 44, 3, 16, 5, 42, 6, 17, 7, 44, 8, 44, 2, 10, 4,  1, 0, 41, 1, 90, 
    0,  7, 4, 98, 9,  1, 6, 73, 2, 35, 3, 94, 5, 10, 7, 32, 1, 31, 8, 95, 
    9, 17, 1, 91, 2, 39, 6, 15, 8, 17, 3, 38, 5, 38, 7, 37, 4, 53, 0, 90, 
    4, 63, 7, 86, 0, 68, 2, 41, 3, 58, 6, 42, 1, 49, 9, 84, 5, 59, 8, 77, 
    4, 35, 3,  3, 7, 71, 5, 60, 0, 83, 6, 83, 8, 39, 9, 44, 2, 47, 1, 76, 
    0, 96, 2, 66, 8, 50, 9, 17, 1, 77, 4, 98, 5, 32, 7, 16, 6, 31, 3, 82, 
    5, 83, 7, 30, 2,  5, 8, 97, 9,  8, 0,  4, 1, 25, 3, 39, 4, 86, 6, 29, 
    2,  1, 5, 44, 4, 83, 3, 67, 6, 50, 8, 85, 9, 23, 0, 38, 7, 68, 1,  7, 
    4, 48, 3, 33, 9, 75, 2, 32, 7, 91, 6, 24, 1, 47, 5, 30, 0, 56, 8, 51
  };
  const int r358[] = {
    10, 10, // Number of jobs and machines
    9, 78, 6, 62, 1, 99, 5, 71, 7, 32, 8, 17, 2, 35, 3, 40, 4, 16, 0, 92, 
    2, 57, 9, 62, 7, 95, 5, 30, 0, 70, 3, 13, 4, 85, 1, 19, 6, 70, 8, 90, 
    2, 26, 0, 64, 1, 60, 3,  5, 5, 80, 7,  5, 6, 63, 9, 49, 4, 55, 8,  8, 
    8, 45, 6, 45, 7, 92, 9, 85, 4, 37, 2, 19, 1, 56, 3, 47, 0,  4, 5, 83, 
    9, 50, 4,  9, 6, 79, 5, 64, 8, 13, 0, 52, 2, 60, 7,  3, 3, 16, 1,  9, 
    8, 64, 5, 58, 4, 45, 6, 34, 3, 39, 0,  6, 1, 64, 7, 28, 2, 59, 9, 75, 
    6, 18, 8, 74, 5, 71, 7, 78, 9, 96, 0, 34, 2, 14, 3, 47, 1, 74, 4, 57, 
    0, 84, 1, 23, 7, 78, 3, 19, 5, 22, 2, 81, 9, 80, 8,  4, 4, 53, 6, 59, 
    9, 34, 5,  4, 8, 55, 2, 88, 7, 66, 3,  3, 0, 20, 6, 46, 4, 11, 1, 13, 
    0,  9, 8, 61, 7, 61, 6,  6, 9, 39, 1, 93, 5, 15, 4, 27, 2, 81, 3, 11
  };
  const int r359[] = {
    10, 10, // Number of jobs and machines
    7, 88, 0, 62, 3, 26, 8, 90, 6, 55, 2, 53, 5, 41, 9, 29, 1, 44, 4, 77, 
    3, 74, 4,  6, 0, 29, 1, 35, 5, 14, 9, 18, 8, 11, 6, 45, 7, 36, 2, 93, 
    1, 64, 2, 66, 3, 90, 7, 89, 4, 17, 5, 15, 9, 54, 0, 79, 8, 41, 6, 14, 
    3, 32, 5, 17, 2, 67, 7, 13, 9, 93, 0, 88, 1, 93, 6,  8, 8, 65, 4, 52, 
    2, 12, 5, 22, 0, 74, 9,  5, 7, 70, 8, 81, 4, 79, 1, 65, 3, 12, 6, 14, 
    7, 28, 2, 71, 5, 36, 1, 61, 9, 40, 4, 59, 0, 10, 8, 89, 3, 54, 6, 73, 
    6, 96, 8, 56, 4, 96, 1, 62, 7, 55, 0, 10, 9, 39, 3, 42, 2, 11, 5, 66, 
    8, 53, 1, 19, 7, 61, 4, 68, 6, 53, 0, 58, 5,  5, 3, 81, 2, 99, 9, 99, 
    9, 24, 2, 94, 8, 93, 3, 17, 5, 83, 0, 65, 7, 81, 6, 93, 1, 87, 4, 15, 
    1, 26, 3, 32, 8, 90, 4, 65, 2, 45, 5, 97, 7,  3, 6, 77, 0, 25, 9, 33
  };
  const int r360[] = {
    10, 10, // Number of jobs and machines
    3, 19, 2,  2, 6, 29, 8, 65, 1, 26, 7, 87, 9, 31, 5, 35, 4, 14, 0, 15, 
    0, 25, 7, 28, 2, 12, 1, 64, 6, 23, 5, 84, 8, 73, 4, 42, 9, 85, 3, 66, 
    3, 27, 4, 62, 5,  2, 2, 74, 6, 27, 9, 38, 7, 67, 8, 54, 0, 19, 1, 66, 
    5,  6, 6, 26, 9, 78, 2, 43, 1, 33, 4, 59, 7, 73, 3,  2, 8, 24, 0, 87, 
    7, 54, 1, 13, 4, 27, 5, 36, 9, 53, 2, 59, 0, 30, 8, 16, 6, 97, 3, 60, 
    0, 71, 2,  6, 9, 71, 7, 48, 3, 89, 6, 60, 1, 77, 5, 76, 8, 68, 4, 84, 
    5, 37, 8, 39, 3, 94, 4, 46, 6, 73, 1, 34, 7, 42, 9,  8, 0, 56, 2, 12, 
    1, 10, 3, 49, 9, 88, 0, 63, 5, 90, 6, 95, 8, 70, 7, 47, 4, 97, 2, 75, 
    9, 75, 0, 70, 8, 91, 1, 24, 6, 84, 2, 28, 7, 96, 4, 13, 3, 43, 5, 63, 
    6, 32, 3, 89, 1, 99, 4,  1, 8, 65, 5, 35, 2, 47, 0, 64, 9, 99, 7, 16
  };
  const int r361[] = {
    10, 10, // Number of jobs and machines
    8, 99, 7, 29, 4, 43, 1, 57, 0, 53, 6, 45, 3, 41, 5, 86, 2, 36, 9, 87, 
    1, 21, 2, 79, 3, 61, 7, 46, 0, 65, 9, 84, 5, 80, 4, 15, 8, 10, 6, 59, 
    3, 10, 6, 13, 1, 44, 8, 20, 4, 66, 7, 87, 0, 54, 5, 87, 9, 30, 2, 83, 
    8, 41, 6, 64, 3, 67, 9, 69, 4, 45, 2, 90, 0, 58, 1, 56, 5,  5, 7, 90, 
    8, 91, 3, 73, 1, 14, 4, 56, 2, 71, 5, 52, 9, 53, 0, 21, 7, 99, 6, 65, 
    8,  1, 5, 58, 6, 40, 7, 21, 4, 56, 2, 12, 0, 78, 3, 84, 9, 17, 1, 12, 
    3, 67, 1, 37, 4, 51, 7, 18, 0, 91, 9, 96, 2, 80, 6, 60, 5,  6, 8, 11, 
    6, 68, 9, 84, 2, 18, 4, 84, 8, 52, 1, 14, 3, 98, 7, 39, 0, 33, 5, 96, 
    5, 29, 3, 21, 7, 30, 4, 43, 6, 18, 9, 38, 2, 66, 0, 13, 1, 25, 8, 87, 
    0, 33, 9, 22, 7, 11, 5,  4, 1, 18, 4, 62, 8, 73, 2, 53, 3, 12, 6, 13
  };
  const int r362[] = {
    10, 10, // Number of jobs and machines
    8, 81, 3, 25, 0, 70, 9, 46, 2, 46, 1,  4, 7, 93, 4,  8, 5, 93, 6, 79, 
    4, 57, 1, 15, 3, 31, 0, 57, 2, 13, 6, 89, 9, 58, 5, 94, 7,  4, 8,  7, 
    0, 76, 7,  2, 4, 79, 8, 89, 9, 74, 6, 32, 5,  6, 1, 83, 2,  3, 3, 88, 
    5, 89, 3, 33, 1, 82, 8, 16, 2, 12, 7, 31, 9, 86, 6, 76, 0, 21, 4, 81, 
    4, 49, 7, 19, 3, 79, 9, 46, 1, 85, 0, 29, 5, 21, 6,  6, 8, 42, 2, 52, 
    4, 19, 2, 55, 8, 13, 5, 35, 7, 14, 1, 58, 0, 54, 9, 60, 6, 29, 3, 90, 
    1, 71, 2, 11, 4, 64, 3, 56, 7, 34, 8, 21, 5,  2, 9, 25, 0, 58, 6, 17, 
    5, 23, 4, 84, 2, 57, 6, 11, 0, 29, 1, 98, 8, 92, 9, 52, 3, 31, 7, 74, 
    7,  3, 0, 29, 9, 15, 6, 83, 5, 64, 2, 83, 1, 42, 8, 16, 3, 81, 4, 95, 
    9,  8, 1, 88, 5,  8, 7, 17, 4, 40, 0, 43, 6, 78, 2, 70, 3, 68, 8, 86
  };
  const int r363[] = {
    10, 10, // Number of jobs and machines
    3, 10, 7, 23, 8, 74, 2, 21, 9, 21, 1, 27, 4, 37, 0, 98, 6, 37, 5, 48, 
    5, 52, 2, 32, 7, 87, 1, 61, 8, 91, 3,  8, 4, 14, 6, 92, 0, 77, 9, 72, 
    9, 69, 0, 90, 5, 51, 2, 42, 3, 34, 7, 73, 4, 60, 1, 13, 8, 44, 6, 83, 
    6, 81, 8,  2, 7, 43, 9, 85, 2, 32, 5, 52, 0, 30, 3, 53, 1, 33, 4, 97, 
    2,  5, 5, 23, 6, 16, 7, 75, 3, 58, 4, 28, 9,  5, 0, 20, 8, 49, 1, 95, 
    6, 49, 5, 95, 2, 39, 4,  3, 9,  1, 8, 49, 7, 55, 1, 84, 0, 99, 3, 44, 
    1, 24, 2, 13, 6, 70, 7, 86, 4, 26, 0, 31, 3, 17, 8, 15, 9, 17, 5, 83, 
    0, 25, 3, 98, 5, 64, 1, 79, 9, 34, 4, 93, 2, 69, 8, 91, 7, 92, 6,  6, 
    7, 45, 9, 36, 0, 23, 1, 42, 2,  7, 6, 56, 8, 64, 5, 79, 4, 56, 3,  1, 
    5,  9, 4, 65, 6, 30, 7, 58, 2, 46, 8, 61, 3, 63, 1, 98, 0, 86, 9, 58
  };
  const int r364[] = {
    10, 10, // Number of jobs and machines
    8, 62, 1, 53, 4, 89, 6, 28, 3, 72, 7, 17, 0, 76, 2, 50, 5, 47, 9, 14, 
    2, 44, 3, 28, 0,  5, 1, 53, 4, 42, 5, 43, 7,  9, 6, 27, 8, 23, 9, 16, 
    9, 95, 5, 46, 7, 49, 3, 69, 2, 49, 1, 88, 6,  6, 0, 77, 8, 53, 4, 37, 
    2, 86, 9,  1, 3,  8, 7, 75, 1,  1, 5, 13, 4, 91, 0, 17, 6, 92, 8, 65, 
    5, 27, 4, 16, 8, 74, 2, 32, 1, 20, 3, 74, 0, 15, 6, 90, 9, 63, 7, 61, 
    1, 89, 8, 77, 3,  5, 2, 64, 5, 43, 0, 17, 9, 39, 7,  1, 6, 53, 4, 92, 
    1, 17, 4,  1, 8, 57, 9, 43, 2, 47, 3, 89, 6, 36, 7, 69, 5, 88, 0, 56, 
    6, 21, 9, 83, 4, 76, 1, 65, 3, 37, 8, 44, 5, 87, 0, 41, 2, 74, 7, 70, 
    3, 12, 4, 21, 6, 57, 1, 46, 0,  3, 5, 42, 8, 60, 9, 58, 7, 53, 2, 18, 
    7,  9, 9, 35, 4, 88, 2, 23, 3, 70, 6, 21, 8, 22, 1, 55, 0, 10, 5, 13
  };
  const int r365[] = {
    10, 10, // Number of jobs and machines
    3, 21, 6,  3, 9, 93, 7, 89, 2, 73, 8, 60, 5, 37, 0, 23, 4, 88, 1, 87, 
    7, 50, 1, 59, 9, 89, 3,  5, 0, 74, 4, 87, 2, 31, 6, 78, 5, 86, 8, 29, 
    1, 68, 6, 13, 5, 15, 0, 82, 4, 67, 9, 29, 8, 27, 3, 66, 7, 73, 2, 92, 
    7, 32, 8, 88, 3, 13, 2, 93, 5, 49, 9, 52, 0, 24, 4,  9, 6, 85, 1, 62, 
    1, 97, 7, 94, 3, 51, 0, 37, 4, 45, 5, 57, 2, 37, 6, 88, 8, 17, 9, 33, 
    3, 47, 1, 15, 4, 69, 7, 55, 0, 68, 5, 50, 2, 58, 9, 30, 6,  9, 8, 93, 
    9, 24, 8, 22, 3, 64, 4, 51, 1, 60, 5, 72, 0, 34, 6, 85, 2,  3, 7, 38, 
    8,  4, 2, 87, 3, 20, 6, 40, 9, 85, 4, 34, 5,  1, 0,  3, 1, 16, 7, 71, 
    2, 72, 5, 25, 6, 22, 9, 86, 3, 92, 0, 62, 8, 37, 1, 72, 7, 45, 4,  1, 
    3, 82, 2, 42, 5, 83, 4,  3, 9, 95, 8, 97, 0, 37, 7, 54, 6, 83, 1, 31
  };
  const int r366[] = {
    10, 10, // Number of jobs and machines
    0, 30, 6, 56, 9, 50, 2, 51, 7, 14, 5, 99, 4, 54, 1, 99, 8, 53, 3, 24, 
    1, 47, 7, 85, 9, 47, 5, 68, 3, 26, 8, 75, 6, 21, 2, 73, 0, 57, 4, 83, 
    4, 47, 1, 60, 9, 77, 8, 74, 2, 10, 0, 12, 7, 83, 3, 39, 6, 40, 5, 88, 
    3, 68, 7,  6, 1, 25, 6, 50, 2, 43, 4, 56, 0, 69, 8, 15, 9, 18, 5, 26, 
    6, 96, 1, 43, 2,  7, 0, 58, 5, 54, 7, 89, 8, 94, 9, 11, 4,  7, 3, 69, 
    5, 84, 7, 67, 1, 10, 6, 47, 3, 36, 8, 14, 2, 18, 4, 23, 0, 57, 9, 72, 
    1, 58, 5,  3, 6, 85, 8, 32, 0, 97, 9, 87, 3, 33, 4, 23, 7, 61, 2, 92, 
    7, 65, 6, 37, 4, 36, 8, 41, 3, 71, 9, 20, 1, 37, 0, 26, 2, 33, 5, 19, 
    8, 79, 2, 10, 5, 86, 1, 79, 3, 51, 9,  7, 0, 60, 4, 68, 6, 58, 7, 50, 
    0, 79, 7, 72, 5, 39, 3, 87, 2, 24, 4, 85, 8, 95, 1, 96, 9, 20, 6, 94
  };
  const int r367[] = {
    10, 10, // Number of jobs and machines
    9, 19, 3, 40, 2, 35, 4, 80, 8, 65, 0, 34, 6, 40, 5, 83, 7, 59, 1, 33, 
    7, 61, 2, 98, 0, 88, 3,  2, 4, 63, 5, 28, 1, 60, 8, 42, 9, 26, 6,  6, 
    4, 63, 1, 88, 9, 18, 8, 92, 3, 71, 2, 46, 6, 13, 7,  5, 5, 24, 0, 10, 
    4, 94, 5, 88, 3, 52, 9,  1, 2, 49, 7, 65, 1,  4, 6, 38, 8,  4, 0, 99, 
    9, 25, 4, 47, 0, 27, 7, 49, 1, 46, 6,  6, 8, 34, 5, 96, 2, 97, 3, 37, 
    8, 38, 1, 47, 3, 15, 0, 22, 5, 78, 9, 68, 7,  6, 2, 49, 4, 87, 6, 23, 
    7, 69, 4, 76, 5,  3, 3, 70, 6, 33, 0, 69, 1, 27, 9, 77, 8, 34, 2, 28, 
    8,  6, 7, 22, 6, 74, 3, 71, 1,  8, 9, 39, 4, 45, 5, 86, 0, 21, 2, 49, 
    1, 22, 6,  4, 8, 27, 7,  8, 3, 33, 5, 89, 2, 99, 4, 60, 0, 90, 9, 59, 
    5,  2, 0, 62, 8, 87, 7, 72, 1, 11, 4, 24, 2, 90, 3, 26, 6, 57, 9,  8
  };
  const int r368[] = {
    10, 10, // Number of jobs and machines
    7, 42, 1, 55, 5, 62, 8, 31, 4, 50, 0, 71, 3, 75, 9, 78, 6, 69, 2, 59, 
    8, 31, 9, 87, 6,  6, 0, 89, 7, 67, 5, 94, 3, 45, 1, 79, 4, 37, 2, 75, 
    9, 78, 4, 60, 2, 49, 8, 60, 1,  8, 0, 13, 5, 69, 7, 72, 3, 51, 6, 39, 
    4, 62, 0, 24, 1, 53, 2, 20, 3, 60, 6, 43, 7, 62, 8, 24, 5, 13, 9, 16, 
    7, 48, 4, 25, 9, 90, 3, 33, 5, 39, 1, 12, 8, 54, 6, 46, 0, 43, 2,  4, 
    2, 73, 6, 57, 5, 38, 1, 50, 0, 32, 7, 41, 3, 44, 9, 81, 4, 35, 8, 61, 
    0, 83, 4, 88, 3, 41, 2,  4, 5, 33, 1, 69, 9, 71, 7, 92, 8, 67, 6, 78, 
    3, 85, 2, 23, 9, 82, 1, 15, 7, 97, 6, 49, 5, 58, 0, 44, 4, 30, 8, 34, 
    2, 31, 5, 10, 7, 74, 3, 78, 9,  9, 6, 78, 4, 66, 0, 58, 1,  3, 8, 70, 
    6, 50, 8,  2, 7, 81, 0, 32, 4, 59, 1, 77, 9, 20, 3, 61, 5, 76, 2, 61
  };
  const int r369[] = {
    10, 10, // Number of jobs and machines
    1,  7, 0, 49, 6, 49, 9, 18, 4, 39, 3, 57, 7,  6, 8, 68, 5, 42, 2, 74, 
    3, 28, 4, 57, 0, 25, 7, 45, 9, 28, 2, 49, 1, 64, 5, 79, 6, 56, 8,  5, 
    1, 87, 4, 30, 6, 99, 9, 53, 7,  4, 2, 98, 5, 74, 3, 29, 8, 12, 0, 46, 
    0,  8, 6, 52, 5, 74, 7, 43, 1, 59, 9, 63, 4, 62, 3, 27, 8, 19, 2, 59, 
    5,  2, 4,  4, 7, 79, 9, 32, 2, 37, 6, 30, 0, 49, 1, 78, 8, 45, 3, 14, 
    5, 82, 0, 49, 4, 65, 8, 13, 2, 49, 3, 39, 6, 86, 9, 18, 1, 85, 7,  3, 
    9, 41, 6,  4, 4, 57, 1, 77, 2, 19, 3, 31, 5, 46, 7, 61, 8, 68, 0, 10, 
    6, 93, 2, 74, 0, 69, 8, 50, 7, 45, 1, 92, 3, 57, 4, 81, 9, 87, 5, 55, 
    2, 50, 4, 97, 9, 17, 8, 37, 1, 54, 3, 62, 5, 91, 7, 51, 0, 30, 6, 75, 
    3, 52, 2, 62, 0, 18, 7, 69, 9, 76, 6, 40, 8, 87, 5, 51, 1, 95, 4, 81
  };
  const int r370[] = {
    10, 10, // Number of jobs and machines
    1,  5, 5, 86, 6, 87, 0,  2, 7, 43, 4, 80, 3, 96, 8, 24, 9, 90, 2, 78, 
    0, 74, 8, 46, 6, 48, 4, 58, 5, 10, 7, 12, 3, 33, 9, 86, 2, 55, 1, 76, 
    0, 59, 1, 58, 4, 54, 5,  8, 8, 38, 9, 43, 2, 21, 6, 72, 7,  6, 3, 99, 
    4, 91, 9, 56, 0,  3, 2, 64, 1, 58, 5, 60, 6, 60, 8,  7, 3, 43, 7, 14, 
    3, 75, 0, 67, 4,  3, 1, 82, 2, 95, 9, 74, 6,  3, 8, 96, 5, 19, 7, 63, 
    6, 15, 3, 43, 0,  4, 4, 78, 2, 50, 5, 86, 9, 34, 8, 16, 1, 57, 7,  9, 
    8, 23, 4, 30, 1, 53, 6, 92, 2, 67, 5, 85, 7, 93, 3, 29, 9, 41, 0, 66, 
    8, 47, 4, 31, 6,  1, 9, 90, 3, 47, 0, 94, 7, 13, 1, 22, 5, 82, 2, 46, 
    3, 50, 2, 39, 0, 89, 6, 35, 7, 81, 4, 96, 5, 10, 9, 38, 1,  6, 8,  4, 
    1, 64, 9, 45, 8, 20, 6, 57, 7, 80, 5, 64, 3, 74, 4, 48, 2, 42, 0, 73
  };
  const int r371[] = {
    10, 10, // Number of jobs and machines
    3, 94, 7, 47, 2, 74, 4,  9, 9, 51, 8,  4, 1, 28, 0, 13, 5, 66, 6, 60, 
    3, 53, 7, 36, 9, 16, 4, 11, 5, 58, 0, 52, 1, 84, 8, 52, 6, 71, 2, 73, 
    4, 75, 0, 20, 7, 36, 5, 63, 2,  9, 6, 41, 3, 25, 9, 39, 1, 51, 8, 64, 
    9, 66, 5, 52, 0, 47, 6, 62, 1, 95, 3, 94, 7, 82, 4, 88, 2, 50, 8, 29, 
    5, 26, 1, 29, 3, 16, 7, 66, 2, 21, 0, 97, 9, 56, 6,  1, 8, 44, 4, 37, 
    7, 99, 6, 68, 9, 97, 8, 76, 1, 40, 5, 52, 2, 87, 0, 30, 4, 64, 3, 31, 
    2,  5, 7, 15, 8, 82, 3, 58, 6, 56, 0, 31, 9, 69, 5, 22, 4, 76, 1, 57, 
    8, 78, 3, 92, 7, 62, 9,  8, 2, 97, 0, 91, 1, 71, 4, 31, 5, 33, 6, 62, 
    4, 32, 0, 71, 8, 66, 1, 67, 7, 67, 9, 37, 3, 24, 5, 60, 2, 69, 6, 14, 
    2, 99, 3, 58, 8, 96, 7, 35, 9, 76, 6, 88, 5,  2, 1, 55, 4,  9, 0, 65
  };
  const int r372[] = {
    10, 10, // Number of jobs and machines
    8, 78, 6, 94, 7,  5, 5, 15, 0,  1, 9,  6, 2, 39, 4, 94, 1, 24, 3, 59, 
    5, 53, 6, 78, 4, 44, 2, 38, 7, 40, 8, 67, 3, 28, 9, 96, 0, 11, 1, 76, 
    2, 12, 0, 76, 4, 86, 6,  7, 1, 22, 5, 27, 8, 27, 9, 79, 3, 37, 7, 68, 
    5, 46, 4, 26, 8, 42, 7, 37, 3, 47, 0, 47, 6, 46, 9,  5, 2, 95, 1, 49, 
    8, 50, 1, 79, 4, 86, 7, 60, 2, 96, 9, 74, 6, 51, 5, 23, 3, 35, 0, 21, 
    9, 69, 3,  6, 7, 44, 0, 22, 6, 86, 1, 50, 5, 10, 2, 35, 4, 87, 8, 76, 
    0, 94, 9, 77, 4, 54, 1,  2, 5, 39, 7,  4, 3, 64, 8, 91, 2,  5, 6, 56, 
    5, 63, 9,  5, 1, 59, 6, 77, 4, 26, 0, 34, 3, 35, 7, 67, 8, 95, 2,  4, 
    5, 18, 6, 67, 8, 57, 0, 45, 3, 48, 7, 52, 9,  9, 1, 79, 4, 52, 2, 70, 
    4, 11, 1, 70, 7, 89, 6, 80, 9, 65, 8, 19, 0,  3, 5, 63, 3, 26, 2,  9
  };
  const int r373[] = {
    10, 10, // Number of jobs and machines
    5, 41, 9,  4, 6, 90, 4, 43, 2, 15, 7, 23, 8, 71, 3, 37, 1,  3, 0, 16, 
    0, 73, 5, 33, 7, 85, 3, 35, 2, 26, 6, 72, 4, 74, 1, 26, 9, 11, 8, 12, 
    5, 50, 9, 96, 2, 38, 3, 94, 0, 14, 7, 36, 8, 29, 6, 29, 4, 69, 1,  7, 
    0, 27, 1, 21, 2, 97, 3, 92, 5, 55, 7, 67, 8, 33, 9, 91, 6, 11, 4, 74, 
    0,  5, 4, 39, 9, 48, 8, 67, 1, 82, 6, 51, 5, 49, 2,  9, 3, 70, 7, 23, 
    3, 55, 4, 94, 6, 95, 1, 12, 7, 31, 2, 67, 9, 70, 5, 46, 0, 53, 8, 59, 
    8, 40, 4, 81, 9, 40, 7, 54, 6, 37, 3, 75, 0, 89, 1, 97, 5,  6, 2, 97, 
    2, 49, 5, 52, 3, 13, 0, 70, 9, 61, 7, 96, 8,  5, 1,  1, 4, 48, 6, 79, 
    2,  8, 1, 27, 3, 58, 6, 75, 4,  9, 5, 35, 9, 93, 0, 70, 7, 78, 8, 33, 
    6, 71, 5, 23, 9, 48, 0, 66, 7, 99, 1, 83, 3, 67, 8,  7, 2, 95, 4, 14
  };
  const int r374[] = {
    10, 10, // Number of jobs and machines
    2, 24, 1, 89, 5, 25, 6,  7, 0, 86, 3, 51, 7, 88, 4, 80, 8, 67, 9, 29, 
    6, 87, 0, 74, 5, 29, 3, 51, 7, 18, 1, 15, 2,  9, 9, 35, 8, 57, 4, 43, 
    2, 69, 1, 64, 7, 15, 6, 45, 9, 48, 3, 99, 8, 71, 5, 88, 0, 20, 4, 33, 
    0, 58, 2, 77, 8, 97, 5, 15, 9, 93, 1, 17, 7, 55, 4, 84, 3, 20, 6, 95, 
    7, 82, 1, 44, 5,  3, 0, 89, 4, 69, 2, 82, 9, 60, 6, 92, 8, 45, 3, 13, 
    7, 94, 0, 18, 5, 59, 9, 40, 1, 50, 3, 67, 4,  5, 8,  7, 6, 40, 2, 67, 
    9, 83, 6, 99, 2, 13, 7, 76, 8, 77, 5, 58, 1, 51, 0, 82, 3, 79, 4, 36, 
    2, 79, 7, 79, 9, 84, 4, 89, 8, 98, 3, 60, 1, 75, 0, 92, 5, 97, 6, 38, 
    5, 36, 1, 46, 2, 91, 7,  8, 6, 86, 9, 46, 4, 38, 0, 25, 8, 47, 3, 30, 
    6, 13, 0, 34, 1, 41, 3, 22, 4, 29, 7, 32, 2, 17, 8, 77, 9, 35, 5, 61
  };
  const int r375[] = {
    10, 10, // Number of jobs and machines
    7, 72, 0, 12, 5, 68, 3, 11, 2, 78, 8, 64, 6, 39, 4, 85, 1, 71, 9, 45, 
    0, 70, 7, 45, 8,  2, 1, 49, 6, 65, 9, 23, 4, 48, 3, 91, 5, 72, 2, 31, 
    3, 53, 7, 85, 1, 66, 8, 54, 4, 84, 0, 76, 6, 99, 5, 13, 9,  9, 2, 62, 
    2, 66, 1, 17, 4, 15, 8, 94, 0, 55, 6, 76, 7, 28, 5, 52, 9,  9, 3, 38, 
    2, 91, 6, 54, 8, 35, 9, 26, 7, 19, 4, 24, 3, 43, 5, 94, 0, 84, 1, 97, 
    7, 76, 3, 49, 9,  2, 0, 52, 2, 97, 6,  5, 5, 94, 4, 45, 1, 33, 8, 88, 
    4, 76, 5, 32, 2, 86, 8, 66, 0, 84, 3, 56, 6, 90, 1, 83, 7, 76, 9,  1, 
    1, 71, 9, 79, 0, 30, 7, 70, 5,  3, 8, 20, 6, 66, 3, 44, 2, 50, 4, 44, 
    0, 33, 2, 24, 8, 34, 5, 84, 3, 66, 4, 28, 1, 42, 7, 41, 6, 89, 9, 48, 
    2, 77, 0,  1, 5, 98, 9, 53, 6, 33, 7, 89, 4, 41, 3, 10, 8, 12, 1, 49
  };
  const int r376[] = {
    10, 10, // Number of jobs and machines
    0, 51, 5, 31, 6, 76, 4, 16, 2, 28, 7, 23, 1, 59, 9, 50, 3, 22, 8, 55, 
    6, 34, 2, 20, 4, 44, 8, 78, 5, 55, 9, 15, 3, 45, 1, 68, 7, 84, 0, 48, 
    3, 49, 0, 67, 5, 14, 8, 11, 6, 42, 7, 97, 2,  1, 1, 76, 9,  5, 4, 84, 
    0, 88, 1, 64, 2, 11, 8,  8, 6, 39, 3, 96, 4, 59, 5, 69, 9, 82, 7, 22, 
    7, 57, 1, 45, 2, 77, 3,  5, 9, 58, 8, 61, 5, 63, 0, 90, 6, 73, 4, 19, 
    7, 41, 9, 15, 3, 11, 0, 74, 5, 72, 4, 49, 8, 19, 6, 98, 1,  7, 2, 32, 
    2, 79, 4, 43, 9, 92, 3,  5, 1, 53, 5, 87, 8, 19, 0, 57, 6, 72, 7, 72, 
    2, 68, 5, 88, 9, 59, 1, 40, 4, 33, 8, 97, 7, 24, 6, 49, 0, 73, 3, 50, 
    6, 15, 7, 82, 2, 22, 4, 51, 5, 14, 0,  8, 1, 41, 8, 51, 9, 68, 3, 79, 
    8, 60, 1, 98, 2, 36, 5, 28, 7, 70, 6, 82, 4, 11, 0, 20, 3, 90, 9, 73
  };
  const int r377[] = {
    10, 10, // Number of jobs and machines
    7, 35, 3, 92, 8,  5, 0, 16, 2, 73, 4, 90, 6, 41, 9, 33, 1, 39, 5, 59, 
    8, 82, 0, 98, 5, 62, 4, 96, 2, 88, 7, 29, 9, 87, 6, 69, 3, 55, 1, 62, 
    0, 37, 4, 40, 7, 29, 5, 77, 3,  5, 6, 24, 9, 69, 1, 29, 2, 37, 8, 34, 
    3, 56, 4, 91, 6, 83, 0,  5, 9, 15, 7, 43, 1, 77, 5, 64, 8, 42, 2, 12, 
    0, 68, 2, 22, 3, 37, 1, 27, 6, 76, 4, 41, 9, 92, 5, 22, 8, 36, 7, 38, 
    7, 25, 0, 26, 1,  9, 5, 79, 6,  6, 4, 71, 2, 91, 8, 20, 3,  4, 9, 86, 
    9, 73, 7, 62, 0, 30, 1, 57, 8, 58, 6, 64, 4, 36, 5, 45, 2, 66, 3,  3, 
    5, 86, 3, 40, 8, 33, 4, 29, 1, 75, 2, 17, 6, 70, 7, 54, 0, 26, 9, 99, 
    3, 27, 6, 87, 5, 35, 7, 27, 8,  5, 9, 23, 4, 74, 1, 42, 0, 86, 2, 41, 
    3, 69, 4, 91, 6, 43, 9, 48, 8, 39, 7, 91, 1, 11, 0, 40, 2, 65, 5, 39
  };
  const int r378[] = {
    10, 10, // Number of jobs and machines
    3, 78, 1, 55, 9, 28, 6, 57, 0, 72, 5, 82, 8, 10, 7, 24, 4, 89, 2, 72, 
    8, 15, 9, 28, 1, 94, 0, 60, 2, 68, 6, 49, 4, 60, 5, 68, 3, 10, 7, 78, 
    3, 85, 1, 27, 7, 38, 5, 48, 4, 85, 0,  6, 9, 16, 6, 51, 2, 82, 8,  7, 
    8, 57, 4, 10, 5, 68, 0,  2, 9, 28, 2, 69, 7, 10, 6, 81, 1, 85, 3, 97, 
    6, 94, 8, 97, 0, 52, 1, 74, 7, 58, 3, 48, 5, 80, 4, 95, 9, 80, 2, 78, 
    0, 86, 2, 67, 1, 64, 8, 57, 4, 22, 9, 43, 3, 92, 6, 94, 5, 20, 7, 80, 
    0, 16, 8, 15, 7, 86, 2,  1, 1,  9, 5, 25, 6, 90, 9, 47, 4, 54, 3, 34, 
    7, 24, 5, 44, 2, 16, 1,  9, 3,  1, 9, 42, 6, 57, 8, 81, 0, 38, 4, 76, 
    1, 25, 6, 20, 7, 24, 5, 31, 2, 26, 8, 20, 4, 85, 9, 51, 0, 24, 3, 94, 
    4, 41, 0, 70, 1, 48, 6, 37, 3, 66, 7, 65, 8, 94, 9, 23, 5, 41, 2, 91
  };
  const int r379[] = {
    10, 10, // Number of jobs and machines
    4, 46, 8, 19, 7, 54, 2,  5, 9, 27, 0, 42, 1, 15, 3, 58, 5, 91, 6, 63, 
    3, 27, 5, 50, 8, 18, 2, 63, 9, 12, 4,  5, 1, 78, 7, 31, 0, 92, 6, 96, 
    4, 67, 3, 90, 9, 49, 8, 94, 1, 88, 7, 67, 2, 22, 6, 39, 5, 12, 0, 80, 
    3, 65, 4, 35, 5,  1, 8, 70, 6, 87, 1, 99, 7, 27, 0, 85, 9, 13, 2, 78, 
    6, 69, 3, 86, 0, 81, 8, 17, 9, 97, 2, 67, 7, 30, 5, 83, 1, 29, 4, 54, 
    8, 75, 0, 67, 7, 72, 9, 51, 5, 72, 6, 26, 4, 31, 3, 73, 1, 61, 2, 69, 
    6, 97, 3, 67, 9, 59, 4, 55, 7, 15, 2, 76, 0, 20, 8, 70, 1, 62, 5, 84, 
    4, 31, 8, 65, 1, 93, 3, 37, 6,  9, 5, 88, 9, 26, 7, 67, 0, 80, 2, 34, 
    4, 74, 2, 70, 8, 32, 1, 88, 6, 60, 0, 41, 9, 60, 7, 50, 5,  1, 3, 72, 
    0,  1, 6, 11, 9, 25, 8, 55, 2, 19, 7, 31, 5, 97, 3, 99, 4, 94, 1, 30
  };
  const int r380[] = {
    10, 10, // Number of jobs and machines
    4, 70, 6, 45, 8, 84, 3,  4, 5, 92, 9, 80, 2, 85, 0, 13, 1, 65, 7, 90, 
    4, 20, 3, 56, 9, 73, 8, 43, 5, 56, 2, 22, 7, 76, 0, 31, 1, 21, 6, 60, 
    8, 56, 6, 74, 1, 83, 9, 51, 4, 32, 5, 86, 3, 19, 0, 73, 7, 37, 2, 10, 
    4,  9, 7, 18, 5, 52, 8, 96, 9, 81, 3,  6, 1, 32, 0, 68, 2, 86, 6, 98, 
    5, 34, 0, 56, 7, 59, 9, 14, 4, 82, 3, 16, 2,  6, 1, 10, 8, 85, 6, 24, 
    8,  9, 7, 41, 2, 51, 9, 17, 1, 37, 0, 30, 4, 30, 3, 89, 5, 14, 6, 38, 
    8, 43, 5, 95, 6,  5, 4, 20, 7, 77, 0, 72, 3, 30, 1, 98, 2, 49, 9,  2, 
    2, 89, 6, 79, 8, 73, 9, 88, 7, 56, 0,  3, 3, 37, 1, 56, 5, 60, 4, 51, 
    6, 31, 5, 43, 7, 62, 9,  2, 8, 31, 0, 38, 4, 77, 2, 80, 1, 80, 3, 84, 
    8, 64, 0, 53, 7, 25, 4, 70, 3, 44, 9, 52, 2,  6, 6, 79, 1, 58, 5,  3
  };
  const int r381[] = {
    10, 10, // Number of jobs and machines
    8, 10, 4, 36, 6, 15, 0, 44, 2, 91, 7, 12, 5, 18, 3, 83, 1, 39, 9, 29, 
    8, 45, 0, 71, 5, 53, 1, 34, 9, 11, 4,  5, 3, 52, 6, 97, 7, 91, 2, 73, 
    9, 19, 0, 49, 3, 19, 6, 10, 5, 55, 2, 64, 1, 76, 7, 27, 8, 78, 4, 89, 
    3, 74, 8, 37, 7, 19, 5, 76, 1, 44, 4, 94, 6, 68, 2, 27, 0, 81, 9, 31, 
    9, 75, 0,  9, 1, 64, 4,  5, 3, 41, 5, 16, 8, 44, 7, 34, 2, 73, 6,  4, 
    6, 41, 1, 99, 5, 37, 9, 46, 3, 22, 2, 43, 0, 72, 7, 82, 4, 16, 8, 29, 
    7, 35, 3, 13, 9,  4, 5,  5, 1, 76, 0, 11, 8, 83, 2, 94, 6,  1, 4, 36, 
    4, 41, 3, 47, 2, 50, 8, 90, 0, 14, 9, 90, 7, 75, 5, 42, 6, 29, 1, 17, 
    2, 89, 4, 39, 5, 79, 8, 39, 1, 64, 7, 25, 9,  2, 6, 48, 3,  7, 0, 12, 
    8, 77, 6, 37, 7, 20, 3, 82, 2, 46, 5, 56, 0, 14, 9, 41, 1, 85, 4, 39
  };
  const int r382[] = {
    10, 10, // Number of jobs and machines
    8, 94, 7, 84, 0, 58, 3, 23, 2, 94, 1,  8, 9, 28, 5, 21, 4, 37, 6, 85, 
    8, 29, 0, 21, 9, 36, 3, 26, 2, 54, 7, 52, 5, 35, 6, 65, 1,  8, 4,  1, 
    8, 68, 2, 42, 5, 29, 6, 95, 3, 16, 4, 49, 9, 64, 7,  8, 0, 31, 1,  4, 
    1,  2, 9, 70, 3, 46, 4, 80, 2, 45, 5, 54, 6, 91, 0, 67, 8, 81, 7, 87, 
    9, 43, 7,  7, 1, 86, 4, 86, 8, 98, 6,  3, 3, 52, 2, 47, 5,  3, 0, 65, 
    9, 21, 3, 63, 1, 92, 7, 94, 8, 85, 4, 30, 6,  6, 2, 19, 0, 52, 5, 17, 
    3, 89, 5, 33, 2, 43, 1, 80, 6, 98, 9, 75, 0, 21, 4, 92, 7, 69, 8,  8, 
    6, 46, 5, 21, 4, 95, 3,  1, 0, 85, 7, 50, 9, 64, 1, 60, 2, 87, 8, 30, 
    7, 57, 4, 25, 1,  3, 0, 77, 5, 24, 2, 19, 6,  1, 9, 86, 3, 10, 8, 30, 
    7, 14, 8, 51, 0, 40, 5, 98, 2, 39, 1, 74, 6, 61, 4, 68, 3, 13, 9, 42
  };
  const int r383[] = {
    10, 10, // Number of jobs and machines
    2, 70, 6, 47, 3, 56, 1, 85, 0, 69, 5,  5, 7, 78, 9, 64, 8, 39, 4, 66, 
    1, 46, 6, 36, 9, 76, 2, 18, 0, 77, 3, 97, 7, 49, 8, 93, 5, 90, 4, 27, 
    0, 83, 5, 43, 7, 86, 2, 90, 6, 62, 8, 78, 4, 60, 9, 90, 3, 76, 1, 27, 
    7, 78, 8, 52, 4, 73, 3, 85, 1,  5, 5, 82, 0, 47, 2,  3, 9, 43, 6, 86, 
    8,  7, 2,  9, 9, 18, 7, 44, 3, 19, 1, 48, 0, 65, 4, 73, 6, 37, 5,  4, 
    2, 59, 0,  2, 6, 87, 9, 89, 3, 97, 5, 88, 1, 65, 7,  8, 4, 28, 8, 50, 
    9, 18, 2, 36, 6,  1, 7, 20, 1, 38, 8,  6, 4, 78, 0, 36, 3, 81, 5, 25, 
    2, 88, 7, 87, 6, 95, 1, 23, 0, 52, 3, 36, 8, 72, 9, 18, 5,  1, 4, 81, 
    1, 40, 5, 53, 3, 66, 2, 52, 9, 30, 7, 99, 8, 90, 0, 25, 6, 14, 4, 64, 
    7, 59, 2, 66, 9, 32, 3, 46, 8, 62, 5, 57, 1, 38, 4, 84, 0, 17, 6, 66
  };
  const int r384[] = {
    10, 10, // Number of jobs and machines
    2, 59, 8, 37, 5, 83, 9, 10, 3, 43, 1,  3, 7, 41, 0, 44, 4, 87, 6,  1, 
    2, 77, 3, 95, 6, 24, 9, 11, 1, 72, 7,  4, 4, 70, 5, 82, 0, 43, 8, 36, 
    4, 40, 0, 33, 1, 68, 7, 73, 6, 42, 3, 62, 8, 13, 9, 26, 5,  8, 2, 60, 
    0, 63, 4, 86, 7, 53, 3, 41, 6, 68, 8, 93, 1, 12, 5, 71, 2, 79, 9, 36, 
    4,  2, 2, 84, 5, 81, 3, 74, 8, 68, 7,  6, 6, 41, 1, 40, 0, 71, 9, 86, 
    2, 82, 4,  5, 1, 76, 8, 76, 9, 56, 6, 48, 7, 91, 5, 93, 0,  6, 3, 12, 
    7,  8, 9, 39, 2, 31, 0, 60, 1, 95, 4, 29, 8, 95, 5, 30, 6, 82, 3, 76, 
    8,  4, 1, 16, 0, 50, 9, 68, 6, 37, 3, 24, 4, 48, 5, 41, 2, 38, 7, 10, 
    0, 75, 8, 97, 6,  6, 7, 34, 2, 99, 9, 64, 4, 86, 5, 62, 1, 95, 3, 52, 
    6, 57, 3, 54, 0, 91, 1, 76, 8, 62, 5, 83, 9, 80, 2, 64, 7, 11, 4, 86
  };
  const int r385[] = {
    10, 10, // Number of jobs and machines
    2, 97, 9, 76, 4, 53, 6,  4, 1, 83, 8,  5, 7, 40, 5, 85, 3,  6, 0, 29, 
    0, 12, 5, 22, 4, 52, 7, 96, 8, 59, 9, 27, 6, 34, 1, 56, 3, 10, 2, 21, 
    2, 28, 7, 68, 9, 97, 1, 48, 0, 71, 8, 40, 4, 59, 5, 69, 3, 40, 6, 62, 
    4, 90, 1, 11, 7, 10, 8, 72, 6, 72, 5, 80, 2, 93, 9, 39, 3, 66, 0, 26, 
    9, 98, 1, 14, 6, 37, 7, 70, 5,  7, 2, 44, 3, 86, 4,  8, 0, 41, 8, 11, 
    7,  4, 8,  9, 0, 94, 4, 75, 5,  1, 1, 40, 6, 21, 9,  4, 2, 76, 3, 64, 
    6, 32, 4,  9, 0, 33, 5,  9, 7, 86, 8, 75, 3, 94, 9, 31, 1, 58, 2, 30, 
    7, 78, 4,  5, 2, 13, 1, 33, 8, 62, 5, 45, 0, 20, 6, 71, 3, 61, 9, 58, 
    3, 85, 8, 84, 5, 65, 0, 24, 9, 37, 1, 79, 2, 83, 6, 59, 7, 61, 4, 66, 
    2, 68, 1, 92, 3, 79, 9, 51, 5, 96, 8, 10, 0, 36, 4, 52, 7, 97, 6, 91
  };
  const int r386[] = {
    10, 10, // Number of jobs and machines
    4, 61, 7, 18, 1, 32, 2, 47, 6, 13, 0, 39, 9,  4, 5, 37, 8, 60, 3, 40, 
    1, 64, 3, 18, 7, 80, 6, 81, 5, 84, 4, 10, 2, 39, 8, 27, 0, 52, 9, 70, 
    2, 88, 4, 68, 8, 39, 9, 20, 6, 87, 1, 99, 3, 91, 5, 69, 0, 96, 7, 78, 
    1,  5, 6, 44, 9, 31, 5,  7, 2, 10, 0, 41, 7, 67, 8, 58, 3, 78, 4, 17, 
    2, 60, 8, 31, 4, 14, 0, 27, 9,  6, 5, 67, 1, 93, 7, 99, 6, 74, 3, 87, 
    7, 39, 5, 75, 9, 43, 8,  1, 6, 31, 0, 36, 4, 95, 1, 36, 3, 18, 2, 42, 
    1, 86, 4,  4, 9, 27, 5, 20, 2, 10, 6, 77, 0, 47, 8, 20, 3, 67, 7,  8, 
    1, 69, 7, 93, 0, 94, 4, 49, 6, 97, 8, 39, 2, 15, 9, 49, 3, 80, 5, 57, 
    6, 56, 7, 78, 9, 13, 2, 98, 1, 93, 0, 72, 5, 36, 4, 84, 3, 72, 8, 81, 
    5, 45, 2, 25, 9,  2, 3, 15, 0, 51, 8, 36, 7, 55, 6, 23, 4, 62, 1, 95
  };
  const int r387[] = {
    10, 10, // Number of jobs and machines
    3,  9, 2,  9, 5, 68, 8, 66, 9, 10, 1, 74, 4, 52, 7, 15, 6,  8, 0, 49, 
    8, 34, 2, 55, 3, 21, 0, 83, 9, 27, 4, 57, 1, 83, 7, 49, 6, 20, 5, 84, 
    2, 76, 4, 56, 6,  5, 0, 26, 3, 80, 5,  4, 9, 56, 1, 13, 7, 17, 8,  2, 
    4, 65, 3, 57, 1, 42, 6, 47, 5, 64, 2, 13, 0, 30, 8, 31, 9, 49, 7, 66, 
    9, 67, 0, 92, 2, 77, 3, 83, 7, 95, 8, 54, 1, 40, 5, 93, 4, 98, 6, 18, 
    2, 61, 7,  2, 1, 26, 6,  2, 3, 35, 8, 76, 0, 85, 4, 99, 5, 86, 9, 82, 
    9, 27, 3, 37, 2, 88, 4, 71, 8, 16, 7, 83, 0, 49, 1, 73, 6, 21, 5, 17, 
    5, 47, 3, 96, 1, 32, 8, 70, 0, 78, 2, 52, 6, 35, 9, 91, 4, 74, 7, 68, 
    7, 23, 3, 22, 8, 96, 5, 48, 9, 16, 1, 14, 2, 50, 6, 96, 0, 14, 4, 12, 
    0, 80, 2, 56, 7,  8, 5, 44, 8, 99, 4, 28, 6, 77, 3, 70, 1, 59, 9, 68
  };
  const int r388[] = {
    10, 10, // Number of jobs and machines
    3, 72, 8, 15, 7, 18, 2, 28, 6, 24, 9, 74, 0, 55, 5, 45, 1,  6, 4, 43, 
    1,  1, 3, 25, 8, 58, 5, 25, 7, 67, 9, 23, 4, 48, 2, 97, 6, 72, 0, 13, 
    4, 12, 5, 75, 6, 58, 8, 69, 7, 59, 1, 94, 9, 31, 3, 46, 2, 20, 0, 36, 
    9, 44, 7, 28, 8, 16, 4, 53, 3, 25, 0, 12, 1, 57, 6, 31, 2, 22, 5, 54, 
    9, 65, 8,  3, 3, 22, 5, 25, 6, 48, 1, 42, 7,  5, 2, 74, 4, 98, 0, 27, 
    7, 92, 2, 80, 0, 92, 3, 86, 1, 54, 8, 88, 5, 13, 4, 48, 9, 41, 6, 48, 
    4, 24, 9, 33, 7, 26, 0, 21, 6,  2, 2,  3, 8, 80, 3, 87, 1, 54, 5, 48, 
    9, 62, 6, 59, 1, 94, 2, 37, 3, 16, 8, 16, 4, 46, 7, 19, 0, 26, 5, 10, 
    9, 97, 0, 72, 5, 13, 1, 38, 2, 87, 7, 34, 6, 63, 3, 22, 8, 16, 4, 81, 
    5, 78, 2, 61, 8, 16, 6, 66, 1,  4, 3,  9, 9, 95, 4, 61, 0, 39, 7, 27
  };
  const int r389[] = {
    10, 10, // Number of jobs and machines
    9, 83, 4, 17, 5, 59, 0, 99, 6, 33, 8, 17, 3, 69, 2, 73, 7, 16, 1, 59, 
    3, 57, 2, 88, 0, 52, 6, 97, 4, 82, 1, 23, 7, 67, 5, 33, 9, 23, 8, 83, 
    9,  4, 7, 72, 4, 38, 8, 73, 1, 89, 6, 60, 3, 37, 2, 86, 5, 98, 0, 35, 
    9, 79, 8, 60, 2, 42, 6, 87, 4, 17, 0, 26, 1, 26, 3, 27, 7, 10, 5, 42, 
    1, 24, 7, 41, 2, 46, 5, 72, 3, 69, 0, 85, 4, 83, 6, 23, 9, 98, 8, 72, 
    3, 21, 8, 83, 0,  9, 2, 28, 9,  8, 5, 24, 1, 91, 4, 51, 6, 62, 7, 94, 
    0, 21, 3, 90, 7, 39, 6, 14, 1, 75, 9, 17, 8, 63, 2, 76, 4, 13, 5, 73, 
    2, 57, 4, 70, 0, 65, 8, 22, 5, 92, 3, 14, 6, 18, 7, 23, 9, 41, 1, 96, 
    3, 26, 1, 16, 0, 33, 6, 60, 5, 34, 8, 91, 4, 29, 9, 45, 7, 47, 2, 85, 
    1, 50, 8, 29, 6, 28, 4, 37, 9, 87, 0, 13, 3, 98, 7, 48, 2, 88, 5, 18
  };
  const int r390[] = {
    10, 10, // Number of jobs and machines
    6,  7, 2, 95, 9, 82, 7, 15, 3, 81, 4, 48, 1, 74, 5, 37, 8, 68, 0, 97, 
    6, 14, 5, 31, 7, 28, 1, 28, 2, 90, 3, 96, 8, 12, 0, 87, 4, 89, 9, 60, 
    0, 90, 8, 53, 2, 62, 4, 79, 3, 93, 7, 60, 9, 66, 1, 18, 5, 85, 6, 65, 
    1, 51, 7, 54, 8, 35, 4,  8, 9, 74, 2, 62, 3, 17, 6, 70, 0, 41, 5, 39, 
    7, 19, 0, 49, 1, 85, 5, 73, 6, 52, 9,  1, 8, 84, 3, 14, 2, 22, 4, 25, 
    6, 73, 9, 12, 8, 70, 5, 53, 0, 42, 4, 63, 1, 47, 2, 15, 3, 24, 7, 34, 
    0, 38, 4, 44, 2, 46, 8,  2, 3,  1, 9,  4, 1, 52, 7,  7, 6, 18, 5, 90, 
    6, 93, 8, 75, 0, 80, 3, 43, 2, 79, 1, 41, 5,  2, 7, 93, 9, 99, 4, 89, 
    4, 10, 3, 92, 7, 49, 1, 95, 9, 90, 2,  4, 8, 20, 0, 91, 6, 64, 5, 42, 
    5, 61, 2, 26, 9, 13, 0, 13, 4, 21, 6,  5, 7, 74, 8, 21, 3, 35, 1, 73
  };
  const int r391[] = {
    10, 10, // Number of jobs and machines
    9, 51, 7, 33, 6, 53, 0, 40, 1, 68, 4, 77, 2, 76, 5,  3, 8,  7, 3, 57, 
    9, 53, 2, 15, 3, 17, 1, 55, 0, 86, 8,  3, 7, 33, 5, 65, 4, 73, 6, 12, 
    9,  7, 2, 89, 5, 48, 8, 71, 7, 43, 1, 68, 6, 47, 4,  3, 3, 58, 0, 97, 
    2, 57, 5, 69, 9, 91, 0, 55, 4, 91, 8, 56, 6, 35, 7, 17, 1, 45, 3, 21, 
    0, 30, 2,  6, 1, 31, 8, 33, 7, 66, 4, 21, 5, 88, 9, 46, 6, 34, 3, 74, 
    0, 34, 7, 98, 8, 83, 6, 97, 3, 28, 2, 18, 1, 63, 9, 42, 4, 64, 5, 83, 
    1, 99, 8, 55, 6, 29, 9, 31, 4, 25, 3, 40, 2, 10, 5, 48, 7, 75, 0, 72, 
    1, 67, 2,  5, 5, 45, 8, 74, 4, 47, 6, 65, 3, 79, 0,  7, 9, 40, 7, 65, 
    8, 23, 7, 87, 0, 24, 5, 35, 4, 63, 2, 26, 9, 52, 1, 83, 3, 61, 6, 38, 
    9, 21, 5, 42, 4, 73, 2, 35, 6, 73, 7, 55, 3, 11, 0, 70, 1, 94, 8, 35
  };
  const int r392[] = {
    10, 10, // Number of jobs and machines
    0, 43, 6,  6, 5, 76, 2, 26, 3, 73, 7, 93, 8, 57, 4, 98, 9, 32, 1, 12, 
    7, 51, 4,  5, 8, 41, 0, 56, 5, 64, 2, 18, 1, 30, 3, 32, 9, 31, 6, 14, 
    4, 78, 0, 75, 1, 49, 7, 13, 2, 34, 3, 84, 8,  1, 5, 33, 9, 94, 6, 62, 
    6, 61, 4, 66, 0, 83, 7, 99, 8, 73, 9, 93, 3, 35, 2, 53, 1, 45, 5, 88, 
    4, 82, 7, 86, 9, 48, 1, 11, 2, 63, 8, 40, 3, 30, 0,  8, 6, 97, 5, 94, 
    5, 79, 1, 58, 8, 66, 4, 26, 2, 73, 3, 66, 9, 94, 7, 95, 0, 96, 6, 25, 
    7, 67, 4,  5, 1, 15, 8, 69, 5, 17, 2, 29, 6, 83, 3, 50, 0, 95, 9, 49, 
    9, 76, 6, 97, 7, 41, 0, 89, 8, 16, 1, 37, 4, 92, 2, 65, 5, 61, 3, 54, 
    7, 52, 1, 29, 3,  3, 9, 49, 8, 45, 2, 98, 6, 39, 0, 78, 5, 54, 4, 22, 
    5, 51, 3, 66, 9, 68, 8,  4, 4, 35, 1, 79, 0, 17, 6,  6, 7,  7, 2, 27
  };
  const int r393[] = {
    10, 10, // Number of jobs and machines
    7, 99, 0, 34, 1, 79, 3, 66, 9, 95, 8, 54, 6, 88, 2, 26, 4, 64, 5, 19, 
    0, 79, 5, 74, 3, 52, 9, 77, 7, 49, 4, 36, 2,  4, 8,  6, 6, 12, 1, 52, 
    0, 97, 1, 68, 8, 37, 4, 54, 2,  3, 3,  8, 5, 65, 7, 89, 6, 73, 9,  3, 
    3, 92, 5, 32, 4, 15, 9, 67, 2, 57, 6, 48, 8, 87, 1, 92, 7, 94, 0, 82, 
    1, 95, 9, 75, 2, 47, 6, 96, 8, 71, 3, 94, 0, 94, 7, 29, 5, 79, 4, 84, 
    9, 89, 4, 71, 7, 50, 8, 94, 1, 46, 0, 91, 3,  4, 6, 56, 2, 83, 5, 40, 
    6, 73, 5,  7, 1, 65, 0, 43, 4, 23, 3, 34, 9, 27, 8, 33, 7, 62, 2, 27, 
    0,  6, 9, 93, 3, 78, 8, 47, 7, 75, 2, 20, 1, 11, 4, 91, 6, 50, 5, 41, 
    4, 69, 2, 61, 1, 51, 9,  8, 7,  6, 8, 17, 3, 22, 6, 60, 0, 18, 5, 45, 
    4, 19, 6, 80, 9, 85, 1, 56, 7, 96, 8, 17, 2, 77, 5,  3, 0, 13, 3, 26
  };
  const int r394[] = {
    10, 10, // Number of jobs and machines
    8, 59, 9, 41, 1, 88, 3, 54, 4, 76, 2, 48, 7, 81, 0, 71, 6, 58, 5, 38, 
    5, 93, 6, 99, 7, 46, 1, 40, 2, 50, 4, 88, 3, 15, 9, 55, 0, 80, 8, 51, 
    6, 57, 0,  7, 2,  5, 7, 60, 9, 35, 5, 66, 3, 14, 4, 23, 1, 26, 8, 53, 
    1,  7, 6, 39, 7, 85, 5, 20, 0, 30, 3, 46, 2, 28, 4, 52, 9, 77, 8, 73, 
    5,  4, 3, 49, 0, 39, 4, 17, 2, 16, 6, 31, 1, 30, 7, 67, 9, 10, 8, 75, 
    5,  3, 9, 95, 4, 49, 0, 83, 8, 49, 1,  8, 3,  7, 7, 27, 6, 44, 2, 15, 
    7, 26, 6, 90, 1, 82, 3, 92, 5, 85, 0, 26, 9, 94, 4, 20, 2, 32, 8, 79, 
    8,  2, 7, 38, 6, 12, 9, 89, 4, 38, 1, 40, 3, 89, 5, 57, 0, 97, 2, 69, 
    4, 59, 2, 30, 5, 36, 0,  5, 1, 69, 6, 30, 8, 75, 9, 89, 7, 29, 3, 87, 
    8, 63, 2, 47, 9, 24, 7, 26, 6, 84, 1,  9, 4, 14, 0, 45, 3, 70, 5, 54
  };
  const int r395[] = {
    10, 10, // Number of jobs and machines
    8, 72, 0, 82, 1, 57, 9, 40, 2,  3, 7, 35, 3, 39, 4, 70, 5, 43, 6, 70, 
    7, 81, 6, 29, 5, 34, 3, 33, 0, 38, 8, 56, 2, 93, 1, 51, 4, 13, 9, 42, 
    2, 17, 3, 30, 6, 91, 9,  1, 1, 55, 8, 21, 4, 68, 7, 14, 0, 18, 5, 37, 
    2,  3, 7, 95, 0, 99, 8, 59, 3, 22, 1, 16, 6, 62, 4, 29, 9, 52, 5, 18, 
    1, 77, 4, 87, 2, 86, 7, 10, 5, 80, 9, 54, 0, 24, 8, 67, 3,  2, 6, 35, 
    8, 52, 5, 19, 1,  5, 2, 56, 6, 69, 7, 87, 3, 50, 9, 69, 4, 85, 0, 99, 
    1, 92, 3,  6, 4, 76, 7, 22, 5, 20, 9, 82, 8,  2, 2, 66, 0, 22, 6, 16, 
    9, 56, 3,  6, 2, 98, 5, 35, 8, 34, 0, 85, 4, 42, 7, 99, 6, 20, 1, 56, 
    1, 51, 8, 15, 3, 50, 7, 27, 6, 43, 4,  4, 9, 73, 2, 79, 0, 82, 5, 59, 
    8, 56, 3, 79, 6, 54, 2, 95, 7, 45, 1, 87, 5, 34, 4, 60, 9, 88, 0, 59
  };
  const int r396[] = {
    10, 10, // Number of jobs and machines
    3, 81, 4,  8, 8, 35, 5, 16, 6, 52, 9,  3, 1, 63, 7, 37, 2,  7, 0, 17, 
    3, 69, 2, 95, 9, 34, 1, 96, 4, 24, 8, 56, 7, 59, 0, 17, 6,  1, 5, 48, 
    2, 75, 6, 13, 4,  8, 0, 90, 5, 96, 9, 54, 3, 82, 1, 67, 8,  4, 7, 52, 
    8, 25, 6, 18, 3,  8, 7, 99, 4,  3, 5, 50, 1, 42, 2, 47, 9, 64, 0, 81, 
    4, 75, 1, 32, 0, 50, 5, 69, 2, 61, 3,  1, 7, 71, 6, 56, 8, 35, 9, 74, 
    4, 89, 3, 95, 2, 61, 9, 27, 1,  5, 0, 10, 6, 65, 7, 48, 5, 88, 8, 91, 
    4, 71, 8, 40, 1, 27, 7, 16, 6, 95, 3, 36, 2, 46, 0, 89, 9, 88, 5, 58, 
    8, 35, 6, 39, 7, 20, 9,  7, 5, 55, 0, 41, 1,  2, 3, 39, 2, 27, 4, 55, 
    8,  2, 1, 22, 3, 59, 5, 11, 7, 34, 4, 57, 2, 29, 9, 76, 0, 21, 6, 52, 
    3, 37, 6, 49, 7, 75, 2, 38, 5,  5, 8, 66, 0, 52, 1, 43, 9, 46, 4, 73
  };
  const int r397[] = {
    10, 10, // Number of jobs and machines
    9,  5, 3, 15, 1, 26, 5, 38, 8, 31, 0, 65, 6, 27, 4, 18, 2, 38, 7, 64, 
    5, 77, 0, 40, 6, 69, 2, 93, 4, 20, 9,  2, 1,  8, 7, 47, 3, 37, 8, 17, 
    3, 20, 9, 25, 4, 20, 2, 90, 5, 87, 7, 24, 1, 75, 8, 66, 6, 62, 0, 42, 
    5,  9, 4, 14, 1, 54, 6, 85, 0, 13, 8, 32, 3, 68, 7, 44, 9, 25, 2, 39, 
    1, 43, 0, 30, 4, 16, 9, 55, 5,  1, 6, 74, 2, 61, 3, 63, 8, 98, 7, 86, 
    9, 87, 6, 90, 4, 60, 8, 87, 1, 15, 2, 12, 0, 44, 7, 24, 3, 83, 5, 19, 
    0, 58, 3, 49, 2, 97, 6, 14, 1, 31, 5,  3, 9, 14, 8, 64, 7,  4, 4, 84, 
    8, 51, 3, 79, 2, 11, 6,  3, 0, 11, 7, 45, 4, 70, 1, 25, 5, 38, 9, 75, 
    9, 99, 6, 92, 7,  2, 0, 50, 8, 20, 3, 68, 4, 86, 2, 38, 1, 95, 5, 71, 
    5, 43, 0, 59, 6, 49, 2, 44, 4, 22, 7, 71, 3, 11, 9, 41, 8, 44, 1, 71
  };
  const int r398[] = {
    10, 10, // Number of jobs and machines
    1, 52, 3, 29, 5, 49, 4, 79, 9,  7, 7, 45, 8, 31, 6,  6, 2, 32, 0, 78, 
    8, 44, 4, 34, 3, 43, 0, 91, 7, 83, 5,  1, 9, 37, 1, 80, 2, 94, 6,  9, 
    3, 64, 9, 76, 1, 78, 6, 16, 2,  3, 0, 30, 4, 84, 5, 65, 8, 25, 7, 89, 
    8,  9, 2, 33, 1, 15, 7, 77, 4, 41, 0, 12, 9, 31, 5, 44, 3, 23, 6, 63, 
    3, 45, 6, 14, 2, 91, 9, 27, 8, 55, 4, 95, 0, 89, 1,  4, 7, 16, 5, 15, 
    8, 39, 6, 13, 3, 16, 0, 25, 5, 19, 9, 87, 1, 61, 4, 37, 2, 88, 7, 96, 
    7, 34, 3, 33, 5, 62, 2,  8, 4, 93, 6, 52, 9, 58, 0, 15, 1, 97, 8, 51, 
    6, 98, 7, 53, 5, 86, 4, 31, 8, 37, 1, 20, 9, 41, 0, 60, 3, 69, 2,  2, 
    7, 51, 4, 33, 0, 69, 6, 52, 3, 80, 5, 79, 1, 51, 8, 57, 9,  2, 2, 52, 
    9, 29, 4, 40, 8, 62, 6, 99, 5, 63, 3,  6, 7, 37, 1,  2, 0, 23, 2, 89
  };
  const int r399[] = {
    10, 10, // Number of jobs and machines
    6, 86, 9, 24, 3,  3, 7, 29, 8, 72, 4, 49, 2, 42, 1, 79, 5, 97, 0, 17, 
    7, 42, 5,  7, 3, 52, 6, 63, 2, 45, 9, 63, 0, 32, 4, 86, 8, 71, 1, 35, 
    5, 45, 3, 12, 1, 76, 6, 69, 7, 52, 9,  4, 4, 78, 2,  1, 0, 23, 8,  2, 
    7, 69, 2,  6, 8, 25, 0, 66, 4, 16, 3, 92, 5, 89, 6, 76, 9, 77, 1, 34, 
    9, 10, 8, 80, 3, 31, 4, 78, 7, 18, 0, 88, 5,  4, 2, 80, 6, 63, 1, 84, 
    8, 66, 2, 68, 5, 96, 6, 20, 0, 94, 9, 85, 1, 50, 7, 65, 3, 19, 4,  4, 
    0, 24, 3, 12, 8, 97, 2, 48, 6, 10, 7, 54, 5, 39, 9,  9, 4, 30, 1, 34, 
    8, 97, 5, 56, 0, 64, 4, 44, 1, 59, 6, 89, 9, 12, 7, 77, 2, 86, 3, 23, 
    6, 22, 4, 79, 2, 42, 8, 76, 9, 60, 3, 61, 0, 37, 1, 29, 5,  5, 7, 22, 
    5, 71, 9, 43, 0, 12, 7,  4, 8, 79, 4, 33, 6, 77, 2, 57, 1, 15, 3, 36
  };
  const int r400[] = {
    10, 10, // Number of jobs and machines
    8, 83, 3, 85, 2, 35, 6, 81, 1, 75, 0, 30, 7, 35, 5, 14, 9, 63, 4, 37, 
    5, 69, 6, 89, 3, 52, 8, 61, 1, 87, 7, 80, 4, 42, 9, 70, 0,  3, 2, 87, 
    1, 50, 2, 55, 9, 56, 6, 97, 0,  8, 3, 39, 8, 78, 4,  5, 5, 17, 7, 89, 
    1, 96, 9, 40, 4, 35, 5, 38, 3, 68, 8, 46, 7, 75, 6, 54, 2, 69, 0, 86, 
    0,  9, 4, 19, 8, 47, 3, 10, 2, 60, 6, 38, 9, 84, 7, 77, 1, 58, 5, 71, 
    3, 74, 0, 80, 5, 69, 1, 39, 8,  4, 4, 97, 7, 64, 6, 33, 2, 51, 9,  4, 
    7, 76, 0, 41, 3, 77, 4, 35, 2, 47, 5, 52, 8, 77, 1, 59, 6, 72, 9,  9, 
    0, 18, 4, 42, 7,  4, 9, 51, 3, 12, 5, 40, 8,  4, 6, 78, 2, 93, 1, 82, 
    5, 31, 2, 52, 9, 72, 1, 42, 0, 90, 3, 41, 8, 57, 6, 16, 4, 80, 7,  9, 
    2, 26, 9, 50, 5, 97, 4, 20, 6, 19, 0, 90, 7, 97, 3, 36, 8, 32, 1, 84
  };
  const int r401[] = {
    10, 10, // Number of jobs and machines
    5, 79, 7, 60, 9, 81, 0, 13, 2,  6, 4, 55, 1, 70, 3, 23, 8, 70, 6, 40, 
    7, 83, 8,  2, 4, 50, 1, 38, 5, 19, 9, 91, 0, 13, 2, 50, 6, 67, 3, 65, 
    1, 81, 5, 93, 2, 54, 8,  9, 0, 82, 4, 10, 9, 26, 7, 17, 6,  9, 3, 30, 
    0, 18, 8,  4, 2, 12, 7, 49, 5, 54, 9, 53, 3, 30, 6, 98, 4, 89, 1, 38, 
    9, 10, 0, 69, 6, 78, 1, 64, 3, 90, 2, 75, 4, 34, 7, 41, 5, 49, 8, 48, 
    1,  5, 8, 39, 4, 74, 3, 25, 5, 55, 2, 36, 9, 45, 7, 27, 6, 13, 0, 76, 
    9, 84, 0, 62, 2,  9, 4, 75, 6, 74, 3, 11, 1, 39, 8, 71, 7, 71, 5, 23, 
    4, 37, 5, 52, 3, 10, 7, 45, 0,  1, 1, 36, 8, 55, 2, 49, 6, 56, 9, 60, 
    2, 94, 6, 58, 7, 32, 0, 65, 8, 43, 1,  5, 9, 24, 4, 85, 5, 79, 3, 92, 
    6, 11, 0, 48, 5, 42, 7, 48, 9, 67, 8, 80, 1, 18, 4, 19, 2,  3, 3, 65
  };
  const int r402[] = {
    10, 10, // Number of jobs and machines
    8, 73, 5,  6, 2, 98, 9, 20, 7, 60, 1, 45, 4,  2, 3, 92, 0, 29, 6,  3, 
    3, 76, 4, 31, 2, 49, 1, 75, 6, 47, 0, 18, 5,  7, 8, 56, 9, 44, 7, 39, 
    4,  7, 8, 81, 0, 64, 6,  7, 5, 48, 7,  1, 3, 44, 9, 70, 1, 94, 2, 11, 
    4, 59, 7, 75, 3, 14, 0, 57, 6, 95, 9, 95, 1, 58, 8, 20, 2, 85, 5, 11, 
    4, 98, 7, 54, 0, 62, 9, 10, 3, 73, 5, 94, 8, 58, 6, 88, 2, 38, 1, 22, 
    2, 41, 0, 34, 3, 83, 4,  4, 8, 14, 1, 70, 6, 49, 9, 52, 7, 63, 5, 58, 
    6, 97, 3, 38, 1, 19, 4, 91, 8, 53, 7, 96, 9, 47, 5,  2, 0, 28, 2, 76, 
    3, 26, 0, 13, 5,  3, 2, 24, 8, 67, 1, 89, 4, 90, 7, 14, 6, 61, 9, 28, 
    8, 67, 2, 82, 6, 21, 4, 72, 9,  2, 5, 82, 3, 42, 0, 96, 1, 94, 7, 10, 
    8, 68, 6,  9, 9, 84, 3, 84, 5, 55, 7, 21, 1, 43, 2, 12, 0, 13, 4, 53
  };
  const int r403[] = {
    10, 10, // Number of jobs and machines
    0, 58, 2, 81, 5, 23, 6, 61, 3, 56, 1, 74, 7,  5, 9, 59, 4, 65, 8, 97, 
    5,  4, 3,  3, 1, 37, 6, 69, 0,  7, 4,  1, 2, 95, 8, 20, 9,  4, 7, 61, 
    9, 26, 6, 81, 3, 48, 8, 10, 7, 85, 2, 17, 4, 69, 5, 59, 0,  6, 1, 88, 
    7, 23, 3, 67, 0, 78, 5, 79, 8, 55, 1, 57, 9, 16, 6,  4, 2, 80, 4,  3, 
    4, 14, 1, 98, 7, 61, 0, 79, 6, 41, 9, 23, 3, 11, 8, 84, 2, 99, 5, 56, 
    6, 95, 7, 61, 0,  3, 3, 50, 4, 54, 2, 10, 5, 75, 1, 43, 9, 72, 8, 61, 
    3,  4, 5, 61, 4, 83, 9, 88, 0, 69, 8, 87, 2, 67, 7, 58, 6, 73, 1,  5, 
    0, 51, 7,  4, 5, 86, 8, 43, 3,  5, 1, 84, 2, 48, 9, 52, 6, 95, 4, 32, 
    0, 56, 1,  3, 2, 94, 8, 91, 5, 50, 4, 58, 6, 32, 7, 98, 9, 14, 3, 40, 
    6, 90, 8, 57, 2, 78, 9, 39, 1, 13, 3, 61, 0, 94, 5, 46, 4, 92, 7, 66
  };
  const int r404[] = {
    10, 10, // Number of jobs and machines
    3, 38, 9, 19, 5, 67, 4, 77, 0, 23, 6,  5, 2, 25, 1, 19, 8, 13, 7, 67, 
    0, 36, 7, 58, 8, 16, 1, 42, 3, 53, 6, 98, 2, 10, 5, 78, 9, 70, 4, 53, 
    0,  3, 4, 75, 9,  5, 5, 72, 1, 75, 8, 93, 6, 29, 7, 30, 3, 25, 2, 61, 
    4, 85, 3, 79, 2, 86, 6, 92, 9, 69, 5, 58, 7, 26, 1, 36, 0, 58, 8, 62, 
    5, 97, 9, 57, 8, 49, 1, 78, 3,  2, 0, 90, 7, 71, 2, 44, 4, 89, 6, 26, 
    2, 69, 3, 56, 7, 79, 4, 73, 5, 27, 0, 11, 1, 47, 8, 10, 9, 89, 6, 73, 
    1, 20, 5, 71, 4, 35, 8, 92, 7, 30, 0, 68, 6, 23, 2, 38, 3, 73, 9, 39, 
    4, 62, 8, 84, 5, 43, 2, 48, 0,  2, 3, 58, 1, 96, 9, 82, 6, 42, 7, 22, 
    4, 29, 0, 73, 6,  9, 8, 74, 1, 77, 7, 47, 5, 64, 3, 77, 2, 66, 9, 65, 
    0, 51, 2, 57, 9, 55, 6, 96, 1, 92, 3, 71, 4, 94, 8, 57, 7, 11, 5, 88
  };
  const int r405[] = {
    10, 10, // Number of jobs and machines
    4, 78, 5, 59, 3, 71, 2, 50, 9, 97, 1, 49, 7, 50, 8, 68, 6, 31, 0, 55, 
    9, 39, 3, 54, 5, 18, 4, 65, 1, 99, 6, 85, 8, 45, 0, 89, 2, 58, 7,  4, 
    2, 14, 7, 20, 5, 64, 6, 32, 8, 13, 9, 97, 1, 49, 4, 84, 3, 33, 0, 44, 
    7, 55, 5,  5, 4, 27, 0, 37, 9,  4, 2, 85, 3, 69, 1, 76, 8, 16, 6, 78, 
    3, 63, 4, 95, 9, 90, 5,  7, 8,  7, 0,  5, 7, 28, 1, 81, 6, 34, 2,  3, 
    9, 30, 4, 96, 0, 16, 6, 88, 3, 93, 7, 93, 2, 13, 8, 37, 1, 16, 5, 74, 
    3, 51, 7, 65, 4, 31, 0, 98, 8, 57, 1, 62, 5, 45, 2, 24, 6, 67, 9, 92, 
    9, 70, 3, 51, 7, 90, 5, 72, 0, 48, 2, 30, 1, 79, 4, 50, 6, 74, 8, 26, 
    0, 60, 2, 31, 4, 46, 8, 81, 3, 11, 7, 46, 9, 36, 6, 17, 5, 70, 1, 16, 
    2, 59, 8, 90, 6, 60, 3, 76, 9, 37, 7, 33, 0, 24, 5, 50, 1, 45, 4, 18
  };
  const int r406[] = {
    10, 10, // Number of jobs and machines
    1, 66, 4, 66, 5, 60, 6, 20, 2, 54, 7,  2, 0, 23, 8, 16, 9, 40, 3, 23, 
    2, 24, 7, 10, 3, 44, 0, 53, 8, 47, 6, 98, 4, 29, 5, 60, 1, 76, 9, 26, 
    2, 59, 0, 62, 5, 74, 9, 12, 8, 10, 7, 19, 1, 27, 4, 29, 6, 29, 3, 41, 
    0, 42, 1, 93, 3, 59, 9, 42, 8, 80, 6, 71, 7, 77, 2, 77, 5, 47, 4, 75, 
    8, 56, 0, 93, 2,  4, 3,  1, 4, 43, 6, 23, 5, 74, 7,  8, 9, 82, 1, 96, 
    2, 46, 0, 68, 9, 79, 3, 39, 1, 92, 8, 10, 5, 58, 4, 33, 7, 35, 6, 68, 
    4, 92, 5, 10, 2, 97, 9, 40, 3, 26, 7,  7, 8,  5, 6, 45, 0, 91, 1, 16, 
    7, 64, 5, 62, 3, 71, 4, 77, 0, 33, 9, 10, 1, 94, 6, 55, 2, 10, 8, 33, 
    6, 56, 8, 97, 1, 76, 3, 48, 5, 71, 9, 71, 4, 53, 0, 94, 2, 84, 7, 78, 
    0, 69, 7, 59, 3, 34, 2,  6, 1, 60, 4, 41, 9,  2, 8, 26, 5, 25, 6, 36
  };
  const int r407[] = {
    10, 10, // Number of jobs and machines
    6, 78, 5,  5, 4, 56, 8, 71, 3, 31, 7, 17, 2, 32, 0, 52, 9,  9, 1, 21, 
    8, 74, 6, 69, 7, 57, 9, 53, 4, 81, 3, 73, 5, 49, 1, 55, 0, 22, 2, 62, 
    1, 39, 5, 12, 3, 26, 8, 81, 0, 98, 2, 98, 6,  4, 4, 40, 9, 15, 7, 72, 
    4, 20, 5, 73, 0, 54, 8,  6, 7, 37, 3, 50, 2, 56, 1,  2, 6, 87, 9, 75, 
    6, 50, 9, 30, 2, 76, 3, 38, 5, 40, 0, 23, 1, 57, 7, 95, 4, 30, 8, 85, 
    7, 50, 2, 88, 3, 82, 6,  4, 4, 44, 0, 21, 1, 76, 5, 25, 9, 40, 8, 10, 
    0, 65, 1, 26, 9, 68, 3, 85, 6, 47, 2, 15, 5, 61, 8, 36, 4, 15, 7, 73, 
    3, 35, 1,  1, 0, 94, 5, 15, 2, 39, 4, 78, 7, 43, 6, 25, 8, 26, 9, 76, 
    8, 46, 5,  2, 1, 83, 3, 28, 0, 69, 4, 85, 6, 65, 2, 52, 7,  3, 9, 99, 
    9, 77, 6, 71, 1, 33, 7, 98, 4, 69, 8, 21, 3, 73, 0,  9, 2, 83, 5, 93
  };
  const int r408[] = {
    10, 10, // Number of jobs and machines
    3, 51, 7, 13, 5, 83, 0,  5, 2,  6, 6, 14, 9, 71, 8,  7, 1, 73, 4,  4, 
    4, 32, 1, 99, 9, 53, 0, 54, 6,  2, 7, 51, 8, 33, 5, 12, 2,  5, 3, 40, 
    2, 91, 9, 44, 8, 93, 1, 54, 4, 29, 0,  1, 5, 85, 6, 22, 3, 42, 7, 11, 
    2, 71, 5, 37, 9, 14, 6, 58, 1, 69, 8, 66, 4, 54, 3, 17, 0, 33, 7,  5, 
    0, 20, 6, 41, 9, 89, 3, 28, 8, 24, 2, 77, 4, 28, 1, 76, 5, 38, 7, 54, 
    1, 28, 0, 93, 7, 95, 3, 12, 8, 41, 6, 16, 4, 45, 9, 70, 2, 51, 5, 43, 
    4, 24, 1, 17, 7,  3, 9, 63, 2, 24, 0, 93, 8, 19, 5,  5, 3, 86, 6, 41, 
    4, 17, 1, 54, 8, 89, 9, 64, 7, 56, 2, 36, 0, 32, 3, 10, 6, 74, 5, 95, 
    5, 44, 3, 51, 6, 35, 1, 71, 4, 38, 9, 10, 2, 43, 0,  6, 8, 72, 7, 22, 
    1, 86, 4, 74, 2,  3, 8,  3, 9, 18, 7, 84, 3, 24, 5, 19, 0, 48, 6,  3
  };
  const int r409[] = {
    10, 10, // Number of jobs and machines
    7, 90, 3, 54, 0, 59, 8, 19, 6, 43, 4, 82, 9, 16, 5, 72, 2, 50, 1, 74, 
    7, 42, 1, 58, 2, 21, 4, 28, 0, 32, 3, 15, 5, 94, 6, 13, 9, 26, 8, 15, 
    1, 84, 5, 10, 2,  9, 7, 63, 0, 21, 4, 35, 6, 59, 8, 25, 9, 50, 3, 88, 
    9, 89, 0, 37, 4, 10, 7, 70, 6, 49, 3,  1, 2,  6, 1, 96, 5, 68, 8, 11, 
    2, 62, 3, 56, 9, 81, 8,  7, 1, 47, 5,  8, 7, 11, 4, 87, 6, 69, 0, 34, 
    8, 58, 7,  9, 3, 71, 4, 40, 2, 98, 6, 99, 9, 19, 0, 67, 5, 20, 1, 81, 
    3, 57, 6, 33, 0, 50, 1, 57, 4, 80, 7, 88, 2, 27, 5, 16, 8, 97, 9, 55, 
    7, 63, 1, 52, 6, 16, 0, 46, 8, 27, 2, 76, 5, 52, 3,  4, 9, 25, 4, 16, 
    6, 92, 7, 58, 3, 23, 5,  4, 2, 82, 9, 69, 8, 58, 1, 30, 0, 70, 4, 38, 
    2, 72, 4,  7, 1, 28, 3, 85, 0, 18, 8, 26, 7, 92, 6, 77, 9, 38, 5, 56
  };
  const int r410[] = {
    10, 10, // Number of jobs and machines
    2, 20, 3,  5, 9, 82, 5, 53, 0,  9, 7, 40, 6, 51, 1,  8, 8, 26, 4, 40, 
    8, 42, 2, 10, 3, 16, 0,  9, 5, 80, 7, 46, 9, 64, 4, 84, 6, 30, 1, 39, 
    7, 27, 9,  3, 0, 54, 8, 71, 1,  7, 4,  9, 6, 84, 2, 55, 5, 34, 3, 48, 
    2,  6, 4, 33, 6, 98, 3, 84, 9, 52, 0, 66, 1, 70, 5, 73, 7, 59, 8, 70, 
    4, 54, 8, 92, 2, 87, 1, 42, 9, 23, 6,  7, 5, 42, 3, 81, 7, 39, 0, 81, 
    9, 45, 2, 38, 5, 15, 1, 80, 4, 47, 0, 75, 6, 93, 8, 46, 7, 96, 3, 84, 
    1, 36, 0, 75, 4, 25, 6, 34, 3, 63, 9, 67, 2, 33, 8, 64, 5, 69, 7, 88, 
    0, 73, 9, 52, 3, 27, 7, 33, 5, 97, 4, 65, 6, 23, 8, 63, 1, 73, 2, 35, 
    0,  4, 8, 19, 5, 88, 7, 99, 1, 16, 4, 85, 2, 56, 6, 87, 9, 89, 3, 59, 
    3, 76, 9, 44, 2, 11, 5, 83, 1, 67, 4, 43, 8, 64, 0, 97, 6, 30, 7, 87
  };
  const int r411[] = {
    10, 10, // Number of jobs and machines
    7, 74, 9, 68, 4, 71, 3, 11, 8,  6, 1, 51, 5, 64, 6, 85, 0, 49, 2, 36, 
    3, 71, 2, 18, 1,  6, 7, 96, 4, 83, 5, 39, 8, 39, 0, 60, 9, 69, 6, 82, 
    7, 81, 2, 77, 6, 82, 9, 76, 4, 93, 0, 81, 5, 26, 8, 92, 1, 72, 3, 42, 
    2, 28, 3, 97, 9, 28, 8, 49, 4, 35, 0, 92, 7, 98, 1,  3, 6, 79, 5, 30, 
    4, 78, 5, 23, 8, 40, 2, 83, 7, 90, 9, 56, 6,  3, 3, 58, 0, 78, 1, 11, 
    3, 41, 1, 43, 8, 98, 5, 88, 6, 16, 7, 69, 4, 33, 2, 32, 0,  5, 9, 96, 
    4,  4, 8, 57, 1, 52, 0, 32, 5, 12, 9, 64, 2, 66, 6, 27, 7, 60, 3, 63, 
    8, 32, 4,  7, 3, 90, 2,  8, 6, 20, 9, 90, 7, 51, 0, 89, 5, 16, 1, 34, 
    0, 25, 9, 45, 7, 45, 2, 50, 3, 30, 5, 91, 1, 46, 4, 83, 6, 41, 8, 46, 
    0, 81, 7, 99, 6, 79, 8,  3, 5, 33, 2, 17, 4, 32, 3, 20, 1, 78, 9, 69
  };
  const int r412[] = {
    10, 10, // Number of jobs and machines
    9, 98, 2, 19, 6, 10, 8, 41, 5, 27, 7, 27, 1, 47, 4, 25, 0, 72, 3, 78, 
    5, 17, 0, 44, 7, 59, 4, 90, 1, 68, 2,  7, 9, 52, 6, 99, 8, 78, 3, 12, 
    3, 35, 0, 28, 9, 95, 4, 81, 6, 91, 8, 32, 7, 64, 1, 52, 5,  7, 2, 31, 
    4, 86, 6, 39, 2, 16, 5, 63, 3, 65, 7, 19, 1, 84, 8, 37, 0, 89, 9, 20, 
    8, 61, 6, 10, 2, 45, 7, 88, 5, 25, 1, 35, 9, 98, 4,  8, 0, 71, 3,  5, 
    5, 21, 6, 90, 7, 63, 1, 15, 2, 98, 4, 80, 9, 47, 8, 83, 0, 15, 3, 40, 
    6,  7, 7, 33, 0, 69, 5, 51, 2, 62, 1, 65, 8, 45, 4, 39, 9, 40, 3, 49, 
    8, 84, 0, 99, 6, 18, 3, 75, 5, 56, 4, 92, 7, 10, 1, 47, 2, 74, 9, 36, 
    0, 11, 8, 20, 5, 48, 7, 48, 4, 89, 3, 13, 1,  9, 9, 28, 6, 67, 2, 26, 
    8, 51, 4, 88, 2, 57, 6, 18, 0, 22, 3, 39, 7, 96, 1, 25, 5, 83, 9, 99
  };
  const int r413[] = {
    10, 10, // Number of jobs and machines
    2, 76, 8, 70, 9, 50, 1, 19, 3, 35, 6, 48, 4, 42, 5,  8, 7, 48, 0, 30, 
    7, 96, 4, 84, 5, 20, 8, 78, 3,  4, 2, 85, 1, 33, 6, 33, 9, 35, 0, 67, 
    4, 96, 5, 86, 0, 10, 6,  5, 1, 94, 3, 54, 8, 69, 9, 63, 2, 18, 7, 74, 
    1, 41, 3, 99, 6, 48, 4, 73, 8, 40, 2, 74, 5, 78, 0, 55, 9, 77, 7, 47, 
    3, 83, 2, 86, 9, 40, 5,  8, 7,  6, 4, 56, 6, 11, 8, 95, 0, 13, 1, 38, 
    8, 32, 6, 29, 5, 62, 3,  8, 7, 29, 0,  2, 1,  6, 9, 20, 4, 21, 2, 87, 
    0, 13, 8, 28, 5, 14, 9, 24, 4, 47, 2, 90, 3, 39, 6,  1, 1, 52, 7, 52, 
    6, 29, 4, 71, 2, 87, 5,  6, 1, 63, 7, 96, 9, 10, 8, 37, 3, 65, 0, 23, 
    4, 21, 8,  4, 2,  2, 3, 56, 1, 35, 9, 80, 7, 21, 5, 73, 6, 64, 0, 39, 
    3, 49, 6, 64, 8, 59, 7,  2, 9, 11, 0, 85, 2, 34, 1, 52, 5, 38, 4, 89
  };
  const int r414[] = {
    10, 10, // Number of jobs and machines
    6, 12, 2, 29, 1, 52, 8, 53, 3, 20, 5, 88, 9, 53, 7,  5, 0, 60, 4, 69, 
    2, 52, 1, 25, 6, 70, 3, 20, 8, 87, 4, 92, 5, 38, 7, 95, 9, 66, 0, 90, 
    9, 43, 4, 75, 1, 58, 8, 89, 2, 87, 0, 80, 3,  7, 7, 18, 5, 82, 6, 98, 
    4, 27, 7,  7, 8, 68, 6, 65, 3, 97, 1, 44, 0, 82, 2, 29, 9, 64, 5, 14, 
    3, 35, 5, 57, 9, 66, 8, 35, 4,  4, 2, 46, 1, 28, 6, 49, 7, 50, 0, 95, 
    7,  1, 6, 48, 1, 76, 0,  8, 5, 76, 8, 47, 4, 26, 9, 56, 3, 10, 2, 65, 
    0, 38, 8, 65, 4, 17, 5, 50, 1, 42, 7,  4, 9, 19, 2, 47, 3, 83, 6, 69, 
    6, 74, 1, 22, 3, 32, 8, 30, 2, 65, 9, 50, 7, 39, 0, 70, 5, 85, 4, 24, 
    4, 74, 3,  8, 5, 75, 1, 18, 8, 49, 2, 76, 7,  2, 6, 84, 0, 98, 9, 62, 
    7, 44, 8, 71, 1, 83, 3, 61, 2, 45, 6, 35, 0, 16, 9, 69, 5, 23, 4, 58
  };
  const int r415[] = {
    10, 10, // Number of jobs and machines
    2, 51, 6, 74, 5,  9, 0, 74, 8, 94, 1, 15, 7, 47, 4, 92, 9, 95, 3, 47, 
    6, 85, 4, 10, 7, 43, 9,  5, 1, 80, 8, 65, 5, 12, 2, 18, 0,  7, 3, 27, 
    1, 10, 8, 57, 4, 25, 5, 68, 6, 77, 3, 92, 7, 45, 2, 17, 0,  8, 9, 29, 
    9, 84, 2, 20, 7, 72, 0, 56, 8, 31, 3, 84, 1,  9, 6, 39, 5, 81, 4,  7, 
    6, 39, 2, 74, 3, 87, 9, 78, 4, 73, 7, 36, 1, 95, 5, 23, 0, 30, 8, 90, 
    9, 35, 4, 60, 3, 24, 7, 12, 5, 12, 6, 72, 0, 76, 1, 87, 8, 98, 2, 98, 
    7, 79, 1, 96, 5, 23, 4, 91, 9, 95, 3, 82, 0, 48, 2, 80, 6, 78, 8, 47, 
    2, 52, 4, 51, 1, 66, 3, 86, 9, 70, 5, 49, 6, 18, 7, 62, 8, 84, 0,  5, 
    8, 52, 3, 66, 1, 64, 6, 33, 4, 44, 0, 14, 7, 25, 2, 53, 5, 65, 9, 71, 
    4, 51, 8, 58, 6, 12, 5, 29, 2, 71, 3, 52, 7, 27, 1, 97, 9,  5, 0, 81
  };
  const int r416[] = {
    10, 10, // Number of jobs and machines
    1, 31, 0, 47, 9, 12, 5, 52, 8, 29, 7, 65, 4, 44, 3,  2, 2, 68, 6, 37, 
    7, 70, 3, 84, 8, 67, 1, 34, 2,  3, 5, 63, 6,  5, 9, 64, 0, 23, 4, 34, 
    5, 32, 2, 10, 9, 53, 0, 14, 1,  9, 7, 82, 8, 46, 3, 53, 6, 20, 4, 77, 
    2, 57, 0, 60, 1, 64, 4, 33, 5,  8, 7, 48, 9, 91, 8, 97, 6,  7, 3, 49, 
    2, 43, 8, 67, 9,  3, 7, 94, 1, 12, 3, 89, 6, 76, 4, 76, 5,  3, 0, 96, 
    9, 52, 8, 57, 7, 51, 2,  1, 3, 74, 6, 21, 4, 94, 0, 50, 1, 84, 5, 68, 
    0, 74, 9, 22, 1, 97, 2, 81, 6, 25, 4, 88, 3, 37, 7, 26, 8, 20, 5, 54, 
    9, 37, 1, 87, 4, 41, 7, 82, 0, 47, 3, 73, 8, 59, 5, 89, 2, 80, 6, 26, 
    5, 17, 4, 85, 8, 32, 1, 54, 0, 63, 7, 53, 6, 12, 2,  9, 3, 88, 9, 77, 
    4, 97, 8, 64, 2,  7, 9, 99, 5, 48, 3, 64, 6, 64, 0, 93, 7, 52, 1, 43
  };
  const int r417[] = {
    10, 10, // Number of jobs and machines
    8,  7, 4, 88, 1, 49, 2, 95, 3, 58, 9, 78, 0, 46, 5, 68, 6, 39, 7, 22, 
    7, 41, 9, 82, 6, 22, 0, 76, 1, 19, 3,  1, 2,  9, 5, 30, 8, 77, 4, 53, 
    9, 78, 2, 79, 1, 88, 8, 89, 5, 26, 6, 88, 7, 76, 3, 43, 0, 38, 4, 68, 
    2, 51, 9, 76, 1, 25, 6, 71, 0, 90, 8, 85, 3, 68, 4, 39, 5, 77, 7, 86, 
    2, 86, 5, 14, 6, 43, 1, 80, 9, 33, 7, 29, 0, 82, 3,  7, 8, 94, 4, 40, 
    8, 74, 1, 51, 6, 57, 4, 88, 5, 74, 0, 55, 9, 59, 2, 71, 3,  2, 7,  5, 
    0, 43, 1, 28, 9, 35, 7, 41, 6, 42, 4, 82, 3, 14, 8, 33, 5, 90, 2, 83, 
    5, 48, 0, 10, 9, 63, 8, 57, 4, 62, 3, 11, 1, 45, 6, 14, 2, 14, 7,  4, 
    8, 96, 3, 44, 5, 74, 7,  7, 4,  9, 6, 85, 9,  3, 0,  4, 2, 50, 1, 57, 
    8, 12, 1, 10, 6, 13, 2,  1, 0, 66, 9, 60, 5, 45, 4, 96, 3, 60, 7, 14
  };
  const int r418[] = {
    10, 10, // Number of jobs and machines
    6, 68, 7, 34, 4, 11, 2, 46, 3, 72, 8, 60, 5,  4, 9, 84, 0, 78, 1, 34, 
    0, 74, 8, 55, 3, 75, 4, 97, 1, 59, 9, 30, 6, 70, 7, 88, 2, 43, 5, 61, 
    2, 12, 4,  2, 1, 38, 9, 63, 7, 21, 5, 31, 8, 11, 6, 90, 3, 21, 0, 94, 
    8, 15, 9, 83, 2, 37, 0, 52, 3, 72, 7, 47, 1, 29, 4, 79, 6, 33, 5, 18, 
    6, 26, 1, 82, 2, 24, 9,  3, 7, 36, 4, 89, 0, 14, 8, 53, 5, 26, 3,  4, 
    6, 16, 3, 50, 9, 22, 1, 89, 0, 67, 4, 30, 8, 16, 5, 72, 2,  7, 7, 14, 
    1, 52, 5, 58, 6, 67, 0, 47, 4, 68, 9, 64, 3, 98, 7, 61, 8,  3, 2, 63, 
    5, 68, 3, 86, 7, 29, 0, 46, 9, 57, 4, 79, 1, 21, 8, 65, 6, 85, 2, 27, 
    4, 78, 0, 89, 9, 38, 3, 17, 8, 56, 5, 46, 6, 53, 1, 40, 2, 84, 7, 74, 
    6, 23, 5, 47, 7, 78, 2, 31, 4, 66, 8, 82, 1, 43, 9, 73, 0, 25, 3, 26
  };
  const int r419[] = {
    10, 10, // Number of jobs and machines
    0, 21, 6, 76, 5, 88, 8,  4, 7, 17, 2, 48, 9, 18, 4, 71, 3, 16, 1, 27, 
    3, 31, 2, 54, 6, 52, 7, 40, 4, 59, 8, 76, 1, 22, 5, 71, 0, 64, 9, 27, 
    5, 12, 9, 69, 7, 79, 8,  4, 0, 49, 2, 62, 3, 57, 6, 74, 4, 45, 1, 38, 
    8, 72, 5, 88, 7, 20, 3, 19, 9, 21, 6, 64, 2, 14, 1, 60, 4, 72, 0,  8, 
    8, 24, 0, 60, 7, 78, 9, 63, 2, 24, 4, 24, 3, 53, 1, 71, 5, 72, 6, 66, 
    6, 17, 5, 37, 8, 83, 9, 95, 4, 57, 0, 99, 2,  1, 7, 38, 1, 60, 3, 47, 
    8, 89, 1, 33, 3, 93, 9, 27, 5, 53, 6, 39, 7, 49, 2, 84, 0, 62, 4, 27, 
    8, 68, 1, 52, 6, 63, 7, 31, 5, 63, 3, 39, 4, 67, 9, 13, 2, 83, 0, 18, 
    5, 84, 3, 74, 2, 65, 8, 77, 4, 25, 9, 88, 6, 42, 7, 95, 1, 11, 0, 36, 
    4, 29, 6, 62, 1, 10, 9, 60, 0, 91, 8, 63, 2, 17, 5, 92, 3,  4, 7, 79
  };
  const int r420[] = {
    10, 10, // Number of jobs and machines
    9, 94, 3, 21, 6, 92, 4, 61, 8, 98, 5,  8, 2,  9, 7, 38, 0, 56, 1, 49, 
    0,  6, 6,  5, 2, 49, 5, 89, 4, 29, 8, 53, 9, 37, 1,  7, 3, 15, 7, 35, 
    6, 94, 2, 76, 1, 76, 9, 15, 8, 80, 7, 48, 5, 34, 4, 19, 0,  8, 3, 70, 
    5, 67, 6, 21, 9, 54, 8,  2, 7, 30, 3, 30, 0, 91, 2, 50, 4, 94, 1, 16, 
    7, 41, 6, 33, 0, 11, 8,  6, 5, 78, 2, 80, 1, 37, 4, 95, 3,  6, 9, 86, 
    6, 36, 2, 52, 3, 41, 5, 98, 0, 95, 4, 92, 8, 18, 1, 60, 7,  2, 9, 61, 
    1, 60, 6, 70, 8, 85, 2, 58, 7, 68, 0, 41, 5, 20, 4, 43, 3, 69, 9, 33, 
    9, 53, 8, 91, 0, 64, 1, 21, 2, 92, 5, 42, 4, 32, 6,  7, 7,  5, 3, 78, 
    0, 32, 1, 10, 5, 17, 7, 85, 8, 86, 6,  9, 4, 97, 2, 40, 3, 54, 9, 29, 
    5, 62, 9, 89, 8, 90, 3, 40, 7, 76, 1, 53, 6, 60, 2, 25, 0, 51, 4, 68
  };
  const int r421[] = {
    10, 10, // Number of jobs and machines
    7, 82, 1, 72, 9, 44, 4, 12, 6, 95, 5, 91, 8, 92, 2, 68, 3, 57, 0, 10, 
    2, 88, 7, 65, 5, 34, 4, 19, 6, 92, 8,  1, 9, 58, 1, 73, 3, 87, 0,  3, 
    5, 24, 0,  1, 2, 22, 3, 96, 8, 43, 9, 76, 4, 42, 1, 86, 7, 25, 6, 37, 
    2, 73, 9, 53, 6, 44, 5, 16, 7, 80, 3, 58, 4, 12, 8, 68, 0, 60, 1,  1, 
    1, 34, 3, 91, 9, 40, 2, 13, 0, 85, 8, 63, 5, 34, 6,  1, 4, 47, 7, 51, 
    2, 76, 9, 75, 8, 21, 5, 95, 6, 47, 7, 75, 0,  7, 4, 83, 3, 93, 1, 61, 
    0, 23, 5, 46, 4, 71, 9,  4, 2, 76, 8, 72, 3, 21, 6, 25, 1, 83, 7, 44, 
    4, 28, 3, 53, 0, 95, 7, 89, 9, 50, 8, 88, 1, 48, 2, 31, 6, 12, 5, 82, 
    8, 44, 4, 35, 5, 71, 0, 83, 1,  9, 9, 26, 7, 47, 2, 99, 6, 79, 3, 87, 
    1, 56, 8, 35, 6, 47, 7, 95, 2, 38, 4,  8, 5, 35, 3, 29, 0, 75, 9,  4
  };
  const int r422[] = {
    10, 10, // Number of jobs and machines
    5, 86, 4, 25, 2, 24, 0, 54, 7, 54, 1, 98, 3, 14, 9, 98, 6, 32, 8, 71, 
    2, 60, 0, 73, 8, 95, 6, 80, 9, 15, 1, 75, 3, 14, 4, 79, 5, 27, 7, 72, 
    4, 10, 0, 23, 6, 32, 3, 44, 8,  4, 5, 32, 9, 95, 2, 39, 1, 36, 7, 53, 
    0, 98, 2, 80, 9, 16, 3, 63, 4, 37, 1, 35, 8, 50, 6, 44, 5, 86, 7, 75, 
    0, 63, 4,  3, 8, 70, 6,  4, 1, 20, 5, 86, 9,  2, 7, 86, 3, 78, 2, 36, 
    9, 81, 0, 79, 2, 18, 8, 89, 4, 64, 7, 77, 6, 73, 1, 35, 3, 48, 5, 81, 
    5, 21, 6, 98, 4, 72, 3, 15, 7,  1, 0, 11, 2, 79, 9, 18, 1, 34, 8, 13, 
    2,  3, 1, 14, 8, 50, 6, 27, 9, 59, 7,  6, 5, 76, 4,  3, 0, 13, 3, 75, 
    4, 91, 9, 12, 5, 20, 1, 37, 6, 67, 3, 43, 2, 17, 8,  6, 0, 72, 7, 45, 
    8, 99, 3, 19, 5, 70, 7, 72, 4, 28, 6, 48, 0, 28, 1, 65, 2, 50, 9, 45
  };
  const int r423[] = {
    10, 10, // Number of jobs and machines
    9, 76, 6, 72, 8, 97, 4, 96, 3, 31, 1, 21, 5, 93, 7, 12, 0, 75, 2, 67, 
    2, 61, 1, 30, 4, 50, 6, 95, 3, 66, 0, 37, 8, 63, 9, 41, 5, 18, 7, 46, 
    3, 13, 8, 40, 1,  5, 9, 55, 6, 31, 4, 69, 5, 41, 0, 40, 7,  5, 2, 32, 
    7, 46, 8, 73, 1, 12, 5, 86, 2, 19, 6, 96, 3, 62, 4, 39, 9, 33, 0, 80, 
    2, 20, 9, 10, 4,  5, 3, 34, 8, 88, 1, 99, 5, 78, 0, 91, 6, 18, 7, 34, 
    5, 54, 4, 91, 6, 56, 0,  9, 7, 15, 8, 53, 1, 76, 9,  3, 2, 48, 3, 40, 
    7, 87, 1, 36, 9, 57, 2, 37, 3, 81, 8,  8, 6, 39, 4, 25, 0, 64, 5, 52, 
    8, 19, 2, 29, 6, 18, 7, 92, 4, 13, 9, 80, 1,  7, 3, 47, 5, 51, 0, 19, 
    7, 22, 2, 74, 3, 86, 0, 40, 4, 66, 1, 58, 6, 34, 5, 60, 9, 51, 8, 47, 
    5,  4, 9, 78, 8, 68, 1, 37, 7, 55, 2, 54, 4, 89, 3, 87, 6, 71, 0, 70
  };
  const int r424[] = {
    10, 10, // Number of jobs and machines
    9, 26, 0, 12, 6, 93, 4, 46, 3, 47, 8, 22, 7, 21, 2, 64, 5, 61, 1, 62, 
    7, 92, 0, 69, 9,  8, 2, 48, 3, 68, 8, 80, 1, 49, 4, 80, 6, 39, 5, 11, 
    2, 49, 6, 66, 7, 71, 4, 75, 3, 23, 5, 65, 9, 51, 1, 62, 0, 23, 8, 66, 
    2, 31, 8, 79, 6,  6, 9, 29, 3, 39, 1, 91, 5, 57, 0, 57, 7, 11, 4, 45, 
    2, 31, 5, 56, 7, 64, 9, 35, 0,  8, 4, 14, 3, 12, 6, 81, 1, 70, 8, 95, 
    9, 61, 8, 87, 2, 43, 4,  6, 1, 74, 7, 45, 0, 57, 6,  5, 5, 74, 3, 29, 
    3, 95, 4, 79, 6, 72, 2,  6, 8,  8, 5, 13, 1, 67, 7, 33, 9, 45, 0, 51, 
    1, 49, 2, 81, 9, 34, 5, 64, 4, 78, 7, 85, 8, 50, 6, 24, 3, 63, 0, 52, 
    8,  6, 2, 18, 0, 98, 3, 62, 9, 83, 7, 65, 4, 43, 6, 52, 1, 75, 5, 58, 
    6, 90, 1, 21, 2, 11, 7,  1, 8, 33, 5, 74, 4,  6, 3, 31, 0, 83, 9, 11
  };
  const int r425[] = {
    10, 10, // Number of jobs and machines
    9, 93, 6, 77, 0, 85, 3, 35, 7, 58, 8,  8, 5, 25, 2, 89, 4, 85, 1, 80, 
    1, 81, 2, 79, 0, 88, 7, 61, 5, 39, 9, 67, 8, 74, 4, 32, 6, 25, 3, 15, 
    2, 41, 0, 66, 4, 83, 8,  9, 3, 44, 7,  2, 1, 52, 6, 53, 5, 73, 9, 26, 
    9, 38, 3, 62, 1, 26, 7, 16, 2, 43, 8, 88, 6, 37, 4, 86, 5, 54, 0, 36, 
    8, 71, 5, 65, 7, 20, 2, 18, 9, 75, 6, 44, 0, 94, 3, 75, 1, 31, 4, 30, 
    8, 62, 1, 34, 0, 40, 5, 96, 7, 44, 6, 10, 9, 89, 4, 99, 3, 62, 2, 76, 
    4, 90, 9, 46, 6, 82, 5, 66, 8, 44, 7,  9, 0, 32, 1, 31, 2, 38, 3, 16, 
    0, 42, 7, 76, 5, 97, 9, 78, 3, 77, 4, 73, 1, 37, 2,  6, 6,  1, 8, 45, 
    1, 74, 9, 49, 7, 38, 6, 94, 3, 53, 2, 14, 5, 38, 0, 17, 4, 42, 8, 22, 
    1, 44, 6, 57, 2, 14, 5, 71, 9, 84, 3, 23, 7,  1, 4, 73, 8,  1, 0, 84
  };
  const int r426[] = {
    10, 10, // Number of jobs and machines
    6, 40, 8, 66, 2, 50, 9, 66, 4, 82, 5, 89, 3, 23, 7, 47, 0, 17, 1, 90, 
    5, 96, 1, 48, 2, 48, 7, 28, 6, 39, 3, 79, 9, 70, 4, 20, 0, 29, 8, 22, 
    0, 24, 1, 14, 5, 76, 7, 43, 2, 19, 6, 22, 8, 15, 3, 27, 9, 77, 4, 85, 
    1, 24, 8, 44, 9, 94, 7, 28, 0, 72, 5,  6, 3, 86, 4, 48, 6,  8, 2, 11, 
    0, 58, 2, 88, 1, 48, 3, 75, 8, 11, 9, 74, 6, 53, 7, 51, 5, 74, 4, 34, 
    5, 26, 8, 83, 4, 74, 9, 59, 6,  9, 0, 25, 3, 36, 2, 31, 7, 76, 1, 90, 
    1, 91, 5, 30, 4, 59, 2, 40, 0, 64, 6, 43, 3, 53, 7, 69, 8, 87, 9,  4, 
    9, 91, 4, 19, 1, 27, 8, 79, 5,  6, 0, 20, 3, 50, 6, 32, 7, 80, 2, 71, 
    4, 52, 7, 30, 5, 37, 3, 31, 9, 40, 2, 67, 1, 24, 6, 21, 0, 34, 8, 35, 
    7, 33, 2, 53, 3, 88, 4, 39, 6, 89, 9, 10, 5, 29, 0, 71, 8, 72, 1,  8
  };
  const int r427[] = {
    10, 10, // Number of jobs and machines
    6, 47, 1, 21, 7, 47, 9, 74, 2, 12, 0, 61, 3, 87, 4, 32, 5, 58, 8, 35, 
    6, 47, 4, 28, 7, 16, 1, 77, 5, 43, 3, 62, 8, 79, 2, 43, 0, 38, 9,  3, 
    1, 54, 9, 89, 0, 26, 5, 94, 6, 48, 3, 79, 7, 31, 8, 48, 4, 58, 2, 76, 
    7, 58, 4,  4, 9,  4, 5,  9, 0, 81, 3, 37, 8, 27, 6, 87, 1, 71, 2, 40, 
    6,  1, 9,  7, 4, 39, 3, 34, 8, 43, 2, 21, 5, 13, 1, 25, 0, 88, 7,  5, 
    6, 82, 7, 75, 8,  8, 5, 14, 3, 37, 1, 68, 2, 32, 9, 48, 4, 12, 0, 20, 
    8, 12, 6, 73, 0, 88, 2, 18, 3, 80, 1, 22, 9, 13, 7, 43, 4, 64, 5, 40, 
    7, 20, 3, 68, 8, 48, 1, 40, 2, 51, 0, 94, 9, 47, 6, 83, 5, 48, 4, 69, 
    6, 12, 3, 24, 8, 77, 5, 44, 7, 83, 2, 80, 4, 54, 9, 29, 1, 35, 0, 42, 
    2, 22, 3,  9, 7, 32, 0, 64, 4, 32, 1, 20, 8, 71, 6,  2, 9, 91, 5, 77
  };
  const int r428[] = {
    10, 10, // Number of jobs and machines
    0,  3, 4, 54, 5, 29, 8, 70, 3, 52, 2, 19, 9, 21, 6, 18, 7, 24, 1, 40, 
    3, 92, 7, 65, 4,  8, 1, 58, 5, 27, 2, 77, 9, 17, 8, 66, 6, 68, 0, 65, 
    4, 38, 8,  6, 1, 31, 6, 93, 5, 21, 3, 82, 0, 59, 9, 58, 2, 41, 7, 57, 
    0, 79, 9, 93, 1, 84, 8, 45, 6, 27, 5, 68, 7, 95, 4, 84, 3, 79, 2, 57, 
    9, 22, 2, 36, 6, 89, 5, 15, 1, 66, 8, 32, 0, 15, 7, 27, 4, 10, 3, 90, 
    9, 42, 8, 54, 5, 82, 6, 45, 1, 99, 7, 35, 3, 93, 0, 41, 2, 34, 4, 13, 
    3, 66, 2, 48, 6,  9, 8, 56, 5, 61, 1, 28, 9, 14, 4, 81, 7, 46, 0, 14, 
    0, 28, 4, 32, 6, 50, 5, 35, 3,  9, 7, 30, 8, 92, 2, 49, 9, 91, 1, 48, 
    1, 65, 0, 69, 2, 42, 7, 78, 3, 77, 5, 92, 4, 64, 9, 47, 6, 62, 8, 90, 
    4, 88, 6, 88, 9, 19, 0, 77, 7, 20, 5, 85, 8, 43, 1, 87, 3, 77, 2, 40
  };
  const int r429[] = {
    10, 10, // Number of jobs and machines
    6, 65, 8, 37, 3, 25, 7, 58, 4, 43, 0, 81, 1, 41, 9,  2, 5,  5, 2, 90, 
    1, 27, 2, 14, 4, 86, 0, 57, 8, 69, 9, 72, 5, 16, 6, 13, 7, 45, 3,  4, 
    5, 48, 8,  7, 1, 67, 2, 70, 3, 48, 0, 65, 7, 97, 9, 43, 4, 70, 6, 44, 
    6, 38, 7, 44, 9,  7, 1, 63, 4, 59, 5, 47, 2, 18, 0, 55, 8, 82, 3, 81, 
    9, 86, 6, 69, 3, 24, 1, 48, 2, 25, 4, 44, 5, 61, 0, 73, 8, 84, 7, 98, 
    5, 28, 6, 56, 9, 55, 4, 54, 8,  5, 0, 50, 2, 22, 3,  2, 7, 26, 1, 31, 
    7, 49, 6, 44, 5, 90, 3, 32, 4, 57, 0, 15, 9,  4, 8,  6, 1, 64, 2, 49, 
    7, 92, 1, 55, 8, 54, 0,  8, 4,  2, 9, 35, 3, 30, 2, 31, 5, 64, 6,  4, 
    7, 34, 3, 20, 6, 12, 5, 50, 8, 73, 2, 69, 4, 79, 0, 27, 9, 22, 1, 11, 
    0, 19, 5, 93, 3, 96, 7, 57, 2, 66, 4, 65, 9, 55, 6, 18, 1, 67, 8, 75
  };
  const int r430[] = {
    10, 10, // Number of jobs and machines
    2, 73, 4, 17, 6, 45, 1, 93, 9, 84, 5, 93, 3, 87, 0, 16, 7, 77, 8, 48, 
    9, 62, 5, 27, 7, 98, 8, 58, 3, 76, 1, 17, 2, 62, 4, 16, 6, 71, 0, 45, 
    2, 68, 4, 98, 5, 35, 3, 96, 6, 42, 0, 36, 9, 73, 8, 19, 7, 44, 1, 95, 
    0, 83, 4, 29, 2, 62, 6, 12, 1, 20, 5, 90, 3, 79, 7, 50, 9, 85, 8, 50, 
    0, 64, 2, 32, 3, 44, 9, 64, 5, 67, 6, 65, 4,  9, 1,  5, 8, 56, 7,  9, 
    1, 14, 9, 26, 0, 38, 6, 37, 2, 98, 4, 98, 8, 98, 3, 25, 7, 97, 5, 57, 
    6, 39, 4, 38, 8, 76, 9, 10, 2, 12, 7, 51, 0, 57, 5, 49, 3, 45, 1, 85, 
    0, 23, 6, 87, 2,  1, 1, 33, 4, 17, 5, 52, 3, 34, 7, 25, 8, 97, 9, 49, 
    5, 83, 7, 21, 3, 73, 2, 25, 1, 24, 8, 56, 9, 14, 4, 30, 0, 32, 6, 81, 
    8, 61, 1, 83, 0, 84, 7, 39, 4, 99, 5, 10, 2, 55, 9, 82, 6, 69, 3, 41
  };
  const int r431[] = {
    10, 10, // Number of jobs and machines
    0, 60, 8, 58, 5, 80, 2, 38, 9, 63, 4, 92, 1, 41, 7, 31, 6, 38, 3, 18, 
    8, 57, 7, 32, 4, 22, 2,  2, 9, 51, 5, 32, 0, 40, 3, 80, 1, 91, 6, 75, 
    5, 69, 2, 56, 9,  9, 8, 18, 6, 54, 7,  6, 4, 96, 0, 69, 3, 51, 1, 61, 
    4, 31, 5, 38, 1,  7, 9, 21, 0, 87, 2, 19, 8, 95, 3, 41, 6, 25, 7, 52, 
    4, 35, 5, 30, 3, 98, 6, 72, 8, 32, 9, 11, 1, 98, 0,  8, 2, 87, 7, 39, 
    4,  9, 1, 39, 9, 74, 7, 93, 2, 95, 5, 29, 0, 48, 8,  6, 6, 78, 3, 10, 
    2,  4, 6, 34, 5, 99, 4, 80, 0, 13, 3, 30, 8, 16, 9, 17, 1, 54, 7, 53, 
    2, 33, 8, 98, 0, 50, 7, 67, 5, 31, 3, 80, 1, 47, 4, 60, 9, 80, 6, 59, 
    8, 12, 4, 61, 7, 71, 1, 86, 0, 97, 5, 32, 2, 20, 9, 87, 6, 17, 3, 51, 
    9, 17, 1, 12, 5, 12, 0, 43, 3, 84, 6, 61, 8, 90, 2, 96, 7,  9, 4, 14
  };
  const int r432[] = {
    10, 10, // Number of jobs and machines
    4, 98, 1, 99, 7,  8, 5, 86, 2, 58, 8, 42, 6, 82, 9, 24, 3, 89, 0, 94, 
    3, 85, 2, 23, 5, 96, 8, 51, 9, 84, 0, 24, 4, 31, 6, 94, 1, 34, 7, 28, 
    4, 81, 6, 13, 2, 24, 0, 58, 3, 48, 8, 61, 9, 64, 7, 67, 5, 13, 1,  2, 
    2, 80, 6, 48, 5, 27, 3,  8, 7, 88, 4, 50, 0, 88, 9, 20, 8,  4, 1, 39, 
    2, 56, 3, 18, 9, 82, 1, 59, 6,  8, 7, 59, 4, 41, 0, 21, 8, 10, 5, 19, 
    3, 59, 5, 52, 6, 29, 2, 70, 8, 70, 7,  8, 9, 91, 0, 49, 4, 47, 1, 45, 
    8, 25, 3, 37, 0, 99, 5, 95, 9, 12, 2, 12, 6, 96, 1, 89, 4, 46, 7, 89, 
    4, 31, 9, 61, 6, 91, 7, 56, 1, 25, 2, 90, 3, 78, 8, 96, 0, 73, 5, 57, 
    2, 19, 5, 23, 4, 86, 7, 57, 3, 63, 0, 54, 6, 56, 8,  8, 1, 32, 9, 65, 
    8, 93, 2, 49, 0, 40, 1,  4, 7, 60, 5, 38, 6,  6, 9, 82, 4, 43, 3, 51
  };
  const int r433[] = {
    10, 10, // Number of jobs and machines
    5, 58, 7, 90, 2,  9, 1, 39, 9, 13, 3, 38, 8, 20, 6, 75, 4, 91, 0, 92, 
    7, 43, 0, 65, 9,  6, 6, 28, 8,  1, 1, 97, 2, 40, 4, 19, 3, 37, 5, 30, 
    5, 89, 1, 60, 0, 37, 2, 39, 7, 89, 6, 40, 4, 18, 9, 22, 8, 64, 3, 73, 
    5, 84, 8,  7, 7, 79, 0, 76, 1,  4, 6, 18, 2, 63, 4, 44, 3, 44, 9, 57, 
    8, 54, 4,  7, 3, 81, 7, 29, 6, 29, 0, 89, 1, 10, 2, 14, 5, 98, 9, 13, 
    4,  6, 9, 16, 7, 87, 3, 65, 0, 22, 2,  7, 1, 96, 8, 31, 5, 98, 6, 44, 
    4, 56, 6, 34, 2, 98, 1, 43, 5, 88, 7, 56, 0, 17, 8, 91, 3, 97, 9, 93, 
    3, 58, 6, 34, 7, 52, 0, 90, 8, 64, 2, 37, 9, 42, 5, 33, 1, 90, 4,  6, 
    0, 53, 3, 74, 7, 40, 6, 56, 1, 60, 5, 74, 4, 12, 8, 62, 2,  5, 9, 15, 
    0, 17, 4, 37, 5, 37, 2, 58, 6, 75, 3, 57, 8, 60, 1, 34, 7, 32, 9, 72
  };
  const int r434[] = {
    10, 10, // Number of jobs and machines
    9, 52, 1, 41, 7, 22, 3, 81, 0, 60, 6, 27, 4, 82, 8,  1, 5, 21, 2, 12, 
    9, 37, 8, 95, 7, 16, 4, 85, 0, 93, 2, 47, 6, 60, 5, 21, 1, 46, 3, 70, 
    3, 99, 7, 66, 9, 40, 2,  4, 5, 97, 0, 18, 1, 23, 8, 53, 6, 20, 4, 39, 
    4, 96, 2, 90, 8, 71, 0, 43, 9, 80, 3, 60, 5,  4, 1, 69, 6, 23, 7, 68, 
    6, 50, 5, 70, 2,  3, 7, 13, 3, 13, 0, 74, 1, 60, 4, 21, 9, 93, 8, 38, 
    5,  6, 7, 20, 9, 53, 3, 22, 4, 53, 8, 32, 6, 64, 0, 33, 2, 34, 1, 43, 
    6, 55, 7, 18, 5, 94, 1, 50, 8, 14, 3, 12, 0, 99, 4, 63, 9, 91, 2, 99, 
    2, 39, 7, 98, 1, 29, 3, 49, 9, 59, 6, 46, 8, 43, 5, 54, 0, 51, 4, 45, 
    7, 52, 5, 52, 1, 15, 4, 69, 3, 65, 0, 98, 8, 41, 9, 79, 2, 32, 6, 38, 
    8, 68, 3, 44, 0,  6, 9,  6, 5, 15, 7, 72, 4, 79, 6, 21, 1, 62, 2,  7
  };
  const int r435[] = {
    10, 10, // Number of jobs and machines
    7, 49, 9, 98, 2, 89, 4,  5, 8, 75, 1, 16, 0,  5, 5, 65, 3, 97, 6, 93, 
    0, 87, 3, 74, 8, 88, 9,  9, 4, 20, 7, 60, 2, 31, 1, 71, 6,  1, 5, 84, 
    0, 18, 6, 81, 4, 25, 5, 49, 2, 84, 7, 72, 3, 36, 1, 36, 9, 52, 8,  3, 
    0, 16, 7, 97, 9, 91, 3, 26, 2, 42, 4, 72, 1, 18, 6, 60, 8, 52, 5, 15, 
    0, 10, 2, 16, 8, 13, 6, 24, 7, 98, 4, 22, 5, 47, 9, 25, 1, 57, 3, 85, 
    2, 54, 5, 15, 0, 24, 3, 77, 7, 18, 4, 73, 1, 67, 6, 80, 8, 69, 9,  5, 
    9,  5, 2,  8, 5, 66, 1, 76, 3,  6, 6, 53, 4, 87, 0, 88, 7, 11, 8,  5, 
    2,  5, 5, 61, 7, 66, 8,  8, 4,  9, 6, 84, 1, 15, 3, 15, 0, 65, 9, 83, 
    0, 81, 6, 15, 1, 55, 9, 28, 2, 98, 3, 82, 8, 69, 7, 70, 5, 23, 4,  7, 
    4, 78, 7,  3, 6, 63, 5, 42, 2, 32, 3, 90, 8, 35, 1, 88, 0, 72, 9, 11
  };
  const int r436[] = {
    10, 10, // Number of jobs and machines
    7, 20, 5, 86, 6, 51, 4, 85, 1, 38, 3, 95, 0, 53, 8, 71, 9, 46, 2,  6, 
    8, 31, 2, 62, 6, 35, 1,  3, 4, 79, 7, 49, 3, 96, 5, 82, 0, 34, 9, 55, 
    2, 22, 6, 86, 7, 33, 0, 93, 1, 62, 5, 66, 8, 92, 9,  7, 3, 84, 4, 34, 
    3, 23, 0, 58, 9, 73, 2, 26, 5, 96, 1, 65, 8, 85, 6, 90, 7, 91, 4, 40, 
    6, 79, 9, 37, 0, 40, 1, 15, 8, 67, 7, 77, 2, 69, 5, 74, 4, 35, 3, 65, 
    6, 91, 7, 43, 5, 90, 0,  4, 2, 77, 8, 42, 3, 42, 1, 55, 4, 76, 9, 19, 
    8, 11, 2,  4, 5, 49, 1, 67, 3, 79, 9, 51, 0, 14, 6, 77, 7, 27, 4, 25, 
    7, 10, 6, 69, 1, 40, 4, 45, 0, 37, 9, 12, 3, 25, 8, 27, 5, 48, 2, 12, 
    6, 69, 4, 21, 1, 92, 9,  9, 7,  9, 0, 39, 3, 77, 2, 17, 5, 47, 8, 40, 
    2, 68, 9, 90, 6, 20, 5, 99, 0, 28, 4, 22, 1, 68, 3, 82, 8, 96, 7, 76
  };
  const int r437[] = {
    10, 10, // Number of jobs and machines
    3, 42, 1, 86, 5, 17, 4,  4, 9, 41, 8, 60, 7, 79, 6, 54, 0,  6, 2,  9, 
    3, 93, 7, 74, 0, 43, 6, 40, 5, 35, 9, 46, 4, 28, 2, 52, 8, 39, 1, 90, 
    4, 83, 1, 39, 2, 81, 5, 20, 7, 37, 9, 60, 0, 54, 3, 86, 6, 57, 8, 25, 
    2, 54, 6, 54, 3, 94, 9, 14, 4,  4, 1, 49, 7, 41, 8, 82, 0, 50, 5, 62, 
    8, 42, 7, 33, 2, 88, 4, 71, 0, 68, 3, 69, 1,  1, 6, 60, 5, 86, 9, 18, 
    6, 62, 8, 59, 3, 24, 9, 53, 1, 60, 7, 81, 4, 89, 5, 59, 0, 62, 2, 68, 
    9, 93, 5, 22, 3, 98, 1, 32, 4, 34, 0, 91, 8, 10, 7, 56, 6, 90, 2, 56, 
    2, 32, 8, 35, 3, 44, 7, 68, 5, 31, 9,  3, 0, 76, 4, 65, 1, 37, 6, 84, 
    3, 45, 7, 27, 1, 79, 0, 29, 4, 90, 5, 13, 2, 57, 8, 92, 6,  6, 9, 91, 
    6, 15, 0, 49, 1, 16, 4,  8, 2, 43, 9, 46, 7, 27, 8, 35, 3, 26, 5, 63
  };
  const int r438[] = {
    10, 10, // Number of jobs and machines
    4, 16, 8, 42, 7, 45, 5, 20, 6,  8, 2, 23, 1,  8, 9, 58, 3, 57, 0, 98, 
    5, 89, 3,  3, 6, 11, 4, 67, 1, 37, 9, 95, 0, 85, 2,  1, 8, 59, 7, 89, 
    0, 51, 1, 46, 9, 71, 6, 61, 5, 47, 8, 28, 4, 45, 7, 56, 3,  5, 2, 87, 
    4, 54, 1, 22, 9, 71, 7, 94, 0, 21, 3, 12, 6, 98, 8, 50, 2,  5, 5, 53, 
    5, 21, 2, 75, 8, 94, 1, 67, 3, 30, 0, 26, 7, 52, 9, 19, 6,  3, 4, 34, 
    5, 48, 2, 42, 0, 45, 8,  8, 4,  4, 7, 93, 3, 49, 9, 47, 1, 44, 6, 14, 
    4, 33, 0, 41, 1,  3, 2, 28, 5, 96, 9, 49, 6, 65, 7, 82, 3, 95, 8, 19, 
    7,  6, 3, 63, 1, 50, 6, 23, 9, 71, 5, 56, 8, 22, 2, 51, 0, 35, 4, 30, 
    8, 77, 5, 91, 2, 40, 4, 29, 6, 57, 1, 49, 9, 67, 7, 75, 0, 73, 3, 65, 
    2, 80, 4, 43, 3, 63, 5, 49, 7, 99, 1, 70, 9, 10, 6, 17, 0, 57, 8, 52
  };
  const int r439[] = {
    10, 10, // Number of jobs and machines
    6, 37, 4, 15, 5, 94, 9, 31, 2, 23, 8, 19, 0,  9, 1, 57, 3,  8, 7, 44, 
    9, 63, 6, 90, 4, 75, 1, 16, 0, 53, 7, 68, 8, 22, 2, 19, 5, 59, 3, 66, 
    4, 64, 7, 82, 5, 71, 9,  4, 2, 41, 0, 31, 1,  5, 3, 23, 6, 72, 8, 92, 
    0, 31, 2, 96, 6, 96, 1, 70, 5, 76, 9, 81, 7, 31, 3,  5, 8, 28, 4, 27, 
    2, 80, 7,  7, 8, 49, 0, 33, 4, 27, 3, 23, 5, 25, 1, 42, 9, 19, 6,  9, 
    7, 74, 0,  3, 4, 68, 5, 29, 9, 53, 6, 28, 3, 98, 1, 66, 2, 24, 8, 76, 
    9, 80, 5, 87, 0, 10, 7, 77, 8, 22, 2, 23, 3, 60, 6, 32, 4, 62, 1, 84, 
    8, 85, 6, 22, 3, 14, 1, 35, 2, 30, 0, 80, 9, 90, 4, 16, 7, 30, 5, 36, 
    1,  9, 2, 88, 0, 69, 8, 40, 9, 69, 6, 61, 3, 20, 7, 60, 4, 47, 5, 99, 
    8, 28, 7, 55, 6, 30, 4, 83, 9, 65, 3, 82, 2, 21, 5,  7, 0, 86, 1, 73
  };
  const int r440[] = {
    10, 10, // Number of jobs and machines
    5, 10, 6, 97, 3, 81, 1, 81, 9, 58, 0, 22, 7, 40, 8, 30, 2, 44, 4, 29, 
    2, 48, 5, 49, 8,  9, 1, 64, 9, 22, 7, 39, 4, 73, 0, 27, 3, 18, 6, 64, 
    7, 99, 6, 71, 0, 71, 2, 76, 8, 74, 4, 97, 3, 83, 1, 80, 5, 26, 9, 38, 
    0, 10, 7, 21, 6, 18, 4, 51, 3, 96, 2, 43, 9, 88, 5, 82, 8,  1, 1, 55, 
    0, 21, 8, 47, 2, 75, 7, 54, 3, 90, 9, 44, 5, 82, 6, 73, 4, 99, 1, 25, 
    4, 92, 9, 50, 2,  1, 1, 63, 0, 81, 8, 12, 6, 78, 7, 46, 3, 70, 5, 56, 
    5, 66, 6, 54, 0, 89, 1, 93, 9,  3, 8, 91, 7, 54, 2, 41, 4, 78, 3, 42, 
    1, 58, 6, 82, 2, 85, 0, 70, 5,  4, 4, 21, 7,  4, 8, 70, 9, 55, 3,  8, 
    0, 68, 4, 61, 3, 75, 7, 55, 5, 30, 2, 50, 9, 17, 1, 40, 6, 77, 8, 45, 
    6, 33, 9, 15, 1, 72, 2, 51, 3, 59, 5, 83, 0,  6, 4, 17, 7, 85, 8, 32
  };
  const int r441[] = {
    10, 10, // Number of jobs and machines
    2, 70, 6, 25, 8, 28, 9, 97, 3, 43, 4, 41, 5, 88, 7, 18, 1, 27, 0, 32, 
    6, 26, 1, 69, 4, 83, 2, 78, 0, 84, 3, 22, 8, 79, 7, 78, 5, 64, 9, 61, 
    7, 47, 6, 49, 4, 75, 9, 49, 1, 35, 3, 42, 8, 80, 2, 65, 0, 63, 5, 43, 
    8, 37, 0, 97, 4, 79, 2, 80, 7, 81, 1, 45, 9, 98, 6, 30, 3, 39, 5, 93, 
    8, 15, 7, 39, 2, 80, 1, 75, 5, 96, 3,  5, 6, 27, 0, 57, 4, 11, 9, 66, 
    1, 54, 3, 71, 0, 64, 6, 68, 7, 45, 4, 70, 5, 23, 8, 19, 2, 96, 9,  5, 
    2, 83, 7, 16, 9, 52, 4, 44, 8, 12, 3,  6, 1, 84, 0,  8, 5, 89, 6, 46, 
    1, 80, 0, 18, 8, 42, 9, 78, 6, 59, 7, 33, 5, 32, 2, 34, 4, 11, 3,  1, 
    4, 70, 5, 27, 0, 99, 3, 82, 7, 77, 8, 63, 1, 81, 6, 88, 9, 99, 2,  5, 
    1, 77, 0, 51, 8, 96, 4, 13, 7, 98, 9, 58, 5, 16, 2, 36, 3, 14, 6, 20
  };
  const int r442[] = {
    10, 10, // Number of jobs and machines
    9, 72, 6, 99, 1, 49, 4, 80, 2, 40, 3, 90, 8, 52, 0, 42, 7, 19, 5, 46, 
    8, 58, 3, 58, 9, 53, 5, 53, 4, 10, 1, 36, 7, 92, 6, 98, 2, 39, 0, 16, 
    7, 82, 2, 64, 6, 61, 1, 45, 0, 21, 5, 96, 4,  8, 3, 59, 9, 14, 8, 20, 
    3, 75, 2, 32, 5, 44, 7, 51, 1, 59, 4, 86, 6, 61, 0, 57, 9, 35, 8, 97, 
    2, 88, 9, 57, 3, 20, 5, 75, 1, 66, 4, 11, 8, 61, 0, 44, 6,  6, 7, 77, 
    8, 85, 7, 61, 2, 64, 4, 96, 9, 83, 1, 55, 3, 24, 0, 40, 6, 72, 5, 70, 
    3, 72, 8, 40, 5, 71, 7, 29, 0,  4, 1, 36, 2, 85, 9, 21, 6, 60, 4, 32, 
    0, 19, 7, 90, 6, 15, 5, 17, 2, 43, 3, 45, 1, 54, 9, 53, 4, 97, 8, 81, 
    6, 63, 7, 28, 2, 67, 0, 81, 3, 97, 8, 51, 4, 25, 9,  5, 5, 73, 1,  1, 
    2, 76, 1, 99, 7, 97, 6, 17, 0,  5, 9, 87, 8, 48, 3, 64, 4, 33, 5, 57
  };
  const int r443[] = {
    10, 10, // Number of jobs and machines
    4, 78, 7, 37, 2, 45, 1,  5, 3, 66, 8, 64, 5, 46, 0, 82, 6, 99, 9,  3, 
    7, 92, 3, 91, 4, 29, 9, 54, 1, 93, 5, 38, 8, 89, 2,  2, 6, 27, 0, 55, 
    8, 66, 3, 10, 9, 91, 2, 63, 0, 67, 5, 46, 4, 71, 1, 88, 7, 88, 6, 98, 
    7, 49, 0, 80, 8, 26, 3, 25, 1, 54, 9, 86, 6, 53, 5, 58, 2, 46, 4, 74, 
    9, 39, 2, 10, 8, 22, 3, 90, 4, 24, 1, 92, 6, 60, 7, 32, 5, 26, 0, 28, 
    1, 88, 7, 35, 0, 17, 9, 47, 6,  8, 4, 79, 8, 73, 5, 47, 3, 26, 2, 80, 
    8, 35, 3, 12, 2, 99, 0, 44, 1, 95, 4, 86, 6, 44, 5, 99, 7, 89, 9, 35, 
    5, 58, 4, 48, 3, 85, 6, 85, 1, 63, 2, 72, 7, 81, 8, 79, 9, 90, 0, 48, 
    7, 78, 3, 49, 9, 25, 8, 81, 0, 85, 5, 25, 6, 54, 1, 85, 4,  6, 2, 73, 
    1, 39, 5, 30, 2, 91, 9, 65, 3, 72, 0, 52, 8, 25, 4, 66, 7, 48, 6, 87
  };
  const int r444[] = {
    10, 10, // Number of jobs and machines
    6, 55, 2, 42, 8, 13, 0, 43, 5, 61, 1, 36, 7, 93, 4, 46, 9, 36, 3, 66, 
    0,  5, 9, 36, 5, 40, 7, 92, 2, 69, 4, 76, 8, 21, 3, 51, 1, 87, 6, 50, 
    1,  6, 9, 39, 0, 15, 5, 58, 4,  2, 2, 98, 3, 60, 7,  3, 6, 97, 8, 59, 
    7, 30, 6, 98, 3, 52, 9, 91, 0, 33, 8, 49, 1, 46, 5, 42, 2, 88, 4, 47, 
    6, 83, 0,  4, 7, 36, 2, 47, 1, 77, 3, 59, 9, 85, 8, 58, 4, 84, 5, 84, 
    9,  9, 0, 79, 2, 98, 1, 51, 6, 14, 5,  5, 7, 83, 3, 26, 4, 44, 8, 45, 
    2, 69, 8, 73, 0, 37, 7, 41, 5, 61, 1,  5, 6, 99, 4, 15, 3, 27, 9, 38, 
    3, 43, 7, 51, 6, 92, 2, 80, 0, 62, 8, 43, 5, 19, 1, 77, 9, 45, 4, 69, 
    0, 78, 7, 74, 3,  8, 4, 81, 9, 21, 5, 98, 8,  8, 6,  1, 1, 96, 2, 55, 
    1, 67, 8, 56, 2, 42, 5, 92, 3,  6, 7, 12, 6, 79, 0, 17, 9, 49, 4, 16
  };
  const int r445[] = {
    10, 10, // Number of jobs and machines
    8, 68, 7, 67, 9, 99, 2, 84, 1, 88, 3, 20, 4, 33, 6, 58, 0, 72, 5, 15, 
    6, 89, 5, 14, 7, 28, 4, 75, 8, 58, 9, 30, 1, 24, 3, 69, 2,  7, 0, 33, 
    6, 67, 7, 95, 2, 14, 5, 44, 4, 14, 1, 57, 8, 48, 3, 27, 9, 35, 0,  9, 
    3, 29, 0, 87, 1, 31, 2, 63, 8, 14, 7, 48, 6, 23, 9, 74, 5, 12, 4, 83, 
    7, 43, 5, 38, 3, 97, 8, 83, 0,  4, 6, 94, 1, 16, 4, 72, 9, 79, 2, 79, 
    9, 56, 8, 59, 4, 53, 5, 98, 6, 51, 0, 23, 2, 11, 1,  4, 3, 87, 7, 19, 
    6,  6, 7, 60, 9, 26, 4, 52, 2, 49, 0, 99, 1, 31, 8, 22, 5, 48, 3, 44, 
    0, 63, 3,  4, 5, 60, 6, 72, 2, 15, 9, 91, 7, 45, 1, 43, 4, 34, 8, 45, 
    6, 17, 4, 32, 7, 57, 0, 68, 8, 26, 2, 76, 9,  9, 1, 84, 3, 65, 5, 68, 
    3,  1, 7, 54, 9, 58, 5,  6, 8, 53, 6,  4, 4, 49, 1, 21, 2,  9, 0, 56
  };
  const int r446[] = {
    10, 10, // Number of jobs and machines
    5, 97, 4, 72, 1,  5, 3, 62, 7, 27, 6, 28, 8, 96, 9, 40, 2, 22, 0, 95, 
    3, 52, 8, 95, 0, 36, 5, 27, 4, 52, 2, 46, 9,  5, 7,  6, 6, 42, 1, 30, 
    3, 94, 6, 89, 8, 14, 0, 73, 2, 77, 5, 87, 4, 79, 7, 87, 9,  8, 1,  9, 
    0, 59, 9, 85, 2, 80, 4,  6, 7, 78, 3, 19, 5, 77, 8, 22, 1, 79, 6, 55, 
    3, 44, 0,  1, 4, 91, 9, 76, 5, 87, 7, 23, 1, 45, 8, 47, 6, 49, 2, 90, 
    8, 60, 7, 88, 9,  6, 5, 48, 1, 31, 6, 49, 0, 14, 3, 84, 4, 17, 2, 23, 
    4, 14, 5, 82, 6, 71, 9, 63, 7, 31, 3,  4, 0, 59, 1, 44, 8, 51, 2, 18, 
    3, 39, 7, 62, 2,  7, 4, 48, 9, 18, 0, 11, 5, 68, 6, 74, 8, 31, 1, 88, 
    3, 24, 6, 56, 4, 13, 0, 49, 5, 29, 7, 77, 1, 88, 2, 99, 9,  7, 8, 74, 
    6, 57, 1, 81, 4, 13, 3, 36, 2, 17, 0, 93, 5, 98, 8, 53, 9, 65, 7, 80
  };
  const int r447[] = {
    10, 10, // Number of jobs and machines
    1, 36, 2, 38, 6, 80, 9, 39, 4, 62, 7, 15, 8, 17, 0, 36, 5, 81, 3, 65, 
    7, 84, 0, 91, 1,  4, 9,  3, 8, 38, 2, 48, 6, 50, 3, 24, 5, 29, 4, 34, 
    4, 82, 3, 44, 5, 21, 1, 83, 2, 91, 6, 46, 0, 83, 8, 10, 9, 41, 7, 23, 
    1, 18, 9, 81, 0, 24, 7, 21, 8, 74, 6, 95, 5, 31, 2, 24, 4, 30, 3, 82, 
    0, 50, 5, 39, 1, 18, 6, 74, 9, 13, 3, 68, 2, 85, 7, 65, 4, 26, 8, 92, 
    3, 26, 7, 77, 2,  2, 9, 63, 4, 72, 1, 42, 5, 85, 6, 73, 8,  9, 0,  2, 
    6, 69, 3, 32, 2, 12, 0, 76, 4, 93, 5, 32, 9, 79, 7, 47, 1, 26, 8, 67, 
    7, 90, 9, 64, 4, 93, 3, 47, 5, 79, 1, 68, 8, 44, 6, 76, 2, 60, 0, 89, 
    1, 47, 8, 18, 0, 59, 7, 21, 9, 32, 3, 43, 2,  6, 5, 34, 6, 76, 4, 19, 
    4, 51, 2, 39, 3, 92, 6,  1, 5, 74, 1, 52, 7, 86, 8, 58, 0, 97, 9, 34
  };
  const int r448[] = {
    10, 10, // Number of jobs and machines
    7, 56, 5, 59, 1, 35, 4, 91, 2, 82, 6, 21, 0, 27, 3, 82, 9, 44, 8, 85, 
    8, 54, 6, 43, 1,  8, 2, 50, 3, 44, 9,  9, 0, 86, 5, 98, 7, 73, 4,  4, 
    0, 79, 4,  6, 9, 13, 1, 25, 5, 73, 8, 13, 7, 24, 3, 25, 2, 39, 6, 52, 
    7, 19, 4, 20, 0, 23, 9, 11, 1, 77, 5, 61, 2, 52, 6, 32, 3, 62, 8, 87, 
    3, 55, 4, 62, 9, 33, 6, 38, 7, 93, 2,  5, 1, 31, 5,  5, 0, 14, 8, 59, 
    3, 74, 4, 10, 9, 26, 2, 55, 5, 57, 8,  8, 1, 48, 6, 40, 0,  6, 7,  2, 
    1, 68, 3, 11, 9,  9, 6, 48, 5, 73, 7, 47, 0, 99, 4, 99, 8, 93, 2, 12, 
    0, 73, 2, 50, 4, 91, 3, 61, 6, 93, 5, 58, 8, 93, 9,  6, 7, 89, 1,  1, 
    1, 47, 2, 24, 6, 73, 9, 65, 5, 91, 8, 97, 3, 23, 0, 13, 4, 97, 7,  7, 
    8, 59, 6, 87, 5, 96, 1,  8, 4, 60, 0, 97, 3, 19, 7, 90, 2, 63, 9,  3
  };
  const int r449[] = {
    10, 10, // Number of jobs and machines
    9, 11, 5, 18, 0, 11, 4, 19, 2, 35, 6, 63, 1, 44, 7, 70, 8, 44, 3, 34, 
    5, 34, 1, 29, 3, 37, 0, 93, 8, 39, 4, 15, 7, 58, 9, 68, 2, 79, 6, 44, 
    9, 40, 4, 97, 5, 37, 8, 97, 1, 18, 6, 28, 7, 11, 3, 20, 2, 43, 0, 25, 
    1, 60, 0, 95, 6, 68, 7, 18, 2, 98, 5, 71, 9, 58, 8, 86, 4, 63, 3, 25, 
    5, 45, 1, 59, 9, 97, 3, 94, 4, 72, 7, 63, 0, 43, 8, 56, 2, 33, 6, 19, 
    1, 69, 9, 91, 2, 19, 7, 92, 8, 43, 4, 64, 0, 28, 6, 24, 5, 14, 3, 43, 
    3, 72, 8, 33, 1, 36, 2, 52, 0, 55, 9, 78, 6, 74, 4, 64, 5, 41, 7, 47, 
    8, 41, 6, 40, 7, 91, 0, 60, 1, 32, 2, 94, 9, 74, 3, 72, 5,  4, 4, 47, 
    6, 25, 5, 30, 4, 99, 8,  7, 0, 55, 2, 10, 1, 71, 3, 14, 7, 54, 9, 36, 
    8, 53, 4, 20, 7, 10, 6, 34, 9,  6, 3, 90, 1, 33, 0, 31, 2, 94, 5, 26
  };
  const int r450[] = {
    10, 10, // Number of jobs and machines
    3, 28, 8, 90, 5, 70, 7, 93, 6, 12, 2, 87, 9, 47, 4, 97, 0, 21, 1, 17, 
    0, 97, 6, 14, 7, 91, 8, 60, 5, 87, 1, 26, 2, 63, 4, 76, 9,  8, 3, 55, 
    3, 15, 8, 92, 1, 75, 7, 47, 0, 29, 2, 45, 5, 64, 4, 40, 6, 34, 9, 27, 
    2, 68, 4, 95, 5, 96, 3, 83, 0, 54, 1, 35, 9, 67, 6,  8, 8, 83, 7, 18, 
    3, 86, 9, 82, 4, 44, 2, 44, 8, 23, 5, 70, 6, 24, 1, 89, 7, 20, 0, 61, 
    9, 87, 3, 83, 4, 24, 0, 71, 7, 23, 1, 70, 2, 90, 5, 74, 6, 27, 8, 57, 
    7, 93, 0,  6, 9, 64, 6, 36, 4, 13, 2, 58, 5, 67, 1, 79, 8, 30, 3, 49, 
    3, 99, 6, 57, 5, 58, 0, 77, 2, 73, 9, 12, 4, 94, 7, 48, 1, 12, 8, 86, 
    1, 61, 9, 87, 2, 27, 0, 76, 5,  6, 8, 18, 7, 75, 4, 73, 3, 79, 6, 13, 
    0, 94, 7, 95, 5, 72, 1, 31, 3, 62, 4, 10, 8, 21, 6,  1, 9, 42, 2, 12
  };
  const int r451[] = {
    10, 10, // Number of jobs and machines
    7, 15, 1, 71, 3, 38, 2,  4, 0, 66, 9, 39, 5, 17, 4, 31, 8, 42, 6, 66, 
    9, 65, 1,  7, 8, 35, 5, 11, 4, 41, 3, 79, 0, 36, 6, 41, 2, 88, 7, 46, 
    3, 91, 9, 22, 8, 27, 6, 94, 2, 39, 7, 54, 0, 73, 1, 12, 5, 81, 4, 33, 
    4, 63, 1, 48, 9, 55, 6, 41, 8, 72, 7, 50, 3, 75, 5,  3, 0,  8, 2, 77, 
    2, 33, 5,  7, 3,  7, 8, 37, 4, 74, 7,  1, 1, 61, 0, 49, 6, 42, 9, 85, 
    6, 84, 9, 20, 1, 18, 5, 58, 3, 39, 8, 50, 2, 93, 7, 81, 4, 58, 0, 11, 
    5, 96, 2, 82, 6, 31, 1, 86, 3, 70, 7, 63, 0, 56, 9,  3, 4, 95, 8, 83, 
    6, 65, 7, 67, 3,  3, 9, 94, 0, 11, 2, 97, 4, 29, 5, 58, 8, 22, 1, 57, 
    8, 82, 3, 94, 1, 55, 5, 67, 6, 77, 4, 63, 7, 56, 2, 10, 0,  9, 9, 22, 
    6, 88, 5, 83, 4, 62, 0, 33, 8, 94, 9, 34, 7, 60, 1, 29, 3, 65, 2, 25
  };
  const int r452[] = {
    10, 10, // Number of jobs and machines
    1, 62, 9, 36, 5, 86, 0, 62, 4,  3, 7, 17, 3, 43, 6, 96, 8, 77, 2, 54, 
    9, 66, 8, 45, 7, 91, 5, 95, 6,  5, 2, 50, 3, 42, 4, 61, 1, 38, 0, 92, 
    5, 71, 7,  9, 8, 76, 2, 19, 0, 73, 3,  3, 1,  4, 9, 25, 6, 35, 4, 23, 
    4, 94, 9, 69, 7, 48, 3, 61, 0, 73, 8, 36, 2, 70, 6, 33, 5, 78, 1, 61, 
    3, 59, 1, 65, 9, 16, 8, 54, 4, 18, 0, 55, 2, 29, 7, 25, 6, 43, 5,  5, 
    6, 14, 9, 22, 5, 90, 3, 78, 7, 14, 0, 38, 8, 54, 2, 70, 4, 20, 1, 15, 
    9, 34, 8,  3, 1, 93, 5, 98, 7, 68, 0, 59, 2, 77, 3, 60, 4, 14, 6, 75, 
    5, 48, 9, 37, 3, 65, 2, 78, 7,  1, 6, 24, 1, 91, 4,  5, 8, 78, 0, 58, 
    1, 34, 5, 48, 0, 75, 3,  3, 9, 99, 6, 70, 2, 45, 7,  5, 4,  4, 8, 27, 
    9, 99, 3, 13, 6, 16, 8, 36, 2,  7, 4, 39, 0, 33, 7, 24, 5, 56, 1, 27
  };
  const int r453[] = {
    10, 10, // Number of jobs and machines
    8, 11, 5, 23, 4, 58, 1, 39, 9, 99, 0, 62, 3, 38, 2,  1, 6, 97, 7, 99, 
    5, 23, 6, 37, 2, 30, 0, 37, 4, 42, 8, 46, 3, 17, 7, 69, 1, 15, 9, 51, 
    5, 33, 7, 76, 4, 73, 2, 45, 3, 60, 8, 94, 0,  2, 9, 60, 1, 34, 6,  8, 
    2, 80, 9, 65, 5, 57, 6, 66, 1, 20, 4, 89, 7, 24, 8, 61, 0, 67, 3, 55, 
    6, 16, 7, 68, 3,  8, 8, 26, 1, 26, 5, 86, 0, 30, 9, 33, 4, 95, 2,  3, 
    8, 15, 5,  9, 2, 83, 6, 26, 7,  8, 9, 53, 4, 17, 3, 77, 0, 55, 1, 10, 
    3, 69, 2, 95, 7, 45, 8, 74, 6, 74, 9, 30, 5,  4, 0, 17, 1, 92, 4, 57, 
    0, 98, 2, 67, 1, 99, 9, 53, 5, 54, 6, 38, 3,  6, 4,  8, 8, 49, 7, 49, 
    8, 60, 5, 72, 2,  3, 0, 96, 9, 28, 1,  6, 6, 43, 7, 74, 3, 79, 4, 20, 
    7, 42, 6, 36, 8, 29, 2, 74, 3, 77, 9, 99, 1, 86, 4, 30, 0, 27, 5, 13
  };
  const int r454[] = {
    10, 10, // Number of jobs and machines
    9,  7, 3, 40, 6, 51, 0, 92, 5, 19, 8, 77, 4, 29, 7, 19, 1,  2, 2, 53, 
    4, 70, 7, 73, 8, 61, 1, 28, 0, 11, 9,  9, 2, 38, 6, 72, 3, 41, 5, 13, 
    5, 45, 2, 40, 9, 99, 6, 88, 8, 77, 4, 97, 7,  2, 1,  5, 3,  9, 0, 18, 
    8, 66, 9, 23, 0, 42, 7, 38, 2, 58, 4, 66, 5,  2, 6, 48, 1, 73, 3, 36, 
    6, 70, 0, 61, 2, 74, 8,  1, 3, 46, 9, 67, 4, 79, 1, 45, 5, 30, 7, 21, 
    9, 50, 2, 39, 0, 22, 6, 29, 3, 79, 4, 65, 7, 97, 8, 34, 5, 55, 1, 31, 
    1, 94, 8, 86, 9, 63, 6, 97, 0, 35, 5, 82, 3,  8, 2, 73, 4, 45, 7, 84, 
    5, 57, 7, 16, 2, 49, 4, 77, 1, 50, 9, 59, 3, 86, 8, 21, 0, 13, 6, 38, 
    5, 12, 6, 85, 7,  3, 9, 37, 3, 87, 4, 66, 0, 95, 2, 24, 1, 98, 8,  9, 
    2, 77, 3, 34, 9, 98, 4, 24, 7, 31, 5, 58, 6, 43, 1, 73, 8, 13, 0, 25
  };
  const int r455[] = {
    10, 10, // Number of jobs and machines
    2, 59, 8, 38, 7, 76, 1,  1, 3, 53, 4, 91, 6, 14, 5, 55, 9, 32, 0, 48, 
    2, 50, 9, 14, 8, 66, 7, 20, 4, 73, 3, 12, 0, 46, 1, 61, 5, 26, 6, 17, 
    7, 36, 2, 14, 6,  4, 9, 30, 3, 59, 4, 75, 1, 59, 0, 65, 5, 12, 8,  6, 
    7, 56, 3, 60, 4, 89, 1, 15, 5, 34, 9, 58, 8, 63, 2, 72, 6, 40, 0, 23, 
    0, 65, 3, 59, 2, 31, 1, 89, 7, 43, 4, 92, 8, 76, 9, 27, 5, 32, 6, 14, 
    8,  1, 6, 68, 0, 73, 7, 66, 3,  2, 5, 98, 9, 46, 2, 19, 4,  1, 1, 60, 
    5, 18, 0, 64, 4, 31, 9, 24, 3,  8, 7, 11, 1, 68, 6, 42, 2, 41, 8, 22, 
    4, 73, 7, 87, 2, 99, 9, 94, 5, 58, 8,  4, 6, 31, 3, 61, 0, 54, 1, 71, 
    4, 10, 2, 43, 7, 48, 3, 14, 8, 62, 5, 96, 0, 15, 6, 44, 9, 99, 1, 15, 
    1, 10, 5, 96, 8, 74, 6, 37, 7, 28, 9, 63, 4, 49, 0, 53, 2, 31, 3,  3
  };
  const int r456[] = {
    10, 10, // Number of jobs and machines
    9, 15, 7, 58, 0, 27, 3, 75, 6,  6, 8, 40, 5, 73, 2, 16, 1, 66, 4,  5, 
    4, 80, 9, 89, 6, 70, 5, 27, 2, 18, 1, 96, 7, 66, 0, 62, 8, 14, 3, 92, 
    3, 70, 4, 52, 1, 39, 7, 79, 2, 10, 9, 14, 5, 13, 0, 20, 6, 84, 8, 93, 
    3, 90, 9, 46, 2, 52, 4,  8, 8, 83, 1, 27, 5, 24, 0, 47, 6, 68, 7, 93, 
    2, 26, 8, 22, 5, 24, 4, 61, 6, 26, 9, 62, 3, 55, 0, 99, 1, 14, 7, 43, 
    9, 52, 0, 89, 6, 27, 1, 32, 8, 82, 2, 10, 5, 91, 7, 85, 3, 41, 4, 36, 
    9, 40, 5, 48, 7, 36, 4, 37, 1, 10, 0, 76, 3, 63, 2, 15, 6, 46, 8, 47, 
    5,  1, 6, 59, 8, 51, 2, 45, 4, 41, 7, 25, 9, 63, 1, 21, 3, 22, 0, 92, 
    0, 82, 2, 91, 6, 17, 7, 48, 3, 92, 5, 70, 1, 18, 4, 59, 8, 42, 9, 74, 
    5, 11, 8, 63, 9, 53, 6,  3, 1, 50, 3, 97, 0, 83, 4, 30, 7, 57, 2, 97
  };
  const int r457[] = {
    10, 10, // Number of jobs and machines
    1, 40, 3,  4, 6, 41, 2, 13, 7, 93, 0, 64, 5,  4, 9, 49, 4, 86, 8,  5, 
    0, 43, 8, 70, 7, 69, 5, 16, 1, 72, 4,  3, 6, 60, 2, 63, 3, 58, 9, 11, 
    2, 32, 9, 87, 7,  6, 3, 74, 8, 50, 4, 51, 5, 49, 1, 41, 6,  4, 0, 26, 
    4, 97, 8, 22, 1, 97, 0, 64, 6, 55, 9, 41, 5, 81, 7, 61, 2, 87, 3, 27, 
    5, 89, 0, 85, 6, 81, 3, 80, 7, 22, 4, 46, 2, 10, 9, 19, 1, 11, 8, 51, 
    3, 65, 0, 60, 2, 55, 7, 76, 9, 48, 5, 68, 4, 65, 6, 65, 1, 22, 8, 31, 
    5, 86, 1, 35, 6, 56, 4, 90, 0, 24, 2, 17, 7, 43, 9, 21, 3, 37, 8, 29, 
    7, 87, 1, 97, 4,  8, 8, 30, 5, 10, 2,  4, 6, 60, 9, 41, 0, 36, 3, 44, 
    2, 54, 3,  8, 5, 46, 6, 70, 8,  3, 7, 74, 4, 63, 1, 96, 0, 49, 9, 83, 
    2,  2, 0, 54, 9, 38, 5, 21, 3, 90, 4, 69, 8, 98, 7, 85, 6,  4, 1, 66
  };
  const int r458[] = {
    10, 10, // Number of jobs and machines
    1, 25, 5,  6, 3, 60, 6, 52, 2, 96, 7, 55, 0,  5, 9,  2, 4, 22, 8, 90, 
    0, 42, 4, 26, 8, 20, 2, 29, 6,  2, 5, 93, 1, 63, 7, 78, 3, 86, 9, 62, 
    6, 16, 8, 14, 4, 70, 3, 12, 5, 53, 1, 29, 7, 54, 0, 24, 2, 73, 9, 32, 
    3, 15, 4, 54, 6, 70, 5, 61, 7, 94, 9, 75, 2, 13, 0, 28, 8, 85, 1, 48, 
    9, 94, 0,  9, 3, 57, 1, 99, 8, 38, 7, 45, 6, 16, 2, 45, 5, 75, 4, 86, 
    3, 37, 7, 51, 1, 78, 0, 82, 9, 31, 2, 43, 4, 60, 8, 91, 6, 67, 5, 87, 
    5, 62, 8, 25, 0, 57, 4, 98, 9, 54, 2, 10, 7, 93, 1, 75, 3, 84, 6, 40, 
    3, 90, 4, 45, 2, 61, 5, 74, 7, 74, 9, 65, 0, 76, 6, 51, 8, 16, 1, 15, 
    8, 46, 5, 77, 9, 13, 3, 84, 7, 95, 0, 24, 2, 41, 1, 80, 6, 61, 4, 76, 
    0, 34, 1, 76, 4, 97, 3, 95, 6, 57, 9, 31, 8, 57, 5, 82, 7, 92, 2,  1
  };
  const int r459[] = {
    10, 10, // Number of jobs and machines
    1,  3, 5, 37, 3, 24, 6, 60, 0, 15, 2, 31, 7, 97, 9, 26, 8,  1, 4, 82, 
    8, 44, 0, 62, 2, 79, 7, 59, 1,  5, 3, 75, 5,  3, 6, 37, 9, 54, 4, 56, 
    5, 43, 9, 47, 2, 15, 3, 16, 6, 67, 1, 21, 7, 53, 4, 92, 8, 37, 0, 75, 
    4, 58, 7, 90, 2, 33, 5, 90, 8, 13, 6, 35, 0, 67, 1, 57, 9, 25, 3, 38, 
    1, 85, 7, 90, 8, 39, 9, 68, 0, 82, 3, 32, 4, 30, 2, 39, 6, 55, 5, 35, 
    4, 48, 7, 32, 8, 18, 9, 26, 1, 47, 0,  6, 2, 28, 5, 10, 3, 63, 6, 16, 
    0,  6, 4, 90, 3, 49, 9, 99, 5, 13, 6, 93, 2, 63, 8, 81, 7, 48, 1, 22, 
    6, 71, 9,  9, 0,  6, 8, 30, 5, 44, 1, 97, 2, 63, 3, 18, 4,  2, 7, 32, 
    0, 52, 5, 77, 7, 31, 2, 43, 9, 77, 1, 96, 6, 66, 4, 82, 8, 83, 3, 28, 
    2, 44, 8, 12, 1, 61, 3, 60, 4, 15, 0, 37, 7, 73, 5, 91, 9, 29, 6, 71
  };
  const int r460[] = {
    10, 10, // Number of jobs and machines
    7,  1, 1, 17, 8,  8, 0, 95, 5, 64, 2, 24, 4, 55, 6, 19, 3, 94, 9, 29, 
    7, 52, 4, 20, 1, 73, 6, 69, 0, 22, 3, 77, 5, 48, 9, 20, 2, 71, 8, 65, 
    9, 68, 1, 12, 6,  4, 3, 96, 4, 30, 5, 37, 8, 57, 7, 31, 2, 58, 0, 63, 
    8, 98, 4, 51, 1, 29, 3,  3, 7, 55, 0, 48, 2, 50, 5, 95, 6, 66, 9, 91, 
    8, 48, 6, 37, 9, 95, 0, 23, 2, 40, 4, 95, 5, 39, 7, 65, 3, 96, 1, 94, 
    7,  4, 3, 16, 4, 61, 2, 91, 8, 32, 6, 11, 1, 88, 9, 67, 0, 41, 5, 52, 
    9, 51, 8, 33, 3, 56, 7, 82, 2, 19, 1, 18, 4, 60, 6, 84, 5, 88, 0, 40, 
    4, 59, 6, 82, 3, 67, 0, 55, 1, 30, 5, 15, 8, 70, 2, 80, 7, 27, 9, 32, 
    4, 89, 8, 77, 3, 77, 1,  1, 0, 93, 7,  5, 5, 42, 2, 13, 9, 80, 6, 23, 
    0, 51, 8, 35, 1, 76, 9, 48, 7, 27, 4, 10, 2, 68, 5, 86, 3, 35, 6, 67
  };
  const int r461[] = {
    10, 10, // Number of jobs and machines
    2, 42, 7, 12, 3, 15, 8,  8, 0, 36, 4, 70, 1, 24, 9, 62, 5,  5, 6, 46, 
    1, 81, 0, 78, 5, 95, 7, 36, 9, 69, 2, 65, 6, 56, 8, 75, 4, 23, 3, 75, 
    6, 43, 5, 33, 1, 77, 2, 44, 9, 82, 7, 37, 0, 51, 3,  5, 8, 69, 4, 14, 
    5, 77, 7, 77, 9, 34, 8, 55, 6, 20, 3, 13, 1, 13, 0, 46, 2, 73, 4, 81, 
    6, 94, 1, 98, 9, 92, 7, 92, 0, 28, 8, 50, 2, 45, 5,  9, 4, 39, 3, 57, 
    9, 20, 7, 40, 0, 28, 4,  2, 8, 11, 6, 16, 3, 52, 2, 27, 1, 49, 5, 39, 
    4, 50, 6, 56, 5, 13, 3, 34, 0,  7, 7, 84, 2, 70, 1,  7, 8, 29, 9, 49, 
    2,  6, 9, 24, 4, 87, 6, 21, 0, 35, 8, 72, 1, 90, 5, 20, 7, 30, 3,  6, 
    2, 59, 6, 59, 5, 30, 9, 75, 7, 93, 8,  1, 1, 39, 4, 54, 0, 75, 3, 35, 
    6, 21, 3, 38, 4, 80, 7, 12, 1, 96, 9, 59, 2, 72, 5, 73, 8, 66, 0, 46
  };
  const int r462[] = {
    10, 10, // Number of jobs and machines
    8, 75, 2, 86, 9, 37, 4, 37, 3,  6, 0, 22, 7, 86, 5,  2, 1,  5, 6, 71, 
    4, 56, 1, 62, 2, 97, 6, 54, 3, 77, 7,  3, 8, 67, 5, 93, 9, 68, 0, 56, 
    5, 48, 6, 91, 2, 88, 3, 44, 8, 76, 1, 98, 0,  8, 7, 83, 4, 44, 9, 47, 
    2, 36, 1, 76, 0, 39, 7, 57, 4, 25, 9, 24, 5, 87, 3, 22, 8, 37, 6, 47, 
    2, 70, 7, 35, 9, 17, 5, 92, 3, 66, 8,  5, 0, 33, 6, 14, 4, 13, 1, 61, 
    9, 34, 1, 44, 4, 36, 2,  3, 8, 15, 5, 23, 0, 70, 7, 10, 6, 75, 3, 86, 
    4, 60, 5, 82, 9, 66, 0, 40, 7, 35, 3, 31, 2, 66, 1, 29, 6,  5, 8,  9, 
    7, 48, 1, 88, 3, 87, 6, 63, 5, 70, 8, 43, 4, 50, 9, 72, 0, 31, 2, 20, 
    3,  8, 9, 53, 6,  7, 2,  4, 0, 19, 1, 94, 5, 82, 4, 12, 7,  7, 8, 45, 
    7, 45, 2, 72, 9, 63, 0, 90, 3, 22, 8, 55, 6, 86, 1, 71, 4, 28, 5,  7
  };
  const int r463[] = {
    10, 10, // Number of jobs and machines
    5, 45, 1, 60, 2, 11, 0, 60, 8, 96, 4,  9, 6, 48, 7, 68, 9, 84, 3, 92, 
    0, 36, 4, 64, 7, 85, 1, 61, 3, 10, 6, 17, 2, 85, 5, 56, 8, 38, 9, 74, 
    0, 12, 4, 58, 6,  4, 9, 66, 2, 98, 8, 93, 3, 42, 7, 21, 5, 47, 1, 13, 
    6, 45, 5, 69, 9, 32, 2, 37, 7,  4, 1, 79, 4, 28, 8, 87, 3, 43, 0, 98, 
    5, 37, 1,  7, 3, 30, 9, 80, 8, 46, 2, 36, 4, 17, 0,  8, 6, 51, 7, 88, 
    7, 27, 2,  9, 4,  7, 1, 94, 8, 71, 0, 42, 5,  9, 9, 98, 6, 42, 3, 80, 
    7, 94, 4, 44, 8, 67, 5, 21, 6, 71, 3, 86, 2, 65, 1, 15, 9, 74, 0, 64, 
    4, 11, 3, 53, 2,  1, 6, 46, 8, 42, 0, 83, 9,  1, 1, 41, 7, 96, 5, 67, 
    4, 45, 7, 99, 9, 50, 5, 41, 6,  3, 8, 72, 2, 83, 1, 73, 3, 46, 0, 99, 
    2,  8, 5, 47, 9, 67, 1, 75, 7, 54, 8, 95, 4, 22, 0, 79, 3, 71, 6, 46
  };
  const int r464[] = {
    10, 10, // Number of jobs and machines
    1, 66, 8,  8, 6, 51, 4, 96, 3, 76, 2, 63, 5, 91, 7, 23, 9, 49, 0, 91, 
    5, 36, 1, 13, 4, 56, 9,  2, 0, 19, 7, 99, 6, 34, 2, 71, 3, 55, 8, 78, 
    8, 23, 5, 98, 1, 72, 2, 52, 7, 39, 0,  7, 9, 31, 3, 40, 4, 53, 6, 35, 
    1, 96, 0, 74, 8, 34, 5, 85, 6, 95, 4, 33, 9, 13, 7, 60, 2, 69, 3, 63, 
    7, 11, 9,  2, 3, 33, 1, 82, 0,  5, 6, 29, 8, 23, 4, 25, 2, 69, 5, 45, 
    1, 42, 8, 26, 9, 26, 4, 32, 6, 96, 5,  1, 0, 38, 2, 97, 7, 87, 3, 40, 
    4, 69, 0, 35, 9, 28, 2, 14, 1, 38, 6, 86, 7, 16, 3, 66, 5, 10, 8, 92, 
    5, 68, 3, 65, 1, 82, 7, 19, 0, 50, 4, 30, 2, 16, 8, 91, 9, 80, 6, 16, 
    2, 38, 9, 20, 1, 32, 0, 46, 3, 25, 7, 32, 6, 42, 5, 65, 4,  4, 8, 79, 
    0,  4, 9, 36, 8,  5, 5, 21, 7, 63, 2, 39, 3, 39, 4, 35, 1,  6, 6, 95
  };
  const int r465[] = {
    10, 10, // Number of jobs and machines
    8, 80, 9, 97, 5, 21, 0, 45, 1, 19, 3, 81, 6, 91, 2,  6, 4, 97, 7, 95, 
    3, 84, 5, 86, 7, 54, 6, 66, 4, 25, 9, 27, 8,  8, 1, 37, 2, 54, 0, 94, 
    0, 35, 3, 45, 2, 87, 4, 45, 5, 11, 7, 37, 8, 20, 6, 91, 1, 63, 9, 55, 
    1, 53, 9, 11, 8, 43, 0, 83, 5, 25, 6,  6, 7,  9, 3,  4, 4, 30, 2, 50, 
    6,  5, 5, 62, 9, 46, 7, 36, 8, 88, 0, 28, 3, 67, 2, 27, 1, 73, 4, 46, 
    2, 51, 7, 12, 4, 48, 0, 32, 5, 53, 1, 79, 3, 74, 9, 91, 6, 24, 8, 34, 
    0, 11, 3, 37, 4, 33, 8, 67, 9, 69, 6,  3, 2, 87, 7, 67, 1, 59, 5, 35, 
    8, 12, 0, 77, 6, 69, 2, 24, 7, 63, 3, 33, 4, 62, 9, 13, 1, 72, 5, 34, 
    5, 71, 1, 36, 8, 91, 3, 70, 0, 36, 7, 65, 4, 33, 2, 40, 9, 36, 6, 41, 
    0, 93, 8, 38, 6, 17, 9, 42, 4, 94, 7, 19, 2, 72, 1,  7, 3, 77, 5, 95
  };
  const int r466[] = {
    10, 10, // Number of jobs and machines
    3, 66, 7, 63, 1, 59, 6,  3, 5, 99, 2, 88, 9,  7, 8, 45, 0, 53, 4, 83, 
    6, 61, 2, 20, 4,  5, 8,  2, 0,  8, 7, 89, 9, 65, 1, 64, 5, 40, 3, 42, 
    3, 29, 2, 57, 1, 84, 9, 28, 8, 18, 5, 50, 6, 16, 7,  5, 4, 98, 0, 31, 
    1, 72, 8, 68, 5, 46, 3,  2, 0, 30, 9, 93, 6, 48, 4,  1, 2, 57, 7, 60, 
    2, 80, 4, 65, 8, 13, 0, 25, 9,  5, 5, 88, 6, 56, 3, 54, 7, 37, 1,  7, 
    2, 88, 0, 88, 4, 90, 7, 47, 8, 60, 3, 64, 5, 90, 6, 68, 9, 20, 1, 93, 
    4, 41, 7, 51, 5, 60, 6, 44, 2, 46, 9, 36, 1, 85, 8, 29, 3, 43, 0, 53, 
    6, 76, 0, 94, 5, 48, 1, 55, 3, 63, 2, 52, 8, 52, 4, 48, 7, 60, 9,  5, 
    7, 73, 3, 41, 5, 84, 1, 63, 4, 62, 6, 21, 2, 52, 0, 52, 8, 72, 9,  1, 
    8, 10, 6, 89, 5, 69, 0, 25, 2, 30, 9, 45, 4, 76, 7, 15, 1, 80, 3, 52
  };
  const int r467[] = {
    10, 10, // Number of jobs and machines
    4, 98, 3, 63, 6, 28, 8, 58, 0, 26, 9, 87, 5, 94, 2, 78, 1, 38, 7, 89, 
    3, 11, 7, 28, 9, 88, 4, 94, 2, 61, 5, 87, 6, 67, 0, 95, 8, 76, 1, 76, 
    6, 71, 4, 36, 7, 94, 0, 88, 5,  7, 3, 36, 1, 81, 9, 80, 2, 69, 8, 86, 
    7,  8, 8, 61, 2, 58, 6, 65, 1,  3, 5, 34, 9,  9, 3, 38, 4, 95, 0, 22, 
    3, 38, 2, 68, 4,  7, 7, 39, 5, 84, 8, 47, 1, 73, 0, 93, 6, 62, 9, 90, 
    0, 12, 7, 99, 3, 45, 4, 49, 1, 29, 8, 69, 6, 51, 9, 39, 2, 72, 5, 48, 
    7, 52, 4, 51, 1, 32, 9, 59, 3, 33, 2, 32, 0,  3, 5, 91, 8, 84, 6, 36, 
    7, 35, 6, 87, 4, 69, 5, 98, 1, 22, 2, 83, 9, 25, 0, 67, 8, 77, 3, 88, 
    9, 26, 5, 14, 4, 85, 6, 22, 8, 94, 2, 22, 0, 68, 1, 60, 7, 36, 3, 37, 
    0, 30, 9, 99, 5, 69, 8, 28, 2, 47, 3, 17, 7, 11, 1, 40, 4, 84, 6, 90
  };
  const int r468[] = {
    10, 10, // Number of jobs and machines
    9, 20, 3,  2, 7, 94, 5, 31, 4, 14, 2, 35, 8, 51, 1, 49, 6, 72, 0, 23, 
    5, 34, 8, 70, 7, 95, 9, 94, 2, 91, 0, 76, 6, 99, 1, 78, 4, 60, 3, 12, 
    1, 88, 2, 66, 4, 85, 3, 16, 8, 62, 0, 74, 6, 50, 9, 67, 5, 67, 7, 35, 
    7,  1, 6, 15, 8, 79, 9, 81, 4, 44, 3, 42, 5, 39, 0,  2, 2, 32, 1, 22, 
    7, 33, 4, 44, 8, 86, 3, 73, 0, 74, 9, 81, 6, 28, 5, 79, 1,  1, 2, 90, 
    6, 40, 1, 20, 9, 77, 3, 35, 7, 60, 4, 75, 8, 90, 2, 38, 5, 82, 0, 91, 
    4, 59, 6, 71, 7, 13, 1, 44, 9, 50, 2, 91, 5, 20, 3, 54, 8, 75, 0, 55, 
    7, 35, 2, 13, 5, 21, 1, 20, 6, 90, 0, 67, 4, 77, 8, 56, 3, 72, 9, 93, 
    7, 65, 2, 81, 1, 74, 3, 99, 5, 57, 0, 94, 6,  9, 9, 48, 4, 86, 8, 82, 
    1,  7, 2, 13, 0, 26, 4, 20, 5, 37, 3, 10, 9, 50, 7, 57, 6, 59, 8, 51
  };
  const int r469[] = {
    10, 10, // Number of jobs and machines
    0, 16, 9, 25, 4, 16, 5, 14, 3, 16, 6, 80, 7, 53, 2, 32, 8, 35, 1, 87, 
    2, 20, 9, 56, 4, 90, 1, 84, 8, 61, 3, 25, 0, 12, 6, 15, 7, 28, 5,  4, 
    4, 61, 0, 53, 2, 88, 3, 56, 7, 67, 9, 27, 8, 82, 5, 47, 1,  3, 6, 71, 
    7, 28, 9, 48, 0, 86, 1, 17, 8, 35, 6, 22, 2, 29, 4, 74, 5, 47, 3, 39, 
    7, 20, 1, 46, 3, 85, 5, 18, 8, 75, 4, 59, 2, 71, 0, 45, 9, 68, 6,  6, 
    6, 50, 5,  5, 4, 55, 8, 88, 9, 94, 1, 70, 3, 62, 7,  7, 0, 50, 2,  7, 
    4, 16, 1, 38, 5, 82, 2, 33, 6, 44, 3, 24, 7, 15, 8, 83, 0, 75, 9, 56, 
    2, 48, 5, 75, 4, 29, 9, 29, 6, 25, 8, 41, 0, 29, 7, 21, 1,  3, 3, 53, 
    0, 39, 5, 87, 3, 95, 9, 45, 7, 59, 6, 77, 2, 13, 1, 59, 8, 45, 4, 18, 
    8, 56, 2, 34, 1, 71, 5, 85, 0, 51, 4, 46, 6,  3, 7, 87, 9, 25, 3, 34
  };
  const int r470[] = {
    10, 10, // Number of jobs and machines
    2, 44, 7, 74, 3, 64, 6, 81, 5, 99, 8, 87, 9, 97, 1, 98, 0, 77, 4, 50, 
    4, 11, 0, 96, 8, 11, 6, 57, 1, 82, 7, 24, 9, 48, 2, 37, 3, 48, 5, 65, 
    5, 91, 0,  2, 6,  5, 8, 35, 3, 17, 1, 91, 9, 22, 7, 74, 2, 88, 4, 50, 
    4, 77, 7, 40, 9, 95, 2, 37, 0, 15, 1, 58, 3,  7, 5, 24, 8, 70, 6, 19, 
    8, 65, 4, 60, 9,  7, 1, 89, 0, 92, 7, 95, 3, 24, 2,  1, 6, 95, 5, 54, 
    5, 59, 1, 30, 0, 46, 4, 40, 6, 46, 3, 18, 7, 60, 2,  2, 8, 11, 9, 94, 
    2,  6, 5, 52, 4, 64, 6, 50, 8, 47, 7, 60, 0, 30, 3,  7, 9, 89, 1, 89, 
    5, 92, 0, 17, 8, 49, 6,  1, 7, 66, 1, 38, 4, 73, 2, 15, 9,  3, 3, 20, 
    5, 37, 8, 43, 7, 57, 1, 37, 0, 95, 4, 11, 3, 42, 2, 26, 9, 94, 6, 86, 
    7, 49, 3, 16, 6, 46, 5, 47, 2, 85, 0, 18, 9, 99, 4, 48, 8, 63, 1, 48
  };
  const int r471[] = {
    10, 10, // Number of jobs and machines
    9, 94, 7, 18, 5, 87, 2, 19, 8, 45, 0, 42, 3, 15, 1, 91, 6, 19, 4, 28, 
    2, 12, 3,  2, 0, 11, 9, 51, 8, 77, 7, 94, 6, 98, 5, 17, 1, 15, 4, 15, 
    4, 29, 8, 90, 9, 18, 2, 29, 6, 26, 0, 60, 7, 29, 1, 13, 3, 58, 5, 96, 
    3, 74, 7, 90, 1,  2, 2, 45, 0, 36, 6,  5, 9, 10, 5, 34, 8, 11, 4, 74, 
    6, 73, 2, 81, 1, 47, 0, 29, 5, 17, 8, 89, 9, 56, 7, 43, 4, 74, 3, 99, 
    0,  5, 1, 76, 7, 27, 6,  2, 9, 97, 2, 99, 4, 31, 3, 48, 5, 52, 8, 89, 
    2, 19, 6, 35, 7, 64, 9, 86, 3, 79, 1, 30, 0, 51, 5, 67, 4, 42, 8, 63, 
    7, 29, 8, 30, 5, 69, 1, 24, 3, 10, 9, 68, 0, 75, 6, 54, 4, 96, 2, 23, 
    1, 74, 7, 13, 4, 26, 0, 54, 5, 37, 8, 95, 6, 41, 3, 79, 9, 68, 2, 87, 
    6, 77, 0,  2, 5, 24, 4, 11, 1, 32, 7, 51, 8, 25, 3, 61, 9, 33, 2, 18
  };
  const int r472[] = {
    10, 10, // Number of jobs and machines
    0, 62, 1, 67, 4, 86, 6, 22, 2, 98, 8,  9, 3, 51, 7, 58, 5, 56, 9, 90, 
    3, 39, 2, 70, 7, 54, 1, 65, 0, 11, 9, 21, 6, 75, 4, 71, 5, 90, 8, 79, 
    2, 87, 3, 63, 9, 60, 5, 49, 8, 22, 0, 15, 6, 62, 7, 87, 4,  3, 1, 73, 
    7, 91, 2, 84, 6, 25, 0, 43, 8, 79, 9, 66, 1, 56, 3, 98, 5, 98, 4, 18, 
    5, 93, 9, 50, 6, 89, 7, 60, 3, 45, 0, 25, 4, 61, 8, 55, 2, 83, 1, 98, 
    2, 55, 9, 90, 4, 78, 8, 25, 3, 64, 0, 15, 1, 58, 6, 42, 7, 20, 5, 22, 
    9, 46, 6, 88, 5, 97, 8, 91, 4, 32, 2, 48, 3, 24, 1, 26, 7, 88, 0, 42, 
    6, 50, 9, 87, 8, 97, 5, 79, 1, 21, 4,  5, 0, 83, 2,  6, 7, 67, 3, 18, 
    0, 39, 4, 53, 5, 62, 7, 76, 3, 93, 8, 33, 9, 40, 6, 78, 1, 79, 2, 17, 
    9, 37, 3, 64, 8, 62, 4, 35, 2, 22, 1, 76, 0, 67, 6, 77, 5, 66, 7, 45
  };
  const int r473[] = {
    10, 10, // Number of jobs and machines
    0, 34, 3, 69, 8, 14, 7,  3, 9, 86, 1, 73, 5, 14, 4, 75, 6, 32, 2, 84, 
    8, 30, 1, 56, 7, 21, 0, 60, 4,  5, 2, 41, 3, 84, 9, 12, 5, 77, 6, 55, 
    8, 58, 6, 53, 2, 59, 4, 69, 1, 93, 9, 16, 3, 54, 5, 58, 7, 41, 0, 57, 
    2, 79, 6,  5, 8,  8, 3, 18, 4, 14, 0, 20, 1,  7, 5, 25, 9, 46, 7, 71, 
    3, 25, 7, 65, 0, 85, 6, 65, 8, 90, 9, 56, 4,  1, 5, 75, 2, 94, 1, 44, 
    6, 31, 0, 75, 7, 65, 1, 53, 9, 25, 4, 29, 2, 67, 3, 89, 5, 65, 8, 44, 
    1, 55, 0, 68, 8, 75, 2, 84, 6,  1, 4, 56, 3, 20, 7, 70, 9, 70, 5, 13, 
    3, 54, 6, 88, 1, 31, 9, 18, 7, 84, 5, 18, 2, 98, 4, 87, 0, 39, 8, 95, 
    1, 51, 7, 64, 9,  3, 6, 30, 0, 33, 5,  1, 3, 68, 4, 65, 8, 35, 2, 91, 
    8,  1, 0,  6, 3, 71, 2, 20, 4, 10, 5,  2, 6, 55, 1, 68, 9, 54, 7, 49
  };
  const int r474[] = {
    10, 10, // Number of jobs and machines
    2, 16, 7, 91, 1, 41, 3, 80, 0, 24, 8, 10, 6, 36, 4, 36, 9, 97, 5, 77, 
    9, 77, 7, 78, 3, 54, 0, 35, 6, 19, 8, 60, 5, 41, 2, 54, 4, 83, 1, 55, 
    1, 88, 2, 14, 6, 24, 5, 96, 8,  4, 7, 39, 4, 51, 0, 63, 9, 15, 3, 79, 
    5, 63, 8, 44, 6, 40, 0, 14, 3, 90, 2,  4, 1, 58, 4, 44, 9, 37, 7, 40, 
    1, 48, 3, 84, 2, 56, 9, 19, 6, 36, 4, 62, 8, 89, 0, 68, 5, 54, 7, 13, 
    4, 22, 5, 66, 8, 25, 2, 34, 1, 27, 9, 34, 6, 93, 3, 54, 7, 36, 0, 81, 
    0, 58, 7, 31, 4, 25, 2, 48, 3, 39, 1, 90, 9, 10, 6, 23, 8, 35, 5, 96, 
    7, 79, 1,  3, 3,  5, 5,  7, 0, 33, 8, 40, 9, 15, 6, 80, 4, 42, 2, 79, 
    4, 83, 9, 18, 1, 86, 5, 49, 8, 49, 0, 56, 2, 62, 7, 76, 6, 91, 3,  4, 
    7, 19, 0, 70, 4, 86, 2, 41, 6, 87, 8, 89, 9,  2, 3, 62, 1, 78, 5, 90
  };
  const int r475[] = {
    10, 10, // Number of jobs and machines
    8, 94, 1, 37, 2, 75, 5, 70, 7, 71, 3, 73, 6, 30, 0, 98, 9, 54, 4, 25, 
    4, 80, 3, 73, 1, 44, 0, 55, 8, 53, 5, 12, 7,  5, 6, 95, 2, 51, 9, 30, 
    2, 19, 0, 24, 4,  3, 6, 87, 7, 25, 3, 20, 5, 26, 1, 17, 8, 93, 9, 70, 
    0, 17, 4, 34, 2, 28, 9, 73, 1, 52, 5, 95, 6, 24, 8, 49, 3, 22, 7, 25, 
    1, 64, 7, 93, 4, 46, 5, 90, 2, 40, 0, 12, 9, 78, 8, 59, 6, 62, 3, 11, 
    9, 16, 7, 94, 4, 59, 5,  8, 6, 68, 3, 83, 0, 84, 8, 32, 1, 15, 2, 23, 
    2,  3, 9,  5, 1, 39, 4, 25, 5, 67, 0,  1, 3, 22, 6, 34, 7, 39, 8, 87, 
    8, 80, 7, 81, 3, 90, 5,  6, 4, 85, 9, 95, 2,  1, 6, 67, 0, 93, 1,  7, 
    1, 33, 4, 15, 9, 68, 5,  2, 3, 67, 7, 11, 6, 17, 8, 94, 0, 36, 2, 30, 
    1, 44, 5, 22, 2, 12, 9, 58, 3, 21, 8, 64, 4,  6, 0, 80, 7, 35, 6, 27
  };
  const int r476[] = {
    10, 10, // Number of jobs and machines
    4, 38, 0, 84, 2, 40, 9, 85, 5,  6, 7, 85, 1, 93, 3, 45, 8, 27, 6, 23, 
    8, 28, 6, 70, 5, 76, 3, 71, 1, 30, 9, 92, 2, 12, 7, 30, 4, 52, 0, 21, 
    7, 89, 3, 33, 1, 98, 8, 95, 9,  5, 5, 95, 6, 29, 4, 15, 2, 76, 0, 57, 
    9, 63, 0,  7, 1, 26, 7, 72, 6, 52, 8, 80, 3, 90, 5,  1, 2, 63, 4,  9, 
    6,  8, 8, 58, 5, 34, 4, 33, 7, 75, 2, 21, 0, 77, 1, 13, 3,  2, 9,  1, 
    8, 69, 2, 73, 5, 64, 7, 29, 3, 24, 0, 18, 6, 98, 9, 12, 4, 20, 1, 45, 
    2, 72, 4, 88, 0, 93, 9, 86, 5, 59, 8, 25, 7, 74, 1, 11, 3, 95, 6, 67, 
    7, 53, 9, 37, 3, 47, 6, 69, 8, 57, 4, 97, 0, 50, 2, 56, 5, 40, 1, 39, 
    9, 25, 0, 34, 8, 83, 2, 34, 6, 45, 4, 17, 5, 57, 1, 72, 3,  3, 7,  3, 
    8, 40, 1, 39, 9, 91, 7, 59, 2, 82, 4, 62, 5,  8, 3, 22, 0, 75, 6, 95
  };
  const int r477[] = {
    10, 10, // Number of jobs and machines
    4, 89, 8, 75, 2, 74, 6, 56, 3,  2, 5, 57, 9, 96, 7, 82, 0, 41, 1, 31, 
    1,  8, 0, 30, 4, 30, 6, 55, 3, 43, 5, 61, 2, 97, 8, 88, 7, 69, 9, 41, 
    8, 77, 7, 27, 1, 31, 6, 32, 4, 15, 3, 65, 2,  1, 5, 17, 9, 33, 0, 52, 
    1, 98, 5, 81, 0,  3, 9, 61, 2, 44, 8, 71, 3, 46, 4, 43, 6, 90, 7, 19, 
    6, 92, 2, 40, 8, 48, 5, 89, 1, 11, 9,  6, 0, 45, 7, 87, 4, 78, 3, 86, 
    5, 41, 9, 49, 3, 25, 6, 11, 7, 73, 4, 25, 2, 73, 0, 95, 1,  8, 8, 59, 
    4,  9, 1, 56, 9, 68, 5, 64, 3, 56, 7, 15, 0, 28, 8,  7, 2,  9, 6, 29, 
    4, 35, 5, 21, 8, 96, 6, 45, 7, 90, 3, 12, 0, 13, 9, 21, 1, 59, 2, 75, 
    7, 65, 1,  2, 2, 20, 6, 43, 0, 70, 8, 74, 9, 99, 5,  5, 3, 49, 4,  4, 
    8, 34, 0, 64, 2, 23, 7, 39, 9, 74, 5, 92, 4, 10, 1, 35, 6,  4, 3, 76
  };
  const int r478[] = {
    10, 10, // Number of jobs and machines
    5, 53, 6, 24, 2, 25, 9, 54, 4, 10, 0, 92, 8, 61, 1, 78, 7, 24, 3, 91, 
    5, 17, 0, 67, 6,  1, 8, 23, 4, 21, 9, 44, 2,  5, 1, 28, 3, 95, 7, 19, 
    7,  2, 9, 28, 2,  7, 3, 33, 0,  5, 8, 95, 5, 58, 6, 83, 1, 75, 4, 26, 
    7, 30, 1, 77, 3, 31, 2, 13, 5, 52, 4,  3, 9, 67, 6, 26, 0, 33, 8, 49, 
    7, 15, 8, 17, 5, 41, 0, 61, 6, 18, 9, 65, 2, 94, 3, 59, 1, 15, 4, 46, 
    4, 71, 0, 96, 3, 78, 8, 13, 1, 19, 7, 40, 9, 69, 2, 21, 5, 42, 6, 51, 
    2, 82, 9, 10, 8, 65, 4, 48, 3, 17, 1, 43, 5, 60, 0, 23, 6, 36, 7,  1, 
    9, 58, 6, 25, 5, 62, 4, 76, 8, 92, 1,  6, 2, 77, 0, 43, 7, 92, 3, 68, 
    0, 78, 4, 44, 1, 27, 7,  6, 6, 94, 9,  9, 5, 96, 2, 82, 3, 38, 8, 93, 
    7, 32, 8, 81, 0, 13, 6, 51, 9, 33, 1, 94, 3, 44, 2, 29, 5, 56, 4, 57
  };
  const int r479[] = {
    10, 10, // Number of jobs and machines
    2, 66, 8, 41, 9, 64, 7, 37, 0, 40, 3, 98, 4, 20, 1, 11, 6,  7, 5, 76, 
    9, 42, 2, 72, 5, 92, 7, 33, 0, 44, 8, 25, 6, 66, 3, 36, 1, 33, 4, 64, 
    1, 55, 5, 22, 4, 73, 0, 14, 3, 73, 9, 64, 2, 98, 7, 69, 6, 62, 8, 96, 
    9, 67, 6, 22, 4, 93, 5, 63, 7, 76, 1, 46, 8, 12, 0, 82, 3, 81, 2, 76, 
    3, 54, 4, 12, 1, 16, 8, 19, 6, 81, 2, 39, 7, 15, 0, 80, 9, 94, 5, 14, 
    7,  7, 2, 49, 0, 64, 5,  1, 6, 19, 4, 30, 9,  9, 8, 60, 3, 15, 1, 43, 
    5, 40, 8, 26, 1, 36, 7, 85, 4,  2, 2, 80, 3, 99, 0, 14, 6, 47, 9, 43, 
    7, 47, 8,  5, 3, 56, 0, 80, 1, 76, 2,  2, 9, 90, 5, 78, 6, 61, 4, 13, 
    2, 98, 4, 44, 8, 24, 6, 76, 0, 76, 1, 39, 7, 16, 3, 88, 5, 57, 9, 14, 
    0, 73, 2, 53, 6, 57, 3,  7, 4, 83, 8, 85, 5, 76, 1,  9, 9,  5, 7, 16
  };
  const int r480[] = {
    10, 10, // Number of jobs and machines
    6, 59, 7, 90, 5,  6, 4, 81, 2, 91, 0, 77, 1, 26, 8, 40, 3, 56, 9, 44, 
    7, 33, 0, 63, 9, 36, 6, 31, 4, 15, 5, 48, 8, 14, 1, 75, 3,  9, 2, 34, 
    9, 35, 2, 97, 0, 55, 4, 93, 6, 82, 3, 92, 7,  7, 1, 71, 5, 72, 8, 59, 
    0, 48, 9, 49, 1, 49, 4, 53, 7, 13, 2, 45, 8, 68, 5, 45, 3, 58, 6, 16, 
    1, 63, 5, 69, 2, 59, 3, 38, 6, 86, 8, 14, 9, 25, 7, 74, 0, 19, 4, 85, 
    1, 28, 9, 33, 0, 79, 8, 18, 6, 19, 4,  5, 2, 66, 7, 92, 3, 79, 5, 40, 
    6, 88, 2, 38, 7, 81, 0, 81, 1,  7, 5, 56, 8, 41, 4, 96, 3, 17, 9, 52, 
    3, 58, 9,  8, 6, 61, 5, 35, 4,  4, 2, 31, 1, 47, 7, 26, 0, 40, 8, 48, 
    5, 46, 6, 62, 7, 39, 4, 89, 9, 35, 3, 31, 1, 27, 2, 37, 8, 96, 0, 13, 
    8,  6, 9, 26, 5, 28, 1, 60, 2, 17, 6, 34, 0, 94, 3, 10, 7, 56, 4,  5
  };
  const int r481[] = {
    10, 10, // Number of jobs and machines
    3, 89, 1, 43, 0,  8, 9, 69, 7, 38, 5, 94, 8, 10, 4,  6, 2, 89, 6,  7, 
    1, 98, 3, 65, 6, 30, 4, 68, 8, 81, 2, 82, 7, 14, 9, 85, 0, 60, 5, 87, 
    7, 96, 8, 32, 2, 20, 6, 18, 4,  6, 9,  5, 5, 68, 0, 22, 1, 42, 3, 69, 
    7, 56, 0, 13, 3, 59, 1, 81, 5, 39, 4, 98, 8, 42, 9, 23, 6, 65, 2, 57, 
    3,  3, 8, 68, 1, 79, 4, 89, 0, 47, 9, 95, 2, 27, 6, 94, 7, 25, 5, 99, 
    3, 18, 5, 83, 7, 77, 9, 82, 0, 15, 4, 85, 2, 94, 8, 88, 1, 14, 6, 55, 
    9, 48, 4,  2, 1, 40, 7, 70, 5, 51, 3, 95, 0, 93, 2, 92, 8, 36, 6, 28, 
    9, 25, 5, 54, 2, 77, 8, 32, 6, 49, 1,  9, 7, 50, 0, 78, 4, 26, 3, 53, 
    8, 66, 7, 89, 5, 77, 0, 89, 6, 69, 9, 18, 1, 23, 3, 85, 4,  6, 2, 73, 
    3, 75, 0, 11, 6, 57, 4,  3, 8, 70, 7, 70, 9, 73, 5, 23, 1, 37, 2, 19
  };
  const int r482[] = {
    10, 10, // Number of jobs and machines
    2, 68, 5, 15, 3, 74, 4, 66, 9, 66, 0, 56, 7, 76, 1, 57, 6, 68, 8, 16, 
    4, 75, 7, 27, 8, 18, 6, 29, 2, 31, 9,  6, 1, 20, 0, 82, 5, 54, 3, 89, 
    8, 79, 6, 45, 4, 65, 1, 49, 2, 76, 5, 55, 7, 91, 0, 32, 3, 80, 9, 25, 
    4, 46, 0, 52, 2, 50, 9, 99, 3, 17, 1, 85, 5, 56, 6, 71, 7, 22, 8, 24, 
    9, 31, 8,  1, 2,  6, 4, 77, 5, 48, 3, 26, 1, 27, 7, 11, 6, 37, 0, 15, 
    1, 42, 9, 52, 4, 59, 6, 63, 5, 66, 7, 63, 0,  2, 3, 39, 2, 53, 8, 65, 
    2, 75, 4,  4, 1, 82, 7, 37, 6, 52, 0, 87, 9, 64, 3, 12, 8, 65, 5, 66, 
    8, 53, 2, 32, 1, 30, 4, 92, 9, 52, 3, 80, 0, 77, 6, 82, 7, 92, 5, 74, 
    9, 22, 0, 64, 3, 23, 5, 35, 7, 32, 8, 77, 4, 38, 1, 43, 2, 40, 6, 40, 
    7,  4, 9, 71, 5, 81, 4, 52, 2, 61, 3, 39, 8, 15, 6, 74, 0, 50, 1, 76
  };
  const int r483[] = {
    10, 10, // Number of jobs and machines
    4, 22, 7, 55, 6,  3, 9, 43, 3, 61, 0,  6, 2,  9, 8, 91, 5, 52, 1, 19, 
    4, 12, 5,  8, 6, 14, 2,  8, 7, 49, 9,  7, 0, 10, 3, 39, 1, 12, 8, 99, 
    1, 82, 5, 79, 0, 42, 9, 19, 4, 97, 2, 31, 3, 82, 7, 39, 8, 33, 6, 14, 
    7, 69, 0, 96, 3, 67, 1, 67, 8, 61, 2,  7, 4, 98, 9, 49, 6, 31, 5,  1, 
    3, 20, 9, 72, 1, 90, 8, 51, 4, 35, 0, 47, 2, 95, 7, 71, 5, 48, 6,  7, 
    9, 65, 3, 49, 4, 84, 2, 79, 7, 43, 8, 31, 5, 43, 1, 37, 0, 27, 6, 46, 
    2, 84, 4, 10, 9,  8, 1, 48, 5, 12, 0, 41, 7, 63, 3, 97, 6, 82, 8, 69, 
    8, 57, 2,  6, 3, 85, 5, 55, 1, 26, 0, 67, 7, 15, 9, 53, 6, 90, 4, 71, 
    6,  8, 1, 63, 3, 33, 9, 12, 8, 16, 2, 48, 4, 92, 5, 76, 0, 62, 7, 68, 
    4, 34, 6, 30, 9, 12, 0, 87, 1, 43, 8, 50, 5, 44, 3, 81, 7, 29, 2,  3
  };
  const int r484[] = {
    10, 10, // Number of jobs and machines
    5, 22, 0, 71, 9, 54, 1, 92, 2, 54, 4, 48, 7, 76, 8, 50, 6, 27, 3, 37, 
    9, 89, 8, 82, 7,  7, 6, 76, 2, 75, 3, 51, 5, 63, 0, 34, 1,  4, 4, 23, 
    1, 12, 7, 55, 0, 41, 8, 13, 2, 80, 9,  2, 5, 80, 6, 42, 3, 88, 4, 33, 
    5, 36, 3, 60, 7, 18, 1, 70, 4,  9, 2, 77, 6, 83, 9, 29, 0, 55, 8, 44, 
    2, 72, 0, 20, 7, 39, 4, 47, 6, 89, 3, 31, 1, 64, 8, 85, 5, 65, 9, 81, 
    1, 12, 4, 82, 5, 95, 9, 79, 8, 14, 3, 54, 2, 19, 6,  9, 7,  9, 0, 41, 
    9, 12, 6, 35, 4, 32, 0, 11, 1, 38, 2, 30, 3, 76, 7, 99, 8, 20, 5, 59, 
    0, 15, 3, 24, 5, 32, 8,  7, 2, 84, 1, 55, 9, 45, 7, 52, 6, 48, 4, 83, 
    9, 50, 4, 93, 3,  8, 6, 84, 5, 19, 1, 76, 7, 98, 0,  4, 2, 19, 8, 37, 
    7, 60, 3, 61, 5, 17, 1, 47, 8, 78, 6, 76, 2,  8, 0, 38, 9, 41, 4,  1
  };
  const int r485[] = {
    10, 10, // Number of jobs and machines
    5, 95, 1, 54, 8, 26, 3, 83, 7, 36, 2, 49, 9, 41, 6,  7, 4, 57, 0, 77, 
    0, 31, 7, 38, 1,  5, 9, 38, 4, 48, 2, 28, 8, 37, 3, 28, 6, 75, 5,  9, 
    7, 28, 4, 54, 2, 95, 8, 64, 3, 41, 1, 81, 6, 76, 0, 21, 5, 18, 9,  8, 
    4, 95, 1, 93, 5, 66, 2,  1, 3, 22, 8, 14, 7, 72, 0, 83, 9, 62, 6, 72, 
    8, 85, 0, 81, 5, 64, 9, 13, 2, 53, 7, 67, 6, 65, 4, 93, 3,  9, 1, 20, 
    6, 14, 3, 66, 4, 77, 1, 78, 2,  6, 9,  2, 8, 90, 5, 14, 0, 10, 7, 42, 
    9, 76, 7, 51, 8, 57, 5, 38, 6, 78, 0, 17, 3, 49, 1, 76, 4, 16, 2,  8, 
    2,  6, 6, 53, 1, 76, 8, 22, 7, 14, 4,  6, 9, 31, 0, 65, 5, 22, 3, 82, 
    0, 85, 8,  8, 9, 53, 7, 13, 2, 68, 3, 16, 6, 58, 1, 22, 4, 16, 5, 61, 
    9,  7, 1, 88, 7, 73, 8, 83, 4, 16, 6, 93, 5, 26, 3, 68, 2, 38, 0, 90
  };
  const int r486[] = {
    10, 10, // Number of jobs and machines
    7, 80, 9, 85, 6, 56, 3, 93, 8, 57, 2, 78, 1,  3, 5, 93, 0, 27, 4, 86, 
    6, 31, 8, 42, 5, 56, 3, 40, 0, 50, 4,  7, 2, 80, 9,  3, 1, 43, 7, 82, 
    8, 66, 4, 70, 9, 58, 1, 54, 0, 70, 3, 35, 5, 47, 6, 60, 2,  2, 7, 50, 
    2, 33, 7, 59, 6, 72, 1, 45, 0, 73, 3, 85, 9, 57, 5, 71, 8, 26, 4, 83, 
    2, 61, 1, 29, 4, 65, 5, 58, 9, 82, 7, 39, 6, 61, 3, 19, 0, 46, 8, 30, 
    2, 26, 5, 22, 1, 68, 3, 26, 4, 95, 7, 15, 6, 42, 8, 36, 9, 39, 0, 74, 
    3, 85, 1, 11, 5, 88, 4, 34, 2,  8, 6, 10, 0, 19, 9, 99, 7, 72, 8, 18, 
    6, 18, 1, 40, 0, 24, 8, 60, 2, 23, 5,  5, 7, 51, 4, 65, 9, 85, 3, 18, 
    3, 42, 4, 48, 0, 74, 9, 13, 2, 20, 8, 85, 5, 67, 7, 63, 6, 24, 1, 19, 
    1, 68, 7, 42, 0, 86, 8,  7, 4, 61, 6, 12, 9, 15, 2, 93, 5, 79, 3, 43
  };
  const int r487[] = {
    10, 10, // Number of jobs and machines
    1, 43, 5, 78, 3, 60, 6, 53, 8, 33, 2, 90, 4, 46, 9, 97, 7,  9, 0, 99, 
    5,  3, 3, 87, 9, 17, 0, 30, 2, 64, 8, 64, 1, 10, 6, 26, 7, 42, 4, 29, 
    5, 74, 7, 42, 2, 89, 4, 50, 6, 76, 8, 48, 9, 40, 0, 15, 3, 27, 1, 65, 
    7, 93, 3, 69, 1, 55, 6, 14, 0, 62, 9,  7, 8, 32, 2, 58, 5, 56, 4, 81, 
    6, 49, 8, 50, 5, 31, 1, 57, 0, 30, 7, 64, 3, 19, 4, 27, 9, 78, 2, 73, 
    7, 52, 6, 86, 1, 34, 9, 42, 0,  3, 4, 18, 8, 66, 5, 86, 2,  7, 3, 85, 
    2,  1, 9, 23, 6, 12, 8, 82, 0, 39, 1, 43, 7, 80, 4, 44, 3, 36, 5, 26, 
    8, 65, 5, 69, 9, 25, 4, 74, 1, 81, 0, 11, 6, 27, 7,  6, 2, 97, 3, 43, 
    4, 26, 9, 54, 7, 67, 0, 56, 1, 95, 2, 40, 6, 94, 3, 26, 8, 85, 5, 43, 
    3, 49, 9, 56, 8,  1, 5, 67, 4, 74, 7, 19, 2, 66, 0, 43, 6, 21, 1, 44
  };
  const int r488[] = {
    10, 10, // Number of jobs and machines
    9, 20, 1, 54, 6, 41, 7, 61, 2, 18, 0, 49, 5, 38, 8, 39, 4, 35, 3, 24, 
    4, 25, 1, 62, 3, 91, 9, 47, 5, 49, 8, 66, 2, 38, 6, 57, 7,  5, 0,  6, 
    2, 13, 5, 32, 1, 97, 3,  1, 0, 14, 6,  2, 8, 95, 4,  2, 9, 27, 7, 51, 
    6, 23, 7,  9, 9, 26, 4, 51, 0, 40, 5, 15, 1, 58, 8, 78, 2, 54, 3, 74, 
    8,  5, 0, 58, 4, 21, 5, 92, 2, 24, 3, 60, 1,  7, 6, 91, 9, 55, 7, 41, 
    5, 79, 2, 22, 4, 26, 9, 75, 3, 63, 1, 85, 8, 52, 0, 62, 7, 17, 6,  9, 
    8, 61, 3, 53, 4, 86, 0, 14, 6, 99, 7, 91, 9, 91, 5, 92, 2,  2, 1, 86, 
    3, 89, 4, 47, 0, 88, 2, 28, 1, 73, 9, 26, 6, 12, 7, 88, 5, 10, 8,  7, 
    9, 84, 5, 75, 2,  4, 3, 99, 8, 97, 6, 24, 0, 25, 1, 74, 4, 23, 7, 40, 
    1, 32, 0, 73, 2, 81, 6, 78, 9, 96, 4, 92, 5, 67, 7, 46, 3, 38, 8, 52
  };
  const int r489[] = {
    10, 10, // Number of jobs and machines
    7, 47, 6, 99, 2, 39, 5, 97, 0, 12, 1, 42, 3, 31, 8, 18, 9, 71, 4,  3, 
    2, 79, 0, 79, 6, 24, 9, 83, 7, 74, 5, 65, 3, 63, 8, 96, 4, 24, 1, 93, 
    7, 28, 0, 20, 6, 22, 4, 13, 3, 41, 1, 70, 2,  4, 8, 11, 5, 76, 9, 10, 
    5,  6, 7, 75, 6, 83, 3, 76, 0, 16, 8, 45, 1, 87, 4, 33, 9, 56, 2, 83, 
    0, 41, 3, 38, 6, 49, 8, 57, 9, 59, 2, 35, 7, 94, 5, 26, 1, 65, 4, 22, 
    6, 55, 3, 78, 0, 25, 1, 92, 5, 96, 9, 93, 7, 39, 4, 83, 8, 45, 2, 83, 
    3, 53, 7,  1, 5, 42, 0, 63, 4, 12, 9, 50, 1, 93, 2, 20, 8, 75, 6,  8, 
    9, 28, 0, 74, 1, 54, 7, 63, 8, 64, 6, 33, 3, 24, 5, 87, 2, 38, 4, 45, 
    3,  3, 9, 50, 4, 53, 1, 11, 7, 63, 6, 43, 0, 93, 2, 36, 8, 71, 5, 28, 
    3, 91, 4, 65, 1, 76, 5, 63, 0, 73, 2, 95, 8, 93, 6, 39, 9, 74, 7, 99
  };
  const int r490[] = {
    10, 10, // Number of jobs and machines
    9, 88, 0, 58, 4, 87, 1, 58, 7, 95, 8, 46, 3, 55, 2, 20, 6, 51, 5, 49, 
    6, 28, 8, 65, 3, 67, 2, 67, 4, 78, 9, 94, 1, 73, 5, 67, 0, 20, 7, 10, 
    7, 60, 4, 26, 6, 99, 2, 57, 1, 75, 0, 51, 5, 66, 3, 16, 8, 28, 9, 34, 
    9, 29, 0, 33, 4, 35, 5, 48, 3, 97, 7, 27, 8, 45, 2, 14, 6, 61, 1, 21, 
    0, 49, 8,  5, 6, 20, 1, 19, 3, 10, 2,  6, 5, 18, 9,  3, 4, 11, 7, 71, 
    3, 83, 7, 67, 5, 15, 6, 15, 8,  9, 4, 33, 2, 97, 0, 67, 9, 83, 1,  5, 
    1, 96, 9, 36, 6,  4, 3, 10, 0, 59, 2, 69, 8, 11, 4,  4, 5, 53, 7, 10, 
    2, 87, 1, 95, 0, 86, 5, 18, 3, 74, 7, 92, 4,  2, 6, 38, 9, 56, 8, 81, 
    1, 92, 7, 51, 5, 77, 6, 39, 9, 48, 4, 97, 2, 51, 0, 32, 8, 14, 3, 76, 
    0, 45, 1, 18, 2, 28, 6, 80, 5, 35, 9, 84, 7, 73, 3, 19, 8, 22, 4, 51
  };
  const int r491[] = {
    10, 10, // Number of jobs and machines
    1, 51, 4, 32, 9, 13, 2, 39, 0, 29, 7, 39, 8, 75, 5, 50, 3, 38, 6, 28, 
    4, 12, 6, 79, 5, 35, 9, 54, 2, 88, 7, 16, 1, 59, 0, 36, 8, 57, 3, 96, 
    8, 99, 3, 47, 7, 27, 1, 71, 9, 49, 2,  8, 6, 29, 4,  2, 0, 95, 5, 20, 
    0, 34, 5, 70, 3, 90, 7, 14, 8, 96, 6, 74, 1,  4, 2, 41, 4,  5, 9, 62, 
    2, 16, 8, 93, 0, 25, 4, 96, 7, 94, 1, 45, 6, 72, 5, 31, 9, 79, 3, 50, 
    2, 32, 3, 47, 9, 91, 8, 64, 6, 29, 5, 15, 0, 40, 4, 40, 1, 72, 7, 63, 
    6, 71, 2, 59, 0, 27, 4, 69, 3, 92, 8, 27, 7, 95, 9, 55, 1, 78, 5, 78, 
    6,  8, 0, 22, 3, 89, 4, 59, 5, 14, 1, 57, 9, 83, 8, 66, 7, 10, 2, 45, 
    5, 27, 4, 82, 2, 42, 8, 30, 1, 52, 9, 96, 0, 68, 6, 97, 7,  9, 3, 49, 
    2, 54, 9, 95, 1, 51, 8, 79, 3, 91, 4, 50, 0, 27, 7,  3, 5,  3, 6, 80
  };
  const int r492[] = {
    10, 10, // Number of jobs and machines
    6, 39, 0, 81, 4, 74, 5,  8, 7, 79, 3, 91, 1, 56, 8, 49, 9, 22, 2, 87, 
    9,  8, 3, 95, 8, 35, 4, 43, 6, 71, 5, 20, 7, 85, 1, 30, 0, 74, 2, 93, 
    2, 14, 0,  6, 3, 25, 7, 27, 8, 16, 1, 71, 9, 80, 6, 54, 5, 26, 4, 78, 
    4, 66, 9, 41, 8, 60, 7, 71, 3, 71, 5,  1, 2,  7, 6, 52, 1, 94, 0, 36, 
    0, 98, 9,  5, 8, 45, 5, 51, 6, 11, 3, 26, 1,  7, 2, 46, 4, 76, 7, 33, 
    0, 20, 3, 85, 8, 91, 5,  4, 1, 57, 6, 54, 9,  4, 7, 40, 2, 12, 4, 92, 
    9, 22, 8, 62, 6, 82, 1, 38, 5, 67, 7, 57, 4, 87, 2, 99, 3, 71, 0, 17, 
    5, 56, 7, 31, 8, 94, 2, 31, 3, 58, 9, 22, 1, 28, 4, 72, 0, 16, 6,  5, 
    6, 30, 4, 50, 1, 71, 9, 31, 2, 36, 0, 82, 7, 58, 3, 46, 5, 21, 8, 18, 
    2, 65, 3, 46, 6, 20, 1, 85, 5, 79, 4, 52, 7, 30, 9, 90, 0, 48, 8, 88
  };
  const int r493[] = {
    10, 10, // Number of jobs and machines
    7, 21, 2, 96, 8, 18, 9, 72, 6, 16, 3, 91, 4, 18, 5, 64, 0, 24, 1, 11, 
    1, 18, 5,  2, 0, 38, 8, 13, 3, 98, 6, 10, 2, 89, 9, 19, 4, 70, 7, 63, 
    8, 99, 5, 78, 2, 59, 1, 63, 7, 44, 0, 44, 6, 80, 3, 35, 4, 77, 9, 10, 
    7, 68, 0, 94, 1, 82, 9, 84, 3,  8, 5,  6, 6, 53, 2, 90, 4, 11, 8, 30, 
    4,  4, 9,  2, 7, 16, 3, 26, 8, 51, 1, 22, 2, 24, 5, 37, 0, 54, 6, 34, 
    6, 15, 3, 70, 0, 74, 8, 77, 5, 55, 7,  3, 4, 79, 1, 67, 9, 12, 2, 25, 
    7,  5, 2,  8, 9, 66, 4, 87, 6, 39, 5, 72, 1, 24, 0, 94, 8, 86, 3, 89, 
    9, 50, 3, 79, 4, 46, 1,  1, 7, 18, 6, 97, 2,  9, 8, 74, 0, 21, 5, 77, 
    6, 61, 3, 91, 1, 67, 8, 13, 9, 40, 4, 91, 0, 99, 5, 55, 2, 63, 7, 82, 
    2, 81, 4, 58, 9, 17, 5, 58, 6, 57, 0, 14, 1, 55, 3, 74, 8, 71, 7, 80
  };
  const int r494[] = {
    10, 10, // Number of jobs and machines
    4, 45, 3, 68, 5, 16, 8, 32, 2, 57, 1, 33, 6, 90, 9, 19, 0, 11, 7, 69, 
    4, 76, 8, 90, 9, 38, 0, 13, 5,  4, 7, 59, 6, 47, 1, 69, 3, 70, 2, 64, 
    0,  3, 3, 95, 4,  8, 8, 97, 2, 34, 9, 85, 5, 47, 7, 39, 6,  2, 1, 67, 
    6, 35, 5, 97, 2, 83, 0, 20, 8,  6, 4, 53, 9, 99, 3, 15, 7, 66, 1, 70, 
    6, 50, 0, 45, 5, 99, 2, 80, 8, 80, 9, 96, 7, 99, 3, 21, 4, 18, 1,  3, 
    3,  8, 1, 46, 4, 29, 9, 80, 6, 17, 2, 62, 0, 77, 5, 89, 7, 82, 8,  4, 
    3, 96, 9,  1, 1, 91, 7, 66, 0, 81, 4, 34, 2, 14, 6, 43, 5, 21, 8, 78, 
    8,  6, 2, 90, 7,  4, 6, 36, 3, 61, 4, 20, 0, 44, 5, 14, 1, 39, 9, 70, 
    9, 11, 2, 19, 1,  8, 0, 60, 4, 82, 8,  3, 5, 63, 3, 73, 6, 64, 7,  3, 
    3, 21, 1, 38, 7, 68, 8,  1, 6, 60, 0, 60, 2, 63, 5, 51, 4,  9, 9, 35
  };
  const int r495[] = {
    10, 10, // Number of jobs and machines
    3, 36, 0,  2, 7, 40, 5,  6, 9, 85, 1, 24, 2, 71, 8, 18, 6, 18, 4,  7, 
    2, 29, 1, 15, 4, 38, 0, 92, 5, 33, 7, 64, 3, 81, 9, 74, 6, 85, 8, 50, 
    6, 79, 5, 53, 4, 17, 8, 11, 2, 29, 7, 66, 1, 26, 0, 33, 9, 22, 3, 58, 
    8, 78, 4, 22, 7, 49, 9, 37, 6,  3, 2, 37, 3,  2, 0, 50, 5, 64, 1, 91, 
    3, 33, 0, 20, 1, 51, 2, 54, 8, 39, 9, 33, 4, 92, 7, 62, 6, 30, 5, 30, 
    8, 71, 2, 22, 4, 49, 9, 86, 0, 11, 5, 21, 3, 59, 1, 35, 7, 73, 6, 29, 
    9, 32, 5, 22, 2,  6, 8, 51, 7, 18, 3, 50, 0, 67, 6, 45, 1, 33, 4, 14, 
    3, 62, 2, 91, 5, 45, 0, 89, 7,  5, 9, 51, 6, 40, 8, 58, 4,  4, 1, 97, 
    5, 28, 1, 37, 3,  2, 8, 26, 9, 44, 4, 18, 0, 35, 2, 22, 6, 93, 7, 73, 
    8, 97, 3, 95, 2, 62, 7, 58, 5, 65, 0, 18, 1, 31, 4, 47, 9, 99, 6, 11
  };
  const int r496[] = {
    10, 10, // Number of jobs and machines
    7, 85, 6, 41, 3, 96, 5, 65, 4, 62, 0, 15, 9, 40, 1, 55, 8, 44, 2, 82, 
    9, 74, 6, 65, 2, 56, 1, 59, 4, 39, 7, 53, 0, 70, 8, 49, 3, 72, 5, 70, 
    0,  9, 9, 19, 4, 21, 3, 49, 1, 64, 7, 99, 8, 40, 6, 98, 2, 52, 5, 71, 
    8, 16, 0, 37, 6, 41, 2, 86, 9,  1, 1, 52, 4, 65, 3, 80, 7, 69, 5, 38, 
    0, 20, 3, 83, 1, 13, 7, 54, 8, 49, 9,  8, 6, 91, 4,  3, 5, 82, 2, 21, 
    7, 25, 0, 28, 8, 61, 6, 45, 5, 30, 2,  2, 3, 44, 4, 90, 9, 94, 1,  1, 
    3, 62, 9,  9, 8, 38, 4, 49, 6, 77, 7, 85, 0, 19, 1, 83, 5, 83, 2, 43, 
    2, 88, 8, 62, 0, 51, 7, 65, 5, 88, 3, 45, 4, 20, 1, 33, 9, 11, 6, 67, 
    5, 52, 1, 48, 4, 32, 8, 25, 2, 82, 3, 95, 6, 75, 7,  8, 0, 48, 9, 89, 
    7, 22, 6, 10, 8, 13, 3, 68, 1, 61, 9, 71, 2, 73, 0, 26, 5, 39, 4, 35
  };
  const int r497[] = {
    10, 10, // Number of jobs and machines
    5, 94, 0, 51, 7, 21, 6, 17, 9, 13, 1, 17, 4, 58, 2, 62, 3, 42, 8, 49, 
    6, 87, 3,  2, 1, 30, 5, 86, 4, 63, 2, 38, 0, 90, 7, 71, 9, 54, 8, 77, 
    9, 65, 1, 74, 8, 51, 5, 88, 4, 15, 2, 14, 6, 72, 0, 41, 7, 44, 3, 36, 
    0, 38, 7, 23, 8, 34, 1, 71, 6,  9, 3, 27, 5, 21, 4, 37, 9, 57, 2, 52, 
    7, 48, 9, 64, 5, 91, 2, 87, 6, 47, 1, 97, 3, 31, 0, 24, 8,  9, 4, 11, 
    9, 33, 3, 42, 1, 27, 2, 76, 5, 80, 4, 64, 0, 74, 8, 75, 6, 24, 7, 33, 
    9, 49, 2, 64, 7, 59, 6,  4, 8, 47, 1, 30, 3, 81, 0, 38, 5, 47, 4, 68, 
    0, 61, 9, 65, 5, 87, 1, 66, 2, 49, 8, 16, 4, 62, 6, 67, 3, 75, 7, 41, 
    6, 40, 9, 74, 2, 36, 7,  5, 0, 89, 1, 78, 8, 66, 5, 85, 3, 95, 4, 39, 
    4, 80, 6, 30, 0, 17, 1, 68, 9, 56, 8, 83, 7, 37, 5, 19, 3, 62, 2, 97
  };
  const int r498[] = {
    10, 10, // Number of jobs and machines
    9, 16, 2,  3, 4,  3, 8, 98, 6,  7, 7, 79, 5, 86, 1, 91, 3, 15, 0, 10, 
    6, 49, 0, 32, 3, 19, 2, 39, 1, 78, 8,  4, 9, 55, 5, 17, 4, 70, 7, 19, 
    2, 92, 9, 34, 4, 60, 0, 59, 5, 16, 8, 81, 7, 75, 6, 68, 1, 99, 3, 13, 
    9, 25, 7, 75, 3, 38, 4, 25, 8, 97, 0, 62, 5, 41, 2, 30, 1, 20, 6, 74, 
    0, 20, 9, 67, 4, 74, 3, 11, 2, 44, 5, 60, 6, 16, 8, 60, 7, 71, 1, 72, 
    8, 48, 4, 61, 9, 41, 1, 79, 5, 46, 2, 23, 6, 37, 0, 30, 3, 59, 7, 49, 
    1, 61, 8, 22, 0, 64, 4,  3, 3,  7, 6, 43, 9, 49, 2, 31, 7, 87, 5, 31, 
    1, 65, 6, 97, 3, 30, 8, 53, 0, 13, 2, 23, 9, 99, 5, 24, 7, 64, 4, 74, 
    7, 86, 8,  1, 5, 38, 4, 95, 9, 37, 0, 99, 6, 92, 2, 54, 1, 55, 3, 33, 
    1, 26, 5, 60, 4,  1, 6,  2, 0, 48, 3, 67, 2, 50, 8,  9, 9, 75, 7, 26
  };
  const int r499[] = {
    10, 10, // Number of jobs and machines
    8, 58, 6, 10, 7, 29, 9, 81, 0, 15, 4, 26, 1, 11, 5, 23, 2, 40, 3, 23, 
    4, 47, 0, 24, 8, 91, 5,  2, 9, 42, 7, 46, 3, 34, 2, 26, 1, 77, 6,  8, 
    6, 48, 5, 95, 8, 73, 9, 23, 4, 93, 3,  2, 0, 60, 2, 30, 1, 41, 7, 69, 
    9, 19, 3, 88, 0, 98, 4, 90, 8, 49, 6,  7, 7, 90, 2, 96, 1, 83, 5, 12, 
    9, 18, 6, 87, 3, 36, 4, 55, 1, 24, 5, 20, 0, 22, 7, 62, 8, 90, 2, 59, 
    2, 46, 6, 16, 8, 41, 5, 66, 7, 55, 0, 32, 4, 80, 1, 88, 3, 44, 9, 36, 
    0, 37, 7, 97, 4, 57, 9, 69, 3, 25, 6, 62, 5, 99, 8, 72, 2, 29, 1, 87, 
    3, 62, 6, 88, 2, 71, 7, 27, 1, 83, 8, 46, 0, 71, 4, 95, 5, 44, 9, 85, 
    4, 54, 6, 65, 2, 54, 1, 43, 3, 43, 5, 41, 8, 60, 9, 30, 7, 44, 0, 71, 
    1, 95, 8, 93, 5, 97, 7, 96, 0, 57, 2, 94, 6, 48, 4,  6, 3, 44, 9, 39
  };
  const int r500[] = {
    10, 10, // Number of jobs and machines
    3, 84, 6, 50, 5, 15, 7, 26, 1, 97, 4, 14, 2, 69, 8, 61, 9,  7, 0, 35, 
    5, 20, 7, 93, 1, 43, 8,  6, 3, 58, 0, 30, 9, 33, 6, 18, 4, 97, 2, 11, 
    6, 95, 8, 42, 4, 68, 7, 52, 0, 51, 5, 88, 2, 64, 3, 15, 9, 98, 1, 70, 
    6, 21, 4, 40, 8,  5, 3, 16, 1, 51, 0, 87, 2, 66, 7, 45, 9, 40, 5, 28, 
    2, 27, 4, 20, 3, 60, 5, 73, 9, 78, 1, 42, 7, 50, 8, 11, 6, 30, 0, 85, 
    2,  2, 6, 47, 0, 24, 8, 77, 4, 18, 5, 35, 1, 78, 7, 61, 3, 56, 9, 86, 
    9,  3, 5, 23, 2, 30, 1, 95, 4,  2, 0, 40, 7, 15, 6, 59, 3, 46, 8, 80, 
    9, 71, 2, 55, 6,  8, 4, 42, 5, 60, 1, 34, 3, 72, 8, 37, 7, 34, 0, 53, 
    4, 76, 0, 47, 2, 19, 5, 33, 8, 92, 6, 81, 3, 29, 1, 44, 7, 62, 9, 24, 
    5, 28, 3, 10, 9, 98, 1,  9, 6, 26, 2, 90, 0, 88, 4, 34, 7,  3, 8, 92
  };
  const int r501[] = {
    10, 10, // Number of jobs and machines
    2, 20, 0, 76, 3, 21, 1, 19, 6, 40, 8, 98, 9, 45, 4, 24, 5, 38, 7, 53, 
    7,  9, 3, 73, 8, 73, 0, 37, 9, 96, 5, 50, 1, 64, 4, 74, 6, 28, 2, 86, 
    0, 69, 4, 15, 1, 29, 8, 37, 6, 39, 3, 35, 5, 44, 9, 79, 7, 91, 2, 67, 
    4, 72, 6, 36, 0,  4, 5, 77, 2, 87, 1, 48, 3, 89, 8, 97, 7, 88, 9, 59, 
    1, 88, 5, 59, 0, 94, 3, 98, 8, 78, 4,  2, 9, 57, 6, 29, 2, 62, 7, 62, 
    5, 92, 2, 12, 1, 57, 8, 21, 3, 57, 9, 78, 7, 33, 0, 50, 6, 38, 4, 38, 
    0, 52, 6, 91, 1,  2, 3, 67, 5, 82, 8, 83, 7, 34, 9, 80, 4, 47, 2, 33, 
    2, 73, 7, 61, 1, 33, 9, 15, 5, 14, 4, 34, 0, 61, 8, 76, 3,  4, 6, 82, 
    1, 87, 2, 57, 3, 87, 4, 63, 7, 13, 0, 71, 8, 98, 5, 94, 9, 49, 6, 50, 
    2,  4, 3, 29, 9, 53, 0, 91, 4, 65, 8, 31, 5, 67, 6, 26, 1, 63, 7, 36
  };
  const int r502[] = {
    10, 10, // Number of jobs and machines
    5, 13, 4,  4, 8, 48, 2, 99, 7, 58, 1, 54, 9, 54, 0, 38, 3,  4, 6, 58, 
    3, 54, 2, 35, 8, 48, 1, 16, 0, 37, 4, 44, 7, 49, 9, 96, 6, 97, 5, 67, 
    6, 76, 1, 70, 9, 12, 5, 23, 8, 60, 3, 68, 4, 53, 0, 43, 2, 49, 7, 12, 
    1, 45, 0, 79, 5, 24, 9, 46, 2, 41, 4, 56, 3,  7, 7, 21, 6, 21, 8, 66, 
    1, 45, 2, 41, 8, 80, 6, 63, 7, 12, 0, 92, 3, 78, 4, 83, 5, 51, 9, 83, 
    3, 23, 0, 71, 9, 86, 8, 64, 1,  8, 7, 47, 6, 33, 2, 55, 5, 41, 4,  5, 
    7, 49, 2, 52, 9, 93, 6, 17, 8, 51, 4, 67, 5, 88, 1, 72, 3, 84, 0, 60, 
    3, 76, 8, 82, 9, 18, 2, 87, 5, 68, 1, 41, 7, 48, 4, 33, 0, 42, 6, 61, 
    6, 64, 0, 97, 1, 38, 2,  6, 9, 57, 4, 18, 3, 49, 8, 84, 7, 37, 5, 18, 
    0, 14, 4, 82, 5, 51, 7, 22, 9, 32, 2, 91, 8, 82, 6, 45, 3, 48, 1, 61
  };
  const int r503[] = {
    10, 10, // Number of jobs and machines
    9, 86, 2, 96, 1, 57, 0, 47, 5, 80, 4, 86, 7, 16, 6, 59, 8, 82, 3, 85, 
    9, 20, 1, 42, 3,  7, 7, 88, 4, 46, 5, 93, 0, 76, 6, 38, 2, 67, 8,  9, 
    7, 34, 9, 95, 4, 13, 2, 59, 5, 16, 3, 89, 1, 89, 0,  6, 6, 35, 8, 86, 
    5, 74, 8, 88, 1, 12, 2, 71, 6, 27, 9, 37, 0, 98, 7, 35, 3, 46, 4, 69, 
    3, 46, 5, 65, 9, 52, 2,  4, 4, 29, 7, 24, 1, 67, 0, 94, 8, 85, 6, 41, 
    9, 21, 5, 69, 3, 26, 7,  5, 6, 88, 2, 61, 4, 11, 1, 34, 0, 14, 8, 62, 
    0, 72, 3,  2, 4, 64, 9, 81, 1, 71, 8, 99, 5, 58, 7, 57, 2, 92, 6, 12, 
    4, 90, 8, 83, 5, 10, 2, 36, 6, 61, 7, 37, 3, 31, 0, 70, 9, 44, 1, 43, 
    5,  9, 9, 11, 7, 16, 8, 85, 4, 52, 2, 34, 3, 94, 0, 34, 1, 81, 6, 50, 
    0, 57, 9, 14, 8, 33, 4, 38, 7, 15, 6, 57, 2, 68, 3, 55, 5, 85, 1, 27
  };
  const int r504[] = {
    10, 10, // Number of jobs and machines
    6, 39, 3,  6, 2,  7, 8, 96, 0, 69, 4, 85, 7, 97, 9, 49, 5, 51, 1, 54, 
    0, 25, 1, 81, 2, 95, 6, 56, 3, 14, 4, 99, 8, 33, 7, 47, 5, 52, 9, 65, 
    7, 99, 5, 31, 0, 43, 2, 48, 8, 55, 3, 15, 4, 93, 9, 54, 1, 82, 6, 90, 
    0,  5, 6,  6, 7, 62, 2, 86, 3, 91, 1, 16, 4, 53, 5, 88, 8, 61, 9, 79, 
    9, 88, 7, 31, 6, 32, 3, 13, 5, 30, 4, 42, 2, 93, 0, 67, 1,  6, 8, 66, 
    1,  8, 2, 70, 9, 86, 4, 32, 8, 36, 6, 76, 7, 71, 0, 50, 5, 17, 3, 82, 
    9, 24, 2, 42, 8, 98, 6, 32, 3, 57, 5, 19, 1, 22, 7, 46, 0,  8, 4, 56, 
    4, 87, 1, 68, 8, 19, 7, 89, 5, 48, 0, 37, 2, 84, 3, 54, 9, 49, 6,  5, 
    5, 24, 6, 42, 4, 23, 0, 69, 3, 85, 2, 28, 1,  5, 7, 87, 9, 76, 8, 37, 
    0, 28, 8, 30, 4, 15, 9, 73, 6, 27, 1, 22, 7, 60, 2, 19, 3, 26, 5,  8
  };
  const int r505[] = {
    10, 10, // Number of jobs and machines
    8, 26, 1, 77, 0, 43, 9, 35, 5, 26, 2, 15, 6, 17, 3, 87, 4, 88, 7, 86, 
    8, 62, 0, 25, 2, 87, 4,  7, 7, 97, 9, 73, 3, 38, 5, 89, 6, 19, 1, 62, 
    8, 48, 7, 21, 1, 85, 5, 54, 2, 81, 4,  9, 9, 90, 3, 56, 6, 88, 0, 26, 
    4, 23, 9, 88, 1, 44, 2, 28, 5, 31, 7, 22, 6, 75, 3, 63, 0, 51, 8, 39, 
    9, 63, 1, 77, 8, 93, 6, 68, 5, 59, 0, 57, 7, 59, 3, 79, 2, 53, 4, 23, 
    5, 64, 2, 96, 8,  6, 4, 79, 1, 70, 0, 82, 6,  7, 9, 63, 3, 98, 7, 22, 
    5, 71, 3, 70, 8, 47, 7, 61, 1, 15, 0, 23, 4, 19, 2, 33, 6, 69, 9, 76, 
    1, 61, 5,  1, 0, 76, 8, 83, 9, 84, 4, 30, 6, 30, 3, 21, 7, 70, 2, 64, 
    1, 54, 6, 13, 2, 19, 4, 92, 3, 19, 8, 35, 5, 37, 0, 59, 7, 84, 9, 35, 
    8, 70, 4, 91, 1, 58, 9, 46, 2, 13, 5, 48, 7, 23, 0, 29, 6, 61, 3, 48
  };
  const int r506[] = {
    10, 10, // Number of jobs and machines
    9, 98, 7, 43, 3, 42, 4, 41, 6, 42, 2, 80, 1, 87, 5, 41, 0, 79, 8, 88, 
    7, 99, 5, 20, 0,  1, 8, 79, 3, 12, 4,  4, 9, 28, 6, 85, 1, 16, 2, 68, 
    3, 11, 7,  5, 6, 53, 0,  8, 4, 51, 9, 35, 8, 81, 5,  6, 2, 39, 1, 60, 
    6, 19, 7, 10, 2, 76, 1, 47, 4, 89, 8, 94, 5, 74, 9, 79, 3, 28, 0,  4, 
    1, 79, 3, 13, 5, 66, 6, 65, 2, 84, 0, 64, 8, 16, 4, 88, 7, 83, 9, 88, 
    2, 84, 1, 52, 3, 46, 0, 59, 8, 42, 9, 18, 6, 44, 4, 12, 7, 86, 5, 38, 
    3, 71, 9, 26, 1,  4, 7, 70, 5, 52, 0, 69, 8, 51, 2, 21, 6, 58, 4, 14, 
    4,  2, 3, 15, 8,  3, 1, 49, 9,  1, 7, 95, 6, 55, 5, 76, 2, 54, 0, 84, 
    0, 44, 9,  3, 6, 70, 3, 36, 1, 92, 7, 28, 5,  6, 2, 43, 4,  1, 8,  8, 
    9, 22, 6, 10, 7, 23, 4, 41, 3, 31, 5, 89, 0, 45, 2, 24, 1, 93, 8, 26
  };
  const int r507[] = {
    10, 10, // Number of jobs and machines
    9, 26, 8, 84, 7, 92, 5, 54, 4, 80, 6, 37, 1, 71, 2,  6, 0, 80, 3, 91, 
    6,  2, 5, 44, 2, 39, 4,  4, 1, 15, 3, 82, 0, 40, 9, 76, 7, 33, 8, 16, 
    5, 58, 6, 46, 2, 37, 3, 61, 4, 57, 8, 55, 9, 80, 7, 78, 1, 14, 0, 21, 
    9, 82, 3, 60, 0, 71, 6, 71, 2, 86, 1, 43, 7, 76, 4, 24, 8, 32, 5, 66, 
    1, 24, 8, 56, 2,  2, 4, 68, 9, 52, 6, 33, 7, 89, 5, 56, 0, 65, 3, 61, 
    5, 65, 8, 20, 4, 21, 9, 59, 7, 51, 1,  4, 0, 15, 6, 78, 3, 99, 2,  9, 
    3,  8, 1, 20, 5, 95, 0, 69, 4, 90, 2, 14, 9, 98, 6, 97, 7, 60, 8, 91, 
    3, 62, 8,  7, 6, 57, 4,  3, 2, 11, 7, 25, 5, 77, 0, 94, 1, 82, 9, 98, 
    3, 22, 4, 59, 8, 77, 7, 70, 6, 33, 5, 37, 1, 29, 0, 54, 9,  8, 2, 75, 
    8, 51, 4, 96, 7, 20, 3, 68, 5, 59, 0, 93, 2, 98, 9, 86, 6, 25, 1, 38
  };
  const int r508[] = {
    10, 10, // Number of jobs and machines
    5, 85, 8, 27, 4,  1, 6, 20, 7, 67, 3, 65, 1, 33, 2,  4, 0, 36, 9, 56, 
    5, 70, 6,  7, 7, 37, 1, 12, 8, 59, 0, 58, 9, 86, 3, 27, 2, 89, 4, 45, 
    4, 85, 2, 15, 8,  2, 3, 39, 6, 38, 5, 41, 0, 19, 9, 67, 1, 73, 7, 21, 
    0, 85, 3, 29, 2,  4, 6, 88, 5,  7, 8, 79, 9, 28, 4, 54, 7, 64, 1, 69, 
    7, 22, 1, 12, 4, 50, 0, 87, 9, 24, 8,  5, 2, 19, 6, 64, 5, 64, 3, 15, 
    0, 58, 4, 36, 2, 48, 1, 57, 7, 60, 6, 57, 9, 27, 8, 69, 5, 65, 3, 76, 
    9, 92, 5, 24, 7, 24, 8,  9, 3, 93, 4, 83, 0, 20, 1, 54, 2, 83, 6, 56, 
    5, 21, 6,  9, 4, 88, 9, 56, 2, 36, 3, 76, 0, 73, 8, 15, 7, 70, 1, 69, 
    6, 39, 9, 49, 8, 25, 7, 53, 2,  2, 4, 51, 3, 70, 5,  4, 1, 28, 0, 27, 
    2, 93, 8, 89, 5, 12, 6, 93, 7, 34, 3,  1, 0, 16, 4, 99, 1, 36, 9, 48
  };
  const int r509[] = {
    10, 10, // Number of jobs and machines
    0, 39, 3, 37, 4, 38, 6, 46, 8, 34, 7, 65, 2, 24, 9, 98, 1, 93, 5, 56, 
    9, 88, 6,  6, 1, 14, 0, 88, 2, 13, 4, 34, 8, 40, 7, 10, 3, 21, 5, 54, 
    4, 80, 9, 59, 1, 84, 3, 62, 7, 86, 0, 73, 5, 95, 8,  6, 6, 77, 2, 26, 
    9, 43, 0, 43, 1, 31, 8,  3, 3, 68, 5, 14, 6, 70, 2, 32, 4, 17, 7, 36, 
    3, 47, 0, 56, 9, 24, 6, 43, 7, 49, 8, 26, 1, 17, 5, 22, 4, 28, 2, 37, 
    6, 12, 3,  7, 7, 50, 1,  5, 0, 96, 8, 20, 9, 70, 5, 23, 4, 80, 2, 74, 
    1, 41, 4, 21, 5, 36, 0,  1, 8, 77, 6, 83, 9, 19, 7, 53, 2, 85, 3, 15, 
    7, 25, 5,  7, 1, 51, 6, 48, 9, 59, 3, 58, 4, 98, 8, 93, 0, 45, 2, 84, 
    2, 65, 8, 69, 6,  6, 3, 20, 5, 33, 4, 38, 1, 69, 9, 62, 0, 26, 7, 78, 
    7, 36, 2, 24, 4, 64, 5, 95, 1, 28, 3, 72, 6, 99, 0, 30, 9, 99, 8, 72
  };
  const int r510[] = {
    10, 10, // Number of jobs and machines
    2, 63, 7, 15, 3, 93, 8, 26, 1, 37, 6, 64, 0, 29, 4, 81, 5, 98, 9, 84, 
    4, 66, 1, 88, 0, 26, 7,  6, 9, 89, 3, 24, 2, 82, 5, 58, 8, 29, 6, 53, 
    9,  3, 1, 39, 8, 84, 5, 90, 0, 37, 2, 90, 3, 18, 4, 29, 7, 82, 6, 27, 
    7, 25, 3, 24, 2, 27, 5, 77, 8, 30, 9, 58, 6, 50, 0, 59, 4, 84, 1, 20, 
    9,  8, 5, 51, 1, 78, 8, 94, 6, 76, 7, 91, 4, 88, 0, 77, 3, 23, 2, 92, 
    9, 39, 8, 87, 6, 78, 2, 94, 3, 53, 4, 91, 5, 65, 1,  6, 7, 82, 0, 77, 
    1, 48, 9, 62, 7, 23, 0, 72, 8, 48, 5, 21, 2, 27, 6, 74, 4, 37, 3, 85, 
    5, 94, 2, 48, 6, 42, 8, 14, 7, 96, 4,  2, 3, 99, 1, 77, 9, 69, 0, 20, 
    4, 13, 0, 48, 9, 48, 5, 90, 6, 91, 2, 55, 7, 54, 1, 33, 3, 98, 8, 54, 
    5, 17, 8, 50, 1, 22, 6, 29, 0, 94, 7, 15, 2, 45, 9, 68, 3, 19, 4, 30
  };
  const int r511[] = {
    10, 10, // Number of jobs and machines
    3,  4, 4, 39, 7, 83, 1, 50, 8, 76, 0, 18, 5, 76, 6, 50, 9, 23, 2, 48, 
    0,  8, 6, 59, 4, 58, 2, 68, 3, 44, 8, 78, 1, 50, 9, 96, 5, 94, 7, 53, 
    4, 50, 2, 11, 3, 73, 0, 36, 9, 62, 7, 42, 6, 14, 8, 26, 1, 91, 5, 47, 
    0, 71, 8, 80, 2, 10, 4, 95, 7, 37, 5, 23, 6,  5, 9,  9, 3, 56, 1, 71, 
    9, 62, 8, 32, 7, 99, 4, 99, 1, 82, 6, 87, 2, 23, 5, 86, 0, 70, 3, 54, 
    1, 11, 8, 89, 4, 80, 6, 57, 7, 23, 0, 42, 5, 90, 3, 29, 2, 95, 9, 99, 
    4, 69, 7, 13, 0, 84, 3, 48, 5, 19, 1, 40, 8, 89, 9, 92, 2, 44, 6, 77, 
    7, 77, 5,  4, 4, 90, 0, 41, 2,  2, 6, 17, 3, 79, 8, 14, 1, 17, 9, 75, 
    6, 94, 0, 97, 1, 96, 7, 90, 3, 21, 9, 85, 4, 96, 5, 43, 2, 57, 8, 18, 
    3, 76, 6, 71, 5, 37, 2, 39, 8, 89, 4,  3, 0, 22, 9, 74, 7, 70, 1, 28
  };
  const int r512[] = {
    10, 10, // Number of jobs and machines
    4, 47, 8, 49, 2, 14, 1, 60, 0, 77, 9, 73, 5, 35, 6, 11, 7, 59, 3, 48, 
    3, 63, 9, 72, 2, 59, 5, 78, 6, 58, 8, 57, 1, 34, 0, 42, 7, 53, 4, 27, 
    1, 36, 6, 48, 3, 71, 2, 90, 4, 59, 0, 24, 5, 55, 8, 71, 7, 42, 9, 72, 
    4, 83, 0, 94, 6, 97, 9, 95, 1, 88, 2, 80, 3, 32, 5, 12, 8, 43, 7, 35, 
    6, 23, 9, 84, 8, 10, 2, 27, 0, 43, 4, 90, 7, 95, 5, 78, 3, 44, 1, 82, 
    1, 65, 0,  4, 7, 31, 3, 62, 2, 89, 4, 71, 6, 61, 9, 60, 5, 95, 8,  6, 
    6, 55, 5,  9, 7,  4, 2, 38, 4, 13, 9, 35, 0, 82, 1, 14, 8, 95, 3, 19, 
    6, 18, 2, 54, 0,  6, 9, 72, 7, 98, 8, 92, 3, 22, 4, 48, 5, 65, 1, 15, 
    0, 14, 7, 29, 4,  6, 3, 68, 1, 40, 8, 92, 5, 52, 9, 78, 2, 95, 6, 22, 
    8, 33, 2, 96, 0, 50, 5, 47, 1, 74, 3, 21, 6, 37, 4, 40, 9, 74, 7, 53
  };
  const int r513[] = {
    10, 10, // Number of jobs and machines
    1, 83, 2, 86, 3, 85, 7, 72, 6, 83, 4, 11, 8, 38, 0, 79, 9, 56, 5, 32, 
    2, 32, 9, 33, 4, 31, 0, 52, 1,  2, 3,  9, 7, 35, 5,  5, 8, 69, 6, 37, 
    8,  4, 7, 92, 1, 16, 6, 55, 3, 95, 2, 71, 4, 74, 5, 79, 9, 74, 0, 58, 
    7,  2, 5, 16, 3, 16, 1, 11, 8, 68, 6, 29, 0, 24, 9, 56, 4, 61, 2, 83, 
    8, 59, 9, 98, 5, 21, 2, 76, 6, 64, 7, 21, 4, 67, 0, 81, 1, 58, 3, 69, 
    6,  8, 7, 69, 9, 86, 3, 34, 0, 34, 8, 30, 2, 41, 1, 39, 5, 66, 4, 48, 
    9,  8, 1, 50, 4, 72, 3, 63, 0, 16, 2, 15, 5, 22, 6, 13, 7, 33, 8, 82, 
    6, 48, 3, 52, 4, 48, 5, 57, 8, 38, 2, 82, 7,  8, 1, 59, 9, 66, 0, 67, 
    7,  7, 4, 47, 3, 12, 9, 40, 8, 31, 5,  7, 0, 26, 6, 70, 2, 87, 1, 85, 
    2, 43, 8, 93, 5,  8, 6, 77, 4, 92, 1, 67, 0, 52, 3, 16, 7, 62, 9, 41
  };
  const int r514[] = {
    10, 10, // Number of jobs and machines
    0, 79, 2, 42, 8, 11, 1, 89, 4, 61, 7, 44, 6, 58, 9, 98, 5, 64, 3, 85, 
    4, 55, 7, 70, 1, 93, 5,  6, 3, 77, 0, 89, 9, 64, 6, 73, 2, 43, 8, 27, 
    5, 31, 4, 45, 3,  1, 2, 77, 8, 65, 1, 67, 6, 88, 9, 49, 7, 48, 0, 18, 
    0, 17, 6, 53, 3, 19, 1, 20, 9,  9, 5, 11, 8, 58, 2, 45, 7, 47, 4, 55, 
    8, 74, 5, 60, 7, 29, 9, 58, 2,  7, 4, 61, 0,  8, 3, 25, 6, 16, 1, 92, 
    7,  9, 3, 64, 9, 57, 8, 17, 5, 17, 6, 62, 4, 21, 2, 25, 0, 25, 1, 63, 
    4, 53, 3, 41, 0, 66, 9, 96, 6, 52, 1, 76, 2,  5, 8, 20, 7, 88, 5, 77, 
    3,  1, 5, 10, 8, 31, 2, 16, 4,  3, 1, 42, 6, 85, 9, 59, 0, 79, 7, 24, 
    1, 89, 0, 77, 5, 62, 3, 63, 7,  2, 4, 16, 8, 48, 6, 79, 2, 33, 9, 62, 
    7, 43, 0, 63, 1, 85, 8, 93, 2, 39, 4, 24, 5, 86, 6, 92, 9, 26, 3, 39
  };
  const int r515[] = {
    10, 10, // Number of jobs and machines
    5, 98, 8, 31, 2, 79, 6,  6, 1, 31, 7,  9, 9, 59, 3, 84, 4, 33, 0, 38, 
    9, 86, 7, 75, 2, 25, 3, 91, 6, 58, 0, 91, 1, 14, 8, 78, 5, 25, 4, 49, 
    1, 19, 0, 77, 8, 22, 3, 80, 7,  7, 9, 67, 2, 90, 6,  2, 5, 68, 4, 74, 
    7, 37, 6, 56, 1, 40, 8, 80, 5, 28, 0, 60, 4, 61, 9, 22, 3, 37, 2, 22, 
    5,  9, 4, 38, 2,  5, 6, 91, 3,  1, 1, 87, 8, 50, 7, 89, 9, 28, 0, 83, 
    8, 48, 3, 88, 4, 19, 9, 43, 5,  1, 1, 41, 0, 49, 6, 51, 2, 97, 7, 13, 
    9, 59, 5, 64, 0, 49, 8, 83, 7, 43, 2, 10, 3, 59, 4, 85, 6, 56, 1, 69, 
    4, 15, 7, 72, 6,  7, 2, 92, 3, 83, 8, 18, 9, 64, 1, 82, 5, 13, 0, 24, 
    5, 64, 8, 67, 4, 30, 1, 36, 7, 98, 3, 97, 0, 76, 2, 24, 6, 94, 9, 14, 
    0, 10, 6, 19, 2, 21, 9, 51, 4, 52, 7, 17, 1, 31, 5, 33, 3, 27, 8, 28
  };
  const int r516[] = {
    10, 10, // Number of jobs and machines
    4, 25, 3, 21, 5, 20, 1, 42, 9,  4, 2, 18, 0, 90, 8, 58, 7, 46, 6,  9, 
    5, 85, 8, 39, 1, 24, 9, 11, 2, 63, 0, 80, 7, 18, 4, 73, 3, 45, 6, 80, 
    3, 55, 6, 45, 2, 29, 4, 92, 1,  2, 8, 58, 7, 75, 0, 69, 9, 46, 5, 91, 
    3, 99, 9, 46, 2, 36, 8,  4, 5, 39, 1, 87, 4, 77, 7, 62, 6, 39, 0, 65, 
    4, 13, 3, 85, 9, 40, 5, 96, 0, 48, 2, 87, 8, 13, 7, 99, 6, 12, 1, 72, 
    5,  2, 3, 81, 9, 73, 6, 70, 2, 40, 7, 71, 8, 46, 4, 17, 0, 32, 1, 73, 
    2, 30, 4, 42, 8, 64, 9, 26, 3, 78, 1, 16, 0, 76, 5, 29, 6, 79, 7, 78, 
    7, 94, 3, 46, 6, 45, 4, 82, 0, 54, 8,  1, 1, 10, 2, 88, 9, 12, 5, 41, 
    6, 35, 8, 89, 2,  4, 3, 68, 1, 17, 0, 21, 4, 97, 7, 66, 5, 49, 9, 80, 
    6, 75, 8, 87, 1, 90, 3, 23, 9, 21, 7, 54, 5, 84, 0, 85, 4, 41, 2, 57
  };
  const int r517[] = {
    10, 10, // Number of jobs and machines
    6, 63, 5, 85, 1, 27, 8, 84, 0, 11, 2, 70, 3,  5, 9, 16, 7, 62, 4, 14, 
    3, 17, 6, 68, 7,  2, 8, 34, 9, 37, 5, 94, 4, 25, 2, 18, 1, 83, 0, 21, 
    4, 30, 3,  3, 5, 22, 1, 86, 6, 36, 9, 24, 0, 33, 2, 11, 8, 48, 7, 31, 
    7, 78, 5, 60, 9, 66, 3, 88, 2, 82, 4, 37, 0, 81, 1, 86, 8, 85, 6, 41, 
    2, 41, 3, 40, 4, 99, 5, 70, 6, 83, 8, 56, 7, 70, 1, 21, 9, 23, 0, 93, 
    9, 50, 8, 61, 3, 72, 1, 95, 4, 55, 0, 93, 6, 55, 7, 25, 2, 62, 5, 48, 
    8, 72, 6, 38, 0, 94, 3, 18, 9, 52, 1, 23, 4, 86, 5, 98, 7, 18, 2, 29, 
    1, 67, 4, 45, 2, 70, 3, 92, 6, 66, 8, 31, 5, 29, 7, 20, 0, 47, 9,  7, 
    6, 44, 3, 76, 2, 32, 8, 33, 9, 97, 1, 99, 4, 43, 0, 83, 7,  8, 5, 18, 
    2, 32, 0, 57, 9, 16, 4, 10, 1, 34, 8, 25, 6, 35, 5, 53, 3, 42, 7, 69
  };
  const int r518[] = {
    10, 10, // Number of jobs and machines
    1, 61, 4, 23, 3, 26, 0, 42, 2, 41, 9, 71, 8, 79, 6, 61, 7, 30, 5, 75, 
    9, 25, 8, 38, 2, 15, 7, 79, 4, 68, 1, 78, 0, 49, 3, 89, 5, 17, 6, 73, 
    6, 18, 4, 38, 1, 51, 2, 71, 3,  1, 5, 26, 0, 53, 9, 52, 8,  5, 7, 98, 
    4, 28, 5, 82, 9, 17, 3, 99, 8, 49, 1, 41, 7, 75, 0, 15, 6, 19, 2, 37, 
    4,  6, 8, 87, 1, 10, 7, 35, 5, 43, 9, 45, 2, 39, 6, 13, 0, 20, 3, 13, 
    7, 96, 0, 96, 4, 43, 5, 40, 9, 50, 6, 95, 2, 64, 1, 40, 3,  4, 8, 42, 
    3, 97, 7, 72, 9, 94, 6, 34, 1, 88, 4,  2, 8, 30, 2, 31, 0,  5, 5, 62, 
    1, 17, 8, 39, 5, 19, 3, 69, 6, 58, 9, 74, 7, 51, 4, 56, 0, 94, 2, 73, 
    8, 63, 1, 39, 5, 16, 3, 68, 0, 60, 7, 16, 2, 15, 9, 51, 4, 48, 6, 54, 
    9, 63, 4, 99, 2, 46, 1,  4, 8, 80, 5, 24, 0,  3, 7, 44, 6, 96, 3, 76
  };
  const int r519[] = {
    10, 10, // Number of jobs and machines
    0, 45, 5, 39, 7, 23, 6, 91, 2,  9, 3,  1, 9, 18, 8, 75, 4, 87, 1, 33, 
    1, 41, 3, 28, 2, 14, 9, 55, 0, 79, 7, 58, 5, 80, 6, 19, 4, 48, 8, 43, 
    7, 90, 3, 21, 0, 81, 4,  8, 8,  1, 6,  1, 9,  7, 1, 51, 5, 48, 2, 97, 
    5, 70, 9, 38, 8, 65, 0, 92, 1, 76, 3, 83, 7, 17, 6, 16, 4, 57, 2, 24, 
    8,  3, 2, 63, 0, 26, 1, 36, 3,  2, 6, 31, 7, 59, 9, 40, 5, 39, 4, 79, 
    2, 92, 1, 34, 9,  1, 6, 89, 5, 98, 0, 23, 4, 64, 8,  2, 3, 29, 7, 36, 
    8, 26, 3, 38, 7, 45, 4, 94, 2, 40, 5, 20, 0, 67, 6, 18, 9, 49, 1, 85, 
    5, 78, 1, 16, 4,  9, 7, 39, 6, 33, 9, 22, 2, 21, 3, 77, 0, 12, 8, 58, 
    4, 34, 6, 52, 9, 27, 3, 66, 8, 69, 2, 28, 0, 45, 5,  4, 1, 59, 7, 88, 
    6, 90, 2, 76, 3, 88, 0, 86, 5,  5, 7, 86, 9, 34, 4, 50, 8, 13, 1, 71
  };
  const int r520[] = {
    10, 10, // Number of jobs and machines
    4, 75, 6, 31, 0, 50, 9, 20, 8, 29, 5, 54, 1, 21, 3, 78, 2, 73, 7, 15, 
    5, 80, 3, 85, 6, 24, 9, 41, 4, 31, 0, 78, 2, 55, 7, 40, 1,  3, 8, 23, 
    5, 94, 2, 10, 4, 13, 9, 60, 1, 56, 8, 48, 7, 30, 3,  5, 0, 98, 6,  8, 
    4, 74, 1, 70, 2,  1, 3, 58, 5, 77, 6, 45, 0, 86, 8, 66, 7, 60, 9, 10, 
    2, 76, 3, 95, 5, 52, 0, 88, 4, 83, 8, 30, 7, 95, 1, 73, 6,  3, 9, 58, 
    8, 86, 3, 83, 0, 60, 9, 38, 5, 43, 2,  5, 4, 96, 1,  9, 7,  4, 6, 93, 
    9, 29, 1, 47, 8, 69, 6, 35, 5, 83, 2, 49, 4, 47, 0, 65, 7, 72, 3, 28, 
    0, 30, 9, 49, 8, 63, 3, 64, 1, 36, 7, 19, 4, 27, 5, 62, 2, 52, 6, 40, 
    1, 98, 3, 82, 2, 85, 6, 34, 9, 28, 7, 48, 0, 53, 5, 25, 4, 59, 8, 54, 
    6, 32, 0, 40, 8, 81, 4, 70, 1, 33, 7, 11, 3, 15, 2, 97, 9, 70, 5,  6
  };
  const int r521[] = {
    10, 10, // Number of jobs and machines
    2, 29, 8, 26, 6, 11, 4, 74, 9, 11, 0, 61, 3, 55, 7, 65, 5, 43, 1, 34, 
    3, 50, 8, 50, 7, 48, 2, 99, 9, 29, 0, 85, 1,  2, 5, 49, 4, 84, 6, 69, 
    3, 30, 9, 12, 0, 61, 1, 19, 2, 82, 4, 42, 8, 29, 5,  6, 6, 82, 7, 89, 
    7, 75, 0, 74, 1, 97, 3, 63, 5, 47, 9,  9, 2, 81, 4, 35, 8, 91, 6, 53, 
    0, 41, 8, 95, 9,  2, 6, 36, 4, 34, 5, 45, 3, 35, 2,  5, 7, 71, 1, 89, 
    0, 80, 3, 36, 5, 82, 9, 99, 4, 97, 2, 63, 7, 18, 1, 59, 6, 95, 8, 40, 
    7, 76, 4, 93, 5, 41, 2, 64, 9, 48, 1, 29, 6, 65, 3, 36, 0, 52, 8, 28, 
    3, 10, 1, 41, 0, 95, 2, 18, 6, 35, 9, 15, 5, 95, 7, 20, 8, 33, 4, 20, 
    0, 36, 3, 62, 8, 75, 9,  1, 4,  7, 5, 56, 7, 40, 2, 71, 1,  9, 6, 67, 
    5,  1, 3, 78, 0, 35, 6, 95, 7, 31, 4, 95, 9, 90, 2, 67, 8,  4, 1, 26
  };
  const int r522[] = {
    10, 10, // Number of jobs and machines
    0, 45, 4, 68, 6, 10, 1, 57, 5, 94, 8, 59, 9, 52, 2, 41, 3, 21, 7, 30, 
    7, 26, 1, 31, 3, 27, 9, 93, 4, 70, 0, 58, 2, 22, 5, 85, 8, 26, 6, 56, 
    1, 21, 9, 84, 4, 13, 3, 93, 5, 22, 0, 33, 2,  4, 7, 70, 8, 18, 6, 96, 
    6, 19, 0, 14, 7, 17, 3, 85, 2, 79, 8, 53, 5, 93, 4, 66, 9, 65, 1,  3, 
    1, 73, 5, 75, 4, 48, 3, 44, 8, 11, 6, 83, 7, 81, 9, 89, 0, 62, 2, 46, 
    9, 50, 8, 87, 6, 29, 1,  2, 0, 10, 4, 25, 2, 38, 3, 71, 7, 58, 5, 13, 
    5, 27, 4,  7, 2, 98, 6, 86, 0,  7, 8, 87, 3, 54, 1, 44, 7, 22, 9, 14, 
    8, 12, 0, 89, 3, 68, 6, 90, 7, 43, 4, 53, 5, 82, 9, 46, 2, 83, 1, 21, 
    6, 75, 8, 73, 5, 27, 1, 33, 3, 76, 4, 31, 2, 38, 7, 92, 9, 10, 0, 22, 
    3, 23, 0, 56, 7, 62, 4,  9, 1, 69, 2, 84, 5, 54, 9, 50, 8, 31, 6, 24
  };
  const int r523[] = {
    10, 10, // Number of jobs and machines
    7, 31, 5, 94, 0, 57, 3, 44, 1, 87, 8, 22, 9, 77, 4, 72, 6, 46, 2, 72, 
    0, 57, 6, 22, 2,  9, 8, 72, 9, 78, 7, 32, 5, 15, 4, 21, 1, 63, 3, 10, 
    6, 59, 9, 28, 1, 39, 4, 17, 8,  3, 3, 33, 2, 31, 5, 20, 0, 94, 7, 89, 
    5, 42, 2, 17, 1, 42, 6,  9, 4, 63, 8, 81, 3, 62, 0, 80, 9, 67, 7, 10, 
    9, 76, 4, 29, 7,  4, 2, 81, 0, 84, 8,  1, 5, 14, 6, 17, 3, 63, 1, 88, 
    1, 65, 7, 87, 4, 85, 0, 76, 3, 95, 8, 12, 9, 65, 6, 68, 5, 65, 2, 28, 
    3,  9, 0, 29, 5, 76, 9, 10, 7, 51, 6, 25, 2, 58, 1, 12, 8, 35, 4, 90, 
    6, 69, 4, 34, 3, 65, 8, 65, 1, 43, 5, 14, 9, 79, 2, 69, 7, 95, 0, 69, 
    8, 30, 3, 59, 1, 84, 4,  1, 5, 42, 0, 73, 7, 71, 9, 64, 2, 44, 6, 71, 
    4, 74, 6, 44, 2, 27, 1, 85, 8, 35, 5, 94, 7,  3, 9, 29, 0, 88, 3, 78
  };
  const int r524[] = {
    10, 10, // Number of jobs and machines
    0, 82, 9, 90, 7,  9, 4, 45, 2, 70, 6, 58, 1, 59, 8, 76, 5, 35, 3, 34, 
    6, 35, 1, 83, 0, 18, 4, 80, 5,  8, 3, 78, 9, 79, 8, 36, 7, 42, 2, 20, 
    3, 67, 4, 88, 8, 67, 5, 71, 1, 60, 0, 87, 2, 66, 9, 14, 7, 63, 6, 46, 
    9, 79, 3, 84, 7, 37, 2, 46, 0, 34, 1, 70, 8, 62, 6, 21, 4, 42, 5, 65, 
    3, 68, 4, 70, 7, 44, 2, 77, 6, 18, 0, 91, 5,  4, 9,  3, 8, 83, 1, 12, 
    7, 62, 2, 11, 5, 66, 8, 20, 9, 14, 3, 73, 4, 45, 6, 82, 1, 59, 0, 10, 
    3, 72, 2, 91, 8, 28, 6, 56, 5, 90, 7, 15, 4, 39, 1, 80, 9, 99, 0, 73, 
    7, 91, 2, 48, 3, 94, 4, 67, 9, 55, 0, 28, 5, 83, 6, 63, 8, 16, 1, 68, 
    8, 83, 6, 68, 9, 61, 4, 53, 2, 93, 7, 24, 5, 14, 1, 78, 0,  9, 3, 85, 
    4, 79, 7, 85, 2, 30, 8,  5, 9,  2, 6, 83, 5, 33, 3, 86, 1, 14, 0, 58
  };
  const int r525[] = {
    10, 10, // Number of jobs and machines
    0, 83, 1, 37, 7, 49, 6,  2, 2,  9, 4, 74, 5, 57, 3,  4, 9, 69, 8, 27, 
    4, 24, 1, 55, 0, 67, 2, 56, 9, 50, 7, 93, 8, 68, 5, 59, 3, 19, 6, 71, 
    7, 38, 9, 25, 3,  7, 0,  1, 5, 34, 4, 14, 6,  2, 8,  2, 2, 60, 1, 27, 
    0, 21, 3, 43, 2, 83, 4, 53, 5, 70, 6, 52, 1, 45, 9, 57, 7, 93, 8, 14, 
    9, 53, 6, 38, 4, 13, 8, 36, 3, 76, 5, 27, 7, 56, 0, 90, 2, 18, 1, 92, 
    1, 60, 6, 11, 7, 98, 4,  2, 9, 44, 2, 50, 8, 85, 0, 55, 3, 76, 5, 88, 
    5, 82, 0, 13, 7, 43, 1, 46, 4, 63, 6, 65, 8, 92, 2, 90, 9, 40, 3, 91, 
    0, 77, 4, 59, 3, 24, 2, 37, 9, 69, 5, 12, 6, 69, 1, 52, 7, 20, 8,  8, 
    0, 73, 7, 83, 1, 65, 9, 89, 6, 27, 2, 97, 5, 46, 4, 13, 8, 15, 3, 89, 
    5, 48, 7, 11, 3, 40, 2,  8, 1, 25, 4, 96, 6,  5, 9, 58, 0, 47, 8, 61
  };
  const int r526[] = {
    10, 10, // Number of jobs and machines
    4, 93, 0, 98, 3, 53, 1, 57, 9, 81, 5, 32, 6,  9, 2, 57, 7,  4, 8, 47, 
    7, 32, 6, 11, 2, 65, 5, 40, 8,  8, 9, 26, 3, 46, 0, 80, 4, 21, 1,  9, 
    9, 71, 0, 49, 7, 12, 8, 35, 6, 55, 5,  5, 2, 24, 4, 36, 1, 42, 3, 96, 
    4, 81, 0, 98, 8, 15, 7, 63, 5, 37, 9, 37, 2, 33, 3, 72, 1, 44, 6,  7, 
    1, 53, 0, 54, 6, 89, 2, 11, 3, 65, 4, 14, 8, 25, 7, 36, 9,  8, 5, 39, 
    5, 44, 9, 91, 2, 30, 3, 97, 6, 29, 0, 82, 4, 61, 7,  3, 1, 59, 8, 23, 
    8, 76, 9, 51, 0,  6, 4, 50, 2, 70, 6, 32, 1, 80, 7, 70, 3, 64, 5,  3, 
    0, 79, 8, 65, 2, 50, 6, 68, 5, 82, 1, 75, 4, 14, 3, 58, 7, 78, 9, 76, 
    1, 99, 2, 43, 7,  9, 5, 32, 8, 66, 4, 11, 0, 54, 9, 89, 6, 54, 3, 66, 
    2, 34, 4,  5, 1, 46, 8, 51, 9, 39, 5, 39, 3, 47, 0, 12, 6, 39, 7, 54
  };
  const int r527[] = {
    10, 10, // Number of jobs and machines
    4, 83, 1, 37, 9, 36, 3,  9, 6, 36, 2, 15, 5, 70, 7, 59, 0, 83, 8, 97, 
    7, 11, 8, 44, 1, 97, 5, 55, 3,  1, 0, 37, 6, 39, 4, 74, 9, 13, 2, 98, 
    5, 10, 8, 86, 1, 78, 9, 40, 0, 57, 6, 47, 2, 53, 3, 77, 7, 23, 4, 74, 
    0,  2, 1, 53, 3, 19, 2, 63, 7, 57, 6, 99, 5, 41, 9, 40, 8, 23, 4, 44, 
    1, 33, 9,  5, 5, 89, 4, 64, 6, 86, 0, 27, 8, 85, 2, 41, 7, 56, 3, 66, 
    2, 96, 9, 76, 8, 52, 4, 28, 1, 64, 7, 93, 0, 62, 3, 38, 5, 95, 6, 69, 
    0, 65, 3, 28, 9, 61, 8, 86, 2, 79, 7, 99, 4, 97, 1, 65, 5,  3, 6, 11, 
    3, 46, 4, 57, 6, 28, 8, 34, 1, 71, 0, 48, 9, 82, 7, 23, 5, 41, 2, 55, 
    6, 33, 3,  2, 5, 52, 7, 39, 2, 85, 9, 34, 4, 69, 0, 43, 1, 30, 8, 49, 
    0, 30, 5, 82, 8, 49, 7, 46, 9, 79, 3, 37, 2, 45, 1, 90, 4, 47, 6, 57
  };
  const int r528[] = {
    10, 10, // Number of jobs and machines
    0, 26, 6, 33, 7, 92, 2, 81, 4,  6, 3, 72, 1, 18, 9, 16, 5, 92, 8, 33, 
    5, 39, 0, 13, 3, 43, 9, 99, 7, 53, 6, 83, 1,  2, 4, 56, 2, 23, 8, 26, 
    9, 53, 1, 88, 2, 60, 0,  2, 7, 96, 6, 76, 5, 67, 3, 38, 8, 99, 4, 99, 
    0,  2, 2, 91, 8, 70, 4, 61, 7, 17, 1, 84, 6,  6, 3, 83, 5, 12, 9, 94, 
    5, 19, 2, 57, 9, 59, 8, 70, 0, 52, 4, 27, 7, 29, 6,  2, 3, 83, 1, 29, 
    5, 73, 8, 82, 2, 90, 6, 94, 7, 24, 1, 80, 9, 34, 4, 73, 3, 94, 0, 11, 
    7, 71, 9, 41, 2, 24, 4, 66, 8, 16, 1, 11, 5, 24, 3, 23, 6, 17, 0,  3, 
    1, 43, 2, 56, 4, 91, 6, 37, 7, 27, 5, 26, 8, 31, 9, 32, 3, 28, 0, 26, 
    6, 43, 0,  1, 1, 96, 4, 82, 9, 14, 2, 38, 5, 71, 7, 13, 3, 83, 8, 44, 
    9, 57, 5, 66, 8,  5, 2, 35, 3,  8, 6, 16, 4, 22, 1, 85, 0, 40, 7, 98
  };
  const int r529[] = {
    10, 10, // Number of jobs and machines
    3,  6, 1, 89, 2, 15, 8, 99, 0, 22, 9, 35, 6, 56, 5, 14, 4, 10, 7, 21, 
    2, 86, 7, 69, 5, 97, 6, 17, 9, 78, 8, 14, 0, 31, 4, 35, 1, 93, 3, 42, 
    0, 93, 4, 26, 8, 10, 1, 65, 3, 63, 9, 63, 5, 21, 2, 74, 6, 55, 7, 47, 
    8, 52, 6,  5, 3, 34, 2, 67, 1,  2, 9, 36, 7, 78, 5, 17, 0, 47, 4, 53, 
    0, 96, 6, 92, 9, 43, 8, 63, 1, 67, 3, 49, 4, 79, 5, 80, 2,  5, 7, 39, 
    8, 36, 3,  5, 4, 90, 1,  4, 2, 86, 9, 24, 0, 66, 7, 33, 5, 25, 6, 11, 
    4, 71, 5, 88, 1, 28, 0, 35, 3,  7, 9, 57, 6, 75, 2, 25, 8, 62, 7, 99, 
    5,  6, 9, 82, 2,  7, 3, 61, 0, 28, 4, 81, 6, 38, 1, 81, 7, 86, 8, 39, 
    8,  6, 5, 70, 6, 97, 3, 47, 9, 34, 4,  7, 0, 55, 2, 36, 1, 16, 7, 70, 
    1, 50, 6, 53, 3, 53, 4, 60, 5,  9, 7, 27, 2, 40, 9, 45, 0, 44, 8, 69
  };
  const int r530[] = {
    10, 10, // Number of jobs and machines
    0, 54, 6, 97, 5, 96, 1, 30, 9, 63, 7, 97, 3, 53, 4, 65, 8, 86, 2,  9, 
    4, 34, 6, 53, 0, 70, 7, 32, 3, 83, 1, 45, 5, 88, 9, 81, 8, 33, 2, 40, 
    7, 69, 5, 93, 8, 77, 6, 93, 4, 45, 0,  4, 3, 39, 9,  4, 1, 91, 2, 31, 
    3, 30, 1, 94, 5, 68, 9, 56, 0,  8, 6, 13, 4, 36, 8, 19, 7, 96, 2, 59, 
    2, 10, 9, 89, 4, 35, 8, 24, 0, 13, 7, 47, 3, 77, 6, 62, 1, 18, 5, 29, 
    8, 57, 0, 70, 9,  1, 3, 32, 4,  9, 2, 89, 6, 84, 7, 72, 5, 88, 1, 35, 
    1, 65, 4, 53, 0, 33, 8, 84, 3, 64, 9, 56, 7, 51, 2, 87, 5, 70, 6, 23, 
    2, 13, 6, 63, 5, 78, 7, 96, 4, 19, 0, 47, 9,  7, 3, 75, 1, 35, 8, 57, 
    9, 69, 5,  1, 0, 90, 1, 66, 6, 89, 3, 80, 4, 10, 7, 94, 2, 89, 8, 28, 
    4, 37, 2, 14, 1, 86, 8, 13, 6, 13, 9, 23, 3, 17, 7, 26, 0, 54, 5, 63
  };
  const int r531[] = {
    10, 10, // Number of jobs and machines
    1, 27, 7, 81, 5, 60, 2, 61, 6, 94, 3, 19, 0, 55, 8, 57, 9, 37, 4, 19, 
    6, 39, 2, 63, 3, 92, 5,  3, 7, 21, 0, 96, 4, 49, 9, 45, 1, 16, 8,  7, 
    3, 40, 9,  7, 5, 31, 0, 82, 8, 36, 6, 95, 7, 68, 1, 86, 2, 84, 4, 10, 
    5, 70, 6, 95, 2, 47, 0, 27, 8, 30, 3, 51, 9, 60, 1,  2, 7, 62, 4, 31, 
    0, 46, 6, 59, 5, 78, 9, 51, 2, 46, 4, 99, 1, 84, 3, 66, 8, 48, 7, 87, 
    6,  5, 8, 51, 1, 63, 2, 77, 4, 77, 0, 18, 7, 69, 3, 22, 9, 16, 5, 87, 
    3, 39, 9,  6, 6, 28, 0, 54, 2, 58, 5, 43, 4, 66, 8, 87, 7, 10, 1, 56, 
    4, 22, 3,  5, 5, 85, 2, 92, 8, 80, 6, 57, 1, 24, 9, 43, 0,  2, 7, 15, 
    8, 29, 0, 79, 6, 85, 4, 29, 5, 10, 7, 29, 9, 73, 1, 37, 2, 68, 3, 94, 
    4, 46, 3, 69, 8, 78, 6, 71, 9, 61, 7, 17, 0, 62, 5, 95, 2, 29, 1, 10
  };
  const int r532[] = {
    10, 10, // Number of jobs and machines
    7,  9, 3, 10, 0, 12, 6, 93, 1, 37, 2, 53, 8, 95, 4, 70, 5, 27, 9, 95, 
    4, 66, 3, 85, 6, 32, 2, 13, 8, 44, 0, 42, 7, 48, 9, 26, 5, 19, 1, 36, 
    3, 12, 5, 97, 8, 99, 2, 93, 9, 11, 7, 96, 4, 76, 0,  5, 1, 28, 6, 78, 
    7, 18, 6, 77, 9, 61, 2, 33, 1, 56, 0, 14, 8, 65, 5, 71, 3, 31, 4, 28, 
    7, 77, 1, 12, 6, 76, 8, 31, 5, 37, 2, 44, 0, 29, 3, 17, 9, 29, 4, 38, 
    4, 21, 1, 30, 8, 77, 5, 99, 6, 72, 9, 44, 3, 67, 0, 72, 7, 93, 2, 66, 
    6, 73, 8,  2, 0, 13, 5, 54, 3,  9, 2, 69, 7, 90, 9, 84, 4, 96, 1, 55, 
    0, 16, 6, 97, 5, 97, 3, 32, 8, 97, 4, 83, 2,  2, 1, 46, 7, 56, 9,  1, 
    3, 11, 4, 52, 7, 21, 0, 55, 5, 21, 2, 10, 6, 79, 1, 98, 9, 26, 8, 19, 
    9, 13, 4, 21, 1,  8, 8, 29, 3, 64, 0, 34, 2,  3, 7, 71, 5, 33, 6, 34
  };
  const int r533[] = {
    10, 10, // Number of jobs and machines
    9,  1, 0, 12, 5, 74, 2, 86, 6, 74, 7, 60, 3, 12, 4, 79, 1, 67, 8, 15, 
    8, 78, 6, 82, 2,  7, 7, 74, 1,  3, 9, 93, 4, 49, 0, 90, 3, 95, 5, 73, 
    0, 46, 2, 60, 9, 97, 7, 82, 4, 34, 6, 99, 3, 39, 8, 63, 1, 55, 5, 25, 
    2, 64, 9, 72, 4, 79, 0, 63, 8, 26, 7, 32, 3, 72, 1,  8, 6, 72, 5, 74, 
    2,  7, 4, 71, 9, 57, 5, 80, 7, 35, 1, 97, 8,  2, 0,  5, 6, 23, 3,  9, 
    1, 85, 2, 45, 9, 84, 7, 34, 8, 49, 5, 21, 0, 49, 3, 15, 4, 62, 6, 41, 
    4, 37, 0, 62, 5, 81, 1, 98, 7, 10, 3, 70, 6,  6, 9, 37, 2, 26, 8, 18, 
    1, 84, 0, 17, 3, 17, 4,  4, 6,  4, 7, 53, 2, 57, 8, 45, 9, 27, 5, 40, 
    6, 92, 9,  3, 3, 78, 5, 26, 1, 90, 7, 27, 8, 37, 2, 44, 0, 23, 4, 52, 
    6, 21, 1,  7, 5, 76, 8, 19, 3, 35, 4, 99, 9, 38, 2, 52, 7, 13, 0, 75
  };
  const int r534[] = {
    10, 10, // Number of jobs and machines
    0, 26, 6, 58, 5, 97, 4, 37, 3, 41, 7, 87, 8, 61, 9, 76, 1, 82, 2, 68, 
    7, 51, 4, 82, 0, 57, 2, 47, 9, 86, 5, 95, 3,  5, 1, 62, 6, 18, 8, 45, 
    1,  8, 4, 24, 7, 19, 8, 36, 3, 67, 2, 63, 9, 85, 5, 14, 6,  1, 0, 32, 
    7, 90, 1, 16, 9, 48, 6, 95, 3, 33, 2, 47, 5, 61, 0, 91, 8,  5, 4,  1, 
    7, 57, 8, 42, 5, 84, 0, 12, 6, 51, 1, 36, 9, 58, 3, 99, 2, 63, 4, 75, 
    7,  6, 8, 83, 6, 54, 0,  3, 1, 75, 9, 11, 4, 66, 2, 51, 5, 47, 3, 75, 
    3, 31, 6, 78, 4, 83, 9, 82, 5, 19, 2, 20, 8, 75, 0, 12, 7, 16, 1,  1, 
    1,  1, 3, 42, 8, 22, 2, 31, 4, 73, 7, 77, 5, 85, 0, 66, 6, 81, 9, 13, 
    8, 56, 5, 44, 1, 79, 0, 58, 2, 60, 7, 51, 4, 83, 3, 23, 9, 51, 6, 10, 
    1, 16, 3, 31, 6, 67, 5, 78, 2, 38, 4, 97, 0, 75, 7,  1, 9, 71, 8, 42
  };
  const int r535[] = {
    10, 10, // Number of jobs and machines
    3, 42, 6, 86, 1,  6, 9, 56, 5, 20, 4, 14, 0, 33, 8, 12, 7, 32, 2, 96, 
    0, 92, 9, 17, 5, 77, 3, 61, 2, 37, 6, 35, 1, 49, 8, 85, 7,  9, 4, 13, 
    4, 67, 8, 19, 7, 96, 0,  8, 1, 24, 3, 75, 9, 41, 6, 93, 5, 24, 2,  2, 
    4, 61, 7, 60, 0, 40, 9, 54, 6, 69, 3, 12, 2, 31, 8,  5, 1, 14, 5, 57, 
    6, 30, 9, 81, 3, 96, 4,  7, 7, 72, 0, 14, 2, 37, 5, 99, 1, 75, 8, 73, 
    4, 15, 5, 11, 0, 25, 6, 90, 8, 56, 2, 32, 7, 37, 9, 40, 3, 57, 1, 93, 
    7, 79, 9, 53, 2, 73, 8, 58, 4, 42, 3, 18, 0, 17, 5, 28, 6, 69, 1, 22, 
    1, 33, 6, 68, 8, 65, 4, 44, 5, 54, 7, 61, 2, 96, 0, 89, 9, 39, 3, 71, 
    2, 49, 1, 30, 9, 31, 0, 52, 8, 43, 6, 64, 7, 89, 5,  1, 4, 16, 3, 13, 
    3, 47, 7, 90, 4, 46, 1, 28, 5, 65, 0, 58, 8, 34, 9, 72, 6, 65, 2, 73
  };
  const int r536[] = {
    10, 10, // Number of jobs and machines
    4, 88, 9,  6, 5, 68, 7, 96, 2, 31, 8, 41, 3, 66, 0, 67, 6, 48, 1, 12, 
    9, 13, 6, 89, 5, 48, 8, 76, 4, 64, 7, 37, 2, 11, 3, 37, 1, 21, 0, 33, 
    7, 25, 3, 73, 4, 85, 6, 74, 8, 76, 5, 12, 0, 43, 9, 22, 1, 76, 2, 74, 
    1, 68, 3, 25, 2, 39, 6, 77, 0,  8, 8, 67, 4, 83, 7, 53, 9, 75, 5, 93, 
    1, 44, 7, 61, 0, 29, 9, 55, 8, 61, 2, 22, 6, 61, 4, 51, 5, 52, 3,  3, 
    6, 99, 5, 29, 2,  3, 1, 69, 7,  9, 3, 77, 8, 35, 9, 62, 0, 58, 4, 98, 
    2, 31, 4,  1, 7, 81, 3, 22, 0, 47, 6, 94, 1, 24, 8, 29, 9, 73, 5,  6, 
    7, 24, 5, 23, 0,  4, 2, 71, 3, 54, 1,  9, 6,  7, 8, 31, 4, 99, 9, 97, 
    9, 39, 3, 46, 5, 36, 8, 13, 0, 46, 7, 98, 1, 27, 6, 26, 2, 83, 4, 85, 
    6, 47, 5, 91, 0, 54, 9, 84, 2, 87, 1, 45, 3, 86, 8, 18, 7, 52, 4,  7
  };
  const int r537[] = {
    10, 10, // Number of jobs and machines
    1, 22, 9, 74, 7, 64, 0, 67, 8, 95, 5, 90, 4, 11, 2,  9, 3, 48, 6, 38, 
    5, 66, 0, 38, 7, 82, 6, 66, 4, 70, 8, 93, 1, 75, 2, 69, 3, 13, 9, 56, 
    5, 28, 2, 46, 1, 24, 8, 41, 3, 47, 6, 49, 4, 83, 7, 53, 9, 56, 0, 39, 
    7, 16, 2, 77, 4, 24, 1, 97, 9, 16, 6,  3, 5, 79, 0, 24, 8,  4, 3, 43, 
    0, 92, 1, 34, 5, 69, 8, 40, 4,  3, 9, 78, 2, 92, 7, 64, 6, 60, 3, 80, 
    1, 81, 4, 99, 3, 71, 9, 33, 6,  3, 8, 78, 0, 50, 5, 15, 7, 59, 2, 11, 
    5, 41, 7, 75, 8, 55, 1, 57, 4, 92, 0,  7, 9, 75, 3, 11, 6, 73, 2, 54, 
    2, 13, 6, 63, 3,  4, 1, 17, 9, 31, 4, 40, 8, 54, 5, 99, 7, 35, 0, 17, 
    4, 26, 7, 32, 8, 97, 1,  6, 3, 23, 5, 67, 2,  3, 6, 50, 0, 60, 9, 98, 
    7, 71, 9, 99, 8, 28, 4, 17, 1, 76, 5, 12, 3, 64, 0, 58, 6, 10, 2, 88
  };
  const int r538[] = {
    10, 10, // Number of jobs and machines
    2, 97, 9,  1, 0,  2, 6, 89, 7, 29, 4, 64, 1, 41, 5, 44, 3, 79, 8, 97, 
    8, 30, 2, 65, 0,  1, 3, 73, 4, 46, 1, 93, 6, 17, 5, 25, 9, 93, 7, 87, 
    8, 97, 2,  8, 1, 49, 6,  8, 9, 86, 7, 74, 0, 91, 5, 46, 3, 57, 4, 50, 
    1, 41, 8, 44, 7, 16, 5, 44, 9, 11, 6, 59, 3, 45, 0, 72, 2, 59, 4, 10, 
    6, 87, 3, 88, 9, 37, 7, 10, 1, 21, 8, 94, 5, 77, 4, 90, 2, 30, 0, 91, 
    2, 45, 3, 57, 8, 45, 7, 76, 4, 47, 1, 12, 5,  1, 9, 15, 0, 21, 6, 52, 
    0, 23, 9, 15, 2, 49, 5, 21, 3, 69, 6, 82, 7, 69, 8, 50, 4,  6, 1,  7, 
    6, 62, 2, 79, 1, 21, 0, 40, 9, 76, 5, 67, 4, 49, 3, 35, 8, 87, 7, 30, 
    1, 29, 0, 31, 9, 99, 8,  1, 6, 97, 4, 30, 3, 82, 2, 56, 5, 47, 7, 62, 
    6, 15, 1, 70, 4, 41, 9, 22, 0,  4, 2, 63, 7, 41, 8, 58, 3, 97, 5, 74
  };
  const int r539[] = {
    10, 10, // Number of jobs and machines
    8, 72, 6, 93, 2, 14, 4, 83, 3,  8, 1, 41, 7, 64, 5, 64, 9, 84, 0, 13, 
    8, 87, 3, 52, 4, 39, 0, 75, 7, 39, 6, 89, 1, 84, 2, 26, 9, 38, 5, 88, 
    0, 69, 9, 40, 2, 11, 3, 44, 7, 20, 8, 28, 5, 25, 4, 19, 1,  5, 6, 34, 
    2, 71, 8, 60, 7, 33, 1, 56, 9, 62, 3, 16, 6, 75, 5, 25, 0, 49, 4, 37, 
    7,  4, 2, 42, 0, 15, 9, 58, 1, 84, 3, 34, 8, 23, 6, 10, 4, 94, 5, 13, 
    3, 81, 7, 90, 5, 11, 0, 26, 2, 29, 6, 27, 4, 64, 1, 96, 8, 85, 9, 79, 
    5, 86, 4, 43, 6, 66, 1, 37, 3, 99, 9, 96, 7, 82, 2, 74, 0, 41, 8,  7, 
    0, 48, 8, 25, 6, 64, 3, 16, 1, 83, 7, 85, 5, 34, 9, 75, 4, 18, 2, 70, 
    5, 95, 4, 74, 3, 27, 6, 94, 0, 20, 7, 73, 1, 99, 9, 61, 2, 81, 8, 24, 
    3, 22, 2, 86, 7, 33, 8, 92, 9, 46, 6, 95, 4, 11, 0, 92, 1, 24, 5,  1
  };
  const int r540[] = {
    10, 10, // Number of jobs and machines
    6, 35, 4, 36, 2, 47, 3, 55, 7, 78, 9,  8, 5, 46, 0, 18, 8, 20, 1, 21, 
    7, 92, 1, 92, 0, 48, 6, 94, 3, 74, 4, 29, 8, 76, 2, 55, 5, 88, 9, 64, 
    9, 41, 7, 95, 1, 61, 2, 65, 8, 38, 3, 11, 6, 16, 4, 58, 0, 53, 5, 55, 
    6, 85, 3, 61, 7, 65, 1, 20, 9, 53, 4, 53, 0, 84, 8, 51, 5, 89, 2, 74, 
    1, 50, 8, 46, 7, 73, 9, 76, 0, 86, 2, 79, 3, 94, 6, 70, 5, 21, 4, 32, 
    4,  2, 8, 63, 0, 68, 2, 89, 7, 38, 9, 21, 5, 22, 1, 64, 6, 26, 3, 96, 
    3, 27, 6, 60, 4, 81, 1, 89, 8, 99, 7, 53, 9, 94, 5, 11, 2, 36, 0, 87, 
    6, 53, 1, 12, 9, 98, 0, 64, 3, 99, 7, 54, 8, 27, 4, 69, 2, 21, 5, 21, 
    1, 68, 3, 40, 8, 49, 2, 27, 0,  6, 9,  7, 4, 67, 6,  6, 5, 71, 7, 32, 
    0, 18, 4, 65, 5, 13, 6, 71, 2, 52, 3, 71, 7, 98, 1, 35, 9, 84, 8, 45
  };
  const int r541[] = {
    10, 10, // Number of jobs and machines
    5, 26, 4, 55, 2, 81, 8, 44, 6, 22, 7, 58, 0, 60, 9, 66, 3, 11, 1, 83, 
    3, 81, 9, 28, 4, 45, 1,  6, 6, 32, 2, 17, 0, 89, 5, 26, 8, 96, 7, 63, 
    1, 53, 5, 59, 6,  8, 4, 54, 7, 66, 0, 19, 2, 27, 9, 17, 8, 74, 3, 22, 
    9, 58, 1,  5, 2, 44, 0, 75, 8, 39, 4, 25, 3, 64, 5, 84, 6, 80, 7, 14, 
    6, 55, 8, 32, 9, 26, 4, 29, 5,  2, 2, 73, 0,  3, 3, 82, 7, 74, 1, 27, 
    1, 81, 9, 32, 3, 23, 8,  4, 5,  9, 7, 24, 0, 18, 2, 12, 6, 94, 4,  2, 
    6, 62, 5, 40, 0, 50, 9, 91, 4, 50, 8, 24, 7, 68, 1,  7, 2,  8, 3, 80, 
    1, 62, 8, 75, 5, 36, 2, 86, 9, 31, 7, 78, 4, 85, 6, 30, 0,  1, 3, 49, 
    6, 60, 7, 11, 4, 57, 0, 46, 2, 85, 9, 71, 3, 87, 5, 45, 1,  3, 8, 70, 
    6, 48, 7, 96, 1, 53, 3, 87, 5, 12, 2, 80, 9,  7, 4, 82, 8,  8, 0, 82
  };
  const int r542[] = {
    10, 10, // Number of jobs and machines
    1, 40, 4, 24, 8, 47, 9, 85, 2, 38, 6, 54, 3, 73, 5, 56, 7, 98, 0, 79, 
    8, 65, 5, 95, 7, 96, 0, 30, 4, 40, 6, 31, 3, 61, 2, 87, 1, 72, 9,  9, 
    5, 31, 7, 23, 6, 29, 1, 64, 0, 19, 4, 85, 2, 22, 8, 71, 9, 81, 3, 21, 
    1, 55, 5, 73, 3, 75, 7, 67, 8,  4, 9, 42, 4, 28, 6, 38, 0, 68, 2, 12, 
    7, 29, 4,  5, 0, 93, 8, 72, 2, 26, 6, 66, 1, 30, 5, 50, 9, 93, 3, 64, 
    6, 67, 2, 48, 3, 52, 5, 13, 4, 78, 0, 92, 7, 45, 9, 31, 1, 63, 8, 42, 
    4, 83, 0, 64, 5, 14, 3, 88, 8, 22, 6, 43, 1, 94, 9, 92, 7, 88, 2, 33, 
    0, 30, 9, 32, 2, 21, 8,  4, 1, 74, 3,  8, 5, 64, 6, 45, 7, 45, 4, 28, 
    2, 75, 3, 45, 8, 35, 0, 62, 7, 55, 5, 69, 9, 78, 4,  6, 1, 40, 6, 95, 
    2, 52, 3, 20, 9, 41, 7, 50, 4, 47, 1,  9, 0, 88, 5, 10, 6, 25, 8, 43
  };
  const int r543[] = {
    10, 10, // Number of jobs and machines
    0, 61, 3, 42, 1,  4, 7, 82, 4, 87, 9, 78, 8, 87, 6, 81, 5, 36, 2, 34, 
    0, 98, 8, 50, 6, 66, 1,  9, 5, 78, 7, 18, 4, 56, 9, 82, 2, 30, 3, 46, 
    3, 35, 0, 18, 4, 86, 7,  9, 9, 40, 5, 73, 6, 48, 2, 92, 8, 61, 1, 76, 
    5, 93, 0, 39, 3, 15, 8, 89, 7, 43, 6, 42, 2, 31, 9, 80, 1, 94, 4, 84, 
    2, 42, 3, 53, 1, 40, 7, 53, 8, 98, 5, 85, 4, 85, 9, 95, 6,  9, 0, 22, 
    9, 87, 0, 38, 3, 27, 2, 87, 1, 98, 6, 88, 8, 59, 5, 81, 4,  7, 7, 71, 
    5, 21, 3, 51, 6, 93, 1, 84, 9, 99, 4, 13, 0, 87, 7, 15, 2, 19, 8, 35, 
    6, 95, 0, 28, 9, 26, 8, 51, 1, 39, 5, 12, 7, 92, 4, 58, 2, 61, 3, 73, 
    3, 26, 8, 68, 9, 49, 6, 78, 2, 81, 1, 32, 7, 14, 5, 58, 4,  6, 0, 64, 
    7, 94, 3, 23, 5, 91, 4, 64, 2, 28, 9, 26, 1, 27, 6, 62, 8,  1, 0, 49
  };
  const int r544[] = {
    10, 10, // Number of jobs and machines
    4, 94, 5, 42, 3, 34, 7, 71, 8, 33, 1, 98, 9, 98, 6, 58, 2, 74, 0, 46, 
    9, 32, 0, 18, 7, 10, 3, 60, 6, 47, 5, 87, 8, 21, 4, 88, 1, 82, 2, 99, 
    9, 12, 2, 90, 6, 56, 3, 16, 0, 44, 4, 90, 5, 78, 1, 12, 7, 18, 8, 15, 
    4, 80, 3, 66, 2, 88, 7, 41, 9, 75, 8, 21, 5,  6, 1, 65, 6, 42, 0, 57, 
    1, 72, 9, 28, 8, 89, 4, 17, 0, 24, 2, 43, 3, 64, 6, 76, 7, 68, 5, 43, 
    6, 77, 9, 76, 5, 31, 1,  6, 8, 46, 0, 10, 2, 68, 3, 19, 4, 56, 7, 20, 
    5, 17, 6, 56, 2, 10, 8, 41, 7, 18, 4, 46, 9, 88, 1, 40, 3, 73, 0, 76, 
    7, 87, 8, 58, 1, 62, 0, 94, 5, 70, 4, 39, 9, 30, 3, 79, 2, 13, 6, 16, 
    9,  4, 6, 31, 3,  5, 5, 42, 4, 71, 1, 26, 0, 77, 2, 35, 7, 78, 8, 29, 
    1, 72, 8, 76, 6, 32, 4, 37, 3, 34, 5, 37, 2, 28, 7, 54, 0, 83, 9, 71
  };
  const int r545[] = {
    10, 10, // Number of jobs and machines
    2, 47, 1, 78, 8, 78, 9, 14, 5, 46, 0, 71, 3, 13, 6, 31, 4, 54, 7, 97, 
    1, 75, 3, 66, 6, 54, 0, 40, 9, 58, 8, 56, 5, 12, 7, 77, 4,  7, 2, 62, 
    0, 60, 1, 78, 3, 58, 2, 54, 5, 51, 4, 44, 8, 41, 7, 15, 9,  3, 6, 77, 
    6, 87, 4, 78, 5, 72, 1, 57, 3, 30, 0, 83, 8,  2, 2, 18, 9, 38, 7, 83, 
    9, 83, 5, 39, 8, 47, 6, 33, 1, 70, 2, 50, 3, 68, 4, 66, 0, 90, 7, 13, 
    9, 56, 7, 13, 8, 33, 6, 38, 5,  4, 1, 72, 3, 28, 2, 41, 4, 41, 0, 47, 
    1, 37, 4, 63, 8, 51, 7, 31, 9,  9, 6, 17, 0, 42, 5, 81, 2, 68, 3, 25, 
    5, 38, 7, 71, 0, 51, 1, 85, 4, 74, 3, 64, 2, 33, 6, 99, 8, 75, 9, 81, 
    6, 37, 1, 31, 3, 99, 0, 29, 9, 59, 7, 32, 8, 98, 4, 40, 2, 42, 5, 65, 
    4,  2, 8, 41, 6,  2, 1, 37, 2, 98, 9,  8, 3, 90, 7, 94, 5, 58, 0, 31
  };
  const int r546[] = {
    10, 10, // Number of jobs and machines
    7, 82, 0,  3, 2, 86, 1, 36, 4, 87, 5, 23, 6, 73, 9, 94, 3, 50, 8, 63, 
    6, 85, 7, 31, 5, 58, 0, 72, 2, 94, 9, 94, 3, 62, 4, 79, 8, 50, 1,  7, 
    6, 29, 7, 46, 9, 99, 5,  2, 4, 37, 2, 37, 1, 60, 0, 88, 8, 54, 3, 87, 
    6, 28, 7,  9, 8, 20, 2, 47, 0, 98, 3, 38, 9, 86, 1, 92, 4, 69, 5, 38, 
    0, 82, 2, 59, 3, 16, 1, 66, 4, 42, 7, 29, 5, 25, 9, 84, 6, 78, 8, 28, 
    5, 23, 9, 10, 3,  8, 7, 97, 6, 59, 2, 56, 4, 30, 0, 63, 1, 45, 8, 68, 
    3, 20, 1, 46, 6, 89, 4, 32, 2, 34, 8, 71, 7, 30, 5, 58, 0, 97, 9, 67, 
    2, 20, 1, 87, 5, 93, 6, 28, 4, 32, 7, 99, 9, 68, 8, 71, 0, 51, 3, 14, 
    8, 81, 4, 89, 5, 96, 1, 31, 6,  3, 7, 56, 2,  2, 3, 34, 0, 89, 9, 71, 
    6, 58, 8, 24, 4, 10, 7, 76, 3, 18, 5, 33, 9, 18, 2, 90, 1, 70, 0,  3
  };
  const int r547[] = {
    10, 10, // Number of jobs and machines
    4, 91, 1, 40, 2, 10, 8, 50, 7, 18, 0, 39, 6, 61, 3, 60, 5, 60, 9, 78, 
    7, 31, 2, 57, 3, 46, 9, 78, 0, 24, 5, 98, 1, 87, 6, 12, 4, 73, 8, 55, 
    1, 78, 8, 11, 9, 51, 3, 32, 6, 18, 5, 70, 0, 57, 7, 47, 4,  8, 2, 50, 
    2, 33, 4, 44, 9, 45, 6, 17, 7, 61, 1, 97, 5, 53, 8, 83, 0, 14, 3, 65, 
    4,  7, 5, 62, 8, 71, 3,  1, 0,  9, 2, 41, 6, 80, 9, 89, 1, 13, 7, 70, 
    0, 46, 4, 39, 9, 58, 5, 72, 6, 92, 1, 56, 7, 57, 3, 42, 2, 36, 8, 62, 
    9, 42, 8, 39, 1,  6, 0, 81, 5, 14, 3, 49, 7, 84, 2, 39, 6, 34, 4, 99, 
    1, 64, 9, 79, 5, 76, 2, 68, 0, 81, 8, 70, 7, 73, 3, 79, 6, 11, 4, 98, 
    8,  9, 2, 64, 9,  4, 1, 35, 0, 98, 4, 95, 5, 71, 3, 99, 7, 71, 6, 50, 
    8, 45, 3, 90, 4, 24, 1, 22, 6, 28, 2, 65, 7, 38, 0, 72, 5, 27, 9, 51
  };
  const int r548[] = {
    10, 10, // Number of jobs and machines
    7, 84, 3, 49, 8, 53, 2, 46, 4, 10, 1, 41, 9, 53, 0, 40, 5, 52, 6, 59, 
    7, 30, 0, 41, 8, 89, 3, 96, 5, 11, 6, 97, 9, 11, 1, 36, 4, 63, 2, 79, 
    7, 43, 9, 10, 3, 26, 6, 87, 1, 99, 2, 33, 0, 15, 4, 40, 5, 71, 8, 64, 
    3,  3, 4, 29, 9, 25, 6, 30, 0, 38, 2, 71, 8, 19, 5, 87, 1, 52, 7, 54, 
    5, 75, 9, 76, 8, 43, 7, 80, 1, 35, 3, 47, 2, 12, 6, 36, 0, 67, 4, 70, 
    1, 87, 2,  9, 3, 69, 0, 50, 8, 76, 6, 33, 4, 38, 9, 75, 5, 96, 7, 97, 
    9, 88, 3, 94, 8, 26, 4, 51, 5, 75, 1, 82, 0, 19, 2, 75, 6, 50, 7, 77, 
    9, 31, 7, 77, 8, 71, 6, 25, 0, 44, 5, 35, 2, 62, 4,  6, 3, 56, 1, 39, 
    0, 73, 8, 82, 1, 74, 7, 99, 5, 67, 3,  9, 9, 13, 6, 98, 2, 71, 4, 25, 
    4, 41, 5, 78, 6, 27, 8, 22, 0, 98, 3, 17, 1, 21, 9, 64, 7, 16, 2, 65
  };
  const int r549[] = {
    10, 10, // Number of jobs and machines
    7, 78, 4, 13, 9, 21, 1, 10, 6, 10, 5, 71, 0, 14, 2, 69, 8, 27, 3, 81, 
    1, 75, 6, 77, 4, 63, 0, 60, 5,  9, 8, 42, 7, 51, 9, 35, 2, 93, 3, 13, 
    4, 11, 0, 10, 6, 98, 2, 20, 7, 84, 1, 68, 9, 55, 8, 24, 5, 59, 3, 79, 
    8, 16, 1, 92, 3, 18, 7, 79, 0, 80, 2, 54, 6,  5, 5,  9, 9, 47, 4, 22, 
    2, 54, 6, 41, 8, 26, 3,  7, 1, 54, 4, 70, 7, 62, 9, 82, 0, 81, 5, 27, 
    6, 17, 1, 20, 9, 78, 8, 91, 3, 14, 0, 53, 5, 59, 4, 61, 7, 11, 2,  7, 
    0, 95, 8, 95, 3, 34, 6, 32, 7, 18, 9, 66, 2, 57, 1, 87, 5, 58, 4,  7, 
    8, 86, 7, 55, 2, 55, 6, 80, 4, 93, 5, 68, 3, 50, 0, 91, 9, 42, 1, 79, 
    7, 34, 2, 58, 1, 43, 8, 33, 6, 76, 9, 84, 5, 75, 0, 96, 4, 52, 3, 98, 
    1, 58, 8,  9, 3, 75, 9,  4, 0, 26, 4, 91, 6, 59, 2, 30, 7, 88, 5, 29
  };
  const int r550[] = {
    10, 10, // Number of jobs and machines
    4, 49, 3, 61, 2, 71, 6,  1, 7, 11, 8, 17, 1, 80, 0, 11, 5, 25, 9, 40, 
    1, 33, 3, 71, 5, 29, 2, 19, 8, 89, 0, 63, 7, 79, 9, 88, 4, 79, 6, 87, 
    5, 96, 3, 19, 4, 23, 0, 24, 9,  7, 7, 65, 8, 46, 1, 80, 2, 25, 6, 99, 
    2,  6, 7, 31, 8,  2, 9, 84, 0, 74, 4,  4, 5, 35, 3, 72, 1, 39, 6, 83, 
    2, 76, 3, 11, 1, 84, 5, 60, 9, 89, 7, 30, 8, 58, 0, 20, 6, 57, 4, 89, 
    8, 34, 0,  7, 6, 34, 1, 33, 3, 64, 4, 68, 9, 91, 2, 86, 5, 46, 7, 53, 
    3, 83, 1, 56, 0,  7, 6, 87, 7, 36, 9, 65, 2, 48, 5, 79, 4, 91, 8, 91, 
    4, 43, 5, 99, 8, 53, 6,  6, 0, 10, 1, 23, 7, 16, 2, 67, 3, 37, 9, 20, 
    6, 81, 9, 40, 1, 93, 4, 34, 0, 95, 8,  4, 7, 83, 3, 73, 5, 58, 2, 61, 
    3, 39, 6, 46, 2, 95, 0, 83, 9, 75, 1, 67, 7, 61, 8,  3, 4, 88, 5, 48
  };
  const int r551[] = {
    10, 10, // Number of jobs and machines
    0, 71, 6, 28, 2, 27, 1, 25, 7, 63, 8,  5, 4, 49, 9, 91, 3, 97, 5, 35, 
    9, 38, 8, 92, 7, 89, 3, 40, 1,  1, 0, 11, 5, 59, 4, 69, 2, 27, 6, 28, 
    1, 41, 0, 72, 9, 76, 2,  9, 7, 62, 6, 94, 8, 53, 3, 32, 4, 56, 5, 36, 
    9, 83, 4,  5, 5, 41, 2, 16, 3, 46, 6, 90, 1, 23, 0,  1, 7,  6, 8, 73, 
    3, 84, 6, 41, 4, 54, 1, 85, 9,  8, 5, 17, 0, 47, 7, 62, 2, 63, 8, 33, 
    6, 58, 5, 33, 7, 61, 1, 87, 3, 54, 0, 97, 2, 67, 4, 80, 8, 75, 9, 80, 
    6, 25, 5, 11, 2, 14, 3, 53, 4, 57, 8, 59, 1, 73, 7, 23, 9, 26, 0, 64, 
    7, 36, 3,  4, 5, 14, 9, 56, 2, 74, 6, 32, 0,  9, 8, 62, 4, 61, 1, 37, 
    9, 15, 4, 68, 3,  8, 1, 97, 7, 23, 2, 54, 8,  8, 6,  3, 5, 86, 0, 78, 
    2, 97, 8, 82, 5, 84, 9, 69, 1, 24, 3, 55, 0, 59, 7, 58, 4, 32, 6, 10
  };
  const int r552[] = {
    10, 10, // Number of jobs and machines
    9, 58, 3, 52, 2, 83, 8, 44, 5, 69, 4, 73, 0, 52, 7,  9, 1, 70, 6, 37, 
    1, 54, 7, 52, 6, 67, 0, 39, 8, 67, 2, 58, 9, 98, 4, 52, 5, 12, 3,  8, 
    1, 44, 7, 57, 0, 47, 6, 89, 4, 24, 9, 15, 5, 77, 8, 74, 2, 29, 3, 25, 
    8, 41, 2,  5, 0, 49, 3, 61, 4, 20, 9, 75, 7, 55, 6, 48, 1, 44, 5, 96, 
    6,  4, 0, 86, 1, 31, 7, 20, 3, 50, 4, 55, 5, 15, 9,  7, 8, 37, 2, 10, 
    3, 96, 6, 75, 2, 87, 7,  9, 0, 87, 4, 65, 8, 82, 9, 44, 1, 36, 5, 86, 
    0, 56, 6, 75, 5, 90, 3, 42, 9, 47, 7, 21, 8, 96, 2, 70, 1, 52, 4, 55, 
    4, 64, 3, 66, 6, 20, 9, 61, 5, 75, 8, 74, 0, 71, 7, 63, 1, 50, 2, 47, 
    5, 40, 1, 57, 7,  8, 4, 38, 3, 97, 8, 49, 6, 77, 9, 52, 0, 99, 2, 34, 
    4,  2, 1, 35, 6, 79, 3, 88, 9, 85, 2, 25, 5, 90, 8, 23, 0, 69, 7, 66
  };
  const int r553[] = {
    10, 10, // Number of jobs and machines
    5, 72, 3, 47, 1,  4, 8, 82, 9, 97, 0, 77, 4,  5, 2, 50, 6, 40, 7, 70, 
    4, 28, 7, 79, 3, 24, 0, 95, 9,  6, 5, 74, 8, 37, 6, 94, 2, 59, 1, 44, 
    7, 17, 2, 49, 8, 97, 3, 74, 0, 16, 9, 96, 4,  3, 1, 70, 6,  4, 5, 96, 
    3, 75, 4, 28, 2, 56, 8, 21, 7, 60, 6, 75, 0, 89, 5,  9, 1, 70, 9,  9, 
    6, 95, 1, 94, 8, 93, 0, 59, 2, 77, 7, 51, 9, 64, 3, 88, 5, 50, 4, 12, 
    9,  1, 2,  5, 5, 27, 1, 75, 3, 34, 0, 57, 4, 61, 8, 10, 7, 88, 6, 54, 
    4, 37, 0,  8, 5, 96, 6, 74, 9,  4, 2, 72, 1, 42, 7, 77, 8, 96, 3, 58, 
    0, 63, 2, 44, 4, 79, 3,  3, 8, 43, 7, 30, 1, 21, 9, 22, 6, 39, 5,  6, 
    7, 34, 2, 14, 0, 43, 9, 83, 1,  8, 5, 95, 6, 56, 3, 62, 4, 94, 8, 68, 
    5, 68, 3, 76, 6,  2, 7, 24, 8, 52, 9, 75, 1, 86, 2,  6, 0, 41, 4, 72
  };
  const int r554[] = {
    10, 10, // Number of jobs and machines
    4, 63, 1, 40, 0, 62, 9, 67, 2, 89, 8, 50, 7, 47, 5, 18, 3, 51, 6, 71, 
    1, 64, 7, 64, 4, 91, 5, 70, 6, 82, 2, 48, 0, 61, 8, 56, 9, 32, 3, 20, 
    7, 16, 9, 41, 5, 65, 8, 10, 1, 64, 2, 15, 0, 87, 6, 76, 3,  9, 4, 77, 
    2, 58, 8, 56, 3,  5, 5, 64, 6, 59, 4, 74, 9, 91, 0, 93, 7, 40, 1, 79, 
    0, 30, 7, 41, 2, 90, 8,  4, 1, 26, 9, 54, 3, 21, 5, 38, 4, 74, 6, 20, 
    3, 13, 2, 22, 0, 75, 6, 84, 1, 36, 9, 99, 8, 12, 5, 34, 4, 76, 7, 43, 
    1, 38, 4, 44, 0, 12, 6, 34, 7, 63, 8, 22, 3, 49, 9, 56, 5, 12, 2, 12, 
    2, 71, 4, 29, 5, 37, 7, 94, 1, 25, 3, 18, 8, 36, 6, 23, 0, 36, 9, 10, 
    0, 60, 9,  2, 3, 29, 4, 83, 5, 89, 2, 45, 8, 11, 6, 94, 7, 81, 1, 75, 
    6, 91, 7, 57, 3, 73, 9, 14, 1, 69, 0,  5, 8, 63, 4, 48, 2, 18, 5, 63
  };
  const int r555[] = {
    10, 10, // Number of jobs and machines
    8, 66, 5, 90, 7, 65, 1, 95, 4, 48, 6, 64, 2, 55, 0, 53, 3, 10, 9, 43, 
    0, 29, 8, 26, 7, 85, 3, 89, 9,  8, 5, 56, 1, 51, 2, 67, 6, 96, 4, 37, 
    8, 70, 9, 78, 0, 44, 3, 47, 1, 95, 7, 52, 6, 61, 2, 63, 5,  6, 4, 57, 
    8, 33, 4,  2, 3, 56, 7,  4, 9, 80, 5, 76, 1, 14, 6, 23, 2,  5, 0, 79, 
    2, 25, 3, 78, 0, 72, 1, 48, 7, 22, 6, 75, 9, 12, 8, 67, 5, 32, 4, 23, 
    5, 94, 2, 39, 0, 10, 6, 63, 8, 50, 3,  2, 1, 58, 4, 66, 9, 56, 7, 31, 
    1, 18, 0, 78, 2, 75, 8, 22, 3, 12, 6, 67, 7, 89, 4, 73, 9, 25, 5, 56, 
    0, 22, 1, 16, 5, 73, 2, 72, 6,  3, 8, 40, 3, 23, 4,  6, 9, 54, 7, 74, 
    0, 66, 4, 47, 8, 90, 9, 15, 6, 55, 7, 97, 5, 34, 3, 24, 1, 11, 2, 73, 
    5, 59, 9, 52, 6, 25, 1, 89, 0, 84, 8, 69, 2, 85, 3,  8, 7, 53, 4,  8
  };
  const int r556[] = {
    10, 10, // Number of jobs and machines
    7, 66, 9, 21, 5, 87, 1, 14, 2, 70, 4, 80, 6, 57, 0, 53, 3, 36, 8, 74, 
    3, 17, 6,  8, 4, 84, 8, 52, 1, 22, 5, 23, 2, 21, 7, 83, 9, 14, 0, 36, 
    6, 66, 7, 71, 3, 46, 9, 60, 5, 24, 8, 64, 0, 58, 1, 96, 2, 96, 4, 97, 
    3,  2, 4, 62, 6, 79, 5, 80, 9, 14, 2, 67, 7, 33, 8, 70, 1, 31, 0, 73, 
    6, 56, 9, 91, 2, 46, 8,  6, 3,  8, 7, 28, 1, 99, 5, 42, 4, 35, 0, 66, 
    5, 33, 0, 85, 4, 41, 9, 11, 1, 36, 2, 42, 3, 91, 8, 22, 7,  5, 6, 38, 
    1, 37, 0, 89, 2,  1, 6,  2, 9, 79, 8, 46, 5, 71, 3, 23, 4, 68, 7, 36, 
    7, 56, 2, 52, 1, 33, 3, 56, 9, 97, 0, 64, 8, 73, 5, 98, 6, 11, 4, 65, 
    4, 42, 5, 42, 8, 95, 6, 54, 2, 30, 9, 80, 3, 39, 1, 59, 7, 67, 0, 10, 
    2, 19, 9, 77, 4, 88, 0, 82, 6,  8, 8, 77, 5, 17, 7, 89, 3, 26, 1, 64
  };
  const int r557[] = {
    10, 10, // Number of jobs and machines
    9, 57, 4, 86, 2, 72, 0, 53, 5, 87, 8, 75, 3, 38, 7, 33, 1, 98, 6, 27, 
    9, 25, 1, 70, 7, 53, 2, 68, 4, 10, 0, 25, 6, 77, 5, 52, 3, 37, 8, 21, 
    9, 23, 4,  7, 1, 14, 0, 46, 8, 62, 3, 97, 6, 69, 2, 50, 7,  7, 5,  1, 
    6, 96, 1,  3, 5, 82, 2, 64, 7,  5, 0, 76, 8, 36, 9, 23, 4, 31, 3, 41, 
    1, 30, 8, 56, 5, 79, 4, 87, 2, 46, 7, 26, 9, 59, 6, 47, 3,  5, 0, 32, 
    3, 77, 6, 30, 9, 65, 1, 39, 0,  5, 4, 70, 2, 85, 8, 84, 5, 14, 7, 77, 
    4, 38, 5, 68, 3, 95, 8, 44, 9, 46, 2, 89, 6, 53, 1, 80, 0, 72, 7, 81, 
    7, 99, 4, 45, 6, 29, 8, 48, 9, 91, 0, 59, 3, 74, 1, 49, 2, 77, 5, 50, 
    4, 65, 2,  5, 7, 26, 3, 83, 5, 30, 1, 70, 6, 81, 8, 26, 0, 31, 9, 75, 
    5, 47, 1, 62, 4, 11, 0, 45, 8, 47, 3, 62, 9, 23, 6, 71, 2, 70, 7, 40
  };
  const int r558[] = {
    10, 10, // Number of jobs and machines
    5, 13, 0, 64, 1, 45, 4, 75, 9, 10, 6, 27, 3, 24, 7, 29, 8, 52, 2, 38, 
    7, 70, 4, 16, 5, 26, 9,  2, 8, 70, 2, 15, 6, 40, 3, 55, 1, 73, 0, 36, 
    2,  5, 0, 66, 7, 10, 3, 15, 9,  2, 5, 77, 1, 27, 6, 93, 4, 54, 8, 34, 
    5, 70, 9, 56, 6,  8, 0, 73, 8, 37, 4, 88, 7, 83, 3, 33, 2, 87, 1, 34, 
    1, 61, 0,  3, 6,  6, 4, 70, 5, 92, 2, 56, 3, 57, 7, 41, 9, 84, 8, 58, 
    9, 30, 0, 68, 4,  6, 6, 87, 5,  8, 8, 53, 1, 77, 2, 11, 3, 49, 7, 77, 
    0, 60, 2, 27, 8,  7, 6, 39, 7,  9, 3, 15, 1, 88, 4,  9, 9, 63, 5, 27, 
    2,  5, 5, 25, 9, 48, 1, 12, 0, 29, 8, 46, 6, 91, 3, 77, 7, 63, 4, 33, 
    3, 58, 9, 84, 0, 97, 2, 79, 6, 47, 1, 12, 7, 37, 8, 71, 5, 94, 4, 63, 
    1, 85, 7, 76, 6, 89, 9, 28, 0,  6, 8, 60, 2, 81, 4, 97, 5, 21, 3, 98
  };
  const int r559[] = {
    10, 10, // Number of jobs and machines
    8, 17, 9, 76, 7, 63, 5, 41, 2, 93, 6, 77, 3, 23, 4, 91, 0, 65, 1, 41, 
    2, 97, 0,  8, 3,  3, 6, 96, 8, 86, 7, 71, 9, 96, 4, 74, 5, 32, 1,  4, 
    3, 46, 9, 98, 1, 31, 6, 16, 5, 87, 8, 37, 0, 22, 7, 37, 4, 95, 2, 65, 
    3, 84, 4, 73, 7, 50, 8, 57, 1, 27, 0, 16, 9, 79, 6,  9, 2, 85, 5, 40, 
    9, 48, 7, 98, 6,  6, 5, 99, 4, 86, 3, 83, 8, 30, 0, 88, 2, 99, 1, 45, 
    2, 15, 7, 40, 9, 17, 1, 55, 0, 70, 5, 58, 6, 99, 8, 33, 4, 70, 3, 51, 
    5, 31, 9, 84, 3, 32, 1, 87, 7, 97, 2,  8, 8, 43, 4, 10, 6, 90, 0, 48, 
    9, 48, 0, 58, 2, 28, 4, 75, 5, 64, 3, 41, 8, 59, 1, 51, 7, 61, 6, 85, 
    3, 66, 2, 33, 4,  3, 8, 29, 5, 31, 1, 51, 0, 84, 7, 99, 9, 63, 6, 62, 
    2, 59, 7, 51, 8, 22, 3, 43, 0, 23, 9, 69, 5, 26, 4,  2, 6, 86, 1, 24
  };
  const int r560[] = {
    10, 10, // Number of jobs and machines
    3, 70, 0, 87, 5,  8, 1, 54, 6, 78, 4, 84, 8,  8, 7, 26, 2, 35, 9, 55, 
    6, 84, 8, 58, 9, 67, 2, 33, 5, 88, 1, 87, 4, 35, 3, 86, 0, 46, 7, 39, 
    8, 74, 6, 23, 4, 79, 0, 59, 1, 66, 3, 70, 5, 43, 2, 64, 9, 26, 7, 53, 
    0,  9, 9, 25, 4, 87, 2, 28, 3, 48, 7, 98, 8, 21, 5, 92, 6, 92, 1, 42, 
    1, 93, 6, 73, 4, 39, 5, 31, 2, 19, 0, 58, 7,  7, 8,  4, 3, 33, 9,  9, 
    4, 35, 8,  7, 6, 87, 0, 81, 9,  7, 7, 90, 3, 42, 5, 99, 2, 87, 1, 55, 
    4, 68, 2, 69, 6, 72, 3, 56, 8, 94, 1, 48, 0, 97, 7, 70, 5, 83, 9, 88, 
    7, 76, 5, 22, 4, 92, 3, 16, 1, 99, 2, 39, 9, 96, 0, 37, 6, 21, 8,  8, 
    3, 46, 4, 60, 7, 46, 6, 87, 1, 91, 2, 22, 8, 19, 5, 44, 0, 33, 9, 87, 
    6, 95, 9, 42, 7, 99, 2,  2, 0, 92, 8, 10, 5, 53, 4,  1, 1,  2, 3, 80
  };
  const int r561[] = {
    10, 10, // Number of jobs and machines
    6, 21, 2, 83, 3, 84, 8,  9, 7, 88, 0, 24, 4, 84, 5, 49, 9, 63, 1, 21, 
    2, 76, 1, 61, 6, 76, 9, 31, 4, 18, 7, 42, 8, 74, 5, 72, 3, 62, 0,  2, 
    6,  5, 4, 43, 1, 59, 9, 56, 0, 63, 5, 14, 7, 68, 2, 23, 3, 67, 8, 33, 
    7, 92, 8, 13, 6, 48, 4, 69, 2, 97, 1, 32, 3, 63, 9, 84, 5, 68, 0,  6, 
    2, 43, 5, 29, 9, 84, 3, 44, 8, 14, 4, 84, 6, 40, 1, 58, 0, 50, 7, 19, 
    0, 15, 7, 49, 8, 93, 2, 61, 9, 53, 1, 20, 5, 25, 4, 93, 3, 67, 6, 62, 
    6, 30, 8,  5, 5, 51, 0, 23, 7, 21, 4, 93, 9, 99, 1, 74, 2, 94, 3, 84, 
    2,  7, 9, 39, 7, 24, 1, 10, 3,  1, 6, 94, 4, 60, 0, 39, 8, 47, 5, 28, 
    8, 25, 2, 17, 0, 61, 6, 32, 9, 89, 5, 15, 1, 39, 7, 97, 3, 66, 4, 45, 
    7, 15, 3,  8, 2, 74, 8, 33, 1, 65, 5,  5, 9, 47, 4, 15, 0, 66, 6, 29
  };
  const int r562[] = {
    10, 10, // Number of jobs and machines
    5, 61, 3, 33, 2, 38, 1, 84, 6, 39, 0, 59, 8, 44, 4, 39, 9, 96, 7, 78, 
    6, 90, 0, 73, 3, 74, 8, 63, 4, 23, 1, 70, 5, 82, 2, 75, 9, 25, 7, 30, 
    8, 10, 2, 39, 6, 86, 3, 51, 0, 30, 1, 26, 9, 76, 7, 96, 4, 62, 5, 38, 
    1, 22, 6, 10, 0, 66, 3, 11, 9, 63, 4, 61, 8, 58, 5, 60, 7, 52, 2,  3, 
    6, 96, 4, 90, 1, 10, 2, 90, 9,  6, 3, 66, 0, 59, 5, 73, 7, 18, 8, 57, 
    4, 39, 2, 79, 7, 49, 9,  3, 0, 27, 1,  9, 6, 46, 5, 55, 8, 63, 3, 39, 
    6, 19, 7, 57, 0, 21, 9, 79, 5, 81, 8, 85, 3, 67, 2, 12, 4, 98, 1, 60, 
    4, 79, 6, 75, 9, 36, 2, 86, 5, 91, 0, 90, 7,  6, 1, 13, 3, 93, 8, 33, 
    3, 28, 4, 54, 0, 53, 2, 83, 5, 61, 1, 14, 6, 47, 9, 61, 7,  9, 8, 32, 
    2, 75, 3, 28, 6, 24, 4, 83, 7, 48, 5, 13, 9,  9, 0, 73, 1, 74, 8, 96
  };
  const int r563[] = {
    10, 10, // Number of jobs and machines
    9, 48, 5, 57, 1, 41, 6, 48, 4, 79, 8, 59, 3,  9, 0, 83, 2,  2, 7, 76, 
    9, 72, 1, 93, 2, 86, 5, 42, 7, 70, 6, 46, 8, 15, 4, 94, 3,  4, 0, 80, 
    8, 85, 1, 33, 2, 77, 3, 61, 5, 34, 7, 48, 4, 69, 6, 10, 9, 38, 0,  5, 
    1, 85, 2, 44, 8, 55, 7, 99, 5, 32, 0, 23, 3, 70, 4, 46, 9, 13, 6, 50, 
    2, 58, 8, 99, 4, 76, 7, 58, 9, 90, 6, 60, 5, 96, 0, 31, 1, 44, 3, 33, 
    3, 39, 8, 50, 6, 16, 7, 94, 0, 31, 9, 74, 1, 53, 4, 49, 5, 76, 2, 56, 
    1, 52, 2, 89, 3, 69, 0, 60, 6, 37, 7, 92, 8, 43, 5, 21, 4, 83, 9, 35, 
    8, 89, 1, 96, 5, 37, 2, 78, 9, 80, 0, 23, 6, 53, 7, 76, 4, 39, 3,  9, 
    7, 70, 0, 89, 5, 40, 1, 78, 6, 15, 3, 82, 2, 60, 4, 78, 8,  1, 9, 13, 
    5, 96, 3, 98, 7, 71, 4, 79, 8, 49, 1, 88, 9, 20, 2, 31, 0, 80, 6, 14
  };
  const int r564[] = {
    10, 10, // Number of jobs and machines
    1, 61, 2, 27, 3, 13, 8, 98, 6, 45, 0, 59, 4, 15, 7, 30, 5, 18, 9, 79, 
    3, 84, 4, 19, 5, 54, 0,  3, 2,  3, 8, 23, 7, 36, 6, 39, 9,  6, 1, 41, 
    1, 26, 9, 25, 3, 98, 2, 38, 4,  8, 6, 50, 5, 32, 0, 17, 7, 73, 8,  8, 
    2, 64, 4, 46, 7, 57, 1, 80, 3, 99, 6, 14, 9, 55, 0, 82, 8, 81, 5, 75, 
    5, 18, 8,  4, 4, 34, 7, 59, 0, 98, 1, 49, 6, 67, 2, 92, 3, 69, 9, 49, 
    6, 65, 3, 41, 8, 52, 0, 44, 7, 97, 5,  8, 1, 33, 2, 84, 9, 67, 4, 81, 
    1, 40, 7,  3, 2, 41, 4, 36, 5, 42, 9, 51, 3, 12, 0,  9, 6, 21, 8, 86, 
    5, 58, 7, 27, 6, 77, 0, 82, 1, 89, 2, 12, 9, 27, 4,  1, 8, 43, 3, 37, 
    3, 49, 4, 15, 8, 91, 6,  9, 2, 14, 7, 39, 9, 17, 0, 52, 1, 67, 5, 69, 
    7, 56, 8, 56, 6, 41, 4, 32, 2, 52, 3, 78, 5,  9, 0, 15, 9, 18, 1, 29
  };
  const int r565[] = {
    10, 10, // Number of jobs and machines
    3, 21, 2, 12, 9, 82, 0, 73, 4,  4, 1, 61, 5, 21, 8,  7, 6, 85, 7, 22, 
    5, 21, 9, 73, 4, 83, 3, 32, 0, 15, 1, 93, 6, 26, 8, 54, 2,  7, 7, 42, 
    7, 87, 3, 49, 9, 61, 1, 85, 6,  9, 5, 59, 2, 58, 8,  7, 4, 80, 0, 32, 
    5, 64, 3, 51, 2, 59, 7, 73, 0, 19, 8, 84, 9, 33, 1, 63, 6, 10, 4, 41, 
    1, 94, 4, 92, 2, 11, 8, 11, 6, 84, 7, 69, 3, 63, 0, 11, 9, 11, 5, 85, 
    8, 94, 2, 54, 7, 67, 6, 51, 4, 38, 5,  1, 0, 97, 9, 15, 1,  2, 3, 34, 
    0, 85, 2, 73, 9, 85, 8, 35, 1, 73, 6, 54, 5, 55, 7, 23, 4, 50, 3, 98, 
    3, 65, 0, 27, 8, 80, 6, 53, 4,  5, 9,  1, 1, 57, 7, 33, 2, 38, 5, 14, 
    3, 90, 4, 23, 0, 57, 1, 39, 9, 15, 6, 98, 7, 30, 5, 73, 8, 77, 2, 39, 
    6, 52, 0, 77, 2, 25, 5, 32, 7, 70, 1, 63, 3,  8, 9, 91, 8, 81, 4,  7
  };
  const int r566[] = {
    10, 10, // Number of jobs and machines
    3, 84, 9, 68, 7, 50, 6, 25, 0, 67, 5,  1, 1, 73, 2, 88, 8, 58, 4, 69, 
    1, 49, 0, 94, 7, 37, 5, 53, 4, 88, 8, 77, 9, 70, 2, 85, 6, 61, 3, 14, 
    3, 18, 8, 11, 1, 55, 2, 19, 6, 42, 5, 93, 9,  1, 0, 64, 7, 19, 4,  1, 
    8, 63, 3, 31, 4, 89, 0,  9, 5, 30, 1, 59, 2, 96, 9, 93, 6, 92, 7, 54, 
    2, 88, 6,  4, 5, 99, 4, 40, 3, 63, 0, 25, 7, 48, 1, 40, 8, 10, 9, 92, 
    7, 32, 2, 39, 4, 70, 0, 74, 9, 76, 6, 54, 5, 94, 8, 35, 1, 81, 3, 18, 
    9,  9, 7, 15, 6, 72, 4, 45, 3, 58, 0, 71, 1,  3, 8, 96, 2, 77, 5, 87, 
    6,  9, 7, 11, 8, 30, 3,  8, 0, 39, 4, 34, 5, 27, 2, 91, 9,  5, 1, 86, 
    1, 13, 3, 22, 9, 22, 5, 14, 4, 49, 0, 87, 7, 34, 6, 95, 8, 41, 2, 48, 
    6,  8, 8, 12, 2, 32, 3, 18, 7, 59, 0, 49, 5, 14, 4, 96, 1, 48, 9, 78
  };
  const int r567[] = {
    10, 10, // Number of jobs and machines
    9, 24, 4, 15, 0, 40, 5, 24, 2, 67, 8, 48, 7, 20, 6, 55, 1, 94, 3, 12, 
    8, 76, 3, 22, 0,  9, 7,  2, 1, 43, 4, 41, 9,  8, 2, 50, 6, 51, 5, 36, 
    7, 27, 4, 40, 8, 13, 5, 51, 2, 85, 9, 76, 6, 55, 0, 12, 1, 62, 3, 18, 
    8, 70, 5, 78, 2, 29, 7, 90, 9, 32, 1, 73, 4, 24, 0, 73, 3, 75, 6, 87, 
    0, 29, 9, 88, 1, 43, 5, 66, 2, 23, 7, 13, 3, 44, 4, 36, 6, 28, 8, 89, 
    5, 78, 8, 88, 1, 19, 0, 10, 7, 47, 3, 74, 4, 17, 2, 10, 9, 11, 6, 53, 
    1, 61, 4,  1, 2, 94, 0,  8, 5, 63, 7, 76, 9, 24, 8, 89, 6, 88, 3, 74, 
    0, 19, 6, 26, 3, 50, 1, 67, 5, 68, 9, 32, 2, 96, 7, 81, 4,  4, 8, 46, 
    8, 47, 9, 37, 5, 61, 3, 16, 0, 34, 7, 61, 1, 23, 6, 45, 4, 76, 2, 94, 
    2, 99, 5,  7, 0, 92, 1, 21, 6,  3, 4, 59, 8, 24, 3, 57, 7, 99, 9, 53
  };
  const int r568[] = {
    10, 10, // Number of jobs and machines
    7, 47, 1, 70, 5,  3, 0, 92, 3, 41, 2, 72, 4,  7, 9, 27, 6, 65, 8, 46, 
    9, 16, 5, 50, 7, 15, 0, 49, 6,  2, 3, 12, 1, 43, 2, 13, 4, 44, 8, 84, 
    8, 54, 7, 45, 9, 25, 6, 64, 2, 12, 3, 95, 1, 34, 5, 23, 4, 88, 0, 51, 
    6, 25, 0, 15, 3, 51, 5, 30, 9, 62, 7, 51, 4, 85, 8, 43, 2,  9, 1, 44, 
    7, 79, 3, 68, 9, 74, 5, 64, 4, 57, 6, 36, 2, 83, 8, 45, 0, 91, 1, 21, 
    4, 57, 6, 12, 3, 41, 5, 85, 1, 86, 8, 50, 9,  1, 2, 98, 7, 15, 0,  9, 
    3, 13, 0, 68, 8, 89, 2, 68, 7, 22, 1, 65, 4, 31, 6, 39, 5, 46, 9, 15, 
    1, 59, 4, 72, 3, 66, 0, 60, 8, 70, 2, 18, 6, 52, 9, 75, 7, 85, 5,  2, 
    5,  1, 4, 58, 6, 13, 9, 33, 1, 84, 8, 39, 3, 91, 7, 41, 0, 91, 2, 55, 
    3,  4, 6,  7, 9, 89, 2, 60, 1, 59, 4, 61, 8, 53, 5, 62, 7, 93, 0,  1
  };
  const int r569[] = {
    10, 10, // Number of jobs and machines
    5, 22, 7, 15, 4, 66, 3, 30, 6, 24, 1,  4, 8, 55, 0, 64, 9, 78, 2,  9, 
    4, 92, 8, 71, 6, 64, 7, 19, 9, 59, 0, 97, 1, 39, 5, 51, 2, 76, 3, 92, 
    1, 81, 5, 87, 0, 41, 2, 95, 4, 40, 8, 77, 7, 82, 9, 73, 6, 34, 3, 93, 
    1, 83, 6, 26, 8, 42, 5, 57, 9, 27, 7, 79, 2, 56, 3, 12, 4, 93, 0, 52, 
    7, 64, 5,  6, 3, 64, 1, 47, 2, 35, 8, 50, 0,  8, 6, 39, 4, 72, 9,  9, 
    8,  8, 1, 32, 9, 95, 2, 81, 5, 90, 6, 76, 7, 46, 3, 17, 0, 46, 4, 46, 
    1, 47, 0, 60, 2, 47, 8, 47, 6, 47, 7, 62, 4, 29, 3, 54, 5, 10, 9,  7, 
    5, 69, 1,  6, 3, 75, 6, 48, 4,  9, 8, 61, 7, 35, 9, 75, 0, 72, 2, 58, 
    7, 68, 5, 85, 2, 12, 4, 22, 9, 95, 6, 73, 0, 78, 8, 63, 3, 86, 1, 91, 
    2, 66, 9,  5, 5, 91, 7, 49, 1, 96, 6, 37, 3,  9, 8, 76, 0, 34, 4, 41
  };
  const int r570[] = {
    10, 10, // Number of jobs and machines
    5, 85, 3, 80, 6, 42, 7, 62, 4, 26, 9, 66, 2, 16, 0, 54, 1, 73, 8, 34, 
    1, 37, 4, 25, 9, 27, 2, 90, 6,  4, 7, 82, 5, 33, 8, 98, 0, 23, 3, 56, 
    0,  6, 3, 22, 2, 92, 9, 24, 6, 63, 4,  5, 1, 40, 8, 35, 7,  9, 5, 55, 
    8, 73, 5, 58, 3, 73, 9, 17, 7,  8, 6, 68, 1, 60, 0,  4, 4, 25, 2, 28, 
    4, 86, 5, 88, 0, 91, 9, 89, 7, 55, 3, 84, 8, 87, 1, 24, 2, 57, 6, 25, 
    8, 39, 5, 63, 9, 79, 4, 69, 2, 13, 7, 32, 0, 26, 3, 55, 1, 12, 6, 34, 
    3, 35, 1, 93, 0, 53, 6, 27, 5, 25, 8, 83, 9, 29, 4, 84, 2, 65, 7, 60, 
    6, 94, 1, 12, 7, 85, 3, 21, 8, 11, 4, 24, 0, 93, 9, 76, 2, 11, 5,  6, 
    7, 42, 1, 16, 8, 29, 0, 56, 5, 23, 2, 56, 9, 42, 4,  8, 3, 60, 6, 95, 
    0, 82, 2, 56, 4, 50, 1, 74, 6, 26, 7, 18, 9, 24, 8, 99, 3, 73, 5, 68
  };
  const int r571[] = {
    10, 10, // Number of jobs and machines
    2, 39, 7,  9, 3, 59, 4, 16, 5, 39, 9, 91, 8, 54, 1, 59, 6, 29, 0, 31, 
    4, 36, 2, 29, 7, 72, 8, 56, 6, 83, 5, 24, 3, 33, 1, 74, 9,  3, 0, 14, 
    6,  1, 8, 17, 5, 17, 7,  7, 2, 37, 3, 37, 1,  5, 0, 72, 4,  5, 9, 33, 
    1,  9, 4, 86, 6, 99, 0, 38, 8,  9, 9, 21, 7, 92, 5, 31, 3, 55, 2, 15, 
    4, 11, 9, 10, 7, 68, 2, 61, 0, 91, 3, 27, 6, 95, 5, 34, 1, 77, 8, 13, 
    4, 92, 5, 47, 6, 81, 2,  8, 1, 38, 0, 34, 9, 73, 3, 55, 7, 84, 8, 68, 
    9, 76, 6, 61, 7, 80, 0, 80, 5, 80, 4, 53, 2,  8, 8, 15, 3, 23, 1, 30, 
    4, 96, 3, 85, 6, 32, 0, 46, 2, 16, 5, 39, 9, 87, 7, 96, 8, 26, 1, 11, 
    0, 63, 3, 47, 5, 44, 1, 15, 4, 26, 7, 73, 9, 67, 2, 85, 8, 21, 6, 15, 
    7, 66, 9, 82, 4, 94, 5, 75, 1, 70, 0, 15, 6, 82, 3,  3, 2, 26, 8, 97
  };
  const int r572[] = {
    10, 10, // Number of jobs and machines
    5, 92, 7, 40, 0, 99, 8, 97, 9, 13, 6, 80, 1, 85, 3, 74, 4, 29, 2, 28, 
    4, 47, 2, 11, 5, 16, 6, 85, 3, 95, 0,  6, 9, 67, 1, 48, 7, 46, 8, 52, 
    2, 39, 8, 62, 9, 23, 7, 98, 6, 41, 3, 10, 0, 61, 1, 63, 5, 19, 4, 78, 
    2, 36, 3, 73, 5, 71, 6, 22, 8, 93, 1, 66, 4, 36, 0, 18, 9,  3, 7, 78, 
    4, 18, 6, 97, 3, 90, 1, 82, 8, 69, 0, 35, 5, 71, 7, 46, 2, 37, 9, 83, 
    9, 81, 3,  1, 6, 42, 4, 98, 7, 26, 5, 90, 0, 30, 1, 89, 8, 71, 2, 20, 
    9, 87, 8, 25, 1, 57, 5, 80, 6, 18, 2, 71, 0, 86, 3, 71, 7, 88, 4,  5, 
    4, 49, 5,  8, 6,  1, 3, 98, 7, 93, 9, 94, 1, 32, 0, 54, 8, 24, 2,  3, 
    4, 52, 6, 41, 5,  8, 8, 49, 1, 91, 9, 10, 7, 19, 0, 72, 3, 16, 2, 54, 
    5, 27, 9, 90, 2, 68, 4, 16, 7, 89, 0, 76, 6, 71, 3, 23, 8, 75, 1, 53
  };
  const int r573[] = {
    10, 10, // Number of jobs and machines
    2, 97, 6, 27, 4, 11, 0, 77, 5,  3, 3, 75, 7,  5, 9, 52, 1, 15, 8,  7, 
    3, 59, 1, 32, 7, 46, 8, 77, 5, 79, 6, 17, 2, 63, 4, 20, 0, 52, 9, 72, 
    5,  8, 7, 17, 3, 51, 9, 70, 4, 18, 6, 57, 1, 40, 0, 79, 8, 78, 2, 49, 
    2, 11, 9, 45, 8,  4, 7, 27, 3, 28, 1, 10, 5, 73, 0,  4, 4,  3, 6, 99, 
    1, 80, 9, 73, 3, 99, 2, 42, 6, 34, 4, 69, 5,  2, 0, 91, 8, 69, 7, 55, 
    5, 54, 8, 57, 6, 21, 0, 20, 9, 94, 7, 40, 2, 29, 4,  7, 1, 92, 3,  5, 
    7, 88, 0, 80, 3, 47, 6, 38, 8, 65, 4, 13, 1, 21, 9, 23, 2, 25, 5, 42, 
    5, 10, 6, 23, 3, 21, 4, 39, 9, 55, 0, 40, 8, 24, 7, 96, 2, 48, 1, 20, 
    4, 98, 1, 90, 0,  2, 9, 31, 7, 87, 8, 47, 5, 32, 6, 57, 2, 34, 3, 20, 
    6, 86, 0,  6, 1, 98, 4, 52, 2, 18, 5, 66, 8, 86, 9, 75, 3, 85, 7, 63
  };
  const int r574[] = {
    10, 10, // Number of jobs and machines
    1, 37, 7, 95, 6, 69, 4, 68, 0, 93, 9, 99, 8, 62, 3, 79, 5, 57, 2, 61, 
    8, 12, 2, 75, 9, 55, 7, 53, 5, 57, 4, 73, 1, 93, 6, 13, 3, 34, 0, 38, 
    6, 17, 0, 27, 9, 43, 4, 64, 3, 59, 7, 96, 5,  2, 8,  5, 1, 67, 2, 70, 
    4, 84, 7, 34, 2, 44, 1, 50, 5, 38, 8, 56, 0, 42, 6, 30, 9, 91, 3, 51, 
    9, 83, 2, 11, 3, 86, 6, 59, 8, 38, 1, 35, 5, 88, 0, 35, 4, 99, 7, 30, 
    2, 14, 3, 65, 1, 21, 9,  5, 4, 91, 0, 91, 6,  6, 8, 75, 5, 65, 7, 40, 
    1, 87, 7, 69, 4, 74, 6, 58, 2, 63, 8, 74, 9, 74, 3, 43, 5, 41, 0, 15, 
    2,  6, 8, 68, 7, 28, 5, 40, 4, 21, 1, 76, 0, 84, 3, 75, 9, 50, 6, 22, 
    6, 18, 7, 69, 5, 41, 3, 40, 8, 87, 9, 56, 0,  8, 4, 40, 2, 61, 1, 69, 
    0, 34, 4, 50, 5,  6, 2, 81, 9, 30, 6, 10, 1, 64, 7, 95, 3, 99, 8, 97
  };
  const int r575[] = {
    10, 10, // Number of jobs and machines
    8, 87, 6, 70, 1, 81, 9,  4, 2, 35, 7, 45, 5, 55, 4, 37, 0, 33, 3,  6, 
    2, 93, 0,  3, 8, 76, 4, 86, 9, 73, 3, 84, 6, 36, 1, 35, 7, 19, 5, 59, 
    2, 28, 7, 14, 1, 39, 6, 23, 0, 70, 5, 19, 9,  6, 4, 54, 8,  6, 3, 52, 
    5, 35, 9, 84, 0, 68, 3, 73, 6, 44, 4, 58, 2, 11, 7, 55, 8, 62, 1, 92, 
    3, 44, 9, 74, 0, 55, 5, 17, 7, 44, 1, 37, 4,  9, 8, 87, 2, 91, 6, 12, 
    9, 19, 2, 27, 4, 17, 6, 71, 3, 21, 8, 39, 0, 18, 1, 53, 5, 55, 7, 83, 
    1, 71, 9, 76, 7, 52, 8, 74, 0, 31, 5, 72, 2, 73, 6, 45, 3, 70, 4, 82, 
    3, 98, 5, 57, 2, 73, 9, 13, 6, 49, 4, 20, 8, 59, 0, 83, 7, 22, 1, 83, 
    3, 65, 9, 16, 8, 17, 5, 53, 7, 36, 4, 79, 1, 95, 2, 39, 0, 84, 6, 12, 
    5, 46, 3, 95, 6, 85, 1,  7, 9, 21, 7, 26, 0, 22, 8, 17, 2, 97, 4, 49
  };
  const int r576[] = {
    10, 10, // Number of jobs and machines
    1,  9, 7, 49, 6, 41, 9, 47, 4, 80, 3,  1, 5, 38, 8, 93, 2, 95, 0, 84, 
    4, 19, 1,  2, 3, 56, 7, 30, 0, 40, 6, 51, 9, 14, 5, 17, 2, 47, 8, 55, 
    3, 57, 7, 88, 5, 23, 8, 81, 1, 95, 0, 84, 6, 67, 4, 58, 2, 77, 9, 66, 
    1, 30, 3, 50, 7, 39, 8, 48, 5,  3, 9, 30, 0, 24, 6, 80, 4, 92, 2, 56, 
    4, 82, 2, 88, 7, 86, 0, 61, 5, 23, 8, 69, 9, 36, 3, 65, 6, 33, 1, 71, 
    1, 53, 9, 85, 7, 50, 6, 88, 2,  5, 8, 65, 4, 12, 0, 10, 5, 84, 3, 93, 
    0,  1, 6, 41, 7, 49, 1, 76, 2, 39, 4, 25, 9, 32, 8, 96, 3, 85, 5, 67, 
    4, 43, 9, 58, 8,  6, 1, 86, 7,  9, 6, 37, 3,  5, 0, 68, 2, 92, 5, 51, 
    6, 16, 8, 51, 5, 70, 4, 66, 0, 63, 7, 53, 9, 72, 1,  6, 3, 62, 2, 47, 
    0,  8, 1, 76, 6, 22, 2, 93, 9, 84, 3, 83, 7, 20, 5, 95, 4,  3, 8, 50
  };
  const int r577[] = {
    10, 10, // Number of jobs and machines
    7, 31, 2, 12, 8,  4, 3, 11, 6, 70, 5,  3, 9, 64, 1,  6, 0, 91, 4, 82, 
    3, 56, 8, 48, 2, 49, 6, 39, 4, 28, 1, 32, 5, 40, 0, 33, 9, 95, 7, 28, 
    8, 77, 9, 93, 5, 90, 4, 50, 3, 56, 1,  5, 0, 22, 2, 59, 6, 33, 7, 90, 
    0, 13, 3, 14, 1, 17, 7, 87, 9,  2, 6, 82, 2, 12, 4, 97, 5, 97, 8, 61, 
    8, 93, 5,  4, 0, 15, 7, 30, 4, 92, 6, 44, 1, 50, 9, 76, 2, 32, 3, 59, 
    7, 81, 9, 17, 3, 72, 1, 96, 2, 40, 5, 29, 6, 37, 8, 26, 4, 53, 0, 95, 
    5, 37, 7, 59, 0, 49, 1, 81, 4, 17, 3, 48, 2, 37, 8, 67, 9, 95, 6,  3, 
    2, 19, 1, 63, 5, 83, 8, 79, 3, 50, 7, 42, 9, 91, 6, 33, 4,  2, 0,  2, 
    6, 25, 0, 85, 1, 20, 3,  6, 2, 32, 9, 25, 7, 41, 4, 60, 5, 79, 8, 97, 
    0, 30, 5, 16, 1, 64, 2, 29, 3, 34, 7, 95, 9, 94, 6,  5, 4, 54, 8, 11
  };
  const int r578[] = {
    10, 10, // Number of jobs and machines
    0, 26, 2, 13, 4, 63, 5, 83, 1, 85, 9, 98, 7, 73, 8, 70, 3, 46, 6, 65, 
    8, 21, 3, 49, 5, 42, 4, 77, 6, 31, 7,  1, 1, 64, 0, 96, 9, 69, 2, 71, 
    0, 43, 7,  3, 4, 35, 1, 57, 3, 32, 9, 81, 8, 35, 6, 90, 2, 54, 5, 91, 
    9, 45, 1, 69, 8, 14, 5, 23, 2, 12, 3, 23, 4, 99, 6, 84, 7, 58, 0, 26, 
    8, 72, 0, 49, 9,  4, 6, 23, 3,  8, 2, 73, 7, 37, 4,  9, 5, 68, 1, 32, 
    8, 75, 7, 20, 0, 60, 1, 90, 9, 69, 4, 48, 6, 19, 2, 50, 3, 50, 5, 49, 
    6, 84, 5, 11, 1, 86, 7, 14, 0,  2, 4, 12, 2, 90, 8, 50, 3, 78, 9, 52, 
    4, 10, 6, 12, 5, 86, 7, 24, 8,  4, 9, 36, 1, 82, 3, 98, 2, 41, 0, 88, 
    1, 82, 2,  9, 6, 29, 0, 39, 5, 96, 4, 78, 8, 16, 3,  7, 7, 34, 9, 96, 
    6, 70, 1, 24, 9, 64, 8, 93, 0, 31, 4,  5, 3, 13, 2, 57, 5, 66, 7, 36
  };
  const int r579[] = {
    10, 10, // Number of jobs and machines
    0, 12, 6, 17, 4, 24, 2, 49, 3,  6, 9,  7, 1, 33, 7, 77, 5, 63, 8, 86, 
    7, 49, 6, 17, 1, 36, 4, 81, 3, 71, 2,  3, 0, 53, 8, 69, 5, 17, 9, 63, 
    4, 34, 1, 88, 0, 36, 2, 95, 8, 37, 7, 99, 5, 80, 6, 28, 3,  3, 9, 90, 
    8, 71, 7,  6, 4, 91, 5, 63, 1, 20, 3, 87, 2, 81, 6, 55, 0, 64, 9, 78, 
    2, 53, 6, 52, 3, 72, 7,  3, 5, 45, 1, 85, 9,  5, 8, 70, 0,  8, 4, 63, 
    0, 66, 4, 32, 9, 45, 6, 40, 1, 41, 5, 37, 8, 85, 3, 77, 2, 44, 7, 83, 
    9, 71, 6, 65, 1, 44, 5, 86, 7, 50, 3, 42, 0, 41, 2, 90, 8, 51, 4, 73, 
    3, 57, 0, 89, 5, 95, 8, 48, 6, 44, 7, 93, 4, 32, 2, 36, 1, 39, 9, 87, 
    7, 11, 4, 74, 6, 87, 2, 32, 8, 78, 5, 87, 1, 31, 3, 95, 9, 23, 0,  8, 
    7, 33, 3, 86, 5, 40, 1, 75, 8, 16, 4, 11, 2,  6, 0, 45, 6, 97, 9, 12
  };
  const int r580[] = {
    10, 10, // Number of jobs and machines
    2, 94, 6, 73, 8, 77, 3, 89, 7, 74, 9, 42, 0, 83, 5, 18, 1, 75, 4, 20, 
    6, 99, 8, 32, 0, 39, 2, 73, 9, 62, 3, 60, 5, 51, 4, 32, 1, 29, 7, 32, 
    5, 97, 2,  2, 6, 30, 3, 50, 7, 79, 4,  8, 8, 59, 0, 99, 1,  4, 9, 52, 
    8, 51, 3, 66, 1, 33, 2, 23, 4, 72, 9, 75, 7, 43, 5, 78, 0, 97, 6, 15, 
    9, 76, 0, 34, 1, 45, 8, 86, 3,  3, 5, 75, 4, 90, 6, 59, 2, 95, 7, 34, 
    2, 42, 3, 48, 9, 74, 7, 86, 5, 60, 0, 98, 6, 92, 8, 21, 4,  8, 1, 81, 
    8, 76, 5, 14, 4,  6, 9, 91, 6, 24, 0, 88, 2, 88, 3,  1, 1, 91, 7, 24, 
    3, 52, 0, 97, 9, 64, 7, 22, 1,  9, 8, 31, 2, 50, 5, 90, 6, 37, 4, 89, 
    2, 52, 6,  2, 7, 47, 5, 21, 1, 48, 9, 45, 3, 99, 8,  3, 4,  5, 0,  7, 
    3, 17, 6, 11, 0, 33, 4, 73, 5,  5, 9, 64, 1,  6, 8, 45, 7, 38, 2, 12
  };
  const int r581[] = {
    10, 10, // Number of jobs and machines
    5, 84, 3, 28, 0, 98, 4, 84, 8, 46, 7, 93, 6, 87, 1, 48, 9, 35, 2, 50, 
    5, 78, 7, 51, 6, 68, 3, 86, 2,  4, 8, 78, 0, 81, 9, 73, 1, 34, 4, 72, 
    5, 69, 8, 69, 2, 94, 6, 54, 4,  5, 7, 45, 9, 34, 3, 14, 0, 68, 1, 27, 
    9,  7, 7, 57, 8, 73, 5, 22, 4, 44, 0, 52, 6, 43, 1, 82, 2, 57, 3, 40, 
    3, 63, 6, 59, 5,  4, 1, 31, 9,  4, 7, 61, 4, 42, 8, 37, 2, 18, 0, 40, 
    5, 22, 3, 16, 8, 41, 9, 75, 0, 72, 7, 95, 2, 90, 4, 60, 6, 10, 1, 36, 
    5, 73, 7,  9, 2, 64, 3, 54, 9, 67, 4, 80, 8, 69, 0, 37, 1, 23, 6, 92, 
    1, 65, 4, 23, 8, 27, 2, 31, 6, 50, 7, 25, 0, 20, 3, 44, 5, 26, 9, 19, 
    4, 69, 9, 17, 0, 61, 3, 81, 1, 58, 6, 50, 2, 35, 8, 24, 7, 54, 5, 43, 
    7, 70, 1,  6, 3, 63, 2, 82, 6, 35, 9,  5, 0, 87, 4, 31, 8, 71, 5, 86
  };
  const int r582[] = {
    10, 10, // Number of jobs and machines
    7, 97, 6,  6, 9, 54, 8, 35, 4, 84, 0, 27, 1,  1, 2, 93, 3, 19, 5, 69, 
    2,  6, 3, 42, 5,  6, 9, 18, 4, 43, 0, 60, 6, 96, 8, 89, 7, 85, 1, 90, 
    8,  7, 9, 94, 1, 18, 5, 13, 2, 69, 6, 60, 4, 98, 0, 44, 3, 45, 7,  8, 
    2, 78, 1,  8, 6, 14, 0, 96, 7, 92, 8, 42, 4, 10, 5, 12, 9, 92, 3, 94, 
    9, 36, 3, 76, 5, 17, 7, 42, 6, 85, 4,  4, 8, 19, 0, 96, 2, 23, 1, 82, 
    3, 68, 8, 14, 1, 63, 6, 57, 2, 54, 0, 65, 4, 80, 9, 46, 7, 58, 5, 31, 
    8, 66, 5, 20, 7, 23, 4, 21, 9, 55, 3, 96, 6, 94, 0, 70, 1, 48, 2, 64, 
    7, 29, 1, 28, 4, 98, 5, 43, 0, 60, 2, 16, 9, 53, 8, 52, 6, 35, 3, 41, 
    0, 60, 8,  4, 9, 32, 4, 84, 7, 18, 6, 43, 2, 55, 5, 66, 3, 56, 1, 50, 
    4, 69, 9, 70, 0, 35, 8,  4, 6, 67, 1, 44, 5, 43, 3, 30, 7, 81, 2, 68
  };
  const int r583[] = {
    10, 10, // Number of jobs and machines
    1, 49, 9, 20, 5, 23, 8, 95, 7, 62, 3, 71, 2, 99, 0, 69, 6, 35, 4,  3, 
    3, 20, 0, 66, 4, 57, 6, 43, 7, 68, 1, 60, 9, 55, 8, 21, 2, 64, 5, 34, 
    1, 83, 2, 96, 6, 59, 7, 50, 9, 52, 4, 26, 0, 83, 8, 97, 3, 45, 5, 82, 
    5,  6, 1, 38, 2,  7, 6, 36, 8, 94, 9, 25, 0,  5, 3, 12, 4, 18, 7, 69, 
    6, 15, 5, 63, 1, 71, 0, 75, 3, 15, 9, 10, 7, 53, 2, 75, 8, 49, 4, 28, 
    8, 42, 2, 15, 1, 55, 0, 93, 5, 94, 9, 50, 6, 44, 7, 46, 4, 91, 3, 43, 
    0, 40, 7, 92, 4, 10, 1, 47, 2, 65, 9, 82, 8, 41, 5, 90, 6, 28, 3, 60, 
    0, 28, 8,  9, 1, 93, 9, 57, 3, 99, 6, 72, 5, 42, 7, 45, 2, 64, 4, 39, 
    5, 28, 8,  9, 3, 96, 1,  7, 2, 12, 0, 54, 4, 39, 7, 10, 6, 86, 9, 52, 
    6, 31, 3, 45, 1, 46, 7, 38, 9, 27, 4, 25, 5,  1, 2, 50, 0, 68, 8, 58
  };
  const int r584[] = {
    10, 10, // Number of jobs and machines
    5, 12, 4, 53, 9, 64, 1, 64, 3,  2, 7, 39, 8, 82, 2, 48, 6, 30, 0, 50, 
    8, 90, 6, 53, 3, 29, 0, 29, 1, 61, 5, 70, 4, 53, 2, 78, 7, 19, 9, 87, 
    7, 86, 0, 10, 1, 77, 2, 67, 9, 79, 3, 20, 5, 49, 6, 78, 8, 77, 4, 31, 
    9, 79, 1, 71, 2, 91, 0, 79, 8, 73, 4, 16, 5,  8, 3, 16, 7, 31, 6,  8, 
    2, 94, 8, 70, 6, 18, 3,  2, 4, 83, 9, 64, 0, 37, 5, 76, 1, 22, 7, 94, 
    0, 91, 3, 81, 9, 93, 1, 49, 2, 24, 6, 28, 4, 68, 8, 57, 5, 87, 7, 68, 
    5, 57, 7, 82, 3, 49, 9, 70, 0, 98, 1, 32, 6, 98, 4, 35, 2, 12, 8, 39, 
    7, 78, 8, 58, 4, 95, 0,  2, 9, 65, 5, 24, 3, 30, 2, 31, 1, 52, 6, 40, 
    9, 42, 3, 71, 7, 68, 6, 70, 8, 77, 2,  5, 5, 58, 0, 38, 1, 91, 4, 90, 
    3, 71, 9, 86, 6, 73, 7, 15, 4, 72, 8,  4, 5, 89, 0, 93, 1, 15, 2, 72
  };
  const int r585[] = {
    10, 10, // Number of jobs and machines
    9, 64, 8, 20, 4, 96, 2, 24, 7, 80, 3, 41, 6, 44, 0, 21, 5, 64, 1, 43, 
    2, 17, 8,  5, 0, 89, 9, 74, 3, 63, 4, 40, 1, 92, 6, 42, 5, 72, 7, 45, 
    7, 50, 4,  2, 2, 23, 3, 87, 1, 91, 9, 60, 6, 70, 8, 25, 5, 58, 0, 22, 
    6, 29, 7, 80, 2,  5, 3, 78, 5,  7, 0, 91, 4,  2, 1, 27, 9, 11, 8,  2, 
    9, 27, 8, 98, 5, 12, 1, 56, 2, 11, 0, 76, 7, 64, 3, 14, 4, 23, 6, 65, 
    7, 79, 0, 83, 9, 98, 4, 57, 8, 44, 2, 38, 5, 66, 3, 38, 1, 64, 6, 86, 
    5, 49, 7, 11, 6, 74, 8, 76, 3, 57, 2,  4, 0,  8, 4, 37, 9, 29, 1, 87, 
    2, 44, 7, 42, 3, 54, 8, 52, 1, 33, 5, 25, 0, 64, 9, 23, 4, 13, 6, 47, 
    1,  8, 4, 28, 7, 94, 9, 65, 8, 29, 0, 43, 2, 71, 6, 69, 3, 65, 5, 29, 
    2, 92, 7,  9, 5, 14, 6, 58, 9, 46, 1, 28, 4, 59, 3, 90, 8,  3, 0, 88
  };
  const int r586[] = {
    10, 10, // Number of jobs and machines
    3, 13, 1, 75, 8, 55, 7, 50, 2, 66, 5, 22, 9, 20, 4, 68, 6, 97, 0, 18, 
    7, 12, 8, 85, 9, 17, 2, 63, 3, 87, 4, 20, 1, 29, 6, 75, 5, 80, 0, 21, 
    1, 82, 0, 16, 7, 64, 5, 19, 6, 39, 9, 96, 2, 11, 4, 65, 3, 71, 8, 13, 
    0, 39, 8, 92, 1, 98, 9, 67, 2, 26, 4, 24, 3, 64, 5, 44, 7, 88, 6, 50, 
    9, 20, 5,  3, 0, 34, 6, 88, 1, 54, 2, 28, 8, 66, 7, 88, 4, 28, 3, 76, 
    8, 83, 6, 44, 2, 83, 3, 34, 0,  7, 7, 29, 4, 17, 1,  5, 9, 80, 5, 19, 
    3, 60, 4, 35, 2, 73, 5, 48, 1, 88, 8, 80, 9, 13, 0, 52, 7,  9, 6,  7, 
    7, 21, 3, 17, 2, 67, 8, 53, 6, 68, 4, 35, 9, 79, 1, 49, 0, 21, 5, 27, 
    0, 83, 1,  6, 9, 93, 3, 19, 2, 89, 7, 29, 8, 53, 6, 27, 5, 46, 4, 81, 
    9, 89, 8, 85, 2, 83, 7, 93, 5, 10, 3, 95, 1, 70, 6, 88, 0, 30, 4, 18
  };
  const int r587[] = {
    10, 10, // Number of jobs and machines
    1, 28, 5, 10, 8, 39, 2, 53, 6, 31, 4, 74, 9,  3, 0, 87, 7, 98, 3,  9, 
    8, 56, 5, 38, 3, 48, 1, 23, 4, 67, 7, 33, 6, 83, 0, 82, 9, 80, 2, 13, 
    7, 70, 1,  2, 5, 86, 0, 57, 4, 65, 3,  2, 6, 35, 9, 15, 8, 44, 2, 25, 
    5, 56, 3, 39, 9, 80, 8, 14, 6, 74, 2, 46, 7, 32, 1,  9, 4, 98, 0, 96, 
    7, 91, 8,  2, 6, 77, 5, 58, 0, 57, 3, 84, 4, 50, 2, 40, 1, 42, 9, 48, 
    9,  7, 1, 16, 3,  3, 8, 89, 6, 16, 7, 24, 0, 87, 2, 78, 5, 79, 4, 25, 
    7, 48, 5, 95, 4, 92, 8, 72, 2, 64, 9, 57, 0, 19, 3, 21, 6, 91, 1, 16, 
    3, 13, 4, 50, 8, 48, 0, 65, 7, 84, 2, 34, 6, 46, 9,  5, 5, 96, 1, 12, 
    9, 89, 8, 33, 6, 51, 2, 91, 0, 66, 3, 38, 4, 88, 5, 77, 7, 65, 1, 46, 
    1, 16, 7, 89, 4,  9, 0, 95, 5, 34, 3, 74, 9, 71, 2, 80, 8, 59, 6, 65
  };
  const int r588[] = {
    10, 10, // Number of jobs and machines
    4, 93, 7, 69, 8, 28, 3, 50, 2, 94, 9, 56, 0,  7, 1, 78, 6, 55, 5, 16, 
    1, 10, 9, 78, 6, 40, 2, 73, 4, 23, 0, 92, 8, 22, 5, 81, 3, 56, 7, 74, 
    2, 67, 0, 84, 1, 39, 5,  9, 6, 45, 7, 35, 9, 24, 4, 11, 3, 14, 8, 49, 
    9, 78, 4, 37, 2, 30, 0, 55, 5, 42, 1,  9, 7, 44, 6, 61, 3,  9, 8, 41, 
    8, 82, 6, 57, 9, 54, 2, 58, 0, 15, 7, 46, 5, 65, 3, 54, 4, 43, 1, 81, 
    5, 95, 1, 82, 2, 49, 0, 44, 3, 76, 6, 92, 7, 19, 9, 15, 8, 38, 4,  4, 
    3,  2, 4, 54, 8, 48, 0, 80, 1, 67, 5, 10, 6, 59, 9, 77, 2, 78, 7, 54, 
    4, 21, 0, 75, 1, 48, 6, 44, 9, 29, 5, 86, 7, 52, 3,  2, 8,  2, 2,  1, 
    0, 95, 8, 53, 6, 53, 4, 43, 1, 13, 5, 72, 3, 44, 2, 38, 7, 40, 9, 50, 
    0, 55, 4,  3, 7, 20, 2, 93, 1, 65, 8, 35, 9, 27, 6, 78, 5, 38, 3, 46
  };
  const int r589[] = {
    10, 10, // Number of jobs and machines
    5, 95, 6, 26, 1, 13, 3, 54, 9, 50, 4, 33, 7, 76, 8,  9, 0, 70, 2, 82, 
    3, 67, 7, 87, 4, 21, 8, 63, 1, 37, 6,  1, 5, 17, 9, 49, 0,  6, 2, 90, 
    4, 98, 7, 17, 1, 36, 9, 22, 8, 20, 2, 25, 5,  4, 0, 14, 3, 83, 6, 41, 
    6, 15, 1, 51, 8, 37, 0, 16, 9, 54, 2, 63, 4, 18, 3, 49, 5, 22, 7, 21, 
    5, 79, 6, 52, 2, 19, 8, 68, 7, 12, 3, 56, 0, 19, 9, 42, 1, 24, 4, 77, 
    0, 70, 6, 90, 3, 47, 5, 91, 1, 30, 4, 88, 9, 71, 2, 54, 8, 75, 7, 96, 
    3,  3, 7, 64, 2,  1, 5,  1, 8, 93, 9, 83, 1, 43, 0, 51, 6, 66, 4, 53, 
    9, 83, 4, 34, 0,  3, 6, 15, 7, 45, 5, 19, 3, 97, 2, 95, 1, 27, 8, 76, 
    9, 74, 0, 60, 7, 80, 5, 96, 6, 66, 4, 44, 2, 97, 8, 75, 3, 15, 1, 18, 
    5, 80, 6,  5, 7, 51, 8, 95, 4, 87, 2, 19, 1, 36, 0, 58, 9, 12, 3, 44
  };
  const int r590[] = {
    10, 10, // Number of jobs and machines
    9, 49, 8, 34, 5, 18, 2, 26, 3, 65, 0,  8, 1, 81, 6, 52, 7, 50, 4, 97, 
    8, 26, 5, 68, 4, 70, 9, 66, 3, 78, 1, 24, 7, 59, 0, 12, 2, 39, 6, 13, 
    3, 12, 8, 21, 9,  5, 5, 17, 7, 15, 4, 11, 2, 97, 6, 45, 1, 64, 0, 45, 
    3, 63, 9, 94, 1, 99, 4, 53, 6, 34, 2, 51, 5, 40, 8,  9, 0, 18, 7, 89, 
    0, 96, 4, 86, 9, 66, 5, 94, 6, 80, 7, 83, 2, 62, 1, 72, 3, 57, 8, 66, 
    6, 72, 1, 90, 8,  7, 4, 69, 2, 30, 5, 87, 7, 80, 9, 31, 0, 72, 3, 60, 
    0, 75, 4,  3, 3, 16, 8, 91, 1, 76, 9, 53, 7, 43, 5, 58, 6, 83, 2, 92, 
    9, 10, 8, 39, 6, 54, 5, 63, 1, 94, 7, 17, 3, 37, 4,  8, 0, 52, 2,  1, 
    1, 22, 5, 26, 9, 40, 2, 12, 4, 11, 8, 46, 6, 93, 7, 80, 3, 88, 0, 87, 
    4, 75, 6, 52, 7, 35, 3, 23, 8, 22, 1,  7, 5, 66, 0, 71, 9, 96, 2, 41
  };
  const int r591[] = {
    10, 10, // Number of jobs and machines
    7, 26, 9, 19, 1, 66, 6, 39, 8, 73, 0, 84, 3, 38, 2, 58, 5, 69, 4, 79, 
    2, 53, 7, 88, 1, 73, 0, 12, 5, 73, 4, 84, 3, 61, 8, 15, 9, 44, 6, 92, 
    7, 95, 9, 25, 2, 40, 8, 45, 0,  6, 1, 64, 6, 21, 3, 50, 4, 12, 5, 58, 
    9, 71, 2, 69, 7,  9, 0, 78, 1, 57, 5, 41, 4, 93, 6, 11, 8, 16, 3, 39, 
    3, 50, 9,  8, 2, 86, 0,  3, 4, 71, 1, 66, 7,  9, 8, 76, 5, 92, 6, 36, 
    8, 93, 6, 56, 2, 59, 7, 95, 0, 85, 9, 15, 3, 32, 5,  6, 4, 78, 1, 80, 
    2, 18, 3, 18, 0, 81, 6, 94, 5, 77, 8, 73, 1, 10, 4, 23, 7, 94, 9, 60, 
    9, 13, 4,  7, 8, 12, 7, 47, 1,  9, 3, 17, 0, 42, 2, 86, 5, 99, 6, 82, 
    7, 72, 4, 74, 3, 73, 5, 84, 0, 67, 1, 16, 6, 73, 9, 14, 8, 12, 2, 23, 
    6, 15, 4, 44, 9, 53, 2, 30, 5, 38, 3, 69, 0, 38, 7, 70, 1, 20, 8, 33
  };
  const int r592[] = {
    10, 10, // Number of jobs and machines
    0, 11, 6, 50, 4, 83, 8, 34, 3, 44, 5, 71, 9, 22, 2, 32, 7, 63, 1, 66, 
    7, 27, 9, 87, 6,  5, 4, 47, 1,  2, 8, 36, 2, 46, 3, 58, 0, 42, 5, 23, 
    0, 87, 6, 80, 8, 34, 3, 28, 2,  8, 9, 69, 7,  2, 1, 61, 4, 32, 5, 35, 
    2, 45, 3, 40, 5, 14, 1, 33, 8, 47, 0, 87, 7, 29, 4, 23, 9,  4, 6, 34, 
    6, 73, 4,  1, 8, 38, 0, 41, 1, 80, 2, 85, 9,  7, 5, 20, 7, 25, 3, 59, 
    9, 87, 2,  6, 3, 29, 4, 90, 1, 85, 6, 71, 0, 74, 5, 89, 8, 51, 7, 20, 
    6, 38, 2, 48, 4, 70, 0, 22, 5, 25, 3, 77, 9, 45, 7, 66, 1, 25, 8, 28, 
    7, 63, 9, 89, 6, 74, 4, 52, 5, 83, 0, 43, 3, 97, 2, 32, 8, 18, 1, 79, 
    2, 16, 6, 37, 9, 32, 0, 97, 7,  9, 1, 89, 5,  8, 4, 40, 3, 88, 8, 83, 
    7, 51, 5, 52, 4, 21, 2, 11, 3, 22, 0, 66, 8, 56, 9, 36, 6, 31, 1, 83
  };
  const int r593[] = {
    10, 10, // Number of jobs and machines
    2, 43, 1, 98, 4, 33, 6, 61, 5, 94, 9, 98, 3, 47, 7, 41, 8, 39, 0, 32, 
    9, 17, 8, 58, 1, 79, 0, 55, 4, 87, 3, 45, 5, 61, 6, 79, 2, 41, 7, 37, 
    4, 13, 0, 36, 2, 59, 5, 12, 7, 22, 8, 18, 9, 56, 6, 51, 3, 32, 1, 28, 
    6, 30, 4, 81, 0, 89, 2, 79, 3, 79, 7, 62, 9,  4, 8, 28, 1,  8, 5, 79, 
    9, 92, 5, 83, 7, 91, 4, 65, 6, 68, 0, 54, 3, 40, 8, 52, 2, 76, 1,  1, 
    9, 46, 5, 44, 3, 37, 6, 87, 7, 93, 4,  4, 8,  5, 0, 56, 2, 94, 1, 36, 
    6, 54, 0, 22, 7, 88, 5, 64, 9, 14, 8, 81, 3, 21, 2, 24, 1, 70, 4, 62, 
    1, 58, 2,  2, 8, 45, 3,  2, 7, 17, 0, 93, 9, 64, 5, 92, 6, 16, 4, 78, 
    3, 71, 4, 87, 1,  5, 0, 15, 9, 49, 5, 14, 6, 67, 7, 59, 8, 34, 2, 85, 
    7, 99, 0, 58, 5, 69, 3, 13, 1, 39, 6, 86, 8, 74, 4,  3, 2, 99, 9, 86
  };
  const int r594[] = {
    10, 10, // Number of jobs and machines
    1, 60, 2, 90, 6, 56, 7, 42, 9, 25, 0, 83, 4, 60, 8, 71, 5, 98, 3,  5, 
    3, 28, 1,  7, 9, 95, 2, 35, 6, 42, 0, 96, 5, 24, 4, 49, 8, 71, 7, 25, 
    8, 61, 6,  3, 4,  7, 2, 42, 9, 99, 5, 24, 3,  5, 7, 79, 1,  4, 0, 65, 
    7, 49, 3, 45, 2, 84, 1, 95, 4, 19, 9, 50, 0, 29, 8, 25, 6, 99, 5, 76, 
    1, 74, 3, 28, 7, 80, 8,  2, 4, 15, 9, 54, 2,  4, 0, 43, 5, 51, 6, 31, 
    9, 18, 4, 58, 8, 47, 7, 49, 0, 88, 3, 94, 5, 21, 1, 22, 6,  6, 2, 55, 
    7, 27, 0, 81, 5, 69, 8, 68, 9,  2, 4, 51, 6, 92, 3,  4, 1, 42, 2, 79, 
    2, 58, 4, 47, 5, 45, 6, 11, 9, 66, 3, 64, 1, 27, 0, 54, 7,  9, 8, 54, 
    6, 70, 4, 63, 3, 43, 9, 56, 7, 17, 2, 68, 5, 60, 8, 80, 1, 51, 0, 85, 
    1, 18, 7, 89, 9, 95, 4, 12, 3, 78, 8, 99, 5, 91, 2, 75, 6,  4, 0, 41
  };
  const int r595[] = {
    10, 10, // Number of jobs and machines
    0, 71, 4, 26, 5, 64, 9, 39, 7, 19, 3, 30, 1,  7, 6, 64, 2, 38, 8, 13, 
    9, 36, 4, 86, 8, 54, 7, 89, 2, 53, 3, 62, 0, 55, 1, 68, 5, 35, 6, 71, 
    1, 10, 3, 63, 6, 78, 8, 34, 0, 93, 9, 85, 4, 66, 7, 95, 5, 72, 2, 51, 
    1, 13, 0, 80, 5,  9, 4, 11, 6, 76, 3, 26, 8, 91, 9, 56, 7, 68, 2, 54, 
    4, 63, 1, 19, 9,  6, 8, 24, 6, 93, 7, 21, 2, 23, 3, 25, 0, 69, 5, 19, 
    3, 46, 1, 89, 6, 97, 0, 49, 5, 89, 7, 99, 9, 95, 8, 16, 4, 41, 2, 47, 
    0, 61, 4, 78, 9,  4, 3, 48, 2, 50, 6, 65, 7, 93, 5, 58, 1, 89, 8, 98, 
    2,  6, 5, 23, 4, 92, 0, 28, 9, 90, 1, 96, 7, 25, 8, 58, 3, 53, 6,  6, 
    6, 84, 7, 65, 0, 73, 1, 86, 5, 62, 9, 30, 8, 97, 2,  1, 4, 78, 3,  2, 
    0,  3, 3,  8, 9, 69, 5, 20, 1, 48, 7, 28, 6, 18, 4, 50, 2, 38, 8,  1
  };
  const int r596[] = {
    10, 10, // Number of jobs and machines
    3, 39, 9, 92, 6, 84, 4, 40, 1, 68, 5, 40, 2, 75, 8, 81, 7, 82, 0, 43, 
    4, 52, 5, 84, 1, 61, 6, 75, 3, 14, 7, 30, 0, 54, 2, 10, 8, 54, 9, 96, 
    3, 15, 0,  2, 2, 91, 7, 35, 9, 60, 6, 93, 1, 22, 8, 88, 5, 92, 4, 45, 
    9, 81, 2, 25, 5, 63, 8, 33, 3, 32, 0, 32, 6, 18, 4, 24, 7,  5, 1, 13, 
    7, 76, 2,  3, 8, 81, 5, 33, 6, 22, 3, 11, 1, 94, 9, 74, 4, 90, 0, 76, 
    4, 91, 6, 72, 1, 15, 9, 63, 0, 98, 3, 17, 2, 28, 8,  3, 7, 37, 5, 80, 
    6, 49, 3, 21, 1, 62, 4, 61, 9, 21, 7, 18, 8, 99, 5, 53, 2, 14, 0, 77, 
    6, 11, 0, 97, 9,  8, 1, 34, 2, 46, 5, 80, 7,  8, 4, 61, 8, 62, 3, 76, 
    7, 48, 4, 52, 8, 98, 2,  6, 3, 49, 6, 64, 5, 52, 0,  2, 9, 33, 1, 93, 
    1, 92, 0, 12, 2,  2, 5, 58, 9, 49, 8, 63, 6, 37, 7, 13, 4, 79, 3, 82
  };
  const int r597[] = {
    10, 10, // Number of jobs and machines
    5, 38, 9, 92, 6, 40, 0, 87, 3,  8, 1, 14, 7, 35, 2, 94, 4, 87, 8, 84, 
    8, 19, 5,  5, 2,  6, 0, 55, 1,  4, 7, 57, 9, 20, 4, 23, 3, 81, 6, 56, 
    5,  5, 9, 10, 7, 36, 8, 32, 6, 17, 4, 25, 2, 49, 0, 22, 1, 75, 3, 52, 
    0, 97, 9, 28, 4, 67, 8, 44, 7, 36, 6, 36, 5, 11, 1, 73, 2, 27, 3, 92, 
    7, 49, 6, 83, 3, 36, 2, 27, 8, 40, 1,  8, 9, 34, 0, 89, 5, 80, 4, 17, 
    8, 15, 2, 96, 0, 41, 9, 46, 7, 13, 5, 89, 1, 36, 3, 94, 6, 62, 4, 31, 
    1, 44, 7, 98, 0, 48, 4,  3, 9, 24, 6, 84, 8, 11, 5, 68, 3, 69, 2, 24, 
    7, 72, 2, 63, 0, 88, 1, 87, 8, 97, 6, 83, 5, 97, 4, 27, 3, 88, 9, 71, 
    0, 87, 4, 21, 5, 74, 8, 48, 1, 57, 7, 16, 2, 31, 9, 52, 6, 92, 3, 50, 
    1, 82, 0, 66, 7, 94, 5, 95, 8, 99, 3, 86, 2, 28, 4, 92, 9, 61, 6, 67
  };
  const int r598[] = {
    10, 10, // Number of jobs and machines
    2,  6, 9, 57, 3, 26, 4, 72, 7, 50, 8, 87, 1, 12, 0, 97, 5,  6, 6, 17, 
    7, 33, 4,  2, 1, 47, 0,  8, 8, 21, 9, 56, 5, 28, 6, 19, 3,  9, 2, 69, 
    8, 88, 7, 23, 2, 29, 3, 99, 4,  2, 1, 56, 9, 79, 5, 42, 0, 10, 6, 59, 
    6, 44, 2,  7, 0, 56, 7, 42, 1, 56, 9, 46, 3, 64, 5, 59, 8, 16, 4, 97, 
    6, 12, 5, 59, 8, 76, 4, 86, 7, 46, 3, 91, 2, 41, 9, 40, 0, 58, 1, 46, 
    7, 79, 3, 97, 2, 29, 6, 54, 8, 85, 4, 67, 1, 20, 9, 71, 5, 67, 0, 58, 
    9, 70, 4, 64, 3, 83, 1, 13, 6, 59, 0, 15, 2, 47, 8, 73, 5, 94, 7,  3, 
    7, 53, 9, 46, 0, 41, 6,  3, 3, 37, 2, 43, 5, 32, 1, 61, 8, 20, 4, 46, 
    0, 21, 7, 58, 2, 33, 9, 17, 1, 76, 8, 86, 5, 16, 4, 65, 6, 40, 3, 29, 
    2, 63, 6, 79, 3, 63, 1, 36, 7, 46, 9, 94, 8, 33, 5, 35, 4, 23, 0, 14
  };
  const int r599[] = {
    10, 10, // Number of jobs and machines
    5,  5, 3, 45, 8, 98, 4, 57, 9, 76, 1, 27, 7, 11, 2, 11, 0, 93, 6, 76, 
    1, 16, 3, 86, 0, 93, 9, 32, 2, 86, 7, 80, 4, 45, 8, 47, 6, 94, 5, 73, 
    9, 41, 7, 78, 1, 23, 4, 65, 2, 19, 8, 47, 0,  1, 6, 80, 3, 90, 5, 55, 
    6, 67, 0, 32, 7, 83, 9, 55, 2, 97, 1, 73, 4, 65, 8, 99, 3, 48, 5, 37, 
    8, 53, 7, 91, 0, 24, 2, 93, 5, 26, 3, 54, 4, 44, 6, 28, 1, 41, 9, 53, 
    5, 54, 9, 52, 6, 30, 7, 99, 4, 10, 0, 37, 3, 49, 2, 47, 8, 42, 1, 33, 
    1, 71, 5, 35, 0, 27, 3, 19, 9, 51, 7,  6, 6, 81, 4, 45, 8, 81, 2,  9, 
    2, 10, 5, 89, 4, 84, 7, 46, 3,  9, 1, 39, 0, 26, 8, 18, 9, 67, 6, 26, 
    0, 20, 7, 26, 5, 37, 6, 62, 1, 14, 4, 77, 2, 27, 9, 12, 8,  1, 3, 39, 
    7, 61, 4, 52, 0, 74, 5, 51, 1, 20, 6, 49, 3, 56, 8, 56, 2, 59, 9, 34
  };
  const int r600[] = {
    10, 10, // Number of jobs and machines
    1, 28, 7, 54, 9, 52, 4, 24, 8, 21, 2, 73, 6, 97, 3, 21, 0, 90, 5, 85, 
    1, 74, 2, 71, 3, 84, 9, 77, 0, 18, 5, 66, 7, 91, 4, 58, 6, 44, 8, 53, 
    0, 79, 8, 39, 6, 87, 5, 27, 3, 95, 2, 82, 7, 81, 4, 46, 1, 54, 9, 58, 
    5, 79, 3, 73, 4, 84, 8, 50, 7, 86, 2, 54, 0, 57, 9, 27, 1, 47, 6, 60, 
    9, 83, 0, 78, 8, 70, 1, 41, 2, 59, 5, 54, 4, 82, 3,  2, 6, 74, 7, 88, 
    3, 10, 4, 50, 0, 88, 5, 37, 8, 86, 1, 57, 6,  1, 7, 11, 2, 80, 9, 15, 
    9, 95, 1,  4, 8, 12, 6, 39, 7, 96, 4, 95, 2, 52, 3, 90, 5, 96, 0, 14, 
    9, 74, 0,  2, 4, 45, 6,  7, 3,  9, 1, 57, 7, 96, 5, 71, 2, 14, 8, 67, 
    4, 91, 5, 77, 7, 23, 0, 37, 1, 22, 9, 83, 2, 60, 3, 66, 8, 70, 6, 81, 
    1,  1, 7, 72, 8, 64, 5, 19, 0, 57, 3, 59, 2, 12, 9, 99, 4, 49, 6, 88
  };
  const int r601[] = {
    10, 10, // Number of jobs and machines
    1,  4, 6, 23, 0,  9, 5, 57, 9, 59, 2, 11, 7, 18, 8, 50, 4, 66, 3, 94, 
    2, 97, 3, 62, 7, 50, 4, 70, 0, 15, 9, 94, 1, 18, 6,  5, 8, 63, 5,  6, 
    4, 43, 6, 12, 3,  3, 5, 66, 7, 79, 2, 24, 8, 59, 1, 80, 0, 16, 9, 85, 
    6, 18, 5, 33, 9, 86, 1, 86, 7, 83, 3, 32, 0, 68, 8, 66, 2, 83, 4, 78, 
    2, 61, 9, 88, 3, 83, 7, 69, 1,  2, 5, 26, 6, 55, 0,  2, 4,  7, 8, 58, 
    6, 92, 0, 44, 3, 42, 8, 52, 9, 88, 1,  4, 4, 76, 5, 80, 2, 73, 7, 52, 
    4, 54, 3, 39, 7, 52, 2, 36, 9, 40, 5, 24, 0, 48, 1, 38, 6, 87, 8, 32, 
    0,  8, 8, 93, 1, 62, 4, 97, 6, 91, 5, 28, 2, 72, 9, 29, 3, 72, 7, 75, 
    5, 77, 7,  4, 0, 40, 4, 23, 8, 71, 3, 64, 6, 66, 1, 53, 9, 71, 2,  3, 
    3, 58, 9, 98, 2, 51, 1, 46, 8, 30, 4, 92, 6, 72, 7, 15, 0, 45, 5, 20
  };
  const int r602[] = {
    10, 10, // Number of jobs and machines
    9, 77, 4, 99, 0, 12, 1, 26, 2, 24, 8, 21, 5, 11, 6, 21, 7, 53, 3, 17, 
    9, 51, 7, 46, 4, 56, 2,  7, 1, 85, 3, 27, 5, 84, 0, 85, 8, 98, 6, 37, 
    5, 70, 2, 27, 9, 90, 8,  7, 6, 59, 0, 67, 1, 63, 3, 30, 7, 63, 4, 81, 
    6, 88, 7, 55, 9, 63, 8, 58, 0, 23, 5, 22, 4, 49, 3, 81, 1, 92, 2, 25, 
    0, 92, 5,  1, 2, 87, 8, 35, 6, 77, 3, 76, 4, 33, 7, 63, 1, 98, 9, 26, 
    4, 15, 0, 99, 2, 67, 3, 10, 7, 17, 8, 11, 9, 93, 6, 37, 1, 27, 5, 67, 
    0, 28, 7, 50, 1, 37, 8, 75, 4, 79, 6, 25, 5, 44, 2, 85, 9, 11, 3, 55, 
    2, 58, 8, 15, 4, 59, 0, 77, 5, 11, 3, 83, 6, 55, 1,  8, 9, 14, 7, 40, 
    0, 18, 3, 16, 2,  8, 5, 89, 6, 71, 4, 25, 7, 42, 9, 99, 1, 34, 8, 49, 
    7, 95, 3, 31, 8, 16, 5, 78, 2, 82, 9,  8, 4, 36, 0, 27, 6, 83, 1, 57
  };
  const int r603[] = {
    10, 10, // Number of jobs and machines
    3, 24, 6, 25, 2, 34, 4, 11, 5, 21, 0, 17, 1, 72, 7, 99, 9, 11, 8, 79, 
    4, 31, 9, 95, 6, 64, 1, 74, 7, 34, 2, 28, 3, 44, 5, 44, 8, 33, 0, 68, 
    5,  5, 7, 82, 1, 74, 9, 17, 4,  1, 3, 96, 2, 86, 8, 15, 6, 67, 0, 10, 
    1, 50, 9, 34, 0, 67, 8, 63, 3, 55, 6, 57, 2, 12, 5, 32, 7, 77, 4, 14, 
    0, 16, 1, 17, 5, 81, 3, 18, 6, 80, 4,  5, 9, 34, 7, 72, 8, 15, 2,  3, 
    4, 44, 3, 68, 9, 42, 7, 55, 6, 79, 1, 95, 5, 78, 8, 62, 2, 35, 0, 75, 
    9,  4, 2,  1, 0, 84, 3, 13, 6, 90, 5, 51, 4, 47, 7, 63, 8, 29, 1, 83, 
    7, 56, 2, 83, 5, 42, 0,  9, 3, 11, 1, 92, 6, 38, 8, 67, 9, 97, 4, 12, 
    7, 47, 0, 78, 6, 85, 9, 70, 1, 68, 4, 33, 5,  9, 3, 98, 2, 70, 8, 54, 
    1, 32, 0, 73, 9, 86, 3, 71, 2, 37, 6, 74, 8, 87, 4, 94, 7, 49, 5, 38
  };
  const int r604[] = {
    10, 10, // Number of jobs and machines
    3,  7, 2, 67, 1,  1, 0, 37, 8, 78, 5, 58, 7, 22, 4, 36, 9, 40, 6, 49, 
    4, 84, 8, 23, 3, 67, 5, 32, 2, 95, 0, 55, 1, 31, 7, 23, 9, 80, 6, 91, 
    4,  8, 0, 93, 8, 19, 1, 79, 6, 52, 9, 43, 7, 98, 2, 21, 5, 78, 3, 66, 
    1, 24, 2, 25, 6, 14, 5, 63, 0, 67, 8,  3, 4, 94, 9, 90, 7, 29, 3, 79, 
    9,  9, 7, 43, 8, 35, 2,  7, 6, 62, 4, 83, 1, 18, 3, 37, 0, 46, 5, 94, 
    0, 15, 9, 98, 6,  6, 1, 88, 2, 33, 5, 80, 3, 93, 7, 40, 4, 63, 8, 84, 
    0, 47, 1,  3, 3, 50, 7, 60, 2, 84, 6, 93, 5, 15, 8, 20, 9, 26, 4, 42, 
    0, 43, 8, 32, 2, 56, 3, 74, 5, 45, 1, 33, 4, 49, 6, 76, 7,  2, 9, 25, 
    3, 64, 6, 70, 8,  6, 2, 93, 9,  1, 4, 52, 0, 72, 5, 14, 1, 42, 7, 76, 
    9, 61, 5, 33, 2, 38, 8, 12, 4, 66, 6, 59, 0, 83, 3, 28, 7, 10, 1, 22
  };
  const int r605[] = {
    10, 10, // Number of jobs and machines
    5, 62, 0, 61, 9, 15, 1, 13, 3, 49, 7, 28, 2, 70, 8, 62, 4, 12, 6, 91, 
    3, 91, 8, 18, 2, 65, 0, 92, 5, 27, 4, 52, 1, 94, 7, 64, 6, 23, 9,  8, 
    4, 50, 2,  7, 3, 72, 0, 47, 1, 92, 8, 74, 7, 79, 6, 22, 5, 90, 9, 34, 
    3, 25, 7,  8, 8, 39, 1,  7, 9, 60, 4, 56, 2, 70, 5, 57, 0,  7, 6, 75, 
    7, 97, 8, 48, 0, 55, 5, 76, 9, 65, 3,  2, 1, 59, 4, 48, 2, 26, 6, 96, 
    5, 21, 1, 19, 4, 54, 0, 91, 8, 79, 6, 32, 3, 16, 9, 43, 7, 76, 2, 45, 
    0, 32, 9,  9, 4, 16, 1, 67, 2, 46, 7, 52, 6,  4, 3, 53, 8, 13, 5, 85, 
    5, 60, 7, 83, 4, 86, 2, 32, 9, 33, 6, 16, 0, 21, 8, 34, 1, 49, 3, 10, 
    6, 14, 7, 39, 0, 73, 1,  8, 9, 28, 2, 54, 3,  1, 4, 38, 8, 89, 5, 81, 
    5, 73, 6, 63, 9,  7, 3, 78, 4, 62, 0, 19, 1, 72, 7, 23, 2, 72, 8, 24
  };
  const int r606[] = {
    10, 10, // Number of jobs and machines
    7, 67, 3, 37, 4, 92, 1, 55, 5,  2, 2, 38, 8, 65, 0,  3, 9, 93, 6, 26, 
    1, 65, 0, 20, 6,  5, 8, 46, 7,  5, 3, 14, 2, 71, 9, 51, 4, 95, 5, 75, 
    7, 80, 4, 71, 3, 72, 2,  8, 9, 97, 8, 25, 6, 37, 0, 59, 1, 45, 5, 77, 
    9, 89, 3, 86, 5, 85, 1,  2, 6, 74, 2, 59, 7, 41, 4, 21, 8, 96, 0, 42, 
    4, 71, 6, 25, 5, 97, 8, 17, 2, 67, 3, 46, 9, 82, 0, 15, 1, 66, 7,  1, 
    8, 15, 2, 79, 5, 98, 6, 70, 3, 11, 4, 94, 0, 59, 9, 56, 1, 92, 7,  2, 
    1, 26, 5, 92, 2, 35, 3, 26, 6, 93, 8, 74, 7, 40, 0,  6, 4, 99, 9, 73, 
    1, 55, 7,  4, 3, 43, 4, 17, 2, 21, 5,  9, 0,  4, 9, 32, 8, 27, 6, 70, 
    8, 74, 3, 54, 2,  2, 4, 26, 7, 89, 1, 69, 9, 12, 0, 67, 6, 10, 5, 36, 
    0, 82, 1, 86, 3, 81, 6, 84, 8, 10, 7, 63, 2, 53, 4, 16, 5, 20, 9, 83
  };
  const int r607[] = {
    10, 10, // Number of jobs and machines
    5, 64, 6,  2, 9, 95, 4, 90, 1, 56, 0, 87, 7, 25, 2, 59, 3, 73, 8, 23, 
    5, 18, 0, 54, 7, 54, 4, 65, 9, 92, 6, 22, 1, 85, 8, 88, 3,  5, 2, 86, 
    7, 28, 0,  3, 1,  4, 8, 57, 3, 56, 6, 67, 9, 24, 5, 66, 2, 70, 4,  2, 
    2, 73, 6, 70, 1,  9, 3, 59, 9, 14, 5, 32, 0, 82, 8,  4, 4, 78, 7, 60, 
    8, 31, 0, 96, 3, 11, 4, 48, 5, 93, 9, 50, 1, 84, 6,  3, 2, 75, 7, 25, 
    8, 94, 5, 17, 1, 47, 2, 25, 4, 35, 0, 11, 7, 29, 6, 11, 3, 89, 9, 88, 
    0, 82, 8, 49, 3, 90, 2, 66, 5,  4, 6, 63, 9, 83, 7, 12, 4, 41, 1, 51, 
    6, 91, 5, 47, 4, 64, 2, 24, 8, 95, 0, 46, 3, 35, 9, 36, 7, 37, 1, 95, 
    1, 97, 6, 43, 7, 59, 5, 92, 3, 42, 0,  1, 2, 35, 8, 96, 4,  2, 9,  4, 
    9, 67, 6, 21, 0, 49, 1, 12, 5, 23, 8, 58, 4, 28, 3, 14, 2, 38, 7, 82
  };
  const int r608[] = {
    10, 10, // Number of jobs and machines
    8, 27, 2, 28, 4,  8, 1,  1, 7, 38, 0, 28, 5, 39, 3, 31, 6, 30, 9, 33, 
    3, 24, 5, 49, 7, 84, 0, 25, 9, 38, 8, 55, 6, 11, 2, 69, 1, 32, 4, 22, 
    6, 48, 9, 22, 0, 27, 3,  6, 8,  7, 2, 16, 5, 22, 7, 68, 4, 41, 1, 17, 
    0, 82, 1, 47, 4, 50, 7,  7, 2, 33, 8, 76, 3, 99, 5, 81, 9,  7, 6, 49, 
    1, 14, 3, 79, 0, 93, 2,  8, 6, 84, 8, 12, 4, 86, 9, 21, 5, 93, 7, 40, 
    4, 51, 2, 54, 5, 51, 3, 84, 0, 44, 9, 73, 6, 13, 8, 72, 1, 88, 7, 13, 
    4, 23, 5,  1, 8, 74, 3, 71, 9,  8, 7, 19, 1,  1, 2, 19, 6,  9, 0, 89, 
    3, 33, 2, 56, 1, 60, 8, 41, 4, 29, 5, 13, 0, 96, 7, 11, 9, 24, 6, 85, 
    6, 10, 0, 44, 8, 92, 9, 76, 7, 65, 3, 78, 1, 16, 4, 66, 5, 80, 2, 39, 
    9, 47, 8, 76, 5, 60, 3, 67, 2, 63, 6, 69, 1, 14, 7, 57, 4, 94, 0, 47
  };
  const int r609[] = {
    10, 10, // Number of jobs and machines
    8, 17, 1, 48, 3,  3, 6,  4, 9, 48, 4, 52, 2, 43, 7, 19, 0, 93, 5, 36, 
    0, 85, 5, 94, 8, 50, 3, 39, 4, 59, 9, 68, 2, 71, 6, 70, 7, 38, 1, 28, 
    0, 49, 1, 74, 8, 93, 2, 26, 4,  8, 3, 64, 9, 29, 6, 95, 5, 93, 7, 11, 
    3, 95, 7, 30, 5, 11, 4, 51, 0, 28, 1, 45, 2, 24, 6, 56, 8, 59, 9, 71, 
    7, 56, 4,  9, 3, 41, 5, 39, 8, 96, 6, 58, 9, 92, 1, 26, 2, 70, 0, 23, 
    1, 11, 2, 87, 9, 38, 4,  9, 8, 20, 0, 45, 7,  3, 6,  6, 5, 74, 3, 35, 
    1, 46, 6,  1, 5, 72, 7,  8, 3, 34, 4, 41, 2, 98, 8, 78, 0, 76, 9, 48, 
    7, 19, 8, 95, 5, 57, 9, 47, 4, 10, 2, 21, 0, 59, 3, 52, 1, 53, 6, 71, 
    0, 97, 7, 36, 5, 16, 9, 25, 8, 98, 2, 23, 6, 49, 4, 90, 1, 81, 3, 48, 
    9, 55, 0, 94, 4, 22, 8, 24, 7, 13, 3, 91, 2, 45, 1, 40, 5, 46, 6, 72
  };
  const int r610[] = {
    10, 10, // Number of jobs and machines
    6, 60, 8,  6, 5, 38, 4, 54, 2, 71, 3, 65, 0, 35, 9, 40, 7,  8, 1, 78, 
    5, 27, 1, 55, 3, 49, 0, 62, 4, 82, 6, 36, 8, 41, 2, 11, 9, 60, 7, 14, 
    1, 94, 9, 79, 0, 73, 5, 91, 4, 46, 6, 73, 3, 92, 8, 73, 2, 23, 7, 29, 
    7, 58, 2, 39, 0, 82, 8,  5, 9, 61, 5, 95, 1, 57, 4, 44, 6, 79, 3, 66, 
    5, 84, 0, 17, 8, 27, 4, 87, 1, 73, 9, 44, 6, 71, 3, 75, 2, 13, 7, 36, 
    6, 79, 2, 12, 1, 46, 7, 22, 4, 46, 3, 33, 8, 12, 9,  3, 5, 48, 0, 94, 
    6, 30, 0, 69, 5, 83, 4, 52, 7, 96, 2, 29, 1, 88, 3, 99, 9, 55, 8, 86, 
    3, 40, 8, 26, 4, 54, 0, 46, 1, 55, 6,  9, 9, 32, 7, 12, 5,  1, 2,  8, 
    6, 40, 7, 67, 4, 59, 0, 79, 2, 16, 1, 46, 5, 99, 3, 57, 8, 40, 9, 56, 
    1, 59, 9, 92, 7, 36, 5, 21, 2, 57, 3, 24, 4,  8, 0, 86, 8, 59, 6, 85
  };
  const int r611[] = {
    10, 10, // Number of jobs and machines
    1, 90, 9, 63, 6, 23, 7, 31, 3, 74, 8, 39, 5, 48, 4, 87, 0, 44, 2, 18, 
    7, 29, 8, 38, 6, 80, 0, 36, 2, 84, 5, 40, 3, 71, 4,  3, 1, 63, 9, 41, 
    5, 69, 9, 90, 6, 89, 0, 31, 7, 80, 4, 25, 2, 24, 8, 36, 3,  7, 1, 94, 
    1, 71, 9, 11, 3, 42, 2, 77, 0, 48, 8, 76, 4, 69, 6, 44, 7, 90, 5, 87, 
    9, 85, 6, 19, 5, 89, 1, 44, 7, 91, 2, 41, 3,  8, 8, 22, 4, 21, 0, 55, 
    7, 78, 2, 47, 1, 76, 4, 11, 0,  9, 6, 23, 9, 66, 5, 85, 3, 81, 8, 21, 
    3,  6, 9, 90, 4, 97, 1, 78, 5, 23, 6, 66, 2, 54, 7,  8, 0, 26, 8, 22, 
    7, 26, 8, 12, 0, 33, 5, 10, 1, 90, 9, 52, 4, 37, 2, 16, 6, 37, 3, 18, 
    5, 78, 8,  7, 7, 51, 1, 31, 0, 63, 4, 56, 6, 99, 2, 59, 9, 78, 3, 22, 
    9, 54, 6, 58, 4, 51, 0, 81, 5, 45, 2, 62, 7, 51, 3,  6, 1, 89, 8,  3
  };
  const int r612[] = {
    10, 10, // Number of jobs and machines
    9,  1, 2, 71, 8,  2, 0, 36, 7, 73, 1, 97, 4, 94, 6, 15, 3, 31, 5, 61, 
    4, 98, 6, 83, 9,  7, 5, 27, 0, 38, 1, 52, 3, 80, 2,  5, 8, 69, 7, 98, 
    1, 95, 4, 57, 9, 33, 3, 65, 0, 62, 8, 97, 7, 85, 6,  4, 5,  9, 2, 56, 
    9, 37, 1, 65, 0, 48, 4, 76, 2, 23, 7, 80, 6, 81, 3, 41, 8, 34, 5, 53, 
    2,  8, 9, 90, 3, 47, 7, 77, 1, 54, 4, 98, 0, 61, 8, 13, 6, 37, 5, 12, 
    9, 59, 7, 89, 8, 59, 0, 56, 2,  3, 6, 68, 5, 92, 3, 45, 4, 96, 1, 96, 
    1, 11, 5, 28, 8, 84, 9, 29, 0, 45, 7, 94, 3, 73, 4, 50, 6, 54, 2, 71, 
    1, 14, 8, 34, 9, 84, 3, 15, 5, 71, 7,  3, 0, 72, 4,  7, 6,  7, 2, 41, 
    7, 14, 6, 45, 1, 24, 5, 28, 2,  2, 3, 45, 4, 67, 8, 43, 0, 14, 9, 86, 
    1,  4, 4, 63, 9, 11, 3, 22, 8, 75, 6, 39, 7, 50, 5,  3, 0, 74, 2, 64
  };
  const int r613[] = {
    10, 10, // Number of jobs and machines
    0, 81, 8, 21, 4, 97, 2, 34, 7, 56, 9, 50, 5,  4, 6, 59, 3, 82, 1, 22, 
    4, 63, 3, 38, 9, 68, 7, 40, 1, 45, 8, 72, 2, 36, 6, 83, 0, 42, 5, 67, 
    3, 57, 6, 59, 1, 85, 9, 35, 5, 25, 8, 58, 2, 87, 7, 88, 0, 47, 4, 77, 
    6, 88, 4, 52, 1, 12, 3, 29, 2, 29, 7, 45, 5, 32, 8, 71, 9,  2, 0, 67, 
    2, 48, 0, 18, 5, 33, 4, 88, 7, 89, 8,  1, 3,  5, 9, 34, 1, 28, 6,  2, 
    7, 48, 4, 84, 3, 61, 9, 83, 2, 28, 5, 90, 6, 11, 0, 55, 8, 61, 1,  3, 
    5, 78, 7, 71, 6,  3, 3, 49, 4, 52, 9, 59, 8, 80, 1,  5, 2, 56, 0, 47, 
    3, 10, 0, 62, 2, 64, 5, 18, 7, 96, 9,  2, 6, 54, 1, 77, 4, 91, 8,  7, 
    2, 75, 4, 24, 3, 70, 7, 82, 5, 94, 9, 90, 6, 34, 8, 14, 0, 37, 1, 17, 
    9, 92, 1,  9, 7,  3, 2, 75, 5, 64, 6, 77, 8, 69, 0, 87, 4, 50, 3, 95
  };
  const int r614[] = {
    10, 10, // Number of jobs and machines
    0,  1, 9, 45, 1, 22, 5, 51, 3, 19, 7, 49, 2, 53, 8, 62, 4, 43, 6, 71, 
    5, 94, 9, 74, 3, 95, 2, 72, 8, 27, 1, 87, 7, 91, 0, 86, 6, 99, 4, 58, 
    2, 41, 0, 25, 7, 16, 8, 39, 5, 21, 1, 66, 4, 74, 3, 37, 9,  3, 6, 43, 
    5, 65, 8, 23, 4, 60, 7, 42, 1, 64, 6, 28, 2, 39, 9,  9, 0, 54, 3, 44, 
    3, 37, 6, 36, 8, 21, 1, 65, 4, 33, 2, 56, 9,  6, 5, 67, 0, 65, 7, 66, 
    4, 85, 1, 11, 3, 57, 5, 94, 2, 13, 0,  1, 6, 54, 9, 33, 8, 46, 7, 42, 
    9,  5, 3, 49, 7, 98, 1, 42, 0, 26, 2,  9, 5, 44, 6, 34, 4, 61, 8, 52, 
    5, 75, 6, 56, 2,  4, 0, 37, 3, 39, 9, 46, 4, 72, 1, 90, 7, 95, 8, 84, 
    0,  8, 2, 55, 5, 14, 3, 26, 1, 60, 6, 67, 8, 23, 7, 69, 4, 10, 9, 95, 
    2, 46, 7, 70, 1, 27, 9,  5, 6, 89, 3, 90, 8, 38, 0, 38, 4, 36, 5, 57
  };
  const int r615[] = {
    10, 10, // Number of jobs and machines
    7, 53, 4, 33, 2,  4, 9, 59, 6,  5, 5, 64, 3, 45, 8,  7, 0, 26, 1, 35, 
    9, 84, 3,  1, 4, 80, 5,  6, 6, 78, 1, 61, 0, 57, 8,  6, 2, 60, 7,  9, 
    7, 75, 6, 57, 5, 18, 8, 45, 4, 23, 0, 47, 9, 99, 1, 47, 2, 78, 3, 56, 
    0, 21, 2, 75, 4, 85, 7, 50, 6, 33, 1,  8, 5, 14, 3, 52, 9, 39, 8, 66, 
    2, 66, 9, 67, 4, 55, 7, 67, 1, 10, 3, 54, 0, 71, 6, 30, 8, 87, 5, 71, 
    9, 75, 2, 30, 6, 76, 5, 78, 3, 52, 0, 60, 7, 83, 4, 19, 8, 38, 1, 79, 
    6,  7, 2, 55, 5, 11, 0, 60, 3, 62, 7, 59, 4, 43, 8, 91, 1, 26, 9, 84, 
    6, 30, 3, 17, 7, 19, 8, 52, 4, 10, 9, 51, 0, 87, 2, 79, 5, 54, 1, 88, 
    4, 11, 5,  6, 3, 53, 2, 52, 0, 29, 7, 31, 9, 19, 6, 52, 1,  4, 8, 76, 
    1, 14, 6, 77, 7, 16, 4, 42, 3, 52, 9, 66, 0, 25, 5,  9, 2, 69, 8,  6
  };
  const int r616[] = {
    10, 10, // Number of jobs and machines
    3, 75, 7, 44, 4, 86, 1, 52, 6, 72, 9, 17, 0, 16, 2, 57, 5, 14, 8, 91, 
    5,  1, 3, 61, 4, 57, 9,  3, 0, 79, 6, 80, 7, 27, 2, 18, 1,  5, 8, 59, 
    7, 48, 2, 50, 1, 94, 4, 39, 9, 11, 5, 70, 0, 95, 3, 43, 6, 63, 8,  4, 
    0, 46, 2, 34, 7, 43, 1, 11, 6, 75, 9, 60, 4, 25, 3, 50, 8, 20, 5, 67, 
    9, 23, 2, 24, 5, 80, 0, 15, 7, 67, 3, 28, 6, 40, 8, 37, 1, 86, 4, 36, 
    9, 83, 4, 29, 6, 94, 2, 79, 7, 14, 1, 30, 5, 56, 3, 65, 0,  5, 8, 78, 
    6, 52, 1, 10, 7, 41, 2, 19, 8, 81, 9, 56, 0, 93, 3, 44, 4, 58, 5, 97, 
    4, 24, 7, 18, 6, 94, 2,  2, 8, 22, 0, 61, 5, 52, 3, 71, 1,  9, 9, 71, 
    3, 72, 8, 92, 6, 28, 5, 35, 4, 46, 2, 63, 1, 38, 9, 27, 7, 64, 0, 88, 
    6, 65, 7, 27, 3, 99, 8, 53, 5, 29, 0, 12, 1,  5, 2, 62, 9, 20, 4, 80
  };
  const int r617[] = {
    10, 10, // Number of jobs and machines
    2, 99, 8, 75, 6, 20, 1, 54, 0, 48, 7,  3, 5, 75, 3, 47, 4, 75, 9, 99, 
    1, 79, 5, 35, 3, 36, 6,  2, 7, 85, 0, 99, 4, 82, 9,  8, 2,  8, 8, 36, 
    3, 49, 1, 63, 0, 46, 7, 13, 2,  3, 9, 70, 5, 69, 4, 41, 8, 18, 6,  8, 
    2, 60, 1, 49, 3, 30, 7,  8, 5, 51, 8, 29, 9, 24, 0, 22, 4, 47, 6, 91, 
    7, 41, 9, 87, 8, 75, 1, 14, 4, 22, 0, 36, 5, 31, 2, 27, 3, 49, 6, 15, 
    1, 54, 7, 81, 6, 84, 5,  3, 4, 35, 9, 37, 3, 10, 0, 42, 8, 55, 2, 73, 
    2, 44, 5, 23, 6,  6, 3, 66, 0, 80, 4, 78, 1, 98, 7, 73, 9, 29, 8,  5, 
    3, 12, 4,  5, 2, 64, 5, 30, 0, 62, 9, 54, 7, 77, 1, 16, 6, 29, 8, 11, 
    9,  6, 4, 79, 3, 51, 2, 72, 0, 16, 6, 43, 8, 18, 1, 30, 7, 30, 5, 70, 
    9,  8, 4, 84, 7, 13, 8, 84, 2, 52, 3,  8, 0, 27, 1, 28, 6, 95, 5, 88
  };
  const int r618[] = {
    10, 10, // Number of jobs and machines
    2, 48, 1, 10, 6, 35, 0, 27, 5, 30, 8, 51, 4, 52, 3, 91, 7, 47, 9, 84, 
    2, 79, 4, 80, 1, 16, 0, 58, 6, 10, 5, 52, 8, 93, 9, 86, 7, 19, 3,  9, 
    9, 58, 5, 50, 2, 69, 0, 37, 8, 25, 3, 66, 6, 44, 7, 59, 4, 34, 1,  1, 
    9, 77, 7, 16, 5, 34, 2,  1, 8, 59, 6, 21, 0,  1, 1, 86, 4, 59, 3, 84, 
    2, 37, 9, 37, 3, 17, 6, 63, 1, 97, 7, 54, 8,  1, 4, 49, 0,  8, 5, 38, 
    6, 55, 2, 31, 4, 68, 9, 43, 7, 64, 3, 58, 0, 56, 8, 79, 5, 63, 1, 60, 
    5,  1, 0, 53, 6, 84, 4, 85, 8, 24, 3, 20, 9, 11, 1, 32, 2, 78, 7, 51, 
    9, 45, 5, 53, 0, 92, 8, 77, 1, 15, 3, 29, 4, 59, 2,  9, 7, 50, 6, 25, 
    9, 77, 3, 42, 8,  7, 4, 78, 2,  2, 6, 94, 5, 82, 0, 77, 7, 12, 1, 38, 
    3, 63, 6, 29, 7, 88, 2,  8, 5, 36, 4, 82, 8, 81, 1, 20, 9, 57, 0, 95
  };
  const int r619[] = {
    10, 10, // Number of jobs and machines
    1, 44, 9, 13, 5, 38, 6, 23, 2, 38, 7, 24, 0,  4, 4, 30, 8, 14, 3, 42, 
    7, 31, 6,  9, 1, 41, 2, 20, 4,  8, 0, 30, 9, 20, 3, 99, 5, 44, 8, 59, 
    2, 32, 0, 36, 3, 67, 9, 67, 6, 94, 7, 99, 5,  5, 4,  9, 1, 53, 8, 98, 
    8, 71, 7, 60, 4, 38, 9, 91, 5, 64, 3, 16, 6, 10, 2, 11, 1, 25, 0, 33, 
    8,  8, 6, 69, 7, 60, 9, 30, 4, 80, 3, 18, 1, 78, 0, 37, 5, 75, 2, 20, 
    8, 32, 9, 62, 6, 65, 2, 67, 4, 27, 1, 76, 5, 34, 3,  6, 0, 24, 7, 25, 
    5, 42, 4, 82, 7, 35, 0, 88, 1, 90, 2, 51, 3, 53, 8, 59, 9, 24, 6, 32, 
    8, 15, 9, 38, 3, 51, 2, 48, 4, 42, 1,  4, 6, 91, 7, 97, 5, 85, 0, 45, 
    9, 61, 2, 96, 6, 10, 4, 78, 0, 86, 3, 66, 8, 20, 7, 88, 5,  7, 1, 27, 
    6, 27, 1, 93, 5, 59, 8, 83, 0, 99, 4, 63, 2, 73, 7, 19, 3, 86, 9, 15
  };
  const int r620[] = {
    10, 10, // Number of jobs and machines
    5, 69, 8, 42, 2, 27, 6, 13, 1, 47, 3, 10, 7, 87, 4, 65, 0, 55, 9, 53, 
    4, 70, 8, 14, 0, 56, 2, 25, 5,  5, 7, 88, 1, 73, 6, 33, 9, 60, 3, 40, 
    4, 91, 6, 90, 3, 17, 2, 62, 9, 97, 5, 99, 7, 38, 0, 49, 8, 29, 1, 38, 
    9, 89, 6, 90, 7, 20, 3, 52, 5, 63, 1, 43, 2, 59, 8, 53, 4, 13, 0, 87, 
    4,  4, 6, 10, 0, 26, 1, 81, 5, 10, 9,  2, 8, 65, 3, 92, 2, 89, 7, 64, 
    5, 11, 0, 85, 1, 53, 7, 77, 8, 13, 9, 36, 4,  9, 3, 98, 6, 32, 2, 64, 
    8, 21, 5, 44, 2, 51, 1, 99, 3,  1, 0, 42, 7, 15, 9, 19, 6, 51, 4, 87, 
    7, 12, 6, 23, 1, 19, 9, 61, 5, 74, 4, 97, 2, 84, 8, 41, 3, 18, 0, 80, 
    1, 83, 4, 81, 6, 46, 7, 78, 9, 59, 3,  3, 8, 13, 2, 11, 5, 18, 0,  4, 
    9, 70, 3, 62, 5, 24, 0, 87, 2, 44, 7, 70, 1, 41, 4, 67, 6,  9, 8, 81
  };
  const int r621[] = {
    10, 10, // Number of jobs and machines
    7, 35, 2, 32, 6, 36, 4, 67, 1, 54, 8, 53, 0, 98, 5, 44, 9, 27, 3, 97, 
    0, 77, 1, 87, 9, 59, 2, 96, 3, 54, 5, 30, 6, 52, 7, 29, 4, 55, 8, 82, 
    3, 22, 8,  7, 0, 58, 2, 98, 4, 83, 9,  3, 1, 36, 5, 70, 6, 14, 7, 87, 
    1,  5, 0, 35, 4, 11, 7, 34, 3,  3, 9, 55, 2, 39, 8, 56, 6, 71, 5, 30, 
    7,  1, 0, 97, 8, 30, 9, 49, 2, 72, 3, 38, 1, 66, 4, 99, 5, 39, 6, 73, 
    0, 87, 2, 43, 8, 62, 5, 82, 9, 64, 4, 46, 6, 59, 1, 54, 3, 26, 7, 31, 
    7, 44, 6, 88, 1, 22, 5, 99, 2, 28, 9, 78, 0, 69, 3, 83, 8, 93, 4,  1, 
    0, 91, 4, 90, 9, 89, 1, 39, 3, 75, 2, 72, 8, 15, 5, 63, 7, 54, 6, 97, 
    5, 26, 9, 85, 1, 57, 3, 81, 8, 87, 7, 71, 0, 65, 4, 90, 2, 57, 6, 55, 
    6, 59, 5, 67, 8, 47, 7, 28, 3, 46, 9, 50, 1, 25, 0, 58, 4, 89, 2, 97
  };
  const int r622[] = {
    10, 10, // Number of jobs and machines
    3, 26, 4, 80, 0, 49, 6, 39, 9, 82, 7, 41, 5, 55, 1, 31, 2, 16, 8, 57, 
    2, 66, 9, 81, 4, 23, 1, 55, 7, 53, 8, 26, 6, 33, 3, 12, 5, 56, 0, 99, 
    9, 85, 0, 14, 5, 19, 3, 69, 7, 17, 2, 58, 1, 53, 6, 49, 4, 89, 8, 19, 
    8, 19, 3,  7, 7, 75, 4, 68, 0, 33, 2, 24, 6,  9, 9, 93, 1,  8, 5, 19, 
    9, 63, 3, 93, 2,  8, 5, 86, 6, 38, 8, 78, 7, 13, 0, 76, 1, 81, 4, 95, 
    1, 62, 8, 12, 9, 29, 2, 71, 0, 83, 5, 59, 4, 68, 6, 52, 3, 33, 7, 81, 
    8, 16, 9, 78, 3, 88, 2, 55, 0, 69, 5, 60, 7, 86, 6, 87, 1, 93, 4, 50, 
    9, 12, 7, 61, 5, 77, 6, 45, 8, 80, 4, 21, 0, 30, 3, 17, 2,  3, 1, 37, 
    5, 93, 8, 28, 7, 69, 9, 38, 3, 12, 0, 40, 6, 74, 1, 97, 4, 98, 2, 61, 
    1, 56, 2, 12, 9, 11, 0, 69, 8, 81, 5, 43, 4, 22, 3, 88, 6, 13, 7, 15
  };
  const int r623[] = {
    10, 10, // Number of jobs and machines
    8, 37, 9, 58, 4, 86, 0, 90, 7, 24, 2, 69, 1, 32, 6, 82, 3, 54, 5, 42, 
    8, 89, 4, 19, 6, 68, 3, 53, 9, 56, 1, 89, 0, 80, 7, 53, 2, 95, 5, 11, 
    0,  8, 9, 83, 6, 52, 2, 52, 5, 41, 3, 61, 7, 42, 1, 44, 8, 17, 4, 19, 
    1, 78, 0, 81, 2, 19, 4,  5, 8, 24, 5, 99, 6,  8, 3, 55, 9,  5, 7, 80, 
    9, 32, 2, 23, 8,  7, 4, 53, 0, 64, 7, 43, 3, 90, 6, 32, 1, 17, 5, 26, 
    8, 25, 2, 37, 4, 21, 7, 35, 3, 15, 9, 99, 5, 36, 0, 51, 1, 33, 6, 39, 
    0, 81, 8, 61, 2, 84, 7, 56, 4, 51, 5, 96, 9, 36, 1, 68, 6, 27, 3, 49, 
    5, 40, 9, 61, 2, 85, 7, 54, 4, 88, 0, 84, 8, 73, 1, 72, 6,  7, 3, 33, 
    8, 18, 6, 81, 1, 46, 0, 36, 7, 24, 3, 63, 5, 75, 4, 55, 2,  7, 9, 50, 
    4, 78, 7,  7, 1, 72, 6, 42, 5, 13, 9, 19, 2, 25, 0, 29, 3, 31, 8, 16
  };
  const int r624[] = {
    10, 10, // Number of jobs and machines
    5, 51, 2, 52, 3, 22, 7, 91, 9, 76, 0, 16, 1, 60, 8, 48, 6, 66, 4, 62, 
    3, 35, 5, 21, 2, 41, 1, 54, 0, 16, 4, 98, 9, 56, 8, 66, 6, 97, 7, 73, 
    8, 39, 3, 42, 9, 83, 1, 92, 4,  3, 6, 22, 0, 94, 5, 65, 2, 46, 7, 19, 
    0, 98, 3, 22, 8, 35, 9, 56, 5, 36, 1, 71, 2, 36, 6, 75, 4, 11, 7, 80, 
    5, 11, 9, 27, 6, 82, 8, 95, 2, 23, 1,  6, 3, 39, 7, 35, 0, 30, 4, 73, 
    2, 23, 1, 20, 8, 82, 6, 78, 9, 83, 7, 94, 5, 22, 0, 20, 4, 10, 3, 95, 
    1, 21, 5, 66, 9, 82, 4, 39, 2, 77, 3, 41, 0, 47, 7, 61, 8, 91, 6, 54, 
    0, 99, 3, 80, 1, 29, 8, 54, 7, 65, 6, 65, 9, 64, 2, 69, 5, 93, 4, 76, 
    8,  5, 3, 18, 2, 85, 7, 21, 1, 96, 5, 34, 6, 46, 0, 90, 4, 18, 9, 16, 
    6, 29, 8,  4, 4, 67, 0, 99, 5, 63, 3, 45, 2, 98, 1, 35, 7, 18, 9, 24
  };
  const int r625[] = {
    10, 10, // Number of jobs and machines
    0, 16, 4, 32, 2, 20, 7, 54, 1, 92, 6, 52, 9, 44, 5, 25, 3,  9, 8, 51, 
    4,  7, 1, 50, 8, 15, 5, 72, 0, 82, 3, 74, 2,  1, 7, 91, 6, 82, 9, 87, 
    2, 46, 6,  3, 0, 16, 7, 60, 9, 65, 1, 51, 3, 69, 5, 66, 4, 21, 8, 68, 
    2, 58, 6, 50, 5,  1, 0, 94, 8, 29, 7, 79, 1, 70, 3, 56, 9, 39, 4,  4, 
    7, 10, 1, 79, 6, 35, 9, 98, 5, 44, 3,  2, 4,  3, 8, 88, 0, 23, 2, 70, 
    4, 29, 0, 32, 2, 21, 5, 58, 8, 68, 9, 95, 3, 58, 1, 95, 7, 70, 6, 42, 
    2,  1, 4, 22, 8, 92, 5, 46, 7,  9, 9, 93, 3, 67, 1, 23, 6, 26, 0, 32, 
    2, 47, 5, 85, 0, 22, 7,  2, 1, 88, 8, 69, 9, 62, 4, 35, 3, 75, 6, 17, 
    2, 37, 1, 16, 4, 61, 0, 63, 8, 77, 3, 96, 6, 62, 7, 56, 9, 10, 5, 10, 
    7, 92, 9, 13, 4, 94, 2, 18, 8, 25, 6, 68, 1, 83, 3, 33, 0, 41, 5, 45
  };
  const int r626[] = {
    10, 10, // Number of jobs and machines
    4, 71, 3, 18, 9, 74, 2,  3, 1, 32, 6, 49, 5, 44, 7, 83, 0,  4, 8, 39, 
    8, 77, 4, 67, 1, 63, 6, 99, 2, 87, 7, 94, 0, 13, 5, 80, 9, 79, 3, 32, 
    9, 54, 5, 11, 1, 24, 7, 69, 2, 75, 6, 73, 0, 97, 8, 48, 4, 18, 3,  1, 
    4, 60, 2, 99, 8,  7, 1, 48, 9, 80, 3, 37, 0, 76, 6, 32, 5, 60, 7, 54, 
    3, 62, 5, 58, 2, 76, 1, 95, 4, 23, 8, 37, 9, 97, 0,  1, 6, 29, 7, 17, 
    5, 20, 9, 49, 8, 79, 2, 86, 4, 41, 7, 57, 0, 92, 3, 75, 1, 50, 6, 76, 
    9, 65, 6,  6, 4,  9, 8, 97, 0, 22, 7, 30, 5, 30, 3, 35, 1, 55, 2, 35, 
    7, 41, 1, 18, 6, 51, 4, 35, 3, 80, 8, 23, 5, 94, 9, 67, 2, 11, 0, 96, 
    7, 19, 0, 69, 4, 18, 5, 24, 9, 97, 3, 81, 1, 94, 2, 84, 8, 11, 6, 80, 
    8, 75, 9, 30, 2, 33, 5, 80, 0, 45, 6, 98, 3,  2, 4, 18, 1, 65, 7, 31
  };
  const int r627[] = {
    10, 10, // Number of jobs and machines
    5, 99, 4, 73, 9, 83, 8, 88, 0, 22, 1, 11, 6, 52, 7,  3, 2, 50, 3, 68, 
    3, 21, 5, 61, 4, 97, 6, 87, 8, 95, 1, 65, 2, 12, 0, 85, 7, 56, 9, 44, 
    0, 29, 7, 94, 3, 36, 9, 79, 6, 15, 2, 58, 8,  3, 5, 60, 4, 77, 1, 95, 
    1, 27, 6, 82, 5,  9, 9, 64, 2, 83, 7, 16, 0, 53, 8, 34, 3, 77, 4,  2, 
    1, 65, 0,  5, 5, 62, 8,  1, 9, 27, 2, 36, 3, 89, 7, 15, 4, 96, 6, 82, 
    8, 12, 5, 43, 2, 89, 1, 52, 7, 80, 0,  4, 9, 52, 4, 76, 3, 58, 6,  1, 
    5, 87, 1, 10, 2, 99, 6, 94, 4, 30, 9, 56, 7, 71, 0, 92, 8, 15, 3, 33, 
    8, 26, 1, 66, 2, 16, 3, 25, 7, 28, 5, 86, 4, 98, 0, 62, 6, 81, 9, 18, 
    6, 61, 0,  7, 4, 14, 8, 22, 3, 66, 5, 18, 2, 21, 9, 24, 1, 85, 7, 69, 
    8, 40, 2, 32, 1, 96, 3, 52, 4, 42, 5, 99, 9, 15, 7, 53, 6, 43, 0, 36
  };
  const int r628[] = {
    10, 10, // Number of jobs and machines
    3, 23, 6, 49, 9, 78, 4, 84, 5, 49, 7, 61, 2, 34, 1, 59, 0, 53, 8, 53, 
    1, 30, 3, 13, 6, 97, 0, 47, 8, 21, 9, 23, 5, 45, 4, 35, 7, 20, 2, 22, 
    3, 37, 5, 33, 6, 66, 1, 96, 9, 32, 4, 26, 0, 90, 2,  7, 8, 19, 7, 99, 
    4, 60, 0, 36, 7,  8, 9,  5, 6, 74, 2, 42, 8, 26, 3, 83, 1, 93, 5, 45, 
    4, 53, 8, 63, 5, 82, 3,  5, 1, 37, 9, 53, 0, 17, 7, 98, 2, 63, 6, 41, 
    4, 51, 3,  3, 6, 98, 5, 45, 8, 24, 2, 62, 7, 94, 1, 86, 9, 45, 0, 11, 
    9, 55, 4, 62, 2, 50, 1, 13, 3, 21, 7, 66, 5, 66, 6, 72, 0,  2, 8, 72, 
    1, 34, 9,  9, 6, 12, 2, 40, 5, 83, 8, 87, 0, 71, 4, 62, 3, 37, 7, 90, 
    4, 26, 7, 12, 5, 41, 2, 54, 8, 65, 1, 51, 0, 63, 6, 75, 3, 35, 9, 38, 
    4, 23, 6, 53, 0, 66, 5, 41, 8, 91, 3, 62, 9, 16, 2, 39, 7, 40, 1, 72
  };
  const int r629[] = {
    10, 10, // Number of jobs and machines
    2, 77, 3,  6, 0, 63, 1, 81, 9, 38, 4,  6, 7, 93, 6, 88, 5, 13, 8, 61, 
    7, 77, 5, 32, 6,  1, 2, 37, 9, 59, 3,  9, 0,  4, 8, 36, 4, 92, 1, 29, 
    3, 12, 4,  6, 1, 56, 2,  4, 7, 23, 9, 60, 6,  5, 8,  4, 0, 14, 5, 77, 
    0, 73, 3, 75, 9, 28, 5, 49, 1,  9, 7, 43, 8, 31, 2, 41, 4, 31, 6, 64, 
    6, 49, 7, 98, 1, 43, 2, 88, 3, 97, 4,  6, 5, 24, 8, 55, 0, 52, 9, 47, 
    9, 31, 6, 42, 7, 79, 8, 23, 2, 59, 3, 70, 4,  1, 1, 17, 5, 28, 0, 55, 
    8, 64, 6,  9, 3, 90, 0, 40, 1, 36, 9, 67, 7, 60, 2, 23, 5, 22, 4, 96, 
    9,  5, 4, 50, 3, 12, 6, 46, 8, 52, 0, 63, 5, 79, 7, 72, 1, 63, 2, 47, 
    3, 55, 1, 46, 4, 44, 9,  7, 0, 43, 6, 76, 7, 60, 8, 71, 5, 56, 2, 43, 
    5, 27, 8, 21, 9, 85, 2, 33, 7, 86, 4,  4, 6, 55, 3,  3, 0, 59, 1, 68
  };
  const int r630[] = {
    10, 10, // Number of jobs and machines
    3, 36, 2, 10, 4, 18, 0, 64, 5, 51, 1, 55, 9, 75, 6, 15, 8, 81, 7, 79, 
    1, 81, 4, 71, 3, 13, 6, 92, 0, 61, 9, 55, 5, 17, 8, 35, 2, 11, 7, 98, 
    3, 23, 8,  1, 6,  8, 5, 39, 7, 75, 2, 79, 9, 19, 4, 49, 1, 36, 0, 46, 
    4, 93, 7, 88, 0, 70, 9,  1, 8, 18, 6, 68, 3, 62, 1, 51, 2, 19, 5, 24, 
    2, 35, 9, 11, 8, 78, 7,  9, 6, 17, 3, 44, 1, 88, 5,  7, 0, 61, 4, 10, 
    6, 28, 5,  4, 0, 44, 9, 31, 3, 70, 7, 14, 4, 92, 2, 37, 1, 85, 8, 61, 
    5, 92, 2, 42, 3, 27, 6, 26, 8, 76, 9, 36, 7, 87, 1, 55, 0, 88, 4,  2, 
    3, 78, 7, 99, 6, 65, 1, 12, 5, 83, 0, 39, 8, 93, 9,  9, 4,  5, 2, 99, 
    5,  5, 0,  8, 4, 76, 8, 26, 3, 74, 1, 31, 9, 88, 7, 55, 2, 89, 6, 53, 
    7, 43, 5, 70, 3, 33, 0,  3, 2, 41, 8, 62, 9, 58, 1, 35, 6, 26, 4, 34
  };
  const int r631[] = {
    10, 10, // Number of jobs and machines
    8, 86, 4, 28, 1, 71, 6, 29, 5, 47, 0, 77, 2, 37, 7, 11, 3, 29, 9, 53, 
    9, 81, 0, 30, 3,  7, 8, 82, 5, 95, 2, 37, 1, 58, 6, 63, 4, 33, 7, 20, 
    3, 58, 9, 38, 0, 51, 2, 81, 5, 12, 7, 32, 8, 62, 1, 62, 6, 81, 4, 34, 
    3, 79, 9, 62, 8, 82, 2, 40, 6, 88, 4, 89, 1,  3, 7, 52, 0,  2, 5, 80, 
    1, 20, 8, 53, 9, 33, 4, 69, 2,  9, 7, 68, 0, 30, 5, 52, 3, 82, 6, 10, 
    2, 71, 5, 43, 7, 37, 3, 71, 0,  7, 1, 55, 4, 13, 6, 43, 9, 25, 8, 70, 
    7,  4, 8, 42, 9, 51, 6, 60, 0, 45, 1, 26, 4, 73, 2, 86, 3,  2, 5, 59, 
    9, 77, 3, 59, 2, 10, 4, 23, 5, 94, 6, 60, 8, 25, 1, 51, 0,  7, 7, 93, 
    0, 67, 6, 73, 8, 56, 4, 83, 1, 74, 7, 31, 5, 28, 3, 99, 2, 67, 9, 14, 
    5, 24, 4, 91, 6, 56, 0, 87, 7,  2, 9, 60, 3, 49, 1, 57, 2,  9, 8, 10
  };
  const int r632[] = {
    10, 10, // Number of jobs and machines
    2, 98, 5, 45, 9, 12, 0, 83, 8, 68, 4, 51, 7, 70, 6,  3, 1, 62, 3, 10, 
    9, 31, 1, 17, 2, 93, 3, 69, 7, 70, 8, 41, 0, 34, 4,  1, 6, 60, 5, 69, 
    8, 38, 1, 21, 3, 72, 4, 61, 6,  8, 9, 14, 2, 46, 0, 15, 5, 12, 7, 61, 
    8,  3, 6, 48, 0, 58, 7, 42, 1, 94, 2, 78, 9, 69, 5,  9, 4, 37, 3,  9, 
    3, 88, 1, 82, 6, 50, 5, 19, 4, 48, 0, 68, 9, 22, 7, 17, 8, 91, 2, 28, 
    5, 45, 6, 69, 7, 45, 9, 89, 0, 78, 3, 24, 2, 29, 4, 32, 8, 59, 1, 72, 
    8, 62, 3, 84, 4, 90, 9, 45, 1, 27, 2, 74, 7, 88, 5, 33, 6, 42, 0, 84, 
    3, 79, 5, 94, 8, 41, 1, 39, 2, 50, 4, 73, 9, 46, 0, 88, 6, 69, 7, 49, 
    2, 99, 5, 78, 6, 15, 7, 45, 4, 62, 0, 58, 3, 70, 1, 14, 8, 29, 9, 56, 
    7, 33, 5, 80, 3, 25, 6, 81, 0, 54, 4, 56, 2, 85, 9, 88, 8, 82, 1, 40
  };
  const int r633[] = {
    10, 10, // Number of jobs and machines
    1, 67, 0, 22, 6, 25, 8, 86, 3, 11, 7, 58, 5, 13, 9, 96, 2,  8, 4, 18, 
    0, 89, 2, 88, 5, 60, 6, 96, 1, 16, 9, 22, 4, 17, 8, 30, 7, 73, 3, 22, 
    4, 54, 2,  8, 0, 52, 3, 75, 5, 29, 9, 24, 7, 30, 8, 29, 6, 65, 1, 34, 
    5,  9, 9,  6, 4, 92, 2, 58, 1, 25, 0, 26, 8, 70, 6, 45, 3, 54, 7, 85, 
    3, 53, 5, 62, 1, 72, 9, 93, 7, 81, 6, 91, 0, 46, 8, 47, 4, 56, 2, 71, 
    6,  7, 5,  4, 9, 63, 2, 26, 0, 71, 7, 19, 1, 36, 8, 70, 4, 44, 3, 78, 
    1, 17, 4, 14, 6, 65, 2, 57, 0,  9, 8, 54, 5, 64, 9, 88, 3, 53, 7, 69, 
    6,  2, 3, 51, 0, 77, 9, 84, 7, 54, 2, 30, 8, 64, 5, 78, 4, 14, 1, 52, 
    5, 95, 4, 91, 9,  3, 6, 70, 0, 59, 7, 81, 8, 98, 1, 34, 2, 46, 3, 41, 
    6, 66, 8, 89, 5, 11, 4, 20, 2, 97, 0, 14, 9, 13, 7, 46, 3, 39, 1, 93
  };
  const int r634[] = {
    10, 10, // Number of jobs and machines
    0, 78, 7, 10, 4, 68, 1, 50, 9, 76, 6, 36, 8, 35, 3, 67, 5,  1, 2, 40, 
    4, 26, 6, 50, 8, 93, 1, 27, 2, 75, 0, 77, 5, 49, 3, 34, 7, 17, 9, 30, 
    9, 92, 1, 24, 3, 72, 2, 64, 5, 74, 0,  5, 7, 53, 6, 47, 8, 58, 4, 82, 
    6, 35, 2, 12, 0, 64, 1, 91, 5, 79, 3, 15, 4, 52, 7, 70, 8,  8, 9, 92, 
    7, 72, 9,  2, 1, 77, 3, 24, 5,  7, 0, 27, 6, 80, 8, 79, 4, 70, 2, 42, 
    1, 45, 7, 33, 9, 18, 4, 34, 8, 45, 2, 19, 0, 61, 5, 53, 3,  7, 6, 86, 
    9, 60, 7, 81, 4, 10, 3, 14, 0, 61, 2, 42, 6,  4, 8, 91, 5, 35, 1, 67, 
    9, 36, 4, 74, 1, 52, 6, 18, 3, 98, 5, 36, 2, 35, 7, 67, 0, 96, 8,  9, 
    1, 72, 0, 22, 6, 43, 9,  9, 5, 49, 7, 23, 2, 60, 4, 39, 3, 51, 8, 99, 
    2, 48, 6, 51, 4, 39, 9, 30, 5, 61, 1, 42, 0,  7, 3, 49, 7, 39, 8, 91
  };
  const int r635[] = {
    10, 10, // Number of jobs and machines
    2, 33, 6,  2, 7, 32, 0, 17, 4, 17, 5, 59, 9, 39, 1, 23, 3, 61, 8, 57, 
    6, 85, 1, 16, 3, 15, 5, 18, 4, 90, 0, 82, 9, 91, 7,  1, 2, 76, 8, 11, 
    5, 51, 3, 26, 2, 73, 9, 69, 1,  7, 4, 92, 8, 24, 7, 58, 6, 65, 0, 53, 
    2,  2, 1, 90, 3, 53, 0, 35, 8, 14, 9,  4, 6,  3, 4, 81, 5, 19, 7, 76, 
    4, 70, 6, 83, 9, 98, 8, 20, 5, 97, 3, 16, 1, 97, 7,  7, 0, 78, 2, 83, 
    4, 78, 8,  6, 1, 93, 2, 92, 0, 59, 6, 77, 5, 79, 9, 74, 3, 92, 7, 34, 
    8,  1, 3, 12, 6, 24, 5, 17, 4, 74, 9, 39, 2, 98, 7,  8, 0, 90, 1, 78, 
    1, 76, 9, 59, 4, 92, 7, 12, 8, 69, 3, 30, 0,  1, 2, 15, 5, 34, 6, 16, 
    9, 18, 0, 49, 2, 98, 7, 39, 6, 47, 5, 83, 3, 72, 8, 77, 1, 37, 4, 73, 
    7, 81, 0, 85, 2, 34, 4, 42, 5, 14, 3, 19, 1, 45, 9, 30, 6, 23, 8, 11
  };
  const int r636[] = {
    10, 10, // Number of jobs and machines
    3, 62, 2, 94, 7, 37, 8, 92, 4, 85, 0, 49, 9, 87, 6, 49, 5, 30, 1, 36, 
    4,  3, 3, 71, 9, 17, 0, 78, 8, 81, 7, 21, 1, 60, 2, 51, 6, 67, 5, 68, 
    4,  4, 1, 69, 9, 98, 3, 71, 5, 16, 2, 89, 6, 53, 0, 40, 8,  5, 7, 31, 
    6, 15, 9,  8, 4, 91, 1, 74, 8, 80, 2, 31, 3, 75, 5, 56, 7, 77, 0, 82, 
    9, 55, 3, 64, 2, 81, 0, 23, 1, 32, 7, 70, 4, 73, 8, 46, 5, 81, 6, 64, 
    5,  4, 9, 70, 2, 37, 0, 53, 8, 82, 7, 62, 3, 48, 4, 81, 1, 22, 6, 25, 
    4, 93, 6, 37, 5, 76, 1, 73, 2, 75, 0, 31, 7, 63, 8, 30, 9, 26, 3, 73, 
    7, 83, 0, 77, 4, 27, 1, 16, 9, 89, 5, 87, 2,  1, 3, 88, 6, 40, 8, 68, 
    9, 82, 6, 37, 3,  4, 1, 59, 5, 51, 2, 77, 4, 88, 0, 35, 7, 22, 8, 92, 
    7,  7, 9, 59, 4, 42, 6, 18, 5, 23, 8, 13, 0,  1, 1, 24, 2,  9, 3, 32
  };
  const int r637[] = {
    10, 10, // Number of jobs and machines
    2, 97, 1,  4, 6, 54, 0, 70, 3, 57, 8, 78, 4, 18, 9,  4, 5, 30, 7, 88, 
    4, 19, 9, 22, 2, 23, 3, 12, 8, 30, 6, 55, 1, 85, 7, 65, 0, 69, 5, 16, 
    6, 17, 1, 29, 0, 42, 8, 68, 3, 85, 5, 30, 9, 81, 7, 38, 4, 71, 2, 41, 
    9, 99, 3, 84, 5,  1, 2, 42, 0, 22, 7, 60, 1, 80, 8, 13, 6, 43, 4,  5, 
    2, 46, 1, 47, 3, 79, 9, 76, 0, 85, 4, 12, 7,  3, 6, 59, 5, 36, 8, 15, 
    3, 24, 4, 35, 0, 35, 6, 52, 9, 34, 8, 36, 7, 22, 1, 25, 5, 41, 2,  8, 
    2, 88, 0, 58, 3, 17, 6, 20, 7, 69, 8, 26, 1, 70, 5, 75, 4, 95, 9, 29, 
    7, 85, 6, 94, 9, 68, 2, 83, 4,  6, 0, 82, 1, 64, 8, 45, 3, 81, 5, 76, 
    7, 84, 2, 47, 1, 44, 0, 75, 9, 83, 3, 55, 8, 42, 6, 50, 5, 80, 4, 85, 
    2, 59, 7, 62, 6, 86, 0, 30, 5, 39, 1, 41, 9, 51, 8, 76, 3, 87, 4, 60
  };
  const int r638[] = {
    10, 10, // Number of jobs and machines
    4,  8, 6, 64, 7, 43, 8,  4, 3, 21, 0, 36, 9, 30, 2, 91, 1, 65, 5, 17, 
    7, 74, 0, 90, 5,  5, 4, 30, 1, 63, 3, 27, 9, 43, 6, 28, 2, 96, 8, 13, 
    7, 70, 5, 31, 9, 33, 1, 52, 6, 86, 3, 11, 0, 45, 8, 98, 2,  1, 4, 17, 
    4, 88, 2, 87, 6, 63, 7, 71, 1, 95, 3, 69, 8, 23, 5, 73, 9, 29, 0, 22, 
    5, 17, 6, 77, 4, 96, 1, 34, 8, 82, 3, 13, 7, 62, 9, 37, 2, 80, 0, 59, 
    0, 87, 7, 21, 1,  2, 4,  8, 3, 77, 5, 16, 8, 25, 9, 57, 2, 39, 6, 45, 
    8, 84, 6, 68, 1, 98, 7, 37, 2, 97, 3, 85, 9, 11, 4, 10, 5, 75, 0,  4, 
    6, 62, 1, 29, 8, 58, 3,  7, 2, 72, 7, 92, 0, 16, 9, 30, 4, 25, 5, 86, 
    2, 17, 3,  1, 4, 34, 7, 85, 8, 97, 9, 64, 6, 30, 0,  9, 1, 76, 5, 48, 
    9, 80, 1, 45, 7, 52, 5, 95, 8, 16, 0, 10, 6, 71, 2, 56, 4, 33, 3, 37
  };
  const int r639[] = {
    10, 10, // Number of jobs and machines
    2, 49, 6, 61, 4, 48, 0,  6, 8, 90, 9, 64, 1, 92, 5, 98, 3, 27, 7, 79, 
    1, 57, 0, 91, 3, 94, 8, 26, 4, 77, 7, 24, 2, 12, 5, 69, 9, 30, 6, 19, 
    7, 82, 8, 45, 3, 50, 4, 81, 1, 61, 0, 76, 6, 89, 9, 49, 2, 54, 5, 20, 
    5, 11, 6, 34, 3, 39, 4, 55, 1, 87, 7, 23, 8, 51, 0, 25, 2, 24, 9, 67, 
    7, 97, 1, 36, 2, 95, 0,  8, 4, 24, 6,  8, 5, 41, 3,  8, 9, 55, 8, 98, 
    2,  3, 7, 36, 5, 99, 6, 67, 4,  8, 9, 60, 8, 44, 1, 93, 0, 42, 3, 88, 
    7, 50, 8, 81, 4,  8, 1, 80, 3,  7, 5, 73, 9, 71, 6, 91, 0, 45, 2, 46, 
    6, 82, 8, 35, 2, 53, 1, 95, 4, 64, 5, 75, 0, 93, 7,  4, 3,  2, 9, 62, 
    7, 68, 2, 84, 4, 66, 1, 24, 9, 12, 6, 76, 3, 51, 8, 23, 0, 52, 5, 64, 
    6, 43, 3,  8, 0, 92, 5, 33, 4, 70, 9, 81, 1, 56, 2, 38, 8, 45, 7, 99
  };
  const int r640[] = {
    10, 10, // Number of jobs and machines
    6, 87, 8, 16, 2, 98, 3, 41, 7, 95, 0, 84, 1, 90, 9, 22, 4, 15, 5, 24, 
    6, 45, 7, 11, 4, 10, 3, 81, 5, 48, 2, 20, 0, 26, 8, 57, 1, 68, 9, 59, 
    4, 98, 2, 23, 7, 30, 5, 29, 0, 89, 1, 70, 6, 75, 9, 98, 3, 17, 8, 59, 
    6, 26, 2, 44, 5, 40, 3, 96, 7, 63, 1, 82, 4, 26, 9, 81, 0, 20, 8, 56, 
    3, 20, 6, 27, 1, 99, 2, 53, 0, 12, 7, 29, 8,  8, 5, 83, 4, 73, 9, 43, 
    1, 44, 3, 15, 5, 81, 6, 19, 2, 63, 8, 97, 7, 31, 0, 87, 4, 30, 9, 39, 
    2, 65, 0, 56, 1, 93, 7, 72, 5, 39, 4, 79, 8, 34, 9, 86, 6, 69, 3, 26, 
    5, 25, 7, 23, 1,  5, 2, 57, 0, 81, 8, 61, 4, 42, 3, 22, 6,  2, 9, 91, 
    2, 79, 9, 58, 6, 60, 8, 33, 4, 31, 5, 47, 3, 15, 7, 52, 1, 80, 0, 12, 
    6,  6, 0, 83, 8, 82, 9, 15, 5, 62, 1, 39, 3, 80, 2, 97, 4, 95, 7, 87
  };
  const int r641[] = {
    10, 10, // Number of jobs and machines
    8, 41, 9, 54, 7, 72, 5,  5, 2, 69, 0, 71, 4,  1, 1, 11, 6, 73, 3,  6, 
    3, 60, 5, 31, 0, 73, 9, 86, 7, 35, 8, 81, 6, 80, 2, 58, 4, 82, 1, 25, 
    9, 82, 0,  6, 5, 92, 3, 91, 1, 33, 7, 11, 4, 65, 2, 80, 8, 29, 6,  4, 
    6, 17, 3, 44, 2, 17, 0, 84, 7, 21, 5, 31, 4, 70, 8, 49, 1, 79, 9, 29, 
    0, 72, 1, 50, 2, 86, 8, 21, 6, 27, 5, 48, 9, 93, 4, 19, 3,  7, 7, 58, 
    6, 48, 0, 32, 1, 37, 3, 48, 7, 41, 9, 76, 8, 84, 5, 85, 4, 93, 2, 99, 
    2, 73, 6, 31, 7, 66, 8, 25, 3, 78, 5, 33, 0, 15, 4, 14, 1, 42, 9, 89, 
    2, 75, 0, 49, 3, 58, 1, 12, 8, 27, 7, 97, 6, 78, 5, 56, 4, 95, 9, 53, 
    8, 72, 2, 42, 3, 31, 6, 79, 4, 40, 7, 38, 5, 94, 9, 21, 1, 75, 0, 66, 
    3, 48, 1,  8, 7, 61, 2, 93, 4, 38, 8, 80, 0, 49, 6, 91, 9, 70, 5, 19
  };
  const int r642[] = {
    10, 10, // Number of jobs and machines
    6, 23, 5,  5, 9, 10, 1, 98, 0, 37, 8, 30, 7, 36, 3, 41, 2, 81, 4,  7, 
    9, 88, 5, 88, 4, 47, 3,  5, 8, 23, 1, 66, 0, 23, 6, 45, 7, 70, 2, 62, 
    5, 31, 1, 17, 6, 11, 7, 21, 9, 78, 2, 88, 4, 43, 8, 98, 3, 44, 0,  1, 
    7, 89, 1, 54, 8,  7, 5, 80, 3, 67, 2, 50, 0, 64, 4, 47, 6, 97, 9, 69, 
    1, 43, 9, 35, 7, 18, 3, 12, 5, 22, 0, 40, 6, 49, 2, 21, 8, 29, 4, 84, 
    5, 24, 1, 41, 3, 23, 8,  3, 2, 70, 7, 32, 6, 72, 0, 25, 4,  1, 9, 53, 
    8, 48, 0, 42, 9, 37, 3, 99, 2, 79, 5, 57, 6,  9, 7,  5, 1, 88, 4, 15, 
    1, 14, 5, 35, 4, 22, 0, 43, 7, 14, 2, 19, 8, 94, 6, 14, 9, 30, 3, 45, 
    5, 50, 8, 87, 4,  8, 6, 37, 9, 60, 0, 38, 2, 50, 3,  8, 7,  7, 1, 81, 
    1, 66, 8, 27, 5, 71, 9, 69, 6, 47, 3, 92, 7, 22, 4, 12, 2, 99, 0, 83
  };
  const int r643[] = {
    10, 10, // Number of jobs and machines
    1, 17, 4, 52, 0,  7, 3, 56, 5, 29, 7, 37, 6, 25, 8, 69, 9, 15, 2, 52, 
    2, 90, 8,  1, 4, 19, 0, 92, 1, 35, 5, 10, 9, 77, 3,  4, 7, 79, 6, 76, 
    8, 33, 4,  6, 2,  1, 6, 46, 3, 89, 0, 95, 7, 78, 5,  7, 1, 38, 9, 46, 
    6, 32, 0, 42, 4, 99, 8, 96, 3, 72, 9, 45, 1, 10, 7, 32, 2, 25, 5, 59, 
    6, 58, 2, 96, 5, 42, 4, 78, 3, 34, 0, 35, 8,  1, 9, 25, 7, 15, 1, 60, 
    0, 67, 1, 29, 5, 38, 6, 40, 4, 75, 8, 90, 7, 16, 2,  8, 3,  6, 9, 70, 
    8, 15, 3, 53, 9, 69, 2, 47, 7,  1, 0, 25, 4, 93, 5, 79, 6,  2, 1, 37, 
    1, 15, 8, 82, 4, 35, 6, 12, 3,  1, 5, 20, 0, 30, 2, 52, 9, 28, 7, 66, 
    0, 13, 9, 38, 7,  3, 5, 19, 6, 11, 4,  3, 1, 98, 3, 92, 2, 90, 8, 68, 
    0, 75, 8, 60, 1, 72, 4, 67, 7, 46, 3, 75, 9, 79, 6, 54, 2, 35, 5, 84
  };
  const int r644[] = {
    10, 10, // Number of jobs and machines
    2, 14, 5, 13, 0,  8, 9,  3, 7, 68, 4, 34, 3, 61, 6, 20, 1, 48, 8, 32, 
    7, 40, 4, 93, 1,  7, 0, 48, 2, 46, 9,  8, 8,  7, 5, 40, 3, 50, 6, 33, 
    2, 86, 5, 47, 7, 44, 6, 78, 9, 34, 4, 75, 0, 24, 1, 42, 3,  1, 8, 21, 
    8, 59, 7, 87, 4, 50, 1, 82, 0, 99, 9, 46, 6, 22, 3, 36, 2, 62, 5, 84, 
    3, 88, 1,  9, 2, 20, 4, 38, 5, 58, 9, 53, 8, 36, 0, 54, 6, 34, 7, 21, 
    1, 30, 0,  5, 9,  4, 8, 44, 4, 99, 5, 14, 2, 49, 7,  5, 6, 49, 3, 54, 
    9, 76, 5,  9, 7, 81, 6, 97, 2, 64, 8, 97, 4, 77, 3, 91, 1,  8, 0, 37, 
    0, 21, 8, 33, 1, 61, 4, 42, 9, 30, 5, 81, 2, 25, 7, 84, 6, 68, 3, 30, 
    2, 52, 7, 19, 0, 41, 6, 26, 3, 30, 4, 40, 8, 13, 1, 82, 5, 24, 9,  6, 
    1, 12, 2, 30, 7, 13, 3,  3, 0, 45, 4, 58, 5, 62, 6, 50, 8, 10, 9, 12
  };
  const int r645[] = {
    10, 10, // Number of jobs and machines
    2, 94, 3,  4, 9, 54, 7, 55, 4, 98, 1, 13, 6, 61, 8, 47, 5, 11, 0, 44, 
    0, 83, 6, 62, 9, 95, 4, 12, 3, 37, 5, 94, 8, 46, 2, 23, 1,  7, 7, 50, 
    7, 69, 8, 95, 0, 92, 2, 41, 6,  2, 4, 84, 9, 93, 3, 19, 5, 19, 1, 28, 
    4, 73, 8, 68, 9,  1, 1, 10, 5, 99, 3, 58, 0, 19, 6, 86, 7, 14, 2, 97, 
    5, 26, 1, 60, 7,  1, 2, 71, 4,  6, 6,  9, 0, 37, 3, 35, 8, 70, 9, 39, 
    1, 32, 5, 20, 7, 68, 8, 83, 6, 30, 2, 72, 9, 36, 4,  6, 0,  2, 3, 35, 
    3, 47, 0, 82, 6, 96, 9, 89, 5, 25, 4, 18, 1, 10, 7, 44, 2, 49, 8, 37, 
    6, 58, 3, 11, 5, 92, 8, 36, 4, 39, 9, 68, 1, 56, 7, 30, 2, 90, 0,  9, 
    5, 71, 3, 52, 7, 92, 6,  9, 9, 21, 0, 21, 1, 44, 8, 16, 2, 59, 4, 37, 
    1, 75, 6, 16, 3, 79, 0, 55, 7, 42, 2, 43, 5, 44, 9, 13, 4, 18, 8, 64
  };
  const int r646[] = {
    10, 10, // Number of jobs and machines
    4, 84, 7, 61, 6, 93, 0,  1, 1,  6, 2,  9, 3, 90, 9, 67, 8, 84, 5, 80, 
    8, 74, 5, 55, 3, 89, 1, 37, 2, 63, 4, 45, 7, 59, 6, 58, 0, 68, 9,  4, 
    6, 35, 1, 94, 7, 18, 9, 42, 4, 70, 0, 69, 2, 65, 3, 51, 5, 52, 8, 79, 
    5, 62, 4,  3, 8, 66, 2, 69, 7, 84, 9, 36, 0, 51, 1,  7, 6, 21, 3, 49, 
    9, 91, 1,  7, 4, 72, 0, 60, 8, 26, 7, 37, 3, 65, 6, 95, 5, 43, 2, 62, 
    0, 14, 5, 33, 3, 94, 4,  8, 2, 51, 1, 11, 7, 88, 6, 37, 8, 25, 9, 69, 
    6, 81, 7, 28, 1, 89, 0,  8, 4, 29, 2, 37, 3, 86, 9,  1, 8, 99, 5, 56, 
    8,  9, 9, 58, 7, 51, 0, 57, 2,  1, 4, 25, 6, 44, 5, 51, 1, 17, 3, 29, 
    4, 20, 9, 90, 5, 13, 0, 87, 3, 46, 1, 32, 8, 87, 2, 22, 6, 97, 7, 98, 
    8, 80, 4, 99, 9, 64, 6, 28, 3,  3, 0, 96, 2, 45, 5, 90, 1, 43, 7, 34
  };
  const int r647[] = {
    10, 10, // Number of jobs and machines
    0, 61, 5, 96, 4, 13, 8, 36, 2, 36, 6, 26, 9, 46, 3, 77, 1,  3, 7, 58, 
    7, 53, 3, 10, 8, 39, 4, 80, 6, 15, 9, 40, 2, 18, 5, 93, 1, 60, 0, 43, 
    8, 88, 2,  7, 6, 88, 5, 58, 4, 99, 0, 27, 9, 83, 7, 27, 3, 11, 1, 13, 
    5, 21, 0, 71, 4, 89, 1, 16, 6, 66, 9, 15, 7, 44, 2, 96, 8, 60, 3, 96, 
    2, 95, 9, 62, 1, 86, 5, 79, 3, 10, 8, 91, 4, 90, 6, 41, 7, 11, 0, 76, 
    9, 23, 1, 56, 2, 17, 4, 45, 6, 11, 5, 19, 3,  4, 7, 51, 8,  9, 0, 45, 
    2, 51, 9, 39, 3, 30, 0, 78, 5, 56, 8, 58, 6, 18, 7, 55, 4, 50, 1, 16, 
    9, 19, 6, 82, 5, 88, 1, 79, 2, 36, 0, 53, 8, 76, 7,  1, 4, 91, 3, 64, 
    0, 38, 3, 87, 1, 14, 6, 32, 8, 30, 4, 51, 7, 61, 2, 41, 9, 21, 5, 85, 
    4, 81, 3, 88, 1, 60, 9, 16, 5, 48, 8, 74, 6, 58, 7,  2, 0, 38, 2,  4
  };
  const int r648[] = {
    10, 10, // Number of jobs and machines
    5, 20, 7, 61, 8, 14, 6, 49, 0, 76, 4, 95, 3, 24, 2, 36, 9, 54, 1, 67, 
    1, 70, 0, 69, 7, 65, 2, 20, 4, 32, 5, 19, 9, 50, 6, 63, 8, 49, 3, 50, 
    5, 39, 6, 46, 3,  8, 7, 99, 0, 34, 2, 20, 8, 42, 4, 94, 1, 40, 9, 64, 
    6, 82, 0, 55, 1,  9, 9, 81, 7, 43, 3, 60, 5, 64, 8, 33, 2, 54, 4, 96, 
    5, 64, 9,  2, 0, 76, 7, 62, 4, 47, 8, 81, 2, 71, 3, 20, 6, 19, 1, 37, 
    7, 22, 6, 20, 2, 24, 9, 47, 1, 82, 4, 33, 3, 25, 0, 83, 8, 29, 5, 66, 
    3, 83, 7, 41, 9, 36, 6, 27, 4, 79, 1, 29, 5, 76, 0,  8, 8, 62, 2, 66, 
    1,  7, 3, 46, 9, 64, 4, 15, 0, 26, 7, 19, 6, 93, 8, 51, 2, 73, 5, 54, 
    2, 20, 6, 41, 1, 53, 8, 21, 3, 25, 5, 25, 0, 19, 9, 29, 7, 45, 4, 87, 
    7, 32, 4, 95, 1, 99, 5, 55, 6, 20, 0, 87, 2, 44, 3, 58, 8, 40, 9, 44
  };
  const int r649[] = {
    10, 10, // Number of jobs and machines
    7, 32, 1, 64, 3, 14, 6, 72, 9, 99, 8, 94, 4, 67, 0, 44, 5, 73, 2, 42, 
    1, 89, 9, 59, 2, 63, 0, 77, 5, 69, 7, 77, 6, 58, 4,  5, 8, 86, 3,  8, 
    3, 89, 8, 53, 7, 16, 6, 52, 9, 16, 2, 98, 0, 54, 5, 57, 4, 60, 1, 25, 
    1, 15, 6, 23, 8, 45, 3,  8, 9, 65, 4, 57, 0, 53, 5, 29, 7, 29, 2, 89, 
    4,  5, 6, 23, 2, 81, 3,  9, 5, 81, 0, 98, 1, 13, 9, 61, 7, 57, 8, 61, 
    2, 68, 4, 43, 6, 25, 5, 25, 0, 78, 8, 50, 7, 52, 9, 13, 3, 95, 1, 24, 
    4, 59, 6, 68, 1, 41, 9, 63, 0, 17, 8, 61, 2, 16, 5, 54, 3, 47, 7, 78, 
    6, 57, 5, 14, 2, 95, 8, 38, 0, 50, 4, 19, 1, 86, 7, 71, 3, 30, 9, 24, 
    3, 29, 7, 35, 8, 45, 9, 93, 4, 46, 5, 97, 2,  6, 0, 12, 1, 85, 6, 77, 
    4, 59, 5, 21, 6, 24, 0,  5, 9, 44, 2, 44, 1, 86, 7, 80, 8, 84, 3, 45
  };
  const int r650[] = {
    10, 10, // Number of jobs and machines
    7, 37, 8, 74, 4, 35, 9, 31, 6, 47, 1, 59, 3, 38, 5, 97, 0, 48, 2, 58, 
    2, 25, 6, 71, 7, 47, 4, 16, 8, 47, 3, 80, 1, 74, 5, 53, 9, 63, 0, 10, 
    4,  4, 0, 85, 6, 61, 3, 14, 2, 94, 1, 70, 7, 58, 8, 55, 5, 80, 9,  9, 
    7,  7, 3, 78, 2, 74, 4,  1, 1, 44, 6, 24, 9, 44, 5,  2, 0, 11, 8, 85, 
    6, 34, 4, 58, 2, 56, 7, 24, 1, 34, 0, 31, 5, 82, 9, 80, 8, 79, 3, 91, 
    4, 90, 9, 51, 7, 47, 3, 13, 2,  7, 1, 85, 5, 51, 6, 21, 8, 77, 0, 39, 
    2, 94, 7, 25, 3, 96, 0, 42, 1, 81, 5, 85, 9, 63, 4, 99, 8, 30, 6, 41, 
    9, 40, 0, 80, 1, 29, 7, 52, 2, 68, 5, 36, 6, 43, 3, 53, 8, 54, 4, 18, 
    8, 87, 7, 11, 0,  1, 1, 38, 5,  3, 2, 73, 6, 58, 3, 35, 4, 64, 9, 43, 
    1, 97, 6, 67, 8, 35, 5, 71, 7, 26, 2, 42, 0, 57, 4, 27, 9, 99, 3, 79
  };
  const int r651[] = {
    10, 10, // Number of jobs and machines
    0, 62, 7, 86, 8, 59, 6,  6, 9, 54, 3, 39, 2, 77, 5, 95, 1, 91, 4, 88, 
    3, 20, 8,  3, 4, 87, 6, 59, 5, 97, 9, 72, 7, 54, 2, 70, 0, 66, 1, 28, 
    4, 27, 2, 70, 8,  8, 1, 75, 6, 13, 5, 17, 9, 13, 3, 66, 0, 16, 7,  8, 
    2, 91, 0, 59, 4, 47, 7, 41, 3, 97, 6, 39, 8, 70, 1, 69, 9, 22, 5, 58, 
    4, 50, 6, 16, 3, 84, 9, 66, 7, 92, 5, 22, 2, 15, 8, 73, 1, 72, 0, 27, 
    3, 88, 0, 95, 9, 56, 4, 91, 7, 16, 6, 65, 1, 70, 8, 88, 5, 72, 2, 25, 
    6, 77, 4,  3, 8, 80, 7, 18, 2, 52, 5, 86, 3, 80, 1,  7, 9, 66, 0, 41, 
    5, 42, 3, 12, 4, 72, 7, 86, 8, 50, 9, 11, 6, 47, 0,  7, 1, 99, 2, 47, 
    6, 73, 5, 86, 8, 44, 3, 78, 1, 55, 0,  8, 7, 30, 9, 12, 4, 40, 2, 31, 
    3, 65, 0, 28, 6, 17, 8, 78, 2, 74, 7, 12, 1, 99, 5, 24, 4,  1, 9, 33
  };
  const int r652[] = {
    10, 10, // Number of jobs and machines
    0, 14, 4, 57, 1, 73, 3, 75, 7, 45, 9, 89, 6, 99, 8, 84, 5, 16, 2, 19, 
    9, 98, 6, 41, 3,  2, 2, 69, 4, 35, 0, 75, 1, 44, 8, 39, 7, 11, 5, 78, 
    5, 26, 1, 38, 7, 12, 8, 52, 0, 98, 3, 65, 2, 36, 4, 22, 6, 37, 9, 94, 
    6, 69, 1, 15, 5, 55, 3, 39, 9, 28, 4, 52, 0, 91, 8, 98, 7, 37, 2, 15, 
    5, 35, 7, 63, 2, 73, 6, 32, 1, 39, 4, 45, 0, 56, 9, 91, 3, 76, 8, 23, 
    4, 60, 1, 21, 7, 77, 6, 74, 5, 86, 0, 31, 8, 77, 2, 24, 9, 41, 3, 32, 
    3, 53, 0, 88, 9, 19, 8, 21, 4, 65, 2, 36, 7, 45, 5, 21, 6,  4, 1, 79, 
    9, 13, 1,  4, 5, 99, 7, 29, 4, 57, 2, 16, 6, 52, 3, 31, 0, 29, 8, 49, 
    2, 12, 3, 97, 4, 86, 1, 29, 7, 54, 6, 98, 5,  2, 8, 22, 9, 12, 0, 14, 
    8, 90, 3, 60, 0,  1, 4, 83, 7, 61, 6, 83, 5, 61, 9, 56, 1, 75, 2, 68
  };
  const int r653[] = {
    10, 10, // Number of jobs and machines
    6, 16, 7, 48, 9, 12, 8, 87, 4, 22, 0, 72, 1, 90, 2, 23, 5, 22, 3, 29, 
    3, 20, 0, 25, 5, 45, 6, 73, 8, 92, 9, 53, 1, 33, 2, 88, 4, 11, 7, 62, 
    9, 91, 8, 71, 7, 34, 2, 68, 0, 37, 1, 38, 4, 78, 5, 66, 3, 86, 6, 70, 
    5, 97, 1, 48, 3, 28, 4, 74, 2, 24, 8, 66, 0, 88, 9, 18, 6, 99, 7,  1, 
    6, 98, 8, 94, 2, 97, 1, 30, 5, 18, 7, 20, 3, 28, 4, 80, 9, 77, 0, 40, 
    9, 29, 1, 48, 0, 66, 5, 24, 8, 84, 4, 59, 3, 22, 2, 95, 6,  7, 7, 85, 
    2, 23, 7, 85, 4, 37, 0, 66, 5, 66, 6, 92, 3, 28, 8, 91, 9, 62, 1, 46, 
    6, 52, 1, 17, 4, 19, 3, 38, 7, 96, 0, 96, 2, 97, 5, 51, 9, 98, 8, 19, 
    7, 40, 4, 41, 8, 98, 0, 97, 2, 91, 1,  1, 5, 50, 6, 16, 9, 10, 3, 41, 
    0, 37, 8,  6, 3, 78, 1, 76, 5, 41, 7, 90, 6, 91, 2,  5, 4, 63, 9, 10
  };
  const int r654[] = {
    10, 10, // Number of jobs and machines
    2, 68, 3, 85, 5, 44, 0, 28, 4,  8, 9, 20, 7, 87, 6, 83, 1,  7, 8, 31, 
    8, 25, 7, 39, 4, 33, 6, 56, 2, 49, 0,  4, 5, 89, 3, 29, 9, 26, 1,  4, 
    0, 42, 7, 63, 3, 20, 6, 53, 4, 62, 2, 91, 9, 37, 5, 38, 8, 31, 1, 30, 
    1,  4, 3, 48, 9, 37, 0, 28, 2, 57, 4, 17, 8, 61, 6, 51, 5,  7, 7, 89, 
    8, 41, 2,  5, 4, 73, 5, 88, 1, 15, 9, 50, 7,  2, 6, 68, 0, 25, 3, 24, 
    0, 32, 6, 14, 5, 72, 1,  6, 4, 37, 7, 79, 2, 92, 9, 56, 8, 14, 3, 88, 
    2, 76, 4, 92, 9, 32, 8, 16, 1, 32, 6, 58, 5, 68, 0, 29, 3, 36, 7, 91, 
    2, 53, 7, 70, 9, 63, 8, 94, 3, 14, 6, 64, 4, 39, 1, 54, 0, 73, 5,  3, 
    8, 56, 2, 73, 9, 83, 3, 97, 4, 16, 1, 99, 6, 61, 7, 82, 0, 94, 5, 53, 
    4, 92, 6, 29, 0, 25, 2, 68, 1, 12, 5, 40, 3, 85, 9, 22, 8, 84, 7, 93
  };
  const int r655[] = {
    10, 10, // Number of jobs and machines
    1, 61, 2, 90, 9, 16, 5, 14, 8, 36, 3, 15, 0, 91, 6, 74, 4, 67, 7, 14, 
    7, 25, 8, 89, 0, 95, 3, 90, 1, 99, 4, 94, 6, 72, 5,  8, 9,  9, 2,  7, 
    1, 30, 9, 33, 2,  8, 0, 99, 6, 62, 8,  5, 5, 90, 3, 75, 4, 60, 7, 73, 
    6, 61, 7, 70, 0, 58, 2, 30, 8, 85, 1, 39, 4, 86, 9, 82, 5,  2, 3, 56, 
    0, 31, 7, 60, 2, 22, 8,  3, 5, 44, 1, 98, 6, 46, 3,  7, 4, 61, 9, 63, 
    9,  1, 8, 24, 4, 32, 6, 47, 7, 26, 2, 44, 5, 69, 1, 80, 3, 35, 0, 44, 
    5, 92, 0, 58, 1, 80, 3, 78, 2, 42, 8, 29, 9, 87, 6, 67, 4, 47, 7, 37, 
    9, 82, 1, 42, 7, 54, 3,  3, 0, 52, 6, 12, 8, 16, 5, 41, 4, 74, 2, 45, 
    3, 72, 9, 72, 2, 63, 4, 19, 0, 79, 1, 38, 6, 41, 7, 37, 5, 66, 8, 20, 
    2, 47, 9,  5, 7, 92, 1, 56, 6, 66, 5, 39, 3, 85, 4, 92, 8, 12, 0, 85
  };
  const int r656[] = {
    10, 10, // Number of jobs and machines
    1, 92, 6, 23, 7, 75, 5, 95, 2, 91, 0, 76, 3, 42, 4, 86, 8, 43, 9, 25, 
    1, 95, 7, 79, 8, 54, 0, 58, 9,  9, 3, 24, 4, 80, 5, 41, 2, 85, 6, 36, 
    1, 56, 6,  5, 8, 63, 4, 63, 9, 47, 3, 58, 2, 31, 5, 79, 7, 12, 0, 32, 
    2, 27, 1, 88, 0, 58, 9, 30, 5, 73, 8, 32, 4, 86, 3, 15, 7, 14, 6, 50, 
    8, 93, 0, 64, 6, 64, 4, 83, 3, 21, 7, 80, 2, 47, 9,  8, 1, 51, 5, 83, 
    2, 97, 6, 17, 0, 73, 5, 65, 1, 20, 7, 60, 3,  5, 9,  2, 4, 21, 8, 63, 
    3, 47, 6, 76, 1, 20, 7, 14, 4, 11, 9, 87, 5, 22, 0, 42, 2,  2, 8, 66, 
    9, 76, 0, 46, 6, 68, 2, 24, 8, 56, 4, 89, 5, 62, 1, 45, 3, 41, 7, 41, 
    1, 93, 6, 45, 9, 87, 3, 68, 0, 29, 8, 26, 5, 11, 7,  4, 4, 47, 2, 97, 
    2, 35, 1,  4, 4, 57, 7, 94, 3, 10, 0, 58, 5, 31, 6, 27, 9, 42, 8,  3
  };
  const int r657[] = {
    10, 10, // Number of jobs and machines
    9, 84, 6,  5, 3, 93, 7, 71, 5, 61, 2, 38, 4, 20, 8, 58, 1, 23, 0, 95, 
    9, 18, 3, 89, 1, 52, 0, 94, 4, 63, 6, 82, 8, 20, 5, 10, 2, 63, 7, 11, 
    0, 95, 1, 51, 7, 25, 6, 93, 4, 79, 8, 95, 5, 81, 9, 10, 2, 62, 3, 43, 
    5,  6, 4, 94, 6, 49, 1, 65, 7, 53, 3, 89, 9, 67, 0, 13, 2, 99, 8, 70, 
    2, 57, 1, 76, 6,  8, 9, 73, 4, 39, 8, 35, 0, 50, 3, 95, 7, 30, 5, 99, 
    1, 40, 2, 30, 0, 45, 5, 27, 3, 41, 7, 47, 4, 13, 9, 55, 8, 52, 6, 27, 
    1, 10, 2, 38, 7, 45, 9, 21, 0, 61, 8, 94, 3,  3, 5, 52, 4, 64, 6, 65, 
    2, 48, 3, 13, 5, 72, 7, 22, 1, 54, 8, 56, 4, 78, 0, 85, 6, 51, 9, 98, 
    6, 77, 4, 79, 1, 58, 2, 54, 3, 10, 0, 36, 8, 92, 5,  7, 7,  5, 9, 87, 
    3, 63, 4, 77, 0, 34, 2, 81, 8, 61, 1, 67, 9, 25, 6, 59, 5,  6, 7, 75
  };
  const int r658[] = {
    10, 10, // Number of jobs and machines
    3, 88, 9, 86, 8, 24, 6, 12, 2, 45, 0, 80, 7, 86, 5,  1, 1, 37, 4, 42, 
    3, 63, 4, 40, 5, 37, 2, 93, 9, 35, 8,  2, 0, 50, 7, 55, 1, 60, 6, 30, 
    6, 45, 4,  6, 8, 64, 9, 99, 0, 34, 3,  8, 7, 18, 1, 14, 2, 14, 5, 95, 
    9,  5, 1, 28, 8, 75, 6, 14, 4, 33, 7, 26, 3, 11, 5,  1, 0, 71, 2, 96, 
    4, 94, 1, 58, 5, 88, 0,  5, 8, 82, 2, 81, 6, 69, 7,  7, 9, 17, 3, 39, 
    1, 82, 2, 46, 0, 12, 5, 83, 7,  3, 6, 60, 4, 50, 9, 92, 3, 65, 8, 48, 
    0, 44, 7, 83, 8, 35, 4, 41, 3, 77, 2, 27, 1, 99, 5, 81, 6, 57, 9, 32, 
    0, 92, 5, 32, 3, 53, 2, 98, 1, 76, 8, 87, 6, 89, 4, 31, 7, 62, 9, 11, 
    8, 51, 1, 94, 2, 67, 4, 89, 9, 51, 5, 42, 7, 81, 6, 92, 3, 93, 0,  8, 
    2, 15, 4,  3, 9, 76, 5, 32, 1, 46, 6, 48, 7,  2, 0, 45, 8, 68, 3, 83
  };
  const int r659[] = {
    10, 10, // Number of jobs and machines
    0, 72, 7, 99, 5, 95, 6, 98, 4, 79, 8,  7, 1, 50, 2, 87, 3, 29, 9, 76, 
    3, 25, 5, 34, 2, 61, 8, 27, 7, 56, 0, 97, 6, 48, 4, 34, 9, 98, 1,  3, 
    9, 45, 4, 91, 6, 51, 2, 19, 5, 34, 7, 84, 8, 89, 1, 26, 3,  3, 0, 64, 
    1, 70, 2, 27, 8,  8, 7, 68, 9, 93, 5, 44, 0, 13, 4, 66, 3, 14, 6, 43, 
    5, 14, 1, 66, 8, 71, 3, 50, 4, 45, 7, 20, 2, 38, 0, 16, 9, 10, 6, 82, 
    2, 42, 8, 20, 0, 59, 6, 80, 7, 35, 9, 19, 5, 56, 3, 93, 1, 29, 4, 37, 
    6, 79, 5,  2, 3,  7, 2, 76, 9, 35, 7, 94, 0, 73, 1, 76, 4, 38, 8, 59, 
    5, 18, 1, 39, 7, 28, 6,  4, 9, 50, 8, 27, 3, 90, 4, 59, 2, 10, 0,  7, 
    6, 28, 2, 15, 7, 64, 4, 43, 1, 19, 8,  1, 9, 68, 5,  8, 3, 31, 0, 60, 
    1, 72, 5, 76, 2, 73, 8, 56, 3, 59, 0, 20, 9,  6, 6, 56, 4, 22, 7, 58
  };
  const int r660[] = {
    10, 10, // Number of jobs and machines
    2, 43, 9, 59, 3,  4, 4, 29, 0, 19, 7, 35, 6, 66, 8, 98, 1,  7, 5, 24, 
    8, 45, 6, 24, 0, 63, 4, 93, 2, 50, 9, 19, 5, 56, 7, 63, 1, 73, 3, 49, 
    8, 95, 2, 15, 7, 57, 6, 61, 0, 21, 5, 61, 4, 61, 9, 41, 3, 64, 1, 52, 
    9, 98, 2, 53, 6, 44, 3, 26, 5, 59, 8, 42, 0, 32, 1, 85, 7, 29, 4, 60, 
    0, 76, 1, 57, 7, 51, 3, 66, 6, 87, 5, 73, 2, 69, 9, 24, 4, 67, 8, 46, 
    0, 42, 2, 86, 8, 17, 1, 76, 6, 84, 9, 41, 3, 16, 5, 66, 7, 97, 4, 26, 
    8, 36, 9, 49, 3, 49, 6, 40, 0, 31, 7, 60, 2, 73, 1, 81, 4, 12, 5, 13, 
    1, 81, 5, 26, 4, 39, 6, 15, 9,  7, 2, 28, 7, 68, 8, 35, 0, 45, 3, 64, 
    4, 38, 8, 80, 5, 61, 1, 41, 0, 61, 9, 36, 3, 66, 7, 74, 6, 50, 2, 83, 
    9, 28, 7,  7, 4, 69, 0, 14, 3, 41, 6, 23, 2, 31, 5, 82, 8, 95, 1, 41
  };
  const int r661[] = {
    10, 10, // Number of jobs and machines
    4,  9, 7, 36, 5, 75, 3, 63, 6, 23, 1, 46, 2, 86, 8, 13, 9, 22, 0, 24, 
    4, 84, 3, 65, 0, 21, 6, 56, 7, 53, 9, 47, 1,  3, 2, 62, 8, 74, 5, 31, 
    7, 74, 8, 87, 3, 19, 2, 55, 6,  7, 5, 19, 1, 59, 9, 27, 0, 29, 4,  7, 
    6, 84, 3, 50, 7, 75, 0, 59, 2, 58, 1, 73, 5, 71, 4, 20, 8, 97, 9, 24, 
    9, 10, 0, 63, 4, 71, 3, 73, 1, 60, 6, 11, 7, 83, 8, 83, 5,  8, 2, 16, 
    0, 67, 7, 64, 9, 92, 2, 50, 1, 34, 4, 94, 6, 75, 3, 16, 8, 21, 5, 52, 
    9, 97, 4, 42, 8, 95, 2, 35, 0, 74, 1, 70, 5, 66, 7, 32, 3, 92, 6, 92, 
    0, 13, 4, 81, 5,  2, 8, 52, 1, 75, 2, 57, 3, 77, 9, 75, 6, 82, 7, 84, 
    9,  9, 1, 16, 4, 91, 8,  3, 7, 15, 0, 45, 2, 57, 6, 62, 3, 75, 5, 65, 
    1, 98, 2, 17, 9, 72, 8, 30, 7, 17, 5, 11, 3, 12, 4, 93, 6, 25, 0, 34
  };
  const int r662[] = {
    10, 10, // Number of jobs and machines
    1, 22, 6, 70, 3, 53, 0, 41, 9, 72, 2, 41, 8, 10, 5, 92, 4, 54, 7, 95, 
    6, 83, 4, 71, 3, 66, 1, 85, 2, 59, 9, 17, 7, 60, 5, 30, 8, 67, 0, 84, 
    6, 68, 8, 23, 3, 62, 1, 83, 5, 74, 9, 10, 0, 10, 4, 44, 2, 40, 7, 17, 
    7, 98, 9, 22, 0, 40, 6, 89, 3, 45, 1, 19, 2, 27, 4, 63, 5, 49, 8, 37, 
    1, 11, 5, 79, 2, 14, 8, 31, 3,  4, 0, 83, 9, 83, 7, 91, 6, 55, 4, 85, 
    1,  2, 2, 35, 5, 87, 6, 92, 0,  7, 9, 39, 8, 22, 7, 82, 3, 26, 4, 59, 
    2, 53, 1, 50, 8, 52, 5, 69, 4, 35, 3, 37, 6, 71, 9, 64, 7, 78, 0, 31, 
    3, 29, 2, 43, 9, 17, 1,  8, 7, 95, 4, 51, 0, 97, 8, 68, 6, 47, 5,  6, 
    5, 82, 0, 53, 4, 38, 9, 86, 3, 77, 2, 64, 1, 50, 7, 82, 8, 80, 6,  5, 
    6, 84, 4, 50, 0, 58, 5, 89, 7, 82, 2, 17, 3, 52, 1, 79, 9,  5, 8,  2
  };
  const int r663[] = {
    10, 10, // Number of jobs and machines
    1, 29, 3,  3, 8, 30, 9, 75, 2, 54, 5, 31, 4, 39, 6, 14, 0, 25, 7, 51, 
    4, 40, 3,  7, 8, 32, 6, 49, 9, 36, 7, 57, 2, 75, 5, 38, 1, 37, 0,  2, 
    0, 36, 2, 78, 4, 96, 7, 56, 8, 88, 5, 90, 1, 94, 6, 92, 9, 29, 3, 93, 
    3, 55, 8, 82, 7, 70, 6, 89, 9,  2, 1, 17, 4, 91, 0, 66, 2,  1, 5, 77, 
    0, 19, 6, 11, 4, 94, 5, 53, 1, 47, 3, 40, 2, 19, 9, 42, 8, 85, 7, 29, 
    2, 94, 0, 63, 5, 92, 8, 24, 7, 78, 9, 90, 4, 22, 3, 81, 6, 33, 1, 90, 
    5, 47, 7, 96, 8, 13, 1, 98, 6, 57, 9, 84, 2, 52, 0, 32, 4, 57, 3, 58, 
    5, 89, 2, 54, 8, 83, 3, 51, 9, 42, 1, 56, 4, 75, 7, 92, 6, 82, 0,  9, 
    4, 17, 8, 14, 1, 31, 5, 14, 7, 15, 0, 84, 6, 63, 3, 59, 2, 80, 9, 64, 
    9, 94, 8, 16, 3, 26, 4, 76, 1, 75, 2, 43, 5, 96, 6,  2, 7, 38, 0, 61
  };
  const int r664[] = {
    10, 10, // Number of jobs and machines
    9, 44, 1,  8, 7, 89, 6, 97, 3, 16, 5, 48, 4,  8, 0, 84, 8, 37, 2, 48, 
    8, 20, 9, 19, 6, 98, 3, 14, 5,  1, 4,  7, 2, 25, 1, 24, 0, 90, 7, 27, 
    2, 27, 5, 42, 7,  7, 1,  1, 4, 88, 8, 63, 9, 73, 0, 88, 3, 34, 6, 70, 
    1, 80, 9, 37, 8, 88, 3, 89, 5, 40, 2,  1, 7, 10, 0, 47, 4, 64, 6, 55, 
    2, 80, 9, 97, 7, 36, 3, 28, 4, 80, 5, 19, 1, 34, 6, 11, 8, 68, 0, 42, 
    5, 12, 1, 12, 8, 93, 9, 19, 3, 32, 7, 48, 2, 53, 6, 88, 0, 71, 4, 43, 
    1, 75, 8, 57, 0, 63, 4, 55, 3, 17, 9, 35, 2, 10, 7, 16, 6, 34, 5, 77, 
    5, 40, 4, 72, 1, 23, 9, 28, 7, 50, 6, 36, 2, 63, 0, 97, 3, 92, 8, 26, 
    9, 70, 4, 30, 6, 61, 3, 50, 8, 54, 2, 96, 5, 26, 7,  6, 1, 77, 0, 69, 
    3, 44, 1, 34, 4, 60, 2, 62, 0, 16, 9, 39, 8, 23, 5, 32, 7, 80, 6, 63
  };
  const int r665[] = {
    10, 10, // Number of jobs and machines
    2, 33, 7, 79, 9, 70, 3, 86, 1, 71, 5,  6, 6, 70, 8, 39, 4, 60, 0, 19, 
    1, 88, 0, 37, 5, 50, 7, 42, 6, 63, 2, 31, 8, 42, 3, 72, 9, 27, 4, 89, 
    1, 76, 7,  9, 5, 75, 3, 19, 2, 71, 4, 29, 0, 87, 6, 32, 9, 26, 8, 22, 
    0, 61, 2, 71, 4, 20, 5, 31, 8, 81, 7, 27, 3, 19, 9, 60, 1, 77, 6, 55, 
    5, 15, 2, 37, 9, 99, 7, 37, 6, 59, 1, 89, 3, 56, 4,  8, 8, 21, 0,  6, 
    0, 44, 6, 68, 7, 71, 9, 97, 4, 80, 1, 49, 8, 21, 2, 95, 3, 78, 5, 40, 
    1,  5, 9, 87, 8, 39, 5, 39, 6, 35, 0, 79, 2, 19, 4, 69, 7, 74, 3, 86, 
    9,  4, 1, 96, 8, 46, 5, 97, 0, 61, 7, 93, 6, 79, 3, 98, 2, 96, 4, 95, 
    5, 56, 3, 34, 7, 45, 8, 81, 6, 73, 9,  9, 2, 66, 0, 66, 1,  6, 4, 86, 
    5, 28, 0, 99, 1, 75, 8, 38, 9, 92, 7, 56, 4,  4, 2, 86, 3, 78, 6, 23
  };
  const int r666[] = {
    10, 10, // Number of jobs and machines
    2, 39, 7, 95, 5, 82, 9, 50, 6,  8, 1, 52, 0, 44, 4, 70, 8, 61, 3, 56, 
    7, 57, 1, 97, 3, 66, 9, 91, 6, 46, 4, 21, 0, 11, 8, 12, 5, 22, 2, 35, 
    0, 95, 5, 30, 9, 88, 8, 65, 1, 18, 4, 15, 6, 62, 7,  2, 3, 55, 2, 11, 
    1, 48, 8, 98, 3, 20, 9, 47, 2, 48, 6,  3, 0, 82, 4, 24, 7, 34, 5, 45, 
    4, 32, 3, 84, 6, 45, 5, 48, 1,  7, 2, 69, 8, 79, 9, 77, 7, 49, 0, 58, 
    8, 80, 6, 35, 1, 94, 0,  5, 3, 89, 2, 26, 4, 21, 9, 13, 5,  3, 7, 24, 
    7, 81, 3, 82, 8, 50, 1, 76, 5, 92, 9,  2, 2, 33, 0, 23, 4, 83, 6, 57, 
    4, 70, 6,  8, 3, 13, 7, 55, 5, 59, 9, 31, 0, 74, 8, 93, 1, 89, 2, 19, 
    5, 63, 2, 10, 6, 72, 3, 29, 9, 13, 7, 87, 4, 31, 0, 94, 8, 51, 1, 17, 
    7, 37, 5,  4, 0, 58, 8, 78, 3, 58, 2, 26, 4, 95, 9, 53, 6, 36, 1,  5
  };
  const int r667[] = {
    10, 10, // Number of jobs and machines
    4, 27, 7, 76, 5, 13, 2, 19, 0, 49, 3,  8, 8, 79, 6, 31, 9, 72, 1, 99, 
    1, 86, 0,  1, 9, 96, 7, 26, 8, 88, 6, 60, 4, 54, 3, 94, 2, 48, 5, 99, 
    3, 34, 5, 72, 6, 97, 1, 95, 9, 80, 2, 87, 8, 34, 7, 35, 4, 11, 0, 38, 
    4, 12, 1, 93, 0, 18, 2, 38, 6, 89, 7, 51, 9, 50, 3, 78, 8, 55, 5, 41, 
    7, 71, 2, 96, 1, 80, 3, 24, 8, 33, 0, 83, 9, 56, 5, 24, 4, 10, 6, 88, 
    1, 48, 7, 15, 2,  6, 6, 84, 0, 77, 3, 46, 4, 36, 8, 60, 5, 55, 9, 33, 
    2, 47, 7, 93, 4, 83, 9, 73, 5, 91, 8, 99, 0, 98, 6, 56, 3, 72, 1, 73, 
    7, 48, 3, 80, 2, 72, 1, 83, 4, 65, 8, 36, 0, 61, 9, 18, 6, 88, 5,  2, 
    8, 31, 7, 42, 0,  6, 6, 92, 5, 86, 9, 65, 4, 32, 1, 81, 3, 53, 2, 15, 
    7, 61, 5, 93, 0, 34, 3, 86, 6, 74, 4, 77, 9, 15, 2, 90, 8, 52, 1, 76
  };
  const int r668[] = {
    10, 10, // Number of jobs and machines
    0, 24, 3, 12, 4, 43, 6, 77, 8, 31, 1, 40, 5, 16, 2, 93, 9, 31, 7, 81, 
    8, 14, 0, 46, 2, 50, 7, 11, 9, 56, 1, 55, 5, 72, 3, 19, 6, 38, 4, 82, 
    2, 14, 5, 51, 6, 91, 1, 21, 0, 69, 3, 76, 4, 57, 8, 79, 7, 21, 9, 17, 
    2, 31, 0, 49, 3,  4, 8, 60, 4, 81, 6, 92, 7,  9, 1, 26, 9, 44, 5, 29, 
    6, 28, 8,  1, 7, 24, 9, 39, 3, 68, 4, 24, 1, 49, 5, 31, 0, 29, 2, 18, 
    5, 78, 7, 14, 3, 85, 4,  2, 0, 57, 2,  2, 9, 37, 6, 12, 1, 46, 8, 93, 
    0, 43, 5, 91, 4, 82, 8, 16, 7, 53, 6, 98, 3, 92, 9, 64, 2,  1, 1, 67, 
    3,  4, 7,  7, 6, 42, 5, 76, 1,  4, 4, 26, 2, 85, 0, 25, 8, 17, 9, 54, 
    5, 19, 3,  1, 8, 96, 0, 25, 9, 51, 6, 21, 1, 13, 4, 49, 2, 79, 7, 39, 
    2, 71, 3, 37, 4, 76, 7, 29, 5, 44, 9, 88, 0, 42, 6, 59, 8, 93, 1, 90
  };
  const int r669[] = {
    10, 10, // Number of jobs and machines
    7, 62, 8, 23, 1, 44, 4, 41, 0,  9, 3, 25, 9,  2, 2, 87, 6, 11, 5, 31, 
    1, 74, 8, 57, 3, 12, 6, 15, 7,  6, 2, 16, 9, 91, 5, 48, 4, 54, 0, 51, 
    2, 77, 5, 91, 4, 94, 0,  8, 1, 74, 8, 48, 7, 87, 3, 32, 9, 56, 6, 97, 
    4, 31, 7, 60, 2, 57, 8, 51, 6, 68, 1, 50, 3, 62, 0, 99, 5, 51, 9, 43, 
    9,  7, 5,  6, 6,  6, 4,  9, 2, 84, 7, 14, 3, 41, 8, 65, 0, 12, 1, 10, 
    4, 17, 9, 74, 2,  7, 1, 23, 3, 95, 0, 70, 8, 76, 6, 45, 7, 30, 5, 24, 
    9, 77, 1, 76, 4, 95, 6, 27, 0, 18, 7, 32, 5, 34, 8, 17, 2, 40, 3, 19, 
    9, 62, 3,  1, 4, 44, 6, 57, 2, 89, 7, 28, 1, 85, 8, 70, 0, 83, 5, 56, 
    7, 40, 6, 63, 8, 94, 3,  3, 2, 85, 9, 29, 1, 35, 0, 70, 5, 16, 4, 37, 
    2,  9, 0, 39, 6,  4, 8, 24, 4, 55, 9, 72, 5, 42, 1, 49, 7, 44, 3, 89
  };
  const int r670[] = {
    10, 10, // Number of jobs and machines
    5, 39, 8, 94, 2, 26, 4, 74, 9, 11, 3, 95, 7, 46, 6, 43, 0, 92, 1,  6, 
    9,  5, 1, 99, 4, 33, 6,  2, 8, 64, 2, 92, 0, 53, 7, 43, 3, 19, 5, 52, 
    0, 94, 2, 73, 5, 36, 7, 13, 1, 77, 4, 71, 8, 55, 9, 26, 6, 66, 3, 33, 
    7, 37, 2, 70, 9, 11, 3, 82, 1, 57, 0, 33, 4,  4, 8, 70, 5, 42, 6, 98, 
    0, 53, 5, 46, 1, 17, 3, 82, 6, 49, 4, 83, 7, 64, 9, 94, 2, 48, 8, 22, 
    2, 12, 6,  1, 3, 19, 4, 98, 8, 72, 1, 39, 0, 38, 5, 89, 9, 58, 7,  6, 
    0,  5, 4, 67, 7, 42, 8, 66, 5, 62, 3, 48, 2, 80, 1,  1, 9, 24, 6, 72, 
    9, 51, 2, 98, 5, 49, 4,  5, 3, 79, 6, 18, 0, 79, 1, 13, 8, 90, 7, 83, 
    6, 75, 8, 31, 7, 60, 3, 28, 4, 44, 0, 73, 1, 60, 9, 25, 5, 22, 2, 61, 
    5, 57, 2, 44, 6, 73, 8, 73, 4, 24, 3, 64, 0, 60, 9, 26, 7, 16, 1, 68
  };
  const int r671[] = {
    10, 10, // Number of jobs and machines
    1,  8, 3, 33, 4, 57, 2, 34, 0, 38, 6,  4, 9, 54, 7, 96, 8, 41, 5, 33, 
    4, 22, 3, 94, 9, 41, 7, 92, 8, 82, 1, 57, 6, 67, 2, 35, 0, 13, 5, 27, 
    3, 98, 4,  1, 9, 16, 6, 53, 1, 66, 2, 54, 5, 72, 8, 47, 0, 10, 7, 70, 
    0, 10, 1, 88, 5, 43, 4, 60, 3, 21, 8, 95, 2, 37, 9, 39, 7, 12, 6, 79, 
    4, 64, 6, 38, 1, 55, 2, 86, 3, 60, 5, 96, 7, 34, 8, 89, 9, 51, 0, 37, 
    1, 44, 4, 14, 7, 20, 0, 47, 8, 35, 2, 37, 5, 49, 6, 10, 9, 55, 3, 98, 
    4, 92, 5, 72, 2, 61, 7, 90, 8, 71, 3, 47, 9, 62, 0, 55, 1, 50, 6,  2, 
    0, 20, 3, 29, 2,  8, 1,  1, 4, 47, 8, 70, 9, 28, 5, 29, 7, 85, 6, 65, 
    5, 56, 2, 30, 7, 50, 1, 99, 8, 96, 0, 56, 9, 19, 6, 83, 3, 97, 4, 32, 
    4, 78, 7, 51, 3,  7, 5, 17, 2, 68, 0,  7, 6, 24, 9, 77, 1, 67, 8, 60
  };
  const int r672[] = {
    10, 10, // Number of jobs and machines
    2, 91, 8,  7, 7, 33, 3, 68, 5, 93, 6, 57, 4, 59, 0, 58, 1, 21, 9, 50, 
    0, 70, 7, 65, 3, 81, 8, 79, 9, 90, 6, 83, 2, 97, 1, 54, 4, 59, 5, 98, 
    2, 82, 1, 46, 7, 90, 4,  9, 8, 11, 0, 59, 9, 72, 6, 30, 3, 73, 5, 48, 
    1,  1, 4, 21, 2, 73, 8, 80, 6, 83, 7, 53, 9,  1, 5, 85, 0, 62, 3, 84, 
    4, 64, 0, 11, 9, 40, 2, 61, 8, 40, 5, 26, 7, 42, 3, 64, 1, 31, 6, 82, 
    7, 16, 6, 22, 0, 85, 9, 31, 2, 15, 1,  5, 3, 32, 5, 66, 4,  7, 8,  7, 
    5, 16, 1, 27, 3, 79, 0, 24, 6,  9, 2, 34, 7, 65, 9, 77, 4, 36, 8, 70, 
    8, 41, 3, 74, 2, 42, 1, 90, 9, 53, 7, 72, 0, 77, 6, 56, 4, 79, 5, 75, 
    1, 84, 4,  2, 6, 36, 9, 92, 8, 20, 5, 95, 0, 66, 3, 80, 7, 44, 2, 47, 
    3, 16, 6, 11, 9, 37, 2, 48, 5, 64, 7, 35, 0, 21, 4, 39, 1,  2, 8, 72
  };
  const int r673[] = {
    10, 10, // Number of jobs and machines
    2, 32, 8,  8, 7, 37, 3, 55, 4, 32, 1, 79, 9, 47, 0, 98, 5, 58, 6, 84, 
    9, 57, 1, 74, 5, 68, 8, 26, 0, 56, 6, 37, 4, 79, 7, 28, 3, 70, 2, 45, 
    4, 43, 7, 72, 8,  5, 1, 16, 2, 84, 5, 83, 3, 53, 9, 49, 0, 75, 6, 89, 
    2, 59, 1, 57, 0, 51, 5, 24, 9, 72, 8, 47, 7, 63, 3, 17, 4, 72, 6, 21, 
    5, 54, 0, 50, 8,  5, 4, 89, 7,  4, 3, 10, 6, 32, 1, 99, 9, 54, 2, 68, 
    1, 25, 5, 80, 9, 92, 8, 34, 6, 77, 2,  1, 0, 96, 7, 89, 3, 98, 4, 34, 
    4, 69, 5, 54, 9, 72, 6, 61, 8, 90, 2, 13, 3, 54, 1, 47, 0, 16, 7, 79, 
    3, 51, 8, 24, 0, 23, 5, 42, 7,  2, 6, 41, 1, 72, 4, 41, 2, 96, 9, 79, 
    1, 53, 8,  1, 4, 41, 6, 89, 5, 37, 9, 68, 3, 51, 0, 81, 7, 46, 2, 71, 
    9, 59, 3, 70, 8, 79, 0, 61, 7, 36, 2, 86, 6, 30, 1, 59, 5, 20, 4, 47
  };
  const int r674[] = {
    10, 10, // Number of jobs and machines
    6, 90, 8, 34, 0, 36, 2, 64, 3, 91, 7, 26, 4, 25, 5, 34, 9, 42, 1, 27, 
    4, 65, 1, 73, 3, 51, 8, 31, 0, 43, 7, 55, 2, 68, 6, 55, 5, 15, 9, 44, 
    1, 62, 0, 60, 9, 33, 5, 96, 7, 27, 3, 85, 2, 28, 6, 60, 4, 91, 8, 75, 
    9, 45, 5, 98, 6, 19, 0, 37, 2, 48, 3, 52, 4, 40, 7, 81, 8, 57, 1, 35, 
    2, 16, 0, 54, 7, 40, 5, 51, 8, 67, 3, 91, 4, 31, 9, 34, 6, 40, 1, 73, 
    7, 66, 1, 14, 0, 28, 5, 80, 3, 23, 6, 41, 8, 59, 9, 10, 4,  4, 2, 91, 
    2, 85, 8, 81, 5, 89, 9, 65, 1, 54, 6, 35, 0, 99, 7, 45, 3, 96, 4, 51, 
    7, 96, 9, 94, 6, 88, 1,  9, 3, 11, 2, 85, 8, 72, 5, 60, 0, 45, 4, 73, 
    7, 64, 2, 49, 6, 78, 8, 96, 3, 56, 1, 27, 4, 72, 5, 50, 0, 86, 9, 53, 
    5, 33, 2, 44, 8, 22, 6,  5, 1, 42, 3,  9, 9, 37, 4, 94, 0, 89, 7, 49
  };
  const int r675[] = {
    10, 10, // Number of jobs and machines
    2, 76, 9, 77, 7, 47, 6, 34, 3, 55, 8, 76, 4,  2, 5, 26, 1, 81, 0, 36, 
    9, 89, 1, 62, 0, 97, 2, 17, 5, 78, 8,  2, 7, 57, 4,  3, 6, 83, 3, 22, 
    8, 68, 2, 14, 9, 66, 1,  7, 0,  7, 7, 89, 4, 47, 6,  5, 3, 64, 5, 43, 
    5, 81, 9, 77, 6, 10, 8, 37, 4, 47, 0, 66, 1, 30, 2, 38, 3, 63, 7, 60, 
    4, 54, 3, 83, 7, 59, 5, 39, 8, 74, 1, 20, 0, 33, 6, 12, 9, 38, 2, 88, 
    7, 79, 9, 31, 1, 72, 6, 20, 5, 45, 4, 78, 0, 74, 3, 83, 8, 56, 2, 56, 
    0, 94, 2, 47, 9, 49, 6, 57, 3,  4, 4, 42, 5, 92, 7, 74, 8, 45, 1, 38, 
    1, 97, 6, 57, 0, 42, 9, 91, 5, 27, 8,  5, 3, 63, 4,  3, 2, 42, 7,  9, 
    7, 89, 1, 28, 3, 39, 0, 50, 2, 42, 9, 58, 4, 82, 8, 88, 6, 20, 5, 32, 
    4,  6, 2,  1, 0, 88, 8, 73, 9, 61, 7, 79, 1, 36, 6, 66, 5, 16, 3, 41
  };
  const int r676[] = {
    10, 10, // Number of jobs and machines
    9, 24, 8, 43, 1, 12, 4, 80, 3, 16, 7, 60, 2, 48, 0, 67, 5, 92, 6, 81, 
    2, 95, 0, 27, 6, 89, 4, 71, 3, 78, 8, 90, 5, 65, 1, 40, 7, 91, 9, 84, 
    9, 56, 5, 93, 1, 79, 0, 79, 8, 89, 2, 64, 3, 82, 4,  6, 7, 25, 6, 80, 
    0, 58, 2, 38, 1, 52, 6, 85, 8, 18, 5, 56, 9, 78, 3, 39, 4, 66, 7, 25, 
    9, 27, 6, 67, 7, 31, 4, 53, 0, 35, 3, 60, 1, 79, 2, 18, 8, 31, 5, 24, 
    8, 75, 9, 81, 0, 84, 6,  1, 7, 87, 2, 80, 3, 94, 5, 75, 1, 94, 4, 37, 
    9, 85, 2, 50, 4, 82, 5, 35, 7, 38, 8, 76, 1, 86, 0, 54, 6, 81, 3, 81, 
    5, 23, 6, 60, 0, 63, 9,  1, 1, 45, 7, 29, 2, 81, 8, 26, 3, 44, 4, 26, 
    7, 79, 4, 85, 0, 85, 5, 10, 1, 20, 8, 30, 2, 52, 6, 15, 9, 63, 3, 12, 
    1, 21, 8, 15, 0, 93, 5, 95, 3, 60, 6, 89, 2, 46, 7,  3, 9, 52, 4, 80
  };
  const int r677[] = {
    10, 10, // Number of jobs and machines
    7, 23, 6,  5, 8,  6, 2, 36, 3, 13, 5, 40, 9,  6, 0, 42, 1, 84, 4, 48, 
    5, 40, 8, 23, 3, 17, 4, 71, 2, 39, 0, 24, 7, 90, 1, 51, 9, 40, 6, 49, 
    6, 30, 9, 39, 4, 80, 8, 63, 1, 41, 2, 56, 0, 32, 3, 17, 7, 97, 5, 22, 
    4, 31, 1, 88, 5, 71, 7, 47, 6, 47, 8, 15, 0, 42, 3,  8, 9, 40, 2, 19, 
    1, 34, 8, 38, 7, 27, 6, 18, 0, 56, 9, 98, 4, 75, 3, 96, 2, 85, 5,  6, 
    0, 47, 4, 82, 7, 52, 2, 40, 1, 70, 9,  6, 6, 25, 8, 68, 3,  3, 5, 10, 
    9, 74, 7,  8, 2, 86, 6, 62, 3, 17, 8,  1, 1, 90, 4, 85, 5, 43, 0, 44, 
    8, 21, 0, 53, 4, 28, 2, 78, 6, 34, 7, 40, 5, 40, 1,  5, 3, 95, 9,  9, 
    5, 42, 7, 24, 3, 10, 6, 29, 1, 30, 9, 34, 8, 32, 4, 75, 2, 49, 0, 52, 
    2, 83, 4, 50, 9, 37, 1, 69, 3, 76, 8, 18, 6, 79, 5, 39, 7, 41, 0, 69
  };
  const int r678[] = {
    10, 10, // Number of jobs and machines
    2, 91, 1, 38, 6, 29, 7, 24, 3, 40, 4, 26, 0, 59, 8,  1, 5, 20, 9,  8, 
    3, 63, 2, 32, 8,  4, 7, 65, 4, 18, 1, 36, 5, 31, 0, 92, 6, 63, 9, 56, 
    1, 89, 8, 86, 0, 19, 6, 61, 2, 27, 3,  7, 9, 66, 5, 54, 7, 63, 4,  5, 
    2, 42, 6, 30, 5, 15, 7,  7, 8, 47, 0, 18, 1,  6, 4, 49, 3, 31, 9, 86, 
    9,  1, 2, 18, 8, 61, 5, 82, 7, 16, 3, 97, 6, 23, 0, 34, 4, 28, 1, 49, 
    5, 31, 0, 94, 4, 79, 1, 14, 6, 26, 8, 70, 9,  5, 7, 62, 2, 52, 3, 80, 
    0, 44, 3, 21, 9, 38, 7, 88, 6, 27, 8, 31, 2, 69, 4, 69, 5, 54, 1,  8, 
    8, 31, 5, 33, 1,  1, 0, 14, 6, 45, 7, 35, 4, 11, 3, 30, 2, 29, 9, 76, 
    9, 70, 3, 36, 1, 85, 7, 62, 4, 70, 8, 33, 6, 34, 0, 68, 2, 28, 5, 12, 
    8, 12, 4, 91, 6, 16, 3, 92, 9, 62, 2, 13, 5, 79, 0, 42, 1, 35, 7, 24
  };
  const int r679[] = {
    10, 10, // Number of jobs and machines
    9, 18, 0, 91, 3,  2, 7,  1, 1, 12, 2, 14, 6, 79, 8,  9, 5, 93, 4, 79, 
    2, 65, 7, 15, 6, 12, 3, 25, 4, 73, 1, 16, 8, 83, 9, 68, 0, 11, 5, 81, 
    9,  4, 6, 31, 1, 48, 8,  5, 7, 85, 4, 96, 5, 45, 3,  1, 0, 46, 2, 54, 
    7, 61, 4, 94, 3, 28, 1, 97, 6, 60, 5, 38, 0, 67, 2, 70, 9, 87, 8, 41, 
    5, 18, 4, 21, 9,  2, 3, 50, 1, 22, 6, 22, 7, 71, 2, 87, 0, 98, 8, 41, 
    1, 20, 3, 19, 5, 43, 2, 39, 6, 47, 9, 32, 0, 31, 8, 30, 7, 27, 4, 31, 
    3,  6, 4, 55, 7, 57, 5,  6, 6, 71, 8, 88, 2, 47, 0, 22, 1, 74, 9, 66, 
    6, 26, 0,  8, 1,  3, 2, 47, 5, 13, 4, 71, 9, 81, 8, 29, 3, 54, 7,  9, 
    2, 84, 5, 52, 1, 56, 7, 66, 9, 57, 3, 53, 0, 92, 8, 74, 4, 51, 6, 21, 
    8, 73, 2, 62, 4, 82, 6,  5, 9, 64, 0, 89, 5, 80, 7, 27, 3, 53, 1, 60
  };
  const int r680[] = {
    10, 10, // Number of jobs and machines
    2, 43, 7, 26, 6, 19, 0, 23, 1, 50, 3, 44, 4, 47, 8, 48, 5, 44, 9, 73, 
    6, 97, 1, 33, 3, 55, 2, 19, 9, 86, 4, 71, 7, 81, 8, 40, 5, 49, 0, 93, 
    6, 47, 5, 29, 2,  5, 7, 95, 4, 31, 8, 40, 3, 21, 9, 10, 1, 15, 0, 74, 
    4,  6, 1, 37, 2, 21, 9, 16, 3, 46, 6, 37, 8, 84, 0, 81, 7, 92, 5, 77, 
    1, 13, 6, 70, 2, 71, 8, 28, 3, 99, 9, 63, 5,  9, 4, 71, 0, 67, 7,  2, 
    0, 62, 6, 97, 7,  6, 9, 88, 5, 38, 3,  1, 4, 60, 8, 29, 1, 71, 2, 77, 
    2, 94, 7, 67, 8,  9, 1, 29, 6, 89, 4, 56, 3, 20, 0, 55, 5, 12, 9, 51, 
    0, 46, 4, 11, 2, 34, 8, 37, 6, 32, 5, 91, 7, 77, 3, 76, 9, 98, 1, 21, 
    9, 21, 4, 22, 8, 55, 5, 85, 0, 74, 6, 65, 2, 50, 3, 78, 1, 38, 7,  6, 
    6, 32, 4,  4, 1, 63, 2, 54, 9, 85, 0, 64, 8, 74, 7, 41, 5, 31, 3, 69
  };
  const int r681[] = {
    10, 10, // Number of jobs and machines
    5, 52, 9, 98, 4, 60, 2, 18, 1, 11, 0, 15, 3,  6, 6, 62, 7, 51, 8, 49, 
    4, 31, 5, 70, 9, 50, 7, 36, 6, 45, 3, 46, 0, 83, 8, 94, 2, 18, 1, 51, 
    4, 30, 7, 96, 0, 16, 6, 13, 3, 45, 8, 38, 2, 12, 5, 46, 9, 40, 1, 78, 
    2, 81, 0, 49, 7, 92, 4, 43, 8, 35, 9,  4, 5, 12, 6, 54, 1, 44, 3, 76, 
    5, 86, 0, 38, 2,  6, 7, 83, 3, 94, 8, 90, 4,  7, 1, 16, 6, 63, 9, 56, 
    6, 76, 5, 16, 0, 71, 7, 10, 9, 48, 8, 21, 2, 92, 1, 30, 3, 61, 4, 16, 
    9, 84, 5, 68, 1, 74, 7, 93, 3, 40, 8, 60, 2, 30, 4, 93, 6, 94, 0, 91, 
    2, 24, 0, 95, 5, 98, 8, 63, 4, 24, 9, 74, 3, 14, 1, 19, 6, 86, 7, 23, 
    4, 73, 8, 30, 6, 92, 7, 62, 9, 46, 2, 92, 3, 61, 0, 30, 1, 54, 5, 94, 
    0, 27, 2, 34, 7, 35, 8, 56, 6, 89, 5, 85, 3, 72, 9, 44, 1, 76, 4, 29
  };
  const int r682[] = {
    10, 10, // Number of jobs and machines
    6, 30, 7, 21, 8, 84, 4, 50, 0, 41, 3, 87, 5, 34, 1, 70, 2, 79, 9, 10, 
    3, 29, 6, 22, 5, 88, 4, 58, 8, 96, 2, 66, 7, 84, 0, 78, 1, 39, 9, 85, 
    4, 89, 7, 10, 8, 80, 0,  7, 9, 39, 6, 65, 3, 74, 2, 44, 1, 61, 5, 91, 
    6, 51, 0, 52, 2, 45, 3, 13, 5, 22, 7, 45, 8, 45, 9, 29, 4,  2, 1, 27, 
    1, 28, 9, 58, 3, 74, 8, 50, 4, 21, 2, 20, 0, 46, 7, 81, 5, 95, 6, 48, 
    1, 10, 6, 83, 9, 89, 7, 54, 0, 70, 5, 93, 4, 54, 3, 61, 8, 25, 2,  2, 
    1, 27, 4, 24, 6,  6, 0,  5, 7, 78, 2, 61, 8, 55, 5, 87, 9, 13, 3, 13, 
    0, 81, 8, 70, 6, 90, 4,  1, 1, 96, 3, 20, 9, 18, 5,  3, 2, 31, 7, 91, 
    9, 29, 5,  2, 4, 94, 3, 52, 6, 97, 7, 72, 2, 45, 1, 75, 8, 30, 0, 65, 
    6, 97, 9, 93, 8, 47, 7, 74, 0, 49, 2, 87, 3, 79, 5, 70, 1, 79, 4,  8
  };
  const int r683[] = {
    10, 10, // Number of jobs and machines
    3, 94, 2, 39, 6, 47, 7, 26, 8, 37, 5, 77, 1, 49, 9, 88, 4, 17, 0, 43, 
    7, 23, 9,  2, 4, 17, 6, 96, 5, 30, 0,  8, 1, 91, 8, 79, 3, 24, 2, 41, 
    1, 96, 8, 42, 5, 19, 6,  4, 7, 23, 4, 71, 0, 55, 9, 61, 2, 71, 3, 58, 
    7, 71, 6, 73, 5, 77, 9, 45, 3, 61, 8, 88, 4, 83, 1, 92, 0, 59, 2,  8, 
    8, 66, 4, 20, 6, 32, 9, 96, 5, 57, 0, 37, 3, 26, 1, 31, 2, 25, 7, 10, 
    0, 44, 4, 30, 7, 10, 2, 69, 6, 19, 8, 89, 3, 56, 9, 97, 5, 93, 1, 56, 
    7, 35, 1, 62, 3, 60, 0, 56, 8, 11, 9, 99, 5, 72, 4, 54, 2, 79, 6, 24, 
    8, 37, 7, 18, 2, 38, 9, 68, 1, 37, 0, 14, 5, 43, 3,  8, 6, 60, 4, 33, 
    4, 78, 6,  3, 9, 97, 3, 42, 8, 74, 5, 87, 1, 91, 2, 55, 7, 78, 0, 91, 
    3, 24, 1, 12, 8, 61, 0, 66, 7,  4, 6, 76, 5, 93, 9, 37, 2, 97, 4, 12
  };
  const int r684[] = {
    10, 10, // Number of jobs and machines
    4, 47, 6,  4, 7, 19, 8, 65, 1, 81, 5, 90, 3, 93, 9,  4, 0, 10, 2, 68, 
    8, 45, 3, 90, 9, 60, 7, 93, 5, 56, 4, 82, 1, 84, 2, 22, 0, 91, 6, 94, 
    4,  4, 1, 65, 3, 43, 5, 79, 6, 87, 7, 57, 0, 94, 8, 90, 9, 63, 2, 68, 
    6, 83, 8, 70, 5, 42, 0, 26, 9, 23, 7, 87, 4, 94, 3, 30, 2, 83, 1, 27, 
    9, 51, 5, 66, 6, 30, 1, 31, 4, 35, 2, 87, 3, 24, 7, 87, 8, 44, 0, 39, 
    3, 59, 9, 60, 5, 63, 4, 40, 2, 77, 7, 99, 1, 86, 6, 15, 0, 10, 8, 20, 
    6, 32, 0, 84, 1, 22, 9, 49, 7, 19, 4,  5, 8, 30, 2, 67, 3, 18, 5,  4, 
    0, 70, 1, 69, 6, 72, 2, 20, 3, 79, 8, 58, 9, 56, 7, 85, 4, 75, 5, 84, 
    2, 69, 3, 80, 6, 79, 8, 86, 5, 68, 7, 68, 9, 87, 1, 10, 4, 64, 0, 18, 
    7, 52, 8, 93, 1, 66, 5, 73, 9, 90, 3,  7, 2, 94, 6, 59, 0, 18, 4, 53
  };
  const int r685[] = {
    10, 10, // Number of jobs and machines
    1, 48, 0, 94, 7, 87, 6, 29, 2, 84, 8, 86, 9,  8, 4, 19, 5, 91, 3, 48, 
    6, 97, 2,  6, 0, 36, 4, 93, 5, 83, 1,  1, 7, 31, 8, 55, 3, 44, 9, 28, 
    0, 24, 4, 23, 2, 31, 9, 35, 6, 37, 7, 63, 5,  3, 1, 61, 8, 93, 3, 75, 
    7, 21, 0,  2, 1, 11, 6, 47, 2, 84, 8, 70, 5, 50, 4, 51, 9,  5, 3, 12, 
    3, 51, 1, 94, 9, 90, 0, 40, 7, 98, 8, 43, 2,  8, 6, 70, 4, 59, 5, 95, 
    0, 33, 2, 77, 9, 67, 6, 68, 4, 65, 8, 42, 1, 22, 7, 25, 3, 45, 5, 87, 
    2, 98, 0, 65, 8, 46, 4, 72, 5, 93, 7, 92, 6, 36, 1, 90, 3, 19, 9, 92, 
    8, 40, 3, 13, 6, 61, 4, 63, 5, 89, 2, 61, 7, 30, 1, 55, 0, 51, 9, 53, 
    3, 51, 9, 75, 0, 99, 4, 78, 8, 53, 5, 94, 7, 31, 6, 73, 1, 42, 2, 52, 
    2, 59, 6, 58, 3, 16, 7, 60, 1, 96, 0, 90, 8, 15, 9, 25, 5, 35, 4, 82
  };
  const int r686[] = {
    10, 10, // Number of jobs and machines
    4, 63, 5, 87, 2, 70, 7, 71, 3, 24, 9, 89, 1, 80, 0, 87, 6, 85, 8, 66, 
    5, 84, 6, 66, 3, 64, 8, 32, 1, 63, 7, 38, 9, 39, 4, 29, 2, 23, 0, 63, 
    0, 46, 4,  3, 7, 59, 5, 35, 1, 72, 3, 64, 9, 62, 6, 20, 2, 44, 8, 58, 
    6, 62, 8, 27, 5,  1, 2, 82, 1, 14, 4, 50, 3, 46, 7, 76, 9, 76, 0, 39, 
    6, 37, 5, 53, 9, 33, 7, 10, 2, 99, 3, 84, 0, 92, 1, 32, 8, 17, 4, 97, 
    6, 99, 9, 63, 0, 44, 5, 73, 4, 33, 2, 36, 1, 80, 3, 53, 8, 97, 7, 38, 
    8,  5, 3, 30, 2, 61, 9, 57, 0, 45, 6, 37, 7, 21, 1, 72, 4, 63, 5,  6, 
    7, 96, 2, 41, 4, 45, 8, 50, 6, 76, 5, 28, 0, 31, 3, 35, 9, 22, 1, 85, 
    3, 65, 8, 86, 6, 94, 9,  2, 2,  5, 4, 39, 7, 85, 5, 30, 0, 68, 1, 17, 
    9, 36, 3, 61, 8, 53, 0, 97, 4, 99, 7, 71, 2, 84, 5, 19, 6, 13, 1, 48
  };
  const int r687[] = {
    10, 10, // Number of jobs and machines
    7, 66, 6, 32, 4, 13, 3, 55, 1, 89, 5, 74, 2, 82, 8, 44, 0, 97, 9,  2, 
    3, 33, 2, 27, 8, 57, 1, 25, 7, 54, 9, 95, 5, 41, 6, 38, 0, 23, 4, 71, 
    6, 84, 9, 80, 2, 31, 1, 93, 8, 81, 3, 43, 4, 80, 7, 15, 5, 18, 0, 68, 
    9, 56, 5, 96, 8, 83, 2, 66, 4, 80, 7, 31, 0, 52, 1, 60, 3, 21, 6, 45, 
    1,  5, 2, 18, 6, 73, 7, 52, 8, 10, 4, 29, 0, 78, 9, 18, 5, 48, 3, 62, 
    6, 91, 5, 96, 9, 79, 4, 45, 7, 18, 8, 24, 2, 59, 3, 92, 0, 93, 1, 69, 
    8, 38, 4, 52, 1, 64, 7, 25, 3, 94, 5, 68, 9, 96, 0, 40, 6, 73, 2, 55, 
    4, 93, 3, 76, 5, 50, 7, 76, 2,  5, 8, 17, 9, 69, 0, 40, 6, 46, 1, 63, 
    5, 58, 7, 29, 0, 71, 9, 47, 8, 37, 2, 97, 4,  1, 3, 14, 6, 89, 1, 92, 
    6, 72, 4, 12, 1, 44, 7, 15, 9, 93, 0, 19, 8, 52, 5, 76, 3, 97, 2, 54
  };
  const int r688[] = {
    10, 10, // Number of jobs and machines
    5, 19, 8, 26, 2, 21, 7, 87, 0, 39, 3, 37, 9, 40, 1, 31, 4, 31, 6, 37, 
    4, 85, 9,  8, 0, 68, 5, 30, 6, 18, 7, 57, 2, 13, 3, 58, 8, 34, 1, 54, 
    9, 65, 0, 39, 4, 22, 2, 87, 1, 85, 8, 65, 7, 84, 5, 85, 3,  9, 6,  8, 
    2, 37, 1, 20, 8, 64, 5, 61, 7, 75, 0, 69, 6, 82, 4, 87, 3, 62, 9, 95, 
    9, 40, 1, 73, 4,  2, 2, 52, 8, 98, 3, 76, 6, 95, 0, 11, 7, 20, 5, 45, 
    7, 39, 4, 60, 9,  1, 3, 94, 5, 48, 1, 38, 8, 83, 0, 58, 2, 43, 6, 33, 
    7, 92, 0, 55, 6, 21, 5, 16, 3, 45, 2, 83, 8, 75, 9, 54, 4, 60, 1, 53, 
    3, 75, 6, 56, 5, 43, 0, 61, 7, 49, 8, 82, 4, 27, 2, 35, 9, 63, 1, 23, 
    6, 53, 5, 27, 9, 16, 0, 30, 1, 69, 3, 43, 2, 14, 7, 44, 8, 89, 4, 87, 
    6, 84, 5, 36, 9,  8, 3,  5, 0, 47, 4, 27, 8, 78, 7, 76, 2,  7, 1, 45
  };
  const int r689[] = {
    10, 10, // Number of jobs and machines
    5, 95, 0,  2, 8, 23, 2, 34, 7, 91, 9, 99, 1, 42, 6, 64, 3,  5, 4, 35, 
    8, 27, 1, 56, 6, 29, 5, 55, 4, 77, 9,  4, 7, 41, 2, 43, 0, 66, 3, 34, 
    1,  7, 8, 53, 2, 41, 0, 84, 3, 41, 6, 27, 7, 13, 9, 44, 4, 34, 5,  6, 
    2, 29, 3, 66, 6, 38, 5, 61, 7, 67, 1, 51, 9, 51, 4, 61, 8, 62, 0, 66, 
    2, 75, 5, 52, 6, 49, 8, 88, 4, 69, 0,  5, 7, 66, 9, 87, 3, 42, 1, 43, 
    5, 47, 4, 50, 2, 19, 1, 77, 7, 24, 6, 13, 3, 20, 8, 60, 9, 90, 0, 29, 
    9, 93, 4, 30, 0, 54, 3, 41, 7, 33, 5, 30, 6, 31, 2, 69, 1, 71, 8, 54, 
    5, 99, 3, 55, 9, 25, 6, 14, 1, 42, 2, 54, 4, 73, 8, 40, 7,  9, 0, 98, 
    9, 65, 3, 87, 6,  1, 5, 92, 4,  2, 2, 22, 8, 59, 0, 65, 1, 34, 7,  6, 
    3, 91, 9, 16, 1, 70, 0, 21, 8, 27, 6, 24, 4, 68, 7, 13, 5, 39, 2, 83
  };
  const int r690[] = {
    10, 10, // Number of jobs and machines
    8,  2, 6,  9, 0, 76, 4, 61, 5, 78, 2, 97, 7, 56, 3, 53, 9, 65, 1, 62, 
    9, 97, 3, 52, 4, 99, 2, 21, 6, 99, 0, 48, 1, 27, 5, 54, 8, 44, 7, 47, 
    3, 69, 0, 83, 4, 68, 9, 81, 2, 54, 8, 51, 1, 85, 5, 24, 6, 51, 7, 65, 
    4, 10, 1, 87, 9, 57, 5, 56, 2, 16, 7, 92, 3, 46, 0, 38, 6, 29, 8, 71, 
    4, 92, 3, 16, 1, 23, 5, 93, 9, 20, 8, 51, 2, 25, 0, 23, 7, 63, 6, 28, 
    2, 99, 5, 89, 9, 52, 6, 15, 1, 46, 8, 50, 7, 70, 4,  9, 3, 72, 0, 70, 
    5, 57, 3, 35, 6, 79, 1, 72, 2, 70, 7, 28, 8,  6, 0, 26, 4, 18, 9, 72, 
    0, 21, 2, 91, 3, 88, 4, 38, 7, 79, 5, 89, 6, 31, 1,  7, 8, 91, 9, 96, 
    9, 25, 7, 78, 6, 96, 1, 61, 4, 25, 3, 70, 0, 53, 8, 99, 5, 60, 2, 50, 
    2, 68, 1, 35, 9,  9, 3, 14, 5, 50, 6, 42, 4, 70, 7, 23, 8, 49, 0, 78
  };
  const int r691[] = {
    10, 10, // Number of jobs and machines
    7, 75, 9, 24, 3, 30, 1,  2, 5, 99, 6, 77, 8, 87, 2, 60, 4, 68, 0, 83, 
    4, 71, 9,  7, 1, 72, 0, 12, 7, 16, 3, 50, 2, 56, 8, 83, 6, 36, 5, 24, 
    4,  5, 7, 74, 2, 28, 8, 88, 3, 80, 0, 18, 6, 89, 5, 50, 1, 69, 9, 19, 
    2, 93, 7, 21, 4, 79, 5, 77, 8, 16, 9, 57, 1, 46, 3, 34, 0, 95, 6, 75, 
    4, 16, 8,  9, 0, 89, 1, 78, 6, 83, 5, 34, 9, 10, 7, 42, 3, 25, 2, 38, 
    9, 60, 7, 59, 0, 14, 2, 35, 6, 84, 8, 64, 1, 81, 3, 20, 5, 78, 4, 43, 
    2, 98, 7, 93, 3, 45, 0, 30, 5, 74, 1, 87, 6, 15, 9, 62, 8, 88, 4, 94, 
    9, 11, 4, 67, 5, 66, 8, 40, 2, 11, 3, 62, 7,  3, 1, 18, 0, 25, 6,  9, 
    9, 96, 6, 55, 8, 48, 2, 43, 1, 11, 0, 10, 4, 85, 3, 32, 5, 76, 7, 73, 
    9, 66, 0, 24, 2, 59, 3, 11, 7, 91, 4, 83, 6, 89, 5, 71, 1,  6, 8, 11
  };
  const int r692[] = {
    10, 10, // Number of jobs and machines
    5, 47, 3, 22, 0, 15, 7, 51, 4, 10, 6, 10, 2, 45, 8, 84, 1, 60, 9,  6, 
    6, 95, 9, 19, 3,  9, 0, 85, 8, 90, 1, 99, 4, 70, 5, 80, 2, 15, 7, 74, 
    6, 17, 5, 53, 0, 51, 4, 31, 9,  9, 3, 10, 7, 19, 2, 97, 1, 78, 8, 46, 
    7, 38, 0, 89, 4, 78, 9, 39, 6, 71, 1, 63, 3, 65, 5, 49, 8, 74, 2, 94, 
    6, 92, 8,  3, 4, 82, 0, 91, 5, 39, 2, 85, 1, 25, 9,  3, 7, 96, 3, 94, 
    0,  3, 6, 15, 8, 97, 1, 56, 9,  1, 7, 19, 5, 11, 4,  9, 2, 36, 3, 88, 
    9, 18, 4, 89, 1, 53, 7, 91, 5, 56, 6, 25, 0, 51, 2, 26, 3, 83, 8, 32, 
    2, 31, 5, 36, 3, 36, 1, 63, 9, 67, 4,  2, 8, 16, 0, 79, 6, 68, 7, 42, 
    3, 86, 9, 83, 8,  2, 0, 89, 6, 99, 1, 36, 7, 65, 4, 31, 2, 96, 5, 41, 
    4, 90, 6, 98, 7, 86, 9, 77, 1, 80, 8, 27, 3, 59, 2, 63, 5, 99, 0, 56
  };
  const int r693[] = {
    10, 10, // Number of jobs and machines
    0, 94, 2, 42, 9, 14, 5,  9, 1, 71, 3, 22, 8, 71, 6, 59, 7, 88, 4, 33, 
    0, 96, 3, 92, 9,  9, 7, 12, 5,  9, 6, 36, 2, 76, 1, 52, 4, 11, 8, 43, 
    7, 10, 0, 65, 6, 31, 3, 60, 4, 43, 8, 92, 9, 38, 2, 39, 5, 48, 1, 54, 
    4, 38, 7, 82, 6, 22, 2, 27, 5, 47, 9, 32, 0, 84, 1, 85, 8, 69, 3, 63, 
    7, 76, 2, 95, 4, 91, 5,  7, 8, 96, 9, 87, 3, 99, 6, 15, 1, 12, 0, 28, 
    4,  9, 3,  6, 9, 57, 1, 56, 7, 95, 6, 39, 5, 31, 8, 72, 0, 62, 2, 20, 
    7, 82, 2, 89, 6, 96, 0, 23, 1, 22, 4,  9, 3, 38, 8, 87, 9, 36, 5,  9, 
    8, 55, 3, 55, 2, 60, 5, 29, 1, 11, 7, 18, 0,  7, 6, 28, 9, 59, 4, 60, 
    9,  3, 8, 74, 5, 69, 4, 23, 2, 90, 0, 16, 3, 98, 1, 75, 6, 65, 7, 51, 
    8, 11, 3, 12, 0, 98, 6, 20, 2, 70, 7, 99, 5, 85, 4, 12, 9, 64, 1, 63
  };
  const int r694[] = {
    10, 10, // Number of jobs and machines
    4, 83, 3, 64, 7, 74, 1, 73, 5,  9, 8, 57, 9, 48, 6, 88, 2, 37, 0, 77, 
    6, 74, 3, 90, 9, 21, 1, 62, 4, 46, 2, 57, 8, 14, 7, 54, 0, 20, 5, 55, 
    1, 22, 9, 46, 5, 53, 2, 38, 3, 35, 7, 17, 0, 19, 6, 32, 4,  3, 8, 33, 
    1, 49, 3, 88, 6, 68, 0, 36, 7, 25, 9, 17, 8, 53, 5, 50, 2, 88, 4, 42, 
    8, 85, 9,  5, 1,  3, 4, 34, 7, 20, 0, 33, 2, 19, 6, 94, 3, 86, 5,  2, 
    8, 32, 2, 42, 9, 46, 0, 98, 6, 67, 1, 79, 3, 57, 4, 97, 7, 19, 5, 38, 
    6, 72, 0, 68, 1, 98, 7, 96, 9, 49, 8, 69, 2, 85, 3, 70, 5, 50, 4, 65, 
    9, 45, 4, 88, 1, 88, 0, 38, 3, 98, 7, 11, 5,  3, 6, 97, 2, 45, 8, 32, 
    9, 78, 2, 46, 6, 47, 3,  5, 5, 30, 8, 64, 7, 51, 1, 46, 4, 46, 0, 12, 
    9, 37, 4, 17, 1, 39, 5,  7, 6, 32, 8, 97, 3, 92, 2, 48, 7, 81, 0, 56
  };
  const int r695[] = {
    10, 10, // Number of jobs and machines
    5, 21, 3, 12, 1, 98, 0, 17, 9, 38, 6, 30, 4, 35, 7, 98, 2, 30, 8, 87, 
    1, 49, 5,  2, 0, 26, 8, 14, 4, 76, 9, 28, 7, 70, 3, 23, 6, 74, 2, 75, 
    6, 96, 0,  1, 9, 80, 3, 67, 1, 80, 8, 69, 7, 10, 5, 22, 4, 17, 2,  8, 
    7, 26, 0, 43, 9, 21, 2,  6, 4, 39, 5, 37, 8, 27, 1, 22, 3, 36, 6, 81, 
    9, 49, 1, 62, 4, 83, 6, 47, 5, 21, 3, 45, 8, 16, 7, 72, 0, 83, 2, 63, 
    2, 38, 5, 83, 6, 33, 4,  6, 7, 53, 0, 71, 3,  9, 1, 62, 8, 54, 9,  5, 
    5, 51, 7,  8, 1, 32, 3, 88, 4, 12, 6, 60, 8, 21, 2, 50, 9, 80, 0, 56, 
    5, 39, 4, 38, 0, 98, 7, 59, 8, 24, 3, 97, 6, 28, 1, 48, 2, 29, 9, 53, 
    3, 19, 6,  7, 8, 68, 4, 89, 0, 91, 5, 39, 2, 37, 1, 71, 9, 30, 7, 65, 
    1, 84, 4, 47, 5, 89, 3, 10, 9, 33, 0, 31, 6, 73, 8, 45, 2, 44, 7, 86
  };
  const int r696[] = {
    10, 10, // Number of jobs and machines
    5, 97, 3, 78, 4,  9, 6, 13, 2, 84, 8, 39, 1, 89, 9, 13, 7, 77, 0, 71, 
    9, 40, 5, 41, 4, 72, 0, 46, 8, 86, 1, 95, 3, 54, 6,  7, 7, 38, 2, 10, 
    1, 44, 3, 37, 7, 36, 4, 63, 0, 17, 5, 58, 2, 80, 6, 86, 8,  9, 9, 70, 
    4, 54, 1, 96, 9, 22, 7, 73, 2, 57, 6, 71, 8, 90, 5, 91, 0, 38, 3, 89, 
    2, 10, 9, 77, 7, 29, 8, 98, 1, 31, 0, 66, 5,  3, 4, 85, 6, 54, 3, 85, 
    2, 61, 6, 97, 8, 81, 7, 64, 5, 29, 4, 78, 1,  1, 3, 71, 9, 37, 0, 88, 
    2, 97, 1, 73, 4, 53, 0, 16, 7, 29, 9, 58, 6, 76, 3, 90, 8, 20, 5, 18, 
    2, 92, 6, 52, 0, 23, 7, 23, 3, 47, 1, 67, 4, 38, 9, 16, 5, 82, 8, 72, 
    8, 85, 1, 91, 4, 51, 0, 98, 5, 57, 3, 41, 6, 36, 2, 87, 9, 44, 7, 15, 
    9, 52, 2, 52, 4, 48, 3, 63, 6,  5, 0, 89, 1, 74, 7, 14, 8, 62, 5, 75
  };
  const int r697[] = {
    10, 10, // Number of jobs and machines
    9, 35, 6, 91, 7,  2, 0,  1, 2, 22, 3, 69, 1,  1, 4, 52, 5, 64, 8, 86, 
    9, 19, 0, 19, 2, 31, 5, 43, 1, 87, 3, 14, 7, 48, 6, 26, 4, 18, 8, 28, 
    5, 23, 1, 86, 0, 80, 2,  1, 9, 40, 4, 82, 3, 16, 6,  8, 8, 33, 7, 43, 
    3,  5, 4, 95, 5, 50, 8, 98, 6,  9, 0, 25, 1, 89, 2, 61, 7, 72, 9, 61, 
    7, 86, 9, 63, 8, 92, 6, 42, 3, 71, 4,  1, 5, 11, 0, 87, 2, 38, 1,  5, 
    7, 31, 9, 42, 0, 16, 8, 25, 1, 33, 4,  4, 2, 66, 5, 32, 6, 83, 3, 54, 
    0, 40, 2, 10, 1, 67, 4, 54, 6, 66, 9, 98, 7, 92, 3, 27, 5, 80, 8, 33, 
    9, 40, 1, 19, 0, 38, 2, 32, 5, 66, 7, 98, 4, 70, 3, 47, 8, 61, 6,  1, 
    9, 86, 0, 41, 5, 70, 3, 83, 2, 51, 1, 14, 6,  1, 8, 36, 4, 99, 7, 84, 
    3, 11, 7, 30, 9,  3, 2, 28, 6, 31, 4, 91, 5, 61, 1, 83, 0, 73, 8, 53
  };
  const int r698[] = {
    10, 10, // Number of jobs and machines
    3,  2, 5, 50, 9,  7, 4, 71, 6, 14, 1, 59, 2, 82, 7, 30, 0, 59, 8, 42, 
    0, 70, 5, 94, 1, 60, 3, 47, 7, 84, 4, 86, 2, 41, 9, 46, 6, 94, 8, 11, 
    3,  2, 0, 23, 6,  6, 5, 24, 2, 85, 4, 13, 1,  4, 7, 75, 8, 57, 9, 87, 
    7, 59, 4, 94, 5,  2, 3,  6, 2, 44, 9,  7, 8, 95, 1, 71, 6, 71, 0, 75, 
    2, 69, 5, 39, 1, 25, 9, 44, 7, 53, 4, 56, 8, 50, 6, 36, 3, 64, 0, 78, 
    3, 11, 1, 75, 4, 47, 6, 44, 0, 81, 8, 17, 5, 18, 7, 40, 9, 52, 2, 33, 
    9, 35, 2, 27, 6, 80, 4, 67, 0, 85, 8, 97, 1, 45, 3, 24, 5,  5, 7,  7, 
    3, 26, 7, 45, 8, 60, 4, 56, 5, 58, 2, 22, 6, 23, 9, 13, 0, 86, 1,  2, 
    5, 45, 7, 74, 1, 16, 2,  8, 8, 53, 3, 76, 4, 30, 0,  6, 9, 95, 6, 43, 
    1, 69, 3, 15, 6, 89, 0, 12, 2, 34, 8, 23, 5, 14, 9, 22, 7, 64, 4, 29
  };
  const int r699[] = {
    10, 10, // Number of jobs and machines
    7, 94, 2, 73, 9, 16, 1, 72, 5, 45, 4, 44, 8, 41, 0, 10, 3, 72, 6, 96, 
    3, 16, 9, 81, 6, 34, 7, 70, 2,  2, 8, 64, 1, 63, 4, 66, 5, 43, 0, 61, 
    7, 63, 3, 29, 9, 27, 6, 40, 8, 64, 2, 57, 0, 88, 1, 54, 4, 52, 5, 13, 
    7, 79, 3, 63, 5, 76, 0,  6, 1, 85, 2, 13, 6, 59, 4, 73, 8, 49, 9, 63, 
    3, 40, 1, 28, 4, 22, 0, 95, 9, 50, 6,  1, 7,  5, 8, 60, 2,  6, 5, 74, 
    2,  2, 1, 80, 3, 61, 8, 58, 4, 71, 5, 82, 9, 44, 0, 68, 7,  3, 6, 90, 
    1, 39, 0, 55, 5, 11, 9, 88, 3, 91, 4, 83, 6, 56, 2, 44, 8,  9, 7, 41, 
    7, 69, 8, 22, 9, 75, 5,  5, 2, 39, 4, 68, 1, 64, 3, 57, 6,  1, 0, 92, 
    5, 45, 1, 66, 4, 25, 8, 28, 3, 58, 0, 44, 9, 66, 7, 98, 2, 97, 6, 22, 
    4, 17, 5, 11, 6, 90, 7, 96, 1,  4, 0,  7, 9, 80, 8, 27, 3, 82, 2, 17
  };
  const int r700[] = {
    10, 10, // Number of jobs and machines
    2, 70, 4,  1, 8, 78, 3, 27, 1, 25, 9, 58, 6, 25, 5,  4, 0, 84, 7, 49, 
    7, 66, 0,  9, 3, 54, 8, 34, 5, 38, 9, 77, 6, 62, 2, 91, 4, 30, 1, 66, 
    0, 43, 5, 51, 2, 13, 3, 76, 9, 62, 6, 37, 8, 39, 7, 20, 4, 76, 1, 28, 
    0, 73, 9, 49, 7, 28, 1, 59, 6, 75, 2, 17, 3, 12, 8, 42, 4,  2, 5, 95, 
    9, 92, 5, 72, 7, 62, 4, 59, 3, 21, 0, 16, 6, 46, 1, 93, 8, 20, 2, 77, 
    7, 27, 3, 18, 8, 15, 5, 92, 0, 92, 6, 95, 4, 88, 9, 76, 2, 45, 1, 73, 
    2, 10, 1, 73, 9, 90, 7, 45, 3, 95, 5, 16, 4, 19, 0, 72, 8, 71, 6, 17, 
    0,  4, 6, 98, 4, 16, 2, 47, 8, 89, 9, 71, 7, 31, 1, 23, 3, 56, 5, 63, 
    6,  7, 0, 40, 9, 83, 1, 95, 4, 75, 7, 63, 5, 42, 3, 65, 8,  6, 2,  7, 
    9, 67, 3, 52, 7, 74, 5, 47, 1,  3, 8, 79, 2, 43, 0, 77, 4, 55, 6, 31
  };
  const int r701[] = {
    10, 10, // Number of jobs and machines
    5, 60, 9, 66, 1, 37, 8, 61, 0, 68, 2, 78, 6, 30, 4, 42, 3, 64, 7, 61, 
    6, 64, 5, 51, 1, 11, 7, 65, 9, 88, 3, 57, 2, 27, 4, 56, 8, 76, 0, 25, 
    7, 78, 4, 25, 9, 26, 2, 41, 6, 57, 0, 71, 5, 26, 1, 52, 3, 69, 8, 67, 
    0, 62, 5, 55, 4, 58, 3, 98, 9, 31, 2, 21, 6, 22, 8, 63, 1, 40, 7, 11, 
    1, 86, 8, 15, 6, 93, 5, 75, 0, 42, 7, 80, 2, 96, 4, 97, 9, 28, 3, 31, 
    3, 66, 6, 32, 1, 88, 4, 45, 0, 51, 7,  4, 9, 46, 2, 78, 8, 17, 5, 26, 
    2, 74, 4, 93, 8, 17, 5, 55, 7, 98, 9, 59, 6, 35, 3, 57, 0, 89, 1, 75, 
    7, 44, 1, 41, 3, 37, 9,  1, 4, 50, 0, 44, 2, 38, 6, 60, 8, 36, 5, 56, 
    4, 13, 0, 16, 5, 19, 7, 85, 8, 52, 3, 92, 6, 73, 9, 88, 1, 30, 2, 81, 
    1, 50, 6, 37, 8, 65, 2, 94, 9, 89, 0, 53, 4, 63, 7, 10, 3,  8, 5, 23
  };
  const int r702[] = {
    10, 10, // Number of jobs and machines
    6, 10, 0, 14, 8, 71, 7, 51, 5, 29, 3, 11, 2, 85, 9, 92, 1, 73, 4,  2, 
    6,  5, 4, 12, 1, 14, 9, 76, 3, 55, 0, 87, 8,  4, 7, 86, 2, 76, 5, 34, 
    0, 52, 7, 32, 3, 34, 5, 13, 9, 91, 1, 79, 6, 50, 8, 66, 4,  9, 2, 51, 
    2, 84, 0, 32, 6, 31, 5, 97, 1, 79, 7,  3, 9, 36, 8, 64, 3, 47, 4, 80, 
    8, 78, 1, 98, 4, 99, 2, 59, 5, 82, 7, 49, 0, 37, 3, 80, 6, 53, 9, 96, 
    6, 24, 1, 17, 3, 83, 4, 83, 8, 36, 9, 33, 5, 79, 0, 43, 2, 44, 7, 65, 
    7, 30, 6, 11, 2, 74, 8, 88, 9, 99, 0, 70, 1,  1, 4, 33, 5,  5, 3, 52, 
    4,  3, 1, 22, 0, 28, 8, 85, 9, 99, 6, 60, 2, 12, 3,  7, 7, 41, 5, 31, 
    5, 37, 0, 28, 6, 90, 4, 47, 3, 59, 7, 43, 9, 90, 8, 59, 1, 85, 2, 86, 
    0, 70, 9, 22, 8, 67, 7, 37, 1,  9, 6, 39, 3,  6, 2, 47, 4,  4, 5, 57
  };
  const int r703[] = {
    10, 10, // Number of jobs and machines
    2, 90, 7, 99, 1, 28, 8, 24, 9, 54, 6, 31, 4, 93, 3, 99, 0, 16, 5, 69, 
    2, 50, 4, 17, 0, 82, 1, 25, 9, 69, 6, 42, 5, 75, 8, 81, 3,  2, 7, 37, 
    8, 29, 1, 76, 5, 10, 3,  9, 2, 28, 7, 18, 0, 81, 9, 23, 6, 53, 4, 45, 
    3, 97, 4,  1, 0, 71, 6, 96, 5, 89, 7, 41, 8,  3, 1,  1, 9, 39, 2, 81, 
    4, 40, 2, 39, 9, 29, 5, 67, 6, 25, 3, 30, 1, 80, 8, 95, 7, 45, 0, 19, 
    7, 19, 2, 49, 5, 92, 4, 86, 1, 78, 0, 31, 3, 58, 9, 87, 8, 60, 6, 36, 
    2, 60, 1, 84, 6, 38, 9, 67, 4, 43, 0, 10, 8, 60, 5, 69, 3, 37, 7, 74, 
    5, 83, 6, 21, 1, 37, 8, 40, 3,  6, 2, 16, 7, 87, 0, 40, 4, 23, 9, 66, 
    1, 94, 6, 47, 9, 84, 7, 67, 4, 77, 0, 86, 2, 94, 3, 79, 8, 38, 5, 51, 
    7,  8, 0, 19, 1, 88, 9, 59, 4, 75, 6, 60, 3, 65, 5,  2, 2, 75, 8, 33
  };
  const int r704[] = {
    10, 10, // Number of jobs and machines
    2, 12, 6,  1, 1, 51, 8, 82, 3,  1, 5, 47, 4, 35, 7, 61, 0, 15, 9, 27, 
    5, 43, 8, 63, 0, 39, 1, 79, 2, 46, 7, 17, 6,  6, 4, 44, 3, 85, 9, 82, 
    4, 53, 1, 99, 2, 66, 6, 70, 7,  8, 0, 17, 3, 49, 8, 18, 9, 17, 5,  4, 
    0, 75, 6, 46, 8,  5, 9,  9, 1,  1, 4, 89, 5, 77, 2, 86, 7, 44, 3, 50, 
    6, 97, 5, 91, 8, 16, 7, 64, 2, 63, 3, 54, 0, 82, 4, 88, 1, 57, 9, 45, 
    4, 83, 6, 48, 2, 70, 1, 53, 9, 23, 8, 81, 0, 58, 7, 86, 3, 37, 5,  1, 
    0, 62, 1, 62, 7, 79, 8, 66, 2, 67, 9,  9, 3, 97, 6, 74, 5, 64, 4, 34, 
    2, 68, 6, 12, 5, 71, 1, 80, 9, 59, 4, 33, 0, 42, 3, 45, 7, 55, 8, 95, 
    5,  4, 0, 29, 3, 57, 8, 10, 6, 48, 2, 54, 1, 76, 7, 25, 4, 46, 9, 31, 
    7, 34, 2, 40, 1, 81, 9, 74, 3, 93, 8, 64, 4, 72, 0, 12, 6, 17, 5, 72
  };
  const int r705[] = {
    10, 10, // Number of jobs and machines
    4, 61, 6,  9, 0, 20, 3, 65, 1, 97, 8, 23, 2, 42, 9, 12, 7, 48, 5, 30, 
    1, 88, 2, 20, 5, 56, 6, 82, 9, 76, 0, 24, 3, 36, 4, 17, 8, 16, 7, 77, 
    5, 45, 6, 99, 0, 81, 9, 88, 3, 25, 7, 94, 1, 45, 2, 60, 4, 34, 8, 12, 
    0, 16, 5, 72, 1, 40, 4, 22, 2, 63, 9, 99, 6, 78, 7, 11, 8, 38, 3, 92, 
    2, 41, 0,  5, 4, 19, 5, 13, 3, 51, 7, 90, 9, 25, 1, 28, 6, 55, 8, 58, 
    7, 66, 0, 34, 9, 65, 8, 38, 1, 43, 2, 13, 4, 39, 5, 91, 6,  9, 3, 15, 
    1, 17, 7, 25, 3, 43, 5, 26, 8, 44, 4, 76, 6, 57, 0, 48, 2, 14, 9, 20, 
    9, 20, 1, 77, 7, 79, 8, 68, 4, 81, 6, 46, 5, 99, 0, 54, 2, 80, 3, 51, 
    7, 22, 8, 88, 5, 31, 0, 24, 6, 28, 4, 11, 9, 42, 3, 47, 1, 14, 2, 66, 
    9, 34, 0, 71, 2, 61, 6,  6, 7, 15, 5,  3, 3, 44, 4, 44, 8, 56, 1, 58
  };
  const int r706[] = {
    10, 10, // Number of jobs and machines
    4, 86, 7, 18, 3,  3, 0,  4, 6, 97, 2, 31, 9, 47, 1, 22, 8, 60, 5, 47, 
    4, 39, 6, 33, 8, 86, 3, 71, 2, 20, 5, 77, 0, 21, 7, 50, 9, 14, 1,  6, 
    3, 34, 8,  5, 0, 67, 6,  4, 2, 81, 9, 99, 1, 76, 5, 16, 7, 98, 4, 17, 
    7, 10, 2, 60, 1, 83, 6, 36, 8, 52, 4, 84, 9, 56, 5, 30, 0,  1, 3, 39, 
    9, 15, 7, 97, 1, 58, 5, 99, 2,  3, 3, 58, 6, 36, 4, 81, 8, 95, 0, 91, 
    5,  4, 4, 83, 6, 67, 2, 94, 9, 80, 8,  7, 0, 41, 1, 18, 3, 66, 7, 51, 
    6, 88, 0, 58, 1, 42, 2, 11, 8, 34, 5, 66, 7, 55, 9,  5, 3, 74, 4, 11, 
    5, 81, 9, 94, 0, 54, 3, 22, 6, 74, 2, 73, 7, 22, 1, 25, 8, 63, 4, 79, 
    8, 29, 2,  2, 5, 85, 7, 72, 4, 62, 0,  2, 9, 58, 6, 93, 3, 91, 1, 64, 
    1, 82, 8, 98, 3, 38, 9, 29, 6, 80, 4, 52, 7, 63, 2, 33, 5, 60, 0, 68
  };
  const int r707[] = {
    10, 10, // Number of jobs and machines
    7, 91, 6, 63, 3, 74, 5, 26, 2,  9, 9, 51, 8, 15, 1, 40, 0, 81, 4, 75, 
    7, 54, 8, 61, 3, 26, 1, 53, 6,  8, 4, 17, 0, 77, 2, 25, 5, 66, 9, 32, 
    6, 72, 9, 43, 1,  8, 3, 11, 2, 32, 8, 32, 0, 54, 5, 42, 4, 85, 7, 45, 
    9, 56, 4, 95, 3, 67, 1, 90, 7, 48, 6, 66, 8,  2, 0, 23, 2,  2, 5, 49, 
    0, 34, 9, 47, 4, 35, 7, 85, 8, 54, 3, 44, 2, 99, 5, 60, 1, 66, 6, 44, 
    9, 33, 0, 26, 2, 27, 5, 37, 4, 71, 6, 52, 1, 34, 7, 21, 3, 69, 8, 59, 
    3,  7, 1, 20, 2, 25, 5, 58, 9, 29, 4, 85, 6, 11, 8, 65, 0, 11, 7, 35, 
    6, 43, 0, 66, 3, 82, 2, 91, 8, 48, 1,  1, 7, 36, 4,  2, 9, 84, 5, 63, 
    2, 91, 8, 76, 5, 58, 7, 97, 1, 37, 6, 30, 0, 40, 4, 27, 9, 19, 3, 73, 
    2, 49, 3, 81, 0, 35, 1, 17, 4, 28, 7, 98, 8, 78, 5, 14, 9, 59, 6, 49
  };
  const int r708[] = {
    10, 10, // Number of jobs and machines
    7, 96, 4, 65, 9, 14, 6, 24, 1, 59, 5, 14, 0, 74, 3, 11, 2, 31, 8, 79, 
    7, 43, 1, 11, 5, 66, 9, 50, 4, 96, 6, 88, 2,  7, 3,  7, 0, 12, 8, 70, 
    2, 84, 3, 27, 7, 81, 9, 71, 1, 39, 0,  3, 6,  2, 8, 44, 4, 75, 5, 90, 
    7, 27, 4, 92, 9,  9, 3, 22, 1,  1, 0, 56, 6, 49, 8,  8, 5, 32, 2,  5, 
    6, 87, 3,  1, 0, 41, 1, 85, 9, 66, 8, 32, 2, 62, 5, 40, 4, 20, 7, 85, 
    9,  2, 3, 67, 1, 58, 7, 23, 8,  2, 6, 30, 5,  4, 2, 30, 0, 94, 4, 30, 
    5, 36, 6, 65, 8, 66, 0, 64, 7, 26, 2, 57, 9, 13, 4, 89, 1, 58, 3, 76, 
    6, 47, 3, 47, 0, 82, 5, 51, 7, 30, 9, 69, 4, 72, 8, 77, 1, 85, 2, 56, 
    8,  9, 7, 40, 1, 67, 6, 63, 2, 74, 9, 69, 4, 61, 0, 63, 5, 57, 3, 58, 
    0, 67, 3, 20, 2, 85, 1, 79, 7, 78, 9,  7, 8, 32, 6, 52, 4, 28, 5, 60
  };
  const int r709[] = {
    10, 10, // Number of jobs and machines
    9, 26, 2, 59, 4, 29, 7, 85, 0, 97, 8, 93, 1, 63, 6, 64, 5, 69, 3, 90, 
    0, 65, 9, 28, 4, 65, 3, 72, 2, 97, 8, 83, 6, 80, 1, 26, 5, 24, 7, 98, 
    8, 26, 0, 39, 9, 70, 6, 69, 3, 48, 1, 94, 2, 15, 4, 99, 7, 66, 5, 15, 
    7, 80, 3, 42, 8, 44, 9, 27, 2, 78, 6, 59, 1, 27, 0, 89, 4, 34, 5, 93, 
    4, 61, 9, 45, 1, 17, 7, 71, 6, 30, 8, 97, 5, 43, 2, 54, 0, 40, 3, 23, 
    4, 78, 9, 71, 5, 56, 2, 56, 1, 51, 6, 91, 3, 31, 8,  1, 0, 24, 7, 20, 
    7, 41, 0, 32, 1, 92, 3,  8, 5, 66, 9, 42, 6, 95, 8, 16, 4, 54, 2, 28, 
    7, 15, 8, 39, 4, 65, 6, 55, 0, 21, 5, 51, 9, 75, 1, 83, 3, 41, 2, 43, 
    9, 13, 1, 25, 0, 82, 8, 55, 7, 53, 2, 38, 4,  2, 5, 46, 6, 22, 3, 56, 
    1, 44, 6,  7, 4, 62, 9, 59, 8, 58, 2, 86, 0, 24, 7, 97, 5, 78, 3, 90
  };
  const int r710[] = {
    10, 10, // Number of jobs and machines
    6, 54, 1, 53, 0, 63, 9, 87, 2,  1, 8, 88, 7, 65, 3, 88, 4, 78, 5, 49, 
    4,  6, 9, 85, 3, 47, 5, 83, 6, 69, 2, 75, 7, 58, 8, 74, 1, 56, 0, 36, 
    9, 75, 1,  2, 5, 72, 3,  9, 2, 16, 4,  2, 6, 46, 0, 44, 7, 95, 8, 19, 
    2, 47, 6, 16, 4, 57, 8,  8, 3, 11, 5, 17, 0, 61, 9, 10, 7, 89, 1, 70, 
    3, 93, 9, 91, 8,  2, 0, 14, 2, 10, 7, 15, 1, 46, 6,  8, 5, 13, 4, 94, 
    6, 61, 9, 19, 3, 50, 2, 43, 4, 78, 5, 99, 7, 39, 0, 90, 8, 19, 1, 30, 
    6, 35, 3, 97, 0,  2, 9, 45, 2, 93, 7, 48, 1, 70, 8, 89, 4, 47, 5, 88, 
    5, 53, 4,  9, 0, 55, 2, 82, 6, 74, 8, 37, 9, 88, 3, 83, 1, 41, 7, 52, 
    0, 71, 5, 41, 6, 17, 7, 78, 4,  7, 2, 33, 1, 95, 8, 97, 3, 50, 9, 10, 
    8, 85, 9,  1, 4, 15, 2, 33, 3, 57, 7, 43, 5, 40, 1, 88, 6, 39, 0, 47
  };
  const int r711[] = {
    10, 10, // Number of jobs and machines
    6, 45, 9, 10, 3, 25, 7, 26, 0, 42, 4, 65, 1, 36, 2, 69, 5, 55, 8, 50, 
    0, 56, 3, 81, 4, 31, 2, 13, 8, 29, 7,  7, 5, 32, 9, 38, 1, 73, 6, 30, 
    4, 31, 0, 18, 2,  4, 7, 29, 6, 47, 1, 23, 9, 37, 3, 51, 5, 90, 8, 98, 
    6, 42, 3,  5, 9, 14, 2, 18, 7, 44, 8,  9, 5, 70, 1, 18, 4, 22, 0, 42, 
    2, 34, 9, 72, 8,  5, 7, 80, 3, 22, 4, 13, 1, 35, 6, 61, 0, 33, 5, 79, 
    7, 51, 5, 72, 2, 27, 3, 31, 9,  5, 4, 40, 8, 55, 0, 46, 1, 51, 6, 41, 
    3, 57, 8, 83, 0, 93, 1, 43, 5, 53, 2, 63, 6, 32, 7, 16, 4, 11, 9, 36, 
    6, 18, 4, 61, 8, 81, 7, 60, 3,  4, 1, 90, 5, 39, 2,  9, 0, 84, 9, 31, 
    8, 32, 4, 89, 2, 44, 7,  1, 9, 66, 1, 96, 0, 74, 5, 66, 6, 91, 3, 60, 
    3, 42, 9, 75, 0, 40, 1, 34, 7, 91, 6, 97, 5,  5, 2, 49, 4, 96, 8, 37
  };
  const int r712[] = {
    10, 10, // Number of jobs and machines
    7, 43, 5, 85, 9, 71, 6, 14, 8, 20, 3, 45, 0, 49, 2, 31, 4, 20, 1, 75, 
    9, 13, 6, 66, 8, 89, 2, 68, 0, 14, 1, 97, 5, 80, 7, 20, 4, 64, 3, 14, 
    7,  2, 2, 22, 8, 98, 1, 79, 5, 68, 3,  6, 6, 50, 0, 38, 4, 80, 9, 19, 
    9,  6, 7, 81, 8, 55, 0, 96, 1, 44, 5, 59, 4,  8, 2,  8, 6, 75, 3, 30, 
    6, 63, 1, 82, 0, 99, 9, 58, 5, 63, 4,  2, 3, 30, 2, 65, 8,  9, 7, 77, 
    1, 12, 9,  8, 8, 66, 3, 52, 4, 54, 7, 15, 5, 76, 0, 53, 6, 28, 2,  2, 
    6,  6, 1, 94, 4, 14, 7, 14, 0, 37, 3, 35, 2, 32, 9, 13, 8, 14, 5, 72, 
    9, 61, 1, 57, 4, 17, 3, 32, 7, 89, 8, 53, 0,  7, 2, 77, 6, 54, 5, 46, 
    9, 92, 2, 96, 0, 69, 6, 32, 4,  8, 8, 89, 5, 44, 7, 26, 3, 49, 1, 20, 
    7, 80, 8,  3, 5, 60, 9, 11, 0, 68, 3, 67, 2, 78, 4, 16, 1, 37, 6, 98
  };
  const int r713[] = {
    10, 10, // Number of jobs and machines
    9, 97, 8, 48, 7,  3, 0, 31, 3, 85, 2, 38, 5, 70, 4, 33, 1, 60, 6, 21, 
    7, 10, 8, 98, 4, 56, 1, 36, 0, 51, 9, 64, 2, 48, 5, 53, 6, 22, 3, 27, 
    9, 74, 4, 27, 3, 66, 2, 98, 5, 65, 7, 53, 6, 56, 1, 75, 0, 43, 8,  7, 
    1, 76, 9, 61, 4,  2, 7, 92, 6, 45, 0, 36, 2, 25, 5, 12, 3,  8, 8,  7, 
    1, 50, 5,  6, 7, 96, 6, 58, 9, 43, 4, 90, 2, 84, 0, 97, 8, 77, 3, 39, 
    4, 13, 8, 99, 7, 71, 2, 67, 6, 48, 0, 42, 3, 59, 5,  1, 1, 18, 9, 30, 
    8, 67, 0,  7, 4, 57, 7, 75, 3, 47, 5, 69, 9, 71, 2,  4, 6, 58, 1, 32, 
    5, 11, 8, 38, 1, 86, 6, 40, 2, 38, 4, 35, 9, 24, 0, 83, 7, 33, 3, 30, 
    1, 13, 5, 19, 0, 10, 3, 37, 6, 74, 8, 86, 4, 68, 7, 25, 9, 22, 2, 51, 
    8, 50, 5, 15, 3, 43, 0, 60, 9, 98, 2, 11, 4, 43, 1, 67, 7, 59, 6, 90
  };
  const int r714[] = {
    10, 10, // Number of jobs and machines
    5, 63, 3, 64, 0, 49, 2, 44, 9, 28, 1, 26, 6, 41, 4, 21, 8, 21, 7, 65, 
    1, 79, 8, 91, 6, 19, 2, 12, 3, 13, 0, 15, 4, 63, 5, 90, 9, 14, 7, 16, 
    2, 91, 1, 41, 7, 26, 4, 11, 3, 37, 0, 57, 9, 19, 8, 42, 5, 38, 6, 20, 
    1, 96, 8, 92, 3,  5, 2, 41, 4, 55, 9, 27, 5, 79, 0, 29, 6, 54, 7, 74, 
    4, 65, 6, 54, 9, 28, 5, 37, 3, 68, 8, 54, 2, 73, 7, 94, 1, 99, 0, 34, 
    9, 88, 6, 76, 2, 51, 8, 17, 3, 79, 7, 31, 4, 11, 5, 58, 0,  6, 1, 69, 
    7,  6, 9, 44, 6, 90, 0, 70, 8, 60, 2, 39, 3, 91, 1, 38, 4, 73, 5, 77, 
    2,  9, 7, 58, 3, 60, 4, 23, 5,  8, 8, 75, 6, 72, 9, 92, 0, 94, 1, 63, 
    6, 70, 1, 90, 8, 43, 5, 67, 7, 58, 4,  7, 9, 13, 2, 34, 3, 20, 0, 77, 
    2, 10, 1, 79, 9, 95, 4, 64, 7, 99, 8, 61, 5, 42, 6, 73, 3, 45, 0, 55
  };
  const int r715[] = {
    10, 10, // Number of jobs and machines
    8, 59, 4, 49, 0, 41, 5, 88, 2, 88, 9, 14, 1, 37, 7, 72, 6, 62, 3, 46, 
    3, 16, 6, 51, 7, 90, 1, 54, 5, 96, 0, 32, 4,  2, 2, 84, 9, 99, 8,  1, 
    2, 80, 8, 70, 0, 52, 5, 61, 7, 34, 3, 99, 4, 38, 6, 39, 1,  7, 9, 97, 
    5, 68, 1, 50, 3, 91, 7, 52, 2, 39, 9, 32, 4, 12, 6, 74, 8, 50, 0, 76, 
    7, 15, 9, 52, 4, 84, 8, 73, 6, 49, 3, 51, 0, 66, 1,  2, 2, 90, 5, 18, 
    6, 42, 2, 33, 5, 40, 3, 58, 9, 11, 7,  4, 8,  6, 4, 21, 0, 28, 1, 74, 
    5, 83, 4, 16, 9, 90, 8, 33, 0, 51, 7, 94, 2, 34, 1, 70, 3, 83, 6, 66, 
    7, 32, 6, 55, 9, 36, 0, 60, 4, 33, 5,  5, 3, 97, 1, 47, 2, 90, 8, 32, 
    8, 10, 3, 78, 5, 35, 0, 53, 6, 62, 4, 22, 9,  8, 7, 74, 2, 63, 1,  4, 
    0, 62, 8, 43, 5, 13, 3, 82, 1, 81, 2,  5, 9, 66, 4, 70, 7, 74, 6, 72
  };
  const int r716[] = {
    10, 10, // Number of jobs and machines
    6, 69, 3, 53, 2, 32, 8, 30, 7, 61, 5, 35, 0, 49, 4, 72, 1, 74, 9, 21, 
    6, 66, 2, 76, 9, 95, 1, 56, 8, 91, 7, 83, 0, 64, 3, 47, 4, 26, 5, 59, 
    4, 15, 8, 49, 5, 95, 2, 68, 3, 92, 0, 85, 1, 66, 9, 32, 6, 45, 7, 10, 
    3,  9, 9, 39, 2, 31, 5, 58, 0, 46, 8, 69, 1, 29, 6, 70, 7, 47, 4, 38, 
    9, 35, 4, 89, 6, 30, 3, 67, 5, 13, 2, 27, 7,  2, 1, 76, 0, 90, 8, 73, 
    6, 97, 0, 90, 1, 38, 2, 63, 3,  3, 8, 32, 7, 39, 5, 48, 9, 94, 4, 62, 
    2,  5, 9, 73, 8,  1, 1, 25, 4, 34, 3, 86, 0, 72, 7, 67, 5, 45, 6, 96, 
    1, 62, 6, 50, 7, 69, 0, 36, 9, 13, 4, 40, 3, 82, 2, 23, 5, 45, 8, 58, 
    1, 86, 4, 10, 8, 30, 7, 60, 0,  9, 6, 29, 2, 30, 5, 83, 3, 98, 9, 42, 
    0, 36, 5,  1, 7, 29, 4, 61, 3, 72, 2, 59, 6, 97, 1, 40, 9, 59, 8, 53
  };
  const int r717[] = {
    10, 10, // Number of jobs and machines
    6, 93, 9, 42, 4, 97, 1, 24, 3, 72, 2, 83, 7, 80, 8, 42, 5,  5, 0, 59, 
    7, 15, 6, 90, 5, 73, 4,  6, 3, 95, 0, 74, 1, 99, 2, 88, 9, 87, 8, 58, 
    4, 73, 6,  8, 8, 35, 3, 73, 9, 82, 0, 65, 1, 74, 5, 50, 7, 94, 2, 27, 
    4, 14, 9, 79, 6, 65, 3, 86, 1, 35, 0, 21, 7, 14, 2, 29, 8, 67, 5, 53, 
    5, 25, 6, 86, 2, 16, 3, 41, 9, 78, 0, 17, 8, 22, 4,  8, 1, 82, 7, 59, 
    4, 68, 0, 71, 9, 52, 1, 43, 7, 95, 8, 39, 3, 96, 6, 80, 5,  1, 2, 43, 
    0,  3, 1, 51, 7, 86, 4, 74, 8, 62, 9, 46, 5, 74, 3, 18, 6, 17, 2, 25, 
    4, 74, 9, 76, 5, 33, 6, 53, 1, 80, 0, 93, 2, 80, 3, 85, 7, 43, 8, 53, 
    4, 44, 7, 96, 3, 50, 8, 58, 0, 14, 1, 80, 2, 53, 6, 90, 9, 51, 5, 42, 
    9, 57, 4, 49, 5, 79, 6, 19, 1, 14, 0, 16, 2, 70, 8, 26, 7, 88, 3,  2
  };
  const int r718[] = {
    10, 10, // Number of jobs and machines
    3, 99, 7, 79, 5, 21, 1, 87, 8, 34, 6, 78, 2, 70, 4, 94, 0, 51, 9, 10, 
    7, 46, 4, 73, 3,  3, 8, 43, 0, 92, 1, 39, 9, 19, 5, 65, 2, 13, 6, 20, 
    7, 92, 3, 33, 4, 35, 2, 14, 0, 81, 9, 17, 8, 90, 5, 87, 6,  6, 1, 92, 
    2, 88, 8, 72, 6,  7, 9, 89, 5, 65, 7, 52, 4, 31, 3, 46, 1, 75, 0, 95, 
    4, 71, 7, 52, 9,  8, 0, 44, 3,  8, 6,  7, 5, 11, 2, 90, 8, 20, 1, 10, 
    9, 72, 4, 87, 7, 25, 3, 59, 6, 61, 0, 78, 2, 46, 1, 95, 5, 26, 8, 59, 
    4, 15, 7, 48, 9, 88, 6, 84, 2, 76, 3, 82, 8, 59, 5, 70, 0, 77, 1, 76, 
    7, 10, 8, 54, 3, 78, 0, 61, 2, 71, 4, 30, 9, 60, 1, 13, 5, 82, 6, 87, 
    8, 55, 0, 98, 7, 87, 9, 30, 1, 63, 5, 33, 2, 10, 4, 85, 6, 82, 3, 82, 
    0, 84, 5, 81, 6, 62, 8, 56, 9, 21, 1, 67, 3, 12, 2, 61, 4, 34, 7, 55
  };
  const int r719[] = {
    10, 10, // Number of jobs and machines
    1, 24, 2,  8, 5, 83, 9, 44, 0, 56, 6, 42, 4,  3, 8, 23, 7, 90, 3,  3, 
    8, 58, 2, 47, 1, 98, 4, 90, 7, 53, 0, 93, 9, 40, 6, 90, 3, 39, 5, 38, 
    9, 35, 8, 46, 1, 73, 2, 70, 0, 14, 4, 95, 5, 22, 3, 70, 6, 15, 7,  4, 
    3, 40, 7, 45, 6, 60, 8, 83, 9, 19, 4, 52, 1, 86, 5, 18, 2, 52, 0, 37, 
    6, 98, 7, 89, 4, 77, 8, 48, 5, 61, 1, 57, 2, 45, 0, 55, 3, 25, 9, 24, 
    5, 62, 8, 44, 1, 91, 2, 37, 4, 46, 9, 82, 3, 55, 0, 40, 6, 10, 7, 41, 
    2, 48, 3, 97, 5, 74, 8, 34, 6, 96, 1, 62, 7, 35, 4, 49, 9, 87, 0, 20, 
    2, 31, 3, 85, 6, 24, 4, 82, 7, 11, 5, 12, 0, 62, 1,  4, 8, 43, 9, 19, 
    0,  4, 7, 73, 3, 54, 5, 36, 2, 81, 1, 70, 9, 91, 6, 84, 8, 40, 4, 29, 
    5, 96, 0,  1, 7, 43, 6, 41, 8, 27, 4, 39, 1,  6, 9, 32, 2, 63, 3, 42
  };
  const int r720[] = {
    10, 10, // Number of jobs and machines
    4, 39, 8, 87, 9, 97, 1, 62, 6, 72, 7,  8, 2, 89, 0, 67, 5, 70, 3, 23, 
    1, 54, 3, 13, 8, 16, 0, 19, 7, 74, 4, 55, 9, 80, 6, 74, 2, 47, 5, 93, 
    3, 92, 0, 18, 8, 80, 5, 30, 7, 76, 9,  3, 4, 84, 6, 36, 1, 11, 2, 95, 
    9, 44, 2, 65, 8, 35, 0, 42, 6, 11, 4, 75, 5, 63, 1,  6, 7,  8, 3, 50, 
    9, 53, 0, 83, 5, 32, 2, 24, 6, 27, 7, 15, 3, 80, 8, 52, 1, 27, 4, 64, 
    7, 78, 9,  4, 2, 10, 4,  9, 0, 44, 3, 89, 6, 92, 8, 95, 5, 68, 1, 54, 
    7, 14, 2, 99, 1, 56, 3, 18, 6, 55, 8, 43, 4, 74, 9, 44, 5, 53, 0, 41, 
    6, 56, 8, 54, 9, 36, 2, 61, 4, 11, 7, 50, 5, 31, 3, 22, 1, 50, 0, 72, 
    6, 30, 8, 67, 1, 13, 5, 58, 2, 15, 9, 51, 4, 84, 7, 88, 3, 48, 0, 32, 
    1, 85, 6, 19, 5, 61, 9, 63, 4, 91, 7,  8, 0, 14, 2, 49, 8, 77, 3,  5
  };
  const int r721[] = {
    10, 10, // Number of jobs and machines
    1, 58, 4, 56, 3, 41, 0, 76, 9, 93, 2, 57, 6, 60, 8, 79, 5, 68, 7, 40, 
    0, 70, 9, 69, 3, 85, 2, 79, 4, 97, 8, 33, 6, 36, 1, 19, 5, 96, 7, 23, 
    6, 17, 1, 83, 8, 73, 5, 86, 7, 53, 9, 29, 4, 51, 3, 22, 0, 33, 2, 25, 
    4, 55, 2, 59, 7, 15, 3, 91, 8, 79, 5, 73, 0, 35, 9, 86, 1, 92, 6, 86, 
    4, 94, 5, 25, 7, 23, 0, 43, 3, 57, 6, 11, 8, 73, 9, 65, 1, 92, 2, 21, 
    3, 31, 1, 22, 4, 26, 2, 20, 8, 58, 9, 73, 0, 64, 5, 72, 7, 64, 6, 67, 
    5, 38, 9, 18, 6, 75, 4, 49, 1, 75, 3, 16, 7, 53, 2, 12, 8, 48, 0, 15, 
    6, 84, 7, 42, 3, 95, 9, 21, 0, 68, 5, 49, 8, 81, 2, 75, 1, 73, 4, 57, 
    6,  2, 8, 89, 5, 49, 3,  4, 9, 33, 1, 51, 0, 85, 7, 47, 2, 96, 4, 11, 
    9, 60, 5, 73, 1, 73, 7, 48, 8, 79, 0, 39, 4, 16, 3, 12, 2, 31, 6, 31
  };
  const int r722[] = {
    10, 10, // Number of jobs and machines
    8, 21, 4, 29, 7, 98, 9, 28, 2, 11, 3, 10, 5, 81, 6, 43, 0, 31, 1, 67, 
    4, 73, 5, 87, 2, 89, 7, 16, 0, 81, 1, 87, 3, 13, 8, 19, 6,  6, 9, 28, 
    7, 69, 4, 28, 0, 13, 9, 85, 5, 76, 1, 74, 2, 84, 8, 57, 6,  2, 3, 23, 
    2, 26, 4,  6, 0, 47, 9, 24, 3, 57, 1, 34, 6, 52, 8, 94, 7, 11, 5, 68, 
    1, 68, 6, 71, 5, 45, 3, 41, 8, 46, 9, 64, 0, 81, 2,  5, 7, 24, 4, 38, 
    9, 15, 3, 92, 1, 11, 5, 19, 0, 80, 2, 99, 8, 59, 4, 83, 6, 42, 7, 27, 
    6, 90, 9, 37, 5, 48, 7, 52, 1, 30, 0, 73, 3, 15, 2,  1, 4, 99, 8,  5, 
    0, 38, 2, 87, 4, 45, 5, 78, 1, 65, 3, 59, 7, 76, 6, 18, 8, 63, 9, 70, 
    6, 53, 9, 67, 5, 65, 0, 48, 3,  5, 8, 34, 2,  3, 4, 71, 7, 35, 1, 26, 
    0, 27, 2, 68, 6, 45, 5, 44, 4, 68, 7, 40, 8, 82, 3, 17, 1, 29, 9, 18
  };
  const int r723[] = {
    10, 10, // Number of jobs and machines
    9, 81, 6, 15, 2, 72, 8, 38, 3,  3, 4, 44, 5, 27, 1, 56, 7, 47, 0, 92, 
    8, 49, 9, 74, 7, 88, 1,  8, 3, 48, 0, 81, 6, 94, 4, 24, 2, 31, 5, 56, 
    6, 70, 8, 93, 9, 37, 1, 56, 0, 71, 4, 45, 3, 95, 2, 11, 5,  9, 7, 18, 
    0, 79, 7, 13, 6, 23, 1, 34, 8, 13, 9, 55, 3, 20, 4, 35, 2, 13, 5,  9, 
    0, 44, 5, 82, 9, 23, 1, 76, 7, 24, 3, 41, 8, 96, 6, 40, 2, 81, 4, 63, 
    6, 34, 5, 32, 4, 75, 0, 30, 9, 65, 7, 60, 8, 17, 2, 93, 3, 60, 1, 16, 
    7, 24, 0, 69, 6, 32, 8, 53, 2, 53, 3, 14, 4, 33, 9, 91, 1, 22, 5, 22, 
    9, 85, 3, 12, 4, 42, 7, 67, 6, 32, 2, 19, 5, 36, 8, 57, 0, 51, 1, 91, 
    5, 85, 7, 45, 2, 21, 1, 32, 4,  2, 3, 17, 9, 21, 6, 89, 0, 38, 8, 35, 
    9, 52, 5, 33, 3, 89, 0, 22, 2, 40, 8, 83, 1,  2, 7, 49, 4, 40, 6, 70
  };
  const int r724[] = {
    10, 10, // Number of jobs and machines
    4,  8, 3, 74, 0, 27, 2, 63, 5, 95, 9, 62, 1,  2, 7, 69, 6, 60, 8, 82, 
    1, 40, 9, 52, 7, 56, 4, 32, 3, 27, 2, 49, 6, 54, 5, 87, 0, 12, 8, 30, 
    9, 10, 1, 35, 6, 90, 4, 33, 3, 16, 5, 23, 7, 59, 2, 95, 0, 65, 8, 47, 
    2, 22, 0, 85, 5, 14, 1, 32, 9, 52, 6,  3, 4, 72, 3, 33, 7, 26, 8, 45, 
    2, 77, 3, 74, 8, 17, 5, 22, 0, 52, 7, 94, 1, 32, 4, 78, 6, 42, 9, 49, 
    8, 20, 2, 94, 3,  4, 0, 91, 9,  7, 5, 96, 6, 35, 7, 82, 1, 67, 4, 44, 
    2, 46, 3, 11, 5, 50, 1, 13, 8, 97, 6, 70, 0, 62, 7, 84, 4, 83, 9, 46, 
    1, 61, 4, 55, 6, 99, 8, 46, 2, 12, 9, 72, 0, 25, 3, 72, 5, 23, 7, 21, 
    5, 33, 9, 29, 6, 41, 1, 83, 7, 33, 2, 56, 0, 31, 4, 25, 3, 34, 8, 89, 
    0, 40, 8, 95, 9, 75, 3, 72, 7, 26, 1, 86, 4, 23, 6, 18, 5, 47, 2, 47
  };
  const int r725[] = {
    10, 10, // Number of jobs and machines
    0, 12, 6,  2, 5, 28, 8, 99, 1, 28, 4, 60, 9, 44, 2, 10, 3, 45, 7, 69, 
    2, 48, 6, 37, 1, 41, 9, 93, 4, 44, 0, 97, 5, 73, 7,  8, 8, 34, 3,  2, 
    7, 86, 5, 24, 2, 90, 1, 58, 6, 53, 3, 59, 9,  8, 4,  7, 8, 54, 0,  1, 
    0, 19, 9, 34, 6,  5, 4, 57, 7,  4, 5, 84, 3, 42, 8, 90, 1,  6, 2, 11, 
    1,  6, 7, 94, 0, 26, 4, 51, 8,  8, 6, 31, 5, 40, 9, 45, 3, 82, 2, 47, 
    4,  9, 8, 21, 9, 39, 5, 99, 3, 14, 0, 65, 2, 60, 7,  6, 6, 30, 1, 56, 
    5, 58, 3, 44, 4, 49, 2, 67, 8, 36, 1, 62, 9, 40, 6, 23, 0, 10, 7, 77, 
    9, 13, 5, 34, 1, 45, 3, 72, 8, 13, 2, 58, 7, 84, 4, 11, 6, 30, 0, 56, 
    4, 58, 9, 33, 0, 78, 1, 91, 3, 92, 7, 83, 5, 84, 2,  4, 6, 87, 8, 52, 
    7, 29, 2, 73, 8, 36, 9, 50, 4, 83, 0, 98, 1,  9, 5, 90, 6, 22, 3, 91
  };
  const int r726[] = {
    10, 10, // Number of jobs and machines
    8, 75, 3, 12, 9, 21, 2,  3, 7, 99, 6, 85, 0, 48, 5, 11, 1, 20, 4, 71, 
    4, 12, 8, 98, 2, 16, 0, 40, 3,  2, 6, 80, 5, 33, 7,  5, 9, 91, 1, 70, 
    7, 22, 4, 32, 0, 12, 5, 92, 2, 34, 1, 18, 3, 37, 8, 79, 6, 95, 9,  2, 
    5, 50, 3, 31, 0, 15, 2, 82, 9, 59, 8, 78, 4, 69, 1, 63, 6, 70, 7, 82, 
    5,  8, 9, 64, 6,  9, 7, 45, 2, 85, 0, 43, 3,  8, 1, 15, 8, 26, 4, 28, 
    3, 32, 5, 68, 0, 35, 8, 70, 6, 28, 9, 13, 7, 30, 4, 44, 1, 86, 2, 43, 
    4, 95, 2, 10, 0, 29, 7, 12, 3, 21, 5, 26, 1, 78, 9, 36, 8, 64, 6,  6, 
    1, 41, 5, 15, 8, 23, 6, 75, 0,  4, 9, 94, 4, 78, 2, 95, 7, 46, 3, 52, 
    5, 86, 3, 80, 9, 96, 2, 58, 6, 84, 4, 13, 1, 28, 0, 98, 8, 48, 7, 77, 
    3, 65, 2, 12, 0, 66, 5,  7, 9, 16, 6, 40, 8, 89, 4,  2, 7, 78, 1, 91
  };
  const int r727[] = {
    10, 10, // Number of jobs and machines
    6, 53, 4, 77, 2,  4, 1, 66, 5, 41, 9, 49, 7, 50, 3, 81, 8, 97, 0, 22, 
    1, 64, 3, 43, 5, 55, 4,  2, 0, 67, 9, 31, 7, 50, 6, 33, 2, 86, 8,  9, 
    3, 52, 5, 21, 6, 88, 8, 77, 7, 33, 4,  2, 9, 77, 2, 59, 0, 54, 1,  7, 
    5, 83, 6, 66, 4, 15, 8,  3, 2, 56, 7, 21, 9, 12, 3, 23, 1, 18, 0, 41, 
    0, 72, 5, 63, 6, 10, 9, 47, 1, 61, 3, 95, 2, 32, 7, 64, 8, 64, 4, 43, 
    8, 64, 1,  1, 2, 14, 6, 47, 3, 44, 9, 25, 7, 21, 0, 92, 4, 99, 5, 75, 
    7, 63, 0, 71, 5, 11, 2, 72, 8, 26, 9, 36, 1, 40, 6, 12, 4, 54, 3, 26, 
    1, 17, 2, 16, 4,  9, 3, 82, 5,  4, 8,  9, 0, 12, 7, 27, 9, 39, 6, 53, 
    2, 11, 7, 42, 1, 90, 5, 31, 3, 10, 8, 60, 9, 88, 6, 87, 0, 73, 4, 59, 
    2,  1, 3, 35, 7, 20, 1, 90, 5, 42, 4, 21, 8, 42, 6, 77, 0, 17, 9, 50
  };
  const int r728[] = {
    10, 10, // Number of jobs and machines
    5, 10, 9, 62, 6, 52, 7, 68, 4,  3, 0, 42, 3,  7, 8, 52, 1,  6, 2, 26, 
    3, 92, 2, 53, 0, 25, 8, 33, 6, 78, 9, 67, 4, 82, 7, 56, 5, 54, 1, 15, 
    6, 92, 4, 45, 1, 45, 0, 72, 2, 48, 9,  2, 3, 13, 7, 94, 5, 76, 8, 33, 
    3, 29, 4, 53, 2, 52, 9, 49, 5, 65, 1, 66, 7, 12, 8, 68, 0, 11, 6, 24, 
    5, 44, 4, 13, 1, 21, 2,  8, 0, 12, 7, 15, 8, 82, 9, 18, 3, 35, 6, 95, 
    0, 38, 4,  6, 1, 31, 2, 51, 6, 83, 8, 31, 9, 88, 3, 99, 7, 21, 5, 68, 
    2, 45, 4, 17, 8, 46, 9, 25, 7, 15, 0, 62, 6, 76, 3, 64, 5, 83, 1, 90, 
    3, 21, 9, 40, 0, 75, 5, 76, 7,  9, 1, 61, 2, 45, 6, 40, 4, 37, 8, 57, 
    4, 36, 6, 46, 5, 67, 2, 42, 9, 23, 1, 68, 3, 29, 8, 81, 7, 19, 0, 54, 
    5, 56, 8,  1, 1, 80, 6,  6, 9, 92, 4, 12, 0,  6, 2, 65, 3, 39, 7,  8
  };
  const int r729[] = {
    10, 10, // Number of jobs and machines
    6, 29, 4, 92, 5, 40, 3, 19, 2, 85, 9, 95, 0, 30, 1, 58, 8, 15, 7,  6, 
    0, 54, 5, 61, 4, 23, 7, 27, 6, 35, 3,  1, 2, 14, 8, 80, 9, 72, 1, 33, 
    4, 33, 3, 35, 7, 27, 8, 73, 6, 72, 5, 71, 0, 32, 1, 78, 2, 26, 9, 65, 
    4, 10, 8, 64, 2, 40, 1, 11, 3, 29, 0, 51, 7, 93, 6, 63, 5, 46, 9,  4, 
    4, 67, 5,  3, 3, 93, 7, 48, 0, 76, 6, 96, 2, 22, 1, 90, 9, 26, 8, 72, 
    0, 68, 6, 57, 5, 94, 9, 80, 1, 19, 2, 78, 3, 82, 4, 90, 7, 94, 8, 89, 
    4, 90, 7, 71, 6, 47, 2, 27, 8, 66, 5, 84, 1, 35, 9,  8, 3, 60, 0, 73, 
    9, 23, 0, 12, 5, 88, 4, 75, 8, 96, 6, 61, 7, 91, 2, 81, 3, 90, 1, 54, 
    5, 32, 9, 43, 1, 17, 8, 87, 6, 65, 0, 44, 4, 14, 3, 63, 7, 92, 2, 95, 
    0, 80, 6, 61, 8, 49, 9, 47, 5, 93, 1, 10, 2, 34, 4, 83, 7, 34, 3, 57
  };
  const int r730[] = {
    10, 10, // Number of jobs and machines
    5, 71, 8, 99, 0, 34, 9,  6, 7, 15, 2, 56, 1, 81, 6, 21, 4, 76, 3,  4, 
    3, 24, 8, 13, 6, 35, 1, 58, 7, 16, 4, 53, 9, 59, 0,  8, 2, 86, 5, 71, 
    8, 53, 3, 43, 1, 18, 5, 44, 4, 42, 9, 65, 7, 47, 0, 62, 6,  5, 2, 30, 
    7, 25, 8, 46, 0,  1, 4, 62, 9, 17, 2,  7, 5, 35, 1, 69, 6, 98, 3, 29, 
    6, 53, 8, 23, 7, 30, 5, 90, 9, 67, 2,  5, 3, 62, 1, 51, 0, 25, 4, 16, 
    6, 94, 4, 12, 7, 40, 9, 27, 2, 96, 5, 47, 8, 54, 3, 34, 0, 58, 1, 13, 
    9, 28, 1, 83, 7, 89, 2, 31, 4, 17, 3, 50, 5,  4, 6, 26, 8, 52, 0,  6, 
    1, 16, 9, 34, 5, 99, 2, 86, 7, 51, 4, 57, 8, 65, 6, 92, 0, 40, 3, 18, 
    7, 50, 0, 58, 4, 54, 8, 79, 9, 70, 2, 16, 3, 16, 6, 26, 1, 55, 5, 50, 
    9, 65, 5, 61, 6, 90, 4,  6, 7,  6, 2, 19, 1, 58, 0, 12, 3, 46, 8, 46
  };
  const int r731[] = {
    10, 10, // Number of jobs and machines
    9, 34, 2, 99, 1, 11, 7, 34, 6, 13, 8, 95, 4, 46, 3, 29, 5, 11, 0, 17, 
    7, 78, 9, 66, 0, 77, 3, 57, 4, 93, 2, 60, 5, 83, 8,  1, 6, 72, 1, 93, 
    0, 70, 8, 82, 4, 93, 5, 55, 7, 83, 9, 17, 2, 16, 1, 10, 3, 72, 6, 94, 
    6, 77, 5,  7, 8, 66, 1, 23, 9, 14, 4, 38, 2, 78, 7, 27, 0, 28, 3, 69, 
    2, 98, 4, 29, 5, 93, 9,  2, 8, 27, 3, 15, 0, 57, 6, 30, 7, 60, 1, 26, 
    1, 17, 7, 84, 0, 30, 3, 30, 8, 73, 4, 97, 5, 60, 9, 59, 2, 65, 6, 79, 
    7, 62, 6, 10, 1, 86, 3, 17, 9, 74, 4, 90, 5,  2, 2, 66, 8, 96, 0, 16, 
    0,  5, 9, 15, 4, 51, 5, 83, 7, 11, 3,  9, 6, 26, 8, 69, 1, 85, 2, 55, 
    6,  2, 2, 12, 9, 16, 3, 59, 8, 35, 7, 21, 0, 18, 4, 47, 5, 92, 1, 53, 
    8, 78, 5, 92, 7, 26, 3, 42, 4, 53, 0, 47, 6, 99, 9, 60, 2, 96, 1, 63
  };
  const int r732[] = {
    10, 10, // Number of jobs and machines
    2, 24, 9, 83, 3, 60, 5, 49, 6, 75, 8,  4, 0, 74, 7, 85, 4, 71, 1, 44, 
    0, 91, 4, 31, 2, 62, 8, 76, 1, 34, 6,  9, 5, 84, 9, 49, 7,  7, 3, 31, 
    9, 30, 0, 23, 6, 98, 8, 32, 1, 31, 2, 30, 4, 62, 3, 28, 5, 66, 7, 85, 
    0, 29, 6, 63, 5, 80, 8, 78, 7, 25, 1, 41, 4, 46, 9, 42, 2, 29, 3, 47, 
    4, 17, 2, 62, 5, 29, 1,  3, 6, 23, 9, 65, 0, 53, 7, 42, 8, 52, 3, 36, 
    0, 80, 7, 24, 1, 19, 6, 63, 2, 72, 8, 23, 3, 48, 5, 93, 4, 33, 9, 99, 
    6, 90, 7, 42, 9, 77, 8,  2, 3, 84, 5, 90, 1, 11, 4,  1, 0, 31, 2, 50, 
    9, 44, 8,  5, 0,  9, 4, 35, 5,  3, 1, 67, 2, 56, 3, 66, 7, 18, 6, 82, 
    9, 58, 3, 53, 7, 61, 0,  2, 8,  7, 4, 39, 2, 44, 5, 72, 6, 43, 1,  3, 
    2, 49, 1,  2, 0, 96, 5, 43, 9, 54, 6, 94, 8,  8, 4, 63, 3, 35, 7, 88
  };
  const int r733[] = {
    10, 10, // Number of jobs and machines
    4, 28, 0, 45, 5, 26, 6, 74, 3,  6, 1, 56, 2, 97, 9, 55, 8, 25, 7, 23, 
    0, 65, 4, 15, 8, 50, 1, 13, 9, 80, 7, 59, 3, 25, 6, 57, 2, 48, 5, 59, 
    4, 56, 3, 63, 1, 70, 6, 18, 5, 49, 7, 63, 9, 82, 2, 29, 8, 80, 0, 38, 
    2, 19, 4, 57, 6, 35, 5,  1, 3, 98, 1, 90, 8, 73, 7, 46, 0, 35, 9,  4, 
    7, 65, 2, 54, 4, 48, 8, 82, 3, 59, 9, 63, 0,  2, 5, 96, 1, 75, 6, 32, 
    4, 96, 6, 43, 8, 45, 2, 58, 0, 40, 1, 40, 7,  9, 9, 28, 3, 11, 5,  3, 
    0, 74, 4,  2, 3, 64, 5,  1, 7, 28, 1, 93, 6,  2, 2, 42, 9,  1, 8, 92, 
    5, 12, 8, 35, 9, 43, 3, 61, 7, 35, 4,  5, 6, 96, 0, 84, 1, 46, 2, 82, 
    1, 35, 7, 92, 8, 51, 4, 66, 5, 33, 2, 72, 9, 29, 0, 25, 3, 20, 6, 76, 
    5, 71, 6, 42, 3, 97, 2, 29, 9, 98, 1,  5, 8, 99, 7, 88, 0, 87, 4, 88
  };
  const int r734[] = {
    10, 10, // Number of jobs and machines
    8, 21, 5, 18, 9, 94, 2, 26, 3, 32, 6, 59, 7, 90, 4, 20, 1, 91, 0, 27, 
    0, 35, 5,  4, 1,  7, 3, 68, 7, 72, 6, 77, 4, 36, 8, 41, 2, 58, 9, 49, 
    8, 90, 2, 17, 3, 77, 0, 47, 9,  2, 4, 65, 6, 14, 7, 22, 5, 95, 1, 39, 
    9, 31, 7, 34, 4, 69, 6, 33, 8, 88, 5, 58, 0,  8, 1, 93, 3, 61, 2, 81, 
    5, 97, 8, 80, 2, 74, 1, 10, 7, 54, 6, 57, 9, 90, 4, 14, 0, 49, 3, 70, 
    5, 61, 6, 37, 1, 71, 3, 53, 0, 71, 4, 73, 7, 62, 8, 36, 2,  3, 9, 79, 
    7, 20, 8,  5, 2, 78, 0, 84, 6, 24, 3, 34, 4, 11, 1, 99, 9, 64, 5, 24, 
    6,  1, 0, 38, 8, 29, 7, 32, 4, 26, 5, 29, 2, 72, 3, 84, 1, 92, 9, 97, 
    3, 36, 6,  7, 9, 99, 0, 61, 4, 55, 8,  4, 2, 29, 7, 40, 5, 53, 1, 37, 
    9,  4, 6, 92, 3, 53, 2, 56, 1, 27, 5, 80, 0, 91, 7, 35, 8,  9, 4, 49
  };
  const int r735[] = {
    10, 10, // Number of jobs and machines
    3, 58, 1, 28, 2,  8, 5, 40, 7, 41, 8, 23, 0, 14, 6, 93, 4, 97, 9,  5, 
    1,  4, 6, 36, 4, 95, 5, 41, 0, 38, 8, 88, 2, 45, 9, 89, 7, 19, 3, 11, 
    4, 22, 1,  4, 7, 31, 9,  3, 0, 35, 6, 41, 2, 38, 3, 31, 5, 89, 8, 75, 
    2, 92, 7, 65, 1, 29, 3, 93, 4, 11, 6, 65, 8, 18, 0, 30, 9,  2, 5, 89, 
    7, 20, 2, 18, 1, 44, 9,  8, 4, 63, 0, 51, 3,  3, 6, 24, 8, 83, 5, 33, 
    6, 52, 1, 28, 7,  6, 4, 91, 8, 72, 5, 39, 0, 62, 3, 30, 2, 48, 9, 88, 
    1, 44, 2, 75, 3, 28, 0, 42, 5, 90, 4, 33, 8, 63, 9, 80, 7, 55, 6, 45, 
    2, 19, 4, 97, 1, 71, 9, 12, 6, 61, 5, 49, 7, 84, 0, 41, 3,  9, 8, 50, 
    8, 31, 1, 19, 4, 40, 7, 80, 0, 51, 2, 31, 6, 44, 9,  3, 5, 85, 3, 37, 
    1, 62, 0, 50, 5, 48, 6,  3, 8, 49, 9, 86, 7, 40, 3, 12, 2, 85, 4, 63
  };
  const int r736[] = {
    10, 10, // Number of jobs and machines
    8, 21, 5, 79, 2, 58, 1, 63, 9, 43, 4,  4, 6,  7, 7, 53, 0, 41, 3, 56, 
    3, 94, 7, 29, 6, 42, 8, 27, 5, 57, 0, 37, 2,  5, 9, 66, 4, 39, 1, 12, 
    9, 83, 2, 67, 6, 54, 8, 20, 1, 72, 0, 37, 4, 79, 3, 74, 5, 22, 7, 41, 
    1, 10, 0, 75, 2,  1, 4, 65, 8, 76, 6, 33, 5, 71, 3, 11, 7, 32, 9, 66, 
    5, 24, 0, 27, 1, 24, 8, 33, 4, 53, 7,  9, 9, 14, 3, 90, 2, 12, 6,  9, 
    5, 42, 6, 14, 4, 17, 1, 70, 8, 66, 0, 71, 3,  4, 7, 74, 2, 69, 9, 39, 
    6, 96, 8, 41, 4, 88, 9, 45, 3, 47, 2, 36, 7, 61, 5, 52, 1, 77, 0, 89, 
    1, 16, 0,  5, 4, 85, 3, 17, 5, 26, 8,  9, 7, 22, 6, 15, 9, 71, 2, 99, 
    4, 93, 7, 76, 3, 28, 8, 75, 1, 77, 9, 50, 2, 52, 0, 35, 6, 93, 5, 11, 
    0, 83, 3, 58, 2, 72, 8, 16, 5, 85, 1, 90, 9, 90, 4, 91, 6, 22, 7, 98
  };
  const int r737[] = {
    10, 10, // Number of jobs and machines
    1, 50, 5, 70, 2, 49, 9, 44, 3, 59, 0, 66, 8, 65, 7, 50, 4, 13, 6, 13, 
    6, 40, 3, 86, 2, 14, 5, 60, 7, 61, 9, 83, 4, 57, 8, 79, 0, 84, 1, 54, 
    6, 64, 0, 83, 7, 44, 9, 81, 4, 80, 3, 57, 2, 98, 1, 59, 5, 41, 8, 61, 
    3,  4, 5, 50, 6, 61, 4, 57, 0, 76, 7,  7, 1, 99, 8, 32, 9, 93, 2, 80, 
    1, 34, 0, 79, 7, 13, 3, 79, 8, 76, 9,  6, 2, 97, 6, 65, 5, 91, 4, 23, 
    1, 56, 8, 93, 0, 30, 2, 44, 3, 10, 4, 12, 5,  1, 9, 38, 7, 65, 6, 76, 
    4, 53, 6, 41, 9, 24, 1, 40, 3, 84, 8, 70, 5,  1, 2,  5, 7, 69, 0, 45, 
    5, 75, 6, 47, 9, 24, 8, 24, 4, 75, 7, 75, 0, 71, 3, 47, 2, 40, 1, 98, 
    0, 81, 9, 85, 7, 44, 1, 17, 8, 16, 4, 62, 5, 58, 2, 63, 6, 45, 3, 57, 
    2, 29, 7, 54, 8, 90, 5, 56, 0, 15, 3, 54, 6, 90, 4, 75, 9, 22, 1, 97
  };
  const int r738[] = {
    10, 10, // Number of jobs and machines
    8, 58, 5, 32, 6, 52, 2, 86, 4, 70, 9, 89, 7, 29, 3, 62, 1, 91, 0, 81, 
    7,  6, 0, 60, 4, 63, 8, 54, 5, 17, 1, 16, 6, 18, 9, 17, 2, 80, 3, 23, 
    1, 34, 5,  9, 3, 70, 0, 36, 9,  1, 7, 27, 8, 33, 2, 50, 6, 43, 4, 26, 
    4, 68, 5, 55, 1, 65, 7, 31, 6, 43, 2, 30, 9, 64, 3, 61, 0, 47, 8, 24, 
    1, 15, 0, 12, 6, 23, 5, 15, 8, 92, 7, 45, 3,  1, 4, 18, 2, 41, 9, 99, 
    2, 91, 6, 99, 7, 75, 5, 92, 3, 24, 9, 11, 4, 99, 0, 37, 1, 56, 8,  5, 
    6, 26, 0, 63, 5, 63, 8, 26, 2, 21, 7,  6, 1, 76, 4, 45, 9, 62, 3, 39, 
    9, 37, 0, 57, 1,  5, 8, 16, 6, 59, 4, 96, 2, 39, 3, 40, 7, 52, 5, 60, 
    8, 18, 5, 34, 1, 79, 9, 16, 0,  3, 2, 62, 3, 45, 4, 93, 7,  9, 6, 20, 
    1, 57, 2, 26, 9, 51, 4, 22, 7, 64, 5, 30, 0, 18, 6, 60, 8, 13, 3,  4
  };
  const int r739[] = {
    10, 10, // Number of jobs and machines
    2, 44, 0, 89, 3, 26, 8, 30, 7,  4, 5,  1, 4, 27, 1, 60, 9, 45, 6, 29, 
    7, 17, 9, 70, 6, 26, 0, 26, 4, 68, 8, 58, 1,  5, 2, 71, 5, 38, 3,  7, 
    6, 43, 4, 82, 5, 97, 1, 61, 2, 93, 9, 12, 0, 92, 7, 65, 8, 70, 3, 65, 
    4,  8, 3, 72, 8, 34, 0, 43, 6, 78, 5, 37, 2,  8, 9, 47, 7, 36, 1, 61, 
    4, 73, 0, 72, 5,  6, 7, 96, 9, 75, 2, 25, 1, 36, 3, 69, 8, 71, 6, 41, 
    0, 84, 5, 56, 6, 37, 4,  9, 3, 40, 1, 20, 2, 24, 9, 69, 7,  7, 8, 78, 
    3, 84, 4, 56, 8, 28, 7, 73, 0,  5, 2, 68, 1, 25, 6,  4, 9, 62, 5, 95, 
    0, 87, 7, 31, 3, 16, 8, 73, 1, 96, 2, 10, 9, 80, 5, 93, 6, 99, 4, 90, 
    4, 75, 6, 81, 5, 25, 2, 94, 7,  2, 1, 28, 0,  2, 8, 10, 9, 43, 3, 84, 
    0, 40, 6,  6, 2, 69, 8, 66, 1, 59, 4, 34, 9,  4, 5, 96, 7, 80, 3, 83
  };
  const int r740[] = {
    10, 10, // Number of jobs and machines
    8, 11, 2, 70, 5,  2, 1,  1, 4, 10, 7, 38, 9, 35, 3, 58, 6, 20, 0, 88, 
    9, 40, 3,  1, 6,  5, 5, 51, 1, 30, 0, 95, 7, 20, 4, 63, 2, 86, 8, 31, 
    4, 88, 2, 81, 1,  9, 5, 91, 9, 62, 3, 56, 7, 24, 8, 89, 6, 59, 0, 86, 
    3,  5, 1, 78, 5, 71, 6, 97, 0, 59, 8, 12, 7, 40, 2, 17, 9, 96, 4, 89, 
    4, 55, 6,  9, 9, 59, 1, 96, 7,  2, 0, 11, 3, 95, 2, 97, 8, 60, 5, 83, 
    3, 64, 2, 26, 5, 72, 8, 67, 0, 99, 4, 79, 1, 50, 9, 51, 7, 59, 6, 41, 
    9, 47, 3, 97, 2, 73, 5, 88, 1, 84, 6, 84, 4, 16, 0, 14, 7, 56, 8, 29, 
    4, 27, 2, 13, 6, 43, 3, 27, 8, 72, 0, 58, 9, 22, 5, 72, 7, 65, 1, 33, 
    0, 76, 4, 36, 8, 25, 5, 20, 7, 25, 9, 14, 6, 85, 3, 89, 2, 56, 1, 49, 
    7, 33, 3, 30, 5, 95, 8, 72, 4, 52, 1, 89, 9, 51, 0, 14, 6, 29, 2, 11
  };
  const int r741[] = {
    10, 10, // Number of jobs and machines
    2, 92, 4, 17, 1, 84, 7, 12, 8, 90, 3, 16, 6, 44, 5, 44, 9, 54, 0,  4, 
    3, 21, 2,  7, 4, 29, 5, 44, 7, 79, 0, 27, 8,  1, 6, 41, 9, 95, 1, 16, 
    9, 24, 3, 78, 5, 12, 2, 92, 7, 37, 0, 90, 8,  4, 6, 98, 4, 29, 1, 93, 
    7, 68, 0, 79, 8, 64, 6,  8, 4, 46, 5, 16, 3, 63, 9, 51, 2, 52, 1, 29, 
    6, 80, 9, 53, 4, 83, 7, 16, 1, 87, 3, 37, 2,  5, 8, 30, 5, 28, 0, 21, 
    6, 70, 9,  1, 8, 88, 7, 23, 3, 18, 1, 61, 5, 96, 0, 87, 2, 81, 4, 29, 
    8, 29, 6, 25, 2, 64, 0, 38, 3, 84, 7, 95, 4, 25, 9, 70, 5, 13, 1, 37, 
    1, 12, 2, 69, 8, 85, 6, 77, 4, 57, 0, 95, 5, 64, 3, 78, 7,  7, 9, 19, 
    4, 61, 1, 70, 5, 25, 2,  7, 9, 17, 7, 47, 0, 53, 8, 68, 3, 41, 6, 81, 
    7, 61, 9, 75, 1, 96, 2, 41, 3, 52, 0, 45, 5, 50, 8, 32, 4,  7, 6, 56
  };
  const int r742[] = {
    10, 10, // Number of jobs and machines
    1, 16, 4, 80, 5, 83, 8, 31, 7, 49, 3,  4, 6, 35, 9, 24, 2, 67, 0, 60, 
    0, 59, 4, 72, 7, 77, 3, 31, 6, 37, 9, 28, 8, 53, 2,  2, 1, 97, 5, 56, 
    4, 60, 8, 38, 9, 67, 2, 90, 0, 23, 7, 87, 6, 30, 1, 20, 3, 10, 5, 98, 
    4, 38, 5, 90, 0, 87, 8, 16, 7, 10, 3, 91, 6, 19, 2,  5, 1, 73, 9, 40, 
    1, 18, 9, 29, 8, 71, 0, 95, 3, 62, 7, 32, 4, 57, 2,  1, 6, 35, 5, 59, 
    2, 39, 3, 49, 1, 63, 6, 38, 0, 63, 7, 18, 8, 81, 9, 90, 4, 32, 5, 30, 
    6, 95, 2, 12, 5, 58, 4,  8, 7,  1, 9, 29, 8,  7, 1, 54, 3,  8, 0, 12, 
    2, 63, 5,  3, 9, 12, 3, 22, 0, 28, 8, 93, 1, 91, 7, 88, 4, 55, 6, 41, 
    2, 56, 4, 46, 8, 57, 9, 25, 0, 46, 3, 40, 7, 70, 5, 63, 6, 65, 1, 40, 
    8, 26, 2,  8, 9,  6, 5, 22, 6, 14, 3, 52, 7,  4, 0, 34, 4, 34, 1, 38
  };
  const int r743[] = {
    10, 10, // Number of jobs and machines
    1, 92, 5, 11, 8,  2, 2, 69, 4, 52, 9, 46, 3, 63, 7, 32, 6, 75, 0, 96, 
    1, 57, 9, 21, 2, 34, 3, 20, 4, 45, 0, 34, 5, 59, 8,  5, 7, 20, 6, 97, 
    0, 73, 8, 70, 7, 35, 4, 22, 9, 27, 6, 85, 5, 86, 1, 98, 3, 52, 2, 27, 
    5, 74, 0, 89, 7, 80, 3, 26, 4, 43, 1, 72, 9, 98, 2, 50, 8, 52, 6, 32, 
    9, 50, 1, 97, 6, 37, 8, 18, 0,  1, 2, 12, 7, 18, 5, 99, 4, 59, 3, 45, 
    3, 89, 0, 36, 9, 43, 5, 75, 6, 74, 8, 54, 4, 95, 2, 75, 1, 46, 7, 57, 
    8, 56, 4, 74, 3, 67, 6, 40, 1,  8, 5, 11, 7, 15, 2, 89, 0, 78, 9, 88, 
    1, 30, 6, 21, 5, 23, 3, 59, 0, 19, 2, 37, 7, 58, 4, 24, 9, 19, 8, 52, 
    5, 99, 1, 37, 0, 43, 6, 92, 8,  6, 4, 56, 3, 81, 2, 88, 7, 90, 9, 51, 
    9, 19, 5,  9, 6,  4, 2, 24, 4, 57, 1, 93, 3, 86, 7, 19, 0, 42, 8, 32
  };
  const int r744[] = {
    10, 10, // Number of jobs and machines
    0, 90, 6, 73, 4, 47, 2, 99, 1, 33, 8, 43, 5,  2, 9, 12, 7, 14, 3, 24, 
    5, 14, 4, 88, 6,  5, 3, 66, 1, 55, 2, 83, 7, 72, 0, 47, 9, 32, 8, 20, 
    5, 19, 2, 47, 6, 58, 1, 76, 4, 12, 8, 66, 9, 23, 7, 44, 3, 99, 0, 34, 
    7, 42, 6, 99, 2, 35, 4, 54, 0, 22, 3, 21, 1, 78, 8, 86, 9, 71, 5, 80, 
    1, 56, 6, 50, 3,  5, 9, 94, 4, 96, 2, 21, 5, 59, 0, 59, 7, 39, 8, 73, 
    4, 87, 2, 79, 1, 63, 5, 29, 6, 39, 9, 95, 3, 12, 7, 82, 8, 41, 0, 45, 
    7, 50, 6, 64, 4, 67, 9, 41, 1, 36, 8, 10, 2, 10, 0, 74, 3, 90, 5, 89, 
    1, 87, 9, 68, 2, 16, 6, 54, 8, 23, 5, 16, 3, 32, 0, 20, 4, 11, 7, 77, 
    3, 34, 8, 76, 7, 13, 1, 87, 0, 60, 4, 90, 6, 93, 5,  7, 2, 39, 9, 91, 
    3, 77, 6, 22, 0, 18, 1, 14, 7, 26, 9, 88, 2, 64, 4, 23, 5,  3, 8, 30
  };
  const int r745[] = {
    10, 10, // Number of jobs and machines
    4, 33, 5, 38, 1, 91, 6, 35, 0, 54, 7, 63, 9, 25, 2, 99, 8,  3, 3, 83, 
    9, 77, 1, 83, 0, 53, 7, 82, 4, 48, 5, 80, 8,  7, 3, 63, 2, 28, 6, 83, 
    2, 65, 4, 87, 0, 18, 1, 41, 5, 55, 7, 31, 3, 49, 8, 26, 6, 65, 9, 75, 
    2, 11, 0, 16, 3, 18, 7, 77, 8, 11, 1, 39, 6, 26, 5, 32, 4, 67, 9, 27, 
    1, 59, 2, 97, 3, 42, 4, 27, 7, 46, 5, 88, 8, 42, 0, 50, 9, 32, 6, 28, 
    9, 21, 1, 41, 4, 84, 8, 64, 2, 40, 5, 59, 6, 57, 3, 82, 0, 89, 7, 68, 
    5, 73, 6,  4, 0, 84, 7, 29, 4, 48, 3, 29, 2, 85, 9, 59, 8, 23, 1, 62, 
    4, 16, 5, 34, 7, 43, 3, 33, 6, 11, 8,  5, 1,  2, 0, 57, 2, 24, 9, 39, 
    7, 90, 0, 31, 5, 77, 6, 65, 8, 85, 9, 26, 4, 93, 2, 99, 1, 39, 3, 34, 
    9,  9, 0, 23, 4, 20, 7, 10, 8, 36, 3, 97, 2, 29, 1, 83, 6, 19, 5, 60
  };
  const int r746[] = {
    10, 10, // Number of jobs and machines
    9, 56, 8, 97, 3, 15, 0, 36, 5, 23, 4, 69, 2, 48, 1, 85, 7, 60, 6, 11, 
    8, 48, 2, 87, 4, 52, 5, 57, 1, 31, 0, 95, 6, 12, 3, 49, 9, 33, 7, 10, 
    8, 98, 1, 50, 0, 95, 7, 52, 4, 63, 3, 29, 2,  8, 5, 23, 9, 47, 6, 81, 
    0, 48, 3, 14, 8, 90, 4, 54, 7, 78, 9, 82, 5, 86, 2, 51, 6, 62, 1, 99, 
    5, 11, 7, 13, 6, 19, 0, 37, 3, 73, 9, 84, 2, 54, 1, 58, 4, 19, 8, 27, 
    2, 32, 7, 60, 6, 47, 8, 55, 1,  3, 3, 80, 9, 55, 4, 35, 5, 54, 0, 41, 
    9, 14, 8, 28, 3, 60, 4, 53, 1, 21, 6, 26, 7, 73, 5, 52, 2, 33, 0, 16, 
    7,  7, 2, 99, 4, 65, 6, 67, 9, 86, 0, 66, 5, 57, 3, 83, 8, 39, 1, 92, 
    8, 65, 1, 79, 0, 11, 3, 84, 9, 77, 7, 52, 4, 87, 2, 88, 5, 31, 6, 22, 
    9,  3, 1,  8, 6, 18, 8, 40, 5, 72, 2, 49, 0, 59, 4, 74, 3, 66, 7, 85
  };
  const int r747[] = {
    10, 10, // Number of jobs and machines
    2, 71, 8,  1, 6, 72, 0, 97, 4, 48, 3,  3, 1, 51, 5, 62, 7, 90, 9, 72, 
    4, 25, 7, 34, 2, 44, 1, 96, 5, 82, 0, 28, 9, 70, 3, 77, 6, 26, 8, 22, 
    1, 78, 4, 47, 7, 44, 8, 36, 5, 54, 2, 29, 3, 91, 9, 21, 0, 62, 6, 68, 
    7, 63, 3, 12, 0, 35, 9, 50, 1, 31, 2, 25, 5, 41, 6, 95, 4, 12, 8, 87, 
    7, 59, 6, 60, 9, 43, 8, 41, 4, 41, 1, 46, 3,  5, 0, 96, 5, 51, 2, 53, 
    5, 64, 2, 85, 3, 50, 0, 50, 7, 14, 6, 21, 9, 26, 4, 20, 1, 53, 8, 88, 
    5, 66, 2, 84, 6,  4, 4, 35, 8, 77, 7, 51, 9,  3, 0, 88, 1,  9, 3, 87, 
    3,  2, 6, 87, 5, 38, 8, 33, 2, 10, 4, 71, 1, 50, 0, 84, 9, 24, 7, 30, 
    6, 98, 4, 90, 9, 47, 1, 28, 0, 58, 7, 37, 2, 53, 5, 25, 3, 41, 8, 21, 
    8, 54, 4, 51, 7,  1, 1,  4, 2, 50, 6, 55, 9, 14, 3, 32, 0, 38, 5, 93
  };
  const int r748[] = {
    10, 10, // Number of jobs and machines
    6, 39, 5,  2, 0, 68, 8, 50, 3, 99, 4, 10, 2, 77, 1, 88, 9, 18, 7, 29, 
    2, 16, 8, 31, 5, 20, 3, 73, 7, 52, 0, 92, 6, 79, 9, 56, 1, 93, 4, 53, 
    0, 43, 1, 94, 2, 11, 5, 13, 4, 94, 6, 87, 7, 26, 3, 53, 8, 81, 9, 39, 
    0, 27, 6,  7, 1, 36, 5, 70, 7, 12, 3, 77, 2, 57, 8, 85, 4, 48, 9, 52, 
    6, 92, 1, 22, 5, 62, 8,  1, 4, 17, 0, 84, 9, 52, 3, 68, 7, 85, 2, 93, 
    8,  2, 9, 71, 7, 55, 1, 76, 2,  8, 0, 50, 3, 61, 4, 57, 6, 68, 5, 76, 
    7, 21, 0, 98, 9, 65, 6, 56, 4, 96, 3, 29, 2, 24, 5, 72, 1, 79, 8, 57, 
    3, 42, 5, 10, 8, 63, 9, 10, 1, 88, 0, 42, 2, 18, 7, 43, 4, 27, 6, 39, 
    0, 88, 4, 48, 2, 95, 9, 98, 8, 19, 3, 58, 6, 88, 1, 13, 7,  8, 5, 23, 
    5, 76, 9, 64, 3, 50, 6, 83, 4,  1, 0, 20, 2, 50, 7,  5, 1, 83, 8,  9
  };
  const int r749[] = {
    10, 10, // Number of jobs and machines
    2, 32, 4, 59, 9,  2, 5, 77, 8, 15, 6, 27, 1, 14, 7, 40, 3, 31, 0, 52, 
    1,  9, 3, 53, 7, 56, 9, 49, 8, 90, 2, 84, 0, 25, 4, 64, 5,  6, 6, 89, 
    0, 35, 6, 38, 1, 18, 2, 93, 5, 87, 8, 16, 9,  2, 4, 75, 7, 32, 3, 46, 
    6,  8, 0, 25, 2, 78, 1, 74, 3, 34, 5, 76, 7, 54, 8, 83, 4, 68, 9, 64, 
    8, 85, 1, 44, 4, 55, 7, 70, 2, 53, 0, 20, 5, 45, 3, 82, 9, 70, 6, 74, 
    3,  6, 8, 10, 5, 16, 4, 33, 6, 52, 9, 65, 1, 31, 0, 63, 2, 80, 7,  3, 
    1, 71, 4, 41, 8, 50, 9,  9, 0, 68, 3, 18, 2, 42, 6,  5, 7, 51, 5, 49, 
    8, 36, 9, 92, 1, 23, 7, 35, 6, 97, 2, 10, 5, 62, 3, 66, 0, 77, 4, 93, 
    7, 92, 4, 20, 8, 10, 1, 83, 6, 30, 5,  4, 2, 85, 0, 36, 9, 18, 3,  1, 
    9, 44, 6, 76, 3, 37, 8, 69, 7, 62, 1, 66, 0, 91, 5, 26, 2, 87, 4, 22
  };
  const int r750[] = {
    10, 10, // Number of jobs and machines
    5, 42, 4, 53, 8,  6, 6,  7, 9, 89, 3, 70, 0, 73, 1, 61, 2, 39, 7, 95, 
    8, 77, 2, 95, 0, 56, 9, 15, 1, 21, 5, 10, 6,  6, 7, 56, 4, 63, 3,  5, 
    4, 94, 9, 32, 3, 75, 1, 91, 0, 60, 7, 92, 8, 58, 2, 33, 6, 56, 5, 96, 
    5, 95, 6, 77, 0, 77, 4, 29, 2, 84, 8, 97, 1, 63, 3, 59, 9, 72, 7, 80, 
    4,  8, 3, 76, 0, 22, 1, 24, 8, 72, 9, 18, 5, 44, 2, 66, 7, 21, 6, 80, 
    1, 68, 9, 43, 3, 67, 7, 51, 8, 47, 6, 71, 0, 80, 5, 56, 4, 32, 2, 88, 
    8, 34, 4, 16, 3,  4, 0, 18, 7, 79, 9, 16, 6, 49, 5, 48, 1, 61, 2, 28, 
    2, 99, 9,  1, 5, 67, 8, 48, 6, 89, 7, 92, 3, 49, 4, 63, 1, 54, 0, 17, 
    6, 94, 9, 99, 3, 67, 2, 54, 8, 36, 4, 62, 5, 72, 1, 28, 7, 75, 0, 50, 
    8, 58, 6, 98, 2, 12, 1, 98, 4, 64, 5, 59, 7,  8, 3, 68, 9, 69, 0, 63
  };
  const int r751[] = {
    10, 10, // Number of jobs and machines
    3, 37, 5, 31, 7,  6, 6, 99, 9, 36, 8, 57, 1, 10, 0, 25, 4, 33, 2, 38, 
    2, 41, 1, 33, 9, 27, 3, 13, 4, 53, 5, 87, 8, 24, 0, 17, 6, 28, 7, 51, 
    0, 27, 4, 19, 1, 13, 9, 82, 2, 24, 5,  9, 7, 61, 3, 43, 8, 33, 6,  8, 
    4, 24, 7, 53, 0, 73, 1, 16, 8, 13, 2, 81, 6, 67, 5, 34, 3, 18, 9, 91, 
    3, 49, 8, 52, 4,  2, 5, 91, 2, 35, 1, 96, 0, 93, 9, 14, 6,  4, 7, 29, 
    9, 61, 7, 90, 8, 54, 2, 13, 3, 55, 1, 39, 0, 86, 5, 63, 6, 49, 4, 29, 
    5, 59, 3, 76, 1, 18, 7, 64, 4, 58, 9, 97, 8, 24, 6, 37, 0,  1, 2, 84, 
    4, 29, 9, 60, 3, 71, 1,  5, 8, 45, 5,  6, 2, 29, 0, 90, 6, 68, 7, 12, 
    6, 25, 7, 43, 0, 50, 3, 86, 5, 88, 9, 84, 2, 16, 1, 80, 8, 22, 4, 54, 
    6,  7, 0, 19, 9,  7, 3, 38, 5, 13, 7, 66, 8, 19, 4, 30, 1, 64, 2, 75
  };
  const int r752[] = {
    10, 10, // Number of jobs and machines
    2, 10, 9, 43, 7, 86, 8, 38, 3, 12, 6, 59, 4, 53, 1, 37, 0, 85, 5, 15, 
    3, 32, 0, 96, 6, 57, 1, 65, 8, 84, 9,  7, 4, 14, 2, 83, 5, 72, 7,  3, 
    6, 90, 5, 98, 1, 58, 8, 21, 2, 99, 3, 79, 9, 78, 4, 98, 7, 74, 0, 14, 
    9, 83, 1, 40, 8, 83, 4, 28, 2, 88, 7, 86, 5, 33, 3, 88, 0, 15, 6, 35, 
    8, 99, 1, 14, 2, 79, 3, 72, 7, 31, 9, 86, 4, 35, 6, 40, 0,  5, 5, 31, 
    1, 10, 5, 17, 3, 41, 2,  5, 9,  8, 0, 42, 7,  9, 8, 64, 4, 77, 6, 44, 
    5, 35, 9, 47, 6, 87, 8, 60, 7, 38, 4, 98, 0, 95, 2, 64, 1, 54, 3, 65, 
    3, 68, 1, 32, 9, 25, 2,  3, 7, 28, 5, 88, 4, 94, 8, 25, 6, 38, 0, 44, 
    5, 13, 9,  8, 0, 58, 3, 83, 4, 95, 2, 10, 6, 68, 1,  3, 8, 66, 7, 37, 
    0, 62, 7, 35, 6, 18, 2, 71, 5, 80, 4,  2, 1, 87, 8, 87, 3, 82, 9, 98
  };
  const int r753[] = {
    10, 10, // Number of jobs and machines
    3, 84, 8, 36, 6, 44, 2, 32, 4, 17, 9,  9, 0, 47, 5, 95, 1, 30, 7, 60, 
    8, 22, 5, 91, 0, 62, 1, 27, 2, 87, 9, 55, 7, 23, 6, 48, 3, 54, 4, 44, 
    0, 57, 4, 18, 6, 90, 1, 10, 8, 15, 7, 63, 9, 99, 3, 18, 2, 63, 5, 10, 
    6, 42, 2, 63, 0, 37, 5, 40, 8, 50, 3, 95, 7, 70, 4,  5, 1, 86, 9, 78, 
    5, 42, 0,  3, 2, 16, 3, 64, 1, 93, 6, 36, 9, 70, 4, 90, 8,  4, 7, 56, 
    9, 81, 8, 61, 6, 73, 5, 46, 7, 92, 2, 73, 4, 99, 3, 98, 0, 61, 1, 56, 
    6, 62, 7, 56, 4, 98, 9, 26, 3, 40, 1, 39, 5, 72, 0, 20, 8, 64, 2, 24, 
    0, 37, 6, 46, 1, 17, 2, 25, 4, 81, 7, 63, 3, 37, 8, 48, 9, 26, 5, 10, 
    4, 72, 1, 26, 2, 91, 8, 76, 3,  2, 9, 89, 0, 78, 5, 57, 7, 71, 6, 59, 
    8, 77, 4, 89, 0, 19, 2,  6, 5, 24, 3, 29, 7, 32, 9, 46, 6, 98, 1, 88
  };
  const int r754[] = {
    10, 10, // Number of jobs and machines
    3, 80, 7, 50, 1, 46, 4,  3, 6, 55, 9, 87, 5, 37, 0, 49, 2, 68, 8,  8, 
    2, 53, 5, 19, 3, 71, 1, 96, 6, 59, 9, 56, 0, 86, 8, 85, 7, 91, 4, 22, 
    3,  6, 5,  8, 4, 43, 0, 72, 9, 46, 2, 68, 8, 35, 6, 84, 7, 35, 1, 74, 
    8, 20, 1, 51, 7, 22, 9, 74, 3, 20, 0, 81, 4, 66, 6,  3, 5, 14, 2, 62, 
    2, 98, 3, 18, 1, 41, 6, 21, 5, 11, 0, 53, 8, 32, 9, 95, 7, 17, 4, 13, 
    5, 76, 1, 51, 3, 87, 0, 95, 2, 37, 6, 12, 7, 33, 9, 48, 4, 12, 8,  8, 
    9, 87, 7, 23, 8, 53, 6,  8, 1, 11, 0, 37, 2, 98, 3,  4, 4, 52, 5, 72, 
    4, 45, 9, 27, 1, 55, 3, 49, 2, 98, 5, 25, 0, 80, 6, 42, 8, 76, 7, 69, 
    6, 73, 2, 34, 8, 93, 5,  9, 0, 16, 7, 12, 4, 11, 1,  9, 3, 23, 9, 20, 
    4, 43, 9,  9, 5, 27, 7, 64, 6, 90, 2, 99, 0,  9, 8, 42, 1,  1, 3, 22
  };
  const int r755[] = {
    10, 10, // Number of jobs and machines
    9, 76, 4, 65, 3, 12, 1, 35, 7, 76, 2, 29, 0, 98, 5, 61, 6, 92, 8, 34, 
    1, 45, 3, 27, 9, 34, 6, 93, 4, 85, 8, 99, 0, 93, 7, 79, 2, 24, 5, 70, 
    3, 14, 8, 77, 2, 61, 0, 17, 5, 36, 7, 83, 4, 85, 6, 24, 9, 35, 1, 10, 
    6, 39, 8, 18, 9, 30, 3, 10, 1, 15, 0, 90, 4, 16, 7, 64, 2, 66, 5, 35, 
    3, 56, 4, 66, 9, 41, 7, 47, 0,  3, 6, 61, 5, 48, 8, 18, 1, 50, 2, 36, 
    5, 82, 3, 25, 8, 26, 0, 24, 9,  3, 2, 36, 6, 81, 1,  3, 4, 57, 7, 14, 
    7, 41, 2, 64, 8, 99, 4, 71, 1, 99, 0, 54, 9, 95, 6, 43, 3, 51, 5, 44, 
    3, 90, 7, 90, 8,  2, 6,  5, 1, 83, 5, 74, 0, 94, 9, 76, 2, 39, 4, 73, 
    0, 82, 8, 77, 7, 86, 1, 39, 9,  9, 2, 60, 6, 80, 4, 11, 5, 92, 3, 19, 
    9, 48, 8, 33, 1, 29, 6, 32, 2,  3, 3, 42, 4, 73, 0, 43, 5, 72, 7, 54
  };
  const int r756[] = {
    10, 10, // Number of jobs and machines
    3,  3, 4, 83, 8, 52, 7, 46, 1, 36, 0, 42, 2, 38, 5, 97, 9, 57, 6, 90, 
    2,  8, 9, 79, 6, 51, 1, 68, 7, 11, 4, 71, 3, 21, 8, 30, 0, 72, 5, 32, 
    2, 48, 5, 66, 7,  1, 3, 70, 8,  8, 9,  8, 6, 67, 4, 13, 0, 44, 1, 32, 
    2, 41, 7, 40, 0,  3, 9, 15, 5,  4, 8,  7, 4, 74, 1, 95, 3, 32, 6, 88, 
    0, 18, 4, 43, 8,  8, 1, 37, 3, 52, 5, 66, 7, 30, 2,  4, 6, 45, 9, 57, 
    6, 46, 9, 86, 5, 63, 7, 90, 4, 20, 1, 94, 2, 92, 0, 97, 8, 56, 3, 31, 
    0, 72, 4, 69, 5, 35, 6, 34, 8, 91, 1, 94, 7, 11, 3, 43, 9,  3, 2, 55, 
    9, 49, 0,  1, 8, 60, 6, 45, 4, 88, 5, 45, 1, 72, 3, 81, 2, 88, 7, 29, 
    9, 83, 5, 84, 6,  7, 7, 59, 0, 69, 4, 13, 1, 97, 3, 78, 8, 64, 2, 86, 
    7, 82, 8, 94, 4, 12, 0, 81, 5, 25, 3, 57, 2, 31, 9, 44, 1, 83, 6, 24
  };
  const int r757[] = {
    10, 10, // Number of jobs and machines
    5, 12, 7, 21, 2, 45, 6, 44, 9, 80, 1, 87, 3, 52, 0, 82, 8, 78, 4,  4, 
    0, 31, 1, 58, 6, 45, 7, 15, 2, 52, 4, 34, 5, 68, 8,  9, 3,  6, 9, 41, 
    4, 23, 6, 82, 9, 77, 8, 35, 0, 63, 3, 92, 5, 99, 1,  3, 7, 42, 2, 58, 
    0, 36, 3, 20, 1, 42, 4, 42, 2, 90, 8,  5, 5, 24, 6, 62, 7, 91, 9, 94, 
    6, 10, 8, 94, 0, 15, 1, 14, 9, 72, 4, 80, 3, 84, 7, 91, 2, 84, 5, 42, 
    5,  4, 3, 22, 2, 44, 7, 15, 4, 77, 0, 33, 8, 67, 9, 72, 6, 63, 1, 80, 
    5, 77, 4, 57, 3,  4, 0, 66, 9, 57, 7, 21, 2, 11, 1, 81, 8, 47, 6, 36, 
    4, 83, 9, 63, 5, 21, 3, 42, 8, 47, 0, 15, 2, 13, 7, 49, 1, 36, 6, 49, 
    0, 25, 6, 92, 1, 54, 2, 26, 8, 47, 9,  2, 3, 95, 4, 53, 7, 74, 5, 50, 
    8, 15, 2, 17, 3, 32, 1, 97, 5, 40, 6, 33, 9, 27, 0, 70, 7,  9, 4, 74
  };
  const int r758[] = {
    10, 10, // Number of jobs and machines
    7, 87, 3,  4, 5, 39, 4, 85, 0, 57, 9, 62, 6, 28, 2, 82, 8, 92, 1, 90, 
    8, 21, 3, 93, 6, 42, 2, 63, 5, 60, 0, 13, 4, 44, 9, 58, 7, 18, 1, 27, 
    5, 15, 3, 55, 9, 46, 8, 49, 4, 38, 1, 75, 6, 72, 7, 64, 2, 90, 0, 80, 
    6, 91, 0, 72, 4,  9, 9, 41, 8, 94, 7, 82, 3, 36, 1,  2, 5, 53, 2, 12, 
    7, 83, 6, 63, 3, 83, 8, 18, 2, 59, 0, 32, 4, 88, 9, 24, 5,  6, 1, 93, 
    4, 65, 0, 27, 8, 33, 2, 79, 5, 40, 6, 95, 9, 58, 7, 10, 1,  1, 3, 76, 
    4, 53, 0,  2, 3, 92, 7, 81, 8, 13, 2, 12, 9, 21, 1, 44, 5, 64, 6, 96, 
    8, 10, 4, 40, 7, 17, 5, 12, 0, 41, 2, 74, 6, 17, 9, 60, 3,  6, 1,  4, 
    5, 54, 9, 75, 4, 57, 6, 92, 3, 40, 8, 31, 0, 49, 1, 79, 2, 97, 7, 87, 
    6, 29, 1, 35, 2, 42, 3, 37, 7, 36, 4,  8, 5, 60, 0, 29, 8,  2, 9, 50
  };
  const int r759[] = {
    10, 10, // Number of jobs and machines
    2, 83, 9, 23, 6, 60, 4, 18, 1, 89, 3, 65, 8, 62, 0,  1, 7, 33, 5, 79, 
    3, 88, 6, 58, 7, 45, 0, 83, 9, 71, 2, 15, 5,  1, 4, 58, 1, 13, 8, 72, 
    0, 64, 6, 19, 5, 80, 8, 82, 7, 99, 1, 18, 4, 49, 2, 38, 9, 73, 3, 81, 
    7, 56, 4, 87, 6, 46, 1, 30, 0, 74, 9, 77, 3, 74, 5, 84, 8,  8, 2, 89, 
    7, 20, 0, 88, 5, 89, 9, 52, 3, 73, 1, 34, 6, 76, 8, 18, 4, 45, 2, 95, 
    7, 81, 1, 28, 2, 76, 5, 85, 8, 92, 9, 18, 6,  1, 4, 90, 0, 37, 3, 11, 
    3,  1, 9, 47, 5, 30, 1, 52, 4, 51, 8, 60, 6, 29, 7, 26, 0, 71, 2, 99, 
    3, 28, 5, 75, 6, 36, 8, 36, 4, 15, 9, 61, 7, 57, 1, 86, 0, 23, 2, 63, 
    2, 33, 7, 12, 3, 40, 4, 27, 1, 28, 9, 87, 0, 30, 5,  2, 6, 71, 8, 75, 
    1, 20, 4, 58, 3, 92, 2, 35, 7, 42, 8, 83, 5, 28, 6, 50, 9,  3, 0, 94
  };
  const int r760[] = {
    10, 10, // Number of jobs and machines
    8, 44, 9, 91, 5, 92, 3, 42, 0, 46, 1, 27, 4,  9, 2, 59, 7, 74, 6, 11, 
    3, 82, 1,  3, 0,  8, 7, 83, 6, 95, 9, 97, 2, 72, 4, 47, 5, 14, 8, 41, 
    2, 99, 4, 85, 1, 14, 0, 44, 6, 48, 5, 98, 3, 81, 9, 40, 7, 98, 8, 12, 
    0, 74, 2, 53, 4, 22, 9, 88, 5, 35, 1, 80, 3, 49, 6, 72, 7, 23, 8, 56, 
    0, 94, 6, 23, 2, 48, 4, 87, 3, 62, 8, 28, 7, 98, 1, 46, 5, 87, 9, 16, 
    3, 62, 0, 43, 4, 79, 9, 73, 2,  6, 6, 40, 7, 14, 1, 51, 5, 81, 8, 62, 
    9, 14, 4, 23, 0, 20, 2, 82, 1, 92, 6, 17, 3, 56, 5, 72, 7, 14, 8, 82, 
    5, 15, 9, 64, 1, 55, 2, 83, 4, 15, 7, 87, 0, 17, 6, 25, 8, 73, 3, 33, 
    8, 56, 2, 45, 7, 76, 4, 50, 1, 86, 5, 26, 9, 65, 0, 27, 6, 14, 3, 38, 
    4, 37, 3, 30, 5, 37, 1, 67, 6, 41, 9, 24, 0, 92, 7,  5, 8, 29, 2, 68
  };
  const int r761[] = {
    10, 10, // Number of jobs and machines
    2, 63, 6, 23, 4, 40, 8, 64, 7, 60, 1, 89, 9, 79, 0, 48, 5, 16, 3, 97, 
    2, 71, 0, 98, 7, 54, 8, 52, 1, 72, 3, 45, 6, 41, 9, 22, 4, 61, 5, 77, 
    4, 30, 6, 86, 3, 61, 1, 31, 5, 99, 9, 22, 0, 41, 8,  2, 7, 96, 2, 50, 
    5, 52, 1, 81, 0, 19, 8, 42, 7, 54, 3, 89, 4, 75, 6, 45, 9, 66, 2,  9, 
    5, 82, 0, 26, 9, 59, 4,  5, 1, 53, 7, 74, 2, 86, 3, 19, 6, 17, 8, 37, 
    5, 10, 4, 63, 3, 86, 2, 44, 6, 52, 0, 88, 1, 79, 8,  7, 7, 77, 9, 15, 
    6, 67, 9, 11, 0, 48, 5, 55, 7, 41, 4, 35, 3, 32, 1, 92, 8, 71, 2, 91, 
    6, 44, 2,  6, 3, 64, 5, 59, 0, 11, 9, 30, 7, 34, 8, 87, 1, 59, 4, 96, 
    6, 64, 7, 88, 4, 76, 3, 50, 0, 24, 9, 39, 8, 61, 5, 53, 2,  3, 1, 40, 
    4, 30, 6, 48, 2, 58, 3, 26, 1, 26, 8, 62, 9, 96, 7, 94, 0,  9, 5, 45
  };
  const int r762[] = {
    10, 10, // Number of jobs and machines
    6,  8, 7, 55, 4, 96, 5,  7, 3,  7, 8, 98, 0, 19, 1, 96, 9, 25, 2, 56, 
    8, 58, 9, 40, 5, 42, 3, 54, 1, 61, 6, 84, 7, 63, 4, 27, 2, 76, 0, 87, 
    1, 83, 6, 36, 2, 28, 8, 99, 9, 67, 0, 98, 4, 11, 7,  5, 3, 38, 5, 92, 
    5,  3, 3, 84, 2, 38, 9, 10, 0, 99, 4, 20, 7, 77, 1, 44, 6, 31, 8, 19, 
    7, 46, 9, 12, 1,  3, 0, 11, 6, 63, 8, 94, 5, 79, 4, 83, 2, 12, 3, 51, 
    7, 29, 6, 18, 3, 55, 8, 28, 4, 19, 0, 96, 1, 44, 5, 80, 9, 19, 2,  6, 
    9, 27, 7, 14, 1, 33, 0, 18, 2, 29, 4, 60, 5, 11, 6, 60, 8, 49, 3, 85, 
    1, 80, 8,  1, 5, 24, 4, 69, 3, 15, 6, 92, 9,  3, 7, 13, 0, 48, 2, 67, 
    8, 63, 0, 19, 7, 35, 1, 44, 6, 54, 3, 84, 2, 44, 5, 30, 9, 54, 4, 82, 
    8, 63, 9, 32, 3, 12, 1, 52, 7, 98, 0, 15, 5, 31, 4, 66, 6, 63, 2, 80
  };
  const int r763[] = {
    10, 10, // Number of jobs and machines
    4, 90, 9, 40, 8, 23, 2, 44, 6,  8, 5, 95, 1, 26, 3, 76, 0, 11, 7, 48, 
    4, 35, 8, 59, 7,  4, 5, 60, 0, 27, 6, 32, 3, 87, 2, 63, 1, 47, 9, 82, 
    2, 51, 0, 25, 8, 56, 6,  1, 5, 26, 4, 48, 1,  4, 9, 43, 7, 44, 3, 85, 
    2, 44, 4, 90, 9, 58, 7, 99, 3, 77, 6, 26, 1, 86, 5, 33, 8, 78, 0, 54, 
    5, 70, 8, 19, 2, 12, 1, 49, 4, 13, 7, 82, 3, 38, 0, 50, 6, 91, 9, 12, 
    0, 31, 6, 71, 4, 20, 7, 31, 2, 36, 1, 37, 9, 36, 3, 62, 8, 61, 5, 42, 
    7, 55, 5, 61, 1, 87, 4, 32, 0, 89, 2,  3, 9, 85, 6, 27, 8, 73, 3, 38, 
    9, 84, 5, 33, 6,  7, 4, 35, 1, 88, 2, 82, 8, 56, 3, 91, 0, 26, 7, 96, 
    1, 16, 8, 38, 2, 34, 9, 68, 5, 15, 0, 79, 4, 69, 7, 85, 3,  6, 6, 93, 
    8, 57, 7, 12, 1, 12, 0, 10, 5, 93, 9, 33, 3, 65, 2, 77, 6, 78, 4, 18
  };
  const int r764[] = {
    10, 10, // Number of jobs and machines
    8, 88, 3, 38, 5, 25, 2, 87, 6, 78, 1, 70, 0, 12, 9, 46, 4,  6, 7, 88, 
    6, 53, 5, 66, 3, 11, 4, 83, 0, 60, 9, 87, 2, 80, 1, 91, 7, 74, 8, 59, 
    3, 91, 1, 57, 5, 41, 2, 82, 6, 98, 4, 78, 9,  6, 7, 24, 8, 21, 0, 96, 
    6,  4, 5, 10, 3, 56, 8, 47, 9, 63, 4, 13, 1, 54, 0, 20, 7, 61, 2, 68, 
    4, 14, 8, 38, 7, 93, 3, 97, 6, 89, 5, 72, 1, 32, 0, 81, 2, 16, 9, 73, 
    3, 63, 7, 37, 2, 99, 6, 66, 0, 76, 8, 67, 5, 82, 1, 41, 4, 74, 9, 30, 
    8, 60, 3, 70, 7, 40, 4, 32, 0, 31, 5, 88, 6, 75, 9,  6, 2, 10, 1, 26, 
    1, 15, 4,  3, 6, 57, 3, 64, 7, 42, 5, 60, 9, 84, 8, 22, 2, 50, 0, 78, 
    4, 18, 9, 74, 2, 82, 3, 78, 7, 54, 5, 61, 6, 90, 0, 25, 8, 80, 1, 95, 
    0, 99, 1, 99, 5, 20, 6, 67, 9, 44, 7, 40, 2,  4, 4, 34, 3, 91, 8, 44
  };
  const int r765[] = {
    10, 10, // Number of jobs and machines
    2, 62, 0, 45, 1, 84, 9, 20, 3, 72, 4, 66, 8,  5, 6, 37, 7, 17, 5, 86, 
    5, 74, 4, 43, 9, 35, 6, 31, 0, 49, 1, 98, 8, 33, 2, 35, 7, 11, 3, 36, 
    2, 70, 1, 39, 8, 83, 6, 33, 9, 12, 3, 77, 4, 95, 7, 43, 0, 74, 5, 60, 
    0, 33, 2, 28, 7, 53, 1, 71, 4, 50, 8, 62, 5, 45, 6, 26, 3, 88, 9,  3, 
    7, 61, 3, 21, 8, 74, 9, 64, 5, 69, 2, 82, 0, 34, 6,  7, 1, 35, 4, 26, 
    3, 68, 7, 38, 4, 88, 1, 60, 0, 45, 8, 63, 2, 18, 5, 30, 6, 36, 9, 78, 
    6, 24, 1, 75, 2, 41, 9, 60, 3, 58, 8,  7, 0,  3, 7, 99, 5, 12, 4, 13, 
    7, 23, 0,  7, 6, 75, 9, 68, 1, 46, 4, 44, 2, 52, 3, 11, 8, 71, 5, 31, 
    9, 27, 6, 48, 8, 33, 4, 83, 3, 33, 1, 81, 2, 68, 5, 74, 0, 48, 7, 78, 
    6, 73, 4, 31, 8, 50, 5, 46, 9, 46, 2, 53, 7, 92, 1, 54, 3, 57, 0, 30
  };
  const int r766[] = {
    10, 10, // Number of jobs and machines
    3, 46, 9, 71, 2, 20, 8, 31, 6, 19, 7, 86, 5, 48, 4, 87, 1,  5, 0, 27, 
    1, 29, 6, 78, 3, 53, 4, 97, 8, 45, 2,  6, 5, 87, 9,  4, 7, 51, 0, 47, 
    4, 63, 2, 65, 1, 27, 0, 95, 7, 16, 5, 75, 9, 82, 6, 83, 8, 14, 3, 63, 
    6,  3, 7, 85, 0, 58, 3, 32, 1, 52, 8, 53, 4, 65, 2, 26, 9,  7, 5, 86, 
    5, 67, 9, 62, 1, 30, 7, 29, 2, 55, 6,  8, 3, 39, 4, 54, 0, 49, 8, 16, 
    4, 38, 9, 28, 8, 32, 5, 31, 3, 11, 7, 50, 6, 77, 0, 31, 1, 16, 2, 50, 
    9, 63, 0, 69, 2, 82, 1,  6, 8, 77, 7, 90, 4, 35, 6, 87, 5, 37, 3, 45, 
    1, 98, 9, 90, 5, 31, 6, 73, 4, 77, 7, 46, 8, 83, 0, 72, 3, 79, 2, 69, 
    5, 67, 6, 82, 2, 85, 3, 17, 7, 83, 0, 75, 8, 24, 4, 46, 1, 95, 9, 46, 
    9, 47, 2, 96, 5, 28, 6, 90, 4, 98, 0, 95, 8, 76, 1, 30, 7, 89, 3, 94
  };
  const int r767[] = {
    10, 10, // Number of jobs and machines
    0,  5, 8, 44, 9, 62, 6, 88, 3, 96, 2, 78, 1, 28, 4,  3, 7, 90, 5, 55, 
    0, 34, 9, 20, 2, 65, 4, 62, 3, 38, 6, 84, 8, 83, 7, 23, 1, 45, 5, 55, 
    7, 40, 3, 89, 5, 18, 2, 16, 8, 52, 4,  9, 0, 70, 1, 84, 9, 29, 6, 47, 
    3, 60, 8,  4, 2, 73, 1, 23, 7, 90, 6,  5, 0, 70, 5, 10, 4, 74, 9, 73, 
    2, 69, 6, 55, 7,  6, 3, 78, 4,  5, 9, 69, 8,  7, 1, 60, 5, 99, 0,  9, 
    5, 42, 4,  8, 9, 89, 6,  9, 1, 81, 7, 61, 0, 42, 8, 75, 2, 60, 3, 62, 
    3, 90, 7, 81, 9, 19, 2, 66, 0,  6, 1, 61, 8, 30, 6, 75, 4, 77, 5, 41, 
    4, 73, 2, 86, 3, 56, 6, 50, 5, 36, 0, 44, 7, 56, 1, 41, 9, 97, 8, 74, 
    1, 40, 5, 17, 8, 15, 0, 69, 7, 11, 6, 94, 9, 43, 3, 61, 2, 84, 4, 39, 
    2, 41, 6, 45, 3, 64, 9, 57, 8, 53, 1, 79, 0, 62, 4, 87, 5, 65, 7, 21
  };
  const int r768[] = {
    10, 10, // Number of jobs and machines
    1, 99, 9, 44, 3, 42, 7, 85, 4, 34, 5, 85, 0, 37, 2,  3, 8, 44, 6, 25, 
    5, 33, 1, 35, 6, 92, 7,  5, 8, 35, 3, 24, 2, 30, 4, 56, 9,  5, 0, 79, 
    4, 85, 3, 42, 6, 83, 0, 81, 1, 59, 7, 51, 8, 83, 9, 50, 5, 23, 2, 81, 
    4, 97, 1, 70, 3, 40, 7, 96, 0, 19, 9,  1, 8, 86, 5, 28, 2, 34, 6, 70, 
    6, 67, 0, 60, 1, 82, 2, 10, 3, 88, 7, 49, 5, 37, 8, 35, 4, 25, 9, 86, 
    3, 83, 0,  4, 9, 78, 2, 78, 4, 87, 1, 37, 5, 99, 6,  1, 7, 34, 8, 18, 
    5, 48, 1, 77, 4, 82, 2, 73, 8, 81, 6, 91, 9, 82, 3, 11, 7, 65, 0, 69, 
    7, 35, 3, 38, 1, 64, 5, 42, 2, 28, 9,  4, 0, 17, 6, 99, 8, 81, 4, 12, 
    0, 34, 6, 88, 9, 75, 8, 89, 4, 36, 3, 79, 5, 11, 7, 48, 1, 74, 2, 62, 
    7,  4, 9, 66, 6, 93, 4, 15, 2, 63, 3, 81, 0, 79, 8, 10, 1, 21, 5, 28
  };
  const int r769[] = {
    10, 10, // Number of jobs and machines
    4, 96, 9,  6, 8, 12, 0, 54, 7, 61, 6, 77, 5, 47, 2,  4, 1, 76, 3, 17, 
    2, 10, 7, 29, 5, 13, 6, 32, 4, 68, 0, 73, 1, 95, 8, 83, 3, 44, 9, 13, 
    5, 89, 3, 11, 7, 13, 4, 90, 8, 53, 2, 44, 0, 16, 6, 99, 1, 55, 9, 82, 
    9, 55, 5, 97, 0, 96, 8, 78, 2, 80, 3, 80, 1, 21, 4, 62, 6, 40, 7, 45, 
    8, 34, 2, 29, 1, 45, 7, 73, 3, 31, 5, 11, 4, 17, 6,  3, 9, 21, 0, 20, 
    6, 73, 2, 33, 3,  1, 9, 68, 8, 11, 5, 22, 7, 15, 0, 43, 4, 26, 1, 23, 
    5, 34, 3, 58, 7, 27, 9, 24, 0, 81, 6, 96, 4,  4, 8, 50, 1, 56, 2,  4, 
    2,  9, 7, 43, 0,  9, 5, 28, 8, 83, 9, 13, 3, 33, 1,  7, 6, 86, 4, 92, 
    7, 75, 9, 37, 1, 46, 8, 95, 2, 80, 0, 56, 5, 51, 3, 27, 6, 97, 4, 34, 
    9, 94, 7, 65, 2, 91, 8, 58, 0, 78, 1, 32, 3, 76, 6, 48, 4, 49, 5, 46
  };
  const int r770[] = {
    10, 10, // Number of jobs and machines
    2, 54, 9, 33, 8, 71, 7,  4, 1, 54, 0,  9, 6, 41, 5, 42, 3, 74, 4, 60, 
    8, 62, 7, 26, 5, 78, 2,  8, 0, 62, 9,  4, 1, 31, 6, 65, 4, 79, 3, 18, 
    4, 89, 3, 15, 5, 91, 7, 12, 1,  3, 8, 14, 0, 45, 2, 53, 6, 54, 9, 42, 
    2, 87, 8, 12, 3, 38, 6, 73, 7, 64, 9, 13, 4, 61, 0, 58, 5, 19, 1, 63, 
    8,  9, 1, 33, 4, 93, 2, 88, 3, 53, 6, 88, 0, 47, 9, 57, 5, 44, 7, 50, 
    2, 56, 7, 38, 1, 63, 6, 14, 8, 56, 9, 23, 5, 75, 4,  5, 3, 56, 0, 72, 
    6, 30, 4, 97, 7, 25, 5, 31, 2, 76, 1, 85, 0, 64, 3, 25, 9, 27, 8, 68, 
    2, 90, 6, 81, 1, 56, 4, 49, 3, 54, 7, 34, 8, 36, 5, 14, 9, 48, 0, 35, 
    6, 16, 3, 92, 5,  7, 7,  8, 4, 67, 8, 93, 1, 60, 0, 12, 9, 48, 2, 88, 
    8, 86, 1, 24, 5,  8, 2, 91, 7, 44, 6, 55, 3, 95, 9, 66, 0, 67, 4, 43
  };
  const int r771[] = {
    10, 10, // Number of jobs and machines
    8, 25, 0, 30, 3, 45, 5, 51, 2, 71, 6, 64, 9, 60, 7, 11, 4, 28, 1, 70, 
    4, 10, 2, 31, 3, 92, 8, 78, 0,  5, 5, 27, 1, 48, 9, 76, 7, 35, 6, 78, 
    5, 27, 2,  7, 4, 27, 0,  3, 6, 17, 9,  1, 7, 58, 3, 74, 8, 34, 1, 44, 
    7, 45, 6, 56, 5, 89, 0, 59, 3, 45, 2,  7, 8,  2, 9, 18, 4, 87, 1, 97, 
    9, 39, 6, 83, 7, 36, 5, 99, 0, 61, 4, 92, 3, 86, 2, 19, 8, 22, 1, 46, 
    6,  1, 8, 31, 5, 24, 9, 66, 2, 33, 4, 87, 0, 83, 7, 53, 1, 33, 3, 67, 
    5, 67, 4, 59, 1, 46, 2, 44, 3, 77, 0, 68, 9, 83, 6, 89, 8, 97, 7, 31, 
    0, 36, 5,  3, 6, 78, 4, 33, 1, 71, 2, 98, 3,  3, 8, 27, 7, 48, 9, 55, 
    4, 37, 1, 54, 0, 38, 5, 32, 7, 52, 9, 32, 2, 49, 8, 66, 3, 96, 6, 52, 
    9, 19, 0, 20, 3, 79, 7, 15, 4,  9, 8, 11, 6, 64, 5, 89, 1, 40, 2, 83
  };
  const int r772[] = {
    10, 10, // Number of jobs and machines
    6,  6, 1, 23, 5, 10, 9, 65, 3,  5, 4,  5, 8, 48, 0,  6, 7, 52, 2, 15, 
    3, 84, 5, 17, 8, 61, 2, 36, 6, 10, 1, 88, 4, 13, 9, 48, 7, 93, 0, 40, 
    7, 11, 4, 43, 8, 66, 2, 15, 3, 69, 9,  1, 0, 83, 1, 12, 6, 59, 5,  6, 
    6, 78, 4, 55, 1, 86, 5, 97, 2, 54, 0, 79, 9, 55, 7, 90, 8, 63, 3, 50, 
    9, 53, 1, 24, 3, 43, 6,  3, 0, 70, 7, 55, 2,  8, 4, 84, 8, 76, 5, 65, 
    3, 71, 5, 52, 6, 69, 1, 25, 7, 91, 9, 55, 8, 57, 2, 86, 4, 48, 0, 60, 
    9, 81, 7, 30, 2, 34, 5, 77, 1, 50, 8, 76, 3, 73, 4, 65, 0, 81, 6, 26, 
    3, 42, 8, 81, 7, 44, 5, 18, 1, 50, 4, 30, 9, 81, 6, 68, 2, 84, 0,  7, 
    2, 44, 8, 42, 0, 16, 1, 13, 9,  8, 5, 69, 6, 84, 7, 66, 4, 46, 3,  2, 
    7, 39, 2, 86, 5, 87, 0, 29, 1, 65, 6, 41, 9,  9, 4, 26, 8, 38, 3, 28
  };
  const int r773[] = {
    10, 10, // Number of jobs and machines
    5, 43, 1, 58, 7, 83, 3, 18, 6, 23, 2, 89, 8, 11, 0, 57, 4, 67, 9, 72, 
    8, 41, 2, 35, 6, 66, 4, 19, 5, 48, 9, 80, 3, 56, 7, 96, 0, 77, 1, 32, 
    2, 56, 8, 84, 1, 64, 6, 65, 5, 80, 3, 77, 0, 35, 9, 94, 4, 20, 7, 93, 
    1, 11, 9, 97, 0, 47, 2,  2, 8, 20, 6, 75, 7, 14, 4, 54, 3, 85, 5,  9, 
    8, 39, 3, 94, 9, 80, 4, 42, 7, 88, 6, 16, 0, 59, 1, 13, 5,  5, 2, 49, 
    2, 50, 8, 79, 0, 79, 9, 48, 7, 23, 4, 43, 3, 12, 1, 71, 6, 55, 5,  9, 
    6, 78, 0, 64, 2, 18, 7, 46, 9, 88, 5, 70, 3, 32, 4, 33, 8, 68, 1, 33, 
    7, 42, 3, 35, 0, 91, 6, 71, 1,  7, 9,  4, 2, 65, 4, 88, 8, 67, 5, 25, 
    4, 74, 6, 59, 7, 41, 1, 85, 3,  4, 0, 87, 8, 33, 5, 84, 2, 75, 9, 78, 
    4,  7, 6, 68, 7, 55, 3,  2, 0, 50, 5, 95, 9, 70, 8, 99, 1,  7, 2, 83
  };
  const int r774[] = {
    10, 10, // Number of jobs and machines
    2, 48, 7, 38, 3,  8, 9, 34, 4, 10, 5, 21, 0, 44, 6,  7, 1, 60, 8, 94, 
    5, 60, 1, 36, 9, 35, 3, 59, 2, 60, 8, 64, 4, 23, 0, 69, 6, 77, 7, 24, 
    1, 23, 3, 70, 9, 22, 4, 73, 6, 47, 2, 33, 5, 59, 0, 58, 8, 25, 7, 48, 
    4, 49, 9, 92, 1, 89, 6, 11, 5, 80, 2, 51, 7,  6, 8, 93, 3, 66, 0, 93, 
    7, 24, 0,  3, 2, 66, 6, 10, 4,  5, 3, 83, 5, 32, 1, 12, 8, 94, 9, 45, 
    6, 68, 4, 34, 8,  4, 7, 54, 3, 20, 0, 58, 2, 78, 1,  7, 5, 90, 9, 56, 
    4, 47, 5, 56, 7,  9, 8, 73, 1, 85, 9, 77, 0, 60, 3, 87, 6, 64, 2, 96, 
    0, 92, 4, 60, 5, 81, 3, 29, 8, 63, 6, 88, 2,  9, 1, 43, 7, 84, 9, 93, 
    5, 50, 4, 92, 9, 11, 3, 18, 2, 65, 1, 33, 8,  2, 6, 14, 0, 53, 7,  6, 
    7, 85, 0, 28, 6, 55, 3, 24, 2, 57, 1, 27, 5, 84, 8, 25, 9, 36, 4,  9
  };
  const int r775[] = {
    10, 10, // Number of jobs and machines
    1,  8, 9, 24, 5,  9, 0, 53, 8, 30, 2, 92, 4, 12, 7, 17, 6, 78, 3, 44, 
    1, 56, 7, 92, 0, 42, 5, 45, 9, 84, 2, 75, 4, 34, 8, 65, 6, 29, 3, 39, 
    9, 10, 1, 87, 0,  5, 8, 92, 2, 27, 6, 83, 5, 75, 7, 44, 3,  1, 4, 71, 
    0,  5, 9, 19, 7, 10, 5, 59, 3, 72, 4, 88, 8, 80, 2, 37, 6, 47, 1, 70, 
    2, 18, 3, 68, 7, 97, 9, 91, 5, 43, 8, 18, 1, 96, 0, 58, 6, 29, 4, 90, 
    5, 29, 2, 41, 7, 59, 0, 61, 8, 53, 4, 92, 3, 40, 1, 84, 9,  1, 6, 97, 
    3, 92, 9, 14, 1, 33, 2, 85, 5, 37, 4, 23, 7, 89, 8, 45, 6, 68, 0, 82, 
    8, 44, 6,  6, 5, 64, 7, 50, 3, 29, 1, 46, 9, 61, 4, 24, 2, 87, 0, 37, 
    1, 36, 6, 69, 8, 65, 4, 45, 9, 52, 7,  9, 3, 94, 5, 56, 0, 64, 2, 31, 
    9, 15, 5, 62, 3, 69, 6, 96, 0, 31, 7, 67, 4,  8, 1, 74, 8, 99, 2, 16
  };
  const int r776[] = {
    10, 10, // Number of jobs and machines
    0, 82, 9, 21, 8, 42, 1, 56, 7, 46, 4, 32, 5, 29, 3, 60, 2, 69, 6, 35, 
    3, 30, 8, 49, 6,  5, 9, 23, 2,  7, 7, 45, 0, 23, 1, 88, 4,  4, 5, 32, 
    0, 30, 1, 11, 9, 68, 2, 26, 6, 13, 8, 89, 4, 84, 3, 37, 7,  2, 5,  5, 
    5, 60, 8, 86, 1, 38, 0, 56, 7, 50, 4, 58, 3, 70, 9, 29, 6, 84, 2, 91, 
    3, 45, 5, 88, 0, 36, 1, 66, 6,  2, 4, 73, 8, 90, 9, 73, 2, 12, 7, 38, 
    8,  9, 3,  5, 9, 41, 7, 82, 5, 33, 4, 44, 2, 12, 1,  1, 6, 98, 0, 11, 
    0, 17, 2, 37, 8, 47, 7, 71, 3,  7, 6, 31, 1, 78, 4, 70, 5, 86, 9, 18, 
    8, 16, 4, 20, 9, 25, 3, 20, 1, 50, 6,  8, 7, 36, 0, 10, 2, 80, 5,  7, 
    6, 63, 2, 77, 1, 14, 0, 80, 9, 25, 8, 23, 7, 64, 5,  6, 4, 49, 3, 12, 
    5, 75, 8, 27, 1, 95, 3,  1, 9, 29, 2, 84, 0, 43, 6,  1, 4, 67, 7, 78
  };
  const int r777[] = {
    10, 10, // Number of jobs and machines
    0, 66, 5, 80, 1, 23, 3, 10, 2, 98, 4, 73, 9, 73, 7, 65, 6, 48, 8, 68, 
    3, 94, 9, 88, 8,  8, 5, 71, 1,  2, 4, 10, 7, 33, 2, 90, 6,  2, 0, 18, 
    2, 84, 0, 79, 8, 81, 4, 18, 7, 89, 6, 75, 3, 31, 1, 83, 5, 95, 9, 55, 
    6,  9, 2, 17, 8, 62, 5, 45, 0, 20, 3, 84, 4,  6, 9, 63, 1, 60, 7, 15, 
    7, 82, 9,  2, 2, 16, 8, 90, 1, 39, 3, 18, 4, 35, 5, 86, 0, 77, 6, 78, 
    5, 99, 6, 24, 8, 15, 0, 11, 2, 75, 1, 27, 3, 29, 4, 16, 9, 76, 7, 96, 
    7, 18, 4, 72, 0, 19, 1, 22, 3, 45, 8, 35, 2,  7, 6, 18, 5, 31, 9, 46, 
    7, 25, 9, 56, 8, 10, 4, 93, 2, 16, 0, 63, 5, 60, 3, 71, 1, 97, 6, 59, 
    9, 40, 5, 11, 4, 60, 2,  8, 0, 94, 1,  2, 8, 95, 6, 26, 7, 59, 3, 51, 
    5, 95, 4, 10, 3,  2, 6, 72, 7, 50, 0, 88, 9, 66, 8, 55, 2, 83, 1,  3
  };
  const int r778[] = {
    10, 10, // Number of jobs and machines
    9, 30, 8, 64, 4, 39, 0, 75, 1, 75, 7, 48, 6, 70, 2, 42, 5,  1, 3, 64, 
    3, 33, 8, 94, 5, 60, 0, 33, 2, 76, 1, 16, 4, 60, 9, 92, 7, 52, 6, 22, 
    7, 32, 0, 78, 4, 53, 5, 96, 3,  8, 1, 29, 6, 35, 2, 98, 8, 57, 9, 73, 
    9, 56, 7, 74, 6, 66, 0,  3, 8, 69, 4, 10, 2, 32, 3, 87, 1, 51, 5, 16, 
    6, 40, 4, 89, 2, 74, 9, 97, 0, 98, 7, 58, 3, 52, 5, 66, 8, 26, 1, 24, 
    0, 58, 5, 64, 6, 84, 4, 60, 2, 38, 1, 32, 7, 87, 8,  9, 3, 56, 9, 78, 
    4, 77, 6, 17, 0,  8, 9, 62, 1, 46, 8, 28, 3, 69, 2, 56, 5, 22, 7, 90, 
    9, 56, 1,  3, 8, 62, 7, 97, 0, 66, 5, 89, 6, 23, 2, 96, 3, 44, 4, 86, 
    4,  2, 6, 43, 9, 65, 3, 27, 8, 45, 1, 13, 2, 14, 5, 37, 7, 35, 0, 20, 
    8, 43, 6, 51, 2, 22, 3, 83, 1,  6, 7, 34, 9,  5, 0, 36, 5, 28, 4, 46
  };
  const int r779[] = {
    10, 10, // Number of jobs and machines
    4,  7, 7, 97, 1, 25, 5,  4, 6, 88, 3, 89, 2, 17, 8, 67, 9, 10, 0, 82, 
    2, 65, 1,  1, 0, 46, 7, 72, 8, 41, 3, 84, 4, 18, 6, 66, 9, 56, 5, 23, 
    7, 34, 1, 23, 4, 54, 0, 32, 9, 44, 5, 61, 6, 65, 8, 34, 3,  5, 2, 71, 
    9, 26, 6, 30, 7, 19, 4, 68, 0, 52, 2, 62, 8, 75, 5, 63, 3, 93, 1, 39, 
    5, 58, 3, 39, 1, 43, 2, 31, 0, 21, 6, 31, 4, 66, 7, 46, 9, 41, 8, 27, 
    2, 92, 4, 90, 7, 97, 1, 50, 5, 41, 6, 52, 3,  7, 9, 90, 0, 84, 8, 26, 
    6, 79, 7, 40, 3, 92, 1, 57, 2, 19, 5, 30, 4, 70, 9, 91, 8, 96, 0, 97, 
    0,  2, 4, 23, 7, 30, 8, 72, 2, 43, 1, 31, 5, 42, 9, 45, 6, 47, 3, 57, 
    8,  3, 3, 11, 0, 24, 4, 69, 9, 79, 2, 10, 1, 37, 6, 11, 5,  3, 7, 39, 
    9, 10, 8, 95, 4, 95, 7, 62, 5, 71, 0, 22, 2, 43, 6, 80, 1, 89, 3, 69
  };
  const int r780[] = {
    10, 10, // Number of jobs and machines
    5, 99, 8, 84, 3,  8, 4, 62, 2, 59, 6, 42, 7, 29, 1, 32, 9, 99, 0, 49, 
    4, 76, 9, 22, 1, 86, 6, 61, 0, 10, 2, 15, 5, 15, 3, 11, 8,  6, 7, 60, 
    8, 63, 2, 68, 0, 40, 3, 27, 7, 35, 1, 94, 6, 74, 5, 64, 4, 30, 9, 74, 
    9, 40, 8, 62, 5, 39, 7,  7, 4, 52, 3, 62, 0, 76, 2, 25, 6, 97, 1, 92, 
    4, 73, 2, 96, 0, 66, 7, 61, 8, 34, 9, 62, 1, 29, 5,  9, 6, 17, 3, 59, 
    6, 63, 5, 63, 9, 66, 1, 25, 7, 44, 0, 65, 8, 34, 2, 44, 3, 85, 4, 12, 
    1, 96, 0, 40, 4, 69, 3, 65, 2, 58, 6, 32, 8,  1, 9, 11, 5, 82, 7, 90, 
    8, 61, 5, 54, 7,  3, 4, 28, 3, 90, 6, 18, 2, 66, 9, 37, 0, 80, 1, 72, 
    7, 98, 3, 32, 2, 15, 9, 44, 8, 43, 6, 72, 1, 91, 0, 10, 5, 38, 4, 77, 
    4, 89, 3, 25, 7,  4, 1, 85, 8, 54, 9, 72, 5, 16, 6, 44, 0, 29, 2,  9
  };
  const int r781[] = {
    10, 10, // Number of jobs and machines
    0, 30, 7, 25, 8, 77, 1, 59, 2, 66, 4, 11, 5, 21, 9,  5, 6, 46, 3, 58, 
    3, 80, 7, 52, 5,  5, 2, 32, 6, 38, 9, 80, 0, 90, 1, 15, 4, 46, 8, 71, 
    6, 87, 1, 18, 5, 81, 7, 98, 8, 97, 0,  8, 2, 31, 4, 86, 3, 13, 9, 77, 
    0, 27, 2, 55, 7, 24, 3, 26, 1, 57, 5, 69, 4, 68, 9, 16, 8, 96, 6, 30, 
    0,  1, 5, 76, 2, 65, 3,  9, 7, 76, 1, 63, 9, 40, 8, 82, 4, 16, 6,  7, 
    5, 88, 0, 59, 6, 76, 9, 40, 3, 66, 1,  1, 4, 30, 2, 76, 7, 81, 8, 97, 
    4, 81, 3,  7, 9, 75, 6, 21, 8, 38, 1, 82, 5, 96, 2, 47, 0, 40, 7, 15, 
    9, 96, 8, 65, 6, 49, 3, 30, 2, 74, 7, 25, 1, 62, 5, 92, 4, 75, 0, 17, 
    7, 86, 1, 68, 3, 57, 8, 67, 4, 72, 6, 33, 9, 81, 0, 95, 5,  7, 2, 14, 
    2, 61, 0, 19, 9, 56, 8, 28, 6, 39, 1, 63, 7, 48, 5,  6, 3, 26, 4,  7
  };
  const int r782[] = {
    10, 10, // Number of jobs and machines
    0, 51, 3, 36, 1, 17, 7, 66, 4, 96, 2, 13, 5, 33, 6, 93, 8, 43, 9, 35, 
    1, 39, 5, 67, 3, 52, 7, 49, 2,  3, 8,  8, 4, 22, 0, 46, 6, 44, 9, 78, 
    0, 55, 7, 52, 9, 28, 4,  4, 1, 34, 6, 14, 3, 62, 8, 28, 2, 47, 5,  2, 
    6, 91, 8,  3, 7, 56, 5, 16, 0, 36, 1, 66, 4, 11, 9, 33, 2,  2, 3, 26, 
    7, 90, 1, 36, 4, 14, 2, 88, 8, 53, 3, 66, 6, 33, 0, 34, 5, 11, 9, 77, 
    5, 11, 6, 29, 3, 78, 7, 93, 0, 63, 1, 92, 2, 72, 4, 68, 9, 70, 8, 79, 
    6, 59, 9, 60, 2, 33, 4, 42, 1, 86, 7, 95, 8,  5, 5, 50, 3, 20, 0, 22, 
    5, 87, 6, 94, 0, 61, 1, 14, 2, 79, 7, 80, 9, 40, 4, 39, 8, 95, 3, 12, 
    6, 12, 0, 42, 4, 15, 7, 94, 8, 68, 1, 59, 2, 46, 3,  8, 5, 17, 9, 71, 
    8, 81, 5, 16, 3, 63, 4, 16, 0, 73, 9, 70, 2, 42, 1, 24, 6, 70, 7, 30
  };
  const int r783[] = {
    10, 10, // Number of jobs and machines
    9, 74, 2, 94, 7, 58, 8, 61, 3, 14, 5, 26, 4, 43, 6, 62, 0, 54, 1, 84, 
    0, 29, 3, 12, 5, 17, 6, 69, 2, 47, 9, 65, 7, 28, 4, 83, 1, 37, 8, 70, 
    9, 28, 4, 22, 8, 12, 7,  2, 3, 98, 6, 99, 5, 21, 1, 27, 2, 84, 0, 89, 
    0, 50, 2, 16, 4, 54, 8, 40, 7,  4, 6, 65, 5, 80, 1, 39, 3, 86, 9, 63, 
    0, 37, 3, 34, 9, 83, 2, 58, 7, 10, 8,  4, 5, 36, 4, 88, 1, 48, 6, 55, 
    0,  7, 2, 35, 5, 32, 3, 42, 9, 43, 7, 16, 1, 61, 8, 92, 4, 30, 6, 93, 
    3, 82, 4, 73, 8, 37, 6,  6, 5, 74, 1, 42, 2, 59, 7, 28, 0, 26, 9, 73, 
    8, 18, 0,  7, 1, 29, 5, 86, 2,  7, 4, 33, 6, 24, 3, 41, 7, 49, 9,  2, 
    0, 11, 8, 95, 9,  8, 2,  6, 7, 78, 3, 83, 4, 39, 1, 56, 5, 30, 6, 44, 
    1, 77, 9, 54, 8, 91, 4, 66, 2, 53, 6, 77, 0, 40, 7, 54, 3, 63, 5, 45
  };
  const int r784[] = {
    10, 10, // Number of jobs and machines
    7, 81, 2, 16, 3, 27, 4, 48, 0, 36, 1, 18, 9,  7, 5, 99, 6, 70, 8, 29, 
    8, 64, 1, 39, 6, 73, 0, 14, 2, 79, 9, 71, 5, 34, 3,  8, 7, 84, 4,  8, 
    0,  1, 9, 64, 4, 57, 8, 84, 1, 41, 7, 38, 3, 24, 5, 38, 2, 37, 6, 85, 
    8, 84, 3, 25, 5, 94, 6, 67, 2, 87, 0, 12, 4, 91, 1, 74, 9, 60, 7, 28, 
    1, 86, 8, 40, 0, 70, 3, 96, 4, 62, 2, 30, 7, 71, 6,  1, 5, 97, 9, 71, 
    8, 56, 3, 11, 7, 92, 9, 34, 1, 51, 2, 46, 5, 67, 0, 91, 4, 87, 6, 47, 
    6, 80, 4, 20, 5, 81, 9,  9, 1, 29, 3, 26, 8, 68, 7, 24, 2, 67, 0, 92, 
    2, 30, 9, 97, 7, 37, 0, 53, 5, 83, 6, 19, 4, 55, 8, 97, 3, 54, 1, 33, 
    5, 70, 3, 79, 8, 89, 7, 87, 2, 77, 4, 46, 6, 74, 0, 45, 9, 19, 1, 25, 
    1, 45, 2, 36, 4, 91, 5, 56, 0, 41, 3, 60, 8, 52, 7, 26, 6, 46, 9, 63
  };
  const int r785[] = {
    10, 10, // Number of jobs and machines
    3,  2, 5, 87, 6, 29, 8, 75, 9, 55, 0, 29, 4, 69, 2, 25, 7, 99, 1, 48, 
    6, 74, 3, 79, 8, 56, 5, 82, 9, 34, 7, 92, 4,  2, 0, 62, 1,  4, 2, 86, 
    5, 93, 0, 11, 6, 51, 2, 84, 4,  7, 1, 57, 7, 35, 3, 75, 8, 10, 9, 49, 
    8, 68, 7, 98, 5, 85, 3, 97, 4, 38, 0, 19, 1, 90, 6, 44, 2, 33, 9, 57, 
    6, 93, 3, 35, 4, 53, 0,  9, 8, 38, 7, 76, 2,  1, 1, 38, 5, 51, 9, 18, 
    7, 32, 3, 49, 2, 64, 9, 65, 0, 92, 8, 39, 5, 64, 6, 16, 1, 92, 4, 73, 
    3, 84, 0,  7, 5, 73, 9, 55, 4, 63, 6, 17, 2, 46, 1, 35, 8, 95, 7, 44, 
    1, 38, 0, 46, 6, 67, 3,  6, 4, 37, 8, 40, 5,  6, 2, 55, 7, 50, 9, 96, 
    0, 78, 7, 23, 4, 19, 5, 72, 1, 95, 9, 42, 2, 12, 3, 14, 8, 65, 6, 44, 
    2, 36, 3, 33, 1, 73, 8, 97, 9,  3, 6, 83, 4, 15, 5, 89, 7, 22, 0, 59
  };
  const int r786[] = {
    10, 10, // Number of jobs and machines
    4, 76, 8, 84, 9, 20, 6, 56, 3, 78, 1, 27, 5,  2, 0, 58, 7, 60, 2, 68, 
    2, 57, 6, 41, 4, 72, 0, 33, 3, 32, 9, 86, 5, 94, 1, 12, 8, 24, 7, 13, 
    7, 56, 0, 21, 4, 20, 1,  8, 5, 49, 6, 25, 8, 80, 3, 42, 2, 49, 9, 76, 
    3, 89, 5, 29, 6, 99, 1, 83, 9, 65, 8, 68, 2, 53, 4, 33, 0, 81, 7, 31, 
    0, 47, 5, 60, 1, 14, 6, 53, 4, 47, 7,  4, 3, 64, 9, 85, 2, 95, 8, 65, 
    6, 74, 9, 65, 5, 91, 3, 84, 7,  4, 2, 17, 4, 60, 8, 67, 1, 47, 0, 14, 
    2,  2, 4, 97, 1, 32, 5, 51, 6, 92, 8, 92, 0,  7, 7, 72, 9, 79, 3, 98, 
    6,  6, 8, 75, 9,  5, 4, 31, 0, 44, 1,  1, 3,  1, 7, 55, 2, 68, 5, 45, 
    6, 81, 3, 80, 5, 86, 1, 50, 4,  7, 0, 20, 7, 18, 2, 59, 9, 86, 8, 21, 
    7, 63, 8, 40, 9, 71, 0, 82, 4, 27, 3, 66, 5, 23, 1, 49, 2, 48, 6,  5
  };
  const int r787[] = {
    10, 10, // Number of jobs and machines
    0, 69, 2, 62, 1, 23, 4, 55, 3,  2, 9, 56, 5, 82, 6, 26, 8, 36, 7,  7, 
    7, 85, 8,  8, 4, 26, 1, 40, 6, 62, 5, 80, 3, 77, 9, 54, 0, 41, 2, 17, 
    8, 25, 1, 47, 3, 20, 9, 76, 6, 27, 7, 86, 2, 59, 4, 15, 5, 32, 0, 87, 
    5, 10, 6, 37, 9, 52, 0, 71, 8, 67, 2, 37, 7, 44, 4, 13, 3, 75, 1, 15, 
    0,  2, 6, 33, 3, 75, 9, 95, 4, 31, 1, 26, 7, 63, 2,  5, 5, 43, 8, 40, 
    2,  3, 9,  2, 3, 16, 7, 96, 1, 59, 0, 16, 6, 84, 4, 45, 5, 14, 8,  9, 
    8, 31, 5, 94, 2, 53, 6, 98, 7, 16, 9, 11, 4, 26, 3, 22, 1, 78, 0, 15, 
    9, 66, 5, 53, 2, 87, 3, 79, 6, 93, 4, 60, 7, 47, 8, 15, 0, 69, 1, 17, 
    1, 38, 3, 93, 8, 33, 6, 68, 5, 51, 2, 33, 9, 30, 7, 85, 4, 95, 0, 83, 
    3, 46, 9, 27, 1, 88, 0, 18, 7, 36, 5, 92, 4, 35, 6, 10, 8, 73, 2,  5
  };
  const int r788[] = {
    10, 10, // Number of jobs and machines
    6, 57, 3, 93, 4, 36, 5, 42, 0, 92, 2, 45, 9, 29, 1, 78, 8, 21, 7, 45, 
    7, 68, 8, 69, 2, 76, 1, 24, 5, 19, 3,  7, 6, 26, 0, 88, 4, 22, 9, 56, 
    0,  5, 6, 72, 5, 87, 2, 81, 4,  3, 7, 40, 9, 29, 1, 55, 3, 67, 8, 49, 
    9, 76, 5, 19, 8, 83, 6, 85, 1, 89, 2, 19, 3, 76, 4, 33, 7, 27, 0, 42, 
    2, 77, 6, 66, 9, 24, 8, 95, 0, 87, 3, 74, 5, 71, 7, 18, 4, 69, 1, 34, 
    3, 28, 9, 61, 0, 98, 2, 51, 4, 65, 6, 62, 1, 29, 7, 49, 5, 26, 8, 11, 
    8,  3, 5, 81, 4, 52, 3,  7, 1, 90, 9, 38, 7, 79, 0, 65, 2, 41, 6, 39, 
    3, 89, 8, 13, 2, 99, 7,  8, 5, 13, 1, 13, 4, 12, 0, 13, 6, 24, 9, 59, 
    9, 32, 8, 60, 4, 11, 6, 60, 5, 35, 0, 87, 2, 99, 7,  7, 1,  8, 3, 52, 
    4, 24, 9, 21, 5, 69, 1, 33, 2, 79, 8, 11, 0, 31, 7, 94, 6,  8, 3, 63
  };
  const int r789[] = {
    10, 10, // Number of jobs and machines
    6, 86, 3, 24, 9, 73, 0, 71, 1, 56, 5, 72, 4, 62, 7, 99, 2, 26, 8, 57, 
    2, 46, 0, 32, 3, 30, 7, 35, 5, 73, 1, 37, 9,  7, 8, 67, 6, 37, 4, 53, 
    7, 85, 3, 20, 1,  8, 0, 87, 8, 96, 9, 81, 4, 54, 6,  6, 2,  7, 5, 68, 
    6, 79, 4, 56, 8, 94, 5,  7, 9,  1, 7, 76, 3, 91, 2, 31, 1, 26, 0, 54, 
    0, 60, 9, 38, 6, 56, 7, 98, 8,  4, 5, 70, 2, 72, 3,  5, 1, 32, 4, 65, 
    8, 48, 7, 26, 6, 11, 2, 59, 1, 64, 9, 86, 4, 97, 0, 78, 3,  6, 5, 98, 
    2, 48, 8, 84, 0, 65, 9, 17, 5, 90, 6,  3, 7,  1, 3, 69, 1,  7, 4, 65, 
    2, 25, 5, 30, 4, 33, 3, 65, 7, 15, 1,  3, 8, 52, 0, 85, 6, 98, 9, 93, 
    5, 27, 2,  5, 1,  5, 7, 57, 6, 14, 3, 60, 9, 36, 8, 56, 4, 62, 0,  9, 
    1, 13, 7, 62, 4, 90, 9, 61, 3, 20, 8, 11, 0, 87, 6,  3, 5, 43, 2, 57
  };
  const int r790[] = {
    10, 10, // Number of jobs and machines
    2, 35, 3, 46, 0, 47, 8, 34, 7, 98, 1, 85, 4, 54, 5, 94, 9, 25, 6, 67, 
    5, 78, 9, 75, 1, 71, 2, 49, 0, 19, 3, 25, 6, 13, 8, 29, 7, 49, 4, 91, 
    1, 86, 4,  8, 5, 91, 8,  1, 3, 96, 6, 12, 9, 33, 7, 36, 2, 67, 0, 37, 
    2, 99, 8, 99, 7,  5, 3, 39, 0, 75, 5, 70, 4, 30, 6, 47, 9, 66, 1,  5, 
    5, 77, 4, 48, 2, 42, 8, 87, 9, 69, 7, 70, 6, 84, 3, 85, 1, 71, 0, 99, 
    6, 77, 8, 69, 3, 46, 0, 90, 5, 33, 7, 85, 9, 29, 1, 10, 4, 37, 2, 45, 
    1, 40, 6, 66, 3, 54, 7, 93, 4, 89, 8, 11, 5, 53, 2, 65, 9, 69, 0, 63, 
    7, 52, 2, 91, 6, 44, 3, 16, 5, 67, 9, 39, 0, 65, 8, 53, 1, 40, 4, 37, 
    7, 40, 6,  7, 1, 34, 0, 19, 8, 37, 4, 11, 9, 65, 5,  1, 2, 88, 3, 54, 
    8, 15, 4, 81, 9, 97, 3, 31, 7, 75, 2, 71, 1, 23, 0,  3, 5, 63, 6, 30
  };
  const int r791[] = {
    10, 10, // Number of jobs and machines
    8, 99, 1, 18, 9, 88, 7, 58, 3, 92, 6,  5, 4, 33, 0, 27, 5, 47, 2, 81, 
    2, 17, 7,  2, 1, 41, 5, 23, 6, 26, 0, 68, 3, 43, 8, 39, 9,  1, 4, 39, 
    8, 43, 1, 41, 7, 33, 9, 30, 3, 23, 0,  9, 2, 28, 5, 70, 4, 72, 6, 35, 
    2, 12, 4, 51, 6, 22, 5, 48, 7, 76, 8, 28, 3, 61, 1, 67, 0, 60, 9, 24, 
    2, 97, 1, 17, 4,  1, 5, 73, 3, 91, 0, 63, 6, 69, 8,  6, 7, 34, 9, 59, 
    7, 57, 0, 96, 6, 72, 3, 32, 9, 64, 2, 81, 1, 89, 4, 10, 5, 96, 8, 88, 
    9, 13, 0, 86, 3, 90, 1,  1, 4, 19, 6, 66, 7, 66, 8, 79, 2, 20, 5, 56, 
    6, 53, 7,  2, 0, 53, 2,  5, 1, 74, 8, 65, 5, 15, 4, 59, 9,  4, 3, 79, 
    2, 21, 0, 69, 8, 94, 6,  5, 1, 10, 3, 74, 9,  1, 4, 21, 7, 72, 5, 58, 
    7, 17, 4,  4, 2, 79, 8, 92, 0, 40, 1, 53, 6, 73, 9, 95, 5, 88, 3, 66
  };
  const int r792[] = {
    10, 10, // Number of jobs and machines
    4,  9, 7, 43, 6, 68, 3, 64, 8, 22, 5, 50, 9, 47, 2, 69, 1, 77, 0, 36, 
    4,  5, 5, 43, 1, 27, 0, 73, 8, 30, 2, 16, 6, 74, 9, 16, 7, 13, 3, 40, 
    6, 91, 0, 15, 5, 27, 8, 69, 2, 11, 9, 84, 3, 53, 1, 85, 4, 64, 7, 45, 
    4, 40, 8, 15, 2, 60, 0, 38, 1, 71, 3, 28, 7, 59, 5, 88, 6, 15, 9, 89, 
    4, 58, 5, 21, 1, 21, 6, 94, 0, 21, 8, 52, 9, 30, 2, 90, 3, 89, 7, 17, 
    2, 56, 0, 48, 1, 92, 5, 56, 8, 94, 3, 54, 9, 53, 4, 34, 6, 60, 7, 16, 
    5, 65, 8, 32, 9, 88, 2, 62, 6, 33, 3, 10, 0, 36, 7, 72, 1, 16, 4, 85, 
    4, 43, 6, 59, 9, 82, 7, 60, 1, 33, 0, 35, 3, 10, 8, 58, 5, 50, 2, 90, 
    9, 22, 6, 95, 1, 62, 5, 84, 3, 89, 7, 89, 4, 98, 8, 46, 2, 21, 0, 37, 
    7, 30, 0, 45, 5, 79, 9,  4, 6,  2, 1, 77, 2, 16, 8, 78, 3, 53, 4, 46
  };
  const int r793[] = {
    10, 10, // Number of jobs and machines
    3, 94, 1, 15, 0,  9, 5, 46, 8, 65, 9, 53, 4, 71, 2,  1, 6, 57, 7, 57, 
    1,  9, 8, 34, 3, 51, 9, 16, 7, 68, 4, 26, 2, 99, 0, 56, 6, 78, 5, 50, 
    2,  7, 7, 61, 1,  7, 8, 23, 5, 14, 4, 28, 9, 74, 3, 96, 6, 73, 0, 65, 
    6, 80, 1, 86, 3, 46, 0, 95, 9, 85, 2, 75, 8, 41, 4, 84, 5, 56, 7, 74, 
    4, 82, 5, 53, 8, 20, 7, 96, 6, 38, 2, 45, 3, 87, 1, 32, 9, 10, 0, 19, 
    2, 82, 5, 72, 3, 27, 7, 34, 6, 81, 9, 56, 0, 89, 4, 56, 1,  5, 8, 35, 
    5, 90, 1, 17, 6, 78, 4, 46, 9, 88, 2, 17, 7, 68, 3, 36, 8, 53, 0, 77, 
    4, 96, 7, 84, 3, 43, 0, 59, 1, 92, 8, 31, 2, 62, 5, 10, 6, 25, 9, 40, 
    3, 67, 4, 88, 2, 89, 8, 46, 9,  8, 1, 52, 0, 25, 6, 56, 7, 65, 5, 48, 
    4, 11, 8, 18, 1, 33, 9, 97, 3, 64, 6, 16, 0, 30, 7, 56, 5, 78, 2, 28
  };
  const int r794[] = {
    10, 10, // Number of jobs and machines
    4, 12, 9,  6, 2,  9, 7, 53, 1, 69, 0, 11, 3, 51, 5, 53, 6, 69, 8, 40, 
    3, 76, 1, 79, 8, 43, 4, 90, 7, 27, 2, 81, 5, 76, 0,  8, 9, 31, 6, 82, 
    6, 18, 3, 30, 0, 51, 8, 42, 7, 96, 1, 81, 2, 38, 4, 54, 9, 32, 5,  4, 
    9, 24, 2, 97, 7,  4, 4, 57, 0, 22, 6, 46, 3, 47, 5, 32, 1, 43, 8, 56, 
    0, 32, 4, 69, 2, 94, 9, 37, 1,  7, 6, 64, 7, 54, 3, 61, 5, 27, 8,  2, 
    3, 62, 2, 67, 9, 94, 7, 23, 6, 66, 8, 81, 0, 32, 5, 81, 4, 23, 1, 53, 
    2,  5, 4,  5, 6, 50, 3, 82, 8, 19, 1,  3, 0, 23, 5, 24, 7, 67, 9,  2, 
    2, 70, 7, 74, 3, 43, 4, 97, 0, 92, 5, 24, 1, 67, 9, 56, 6, 46, 8, 21, 
    8, 88, 5, 79, 3, 12, 9, 34, 6, 12, 0, 70, 2, 75, 1, 88, 4, 43, 7, 16, 
    8, 39, 3,  9, 6, 56, 2, 19, 4, 83, 7, 78, 5, 36, 0, 76, 9, 50, 1, 56
  };
  const int r795[] = {
    10, 10, // Number of jobs and machines
    0, 33, 9, 67, 3,  2, 2, 48, 4, 59, 5, 51, 8, 31, 7, 39, 1, 93, 6, 98, 
    6, 75, 9, 20, 1, 43, 7, 27, 4, 21, 3, 99, 2, 43, 5, 18, 0, 57, 8, 64, 
    9, 77, 1,  5, 0, 89, 6, 83, 3, 65, 5, 86, 7, 66, 2, 23, 8, 33, 4, 45, 
    3, 45, 0, 36, 7, 82, 4, 43, 8, 89, 1, 10, 6,  1, 2, 86, 9, 83, 5, 49, 
    8, 49, 6, 48, 9, 30, 7, 69, 0, 57, 3, 13, 5, 99, 4, 98, 1, 98, 2, 73, 
    9, 92, 1, 84, 2, 30, 4, 47, 3, 54, 8, 93, 7, 45, 6, 52, 0, 72, 5, 77, 
    8,  1, 6, 79, 3, 15, 1, 16, 5, 61, 7, 11, 2,  3, 0, 85, 9, 79, 4,  6, 
    6, 71, 3, 93, 1, 28, 2, 16, 4, 12, 0, 33, 7,  8, 8, 49, 5, 87, 9, 67, 
    8, 77, 5, 40, 7, 60, 6, 17, 4, 41, 9, 21, 0, 67, 2, 19, 1, 87, 3, 82, 
    2, 77, 7, 75, 9, 47, 0, 84, 3, 42, 8,  2, 6, 68, 5, 77, 4,  5, 1, 99
  };
  const int r796[] = {
    10, 10, // Number of jobs and machines
    2, 64, 5, 86, 0, 30, 3, 98, 1, 87, 9, 81, 8, 61, 7, 63, 6, 87, 4, 16, 
    5, 82, 1, 51, 0, 60, 2, 49, 7, 90, 6, 86, 9, 42, 8, 11, 3, 46, 4, 44, 
    0, 30, 7, 28, 3, 45, 6, 85, 8,  2, 2, 48, 5, 95, 9, 57, 4, 39, 1, 80, 
    2, 67, 4, 21, 7, 60, 0, 97, 5, 24, 6, 92, 9, 39, 8, 74, 1, 74, 3, 27, 
    4, 10, 3, 34, 2, 62, 7, 85, 5,  2, 0, 48, 1, 13, 8, 22, 6, 11, 9, 72, 
    2, 31, 7, 37, 5, 26, 3, 13, 8, 90, 4,  2, 9, 85, 1, 75, 0, 77, 6, 39, 
    3, 14, 8, 82, 5, 71, 6, 82, 1, 82, 4, 13, 9, 92, 2,  3, 7, 21, 0, 22, 
    5, 52, 0,  5, 6, 87, 8, 43, 4, 75, 3, 81, 1, 18, 7, 27, 2, 30, 9, 17, 
    4, 18, 8, 79, 5,  4, 6, 18, 0, 17, 7, 87, 9, 22, 2, 86, 3, 74, 1, 43, 
    0, 93, 9, 39, 7, 57, 3, 23, 2, 93, 8, 89, 4, 14, 6, 58, 5, 54, 1, 69
  };
  const int r797[] = {
    10, 10, // Number of jobs and machines
    5, 50, 6, 96, 8, 32, 0,  1, 9, 19, 3, 86, 1, 30, 4, 11, 2, 36, 7, 67, 
    5, 29, 8, 21, 9, 91, 6, 75, 3,  9, 7, 28, 1, 41, 2, 96, 0, 71, 4, 46, 
    3, 96, 4, 79, 0, 96, 6,  2, 7, 66, 1, 79, 2, 78, 5, 96, 9, 40, 8, 66, 
    3, 62, 7, 90, 0, 22, 9, 33, 8, 63, 5, 46, 1,  6, 2, 65, 4, 20, 6, 78, 
    6, 36, 7, 63, 4,  9, 8, 13, 1, 18, 9, 23, 3,  4, 0, 37, 5, 31, 2, 40, 
    1,  3, 9, 81, 0, 84, 6, 67, 5, 64, 3, 52, 4, 40, 8, 16, 7, 95, 2, 48, 
    6,  8, 5, 57, 3, 68, 9, 73, 0,  9, 8, 38, 7, 62, 2, 76, 1, 89, 4, 89, 
    5, 82, 9, 92, 2, 70, 3, 45, 6, 16, 8, 66, 7, 27, 1, 66, 4, 60, 0, 42, 
    2, 35, 8, 57, 0, 65, 9, 45, 1, 50, 5, 38, 3, 93, 6, 84, 4, 90, 7,  6, 
    7, 18, 3, 63, 1, 50, 5, 88, 0, 83, 2, 22, 8, 96, 6, 39, 9, 70, 4,  6
  };
  const int r798[] = {
    10, 10, // Number of jobs and machines
    7, 93, 1, 63, 6, 53, 2,  5, 9,  4, 3, 72, 0, 95, 4, 74, 8, 38, 5, 90, 
    7, 26, 1, 11, 3,  5, 6, 10, 8, 13, 4, 43, 5, 68, 2, 16, 9, 70, 0, 57, 
    6, 39, 8, 88, 4, 67, 3, 44, 5,  8, 1, 15, 7, 48, 9, 89, 2, 32, 0, 62, 
    1, 70, 5, 74, 9, 78, 3, 99, 8, 37, 4, 61, 6, 89, 2, 19, 0, 79, 7,  9, 
    7, 97, 2, 79, 8, 20, 5, 54, 9, 47, 3, 92, 6,  2, 1, 30, 0, 96, 4, 14, 
    6, 49, 4, 38, 0, 31, 1, 49, 7, 10, 5, 49, 3, 52, 9, 73, 2, 47, 8, 70, 
    9, 31, 2, 30, 4, 31, 7, 96, 1, 23, 3, 82, 0, 80, 8, 99, 5, 19, 6,  1, 
    7, 41, 1, 25, 3, 56, 5, 19, 8, 57, 0, 32, 4, 27, 2, 14, 6,  2, 9, 47, 
    5, 70, 7, 81, 0, 79, 6, 66, 9, 18, 3, 74, 8,  7, 1, 94, 4, 70, 2, 60, 
    0, 11, 4, 47, 8, 50, 2, 23, 1, 51, 9, 49, 7, 97, 3, 68, 5, 42, 6, 54
  };
  const int r799[] = {
    10, 10, // Number of jobs and machines
    4, 82, 6,  6, 7, 28, 5,  3, 1, 73, 0, 82, 8, 33, 2, 25, 9, 59, 3, 10, 
    0,  1, 6, 55, 8, 46, 9, 70, 3, 64, 2, 96, 4, 90, 1, 37, 5, 15, 7, 37, 
    3, 69, 7, 91, 0,  7, 4, 22, 5, 82, 2, 93, 9, 67, 1, 78, 8, 90, 6, 70, 
    0, 33, 6, 60, 2, 75, 1, 33, 5, 62, 8, 55, 9, 91, 4, 68, 3, 28, 7,  7, 
    1,  6, 9, 44, 5, 71, 3, 21, 6, 15, 2,  6, 7, 37, 8, 36, 4,  6, 0,  3, 
    8, 66, 5, 35, 6, 76, 9, 29, 0, 17, 7, 37, 3, 28, 4, 25, 2, 38, 1, 44, 
    2, 28, 3, 48, 6, 26, 7,  3, 8, 15, 1,  6, 4, 16, 5, 30, 0, 58, 9, 52, 
    1, 55, 3, 76, 6, 58, 7, 15, 5, 86, 4, 29, 9, 47, 0, 75, 2, 58, 8, 11, 
    5, 59, 6, 39, 7, 84, 1, 12, 0, 42, 2, 59, 9, 24, 8, 74, 4, 19, 3, 39, 
    4, 59, 0, 57, 1, 58, 5, 63, 3, 85, 6, 28, 9, 74, 7, 57, 8, 57, 2, 10
  };
  const int r800[] = {
    10, 10, // Number of jobs and machines
    0, 42, 8, 96, 9, 83, 6, 11, 2, 95, 1, 81, 3, 39, 4, 23, 5, 54, 7, 84, 
    0, 75, 7, 82, 6, 43, 8, 55, 5, 48, 1,  8, 3, 81, 4, 21, 2, 39, 9, 62, 
    9, 71, 6, 71, 8, 59, 1, 81, 4, 77, 3, 18, 7, 79, 5, 43, 2, 22, 0, 21, 
    0, 58, 8, 64, 1, 90, 3, 33, 4, 16, 6, 60, 5, 84, 2,  8, 7,  3, 9, 78, 
    0, 43, 6,  2, 5, 88, 2, 91, 4, 55, 9, 62, 7, 57, 8, 43, 1, 74, 3, 82, 
    2, 21, 8, 13, 6, 99, 0,  5, 3, 30, 5, 43, 4, 36, 1, 57, 9, 74, 7, 74, 
    8, 90, 1, 35, 2, 72, 0, 85, 7, 51, 3, 53, 4, 64, 5, 93, 6, 36, 9, 62, 
    6, 59, 0, 31, 9, 11, 8, 18, 4, 24, 1, 64, 7, 99, 3, 30, 5, 27, 2, 34, 
    6, 95, 9, 64, 0, 19, 1, 88, 7, 23, 2, 36, 3, 73, 8,  5, 4,  6, 5, 22, 
    7, 32, 3, 89, 9, 22, 0, 10, 5, 25, 6, 87, 1, 54, 8, 22, 2, 94, 4, 23
  };
  const int r801[] = {
    10, 10, // Number of jobs and machines
    2, 93, 9, 74, 4, 21, 0, 61, 5, 22, 6, 59, 1, 43, 7, 94, 8, 92, 3, 87, 
    8, 73, 1, 83, 4, 31, 7, 81, 6, 33, 3, 86, 2, 12, 5, 98, 9,  8, 0, 44, 
    6, 36, 0, 84, 8, 31, 1, 65, 3, 25, 9, 73, 5, 23, 2, 38, 7, 98, 4, 85, 
    2, 50, 6, 65, 5, 11, 1, 95, 7, 55, 4, 38, 0, 46, 9, 28, 3, 74, 8,  6, 
    8,  2, 4, 26, 1, 97, 0, 26, 5, 27, 7, 85, 9,  8, 3, 92, 2,  1, 6, 85, 
    0, 75, 8, 17, 1, 15, 4, 49, 5, 79, 9, 24, 6, 16, 7, 73, 3,  5, 2, 56, 
    2, 76, 9, 81, 7, 44, 8, 87, 4, 86, 5, 54, 3, 96, 6, 87, 0, 60, 1, 49, 
    8, 68, 9,  2, 1, 63, 2, 99, 3, 34, 0, 72, 6, 50, 5, 34, 7, 83, 4,  7, 
    3, 40, 2, 98, 9, 15, 0, 50, 5, 79, 8, 97, 7, 34, 1, 30, 4, 86, 6, 45, 
    6, 21, 1, 77, 0, 47, 2, 12, 7, 42, 3,  1, 9, 69, 8, 52, 5, 99, 4, 38
  };
  const int r802[] = {
    10, 10, // Number of jobs and machines
    9, 50, 6, 57, 3, 30, 8, 12, 2, 36, 4, 25, 1,  7, 7,  3, 5, 28, 0, 50, 
    2, 36, 7,  3, 4, 99, 8, 45, 9, 82, 6, 40, 0, 19, 1, 51, 3, 63, 5, 40, 
    2, 16, 5, 24, 9, 76, 3, 10, 6, 13, 1, 55, 7, 56, 0, 98, 8, 28, 4, 37, 
    6, 25, 8, 61, 1, 25, 7, 98, 9, 91, 2, 74, 5, 29, 0, 43, 4, 51, 3, 93, 
    5, 76, 1, 61, 9, 38, 7, 31, 2, 73, 3, 94, 4, 24, 0, 16, 8, 16, 6, 72, 
    2, 76, 4,  3, 6, 96, 9, 95, 8, 24, 5, 25, 0, 53, 1, 68, 3, 71, 7,  3, 
    2, 89, 6, 80, 8, 74, 9, 84, 1, 65, 7, 36, 0, 19, 3, 36, 4, 40, 5, 20, 
    2, 79, 3,  5, 0, 72, 1, 27, 8, 15, 9, 92, 6, 21, 4, 71, 7,  5, 5, 35, 
    7, 37, 1, 12, 9, 27, 4, 72, 8, 80, 5, 50, 0, 30, 2, 45, 6, 93, 3, 36, 
    7, 45, 8, 26, 6, 68, 0, 35, 3, 52, 4, 83, 5, 34, 1, 70, 2, 57, 9, 10
  };
  const int r803[] = {
    10, 10, // Number of jobs and machines
    6, 10, 1, 94, 4, 51, 5, 69, 7, 46, 0, 15, 9, 67, 2, 59, 3, 12, 8, 35, 
    6, 11, 2, 27, 9, 47, 3, 14, 7, 58, 1, 32, 5, 87, 8, 97, 4, 54, 0, 79, 
    0, 10, 6, 17, 8,  5, 1, 48, 9, 40, 3, 38, 4, 49, 5, 22, 7, 21, 2,  5, 
    1, 44, 4,  1, 6, 38, 5, 21, 2, 80, 0, 43, 8,  9, 3, 23, 7, 97, 9, 79, 
    6, 53, 9, 79, 3, 51, 2,  9, 8, 12, 7, 96, 5, 58, 1, 55, 0, 39, 4, 60, 
    2, 60, 3, 30, 9, 11, 1, 65, 8, 53, 5, 52, 4, 56, 7, 64, 0,  9, 6, 90, 
    1, 73, 6, 85, 9, 25, 5,  6, 4, 27, 2, 72, 7, 14, 8, 15, 3, 93, 0, 50, 
    1, 18, 5, 68, 2,  9, 7, 94, 9, 57, 3, 85, 6, 90, 0, 73, 8, 60, 4, 86, 
    8, 58, 1, 20, 2, 63, 3,  3, 7, 84, 4, 29, 9, 94, 0, 86, 6, 43, 5, 94, 
    7, 81, 9, 16, 0, 50, 4,  7, 8, 91, 6, 87, 2, 96, 5, 38, 1, 45, 3, 85
  };
  const int r804[] = {
    10, 10, // Number of jobs and machines
    6, 14, 8, 55, 7,  8, 5, 33, 9, 85, 0, 87, 2,  1, 1, 71, 4, 44, 3, 21, 
    3, 51, 4, 99, 5, 91, 6, 60, 7, 55, 0, 84, 1, 80, 8, 82, 2, 64, 9, 90, 
    4, 15, 5, 19, 0, 76, 7, 55, 3, 23, 1, 13, 6, 18, 8, 67, 9, 60, 2, 35, 
    3, 15, 2,  5, 6, 85, 4, 20, 5, 94, 1, 86, 0, 48, 8, 37, 7, 18, 9, 51, 
    7, 74, 2, 48, 3, 74, 0, 72, 1, 60, 6, 84, 9, 21, 8, 70, 5, 55, 4, 10, 
    8, 33, 7, 40, 9, 19, 2, 31, 3, 53, 1, 68, 5, 68, 6, 58, 0, 72, 4, 37, 
    3, 94, 8, 59, 0, 87, 9, 72, 1, 89, 4, 20, 2, 70, 6, 43, 5, 78, 7, 80, 
    9, 89, 7, 98, 3, 20, 4, 19, 6, 19, 1, 76, 2, 65, 5, 53, 0, 82, 8, 79, 
    6, 87, 2, 10, 5, 63, 9, 87, 8, 46, 3, 96, 0, 76, 7, 13, 1, 81, 4, 25, 
    4, 41, 6, 37, 2, 70, 3, 38, 1, 96, 7, 35, 8, 82, 9, 26, 0, 78, 5, 47
  };
  const int r805[] = {
    10, 10, // Number of jobs and machines
    9, 40, 1, 95, 8, 61, 5, 37, 0, 46, 3, 30, 7, 62, 6, 58, 2, 57, 4, 52, 
    0, 71, 1,  5, 4,  9, 9, 76, 6, 66, 2, 62, 3, 27, 7, 56, 8, 83, 5, 56, 
    4, 46, 5, 38, 0, 74, 7,  8, 8, 71, 2, 99, 6, 36, 9, 28, 1,  3, 3, 33, 
    0, 98, 5, 16, 2, 32, 4, 80, 7, 78, 6, 92, 8, 21, 3, 93, 9, 39, 1, 12, 
    1, 21, 6, 42, 2, 16, 8, 10, 5,  8, 9, 52, 0, 33, 3, 60, 4,  8, 7, 75, 
    7, 24, 9, 42, 3,  6, 0, 38, 4, 60, 5, 95, 2, 36, 8, 84, 6, 30, 1, 11, 
    4, 41, 6, 34, 5, 26, 2, 59, 7, 74, 1, 27, 8, 48, 3, 82, 9, 55, 0, 45, 
    9, 75, 7, 39, 3, 43, 2, 56, 6,  5, 0, 58, 8, 15, 4, 27, 5, 39, 1, 30, 
    0, 40, 5, 73, 7, 13, 6, 20, 4, 55, 1, 67, 2, 92, 8, 20, 9, 10, 3,  1, 
    0,  5, 2, 28, 9, 90, 8, 69, 3,  5, 6, 39, 5, 62, 4, 62, 1, 60, 7, 67
  };
  const int r806[] = {
    10, 10, // Number of jobs and machines
    1, 57, 0, 87, 9,  4, 2, 88, 5, 45, 6, 25, 7, 81, 4, 93, 3, 84, 8, 91, 
    5, 53, 2, 50, 4, 27, 1, 54, 8, 92, 6, 65, 7, 41, 3, 38, 9, 99, 0, 73, 
    5, 43, 1, 60, 7,  5, 8, 89, 4, 89, 9, 75, 3, 55, 2, 99, 6, 71, 0, 23, 
    8,  7, 6,  7, 9, 96, 5, 18, 0, 40, 3, 42, 2, 63, 1, 46, 7, 83, 4, 73, 
    4, 53, 9, 31, 5, 47, 1, 92, 7, 83, 6, 94, 0, 21, 2, 11, 3,  2, 8, 40, 
    3, 92, 6, 93, 8, 84, 0, 38, 4, 58, 5, 61, 9, 33, 2, 51, 7, 41, 1, 43, 
    0, 83, 9, 28, 8, 26, 1, 48, 3, 60, 6, 70, 2, 90, 7, 77, 5, 45, 4, 21, 
    3, 38, 9, 96, 7, 38, 5, 27, 1, 50, 4, 49, 6, 52, 2, 41, 0, 96, 8, 39, 
    0, 82, 2, 74, 8, 75, 7, 74, 4, 89, 3, 34, 5, 95, 1, 36, 9, 69, 6, 93, 
    5,  8, 3, 59, 6, 77, 1, 81, 8, 40, 9, 23, 2, 51, 0, 55, 4, 34, 7, 65
  };
  const int r807[] = {
    10, 10, // Number of jobs and machines
    1, 56, 5, 21, 4, 70, 7, 12, 3, 99, 8, 28, 9, 18, 2, 60, 0, 82, 6, 38, 
    0, 44, 6, 93, 8, 75, 1, 49, 2, 77, 5, 14, 9, 21, 7, 73, 4, 31, 3, 71, 
    0, 70, 6, 41, 5, 75, 8, 44, 4, 33, 3, 69, 1, 47, 2, 86, 9, 91, 7, 27, 
    6, 25, 2, 54, 5, 26, 7, 32, 8, 26, 4, 59, 1, 83, 0, 52, 3, 93, 9, 80, 
    8, 30, 1,  3, 0, 97, 9, 97, 4, 43, 7, 37, 3, 16, 6, 17, 5, 41, 2, 25, 
    2, 74, 3, 81, 5, 32, 9, 39, 6, 48, 4, 88, 7, 42, 0, 87, 1, 79, 8,  3, 
    6, 75, 7,  4, 1, 25, 0, 22, 5, 43, 4, 45, 8, 80, 2, 97, 9, 35, 3,  7, 
    6, 74, 4, 41, 3, 71, 2, 56, 1, 29, 9, 50, 5, 17, 8, 90, 0, 53, 7,  6, 
    6, 43, 5, 99, 7, 80, 3, 22, 4, 69, 8, 61, 0, 36, 9, 42, 1, 31, 2, 71, 
    6, 29, 9, 50, 2, 78, 4, 94, 8, 82, 5, 10, 0, 34, 7, 64, 1, 42, 3, 97
  };
  const int r808[] = {
    10, 10, // Number of jobs and machines
    9, 10, 0, 40, 3, 92, 4, 74, 2, 37, 5, 98, 6, 29, 7, 78, 1, 94, 8, 52, 
    0, 70, 8,  9, 4, 75, 5, 88, 7, 77, 6,  1, 3, 83, 1,  1, 2, 98, 9, 64, 
    5, 85, 3, 10, 2, 13, 0, 88, 9, 47, 4, 50, 1, 20, 6, 24, 7, 25, 8, 82, 
    6, 67, 5, 69, 0, 89, 3, 15, 2, 57, 7, 49, 1, 55, 8, 16, 4, 23, 9, 28, 
    4, 73, 8, 22, 3, 16, 5, 70, 6, 25, 9, 61, 2, 13, 0, 78, 1,  1, 7, 54, 
    1, 31, 7, 81, 9, 97, 8, 32, 4, 67, 3, 67, 0, 57, 6, 62, 5, 19, 2, 10, 
    9, 88, 5,  7, 7, 82, 2, 63, 8, 29, 0, 80, 3, 32, 4, 34, 6, 23, 1, 16, 
    0, 43, 7, 73, 2, 86, 8, 95, 6,  1, 5, 42, 1, 73, 3, 44, 9, 17, 4, 72, 
    8, 27, 2, 40, 9, 94, 6, 46, 0,  7, 3, 42, 5, 53, 4, 51, 7,  9, 1, 26, 
    5, 86, 4, 55, 8, 39, 3, 75, 1, 92, 7, 96, 0, 35, 2, 20, 6, 36, 9, 22
  };
  const int r809[] = {
    10, 10, // Number of jobs and machines
    2, 80, 5, 69, 4, 14, 8,  1, 3, 72, 0, 98, 7, 11, 6, 37, 9, 88, 1, 64, 
    8, 90, 1, 34, 6, 27, 5, 77, 9, 53, 0, 63, 7, 76, 2, 14, 3, 94, 4, 38, 
    5,  4, 8, 93, 7, 16, 4, 58, 0, 24, 6, 46, 2, 47, 3, 27, 1, 79, 9, 73, 
    4, 49, 8, 53, 6, 81, 1, 16, 7, 86, 9, 36, 2,  5, 5, 75, 0, 85, 3, 21, 
    3, 93, 2, 36, 9, 49, 0, 45, 5,  6, 7, 64, 1, 27, 4, 16, 6, 82, 8, 52, 
    9, 85, 4, 55, 7,  1, 8, 26, 1, 63, 5, 68, 2, 68, 3, 13, 0,  2, 6, 27, 
    9, 16, 1, 71, 4,  4, 2, 43, 8, 22, 5, 31, 0,  6, 7, 98, 3, 22, 6, 92, 
    8, 72, 1, 11, 4, 15, 7, 55, 5, 96, 2,  3, 3, 95, 6, 21, 0, 84, 9,  7, 
    5, 41, 3, 20, 4, 29, 7, 55, 8, 89, 0, 98, 1, 66, 2, 37, 9, 16, 6, 21, 
    0, 98, 7, 24, 8, 14, 4, 92, 3, 80, 5, 88, 2, 51, 6, 84, 1, 14, 9, 67
  };
  const int r810[] = {
    10, 10, // Number of jobs and machines
    8, 60, 4, 46, 7, 80, 5,  2, 6, 61, 2, 24, 1, 68, 0, 34, 3, 97, 9, 65, 
    9, 89, 3, 62, 2, 57, 4,  3, 1, 55, 6, 58, 8, 99, 7, 87, 5, 64, 0, 69, 
    5, 94, 1,  8, 9, 72, 7, 69, 3, 81, 0, 15, 8, 60, 4, 93, 2, 39, 6, 38, 
    3, 65, 4, 40, 8, 80, 6, 21, 2, 74, 1, 50, 5, 95, 9, 80, 7, 68, 0, 98, 
    5, 88, 6,  3, 1, 25, 2, 90, 9, 71, 4, 23, 0, 60, 8,  4, 7, 68, 3, 69, 
    7, 77, 3, 73, 8, 59, 0,  4, 6, 25, 9, 40, 4, 64, 5, 14, 2, 27, 1, 76, 
    0, 45, 8, 11, 7, 92, 3, 51, 6, 68, 2, 43, 1, 71, 4, 24, 5, 86, 9, 48, 
    6, 86, 4, 54, 3, 76, 0, 20, 1, 24, 8, 83, 5, 25, 9, 21, 2, 79, 7, 65, 
    1, 60, 2, 22, 8, 39, 3, 57, 6, 35, 4, 31, 0, 31, 7, 80, 5, 33, 9, 62, 
    7, 67, 3, 51, 9, 17, 5, 39, 8, 38, 2, 95, 0,  1, 1, 42, 4, 81, 6, 19
  };
  const int r811[] = {
    10, 10, // Number of jobs and machines
    7, 57, 9,  6, 0, 28, 4, 92, 8, 63, 1, 16, 6, 99, 3, 25, 5, 78, 2,  1, 
    8, 93, 3, 32, 1,  9, 6,  7, 5,  1, 2, 39, 0, 71, 4, 13, 9, 93, 7, 85, 
    6, 86, 4, 53, 9,  5, 1, 46, 8, 75, 5, 65, 2, 71, 7,  1, 3, 86, 0, 49, 
    5, 23, 0, 50, 8,  4, 7, 60, 3,  4, 4, 50, 2, 18, 1, 97, 6, 58, 9, 28, 
    8, 86, 6, 57, 3, 60, 5, 91, 0, 13, 9, 23, 2, 31, 4, 91, 7, 19, 1, 99, 
    0, 64, 1, 29, 6, 96, 5, 94, 8, 26, 2, 46, 4,  6, 7, 40, 3, 32, 9, 67, 
    2, 73, 5, 40, 1, 89, 8, 13, 0, 77, 3, 56, 4, 22, 6, 37, 9, 75, 7, 33, 
    5, 39, 6, 32, 3, 19, 9, 42, 4, 37, 2,  8, 7, 73, 0, 10, 1, 45, 8, 53, 
    8, 66, 9, 60, 6, 72, 1, 99, 0, 59, 5, 30, 4, 17, 3, 34, 7, 25, 2, 68, 
    7,  2, 6, 57, 9, 22, 2,  4, 1, 11, 3, 47, 4, 62, 5, 48, 0, 23, 8,  7
  };
  const int r812[] = {
    10, 10, // Number of jobs and machines
    9,  3, 2,  4, 0, 91, 5, 43, 7, 94, 3, 10, 8, 14, 6, 75, 1, 89, 4, 96, 
    3, 92, 2, 56, 4, 88, 7, 59, 0,  7, 9, 44, 8, 13, 1, 23, 5, 50, 6, 84, 
    5, 46, 9, 81, 2, 97, 6, 37, 7, 18, 3, 22, 1, 21, 8, 18, 4, 49, 0, 29, 
    6, 10, 4, 78, 1, 18, 0, 23, 2,  1, 8, 42, 3, 99, 7,  2, 9, 97, 5,  2, 
    7, 99, 5, 29, 4, 23, 2, 28, 0, 92, 3, 17, 1, 36, 9, 59, 8, 47, 6, 38, 
    7,  9, 6, 54, 0,  9, 1, 40, 8, 23, 3, 90, 2, 58, 4, 81, 9,  6, 5, 38, 
    4, 57, 5, 52, 3,  8, 0,  3, 2, 65, 1, 43, 7, 92, 9, 71, 6, 56, 8,  2, 
    3, 39, 5, 79, 4, 55, 8,  1, 6, 54, 9,  4, 2, 44, 0, 97, 1, 17, 7, 74, 
    8, 33, 3, 82, 6, 55, 5, 41, 1, 25, 0, 16, 7, 45, 9,  3, 2,  9, 4, 74, 
    3, 54, 9, 40, 8, 58, 5, 25, 6,  3, 0, 21, 4, 48, 2, 22, 1, 47, 7, 26
  };
  const int r813[] = {
    10, 10, // Number of jobs and machines
    0, 26, 9, 34, 4, 14, 8, 50, 6,  5, 3, 70, 5, 17, 7, 96, 2, 48, 1,  3, 
    9, 37, 3, 70, 1, 44, 6, 81, 7, 49, 8, 93, 5, 82, 0, 25, 4, 61, 2, 46, 
    2,  6, 3, 36, 8, 42, 6, 95, 1, 39, 7, 80, 0, 19, 9, 25, 5, 67, 4, 14, 
    9, 54, 0, 15, 1, 90, 5, 21, 4,  2, 3, 66, 6, 49, 2, 66, 8, 86, 7, 55, 
    2, 75, 4, 91, 5, 75, 1,  3, 7, 98, 8, 92, 9, 67, 0, 51, 3, 51, 6, 46, 
    8, 41, 3, 11, 1, 89, 0, 76, 7, 73, 6, 96, 9, 83, 2, 43, 5, 36, 4, 37, 
    1, 65, 9, 59, 7, 41, 3, 47, 4, 84, 0, 52, 6, 28, 2, 20, 5, 17, 8, 69, 
    3, 12, 9, 45, 1, 24, 2, 88, 6,  6, 7, 99, 4, 51, 5, 74, 0, 11, 8, 49, 
    1, 69, 0, 69, 5, 86, 8,  2, 3,  7, 7, 90, 6, 47, 4, 69, 2, 25, 9,  5, 
    0, 41, 8, 90, 2,  8, 1, 56, 4, 94, 3, 83, 7, 97, 5,  5, 9, 47, 6,  5
  };
  const int r814[] = {
    10, 10, // Number of jobs and machines
    3, 97, 9, 30, 4, 41, 7, 19, 0, 52, 5, 66, 1, 18, 8, 75, 2, 73, 6, 27, 
    3, 32, 6, 83, 9, 90, 5, 44, 8, 91, 2, 74, 1, 92, 4, 75, 0, 78, 7,  9, 
    6, 50, 0, 25, 4, 30, 3,  8, 1, 27, 5, 29, 9, 36, 7, 83, 8, 77, 2, 63, 
    4, 18, 3, 33, 0, 59, 8, 25, 1, 11, 7, 22, 5, 57, 2, 75, 6, 66, 9, 28, 
    3, 32, 2,  4, 6, 79, 5, 76, 0, 69, 9, 41, 4, 87, 7, 63, 1, 85, 8, 50, 
    6, 11, 3, 10, 0, 29, 5, 28, 9, 69, 2, 23, 8, 72, 4, 88, 1,  4, 7, 40, 
    5, 99, 8, 96, 6, 69, 2, 66, 1, 57, 3, 37, 9, 37, 7, 40, 0, 74, 4, 69, 
    4, 36, 7, 50, 6, 22, 0, 84, 8, 58, 1, 46, 3, 82, 2, 36, 9, 62, 5, 44, 
    3, 90, 0, 52, 5, 40, 7, 63, 6, 28, 8,  2, 2, 39, 1, 41, 9, 14, 4, 15, 
    6, 19, 3,  7, 9, 23, 1, 30, 8, 52, 0, 21, 2, 31, 5, 29, 7, 66, 4, 31
  };
  const int r815[] = {
    10, 10, // Number of jobs and machines
    9, 23, 4, 92, 2,  9, 8, 16, 5, 29, 3, 47, 7, 60, 0, 99, 6, 45, 1, 83, 
    8, 47, 6, 21, 2,  2, 0, 77, 3, 22, 4, 48, 9, 77, 1, 22, 7, 56, 5, 59, 
    2, 24, 3, 95, 8, 52, 7, 15, 6,  5, 1, 80, 9, 30, 4, 95, 0, 14, 5, 94, 
    4, 18, 0,  2, 6, 89, 3, 32, 8, 83, 5, 89, 7, 62, 2, 25, 9, 29, 1,  7, 
    4, 19, 9, 30, 7, 52, 8, 98, 6, 54, 0, 13, 2, 38, 5, 35, 3, 88, 1, 25, 
    0, 88, 5, 34, 2,  3, 6,  8, 1, 38, 8, 33, 7, 21, 9,  5, 4, 61, 3, 11, 
    7, 29, 6, 64, 1, 16, 4, 75, 5, 80, 9, 41, 3, 68, 0, 62, 8, 42, 2, 69, 
    2, 23, 1, 15, 5, 13, 9, 93, 6, 86, 0, 55, 3, 18, 7, 44, 8, 42, 4, 67, 
    6, 90, 2, 30, 1,  8, 0, 79, 7, 79, 5, 49, 9, 76, 3, 23, 8, 54, 4, 30, 
    0, 31, 4, 87, 8, 51, 9, 16, 6, 37, 1, 58, 3, 44, 2, 83, 5, 99, 7, 15
  };
  const int r816[] = {
    10, 10, // Number of jobs and machines
    1, 99, 5,  2, 8, 66, 3, 93, 6, 81, 2, 38, 9,  9, 4, 19, 0, 74, 7,  2, 
    1, 25, 3, 95, 4, 55, 2, 20, 6, 93, 7, 90, 0, 65, 9, 55, 8, 54, 5,  8, 
    4, 52, 5, 57, 9, 59, 0, 97, 3, 71, 8,  9, 1, 99, 2, 81, 6, 57, 7, 85, 
    0,  9, 7, 74, 4,  6, 8, 42, 3, 50, 5, 52, 6, 92, 1, 97, 9, 37, 2, 44, 
    8, 24, 3, 54, 7, 37, 2, 29, 6, 48, 5,  9, 0,  4, 9,  5, 4, 70, 1, 90, 
    8, 87, 7, 88, 6, 73, 4, 53, 5, 14, 1, 94, 9, 26, 2, 60, 3, 26, 0, 84, 
    9,  7, 4, 71, 1,  2, 8, 80, 0, 54, 3, 82, 7, 78, 2, 47, 5, 95, 6, 59, 
    6, 30, 0, 80, 5,  6, 9, 59, 7, 13, 8, 78, 3, 35, 2, 99, 4, 97, 1, 52, 
    3, 49, 6, 59, 7, 26, 1, 98, 4, 28, 2, 14, 0, 66, 9, 46, 5, 57, 8, 64, 
    9, 38, 0,  2, 3, 48, 2, 63, 6, 79, 4, 59, 8, 84, 1, 14, 5, 94, 7, 57
  };
  const int r817[] = {
    10, 10, // Number of jobs and machines
    7, 11, 2, 69, 8, 84, 3,  7, 9, 10, 4, 68, 1, 43, 5, 36, 6, 17, 0, 56, 
    9, 54, 4, 27, 2,  3, 1, 98, 0, 14, 3, 28, 6, 33, 8, 74, 7, 45, 5, 27, 
    8, 30, 6, 10, 5, 62, 0, 90, 4,  7, 2,  4, 9, 39, 7, 96, 1, 13, 3, 36, 
    9, 83, 5, 46, 4, 11, 2, 31, 6, 31, 7, 18, 0, 16, 8,  8, 3, 60, 1, 43, 
    2, 78, 4,  8, 8, 84, 3, 97, 0, 78, 9, 78, 7, 71, 1, 74, 6,  3, 5, 99, 
    9, 92, 8, 43, 6, 20, 3, 92, 2, 67, 1, 84, 5, 15, 4, 12, 0, 47, 7, 46, 
    7,  5, 8, 95, 3, 12, 4, 16, 6, 56, 5, 90, 9, 64, 1, 62, 2, 32, 0, 72, 
    8, 21, 9, 56, 7, 91, 4, 12, 3, 49, 6, 92, 0, 44, 5, 37, 2, 57, 1, 68, 
    1,  9, 4, 55, 2, 41, 9, 11, 7, 62, 0, 99, 5, 80, 8,  1, 6, 60, 3, 45, 
    2, 32, 9, 35, 4, 93, 5, 88, 1, 24, 7, 76, 8, 37, 0, 53, 6,  3, 3, 41
  };
  const int r818[] = {
    10, 10, // Number of jobs and machines
    7, 82, 3,  5, 4, 82, 6, 68, 5, 51, 1, 27, 9, 55, 2, 29, 8, 88, 0, 93, 
    7, 28, 4, 62, 9, 97, 6, 21, 8, 81, 2, 10, 0, 39, 1, 54, 5, 65, 3, 24, 
    5, 84, 9, 89, 2, 86, 4, 32, 8, 27, 6, 44, 1, 80, 3,  6, 0,  1, 7, 74, 
    0, 50, 1, 98, 6, 37, 4, 71, 9,  7, 3, 70, 5, 21, 8, 35, 2, 42, 7, 43, 
    5, 63, 1, 68, 6, 51, 7, 58, 3,  1, 8, 74, 2, 20, 0, 75, 4, 41, 9,  4, 
    0, 67, 2, 93, 3, 11, 5, 50, 6, 32, 9, 72, 7, 38, 4, 95, 8, 79, 1, 12, 
    7, 12, 3, 79, 0, 52, 9, 95, 4, 60, 2, 40, 5, 94, 8, 73, 1, 80, 6, 60, 
    4, 80, 5, 25, 3, 32, 0, 19, 2, 53, 1, 75, 6, 59, 8, 12, 7,  5, 9, 81, 
    0, 85, 4, 69, 3, 78, 5, 55, 7, 86, 2, 68, 8, 39, 9, 59, 1, 10, 6, 85, 
    9, 16, 2,  8, 7,  9, 5, 74, 4, 54, 6, 81, 8,  3, 1, 67, 3, 66, 0, 71
  };
  const int r819[] = {
    10, 10, // Number of jobs and machines
    1, 89, 5, 63, 0, 14, 9, 90, 2, 79, 8, 98, 6, 57, 4, 24, 3, 19, 7, 13, 
    0, 98, 3, 80, 4, 55, 6, 23, 9, 93, 7, 91, 5, 23, 8,  5, 2, 49, 1, 97, 
    0,  7, 2, 29, 1, 73, 9, 99, 6, 96, 4, 31, 5, 39, 8, 95, 3, 65, 7, 18, 
    5,  4, 3,  6, 6, 65, 7,  5, 9, 55, 1, 46, 4, 11, 0, 52, 8, 60, 2, 97, 
    7, 64, 2, 26, 6, 45, 8, 61, 4, 62, 0, 21, 5, 59, 1, 82, 9, 68, 3, 37, 
    4, 52, 8, 47, 3, 50, 2, 91, 9, 57, 5, 19, 0, 31, 1, 67, 6, 21, 7, 50, 
    7, 40, 9, 48, 3, 14, 1, 67, 0,  5, 8, 16, 2,  4, 5, 96, 4, 50, 6, 77, 
    4, 91, 9, 17, 8, 45, 0, 84, 2, 82, 1, 12, 7,  1, 3, 64, 5, 82, 6, 64, 
    1, 22, 8, 79, 5, 98, 4, 47, 6,  2, 0, 75, 9, 29, 3,  3, 2, 65, 7, 97, 
    9, 11, 0,  3, 7, 27, 8, 92, 5, 23, 6, 22, 2, 68, 4, 58, 1, 72, 3, 89
  };
  const int r820[] = {
    10, 10, // Number of jobs and machines
    8, 87, 2, 88, 4, 26, 6, 50, 9, 58, 0, 47, 1, 65, 5, 14, 3, 85, 7, 16, 
    8, 62, 5, 17, 6, 93, 4, 95, 9, 76, 3, 91, 7, 14, 0, 88, 1, 97, 2, 29, 
    8, 14, 1, 42, 7, 38, 3,  8, 4, 40, 9, 81, 5, 84, 0, 44, 6, 57, 2, 56, 
    7, 20, 1, 28, 4, 11, 0, 48, 8,  6, 9, 98, 3, 27, 6, 21, 2, 92, 5, 16, 
    9, 79, 0, 94, 3, 60, 1, 31, 7, 15, 2, 69, 4, 51, 5, 61, 8, 31, 6, 39, 
    5,  2, 8, 33, 0, 72, 7, 45, 1, 84, 9, 30, 6,  7, 3, 66, 2, 86, 4, 82, 
    3, 73, 5, 30, 2, 45, 7, 40, 4, 22, 8, 65, 1, 36, 0, 46, 6, 62, 9, 16, 
    3, 36, 2, 85, 7, 92, 1, 40, 5, 38, 9, 38, 4, 29, 8, 24, 6, 18, 0, 63, 
    6, 68, 2, 64, 8, 76, 7, 77, 5, 93, 1, 47, 9, 91, 3, 80, 4, 75, 0, 96, 
    5,  7, 9, 35, 6, 93, 7, 13, 3, 91, 2, 47, 4, 37, 1,  7, 8, 47, 0, 44
  };
  const int r821[] = {
    10, 10, // Number of jobs and machines
    6, 84, 5, 37, 9, 31, 4, 76, 3, 29, 1, 44, 2, 57, 0, 89, 7, 68, 8, 16, 
    3, 19, 1, 26, 6, 23, 5, 35, 7, 18, 0, 14, 9, 28, 8, 26, 2, 97, 4, 37, 
    3,  1, 4, 28, 1, 58, 6, 78, 9, 17, 7, 88, 5, 56, 0,  3, 2, 72, 8, 15, 
    2, 84, 9, 81, 6, 67, 4,  1, 3, 10, 1, 74, 0, 38, 5, 47, 7, 72, 8, 80, 
    8, 80, 3,  4, 0, 45, 4, 26, 7, 47, 5, 70, 2, 32, 9, 87, 6, 39, 1, 51, 
    2, 22, 8, 55, 5, 33, 4, 81, 9, 62, 7, 18, 6, 81, 3, 41, 1, 57, 0,  9, 
    9, 36, 5, 95, 4, 18, 7, 93, 8, 39, 2,  4, 0, 99, 1, 71, 6, 40, 3, 79, 
    1, 75, 3, 35, 9, 37, 8,  3, 7, 82, 4, 83, 0, 36, 6, 48, 5, 22, 2, 28, 
    8, 22, 0, 69, 5, 65, 2,  8, 6, 52, 3, 13, 9, 92, 7, 94, 4, 13, 1, 17, 
    5, 49, 1, 25, 8, 44, 0, 11, 4,  9, 2, 63, 6, 44, 9, 81, 3, 99, 7, 70
  };
  const int r822[] = {
    10, 10, // Number of jobs and machines
    0, 59, 8, 63, 1, 34, 2, 23, 6, 43, 4, 33, 9, 10, 3,  9, 5, 93, 7, 41, 
    9, 63, 0, 94, 1, 67, 4, 58, 8, 82, 2, 55, 5, 71, 3,  5, 7, 53, 6, 33, 
    0, 63, 4, 22, 9, 46, 2,  9, 7, 76, 6, 68, 3, 78, 1, 60, 8, 56, 5, 22, 
    3, 31, 7, 13, 9,  6, 1, 39, 4, 34, 6, 23, 5, 63, 2, 56, 8, 93, 0, 26, 
    9, 98, 3, 28, 4, 32, 5, 12, 7, 47, 8, 64, 6, 50, 0, 94, 2, 33, 1, 99, 
    1, 85, 7, 99, 2, 64, 6, 48, 9, 86, 3, 68, 5, 27, 0, 71, 4, 64, 8, 77, 
    4, 31, 5, 51, 7, 26, 8, 87, 1, 44, 0, 57, 3, 96, 2, 37, 6, 90, 9, 53, 
    0, 27, 4, 49, 2, 22, 8, 91, 6, 55, 3, 11, 1,  8, 9, 53, 5,  1, 7, 98, 
    3, 98, 4,  4, 0, 89, 7, 68, 9, 85, 8, 70, 6, 27, 2, 74, 1, 82, 5, 90, 
    0, 36, 7, 44, 5, 99, 3, 51, 4, 56, 9, 98, 6, 57, 1, 41, 2, 53, 8, 31
  };
  const int r823[] = {
    10, 10, // Number of jobs and machines
    9, 39, 5, 13, 4, 26, 6, 74, 1,  7, 2, 22, 8,  2, 3, 42, 7, 79, 0, 17, 
    0, 85, 4, 67, 2, 54, 7, 46, 8, 15, 6,  4, 5,  9, 3, 87, 9, 40, 1,  4, 
    6, 94, 0,  6, 4,  2, 3, 82, 9, 18, 2, 45, 7, 71, 8, 47, 1, 76, 5, 35, 
    3, 32, 8, 39, 6, 89, 7, 25, 4, 71, 9,  4, 5, 39, 2, 69, 1, 74, 0, 81, 
    9, 50, 3,  5, 7, 77, 1, 96, 8,  6, 0, 82, 2, 16, 4, 61, 6, 23, 5, 82, 
    9,  6, 8, 76, 2, 36, 6, 63, 5, 88, 0, 25, 3, 12, 4, 61, 7,  3, 1,  5, 
    0, 25, 8, 30, 2,  5, 3, 18, 1, 82, 6, 65, 5, 77, 7, 34, 4, 35, 9, 20, 
    8, 81, 7, 24, 6, 68, 9, 38, 1, 74, 3, 31, 2, 83, 5,  4, 4, 34, 0, 90, 
    0, 72, 3, 24, 5, 39, 4, 53, 2, 55, 1, 34, 6, 99, 8, 27, 9, 19, 7, 91, 
    1, 69, 8, 49, 9, 56, 7, 35, 0, 24, 2, 15, 4, 60, 3, 94, 6, 68, 5, 64
  };
  const int r824[] = {
    10, 10, // Number of jobs and machines
    0, 67, 5, 68, 4, 81, 6, 21, 1,  6, 9, 25, 7, 99, 8, 49, 3, 25, 2, 41, 
    6,  1, 8, 88, 0, 18, 9, 93, 5,  1, 4, 45, 7,  2, 1, 66, 2, 12, 3, 24, 
    0, 47, 7, 91, 8, 66, 9, 78, 3,  3, 4, 34, 2, 35, 6, 76, 5, 53, 1, 84, 
    2, 60, 1, 11, 3, 73, 6, 46, 8, 40, 5,  7, 9, 40, 7, 29, 0, 38, 4, 51, 
    3, 99, 9, 21, 0, 43, 1, 19, 8, 30, 6, 13, 7, 88, 5, 54, 2, 69, 4, 53, 
    8,  6, 4, 15, 7,  8, 6, 58, 9, 29, 2, 52, 3, 80, 5, 18, 0, 81, 1, 75, 
    5,  2, 1, 11, 6,  7, 7, 37, 4, 83, 9,  9, 8, 59, 3, 72, 0, 19, 2, 59, 
    0, 67, 8, 68, 6, 44, 1, 46, 4, 48, 3, 11, 2, 84, 5, 30, 7, 81, 9, 18, 
    2, 99, 3, 73, 1, 10, 9,  5, 8, 57, 5, 45, 7, 27, 6, 13, 4, 73, 0, 62, 
    5, 82, 0, 17, 9, 99, 8, 82, 4, 76, 7, 42, 2, 70, 3, 90, 1, 22, 6, 78
  };
  const int r825[] = {
    10, 10, // Number of jobs and machines
    7, 33, 9, 40, 2, 75, 0, 72, 4, 51, 8, 98, 6, 71, 3, 74, 5,  7, 1, 64, 
    7, 69, 0, 83, 1, 19, 9, 91, 6, 94, 4,  8, 2, 76, 8, 71, 3,  7, 5, 91, 
    6, 91, 5, 46, 0, 45, 8, 22, 7, 23, 3, 48, 4, 42, 2, 49, 9, 45, 1, 92, 
    4, 25, 8, 69, 6, 36, 5,  4, 3, 53, 9, 89, 2, 18, 7, 93, 0, 67, 1,  6, 
    8, 82, 5, 30, 7, 16, 1, 47, 9, 52, 3, 47, 4, 37, 6, 47, 2, 38, 0,  8, 
    2, 82, 5, 86, 6, 31, 1, 60, 9, 55, 7,  8, 3, 34, 8,  3, 0, 57, 4, 93, 
    2, 14, 1, 99, 6, 18, 7, 78, 9, 68, 3, 80, 8, 99, 5, 36, 0, 94, 4, 37, 
    4, 84, 7, 93, 8, 94, 5, 40, 6, 33, 2, 32, 0, 92, 1, 52, 9,  2, 3, 21, 
    7, 12, 6, 34, 8, 36, 9, 37, 5, 74, 1, 92, 3, 30, 0, 44, 2, 89, 4, 39, 
    5, 79, 8, 42, 4,  4, 7, 64, 2, 39, 1, 32, 6, 77, 9, 23, 3, 23, 0, 92
  };
  const int r826[] = {
    10, 10, // Number of jobs and machines
    4, 56, 5, 72, 8, 47, 7, 61, 9, 36, 1, 73, 3, 64, 2, 14, 6,  1, 0,  9, 
    2, 95, 5, 46, 8,  3, 9, 22, 7, 78, 6, 97, 0, 56, 1, 26, 3, 14, 4, 65, 
    1, 69, 7, 25, 9, 87, 6, 42, 4, 13, 5, 26, 0, 29, 2, 43, 3, 12, 8, 37, 
    8, 12, 7, 25, 5, 67, 9,  3, 1, 25, 4, 51, 3, 49, 0, 95, 2, 93, 6, 24, 
    7, 51, 8, 21, 5, 31, 2, 68, 0, 14, 3, 45, 6,  5, 1, 46, 4, 56, 9, 75, 
    7, 27, 1, 52, 2, 77, 3, 44, 0, 50, 6, 47, 5, 94, 8, 24, 9, 14, 4, 10, 
    4,  2, 9, 47, 8, 63, 1, 13, 7, 52, 5, 15, 0, 99, 2, 11, 3, 89, 6, 49, 
    7, 93, 3, 33, 1, 19, 9, 17, 2, 85, 5,  7, 8, 34, 0, 28, 4, 88, 6, 10, 
    0, 41, 9, 57, 1, 66, 6, 55, 3, 86, 4, 47, 8, 57, 5, 31, 2, 99, 7, 64, 
    0, 60, 4, 43, 8, 70, 1,  9, 9, 70, 7, 89, 2, 74, 5, 74, 3, 46, 6,  8
  };
  const int r827[] = {
    10, 10, // Number of jobs and machines
    6, 43, 0, 40, 9, 97, 8, 39, 3, 24, 7, 18, 4, 54, 1, 39, 2, 28, 5, 10, 
    1,  2, 5, 16, 6,  4, 8, 42, 2, 37, 4, 66, 9, 23, 3, 89, 7, 24, 0, 27, 
    6, 49, 2, 85, 8, 22, 1, 59, 9, 13, 0, 27, 3,  2, 4, 24, 5, 85, 7, 96, 
    4, 57, 0, 33, 3, 81, 8, 93, 7, 66, 1, 59, 6, 74, 5, 63, 9, 40, 2, 99, 
    5,  8, 6, 60, 3, 53, 0, 49, 4, 48, 9, 68, 7, 80, 1, 33, 2, 77, 8, 74, 
    4,  2, 0, 27, 2, 36, 9, 28, 5, 31, 7, 65, 6, 20, 8, 99, 3, 81, 1, 34, 
    6, 21, 5, 21, 8, 17, 4, 67, 0, 33, 7, 45, 2, 28, 1, 83, 9, 42, 3,  1, 
    1, 16, 0, 35, 3, 41, 6, 76, 4, 97, 8, 56, 2, 89, 5, 39, 9, 17, 7, 50, 
    7, 11, 1, 80, 5, 75, 0, 27, 6, 52, 2,  5, 3, 18, 9, 99, 4, 42, 8, 90, 
    8, 57, 1, 59, 7, 82, 4, 75, 6,  3, 5,  2, 9, 79, 0, 69, 3, 80, 2, 52
  };
  const int r828[] = {
    10, 10, // Number of jobs and machines
    7, 57, 3,  6, 0, 47, 2, 90, 9, 86, 8, 64, 5, 26, 1, 29, 4, 99, 6, 21, 
    3, 16, 4, 45, 5,  5, 1, 30, 7, 22, 8, 86, 2, 56, 0,  2, 9, 81, 6, 24, 
    6, 82, 9, 86, 8,  8, 3, 67, 2, 78, 5, 85, 1, 73, 0, 74, 7, 28, 4, 69, 
    6, 79, 2, 58, 3, 30, 0, 64, 5, 24, 9, 19, 7, 73, 8, 86, 4, 14, 1, 60, 
    2, 56, 0, 74, 4, 33, 1, 11, 7, 87, 6, 17, 5, 41, 3, 51, 9, 27, 8, 15, 
    2, 45, 8, 91, 3,  9, 6, 54, 7, 85, 5, 68, 9, 49, 0, 21, 1, 76, 4, 55, 
    8, 82, 9, 24, 1, 47, 2, 94, 4, 91, 5,  2, 7, 61, 0, 44, 3,  3, 6, 30, 
    1, 75, 7,  3, 9, 73, 3, 21, 5, 35, 4, 90, 0, 15, 2, 65, 6, 53, 8, 20, 
    0, 70, 1, 19, 3, 73, 5, 83, 4, 59, 2, 88, 6, 33, 8, 65, 7, 17, 9, 40, 
    6, 88, 9, 49, 5, 90, 0, 88, 3, 95, 1, 27, 4, 10, 8, 65, 2, 45, 7, 97
  };
  const int r829[] = {
    10, 10, // Number of jobs and machines
    3,  1, 5, 48, 0,  3, 8, 54, 2, 70, 1, 45, 7, 95, 9, 82, 6, 90, 4, 14, 
    2, 35, 7, 13, 5, 64, 9, 43, 0, 63, 4, 96, 8,  4, 6, 34, 1, 39, 3,  8, 
    3, 27, 0,  3, 2, 66, 6, 53, 9, 90, 5, 22, 1, 66, 8, 32, 7, 17, 4, 56, 
    4, 56, 0, 51, 1, 64, 3,  5, 6, 50, 5, 63, 2,  6, 7, 64, 8, 82, 9, 77, 
    8, 43, 4, 23, 6, 63, 1, 57, 5, 43, 3, 21, 2, 52, 7, 30, 0,  9, 9, 17, 
    7, 43, 3, 87, 0, 80, 9, 56, 5, 79, 2, 34, 4, 52, 8, 87, 1, 62, 6, 57, 
    2, 23, 1, 22, 3, 38, 6, 84, 8, 21, 4, 78, 0, 68, 7, 69, 5, 28, 9, 77, 
    5, 80, 9, 59, 2, 19, 4, 69, 6, 29, 8, 35, 0, 66, 1, 58, 7, 17, 3, 67, 
    0, 82, 3, 63, 5, 94, 7, 58, 8, 45, 9,  9, 4, 27, 1, 90, 2, 16, 6, 72, 
    7, 76, 0,  6, 4, 87, 8, 97, 6,  5, 5, 87, 3, 31, 2, 53, 9, 91, 1, 63
  };
  const int r830[] = {
    10, 10, // Number of jobs and machines
    4, 18, 2, 31, 9, 55, 8, 41, 7, 20, 1, 19, 5, 95, 6, 82, 0, 13, 3, 52, 
    8, 71, 1, 47, 0, 57, 2, 72, 5, 56, 3, 43, 6, 60, 4, 17, 9, 87, 7, 29, 
    7, 77, 2, 40, 6, 62, 9, 15, 0, 83, 8, 43, 5, 99, 1, 13, 3, 38, 4, 20, 
    3, 21, 2, 36, 8, 31, 7, 43, 0, 34, 9, 35, 5, 46, 4, 85, 6, 89, 1,  4, 
    8, 38, 3, 48, 9, 73, 2, 64, 1,  6, 4, 80, 5, 46, 0, 38, 7, 20, 6, 48, 
    0, 80, 7, 95, 9, 38, 5,  1, 3, 28, 8, 63, 4, 56, 6,  6, 1, 44, 2, 65, 
    2, 68, 5,  8, 9, 86, 8, 28, 4, 10, 0, 79, 3, 66, 6, 29, 7, 31, 1, 43, 
    3, 97, 0, 67, 6, 48, 5, 60, 2, 55, 8, 75, 1, 31, 7, 40, 4, 47, 9, 78, 
    6, 56, 8, 66, 3, 81, 5, 69, 7, 50, 0, 66, 1, 19, 2, 31, 4, 21, 9, 56, 
    5, 12, 8, 18, 9, 38, 4, 79, 3, 40, 2,  4, 7, 69, 0, 27, 6, 49, 1, 45
  };
  const int r831[] = {
    10, 10, // Number of jobs and machines
    4, 54, 0, 55, 1, 10, 7, 75, 5, 44, 3, 44, 8, 15, 9, 84, 2, 67, 6, 30, 
    4, 83, 1, 88, 2, 88, 9, 19, 0, 29, 6, 38, 7, 97, 8, 80, 5, 30, 3, 52, 
    0,  2, 1, 90, 2, 85, 5, 37, 6, 46, 4, 30, 7,  6, 3, 58, 8, 15, 9,  9, 
    8, 47, 3, 47, 5, 41, 7, 89, 6, 14, 1, 77, 2, 14, 9,  4, 4, 85, 0, 46, 
    9, 99, 7, 49, 0,  8, 5, 45, 6, 92, 3, 86, 4, 78, 2, 52, 8, 82, 1, 33, 
    9,  1, 4, 24, 1, 76, 6, 65, 2, 46, 3, 84, 8,  9, 5,  6, 7, 13, 0, 77, 
    9, 83, 7, 68, 4, 40, 5, 72, 8, 77, 3, 37, 1, 16, 2, 75, 0, 27, 6, 37, 
    3, 69, 0, 30, 7, 95, 8, 49, 6, 91, 5, 96, 1, 37, 4, 45, 9, 29, 2, 36, 
    5, 56, 8, 55, 9, 54, 6, 92, 0, 13, 2, 61, 1,  1, 3,  8, 7, 82, 4,  8, 
    1, 13, 2, 69, 4, 74, 6, 33, 7, 32, 3, 75, 8,  8, 5, 68, 9, 37, 0, 48
  };
  const int r832[] = {
    10, 10, // Number of jobs and machines
    4, 74, 6, 73, 7, 26, 0, 50, 3, 21, 8,  5, 5, 35, 9, 64, 1, 17, 2, 21, 
    7, 33, 5, 88, 8, 73, 0, 80, 4, 77, 2, 48, 1, 46, 9, 68, 3, 68, 6, 39, 
    3, 86, 0, 76, 2, 35, 4, 14, 8, 59, 6, 43, 9, 89, 5, 19, 7, 30, 1, 38, 
    3, 50, 7,  8, 0,  4, 9, 11, 8, 89, 5, 91, 1, 81, 4,  6, 2, 49, 6, 95, 
    1, 40, 5, 42, 4, 26, 3, 95, 2, 18, 0, 72, 8, 33, 6, 93, 7,  1, 9, 51, 
    9, 35, 7, 96, 5, 94, 4, 75, 8, 58, 6,  6, 1, 79, 2, 65, 3, 67, 0, 31, 
    9, 23, 8, 83, 1,  1, 6, 35, 4, 14, 5, 17, 0,  3, 7, 68, 3, 10, 2, 74, 
    9, 56, 6, 50, 1, 72, 3, 82, 7, 36, 0,  1, 5, 30, 4, 48, 8,  9, 2, 40, 
    2, 75, 9, 39, 3, 26, 8, 30, 1, 16, 5, 29, 6, 96, 0, 50, 7,  8, 4, 47, 
    6,  5, 1,  6, 2, 46, 0, 54, 9, 24, 4, 76, 8, 98, 5, 23, 3, 27, 7,  9
  };
  const int r833[] = {
    10, 10, // Number of jobs and machines
    7, 96, 4, 61, 9, 42, 6, 98, 2, 40, 5,  4, 8, 25, 3,  4, 0, 16, 1,  7, 
    9, 31, 0,  1, 1, 39, 3, 26, 4, 56, 8, 98, 6, 44, 5, 88, 7, 55, 2, 36, 
    5, 93, 1, 11, 2, 57, 9, 41, 0, 77, 6, 82, 3, 72, 7, 79, 4, 50, 8, 13, 
    1, 65, 2, 31, 8, 18, 3, 39, 4, 26, 6, 45, 0, 94, 7, 21, 9, 23, 5, 84, 
    5, 40, 1, 47, 4, 43, 2, 86, 9, 51, 0, 11, 7, 12, 3,  4, 8, 89, 6, 47, 
    8, 46, 7, 48, 4, 73, 3, 68, 1, 50, 0, 27, 6, 96, 9, 84, 5, 72, 2, 95, 
    5, 60, 7, 50, 9, 24, 1, 30, 0, 23, 6, 18, 3, 45, 8,  3, 2, 18, 4, 10, 
    8, 30, 1,  7, 0, 83, 3, 34, 5,  3, 9, 19, 4, 51, 7, 85, 2, 59, 6, 31, 
    5, 96, 9, 63, 8, 57, 3, 39, 0, 11, 6,  2, 2, 84, 4, 51, 7, 15, 1, 74, 
    4, 18, 3, 68, 8, 37, 5,  1, 7, 69, 1,  6, 6, 13, 9, 31, 0, 79, 2, 46
  };
  const int r834[] = {
    10, 10, // Number of jobs and machines
    7, 95, 5, 50, 9, 68, 3, 25, 6, 52, 2, 47, 4, 70, 0, 51, 1, 87, 8, 33, 
    2, 41, 0, 44, 3, 28, 4, 57, 8, 51, 7, 71, 6,  4, 1, 49, 5, 60, 9, 25, 
    5, 65, 2, 36, 3, 61, 0,  4, 8, 46, 9,  2, 7,  4, 6, 58, 1,  6, 4, 64, 
    4, 50, 3, 28, 9, 81, 5, 73, 0, 49, 7, 22, 6, 10, 2, 76, 1, 74, 8, 50, 
    7,  7, 9,  9, 1,  4, 6, 90, 2, 39, 4, 52, 0, 51, 8, 85, 3, 26, 5, 21, 
    5, 93, 9, 18, 8, 71, 3, 98, 1, 70, 0, 50, 4, 38, 2, 25, 7,  7, 6, 18, 
    7, 50, 9, 65, 2, 54, 4, 54, 6, 91, 8, 43, 0,  8, 5, 66, 3, 74, 1, 54, 
    7, 85, 1, 91, 6,  5, 0, 68, 5, 47, 8, 77, 4, 67, 9, 50, 2, 81, 3, 28, 
    8, 93, 6, 96, 9, 86, 5,  1, 4, 52, 0, 68, 2,  2, 3,  1, 1, 89, 7, 40, 
    0, 27, 8, 36, 9, 16, 2, 76, 4, 63, 7, 53, 5, 65, 1, 31, 6, 55, 3, 80
  };
  const int r835[] = {
    10, 10, // Number of jobs and machines
    3, 82, 9, 45, 5, 81, 6, 63, 0, 18, 7, 24, 2, 42, 8, 73, 1, 24, 4, 23, 
    5, 10, 2, 12, 8, 52, 3, 89, 4, 25, 6, 27, 0, 97, 1, 51, 7, 26, 9, 95, 
    6, 54, 1, 32, 8, 65, 3, 92, 4, 14, 5, 81, 9, 20, 2, 32, 7,  8, 0, 82, 
    7,  2, 9, 87, 1, 24, 6, 63, 4, 19, 8, 50, 3, 24, 0, 65, 2, 89, 5, 20, 
    5, 78, 1, 26, 9, 90, 2, 26, 0, 67, 3, 49, 8, 34, 4, 56, 6, 76, 7,  3, 
    5, 22, 8,  3, 6, 73, 1, 24, 0, 21, 3, 10, 7, 66, 9, 95, 2,  1, 4, 21, 
    6, 13, 8, 83, 2, 34, 0, 65, 7, 34, 9, 69, 4, 45, 3, 61, 1, 51, 5, 33, 
    9, 83, 7,  4, 6, 90, 5,  8, 0, 12, 2, 30, 4, 40, 1, 24, 8, 18, 3,  1, 
    5, 48, 4, 94, 8, 32, 3, 73, 0, 76, 1, 78, 9, 26, 7, 83, 2, 12, 6, 41, 
    1, 43, 8, 48, 9, 62, 0, 75, 6, 92, 7,  9, 4, 28, 2, 16, 3, 12, 5,  5
  };
  const int r836[] = {
    10, 10, // Number of jobs and machines
    1, 38, 4, 99, 2, 11, 3, 63, 0, 60, 9, 95, 8, 59, 5, 23, 6, 68, 7, 74, 
    0, 95, 3, 55, 8, 16, 2,  2, 5, 42, 1,  7, 4, 21, 7, 85, 9, 39, 6,  7, 
    1, 82, 8,  2, 7, 69, 9, 75, 0, 52, 5, 55, 6, 93, 4, 31, 2,  9, 3, 62, 
    6, 37, 5, 86, 1, 84, 8, 23, 9, 87, 7, 15, 2, 98, 3, 82, 0, 88, 4, 18, 
    2, 18, 5, 83, 6, 16, 0, 48, 9,  6, 4, 66, 7, 39, 3, 36, 8, 27, 1, 12, 
    1, 86, 4, 72, 3,  9, 0, 41, 2,  2, 9, 41, 5, 69, 7, 50, 8, 12, 6, 31, 
    3,  8, 9, 61, 8, 51, 5, 35, 2, 20, 7, 79, 0, 11, 1, 52, 4, 79, 6, 73, 
    3, 49, 7, 56, 6, 61, 2, 53, 9, 93, 4,  2, 5, 97, 0, 22, 8, 78, 1, 28, 
    9, 14, 2,  1, 4, 67, 3, 85, 7, 57, 8, 62, 5, 52, 0, 26, 6, 46, 1, 92, 
    1, 37, 6, 68, 8, 78, 3,  4, 7, 96, 4, 83, 9, 60, 0, 59, 5, 68, 2, 32
  };
  const int r837[] = {
    10, 10, // Number of jobs and machines
    4, 90, 2, 48, 5, 98, 1, 23, 7, 86, 9, 52, 6, 52, 0, 26, 8, 78, 3,  5, 
    8, 92, 9, 98, 3,  9, 6, 66, 0, 48, 7, 54, 2, 76, 4, 42, 5, 31, 1, 99, 
    2, 70, 6, 58, 1, 55, 0, 50, 3, 26, 8, 82, 5, 26, 7, 82, 4, 57, 9, 55, 
    2, 90, 1, 60, 3, 74, 8, 57, 6, 41, 9, 62, 4, 21, 5, 59, 7, 93, 0, 44, 
    4, 39, 8, 86, 7, 51, 3, 19, 5,  3, 0, 82, 1, 32, 6, 21, 2, 39, 9, 20, 
    6, 86, 4, 19, 3, 16, 1, 12, 5, 14, 9, 78, 8, 11, 2, 39, 7, 27, 0, 71, 
    8, 64, 0, 59, 2, 77, 4, 32, 6, 13, 7, 59, 1, 46, 3, 46, 5, 41, 9, 97, 
    9, 82, 2, 31, 7, 72, 3, 97, 4, 24, 1, 16, 0, 93, 8, 99, 5, 52, 6, 68, 
    6, 54, 8, 37, 0, 43, 9, 81, 7, 19, 1, 12, 3,  9, 2, 63, 4, 94, 5,  9, 
    8, 47, 6,  3, 9, 88, 7, 80, 3, 56, 4, 49, 1,  1, 5, 77, 2, 39, 0, 62
  };
  const int r838[] = {
    10, 10, // Number of jobs and machines
    0, 94, 6, 51, 1, 57, 9, 83, 7, 46, 2, 15, 5, 35, 4, 56, 8, 38, 3, 40, 
    6, 34, 2, 87, 0,  8, 4, 69, 1, 59, 8, 14, 7, 18, 3, 22, 9, 55, 5,  2, 
    4, 51, 5, 72, 2, 64, 0, 20, 3, 60, 9, 67, 1, 92, 8, 47, 6, 17, 7, 48, 
    1, 48, 0, 79, 4, 32, 6, 30, 2, 19, 8, 80, 7, 28, 5, 33, 3,  6, 9, 44, 
    4,  9, 1, 29, 7, 90, 9, 38, 6, 38, 8, 93, 0, 94, 5, 67, 3, 29, 2, 69, 
    0, 80, 8, 25, 7, 23, 2,  9, 9, 71, 4, 92, 6, 40, 5, 25, 1, 10, 3, 31, 
    5, 13, 2, 28, 0, 19, 3,  8, 9, 86, 1,  2, 7, 18, 8, 95, 4, 23, 6, 83, 
    3, 66, 0, 32, 6, 42, 9, 62, 7, 37, 4, 73, 1, 23, 8, 92, 5, 37, 2, 70, 
    0, 45, 9,  8, 8, 44, 2, 82, 5, 95, 3, 18, 1, 77, 4,  1, 7, 53, 6,  5, 
    2, 42, 7, 25, 1, 12, 5, 81, 0, 52, 3,  6, 6, 95, 4,  5, 8, 38, 9, 70
  };
  const int r839[] = {
    10, 10, // Number of jobs and machines
    2, 35, 7, 32, 9, 47, 5, 67, 6,  9, 0, 77, 3, 20, 4, 31, 1, 37, 8, 72, 
    9, 79, 0, 97, 5, 51, 3, 33, 4, 39, 8,  4, 7, 85, 2, 52, 6, 72, 1, 69, 
    0, 64, 3, 58, 9, 70, 6, 41, 2,  7, 5, 29, 8, 72, 1, 46, 4, 66, 7, 78, 
    1, 75, 7, 93, 4, 45, 6, 77, 3, 64, 5,  2, 2, 91, 8, 92, 9, 61, 0, 94, 
    4, 12, 6,  9, 2, 67, 5, 62, 0, 43, 1,  4, 9, 55, 3, 31, 8, 87, 7, 97, 
    4, 48, 8, 74, 2, 26, 9, 89, 1, 97, 5, 30, 6, 17, 3, 13, 0, 36, 7, 62, 
    6,  5, 0, 27, 2, 18, 1, 45, 9, 72, 4, 15, 3,  9, 5, 62, 7, 99, 8, 49, 
    7, 15, 0, 75, 3, 57, 2, 24, 1, 60, 5, 79, 9,  8, 4, 30, 8, 41, 6,  7, 
    2, 90, 6, 52, 7, 36, 3, 31, 1, 80, 9, 80, 4,  3, 5, 22, 0,  5, 8, 64, 
    3, 12, 1,  4, 8, 50, 4, 51, 7,  5, 5, 31, 6, 30, 2, 16, 9, 69, 0, 19
  };
  const int r840[] = {
    10, 10, // Number of jobs and machines
    6, 66, 8, 22, 4, 24, 1, 40, 0,  9, 7, 36, 2, 36, 5,  1, 9, 63, 3,  2, 
    9, 25, 3, 51, 1, 64, 2,  3, 8, 43, 6, 89, 4, 92, 0, 51, 5, 63, 7, 79, 
    7, 82, 5, 43, 1, 68, 2, 84, 4,  5, 3, 27, 0, 72, 9, 87, 6, 22, 8, 81, 
    8, 98, 0, 11, 1, 12, 3, 98, 2, 91, 7, 58, 9, 18, 4, 25, 6,  4, 5, 93, 
    0, 12, 5, 44, 9, 32, 6, 43, 8, 88, 3, 80, 2, 22, 7, 64, 4, 45, 1,  9, 
    0, 78, 1, 16, 7, 16, 8, 14, 5,  8, 4, 63, 2, 20, 9, 48, 6, 63, 3, 39, 
    3, 57, 0, 80, 6, 94, 1,  6, 7, 56, 4, 61, 5, 32, 9, 71, 8, 61, 2, 88, 
    7, 77, 9, 67, 2, 96, 3,  6, 4, 17, 0, 67, 6, 41, 8, 88, 1, 34, 5, 86, 
    2, 17, 6, 33, 8, 81, 5, 52, 3, 74, 7, 93, 9, 15, 1,  5, 0, 23, 4, 79, 
    6, 38, 2, 92, 3,  3, 0, 88, 8, 29, 5, 41, 7, 61, 1, 30, 9,  1, 4,  4
  };
  const int r841[] = {
    10, 10, // Number of jobs and machines
    4, 14, 8, 70, 6, 37, 1, 54, 5, 77, 0, 94, 3, 91, 7, 25, 2, 72, 9,  1, 
    1, 52, 4, 61, 3,  8, 8, 25, 9, 85, 5, 30, 2, 77, 7, 59, 0, 56, 6, 86, 
    1, 92, 3, 76, 0, 12, 5, 61, 4, 41, 2, 17, 8, 53, 6, 40, 9, 42, 7, 18, 
    0, 45, 8, 21, 9, 59, 7, 99, 5, 17, 6, 72, 2, 44, 1, 94, 3, 84, 4, 17, 
    5,  9, 1, 40, 4, 55, 6, 76, 7, 52, 8, 80, 9, 52, 3, 49, 2, 65, 0, 24, 
    7, 90, 4, 99, 6, 22, 3, 37, 9, 99, 8, 57, 0, 82, 2,  6, 1, 16, 5, 42, 
    6, 31, 8,  8, 7, 60, 3, 27, 4,  5, 2, 51, 0, 53, 1, 79, 9, 92, 5, 27, 
    4, 48, 6, 10, 5, 90, 9, 94, 8, 36, 7, 67, 1,  8, 2, 59, 0, 96, 3, 16, 
    1, 10, 6, 38, 3, 96, 2, 93, 9, 48, 0, 77, 4, 39, 8, 16, 5, 41, 7, 84, 
    2, 58, 5, 78, 9, 58, 6, 94, 4, 26, 3, 51, 7, 75, 0, 68, 1, 47, 8, 74
  };
  const int r842[] = {
    10, 10, // Number of jobs and machines
    5, 68, 7, 34, 1, 35, 3, 26, 9, 60, 4, 76, 6,  1, 8, 29, 2, 26, 0, 50, 
    7, 22, 6, 11, 0, 53, 3, 85, 1, 16, 9, 94, 5, 54, 2,  3, 4, 62, 8, 15, 
    3, 32, 9, 24, 1, 89, 5, 36, 0, 11, 4, 19, 2, 31, 6, 48, 8,  2, 7, 64, 
    2, 21, 3, 23, 6,  7, 0, 42, 5, 76, 9,  4, 7,  2, 8, 37, 1, 62, 4, 95, 
    9, 57, 1, 38, 4, 69, 2, 97, 6, 26, 0, 21, 8, 15, 7, 12, 3, 77, 5, 82, 
    9, 38, 5,  1, 7, 39, 8, 11, 4, 69, 3, 55, 1,  4, 6, 53, 2,  6, 0, 10, 
    0, 42, 7, 27, 8, 61, 4, 81, 5, 38, 9, 28, 2, 81, 1, 71, 6, 50, 3, 93, 
    1, 95, 6, 96, 3, 85, 2, 86, 5, 22, 8, 73, 4, 73, 9, 64, 0, 46, 7, 76, 
    7, 54, 1, 54, 3, 94, 5, 54, 4, 36, 8, 62, 9, 85, 0, 36, 2, 38, 6, 36, 
    5, 78, 1, 92, 6, 37, 7, 27, 9, 12, 3, 32, 4,  4, 2,  1, 0, 53, 8, 94
  };
  const int r843[] = {
    10, 10, // Number of jobs and machines
    2, 75, 3, 47, 5, 17, 6, 95, 8, 66, 4, 79, 0, 19, 9, 17, 1, 74, 7, 32, 
    2, 33, 0, 17, 3, 55, 4, 65, 9, 78, 8, 66, 1, 48, 7, 30, 5, 51, 6, 16, 
    0, 44, 1, 51, 8,  3, 6, 74, 4, 96, 5, 82, 9, 20, 3, 42, 7, 88, 2, 35, 
    4, 54, 3, 59, 6, 54, 7, 88, 5, 18, 2, 62, 9, 90, 8,  5, 0,  6, 1, 68, 
    2, 36, 6, 43, 3, 73, 5, 86, 0, 87, 4, 49, 9, 42, 1, 14, 7, 56, 8,  7, 
    5, 59, 1, 32, 0, 45, 4, 70, 7, 22, 8, 94, 6,  9, 2, 20, 3, 86, 9, 30, 
    2, 10, 3, 60, 1, 16, 7, 73, 9, 73, 8, 31, 4, 18, 6, 11, 5, 90, 0, 67, 
    9,  4, 2, 78, 6, 15, 5, 48, 7, 79, 8, 77, 3, 66, 4,  9, 1, 74, 0, 49, 
    3,  9, 2, 87, 4, 33, 6, 48, 9, 36, 1, 28, 8, 72, 7, 83, 5, 58, 0, 35, 
    9, 43, 0, 68, 8, 64, 4, 69, 7, 65, 6, 45, 3, 96, 2, 74, 1, 70, 5, 75
  };
  const int r844[] = {
    10, 10, // Number of jobs and machines
    5, 29, 3, 12, 0, 85, 4,  7, 7, 20, 1,  6, 8, 57, 2, 90, 6, 94, 9,  8, 
    0, 38, 2, 22, 5,  9, 4, 42, 7, 13, 3, 71, 8, 96, 6, 22, 1, 42, 9, 54, 
    8, 93, 0, 54, 1, 88, 7, 58, 4, 78, 6, 77, 3,  3, 9, 40, 2, 46, 5, 76, 
    6, 91, 2, 13, 4, 27, 9, 75, 1, 89, 5, 89, 3, 16, 0, 86, 7, 11, 8, 93, 
    6,  2, 9, 55, 3, 45, 8,  1, 7, 13, 5, 21, 4, 18, 1, 70, 2, 48, 0, 66, 
    9, 87, 7, 70, 0, 40, 5, 14, 4, 78, 1, 12, 8, 76, 6, 59, 3, 71, 2, 12, 
    3, 39, 8, 58, 2, 79, 4, 12, 0, 14, 9, 44, 7, 51, 6, 78, 5, 80, 1, 49, 
    0, 45, 7, 32, 9, 81, 6, 39, 4,  1, 8, 22, 5, 71, 1, 14, 2, 59, 3, 93, 
    9, 21, 3, 90, 6, 24, 2, 12, 5, 69, 1, 55, 0, 48, 4,  3, 7, 70, 8,  7, 
    5, 28, 1, 52, 9, 96, 6, 84, 8, 85, 7, 27, 0, 35, 3, 49, 4, 59, 2, 41
  };
  const int r845[] = {
    10, 10, // Number of jobs and machines
    6, 46, 4, 92, 3, 77, 7, 76, 1, 85, 0, 31, 9, 46, 5,  1, 8, 11, 2, 87, 
    1, 41, 2, 16, 3, 79, 5, 55, 0, 41, 6, 27, 9, 35, 4,  3, 7, 13, 8, 93, 
    4, 43, 7, 29, 2, 54, 6, 93, 1, 97, 8,  7, 0, 11, 3,  6, 9, 10, 5,  7, 
    5,  3, 1, 79, 3, 36, 6, 64, 0, 31, 8, 89, 9, 77, 7, 31, 4, 55, 2,  4, 
    7,  8, 0, 35, 9, 85, 3, 84, 6, 23, 2, 31, 5, 27, 1, 83, 8, 67, 4,  8, 
    2, 56, 7, 19, 4, 69, 0, 36, 3, 54, 8, 51, 5, 21, 6, 15, 1, 39, 9,  4, 
    8, 39, 4, 82, 3, 10, 1, 25, 9, 87, 2, 23, 5, 80, 0, 16, 6, 70, 7, 34, 
    1, 17, 2, 80, 6, 35, 0, 37, 5, 16, 8, 90, 4,  2, 3, 68, 7, 82, 9, 35, 
    8, 99, 6,  8, 1,  5, 9, 92, 0, 93, 7, 44, 3, 18, 2, 87, 4, 67, 5, 14, 
    9, 60, 0, 23, 1, 39, 6, 27, 7, 67, 3, 70, 8, 38, 2, 62, 4, 33, 5, 62
  };
  const int r846[] = {
    10, 10, // Number of jobs and machines
    7, 87, 4,  7, 1, 32, 8, 21, 0, 22, 2, 88, 9, 47, 3, 46, 5,  1, 6, 39, 
    8,  4, 1, 76, 3, 87, 6, 91, 5, 99, 2, 27, 4, 12, 0, 64, 9, 65, 7, 74, 
    9, 39, 2, 22, 0, 89, 6, 55, 4, 36, 3, 16, 5, 17, 8, 32, 1, 10, 7, 15, 
    2, 23, 0, 54, 6, 29, 9, 51, 1,  3, 8, 81, 7, 84, 3, 10, 5, 53, 4, 29, 
    7, 51, 9, 19, 5, 66, 1, 51, 2, 92, 8, 95, 4, 63, 0, 36, 3, 56, 6, 22, 
    7, 80, 4,  7, 1,  5, 6, 26, 9, 24, 3, 70, 8, 36, 2,  7, 5,  6, 0, 68, 
    0, 12, 8, 23, 9, 14, 2, 20, 7, 41, 1, 51, 3, 73, 5, 17, 6, 12, 4, 34, 
    6,  7, 8, 85, 4, 42, 1, 38, 7, 83, 0, 93, 5, 85, 9, 13, 3, 81, 2, 38, 
    3, 89, 2, 42, 4, 52, 8, 75, 5, 78, 0, 26, 7, 39, 6,  1, 9, 21, 1,  2, 
    0, 15, 2, 29, 6, 94, 8, 99, 7, 71, 9, 99, 1, 72, 4, 17, 3, 61, 5,  2
  };
  const int r847[] = {
    10, 10, // Number of jobs and machines
    7,  2, 5, 56, 3, 85, 6, 41, 2, 35, 4, 70, 8, 39, 1, 34, 0, 33, 9, 14, 
    0, 63, 5,  5, 2, 97, 7, 75, 8, 52, 3, 68, 4, 92, 6, 35, 1, 17, 9, 58, 
    3, 90, 2, 87, 8, 14, 0, 31, 7, 84, 9, 43, 6,  1, 1, 60, 5, 88, 4, 52, 
    0, 50, 6, 88, 5,  1, 1, 71, 9, 40, 2, 78, 4, 86, 8, 33, 7, 87, 3, 74, 
    0, 16, 7, 42, 5, 75, 9, 10, 2, 37, 3, 77, 8, 54, 6, 30, 1, 74, 4, 30, 
    6, 74, 5, 70, 2, 40, 0, 62, 9,  8, 1, 74, 7, 60, 4, 99, 3, 81, 8, 31, 
    3, 61, 8, 60, 6, 61, 7, 29, 9, 73, 2, 96, 4, 71, 0, 98, 1, 91, 5, 27, 
    7, 35, 3, 68, 9, 38, 0, 24, 4, 59, 1, 44, 6, 34, 5, 19, 8, 42, 2, 51, 
    4, 45, 2,  9, 9, 80, 7, 51, 3,  9, 0, 53, 5, 29, 6, 82, 8,  5, 1, 54, 
    9, 77, 4,  8, 8, 76, 5, 94, 2, 37, 7, 39, 0, 95, 1, 18, 6, 70, 3, 58
  };
  const int r848[] = {
    10, 10, // Number of jobs and machines
    6,  2, 9, 32, 8, 50, 7, 20, 5, 32, 1, 61, 4, 67, 0, 68, 2, 19, 3, 69, 
    7, 22, 0, 29, 1, 23, 5, 80, 6, 86, 4, 36, 3, 34, 8, 45, 2, 69, 9, 85, 
    9,  5, 4, 75, 2,  2, 6, 85, 3, 96, 5, 75, 1, 21, 0, 95, 8, 50, 7, 33, 
    8, 68, 5, 45, 4, 80, 0,  2, 9, 89, 3, 49, 1, 77, 6, 37, 2, 15, 7, 28, 
    7, 28, 1, 52, 6, 51, 8,  7, 4, 62, 9, 19, 2, 71, 5, 40, 3, 84, 0, 91, 
    8, 16, 4,  1, 5, 25, 2, 24, 0, 70, 3, 11, 1, 56, 6, 45, 7, 56, 9, 28, 
    9, 43, 3, 21, 5, 80, 1, 56, 4, 17, 2, 30, 8, 53, 0, 90, 7, 99, 6, 14, 
    2, 60, 7, 48, 0, 95, 5, 74, 4, 54, 1, 29, 9, 35, 6, 69, 3, 98, 8, 75, 
    3, 54, 6, 58, 4, 17, 1,  4, 7, 60, 0, 87, 8, 32, 9, 11, 5, 53, 2, 16, 
    9,  9, 1, 50, 4, 39, 6,  7, 5, 92, 8, 86, 0, 25, 2, 75, 3, 54, 7, 89
  };
  const int r849[] = {
    10, 10, // Number of jobs and machines
    1, 26, 6, 21, 3, 25, 2, 77, 9, 83, 5, 14, 4, 10, 8, 12, 0, 98, 7, 66, 
    9, 15, 8, 20, 5, 20, 0,  4, 1,  7, 4, 84, 3, 35, 7,  7, 6, 78, 2, 42, 
    8, 92, 1, 26, 6, 72, 0, 99, 9, 42, 5, 96, 7, 45, 4, 53, 2, 99, 3, 37, 
    6, 42, 0, 80, 2, 76, 5, 41, 4, 41, 8, 31, 9, 65, 7, 19, 3, 17, 1, 97, 
    0, 32, 3, 17, 8, 97, 9, 54, 2, 23, 5, 39, 1, 27, 4, 82, 7, 78, 6, 46, 
    9, 99, 2, 78, 3, 66, 0, 74, 6, 92, 5,  5, 7, 63, 8, 43, 1, 89, 4, 85, 
    0, 13, 9, 79, 1, 18, 2, 68, 8, 51, 6,  2, 3, 59, 4, 55, 7, 16, 5, 22, 
    5, 75, 8, 23, 2, 59, 4, 29, 0, 78, 7, 39, 1, 91, 3, 20, 6, 94, 9, 82, 
    0, 29, 6, 54, 9, 38, 4, 61, 1, 73, 5, 61, 2, 64, 7, 70, 8, 64, 3, 73, 
    0, 15, 6, 10, 7, 21, 9, 24, 1, 94, 3,  2, 4, 39, 5, 42, 8, 38, 2, 70
  };
  const int r850[] = {
    10, 10, // Number of jobs and machines
    3, 73, 6, 58, 8, 34, 7, 64, 1, 26, 9, 82, 4, 10, 0, 78, 2,  6, 5, 81, 
    3, 64, 5, 89, 1, 55, 0, 37, 9, 11, 7, 25, 2, 26, 6,  6, 4, 79, 8, 23, 
    0, 12, 2, 23, 1, 16, 9, 52, 8, 59, 5, 89, 4, 28, 6, 68, 7,  4, 3, 41, 
    5, 83, 6, 45, 0, 85, 7, 40, 2, 67, 3,  8, 9, 94, 4, 72, 8,  7, 1, 11, 
    6, 88, 2, 49, 9, 97, 0, 31, 4, 67, 7,  5, 5, 96, 3,  4, 8, 64, 1, 78, 
    5,  2, 7, 68, 2, 18, 3, 84, 8, 95, 6, 18, 4, 31, 9, 26, 0, 98, 1, 33, 
    5, 38, 3, 99, 8, 48, 4, 31, 9, 76, 1, 13, 0, 72, 2, 73, 7, 54, 6, 28, 
    4, 12, 6, 48, 1, 94, 8, 97, 0, 55, 7, 55, 2, 28, 5, 39, 9, 59, 3, 35, 
    9, 32, 7,  4, 3, 56, 4, 64, 8, 20, 1, 42, 0, 48, 5, 11, 6, 93, 2, 98, 
    0, 90, 2, 39, 3, 26, 8, 10, 6, 99, 5, 69, 9, 44, 7, 24, 1, 66, 4, 67
  };
  const int r851[] = {
    10, 10, // Number of jobs and machines
    9, 91, 5, 55, 7, 39, 3, 64, 2,  8, 1,  5, 4, 63, 8, 15, 6, 47, 0, 64, 
    8, 65, 9, 75, 0, 35, 5, 47, 3, 53, 6,  3, 7, 81, 2, 69, 1, 21, 4, 34, 
    4, 60, 2, 46, 0, 36, 6, 25, 8, 82, 3, 16, 9,  1, 5, 70, 1,  2, 7,  9, 
    8, 30, 4, 48, 3, 13, 1, 84, 0, 15, 7, 84, 9, 95, 5, 63, 6, 67, 2, 30, 
    2, 86, 4, 40, 8, 56, 5, 49, 6,  3, 0, 14, 7, 73, 3, 55, 1, 59, 9, 97, 
    8, 89, 2, 22, 4,  7, 7, 15, 3, 85, 1, 64, 5,  3, 6, 22, 9, 71, 0, 92, 
    0, 40, 8, 28, 9,  3, 4, 30, 2, 53, 1, 52, 3, 13, 6,  3, 5, 28, 7, 57, 
    0,  5, 2, 55, 7, 80, 1, 17, 8,  6, 6, 17, 9, 37, 3, 14, 5, 16, 4, 34, 
    3, 89, 9, 90, 6, 52, 2, 16, 5, 23, 1, 41, 8, 13, 0, 73, 7, 49, 4, 26, 
    4, 82, 2, 85, 9, 80, 3, 49, 0, 56, 5, 96, 7, 39, 6, 30, 8, 39, 1, 70
  };
  const int r852[] = {
    10, 10, // Number of jobs and machines
    8, 56, 3, 98, 2, 99, 9, 80, 0,  9, 6, 29, 7,  3, 1, 13, 5, 44, 4, 62, 
    8, 39, 5, 78, 1, 74, 0, 80, 2, 66, 6, 38, 9, 46, 3, 49, 7, 95, 4,  1, 
    8, 65, 7, 26, 9, 92, 5, 10, 3, 14, 2, 14, 4, 34, 0,  5, 6, 40, 1, 13, 
    2, 55, 3, 62, 8, 90, 6, 54, 1, 72, 7, 99, 9, 29, 4,  5, 0, 21, 5, 31, 
    1, 22, 2, 50, 5, 21, 3, 86, 0, 86, 6, 70, 8, 18, 4, 21, 9, 82, 7, 54, 
    7, 54, 5, 60, 4, 29, 0, 20, 1, 74, 3, 11, 2, 57, 9, 33, 8, 35, 6, 98, 
    5, 71, 9,  6, 0, 86, 2, 64, 1, 41, 4, 46, 3, 83, 6, 70, 8, 55, 7, 58, 
    4, 50, 6, 33, 5, 84, 7, 27, 9, 44, 1, 77, 2, 89, 3, 42, 0, 28, 8, 94, 
    3, 19, 5, 12, 1,  4, 7, 68, 0, 13, 2, 49, 8, 12, 9, 46, 6,  1, 4, 72, 
    0, 19, 5, 18, 1, 52, 9, 82, 4, 73, 3, 71, 7,  3, 2, 71, 6, 12, 8, 63
  };
  const int r853[] = {
    10, 10, // Number of jobs and machines
    4, 26, 5,  4, 1,  2, 0, 91, 9, 23, 2, 28, 8, 98, 3, 25, 6, 76, 7, 83, 
    0, 54, 7, 79, 5, 69, 6, 40, 2, 71, 1, 91, 8, 98, 3, 30, 4, 83, 9,  7, 
    6, 16, 9, 20, 5, 98, 0,  3, 4, 75, 8,  4, 3, 73, 1, 21, 2, 79, 7, 74, 
    7, 95, 4, 22, 0, 58, 3,  1, 9, 94, 6, 44, 1, 11, 2, 34, 8, 64, 5, 56, 
    1, 48, 4, 98, 6, 11, 5, 73, 8, 50, 3, 12, 0,  2, 9, 10, 2, 25, 7,  3, 
    8, 28, 0, 96, 7, 83, 9, 25, 5, 94, 1,  6, 2, 73, 3, 69, 6, 59, 4, 36, 
    9, 85, 4, 27, 1, 86, 5, 38, 7,  3, 8, 49, 0, 62, 3, 93, 6, 94, 2, 28, 
    6, 16, 9, 60, 1, 49, 0, 98, 4, 61, 5, 20, 3, 93, 2, 91, 8, 88, 7, 98, 
    5, 63, 4, 13, 7, 28, 8, 22, 6, 41, 3,  3, 2, 54, 9, 10, 1,  2, 0, 42, 
    7, 70, 0, 94, 8,  9, 1, 46, 6, 63, 2, 61, 3, 66, 9, 53, 5, 20, 4, 48
  };
  const int r854[] = {
    10, 10, // Number of jobs and machines
    8, 98, 7, 42, 4, 70, 3, 15, 5, 77, 9, 53, 2, 51, 1, 73, 6, 65, 0,  1, 
    8, 93, 3, 70, 2, 87, 6, 95, 9, 66, 7, 69, 5, 57, 1, 36, 0, 33, 4, 30, 
    4, 66, 7, 84, 6, 90, 3, 47, 2, 32, 9, 26, 8, 39, 1, 32, 0, 69, 5, 28, 
    0, 29, 1,  9, 5, 10, 4, 88, 7, 81, 8, 44, 3, 11, 9, 63, 2, 76, 6, 65, 
    5, 64, 4, 98, 3,  7, 2, 85, 7, 69, 8,  8, 6, 88, 9, 75, 1, 44, 0, 68, 
    3, 44, 0, 91, 6, 30, 4, 41, 1,  7, 2, 61, 8, 53, 5, 31, 9, 39, 7, 47, 
    9, 94, 8, 64, 6, 76, 0, 42, 1, 77, 2,  7, 7, 17, 4, 57, 3, 29, 5, 26, 
    9, 87, 0, 48, 2, 76, 5, 94, 3, 88, 8, 65, 1, 44, 4, 83, 7, 72, 6, 28, 
    3, 79, 7, 24, 0, 50, 2, 22, 4, 57, 6, 16, 9, 29, 8, 73, 1, 73, 5, 43, 
    7, 96, 3, 56, 0, 60, 6, 47, 2, 39, 4, 46, 1, 22, 9, 40, 8, 90, 5, 52
  };
  const int r855[] = {
    10, 10, // Number of jobs and machines
    5, 57, 7,  3, 0, 98, 8, 39, 4, 18, 9, 59, 1, 65, 2, 44, 3, 87, 6, 49, 
    0, 15, 6, 31, 2, 69, 8, 80, 9, 46, 3, 81, 7, 94, 5, 66, 1, 40, 4, 30, 
    5, 90, 4, 89, 6, 33, 3, 70, 2,  3, 1, 27, 8, 93, 7, 42, 0, 81, 9, 11, 
    7, 35, 3, 77, 4,  7, 6, 91, 1, 92, 8, 12, 9, 23, 0, 64, 5,  9, 2, 28, 
    9, 38, 4, 76, 7, 84, 1, 24, 0, 46, 6, 27, 2, 49, 5, 26, 3, 72, 8, 17, 
    4, 14, 5, 57, 0, 24, 7, 77, 3, 11, 8, 56, 1, 10, 2, 94, 9, 27, 6, 40, 
    7, 42, 3, 87, 9, 53, 6, 78, 4, 73, 2, 70, 5, 85, 0, 73, 8, 24, 1, 83, 
    7, 23, 1, 11, 3, 36, 8,  9, 9, 49, 5, 99, 0, 57, 4, 27, 6, 85, 2, 49, 
    6, 42, 8, 25, 1, 61, 4, 70, 0, 64, 2,  6, 7, 84, 9, 16, 3, 75, 5, 46, 
    2, 95, 6, 52, 8, 62, 5, 33, 3, 42, 9, 48, 4, 39, 1, 45, 7, 11, 0, 35
  };
  const int r856[] = {
    10, 10, // Number of jobs and machines
    7, 45, 0, 28, 4, 65, 6, 64, 9, 79, 8, 95, 2, 15, 5, 89, 1, 59, 3, 88, 
    5, 18, 3, 77, 4, 47, 2, 25, 0, 26, 8, 26, 9, 68, 7, 45, 6, 76, 1, 95, 
    8, 89, 5, 86, 9, 21, 3, 60, 6, 93, 7, 61, 1, 92, 0, 15, 2, 78, 4, 13, 
    1, 41, 2, 69, 7, 82, 4, 73, 5, 98, 0, 71, 3, 40, 6, 68, 8, 68, 9, 63, 
    0, 96, 4, 10, 9,  5, 5, 46, 7, 34, 1, 57, 8, 77, 2, 77, 6, 67, 3, 18, 
    7, 68, 3, 26, 4, 60, 9, 88, 2, 93, 8, 93, 5, 83, 6, 96, 1, 92, 0, 65, 
    6, 85, 5, 42, 2, 57, 8, 98, 3, 86, 0, 46, 4,  6, 9, 23, 1, 80, 7, 16, 
    8, 63, 7, 28, 6, 70, 1, 87, 3, 22, 5, 33, 9, 13, 0, 88, 2, 80, 4, 26, 
    4,  1, 2, 82, 3, 64, 8, 10, 6, 17, 9,  2, 0, 77, 7, 92, 1,  9, 5, 63, 
    1, 46, 9, 68, 6, 47, 4, 86, 5, 81, 8, 48, 3, 66, 2, 94, 7, 92, 0, 59
  };
  const int r857[] = {
    10, 10, // Number of jobs and machines
    7,  7, 8, 91, 6, 56, 3, 85, 1, 83, 4,  4, 9, 66, 0, 10, 2, 92, 5, 66, 
    2, 43, 4,  1, 8, 18, 1, 44, 9, 32, 0, 88, 5, 24, 7, 87, 3, 12, 6, 40, 
    5, 64, 6, 66, 4, 32, 1,  1, 2, 63, 9, 64, 3, 39, 7, 65, 8, 42, 0, 19, 
    5, 17, 0, 44, 1, 34, 4, 62, 2, 48, 9, 70, 7, 18, 8, 94, 6, 27, 3, 98, 
    3, 53, 8, 16, 5, 31, 0, 27, 9, 89, 4, 95, 1, 90, 6, 64, 7, 43, 2, 16, 
    2, 67, 0, 78, 1,  9, 8, 63, 9, 83, 7, 42, 6, 85, 5, 96, 3, 55, 4, 73, 
    9, 95, 5,  8, 1,  1, 4, 74, 6, 84, 7, 88, 2, 87, 3,  4, 0, 68, 8, 99, 
    8, 26, 6, 95, 4,  3, 3, 38, 9, 95, 7, 60, 5, 38, 1, 26, 2, 91, 0, 61, 
    6,  8, 7, 62, 9, 93, 2, 73, 1, 62, 0, 99, 4, 96, 3, 40, 8, 87, 5, 95, 
    1, 73, 0, 30, 5, 91, 7,  1, 8, 72, 4, 69, 6, 28, 3, 50, 2, 35, 9, 95
  };
  const int r858[] = {
    10, 10, // Number of jobs and machines
    6, 55, 1, 59, 7, 47, 8, 89, 4, 61, 9, 13, 2, 29, 5, 87, 3, 41, 0, 89, 
    5, 56, 7, 10, 2, 52, 1, 76, 9,  1, 3, 17, 4, 68, 0, 91, 8, 67, 6, 61, 
    0,  9, 5, 64, 2, 80, 1, 62, 8, 11, 3, 93, 4, 52, 7, 31, 6, 51, 9,  7, 
    4, 15, 7, 94, 0, 46, 6, 94, 5, 59, 2, 50, 3, 45, 1, 59, 8, 70, 9, 55, 
    1, 60, 0, 89, 4, 21, 5, 24, 7, 18, 6, 55, 2, 74, 3, 29, 8, 15, 9, 78, 
    2, 81, 8, 59, 5, 49, 7, 42, 6, 54, 1,  4, 4, 31, 0, 31, 3, 22, 9, 75, 
    8, 79, 2, 37, 9, 58, 6, 88, 4, 90, 5, 43, 3, 24, 1, 90, 0, 40, 7, 52, 
    3, 29, 6, 67, 7, 96, 1, 18, 4, 40, 8, 43, 5, 63, 2, 21, 9,  4, 0, 89, 
    0, 61, 9, 43, 4, 70, 2,  2, 1, 53, 8, 51, 5,  4, 3, 99, 6, 61, 7, 95, 
    5, 67, 3, 25, 8, 20, 0, 65, 2, 11, 1, 99, 6, 94, 4, 54, 7, 47, 9, 21
  };
  const int r859[] = {
    10, 10, // Number of jobs and machines
    7, 15, 0, 96, 9, 91, 1, 83, 2, 25, 5,  4, 3, 39, 6, 66, 8,  7, 4, 85, 
    4, 66, 3, 82, 5, 34, 8, 82, 0, 32, 1,  3, 9,  2, 6, 46, 7, 51, 2, 44, 
    5, 83, 9, 72, 4, 91, 0, 49, 3, 24, 1, 62, 7, 54, 6, 76, 2,  4, 8, 15, 
    4, 14, 5, 43, 7, 60, 3, 48, 2, 32, 1, 15, 6, 29, 8, 70, 9, 64, 0, 17, 
    7, 82, 0, 75, 9, 25, 5, 39, 8, 68, 4, 96, 1, 67, 6, 46, 3, 71, 2, 27, 
    6, 52, 8, 86, 2, 55, 4, 10, 1,  6, 5,  4, 9,  7, 0, 69, 3, 66, 7, 61, 
    0, 59, 4, 77, 8,  8, 2, 64, 6, 12, 7, 39, 1, 74, 5, 11, 9, 71, 3, 86, 
    0, 61, 5, 15, 8, 14, 3, 45, 1, 66, 6, 72, 7, 91, 2, 35, 4,  5, 9, 58, 
    5,  5, 2, 96, 6, 77, 8, 27, 7,  4, 1, 99, 0, 58, 3, 31, 9, 70, 4, 86, 
    1, 11, 7, 38, 8, 15, 3, 24, 4, 79, 6, 91, 0, 22, 5, 11, 2, 77, 9, 18
  };
  const int r860[] = {
    10, 10, // Number of jobs and machines
    7, 37, 4, 23, 8, 36, 3, 30, 2, 58, 5, 39, 0, 44, 1, 70, 6, 23, 9, 39, 
    3, 68, 8, 63, 0, 69, 4, 24, 9, 94, 1, 86, 6, 25, 2, 28, 5, 79, 7, 99, 
    5, 19, 2, 63, 1, 61, 0,  5, 9, 17, 3, 44, 6, 83, 7, 72, 4, 94, 8, 77, 
    1,  7, 2, 48, 4, 50, 9, 11, 8, 40, 5, 81, 3, 45, 6, 31, 7, 39, 0, 35, 
    3, 53, 6, 19, 9, 27, 5, 29, 2,  2, 1, 43, 7, 88, 0, 23, 8, 26, 4, 82, 
    6, 44, 4, 96, 9, 26, 5, 75, 0, 48, 8,  2, 2, 79, 7,  5, 3, 45, 1, 37, 
    1, 25, 6, 50, 9, 91, 7, 18, 0, 38, 3, 13, 2,  4, 4, 40, 8, 34, 5,  5, 
    4, 48, 6, 14, 1, 44, 5, 99, 2, 83, 3,  6, 8, 69, 9, 99, 0, 76, 7, 14, 
    4, 24, 9,  2, 6, 57, 0, 76, 8, 64, 2, 70, 7, 41, 5, 83, 3, 92, 1, 84, 
    3, 94, 7, 52, 1, 99, 6, 13, 0, 54, 9, 47, 2, 16, 5, 47, 4,  3, 8, 23
  };
  const int r861[] = {
    10, 10, // Number of jobs and machines
    3, 74, 4, 62, 9,  2, 6, 19, 5, 17, 0, 80, 1, 75, 8, 68, 2, 89, 7, 59, 
    7, 45, 1, 31, 0, 94, 2, 79, 5,  1, 3, 45, 6, 58, 8, 45, 4, 70, 9, 93, 
    8, 84, 3, 30, 5, 73, 9,  1, 1,  7, 2, 68, 0, 80, 6, 63, 7, 76, 4, 53, 
    3, 77, 9, 71, 6, 33, 0, 59, 1, 13, 5, 76, 8,  2, 7, 19, 2, 93, 4, 13, 
    2, 47, 5, 50, 7, 84, 9, 78, 0, 11, 3, 10, 1, 39, 4, 54, 8, 80, 6, 43, 
    1, 46, 9, 89, 0, 90, 6, 60, 8, 13, 4, 70, 3, 50, 5, 85, 7, 26, 2, 44, 
    5, 94, 3, 77, 1,  6, 2, 72, 6, 52, 4, 92, 8, 43, 0, 77, 7, 41, 9, 33, 
    1, 59, 2, 64, 5, 42, 4, 33, 0, 55, 6, 91, 3, 23, 7, 66, 9, 51, 8, 69, 
    4, 99, 2, 71, 3, 13, 1, 61, 8,  5, 7, 38, 9, 72, 6, 13, 5, 17, 0, 93, 
    1, 48, 7, 57, 6, 80, 4, 72, 3, 16, 0, 57, 2, 34, 8, 82, 9, 15, 5, 89
  };
  const int r862[] = {
    10, 10, // Number of jobs and machines
    4, 83, 0, 74, 9, 18, 6,  3, 3, 23, 2, 43, 7, 17, 5, 41, 1, 62, 8, 55, 
    6, 45, 9,  2, 7, 46, 3, 38, 1, 41, 8, 74, 0, 97, 4, 31, 2, 76, 5, 90, 
    2, 20, 7, 15, 1,  7, 5, 20, 0, 84, 4, 74, 8, 38, 6, 77, 3, 45, 9, 21, 
    8, 52, 4, 20, 0, 11, 1, 64, 5, 69, 6, 51, 2, 77, 9, 67, 3, 80, 7, 23, 
    9,  4, 1, 73, 8, 61, 2, 95, 0, 86, 6, 53, 7, 47, 5, 29, 3, 95, 4, 89, 
    8, 68, 7, 70, 5, 24, 4, 52, 6, 15, 1, 77, 2, 92, 9, 81, 3,  2, 0, 45, 
    1, 37, 0, 55, 6, 69, 5, 26, 8, 21, 2,  6, 4, 61, 9, 36, 7, 31, 3, 53, 
    1, 59, 7, 75, 3, 58, 8, 20, 9, 86, 4, 12, 5, 30, 0, 89, 2,  3, 6, 18, 
    9, 16, 3, 57, 7, 42, 0, 93, 1, 19, 8, 73, 4, 18, 5,  2, 2,  7, 6, 45, 
    9, 10, 5, 68, 7, 98, 0, 46, 1, 33, 8, 96, 2, 75, 4, 32, 3, 25, 6, 21
  };
  const int r863[] = {
    10, 10, // Number of jobs and machines
    2, 26, 1, 31, 6, 20, 5,  7, 7, 46, 9, 87, 3, 94, 8, 40, 4,  4, 0, 69, 
    1, 76, 2,  1, 6, 73, 9, 17, 4, 62, 5, 37, 7, 51, 0, 63, 8, 29, 3, 22, 
    1, 30, 8, 62, 2,  6, 3, 15, 6, 87, 9, 86, 0, 72, 7, 74, 4, 97, 5, 85, 
    0, 10, 7, 42, 5, 99, 2, 42, 9, 58, 6, 33, 4, 63, 8, 14, 3, 64, 1, 61, 
    4, 58, 0, 27, 8, 42, 3, 18, 1, 18, 2,  5, 6, 78, 7,  1, 9, 94, 5, 26, 
    3, 91, 1, 35, 0, 78, 6, 98, 9, 19, 8, 54, 5, 76, 4, 79, 7, 97, 2, 86, 
    4, 55, 3, 75, 2, 63, 0, 73, 9, 84, 1, 53, 5, 84, 6, 66, 8, 61, 7,  6, 
    9, 49, 5, 96, 7, 93, 4, 94, 6, 38, 3, 50, 2, 88, 0, 46, 8, 52, 1,  6, 
    8, 86, 4,  6, 9,  7, 7, 60, 5, 29, 6, 75, 2,  1, 0, 63, 1,  5, 3, 79, 
    0,  5, 1, 63, 9, 46, 4, 51, 8, 27, 3, 14, 6, 13, 2, 63, 7, 62, 5, 38
  };
  const int r864[] = {
    10, 10, // Number of jobs and machines
    7, 12, 8, 65, 1, 68, 6, 10, 9, 40, 4, 35, 3, 13, 2, 76, 5,  4, 0, 38, 
    3, 80, 5, 85, 7, 21, 9, 86, 2, 56, 6,  7, 0, 25, 4, 92, 8, 69, 1, 53, 
    6, 52, 1, 65, 2, 70, 7, 27, 9, 34, 8, 99, 3, 99, 0, 55, 5, 40, 4, 25, 
    7, 56, 4, 57, 3,  7, 6, 56, 5, 62, 9, 61, 8, 33, 2, 46, 1, 61, 0, 42, 
    6, 84, 1, 22, 2, 82, 9, 53, 0, 55, 3, 94, 8, 24, 7, 46, 5, 29, 4, 68, 
    9,  4, 6, 76, 0, 32, 5, 10, 2, 39, 4, 18, 1, 29, 7, 64, 3, 88, 8, 95, 
    9, 20, 4, 90, 2, 45, 6, 46, 1, 62, 7, 53, 3, 37, 5, 71, 0, 51, 8,  6, 
    4, 16, 3, 35, 0, 14, 6, 91, 7, 49, 9, 31, 2, 85, 8, 83, 1, 27, 5, 86, 
    1,  4, 7, 66, 6, 95, 9,  7, 0, 56, 4, 94, 5,  5, 3, 84, 2,  7, 8, 55, 
    0, 63, 4, 15, 6, 33, 5, 86, 8, 81, 1, 61, 3, 79, 2, 24, 9, 87, 7, 26
  };
  const int r865[] = {
    10, 10, // Number of jobs and machines
    3, 38, 5, 84, 4, 83, 7, 76, 6, 66, 8, 86, 9, 98, 0, 13, 1, 83, 2, 73, 
    2, 24, 9, 94, 4, 49, 1, 52, 5, 47, 3, 25, 0, 27, 7, 47, 8, 81, 6, 63, 
    2, 81, 3, 96, 6, 84, 4, 80, 9, 68, 1, 17, 5, 14, 0, 95, 8, 53, 7, 81, 
    9, 65, 3, 68, 6, 78, 1, 46, 2, 93, 5, 34, 0, 69, 4, 14, 7, 22, 8, 15, 
    5, 26, 0, 81, 7, 40, 2, 67, 1,  5, 6, 13, 4, 61, 3, 32, 8, 38, 9, 92, 
    7,  8, 5, 20, 0,  2, 3, 83, 2, 29, 6, 51, 4, 49, 1, 98, 8, 62, 9, 82, 
    2, 22, 3, 79, 1, 97, 6, 77, 9, 80, 4, 45, 7, 61, 0, 95, 8, 43, 5, 31, 
    8, 36, 4, 90, 7, 26, 1,  6, 6, 16, 3, 93, 5, 11, 9, 16, 2, 91, 0, 96, 
    4, 97, 7, 55, 8, 45, 2, 59, 1, 60, 3, 64, 6, 18, 9, 74, 0, 39, 5, 75, 
    2, 86, 0, 14, 4,  9, 9, 49, 6, 21, 1, 47, 3, 58, 5, 17, 8, 62, 7, 51
  };
  const int r866[] = {
    10, 10, // Number of jobs and machines
    4, 15, 0, 43, 5, 85, 1, 18, 6, 44, 3,  7, 7, 91, 8, 80, 9, 57, 2, 78, 
    2, 88, 8, 17, 6,  3, 1, 96, 7, 67, 5, 41, 3, 58, 0, 51, 9, 40, 4, 22, 
    8,  4, 9, 66, 6, 21, 3, 39, 2, 59, 0, 87, 7,  7, 1, 84, 5, 14, 4, 64, 
    4, 85, 6, 19, 1, 43, 3, 82, 8, 99, 0, 36, 5, 44, 9, 63, 7, 31, 2, 47, 
    3, 77, 0, 97, 1, 86, 6, 85, 2, 47, 9, 37, 4, 84, 8, 81, 7, 59, 5, 90, 
    4, 46, 7, 74, 2, 17, 9, 44, 8, 81, 1, 51, 6, 12, 5, 39, 0, 74, 3, 52, 
    5, 93, 3, 40, 1, 33, 7, 12, 9, 51, 2, 79, 8, 94, 0, 38, 6, 72, 4, 65, 
    3, 17, 5, 24, 7, 47, 4, 82, 2,  1, 6, 26, 8,  1, 0, 34, 9, 72, 1,  7, 
    4, 95, 3, 24, 1, 83, 0, 80, 5, 44, 7, 18, 9, 92, 8, 33, 2, 84, 6, 72, 
    1,  9, 3, 20, 9, 98, 8, 50, 5, 68, 0, 96, 7, 37, 6, 43, 2,  9, 4, 39
  };
  const int r867[] = {
    10, 10, // Number of jobs and machines
    3, 81, 0, 77, 2, 60, 7, 50, 6, 21, 9, 58, 1, 62, 5, 59, 8, 45, 4, 90, 
    0, 51, 4, 54, 3, 91, 6,  1, 7, 24, 1, 48, 2, 54, 5, 92, 9, 99, 8, 55, 
    4, 33, 1, 34, 8,  4, 7, 17, 2, 59, 9, 14, 0, 79, 6, 45, 5, 55, 3, 97, 
    7, 81, 9, 20, 8, 91, 1, 76, 5, 58, 6, 13, 2,  3, 4, 16, 3, 71, 0, 47, 
    2, 34, 6, 61, 9, 44, 0, 97, 4, 66, 5, 68, 3, 13, 8, 40, 7, 41, 1, 94, 
    1, 50, 2, 91, 6, 99, 8, 57, 3, 99, 9, 59, 4, 75, 5, 39, 0, 67, 7, 46, 
    0,  7, 4, 19, 9, 48, 7, 18, 2,  1, 1, 96, 6, 75, 3, 24, 8, 20, 5, 24, 
    2,  7, 6, 97, 7, 74, 0, 25, 3, 70, 5, 56, 1, 95, 4, 41, 8,  6, 9, 98, 
    5, 44, 9,  7, 1, 36, 0, 56, 3, 42, 7, 78, 4, 81, 6, 93, 2, 23, 8, 32, 
    3, 88, 5, 16, 4, 15, 8, 63, 7, 47, 0, 54, 2, 86, 9, 12, 1, 51, 6, 73
  };
  const int r868[] = {
    10, 10, // Number of jobs and machines
    7, 55, 9, 67, 4, 61, 8, 32, 2, 20, 5, 84, 0, 88, 3, 55, 6, 63, 1, 34, 
    2, 85, 7, 25, 3, 41, 1, 89, 8,  3, 9, 18, 4, 60, 5, 24, 6, 65, 0, 44, 
    9, 40, 5, 76, 4, 94, 1, 97, 0, 42, 3, 63, 8, 34, 6, 14, 7, 98, 2, 36, 
    3,  7, 6, 33, 9, 43, 5, 43, 4, 39, 1, 56, 7, 56, 8, 89, 0,  2, 2, 48, 
    2, 33, 9, 50, 4, 83, 8,  3, 7, 45, 1, 76, 6, 24, 0, 45, 3, 84, 5, 36, 
    7, 35, 6, 52, 5, 71, 1, 93, 3, 86, 2, 63, 9, 75, 0, 41, 4, 82, 8, 11, 
    9, 24, 0, 12, 1, 72, 2, 90, 4, 52, 3, 82, 8, 74, 7, 61, 6, 20, 5, 79, 
    1, 56, 7, 50, 3, 99, 5, 97, 2, 38, 0, 32, 8,  5, 6, 51, 9, 87, 4,  3, 
    1, 17, 6, 87, 5, 82, 7, 74, 8, 45, 4,  2, 9, 74, 2, 14, 0,  5, 3, 86, 
    6, 21, 7, 46, 5, 56, 9, 68, 1, 61, 4, 41, 8, 62, 0, 42, 2, 37, 3, 76
  };
  const int r869[] = {
    10, 10, // Number of jobs and machines
    4, 16, 7,  7, 1, 87, 0, 46, 3, 24, 9, 20, 2, 38, 6, 70, 5, 56, 8, 35, 
    3, 12, 0, 76, 2, 59, 8,  1, 6,  6, 7, 48, 5, 95, 9, 83, 1, 33, 4, 93, 
    5, 40, 9,  1, 3, 68, 1,  4, 6, 37, 2, 81, 8, 70, 4,  2, 0, 62, 7, 96, 
    9, 63, 5, 70, 3,  4, 0, 50, 7, 90, 4, 97, 6, 61, 1, 84, 8, 79, 2, 10, 
    1, 24, 4, 30, 5, 43, 8,  2, 3, 23, 7, 65, 0, 45, 2, 71, 6, 45, 9, 62, 
    6, 13, 7, 89, 0, 96, 5, 19, 2, 50, 8, 54, 3, 84, 4, 18, 9, 80, 1, 73, 
    3,  1, 1, 15, 9, 50, 2, 41, 8,  5, 5, 33, 4, 90, 0, 53, 6, 68, 7, 93, 
    7, 38, 8,  5, 6, 32, 0, 11, 2, 46, 4, 40, 1, 12, 5, 27, 3, 34, 9, 32, 
    7, 78, 5, 88, 3,  3, 1, 46, 9, 16, 6, 58, 0,  5, 8, 18, 4, 92, 2,  9, 
    8, 96, 5,  7, 1, 36, 2, 77, 0, 83, 6, 84, 3, 51, 9,  9, 7, 92, 4, 41
  };
  const int r870[] = {
    10, 10, // Number of jobs and machines
    6, 72, 8, 35, 3, 35, 1, 89, 4, 90, 7, 89, 5, 37, 9, 82, 2, 28, 0,  1, 
    3, 11, 8, 25, 1, 75, 6, 39, 5, 14, 9, 74, 2, 79, 4, 42, 0, 87, 7, 46, 
    0, 15, 2, 69, 1, 61, 6,  7, 9, 88, 4, 18, 3, 25, 7, 69, 8, 33, 5, 31, 
    7, 15, 0, 59, 6, 37, 9, 31, 3, 11, 8, 89, 5, 59, 2,  8, 1, 27, 4, 99, 
    2, 51, 9, 85, 5, 70, 1, 58, 3, 13, 6, 54, 4, 21, 0, 46, 8, 64, 7, 82, 
    4, 84, 8, 44, 1, 40, 9, 61, 5, 57, 6, 75, 2, 26, 3, 57, 7, 35, 0, 20, 
    6, 86, 9,  2, 8, 37, 1, 22, 4, 60, 5, 12, 7,  8, 3, 25, 0, 21, 2, 76, 
    7, 66, 8,  2, 4, 79, 0, 10, 1, 78, 9, 59, 3, 46, 5, 48, 2, 92, 6, 45, 
    0, 55, 8, 37, 9,  9, 3, 61, 4, 42, 6, 51, 1,  1, 2, 15, 7,  9, 5, 56, 
    7, 22, 3, 11, 0, 39, 4, 94, 1, 50, 5, 25, 6, 20, 2, 92, 8, 14, 9, 98
  };
  const int r871[] = {
    10, 10, // Number of jobs and machines
    6,  5, 7, 33, 4, 98, 5, 25, 0,  7, 9, 93, 1, 92, 8, 42, 2,  4, 3, 78, 
    6, 53, 5, 70, 7, 87, 9, 18, 0, 76, 1,  4, 4, 32, 8, 41, 2, 51, 3, 64, 
    6, 90, 5, 57, 7, 65, 0, 10, 8, 63, 4, 39, 9, 26, 2, 48, 1, 80, 3,  1, 
    8, 42, 2, 65, 7, 33, 1, 97, 4, 19, 9, 15, 3, 82, 5, 40, 6, 26, 0, 77, 
    3, 15, 6,  6, 0, 71, 5, 41, 1, 42, 4,  5, 9,  5, 2, 74, 8, 27, 7, 16, 
    0, 15, 5, 70, 1, 80, 8, 91, 2,  1, 6,  5, 3, 16, 9, 70, 4, 39, 7, 50, 
    0,  7, 9,  5, 1,  5, 7, 55, 8, 40, 5, 15, 6, 19, 2, 79, 4, 21, 3, 89, 
    8, 35, 9,  2, 0, 97, 3, 11, 1, 42, 4, 33, 5, 21, 2, 84, 7, 53, 6, 91, 
    7, 86, 5,  5, 1, 45, 8, 33, 3, 75, 4, 46, 6,  7, 2, 69, 0, 68, 9, 18, 
    1, 70, 2, 19, 7, 22, 6,  3, 0, 91, 4, 41, 3, 40, 8,  7, 9, 43, 5, 17
  };
  const int r872[] = {
    10, 10, // Number of jobs and machines
    2, 53, 8, 14, 9, 76, 7, 76, 3,  1, 6, 72, 5, 74, 4, 66, 0, 39, 1, 43, 
    5, 46, 6, 52, 0, 89, 9,  8, 1, 13, 8, 34, 7, 68, 3,  5, 4, 36, 2, 37, 
    1, 24, 0, 55, 5, 72, 2, 62, 8, 93, 6, 87, 7, 37, 9, 32, 3,  7, 4, 95, 
    2, 25, 0, 67, 3, 98, 5, 16, 4, 93, 1, 84, 6, 95, 8, 15, 7, 77, 9, 61, 
    5, 81, 4, 47, 0, 56, 9, 79, 3, 36, 6, 28, 1, 75, 8, 53, 2, 56, 7, 47, 
    6,  7, 1, 56, 9, 94, 5, 32, 3, 41, 2, 87, 0, 29, 7, 51, 8,  8, 4, 45, 
    4, 31, 9, 72, 6, 10, 1,  2, 0, 20, 8, 91, 7, 60, 2, 12, 5, 84, 3, 98, 
    4,  2, 8, 22, 3, 74, 0, 89, 5, 53, 6, 83, 7, 19, 9, 29, 2, 80, 1, 76, 
    6, 11, 3, 72, 0, 13, 9, 67, 4,  6, 2,  2, 5, 35, 7, 16, 8, 30, 1, 42, 
    0,  7, 4, 32, 5, 86, 9, 22, 8, 34, 2, 77, 7, 58, 3, 23, 1, 39, 6, 15
  };
  const int r873[] = {
    10, 10, // Number of jobs and machines
    6,  4, 4, 42, 0, 30, 2, 28, 5, 42, 1, 75, 3, 67, 8, 51, 7, 62, 9, 77, 
    1, 54, 9, 54, 5, 14, 2, 85, 7, 67, 3, 58, 4,  2, 0, 86, 8,  9, 6, 45, 
    8, 42, 4, 80, 6, 72, 0, 95, 5, 13, 9, 32, 7,  6, 2, 27, 1, 60, 3, 96, 
    1, 71, 6, 52, 2, 39, 5, 65, 3, 76, 4, 71, 9, 35, 7,  5, 0, 23, 8, 32, 
    0, 93, 9,  3, 3, 98, 6, 91, 4, 29, 5,  1, 8, 62, 7,  7, 1, 68, 2, 90, 
    6, 58, 2, 62, 3,  2, 9, 81, 7,  5, 5, 97, 8, 29, 1, 64, 4, 89, 0, 69, 
    3, 34, 6, 75, 0, 28, 1, 35, 2, 57, 5, 46, 9, 54, 4, 85, 7, 21, 8, 91, 
    8, 76, 3, 31, 0, 94, 4, 13, 7, 52, 5, 52, 9, 83, 2, 38, 1, 16, 6, 88, 
    0, 58, 4, 90, 7, 84, 6, 93, 2, 91, 3, 85, 1, 52, 9,  2, 5, 77, 8, 32, 
    1, 20, 5, 75, 4, 45, 3, 87, 6, 67, 9,  2, 8,  6, 0,  1, 2, 36, 7, 24
  };
  const int r874[] = {
    10, 10, // Number of jobs and machines
    5, 24, 6, 14, 1, 33, 3, 14, 0, 81, 4, 21, 2, 68, 8, 98, 7, 62, 9, 51, 
    0, 43, 8,  2, 7, 25, 1, 21, 2, 51, 5, 62, 6, 18, 4, 85, 3, 13, 9, 91, 
    6, 39, 3,  2, 5, 24, 9, 78, 7, 32, 4, 75, 2, 76, 1, 45, 8, 13, 0, 56, 
    6, 56, 8, 21, 2, 97, 0, 37, 5, 57, 9, 99, 7, 35, 1,  5, 4, 64, 3, 19, 
    2, 17, 6,  3, 1, 47, 4, 44, 7, 66, 3, 83, 0,  6, 5, 47, 9, 63, 8, 52, 
    8, 56, 2, 90, 3, 36, 0, 67, 6, 12, 4, 19, 5, 45, 1, 15, 7, 73, 9, 66, 
    9, 36, 1, 11, 0, 80, 7, 89, 4, 44, 8, 50, 2, 45, 5, 56, 6,  3, 3, 21, 
    0, 82, 5, 97, 9,  1, 7, 44, 2,  1, 3, 69, 4, 90, 1, 38, 8, 31, 6, 73, 
    8, 68, 6, 93, 4, 27, 0, 15, 7, 37, 2,  2, 3, 81, 9, 49, 1, 50, 5, 13, 
    7, 14, 2, 54, 1,  4, 6,  9, 4, 43, 0, 26, 8, 44, 3, 82, 9, 22, 5, 51
  };
  const int r875[] = {
    10, 10, // Number of jobs and machines
    5, 89, 9, 67, 0,  4, 1, 99, 2, 81, 3, 50, 7, 82, 4, 12, 8, 21, 6, 62, 
    0, 83, 9, 68, 3, 25, 1,  8, 2,  1, 6, 78, 7, 78, 8, 25, 5, 10, 4, 58, 
    5,  1, 0,  3, 1, 74, 3, 83, 4, 98, 7, 38, 6, 55, 9, 70, 2,  7, 8, 37, 
    5, 54, 1, 38, 2, 51, 0, 34, 6, 97, 9, 68, 3,  4, 8, 44, 4, 63, 7, 35, 
    1, 67, 9, 35, 3, 13, 0, 21, 7, 65, 5, 55, 2, 11, 6,  6, 8, 23, 4,  7, 
    3, 56, 4, 79, 7, 92, 9,  3, 2,  9, 0, 70, 6, 14, 8, 62, 5, 97, 1, 17, 
    9, 59, 3, 66, 0, 96, 5, 61, 4, 29, 2, 62, 1, 23, 8, 16, 6, 71, 7, 74, 
    6, 15, 2, 23, 4, 47, 1, 46, 8, 41, 3, 88, 5, 47, 9, 26, 7, 94, 0, 99, 
    8, 51, 0,  4, 9, 68, 3, 94, 2, 15, 7, 11, 6, 46, 4, 17, 1, 56, 5, 15, 
    7, 93, 2, 15, 0, 77, 5, 99, 4, 31, 6, 54, 3, 28, 1, 88, 9, 54, 8, 73
  };
  const int r876[] = {
    10, 10, // Number of jobs and machines
    7, 55, 6, 27, 2, 63, 9, 65, 3, 60, 4, 26, 5, 79, 0, 92, 1, 18, 8, 84, 
    3, 58, 9, 18, 7, 26, 8, 48, 5, 97, 4, 48, 1, 87, 6,  9, 0, 16, 2, 13, 
    9, 64, 3, 89, 4, 36, 5, 52, 8, 44, 0,  5, 2, 74, 7, 61, 1, 13, 6, 85, 
    0, 96, 9, 12, 5, 34, 4, 82, 3, 80, 8, 16, 7, 51, 6, 81, 2, 63, 1, 27, 
    9,  8, 2, 86, 1, 24, 3, 44, 6, 61, 4, 15, 5, 92, 7, 48, 0, 14, 8, 27, 
    2, 75, 7, 11, 8, 36, 9, 53, 6, 29, 0, 90, 5, 15, 1, 26, 3, 39, 4, 75, 
    0, 78, 1,  6, 6,  3, 2, 58, 7, 74, 9, 55, 5, 87, 4, 98, 3, 59, 8, 48, 
    5, 78, 9, 76, 4, 53, 0, 21, 2, 49, 1, 58, 7, 29, 6, 44, 8, 90, 3, 15, 
    4, 72, 9, 15, 6, 65, 3, 79, 5, 87, 8, 71, 1, 49, 7, 97, 0, 66, 2, 21, 
    2, 11, 0, 87, 3, 48, 8, 89, 1, 23, 6, 16, 9,  1, 4, 49, 7, 70, 5,  5
  };
  const int r877[] = {
    10, 10, // Number of jobs and machines
    0, 55, 1,  1, 2, 18, 5, 55, 8, 28, 4, 88, 6, 28, 7, 80, 9, 26, 3, 39, 
    0, 90, 5,  4, 1, 36, 3, 97, 9, 11, 8, 68, 4, 82, 6,  3, 7, 97, 2, 86, 
    4, 51, 5, 22, 1, 14, 7, 13, 6, 24, 3, 67, 8, 46, 9, 45, 2, 60, 0, 56, 
    3, 61, 8, 79, 6, 21, 5, 82, 0, 59, 4, 55, 1, 31, 2, 56, 7, 92, 9, 21, 
    4, 22, 1, 49, 5, 37, 0,  1, 3, 55, 6, 81, 8, 90, 7, 86, 9, 53, 2, 31, 
    4, 17, 5, 65, 2,  4, 9, 75, 7, 27, 0, 39, 1, 95, 6,  8, 8, 51, 3, 90, 
    2, 48, 0, 13, 4, 56, 1, 10, 5,  9, 9, 64, 8, 53, 7, 98, 6, 73, 3, 91, 
    9, 36, 8, 21, 2, 58, 0, 62, 7, 15, 6, 13, 5, 79, 1, 32, 3, 86, 4, 43, 
    1, 34, 9, 63, 7, 33, 3, 43, 5, 54, 0, 51, 8, 39, 4, 93, 2, 63, 6, 94, 
    1, 37, 3, 45, 2,  4, 9, 70, 4, 14, 6, 57, 0, 92, 8, 17, 5,  5, 7, 81
  };
  const int r878[] = {
    10, 10, // Number of jobs and machines
    2,  2, 3, 12, 6, 96, 0, 14, 7, 65, 5,  7, 8, 99, 9, 61, 4, 40, 1, 89, 
    9,  3, 2, 70, 4, 49, 8, 65, 0, 65, 1,  3, 3, 71, 7,  8, 6, 11, 5, 45, 
    0, 32, 8, 41, 6, 59, 1, 68, 9, 81, 4, 11, 7, 69, 3, 78, 5, 25, 2, 79, 
    2, 71, 0, 19, 1,  7, 7, 92, 3, 34, 9, 53, 5, 18, 6, 60, 4,  2, 8, 18, 
    6,  8, 9, 33, 0, 20, 3, 23, 8, 35, 7, 58, 2, 40, 4, 83, 1, 92, 5, 76, 
    9, 62, 5, 84, 1, 86, 2, 46, 4, 11, 3, 97, 8, 17, 6, 76, 0, 45, 7,  4, 
    6, 28, 9, 21, 2, 51, 4, 14, 7, 52, 0,  5, 5, 37, 8, 13, 3, 55, 1, 45, 
    7, 28, 1, 85, 2,  2, 0, 28, 9, 72, 5, 54, 8, 69, 4, 90, 3, 44, 6, 98, 
    7, 91, 5, 44, 3, 73, 6, 87, 9, 84, 1, 84, 2, 56, 4,  1, 0, 73, 8, 64, 
    1, 53, 7, 20, 3, 30, 4, 46, 5, 56, 0, 28, 8, 30, 9, 19, 2, 16, 6, 24
  };
  const int r879[] = {
    10, 10, // Number of jobs and machines
    5, 51, 9, 20, 7, 99, 0, 21, 2, 12, 3, 71, 8, 28, 1, 40, 4,  7, 6, 96, 
    4, 92, 5, 20, 9, 17, 7, 45, 1, 30, 8,  2, 3, 54, 6, 44, 2,  3, 0, 44, 
    3, 61, 9, 10, 2, 34, 5,  5, 6, 81, 4, 12, 8, 34, 0, 48, 1, 48, 7, 84, 
    3, 22, 7, 76, 5, 32, 6, 86, 8, 71, 4, 79, 9, 80, 2, 21, 1, 16, 0, 16, 
    0, 95, 1, 11, 5,  5, 8,  5, 4,  9, 6, 40, 2, 76, 7, 81, 3, 31, 9, 14, 
    7, 64, 5, 87, 8, 81, 1, 28, 3, 94, 2, 69, 0, 40, 9, 39, 6, 39, 4, 40, 
    5, 45, 0, 44, 4, 19, 1, 73, 8, 25, 2, 22, 6, 40, 3, 32, 9, 61, 7, 54, 
    4, 86, 2, 22, 6, 69, 7, 53, 8, 69, 0, 40, 3, 90, 1, 41, 5, 51, 9, 75, 
    0, 45, 6,  3, 9, 32, 1, 59, 5,  5, 8, 13, 4, 83, 3, 98, 7, 56, 2, 92, 
    1, 33, 0, 10, 7, 38, 8, 38, 4, 48, 2,  9, 6, 10, 3, 73, 5, 71, 9, 47
  };
  const int r880[] = {
    10, 10, // Number of jobs and machines
    3, 56, 4, 98, 0,  9, 5, 98, 6, 53, 7, 21, 2, 24, 9, 38, 1, 65, 8, 15, 
    4, 29, 5, 33, 1, 20, 9, 85, 0, 24, 3, 93, 2, 26, 6, 60, 7, 66, 8, 32, 
    6, 44, 3, 74, 7, 60, 5, 46, 8, 78, 4, 56, 2, 37, 1, 13, 0, 78, 9, 89, 
    0, 56, 3, 23, 7, 99, 1, 64, 8, 97, 2, 50, 6, 88, 9, 29, 4, 58, 5,  2, 
    0, 92, 4, 92, 3, 27, 5, 41, 8, 29, 2, 98, 6,  7, 9, 44, 7, 25, 1, 51, 
    6, 10, 0,  7, 4, 41, 1, 80, 7, 27, 8, 44, 3,  3, 2, 88, 9, 70, 5, 40, 
    8, 89, 5, 24, 3, 51, 9, 11, 7, 33, 2, 50, 4, 12, 1, 17, 6, 92, 0, 63, 
    9, 77, 3,  2, 8, 87, 0, 15, 7, 87, 2, 25, 1, 93, 5, 97, 4, 73, 6, 99, 
    2, 45, 0, 20, 4, 90, 5, 99, 8, 37, 6, 93, 9, 91, 3, 57, 1, 69, 7, 48, 
    2, 88, 8, 89, 1, 31, 5, 55, 4, 32, 7, 54, 9, 56, 0, 40, 6,  6, 3, 27
  };
  const int r881[] = {
    10, 10, // Number of jobs and machines
    9, 62, 4, 19, 0, 86, 8, 90, 2, 56, 6, 91, 5, 39, 3, 41, 7,  8, 1, 82, 
    7, 92, 9, 97, 8, 13, 2, 10, 6, 72, 1, 90, 5, 22, 4, 78, 0, 35, 3, 13, 
    0, 91, 9, 43, 2, 35, 3, 27, 6, 15, 1, 66, 7, 52, 8, 20, 4, 63, 5, 22, 
    8, 59, 6, 54, 5,  6, 3, 44, 2, 90, 0, 82, 9, 25, 4, 80, 7, 33, 1, 97, 
    6,  6, 4, 31, 3, 84, 5, 52, 0, 46, 9, 13, 7, 64, 1,  7, 2, 76, 8, 31, 
    5, 70, 1, 52, 6, 49, 2, 73, 8, 13, 3, 33, 4, 94, 0, 32, 7, 71, 9, 85, 
    7,  9, 1, 10, 3, 85, 4, 46, 5,  7, 0, 44, 8, 32, 9, 28, 2, 62, 6, 28, 
    6, 18, 0,  9, 1, 33, 4, 99, 9, 92, 2, 14, 5, 30, 8, 76, 3, 85, 7, 65, 
    6, 81, 8, 29, 4, 72, 9, 44, 5, 35, 0,  7, 2, 47, 1, 60, 3, 79, 7, 40, 
    5, 34, 6, 42, 7, 17, 8, 80, 3, 69, 1,  3, 2, 41, 0, 20, 4, 64, 9,  5
  };
  const int r882[] = {
    10, 10, // Number of jobs and machines
    5,  2, 6, 41, 8,  3, 0, 24, 7, 78, 4, 91, 9, 83, 2, 46, 1, 18, 3, 78, 
    6, 82, 7, 61, 5, 19, 2, 29, 3, 34, 8, 10, 4, 55, 1, 75, 9, 63, 0, 56, 
    5, 72, 4,  8, 0, 11, 7, 28, 2, 25, 1, 85, 8, 70, 9, 85, 6, 26, 3, 79, 
    5, 86, 4, 76, 6, 63, 8, 17, 9, 21, 0,  6, 7, 94, 3, 24, 1, 11, 2, 83, 
    8, 54, 6, 70, 4, 42, 7, 56, 1, 12, 5, 30, 2, 22, 0,  6, 9, 48, 3, 80, 
    5, 16, 1, 92, 2, 77, 4,  9, 3, 26, 6, 92, 9, 24, 8, 23, 0, 67, 7, 12, 
    1, 71, 4, 17, 9, 31, 8, 91, 2, 17, 3, 58, 7, 52, 0, 39, 5, 33, 6, 31, 
    8, 29, 1, 86, 4,  2, 3, 91, 6, 21, 7, 78, 0, 23, 2, 95, 5, 12, 9, 43, 
    1,  8, 7, 30, 0, 15, 5, 27, 2, 65, 8, 31, 9, 24, 3, 38, 6, 40, 4, 78, 
    1, 65, 5, 94, 9, 28, 4, 94, 0, 12, 7, 37, 6,  6, 3, 11, 2,  7, 8, 40
  };
  const int r883[] = {
    10, 10, // Number of jobs and machines
    6, 36, 3, 48, 7, 40, 4, 33, 5,  3, 9,  6, 1, 80, 2, 61, 0,  6, 8, 57, 
    6, 16, 8, 72, 5, 29, 0, 28, 4, 13, 1, 70, 9, 40, 2, 37, 3, 62, 7, 40, 
    9, 30, 7, 87, 3, 72, 1, 18, 2, 90, 8, 22, 6, 55, 0, 74, 5, 22, 4, 72, 
    1, 63, 7, 19, 2, 66, 5, 42, 4, 56, 0, 21, 8, 70, 3, 22, 6,  7, 9, 88, 
    9, 59, 7, 30, 0, 33, 4, 10, 1, 91, 2, 23, 6, 95, 5,  1, 3, 45, 8, 78, 
    9, 59, 6, 36, 2, 41, 0, 15, 8,  8, 1, 20, 5, 21, 3, 57, 4, 97, 7, 12, 
    0, 61, 8, 62, 3, 83, 7, 15, 2, 21, 5, 17, 1, 45, 4, 87, 6, 16, 9,  6, 
    0, 17, 3, 95, 5, 69, 7, 40, 2, 99, 1, 34, 4, 50, 9, 35, 8, 26, 6, 47, 
    5, 84, 0, 87, 7, 77, 6,  3, 9, 92, 2, 96, 8, 56, 3, 64, 4, 43, 1, 44, 
    8,  2, 0, 67, 4, 64, 5, 11, 6, 14, 2, 53, 7, 61, 1, 36, 3, 65, 9, 73
  };
  const int r884[] = {
    10, 10, // Number of jobs and machines
    8, 54, 2, 19, 7, 46, 3, 59, 6, 41, 9, 93, 4, 54, 0, 18, 1,  4, 5, 52, 
    5, 23, 6, 79, 3, 55, 4, 64, 8, 14, 2, 29, 9, 91, 0,  2, 1, 60, 7, 76, 
    1, 40, 5, 41, 4, 58, 3, 66, 2, 56, 7, 39, 8, 10, 0, 72, 9, 42, 6, 75, 
    9, 66, 1, 98, 6, 76, 8, 43, 3, 48, 4, 59, 7, 54, 5, 63, 2, 87, 0, 54, 
    4, 18, 1, 90, 0, 73, 5, 14, 2, 84, 8, 60, 6, 56, 9, 35, 7, 36, 3, 43, 
    3, 67, 1, 94, 2, 33, 7, 74, 6, 89, 5, 55, 4, 68, 8, 58, 9, 19, 0, 57, 
    3, 54, 5, 64, 4, 78, 9, 94, 0, 49, 2, 67, 7, 47, 8, 48, 6, 49, 1, 87, 
    1, 81, 0, 33, 2, 29, 4, 39, 5, 17, 3, 45, 8, 75, 7,  8, 9, 82, 6, 41, 
    6, 78, 8,  9, 7, 80, 5, 93, 4,  7, 9, 94, 3, 77, 1, 33, 0, 78, 2, 37, 
    8, 75, 1, 93, 7, 82, 0, 74, 9, 91, 5, 38, 4, 19, 2, 13, 3, 97, 6, 16
  };
  const int r885[] = {
    10, 10, // Number of jobs and machines
    2, 51, 0, 19, 6, 33, 4, 77, 9, 21, 5, 88, 3, 93, 7, 28, 1, 10, 8, 60, 
    2, 27, 8, 17, 6, 46, 4, 63, 1, 93, 3, 33, 9, 13, 5, 45, 7,  7, 0, 68, 
    0, 84, 3, 23, 1, 24, 8, 34, 5, 71, 7,  2, 2, 36, 4, 47, 9, 62, 6, 11, 
    8, 76, 7, 62, 3, 81, 5, 35, 1,  3, 4,  1, 0, 44, 9, 15, 6, 10, 2, 66, 
    7, 65, 6, 40, 1, 50, 9, 63, 2, 69, 0, 57, 8,  5, 3, 88, 4, 75, 5, 86, 
    8, 54, 5, 29, 7, 30, 6, 78, 3, 52, 4, 72, 1, 98, 0, 15, 9, 50, 2, 78, 
    4, 20, 5, 31, 7, 50, 2, 93, 0,  4, 6, 43, 8, 76, 9, 99, 3,  5, 1, 23, 
    4, 93, 3, 79, 8, 26, 2, 13, 5, 20, 7, 21, 1, 63, 0, 93, 9, 39, 6, 29, 
    5, 54, 2, 43, 3, 84, 0, 54, 7, 99, 1, 38, 4, 49, 6, 44, 9, 81, 8, 67, 
    1, 70, 3, 60, 7, 81, 0, 83, 4, 14, 9, 39, 6, 76, 5, 10, 8, 68, 2, 23
  };
  const int r886[] = {
    10, 10, // Number of jobs and machines
    2,  3, 3, 31, 9, 21, 7, 62, 8, 17, 4, 92, 5, 94, 6, 71, 0,  3, 1, 41, 
    6, 87, 2, 32, 9, 91, 0, 41, 1, 66, 7, 39, 8, 99, 4, 67, 5, 73, 3, 77, 
    7, 49, 2, 19, 9, 83, 3, 89, 1, 91, 4, 31, 8,  2, 6,  8, 5, 23, 0, 37, 
    8, 70, 7, 40, 5,  5, 3, 99, 9,  5, 0, 80, 6, 31, 1, 62, 2, 97, 4,  1, 
    5, 72, 9, 94, 7, 60, 6, 26, 2, 89, 1, 96, 8, 31, 4, 31, 0, 20, 3, 66, 
    1, 36, 3, 46, 2, 87, 4, 17, 9, 50, 6, 13, 0, 56, 8, 35, 5, 97, 7, 11, 
    6,  2, 1, 91, 2, 93, 8, 24, 0, 38, 5,  2, 3, 25, 9,  9, 7, 41, 4, 75, 
    9, 35, 0, 96, 6, 30, 4,  4, 8, 46, 7, 47, 3, 87, 5, 82, 1, 15, 2, 42, 
    7, 10, 4, 54, 5, 59, 8,  8, 0,  3, 1, 59, 6, 75, 9, 16, 2, 31, 3, 28, 
    1, 23, 2, 17, 7, 68, 3, 53, 9, 94, 4, 43, 8, 51, 0, 39, 6, 72, 5, 88
  };
  const int r887[] = {
    10, 10, // Number of jobs and machines
    8, 83, 3, 46, 4, 96, 1, 87, 7, 52, 9, 35, 0, 95, 6, 75, 5,  9, 2, 11, 
    8, 62, 2, 36, 6, 90, 3, 54, 7, 65, 0, 27, 1, 26, 5, 34, 4, 70, 9, 44, 
    9, 43, 7, 27, 8, 75, 5,  5, 4,  4, 2, 65, 0, 16, 3, 38, 1, 79, 6, 46, 
    0, 25, 9, 38, 5, 32, 8, 31, 1, 44, 2, 39, 7, 87, 4, 11, 6, 12, 3, 52, 
    7, 37, 4, 72, 0, 99, 9, 10, 5, 24, 1,  1, 8, 65, 6,  9, 2, 38, 3, 32, 
    1,  8, 3, 90, 4, 50, 6, 71, 2, 37, 5, 80, 7, 12, 8, 20, 0, 73, 9, 87, 
    5, 18, 0, 32, 3, 75, 2, 76, 6, 58, 9, 57, 7, 82, 8, 47, 1, 88, 4, 15, 
    4, 76, 5, 93, 7, 70, 3, 83, 0, 88, 2, 69, 1, 33, 9, 13, 6,  4, 8, 35, 
    0, 41, 3, 11, 1, 85, 4, 36, 2, 91, 8, 66, 9, 20, 5, 92, 7, 11, 6, 30, 
    5, 83, 4, 50, 7, 44, 1, 91, 2, 56, 9, 51, 6, 86, 0, 31, 3, 15, 8, 92
  };
  const int r888[] = {
    10, 10, // Number of jobs and machines
    3, 98, 6, 59, 8, 17, 5, 27, 2, 84, 7, 78, 9, 12, 0, 93, 1, 82, 4,  2, 
    5, 54, 1, 10, 6, 88, 3, 77, 8, 82, 2, 12, 4, 30, 7, 32, 9, 39, 0, 65, 
    1, 73, 3, 39, 0, 90, 5,  5, 8, 16, 9, 25, 6, 26, 4, 70, 7, 28, 2, 94, 
    7, 70, 6,  8, 5, 65, 3, 93, 8, 74, 0,  3, 1,  5, 9, 63, 4, 61, 2, 40, 
    1, 76, 8, 99, 7, 73, 4, 25, 6, 67, 3, 18, 2, 25, 0, 20, 9, 47, 5, 48, 
    1, 61, 9, 83, 6, 78, 0, 93, 7,  7, 2, 18, 3, 64, 8, 67, 5, 87, 4, 49, 
    6, 48, 1, 38, 4, 55, 0, 29, 9, 99, 5, 21, 8, 28, 7, 84, 3, 20, 2, 86, 
    8, 79, 2, 90, 5, 90, 9, 41, 4, 27, 6, 94, 7, 30, 3, 34, 0, 74, 1, 74, 
    8, 58, 9, 60, 5, 13, 2,  1, 3, 34, 4, 94, 7, 96, 6, 64, 0, 52, 1,  2, 
    7, 53, 5, 60, 6,  4, 3, 95, 2, 18, 9, 60, 0, 31, 8, 42, 4, 70, 1, 96
  };
  const int r889[] = {
    10, 10, // Number of jobs and machines
    7, 21, 1, 17, 4, 59, 6,  6, 5, 54, 2, 36, 3, 34, 9, 71, 8, 94, 0, 36, 
    7,  8, 9, 59, 3, 42, 4, 49, 0, 65, 8, 98, 1, 31, 6, 28, 2, 78, 5, 36, 
    6, 28, 8, 77, 2, 22, 0, 38, 4, 98, 5,  5, 1, 10, 3, 76, 7, 54, 9, 51, 
    8, 50, 9, 32, 7, 28, 2, 11, 5, 70, 6, 64, 0, 68, 3, 47, 1, 47, 4, 19, 
    8, 12, 7, 86, 5, 17, 2, 33, 4, 82, 6, 88, 0, 10, 3, 74, 1, 79, 9, 92, 
    3, 51, 6, 43, 7, 95, 9, 63, 8, 32, 0, 12, 4,  4, 1, 48, 2, 11, 5, 38, 
    1, 90, 3, 18, 2,  1, 5, 27, 7, 26, 9, 58, 8, 69, 6, 50, 4, 66, 0, 93, 
    4, 49, 0, 51, 7, 56, 6, 76, 8, 46, 1, 96, 5, 57, 3, 92, 9,  3, 2, 65, 
    2, 24, 0, 59, 9, 91, 3, 89, 5, 11, 8, 51, 1, 69, 4, 88, 6, 22, 7, 59, 
    2, 53, 3, 32, 7, 27, 5, 13, 0, 65, 1, 29, 9, 51, 8, 57, 6, 32, 4,  7
  };
  const int r890[] = {
    10, 10, // Number of jobs and machines
    3, 77, 7, 27, 2, 82, 9, 47, 4, 55, 1, 52, 0, 53, 5, 96, 6, 60, 8, 67, 
    1,  6, 9, 91, 4, 71, 8, 16, 7, 84, 2, 41, 3, 19, 5, 17, 6,  2, 0, 70, 
    8,  1, 7, 88, 4, 28, 1, 42, 0, 31, 5, 75, 9, 53, 2, 78, 3, 35, 6, 92, 
    8, 30, 5, 26, 1, 42, 7, 71, 3,  1, 9, 41, 6, 33, 2, 55, 0, 55, 4,  5, 
    5, 97, 2, 57, 6, 66, 7, 70, 8, 48, 1, 96, 4, 50, 3, 57, 9, 86, 0, 13, 
    6, 55, 2, 34, 7, 34, 0, 65, 5, 65, 8, 64, 9, 93, 3, 98, 1, 43, 4, 90, 
    3, 72, 8, 28, 5, 82, 7, 40, 9,  3, 0, 16, 6, 31, 1, 14, 4, 75, 2,  7, 
    6, 83, 8, 25, 2, 15, 0, 96, 4, 77, 5, 20, 1, 70, 3,  6, 9,  9, 7, 14, 
    3,  6, 2,  7, 8, 55, 7, 79, 9, 47, 0, 54, 4, 77, 1, 71, 6, 20, 5, 97, 
    3, 19, 7, 31, 9, 21, 1, 79, 4, 58, 0, 36, 2, 83, 8, 80, 5, 87, 6, 69
  };
  const int r891[] = {
    10, 10, // Number of jobs and machines
    2, 62, 1, 94, 5, 52, 8, 15, 0,  2, 9, 46, 6, 89, 7,  5, 4, 29, 3, 23, 
    7,  1, 3, 13, 8, 46, 0, 87, 1, 39, 6, 84, 5, 79, 4, 33, 2, 27, 9, 54, 
    5, 84, 6,  1, 7, 55, 2, 56, 8, 23, 4, 71, 0, 56, 1, 47, 9,  1, 3, 33, 
    8, 62, 4, 69, 7, 60, 5,  6, 6, 22, 1, 82, 0, 74, 2, 41, 3, 85, 9, 55, 
    1, 82, 6,  9, 9, 91, 3, 66, 8, 17, 7, 79, 0, 63, 5, 52, 4, 12, 2, 53, 
    0, 85, 9, 55, 1, 40, 6, 31, 7, 62, 8, 42, 5, 78, 4,  3, 2, 88, 3, 55, 
    9, 90, 4, 96, 3, 51, 5, 80, 2, 41, 8, 28, 7, 28, 6, 49, 1, 91, 0, 83, 
    9, 28, 1,  2, 2, 53, 5, 50, 0, 65, 8,  4, 3, 17, 6, 60, 7, 78, 4,  2, 
    9, 65, 6, 59, 8, 40, 1, 56, 3,  4, 4, 83, 7,  7, 2, 65, 5, 35, 0, 78, 
    2, 64, 9, 15, 1, 41, 7, 94, 0, 54, 6, 61, 3,  8, 5, 64, 8, 50, 4, 32
  };
  const int r892[] = {
    10, 10, // Number of jobs and machines
    1, 26, 5, 49, 6, 89, 2, 28, 9, 94, 4, 28, 0, 42, 8, 62, 3,  6, 7, 10, 
    4, 28, 7, 88, 3, 82, 8, 56, 9, 15, 1, 97, 0, 40, 6, 27, 5, 77, 2, 33, 
    9, 78, 7, 23, 6, 71, 3,  2, 0, 51, 1, 65, 4,  6, 5, 44, 8, 32, 2, 26, 
    9, 32, 1, 46, 8, 20, 2, 86, 6,  6, 3, 88, 5, 76, 0, 89, 4, 64, 7, 84, 
    7, 65, 0, 59, 3, 67, 6, 82, 1,  1, 9, 65, 4, 49, 5, 45, 2, 59, 8, 75, 
    0, 96, 2, 29, 6, 45, 1, 21, 3,  8, 9, 47, 5, 90, 7, 46, 4, 23, 8, 18, 
    1, 70, 4, 33, 6, 92, 2,  7, 9, 45, 3, 63, 5, 23, 7,  1, 0, 77, 8, 62, 
    7, 16, 2, 99, 9, 62, 4, 45, 6, 44, 3, 25, 1, 33, 0, 27, 8, 98, 5, 12, 
    6, 58, 1, 70, 4, 98, 3, 69, 8,  8, 5, 15, 7, 31, 9, 77, 2, 80, 0, 20, 
    7, 74, 9, 61, 4, 91, 1, 30, 6, 44, 2,  9, 8, 82, 0, 70, 5,  7, 3, 29
  };
  const int r893[] = {
    10, 10, // Number of jobs and machines
    6, 64, 2, 42, 1, 71, 4, 82, 9, 56, 5, 84, 7,  1, 8, 23, 0, 76, 3, 81, 
    5, 16, 9,  7, 8, 50, 3, 20, 6, 26, 7, 37, 1, 96, 4, 87, 2, 73, 0, 17, 
    6, 62, 9, 42, 4, 96, 5, 57, 8, 23, 7, 54, 1, 25, 2, 10, 0, 81, 3,  3, 
    1, 81, 8, 59, 5, 80, 0, 15, 9, 87, 7, 24, 2, 60, 4,  8, 3, 20, 6, 87, 
    8, 38, 1, 98, 7, 44, 6, 34, 0, 47, 3, 79, 9, 13, 5, 75, 2, 66, 4, 63, 
    8,  2, 4, 75, 7, 24, 9,  3, 2, 73, 5, 85, 0, 76, 1,  3, 3, 96, 6, 45, 
    1, 94, 9, 28, 7, 82, 4, 83, 0, 23, 6, 80, 2, 44, 3,  5, 5, 19, 8, 17, 
    8, 21, 5,  4, 7, 70, 9, 97, 1, 27, 2, 98, 3,  8, 0, 56, 6, 12, 4,  9, 
    0, 73, 2, 26, 8, 30, 9, 39, 3, 49, 7, 61, 6, 96, 1, 43, 4, 68, 5, 13, 
    9,  8, 3, 63, 4, 18, 8, 66, 0, 44, 5, 49, 1,  3, 7, 75, 2, 71, 6, 19
  };
  const int r894[] = {
    10, 10, // Number of jobs and machines
    1,  7, 5, 13, 4,  5, 8, 90, 9, 59, 0, 26, 2, 68, 6, 99, 3, 72, 7, 94, 
    8, 29, 5, 42, 4, 91, 1, 29, 0, 52, 2, 97, 7, 37, 3, 19, 6, 64, 9, 96, 
    9, 99, 5, 44, 4, 10, 0, 25, 1, 33, 8, 83, 2, 46, 3, 13, 6, 81, 7, 70, 
    9, 54, 4, 51, 6, 92, 7, 40, 5, 57, 2, 12, 3, 37, 1, 94, 0,  4, 8,  9, 
    1, 26, 4, 47, 3, 41, 6, 24, 0, 31, 2, 57, 8, 81, 7, 52, 9, 44, 5, 66, 
    2, 18, 9, 15, 3, 78, 7,  2, 6, 73, 1, 10, 5, 34, 0, 89, 8, 77, 4, 24, 
    5, 74, 1, 95, 4,  9, 0, 23, 9, 73, 2, 58, 8, 16, 7, 57, 3, 78, 6, 37, 
    8, 47, 4, 47, 1, 83, 3, 36, 2, 10, 5, 90, 7, 93, 0, 41, 6, 77, 9, 12, 
    4,  6, 5,  4, 2, 42, 7, 14, 1, 40, 6, 59, 9, 17, 0, 84, 8, 38, 3, 34, 
    2, 89, 4, 81, 5, 73, 9, 28, 7, 68, 3, 10, 8, 69, 0,  1, 6, 77, 1, 15
  };
  const int r895[] = {
    10, 10, // Number of jobs and machines
    5, 68, 0,  8, 6, 95, 7, 14, 3, 71, 1, 40, 4, 42, 2, 80, 8, 85, 9, 92, 
    2, 68, 5, 32, 6,  8, 9, 11, 4, 83, 8, 29, 7, 65, 0, 15, 3, 77, 1, 70, 
    6, 15, 7, 46, 1, 28, 9, 41, 8, 86, 3, 39, 4, 45, 0, 47, 2, 13, 5,  5, 
    8, 79, 7,  6, 6, 48, 1, 37, 2, 17, 5, 25, 0, 54, 4,  6, 3, 59, 9, 19, 
    8, 22, 4, 37, 1, 87, 6, 65, 3, 29, 5, 81, 9, 91, 7, 89, 2, 33, 0, 53, 
    8, 99, 0, 81, 1, 34, 7, 31, 2, 83, 3, 37, 6, 79, 9, 13, 5, 99, 4, 68, 
    0, 46, 9, 20, 7, 10, 5, 33, 4, 20, 3, 82, 1, 74, 6, 44, 2,  6, 8, 50, 
    0, 74, 4, 89, 8, 62, 3,  6, 9, 74, 2, 41, 6, 34, 1, 34, 5, 30, 7, 54, 
    8, 61, 4,  9, 9, 56, 5, 22, 1, 70, 7, 82, 2, 40, 6, 59, 0, 14, 3, 19, 
    9, 84, 4, 30, 8,  5, 7, 83, 1, 51, 5, 33, 6, 40, 2, 73, 0, 47, 3, 35
  };
  const int r896[] = {
    10, 10, // Number of jobs and machines
    2, 86, 7, 98, 8, 70, 5, 88, 4, 25, 6, 71, 3,  2, 1, 48, 9, 84, 0, 43, 
    4, 27, 8, 85, 3, 79, 5, 75, 7, 26, 2, 80, 0, 24, 9, 68, 6, 79, 1, 65, 
    6, 43, 5, 35, 2, 75, 9, 54, 4, 53, 7, 74, 3, 37, 0, 81, 1, 56, 8, 89, 
    3, 60, 4, 14, 2, 76, 8, 24, 5, 38, 9, 68, 6,  3, 1, 25, 0, 21, 7, 38, 
    3, 69, 9, 99, 4, 20, 6, 13, 7, 49, 5, 92, 1, 25, 2, 61, 0, 58, 8, 88, 
    1,  7, 2, 70, 8,  2, 0, 35, 4, 34, 7, 47, 3,  9, 5, 96, 9, 72, 6, 69, 
    0, 12, 7,  1, 4, 58, 5, 45, 8, 54, 9, 24, 1, 86, 6, 30, 2, 29, 3, 58, 
    0, 14, 9, 86, 4, 23, 2, 78, 6, 20, 1, 66, 5, 18, 8, 43, 3, 75, 7, 76, 
    4, 19, 5, 19, 3,  5, 8, 68, 0, 31, 9, 64, 1, 54, 6,  5, 7, 33, 2,  3, 
    2, 45, 1, 32, 7, 54, 9, 37, 3, 31, 5,  7, 0, 75, 6, 15, 8, 29, 4,  2
  };
  const int r897[] = {
    10, 10, // Number of jobs and machines
    2, 46, 7, 28, 3, 16, 5, 65, 4, 76, 6,  1, 0, 69, 1, 92, 9, 18, 8, 78, 
    6, 64, 1, 95, 4, 90, 7, 98, 9, 42, 0, 69, 3, 32, 5, 46, 8, 29, 2,  3, 
    4, 94, 1, 85, 8, 33, 5, 63, 2, 51, 9, 70, 0, 18, 6, 22, 7, 11, 3, 73, 
    6, 27, 4, 66, 2, 47, 5, 63, 0, 99, 7, 79, 9, 11, 8, 89, 1, 43, 3, 99, 
    5, 96, 1, 29, 2, 45, 9, 70, 7, 55, 4, 28, 3, 74, 8,  8, 0, 65, 6, 60, 
    8, 38, 1, 89, 0,  6, 9, 23, 3, 30, 2, 34, 7, 51, 5,  2, 6, 30, 4, 47, 
    5, 61, 3,  1, 1,  6, 6, 27, 0, 85, 2, 31, 7, 50, 9, 44, 8, 83, 4, 82, 
    2, 79, 5, 61, 8, 47, 3, 89, 4, 51, 9, 54, 1, 21, 7,  2, 0, 26, 6, 34, 
    1, 88, 2, 11, 8, 37, 7, 18, 3, 66, 5, 89, 6, 29, 9, 67, 4, 35, 0, 35, 
    1, 14, 5, 89, 7, 99, 2, 47, 3, 39, 6, 95, 9, 75, 8, 36, 0, 90, 4, 82
  };
  const int r898[] = {
    10, 10, // Number of jobs and machines
    4, 58, 3, 20, 9, 49, 6, 91, 0, 59, 5, 85, 1,  3, 7, 30, 2,  4, 8,  6, 
    7, 79, 5, 60, 4, 31, 6, 16, 2, 19, 3, 59, 9, 12, 0, 61, 8, 41, 1, 99, 
    9, 36, 5, 33, 3, 68, 6, 60, 1, 41, 7, 20, 8, 28, 2, 59, 4, 81, 0,  1, 
    4, 23, 8, 68, 7, 92, 1, 50, 6, 72, 5, 69, 3, 51, 2, 27, 9, 70, 0,  6, 
    1, 11, 2, 66, 7, 82, 5, 52, 4, 85, 6, 12, 8, 27, 0, 82, 3, 24, 9, 33, 
    3, 73, 2, 92, 6, 13, 4, 10, 1, 32, 7, 76, 9, 17, 0, 80, 8, 15, 5, 55, 
    1, 91, 8, 27, 9, 14, 3, 47, 2, 78, 7, 83, 5,  8, 0, 27, 6, 51, 4, 86, 
    9, 37, 6, 90, 2, 46, 7, 87, 5, 76, 8, 41, 3,  5, 1, 45, 4, 52, 0, 55, 
    6, 35, 4, 64, 9, 34, 1, 18, 3, 23, 2, 82, 5, 95, 8, 49, 7, 54, 0, 94, 
    8,  4, 6, 30, 3,  7, 7, 32, 5, 69, 2, 48, 0, 62, 9, 52, 4, 36, 1, 23
  };
  const int r899[] = {
    10, 10, // Number of jobs and machines
    1,  8, 0, 11, 6, 99, 9, 66, 4, 55, 5, 22, 8, 12, 2, 31, 3, 36, 7, 53, 
    8, 68, 1, 63, 0, 25, 3,  6, 6, 21, 4, 34, 7, 90, 5,  7, 2, 87, 9, 29, 
    2, 18, 7, 77, 9,  9, 6, 71, 1, 90, 5, 87, 4,  9, 8, 63, 3, 39, 0, 88, 
    6,  8, 7, 11, 4,  4, 2, 66, 9, 66, 1, 13, 3, 85, 0, 96, 5, 23, 8, 29, 
    0,  7, 3, 97, 5, 89, 8, 38, 4, 57, 2, 97, 7, 98, 9, 46, 1,  6, 6, 25, 
    4, 32, 0, 99, 3, 68, 9, 78, 8, 85, 1,  1, 6, 45, 2, 47, 5, 41, 7, 62, 
    5, 99, 3, 27, 0, 75, 9, 33, 7, 27, 8, 29, 4, 17, 1, 44, 6, 99, 2, 73, 
    0,  5, 5, 29, 3, 61, 1, 86, 8, 64, 4, 97, 9, 50, 7, 37, 2, 66, 6, 69, 
    1, 48, 7, 11, 4, 92, 8, 28, 2, 63, 6,  7, 9, 84, 3, 65, 5, 20, 0, 65, 
    8, 49, 4, 28, 9, 77, 7, 79, 1, 47, 0, 65, 6, 46, 3, 56, 2, 48, 5, 69
  };
  const int r900[] = {
    10, 10, // Number of jobs and machines
    0, 53, 4, 60, 8, 60, 6, 88, 7, 13, 1,  6, 5, 72, 3, 80, 9, 93, 2, 36, 
    3, 39, 5, 90, 0, 44, 2, 89, 9, 34, 4, 26, 7, 71, 6, 51, 1, 21, 8,  5, 
    3, 25, 1, 58, 4, 12, 0, 44, 6, 20, 8, 29, 2, 47, 7, 18, 5,  6, 9, 28, 
    7, 94, 9, 34, 8, 80, 1, 16, 2, 64, 4,  3, 3, 53, 6, 50, 0, 96, 5, 24, 
    8, 93, 6, 54, 2, 33, 3, 87, 4, 42, 0, 11, 1, 45, 9, 52, 5, 35, 7, 92, 
    7,  7, 0,  2, 9, 14, 3, 11, 1,  8, 2, 52, 8, 37, 4, 90, 5, 40, 6, 27, 
    2, 87, 9, 11, 3, 87, 1, 38, 6, 84, 5, 94, 7, 62, 8, 74, 0, 44, 4, 91, 
    3, 73, 7, 49, 4, 24, 9, 79, 8,  4, 5, 74, 6, 25, 2, 62, 1, 45, 0, 66, 
    9, 41, 5, 90, 4, 11, 0, 71, 6, 69, 7, 43, 2, 57, 8, 22, 1, 52, 3, 82, 
    3,  4, 9,  2, 4,  3, 8, 27, 7, 33, 5, 49, 2, 37, 0, 20, 1, 63, 6, 32
  };
  const int r901[] = {
    10, 10, // Number of jobs and machines
    9, 14, 3, 84, 7, 34, 1, 71, 4, 62, 0, 77, 6, 43, 8, 92, 2, 64, 5, 95, 
    0, 81, 2, 92, 9, 54, 8, 86, 1, 27, 5, 48, 4,  4, 6, 97, 7, 21, 3, 22, 
    8, 49, 5,  9, 2, 23, 4, 81, 9, 71, 6,  1, 0, 54, 1,  5, 7, 22, 3, 21, 
    4, 41, 9, 36, 2, 97, 5, 74, 0, 67, 3,  3, 7, 30, 6, 62, 1, 36, 8, 29, 
    1, 77, 4, 42, 2, 86, 5, 12, 0, 88, 9, 32, 6, 45, 8, 51, 3, 52, 7,  4, 
    8, 17, 2, 55, 5, 12, 1, 12, 6, 70, 9, 99, 7, 65, 0, 36, 3, 71, 4, 89, 
    2, 41, 7, 92, 3, 13, 9, 32, 4, 24, 6, 85, 5, 11, 0, 98, 1, 88, 8,  7, 
    7, 79, 6, 43, 4, 46, 8, 85, 0, 29, 2, 46, 5, 46, 1, 49, 3, 37, 9, 69, 
    3, 43, 0, 51, 8, 46, 5, 68, 9, 57, 1, 38, 4, 86, 7, 44, 2, 11, 6, 79, 
    6, 11, 9, 55, 1, 44, 8, 55, 3, 10, 5,  6, 7, 45, 4, 92, 2, 98, 0, 50
  };
  const int r902[] = {
    10, 10, // Number of jobs and machines
    8, 39, 2, 35, 9, 55, 3, 37, 7, 89, 4, 90, 6, 53, 1, 87, 5, 47, 0, 11, 
    9, 49, 7, 91, 0, 25, 8, 18, 1, 51, 3,  2, 4, 63, 6, 79, 2, 12, 5, 78, 
    4,  3, 1, 25, 7, 44, 6, 14, 2, 22, 5, 39, 3, 19, 8, 47, 0, 36, 9, 77, 
    0, 19, 3, 61, 9,  1, 7, 10, 1, 94, 2, 66, 6, 54, 8, 34, 5, 83, 4, 49, 
    0, 24, 4, 27, 1,  2, 2, 36, 5, 91, 6, 28, 7, 91, 9, 84, 3, 39, 8, 32, 
    9, 99, 2, 98, 6, 67, 3, 78, 7, 17, 4, 37, 8, 12, 1, 21, 5,  9, 0,  7, 
    8, 94, 7, 12, 2, 48, 0, 60, 4, 57, 9, 14, 5, 99, 6,  6, 3, 23, 1, 37, 
    6, 15, 5, 56, 2, 18, 7, 21, 4, 17, 8,  4, 3,  6, 9, 64, 0, 35, 1, 23, 
    8,  7, 4, 66, 9, 63, 0, 85, 7, 12, 3, 40, 1, 12, 6, 21, 5, 21, 2, 52, 
    0, 81, 4,  5, 3, 48, 9, 93, 7, 11, 6,  2, 2, 82, 8, 90, 1, 43, 5, 73
  };
  const int r903[] = {
    10, 10, // Number of jobs and machines
    6, 36, 8, 13, 1, 12, 4, 67, 2, 22, 5, 15, 0, 59, 3, 52, 7, 61, 9, 26, 
    6, 34, 2, 20, 8,  5, 4, 63, 5,  6, 3, 42, 0, 56, 1, 52, 9, 61, 7, 35, 
    4, 64, 7, 84, 2, 91, 9, 22, 6, 49, 5,  6, 8, 35, 1, 70, 0, 44, 3, 12, 
    8, 59, 9, 34, 0,  1, 5, 92, 3, 54, 1, 12, 6, 45, 7, 88, 4,  7, 2, 57, 
    5, 52, 3, 26, 6, 94, 8, 43, 1, 56, 7, 34, 9, 90, 0, 63, 4, 33, 2, 90, 
    8, 72, 1, 99, 4, 20, 7, 10, 0, 89, 2, 12, 9, 98, 6, 35, 3, 68, 5, 21, 
    2, 69, 8,  5, 7, 91, 6,  4, 0,  4, 5, 88, 3,  3, 9, 74, 4, 68, 1, 56, 
    6, 51, 4, 73, 5, 35, 7, 29, 3, 72, 9, 30, 8, 95, 0, 73, 1, 68, 2,  8, 
    4, 30, 5, 20, 0, 71, 1, 93, 7, 84, 3, 16, 2, 91, 8, 67, 6, 54, 9, 92, 
    4, 95, 6, 87, 2, 15, 5, 33, 1, 13, 0, 61, 3, 57, 8, 97, 7, 37, 9, 92
  };
  const int r904[] = {
    10, 10, // Number of jobs and machines
    1, 29, 9, 97, 2, 66, 0, 14, 5, 81, 8, 35, 4, 55, 3, 43, 6, 16, 7,  5, 
    4, 16, 1, 58, 8, 27, 3, 45, 2, 70, 5, 88, 0, 56, 7, 42, 9, 62, 6, 14, 
    7, 87, 9, 56, 1, 81, 8, 53, 3, 29, 2, 47, 5, 33, 4, 44, 0, 23, 6, 53, 
    5, 98, 2, 35, 4, 16, 1, 75, 6, 92, 3, 81, 7, 62, 8, 89, 9, 45, 0, 67, 
    8, 43, 0, 71, 5, 47, 2, 17, 3, 47, 7, 76, 6, 12, 9, 14, 1, 98, 4, 76, 
    7, 66, 4, 36, 6, 80, 3, 53, 5, 11, 0, 35, 9, 70, 1, 58, 8, 38, 2, 74, 
    8,  7, 1, 84, 0, 34, 2, 40, 7, 38, 9, 65, 3, 21, 4, 34, 6, 63, 5, 29, 
    1, 94, 8, 78, 9, 74, 5, 49, 4, 44, 7, 65, 6, 37, 0, 30, 3, 74, 2, 36, 
    5, 10, 7, 40, 6, 59, 8, 43, 9,  5, 2, 20, 0, 76, 1, 36, 3, 76, 4, 54, 
    9, 60, 0, 87, 8, 81, 4, 96, 1, 13, 6, 87, 2, 42, 7,  6, 3, 44, 5, 65
  };
  const int r905[] = {
    10, 10, // Number of jobs and machines
    6, 29, 2, 21, 9, 42, 4,  2, 1, 81, 7, 12, 5, 39, 8, 10, 3, 11, 0, 87, 
    6, 22, 3, 68, 5, 97, 8, 43, 1, 39, 0, 97, 7, 52, 9, 49, 2, 25, 4, 44, 
    7, 62, 2, 45, 5,  1, 3, 35, 1, 50, 4, 94, 9, 83, 8, 52, 0, 45, 6, 49, 
    7, 71, 4, 65, 5, 96, 2, 36, 8, 71, 1, 70, 3, 44, 0, 71, 6, 51, 9,  7, 
    7, 83, 4, 92, 5,  4, 2, 55, 0, 90, 9, 47, 8, 92, 6, 79, 3, 97, 1, 83, 
    5, 76, 7, 62, 8, 65, 0, 64, 2, 72, 9,  6, 4,  5, 3, 99, 1, 36, 6, 18, 
    4, 87, 1, 17, 8, 94, 6,  5, 2, 33, 3, 40, 0, 47, 5, 36, 9, 86, 7,  7, 
    9, 77, 3, 82, 2, 56, 5,  2, 4, 51, 1, 56, 8, 88, 0, 45, 7, 93, 6, 19, 
    4, 28, 0, 21, 7, 91, 3, 35, 8, 66, 1, 98, 6, 41, 5, 65, 2, 81, 9, 41, 
    7, 91, 2, 94, 3, 78, 4, 90, 0, 27, 5, 64, 9, 97, 8, 92, 6, 79, 1, 77
  };
  const int r906[] = {
    10, 10, // Number of jobs and machines
    0, 50, 6, 15, 2, 31, 3, 35, 7, 45, 4, 65, 9, 14, 1, 39, 5, 68, 8,  2, 
    9, 66, 8, 50, 5, 52, 7, 53, 0, 67, 1, 51, 3, 63, 4, 10, 2, 26, 6, 96, 
    7, 47, 6, 63, 1, 50, 0, 98, 9, 39, 3, 55, 8, 12, 5, 53, 2, 14, 4, 48, 
    2, 62, 8, 84, 7, 88, 4, 68, 0, 12, 1, 88, 3, 18, 9, 32, 6, 45, 5,  5, 
    4, 47, 3, 15, 1, 92, 2, 72, 6, 38, 0, 52, 8, 64, 9, 96, 5, 81, 7, 86, 
    3, 32, 6,  3, 5, 97, 4, 49, 7, 81, 0,  9, 1, 66, 2, 52, 9, 92, 8, 56, 
    5, 81, 2, 87, 4, 49, 3, 84, 6, 88, 0, 84, 8, 97, 7,  7, 9, 89, 1, 20, 
    1, 17, 5, 32, 7, 77, 6,  3, 8, 30, 0, 16, 4, 44, 9, 97, 2, 85, 3, 49, 
    2, 45, 5, 25, 3, 29, 6, 74, 8, 15, 0, 88, 1, 11, 7, 84, 4, 54, 9, 17, 
    7, 72, 8, 71, 6, 20, 4, 38, 3, 11, 2, 88, 9,  1, 1, 12, 5, 75, 0, 55
  };
  const int r907[] = {
    10, 10, // Number of jobs and machines
    1, 86, 3, 34, 4,  4, 5, 33, 6, 41, 2, 66, 9, 11, 8, 50, 0, 85, 7, 21, 
    0, 70, 8, 73, 6, 88, 9, 54, 1, 90, 7, 33, 4, 23, 3, 64, 2, 62, 5, 52, 
    3, 47, 9,  7, 4, 65, 1, 99, 0, 91, 8, 89, 2, 66, 5, 84, 6, 78, 7, 39, 
    0, 80, 3, 54, 1, 27, 7, 63, 6,  9, 5, 51, 4, 44, 9, 92, 2, 92, 8, 61, 
    2, 50, 7, 13, 6, 47, 5, 17, 8,  2, 0, 76, 1, 10, 3, 41, 4, 90, 9, 45, 
    5, 78, 1, 88, 0, 28, 3, 89, 6, 45, 7, 59, 2, 77, 4, 35, 8, 31, 9, 84, 
    6, 82, 9, 31, 7, 54, 8, 66, 1, 15, 5, 41, 3, 88, 2, 36, 0, 19, 4,  4, 
    4, 33, 0, 27, 1, 71, 8, 19, 7, 57, 2, 15, 6, 34, 5, 79, 3, 48, 9, 99, 
    4, 85, 6, 41, 2, 72, 9, 91, 5, 68, 1, 52, 8, 92, 3, 33, 7, 76, 0, 14, 
    1, 28, 0, 40, 4, 94, 3, 42, 2, 40, 6, 72, 8, 54, 9, 43, 5, 33, 7, 73
  };
  const int r908[] = {
    10, 10, // Number of jobs and machines
    4, 12, 8, 59, 3, 16, 7, 50, 1, 22, 2, 26, 9, 27, 6, 70, 0, 71, 5, 17, 
    9, 93, 2, 65, 7, 49, 1, 96, 0, 98, 3, 51, 6, 58, 8, 11, 5, 86, 4, 19, 
    4, 76, 6, 73, 7, 91, 5, 35, 8, 63, 1, 80, 9, 85, 0, 27, 3, 80, 2, 87, 
    4, 31, 8,  2, 6,  7, 2, 35, 0, 62, 5, 23, 7, 81, 9, 89, 1, 19, 3, 88, 
    0,  9, 9, 47, 7, 43, 8, 22, 4, 13, 3, 84, 1, 70, 6, 67, 5, 70, 2, 82, 
    8, 75, 9, 78, 2, 63, 6, 86, 7, 66, 4, 27, 5, 84, 1, 60, 3, 41, 0, 31, 
    0,  2, 2, 58, 7, 13, 8, 44, 3, 53, 5, 69, 9, 62, 4, 40, 1, 26, 6, 23, 
    8, 32, 6,  4, 9, 75, 0, 14, 5, 36, 3, 46, 1, 55, 4, 91, 2, 98, 7, 57, 
    8, 48, 6, 50, 7, 15, 3, 41, 9, 32, 5, 84, 2,  8, 4, 86, 0, 35, 1, 14, 
    6, 16, 7, 85, 5, 63, 1, 99, 4, 36, 8, 10, 3, 70, 9, 41, 0, 89, 2,  1
  };
  const int r909[] = {
    10, 10, // Number of jobs and machines
    1, 94, 2,  2, 5, 20, 9, 65, 8, 12, 7, 32, 6, 70, 4, 36, 0, 58, 3, 66, 
    7, 22, 3, 63, 6, 65, 8,  9, 1, 47, 0, 97, 9,  7, 5, 48, 4, 79, 2, 44, 
    6, 48, 5, 92, 3, 83, 4, 93, 9,  5, 2, 44, 8, 57, 7, 72, 1, 29, 0, 83, 
    4, 81, 5, 10, 8, 78, 0, 67, 6, 86, 1, 37, 2, 82, 3, 35, 9, 68, 7, 10, 
    4,  1, 2, 78, 1, 46, 5, 74, 8, 42, 3,  7, 7, 97, 0, 84, 6, 61, 9, 55, 
    1, 78, 5, 45, 7, 41, 8, 37, 4, 41, 3, 53, 6, 80, 9,  1, 2, 25, 0, 49, 
    3, 42, 8, 13, 9, 31, 5, 69, 6, 80, 2, 28, 0, 73, 4, 65, 1, 26, 7, 76, 
    5, 46, 9, 98, 3, 14, 7, 87, 2, 76, 1,  3, 8, 35, 0, 89, 4, 29, 6, 32, 
    1, 49, 0, 19, 2, 56, 8, 31, 6, 71, 7, 31, 3, 37, 9, 95, 5, 40, 4, 61, 
    0, 40, 7, 72, 9, 43, 8,  4, 1, 82, 3, 84, 2, 13, 5, 26, 4, 79, 6, 64
  };
  const int r910[] = {
    10, 10, // Number of jobs and machines
    9, 41, 4, 76, 5,  3, 2, 39, 1, 80, 7, 12, 8, 79, 3, 13, 6, 53, 0,  5, 
    6, 74, 7, 75, 5, 82, 9, 31, 1, 43, 3, 23, 8, 75, 4, 10, 2, 11, 0, 86, 
    0, 17, 2, 53, 4, 19, 1, 21, 6, 42, 7, 14, 5, 40, 3, 13, 9,  1, 8, 24, 
    3, 39, 8, 59, 0, 69, 1,  7, 5, 68, 2, 74, 9, 22, 6, 80, 4, 68, 7, 32, 
    3, 74, 4, 84, 9, 22, 1, 71, 6, 58, 7, 10, 0,  9, 2, 44, 5, 90, 8, 92, 
    7, 70, 4, 27, 8, 20, 2, 34, 6,  4, 1, 64, 9, 74, 3,  4, 0, 28, 5, 58, 
    4, 45, 9, 56, 1, 37, 0, 55, 5, 33, 3, 71, 7, 50, 8, 78, 6, 53, 2, 29, 
    6, 98, 4,  1, 8, 54, 5, 58, 2, 12, 1, 19, 9, 36, 7, 94, 0, 17, 3, 91, 
    7, 16, 2, 48, 8, 28, 1, 36, 4, 11, 5, 71, 0,  7, 9, 58, 3, 58, 6, 13, 
    9, 51, 2,  2, 8, 25, 1, 32, 7, 41, 3, 32, 6, 80, 5, 58, 4, 99, 0, 66
  };
  const int r911[] = {
    10, 10, // Number of jobs and machines
    7, 91, 0, 28, 9, 58, 1, 38, 2, 89, 4, 66, 5, 13, 8, 66, 3, 81, 6, 90, 
    2,  6, 0,  7, 1, 26, 3, 29, 8,  7, 9, 16, 7, 57, 4, 29, 5, 93, 6, 59, 
    4, 61, 3, 64, 0, 60, 9, 87, 7, 17, 1, 98, 2, 86, 6, 31, 8, 25, 5, 84, 
    6, 58, 1, 58, 7, 86, 0, 30, 8, 82, 5, 13, 4, 95, 9,  9, 3, 12, 2, 22, 
    7, 52, 8, 71, 9, 88, 2, 76, 4, 31, 1, 52, 3, 91, 0, 70, 5, 38, 6, 53, 
    2, 59, 0, 98, 8, 21, 9, 99, 5, 35, 4, 81, 6, 89, 3, 37, 7, 95, 1, 66, 
    3,  2, 8, 35, 6,  1, 9, 20, 0, 37, 5, 81, 2, 85, 1, 96, 4, 64, 7, 31, 
    1, 33, 2,  3, 5, 40, 0, 96, 3, 56, 8, 70, 6, 79, 9, 65, 7, 62, 4, 50, 
    0, 40, 4,  4, 9, 32, 8, 60, 5, 65, 3,  6, 2, 26, 7, 22, 6, 63, 1, 65, 
    1, 91, 9, 14, 8,  8, 6, 50, 0,  8, 5, 26, 3, 32, 4,  9, 2, 15, 7, 92
  };
  const int r912[] = {
    10, 10, // Number of jobs and machines
    9, 97, 8, 21, 7, 86, 1, 72, 4,  9, 2, 82, 0, 18, 6, 74, 3, 64, 5, 76, 
    6, 88, 1, 12, 5, 61, 0, 77, 2,  2, 7, 65, 3, 29, 4, 87, 8, 45, 9, 84, 
    6, 70, 4,  9, 7, 10, 0, 84, 5, 80, 2, 98, 1, 35, 8, 65, 9, 49, 3, 25, 
    2, 87, 0, 63, 1, 46, 6, 32, 8, 88, 4, 47, 7, 88, 5, 92, 9, 68, 3, 71, 
    3, 48, 4, 24, 7, 38, 2, 65, 5,  6, 1, 60, 0, 41, 9,  5, 8, 60, 6, 65, 
    2, 46, 7, 99, 5, 60, 6, 65, 3, 25, 0, 32, 4, 90, 9, 76, 8, 49, 1, 60, 
    0, 56, 3, 94, 7, 82, 9, 81, 6,  9, 8, 76, 1,  7, 5, 98, 2, 17, 4, 24, 
    1, 85, 9, 49, 4, 48, 7, 66, 3, 58, 5, 99, 8, 83, 6, 73, 2,  2, 0, 14, 
    0, 13, 2,  9, 8, 69, 1, 88, 5, 79, 7, 27, 3, 73, 9, 26, 4, 51, 6, 32, 
    7, 87, 8, 72, 5, 70, 2, 46, 6, 55, 4, 23, 3, 21, 9, 15, 0, 92, 1, 48
  };
  const int r913[] = {
    10, 10, // Number of jobs and machines
    3, 99, 4, 56, 2, 41, 5, 53, 7,  1, 8, 69, 0, 51, 9, 89, 1, 85, 6, 85, 
    3, 90, 0, 63, 2, 73, 9, 93, 5, 94, 6, 43, 8, 94, 4, 62, 1, 62, 7, 61, 
    3, 78, 0, 19, 5, 70, 8, 89, 9, 14, 2, 80, 4, 73, 6, 80, 1, 45, 7, 44, 
    9, 94, 2, 98, 5, 24, 0, 17, 4, 26, 7, 74, 3, 54, 8, 78, 6, 36, 1, 59, 
    1, 90, 4,  2, 5, 75, 6, 91, 0, 64, 3, 49, 2, 70, 9, 17, 8, 89, 7, 84, 
    1, 12, 4, 18, 5, 29, 7, 70, 2, 13, 0, 85, 3, 67, 9, 14, 6, 46, 8, 53, 
    6, 83, 8, 99, 4, 75, 1, 62, 9, 21, 3, 76, 0, 75, 2, 32, 7,  6, 5, 69, 
    5, 87, 0, 18, 9, 85, 2, 51, 6, 73, 1, 21, 4, 54, 7, 23, 3,  6, 8, 46, 
    8, 27, 5,  2, 6, 77, 1, 46, 3, 93, 2, 62, 4, 85, 7,  4, 9, 21, 0, 75, 
    5,  7, 7, 41, 1, 55, 0, 69, 3, 35, 4, 89, 9, 56, 8, 61, 2, 42, 6,  9
  };
  const int r914[] = {
    10, 10, // Number of jobs and machines
    3, 62, 0, 54, 4, 60, 8, 68, 7, 49, 9, 57, 2, 74, 1, 22, 5, 80, 6,  9, 
    0, 59, 3, 92, 1, 27, 6, 33, 2, 64, 9, 88, 4, 20, 7, 88, 5,  5, 8, 40, 
    0, 75, 7, 78, 1, 33, 3, 13, 5, 81, 9, 50, 4, 94, 2, 14, 8, 86, 6, 15, 
    9, 64, 0, 31, 1, 96, 4, 93, 5, 49, 7, 10, 3, 57, 8, 53, 2,  1, 6, 87, 
    6,  2, 5,  4, 3, 94, 2, 34, 9, 34, 4, 24, 7, 33, 1, 13, 8, 40, 0, 61, 
    2, 62, 3, 47, 8, 39, 5, 44, 7, 54, 9,  4, 4, 63, 0, 69, 6, 85, 1, 21, 
    3, 79, 5, 15, 0, 86, 8, 62, 7, 63, 6, 12, 9, 14, 4, 81, 2, 34, 1, 10, 
    3, 98, 4, 41, 7, 56, 9, 45, 0,  2, 8, 49, 6, 44, 2, 67, 1,  2, 5, 24, 
    9,  3, 3, 55, 4, 43, 2, 82, 7, 11, 8, 22, 0, 59, 6,  2, 5, 95, 1, 87, 
    6, 72, 3, 92, 5, 68, 9, 51, 7, 22, 4, 60, 8, 64, 0,  5, 2, 74, 1, 26
  };
  const int r915[] = {
    10, 10, // Number of jobs and machines
    4, 95, 9, 23, 5,  7, 8, 53, 2, 97, 7, 69, 3, 90, 6, 95, 0, 14, 1, 68, 
    9, 34, 7, 12, 0, 58, 4, 74, 5, 86, 6, 42, 3, 85, 1,  6, 2, 83, 8,  2, 
    6, 93, 5, 39, 0, 78, 7, 23, 2, 65, 3, 12, 9, 62, 4, 79, 1, 36, 8, 42, 
    9, 77, 1, 41, 3, 10, 0, 37, 5, 43, 2, 98, 4, 21, 6, 29, 7, 21, 8, 97, 
    0,  2, 3, 95, 7,  2, 2, 99, 5, 61, 8, 34, 6, 51, 1,  7, 9, 61, 4, 99, 
    7, 87, 4,  7, 2, 15, 1, 93, 6, 72, 0, 74, 5,  8, 3, 61, 8, 29, 9, 49, 
    0, 32, 7, 19, 4, 95, 9, 19, 2, 92, 6, 40, 3, 46, 1, 53, 5, 88, 8, 95, 
    8, 17, 2, 23, 1, 36, 7, 25, 5, 17, 4, 14, 9,  8, 0,  8, 6, 97, 3, 99, 
    2, 75, 7, 34, 5, 57, 8, 93, 4, 15, 6, 53, 1, 81, 0, 67, 9, 80, 3, 31, 
    4, 81, 7, 46, 6, 90, 5,  9, 2, 32, 8, 78, 0, 95, 9,  6, 1, 91, 3, 81
  };
  const int r916[] = {
    10, 10, // Number of jobs and machines
    0, 56, 4, 65, 8, 55, 3, 26, 6, 19, 9, 99, 5, 23, 7, 53, 1, 93, 2, 50, 
    7, 31, 3, 72, 9, 94, 0,  7, 8, 86, 1, 13, 6, 19, 5, 82, 4, 93, 2,  6, 
    7, 40, 1, 33, 2, 65, 4, 93, 3, 57, 5, 27, 6, 24, 9, 34, 8, 29, 0, 83, 
    9, 51, 4, 89, 1, 65, 0, 18, 2, 29, 3, 69, 7, 11, 8, 68, 6, 37, 5,  8, 
    1, 57, 3, 91, 5, 27, 8, 92, 9, 87, 7, 38, 4, 92, 0, 88, 6, 16, 2, 44, 
    1,  7, 4, 59, 5, 89, 2, 88, 3, 86, 6, 91, 9, 38, 8, 74, 7,  5, 0, 84, 
    7, 61, 5,  2, 4, 90, 6, 97, 3,  5, 0, 70, 9, 96, 1, 87, 8, 56, 2, 10, 
    6, 77, 9, 71, 8, 31, 5, 71, 1, 14, 3, 30, 7, 60, 4, 56, 0, 86, 2, 92, 
    2, 90, 4, 13, 7, 19, 3, 67, 1, 47, 0, 57, 6, 22, 9,  9, 5, 35, 8, 39, 
    4, 76, 8, 35, 1,  1, 9, 75, 6, 44, 3,  8, 0, 42, 7, 33, 2, 15, 5, 93
  };
  const int r917[] = {
    10, 10, // Number of jobs and machines
    9,  7, 8, 90, 2, 35, 4,  6, 7, 68, 3, 82, 1, 65, 5, 78, 0, 34, 6, 76, 
    0, 69, 9, 78, 2, 88, 3, 80, 4, 30, 7, 31, 5, 62, 1, 24, 8, 94, 6, 60, 
    5, 67, 3, 38, 2, 23, 9, 32, 6,  2, 7,  5, 4, 72, 1, 15, 8, 70, 0, 59, 
    1, 85, 8, 67, 9, 31, 2, 33, 5, 26, 0, 82, 3, 99, 7, 99, 4, 95, 6, 78, 
    3, 77, 4, 30, 9, 51, 0, 32, 7, 85, 8, 89, 2, 67, 5, 21, 6, 67, 1, 76, 
    0, 13, 6, 65, 8, 62, 2, 28, 9, 84, 1, 81, 5,  1, 3, 39, 7, 26, 4, 58, 
    1,  4, 5, 22, 7, 66, 0, 91, 3, 25, 9, 23, 2, 24, 4, 61, 6, 98, 8, 30, 
    3, 80, 8, 60, 9, 19, 7, 60, 1, 84, 4, 40, 2, 93, 0,  8, 5, 97, 6, 22, 
    4, 69, 9, 42, 3, 23, 8, 57, 0, 32, 7, 67, 5, 66, 1, 36, 2, 55, 6, 43, 
    8, 11, 0, 30, 5,  6, 3, 98, 2, 47, 7, 56, 1, 14, 9, 32, 4, 24, 6, 91
  };
  const int r918[] = {
    10, 10, // Number of jobs and machines
    3, 61, 4, 84, 9, 65, 1,  2, 6, 20, 8, 87, 7, 88, 5, 80, 0, 49, 2, 28, 
    1, 16, 3, 70, 7, 22, 4, 57, 9, 71, 6, 23, 2, 45, 5, 76, 0, 76, 8, 39, 
    2, 37, 7, 76, 4, 37, 0, 59, 1, 13, 6, 54, 9, 43, 5, 29, 8, 77, 3, 18, 
    6,  8, 5, 59, 7, 15, 0, 51, 3, 60, 4, 24, 8, 90, 2, 12, 9, 27, 1, 81, 
    1,  1, 7, 62, 3, 68, 2, 48, 4, 70, 0,  9, 6, 93, 8, 94, 5, 53, 9, 31, 
    4,  6, 8, 31, 1, 40, 7, 70, 0, 26, 5, 86, 9, 61, 6,  2, 2, 49, 3, 34, 
    5, 58, 3, 78, 6, 29, 1, 33, 4, 42, 9, 97, 2, 19, 0,  5, 8, 58, 7,  5, 
    5, 48, 2, 92, 3, 48, 6, 39, 9, 75, 1, 76, 8, 76, 0, 90, 4, 67, 7, 58, 
    2, 18, 7,  1, 6, 85, 0, 56, 5, 40, 9, 76, 1, 91, 8, 68, 4, 88, 3, 72, 
    9, 27, 2, 23, 1, 83, 6, 10, 4,  1, 3, 57, 0, 50, 5, 67, 8, 83, 7,  4
  };
  const int r919[] = {
    10, 10, // Number of jobs and machines
    9, 32, 0,  2, 3, 22, 5, 43, 8, 23, 6, 30, 4, 61, 1, 26, 2, 33, 7, 22, 
    3, 76, 2, 10, 0, 65, 5, 34, 8, 75, 6, 14, 7, 13, 4, 51, 9, 86, 1, 62, 
    7, 23, 5, 80, 2, 10, 9, 74, 6, 14, 0, 42, 1, 90, 8, 64, 4, 94, 3, 82, 
    6, 74, 8, 25, 2, 66, 7, 89, 3, 75, 1, 87, 9, 31, 4, 71, 5, 95, 0, 50, 
    9,  5, 0, 26, 1, 90, 3, 78, 2, 11, 5, 40, 7, 33, 6, 66, 8, 41, 4, 41, 
    7, 84, 0, 64, 2, 18, 6, 27, 5, 58, 9, 58, 1, 33, 4, 73, 8, 81, 3, 98, 
    8, 76, 5, 68, 0,  9, 4,  4, 3, 58, 9, 55, 6, 84, 7, 14, 2, 79, 1, 27, 
    7, 16, 1, 82, 3, 91, 0,  3, 9, 18, 2, 61, 4, 47, 6, 95, 8, 53, 5, 52, 
    6,  9, 7, 89, 1, 50, 8, 73, 2, 98, 9, 21, 4, 58, 0, 13, 5, 12, 3, 97, 
    7, 36, 5, 12, 2, 70, 8, 12, 4, 78, 0, 84, 6, 80, 1, 97, 3, 31, 9, 95
  };
  const int r920[] = {
    10, 10, // Number of jobs and machines
    1, 86, 3,  1, 8, 22, 6, 36, 0, 49, 4, 76, 7, 88, 2, 53, 5, 83, 9,  1, 
    9, 36, 0, 16, 1, 22, 8, 54, 2, 58, 5, 61, 6, 52, 3, 23, 4, 97, 7, 18, 
    1, 60, 3,  8, 5, 69, 9,  4, 6, 31, 8, 79, 4, 32, 2, 44, 0, 57, 7, 82, 
    9, 12, 3, 32, 7, 30, 1, 81, 8, 28, 6, 67, 0, 29, 5, 41, 2, 91, 4,  1, 
    9, 19, 5, 65, 4,  5, 1, 45, 6, 50, 7, 88, 3,  3, 0, 84, 8, 80, 2, 78, 
    7, 25, 5, 42, 8, 80, 0, 58, 9, 49, 1, 44, 2, 54, 3, 78, 6, 68, 4, 16, 
    4, 49, 9, 35, 1,  8, 2, 38, 8, 69, 5, 98, 3, 74, 7, 64, 0, 93, 6, 61, 
    2, 52, 9, 51, 8, 52, 7, 51, 1, 21, 4, 90, 6, 52, 5, 68, 0, 42, 3, 24, 
    5, 85, 4, 21, 3, 40, 9, 14, 0,  1, 6, 73, 1, 78, 7, 14, 8, 17, 2, 15, 
    4, 70, 6, 58, 3,  8, 1, 64, 7, 68, 9, 98, 2, 88, 5, 48, 0, 68, 8,  5
  };
  const int r921[] = {
    10, 10, // Number of jobs and machines
    5, 54, 9, 37, 2, 89, 6, 34, 8, 95, 4, 38, 1, 55, 0, 17, 3, 68, 7, 82, 
    4, 14, 6, 62, 7, 52, 9, 52, 5, 83, 3, 15, 8, 48, 2, 84, 0, 29, 1, 99, 
    5, 24, 1, 44, 8, 24, 2, 42, 7, 40, 4, 37, 6, 54, 9, 60, 3,  2, 0, 45, 
    0, 31, 8,  5, 3, 82, 1, 71, 9, 41, 2, 35, 7, 74, 5, 28, 6, 64, 4,  6, 
    6, 95, 0,  5, 9, 65, 7, 71, 8, 10, 5, 68, 2, 87, 3, 29, 4, 59, 1, 57, 
    6,  9, 4, 29, 9, 27, 0, 98, 5, 13, 3, 46, 7, 16, 8, 23, 2, 70, 1, 13, 
    4, 51, 1, 18, 8, 40, 9, 24, 5, 55, 0,  3, 7,  6, 2, 50, 3, 60, 6, 91, 
    2, 38, 0,  1, 6, 31, 4, 75, 1, 27, 7,  4, 3, 10, 5, 27, 9, 99, 8, 97, 
    6,  8, 3, 35, 1, 60, 9, 46, 5, 65, 2, 27, 7, 95, 8, 56, 4, 99, 0, 64, 
    8,  7, 0, 61, 5,  9, 1, 96, 9, 75, 6, 43, 2, 43, 3, 81, 4, 39, 7, 44
  };
  const int r922[] = {
    10, 10, // Number of jobs and machines
    1, 79, 7, 79, 0, 26, 9, 24, 2, 25, 8,  8, 3, 24, 4,  1, 5, 81, 6, 63, 
    6, 67, 8, 99, 1, 30, 7, 61, 9, 29, 4, 74, 2, 80, 5, 20, 3, 57, 0, 42, 
    1,  5, 4, 21, 8,  5, 5, 91, 2, 59, 3,  6, 6, 61, 0,  7, 9, 31, 7, 37, 
    7, 30, 5, 60, 3, 61, 6, 59, 4, 62, 0, 86, 9, 70, 1, 17, 8,  4, 2, 32, 
    2, 32, 7, 93, 6, 54, 0, 70, 5, 82, 3, 11, 1, 66, 9, 88, 8, 58, 4, 80, 
    1, 54, 9, 10, 0, 50, 4, 35, 5, 34, 7,  5, 3, 29, 8, 72, 2, 52, 6, 60, 
    1, 99, 7, 13, 2, 75, 0, 18, 8, 19, 6, 84, 4, 88, 3,  9, 9, 93, 5, 13, 
    2, 65, 7, 82, 9,  5, 0, 44, 8, 39, 3, 61, 1, 89, 4, 90, 5, 71, 6, 83, 
    6, 38, 3, 80, 5, 42, 8, 36, 7,  6, 4, 56, 2, 75, 9, 57, 1, 42, 0,  8, 
    4, 88, 5, 87, 1, 60, 0,  5, 9, 97, 8, 29, 2, 90, 6, 94, 7, 28, 3, 86
  };
  const int r923[] = {
    10, 10, // Number of jobs and machines
    4, 85, 0, 93, 9, 98, 1,  9, 8, 98, 6, 71, 5,  7, 7,  8, 3, 42, 2, 23, 
    7, 26, 8, 32, 3, 93, 1,  7, 4, 23, 0, 51, 6,  4, 5, 66, 9, 66, 2, 46, 
    8,  2, 3, 76, 4, 78, 1, 76, 7,  5, 2, 47, 9,  6, 5, 53, 6, 37, 0, 29, 
    6, 60, 5, 33, 3, 80, 2, 33, 9, 43, 7, 49, 0, 21, 8, 48, 4, 99, 1, 92, 
    1, 42, 7, 54, 6, 68, 0, 12, 9,  8, 3, 84, 2, 74, 5,  2, 8,  4, 4, 37, 
    0, 74, 5, 54, 9, 42, 8, 45, 2, 24, 7, 21, 1, 98, 4, 53, 3, 90, 6, 51, 
    4, 99, 7, 67, 2, 83, 9, 20, 1, 96, 8, 88, 3, 76, 5, 27, 6, 90, 0, 57, 
    1, 71, 2, 48, 6, 10, 3, 87, 0, 96, 9, 10, 7, 96, 8, 29, 5, 35, 4, 36, 
    8, 30, 5, 60, 2, 50, 7, 98, 9, 57, 6, 87, 4,  1, 1, 31, 3, 14, 0, 76, 
    2, 53, 3, 53, 5, 60, 0, 11, 4, 88, 8, 25, 9, 66, 1, 52, 6, 10, 7, 13
  };
  const int r924[] = {
    10, 10, // Number of jobs and machines
    8, 70, 3, 13, 5, 62, 1, 96, 4, 87, 9, 29, 0, 28, 7, 42, 6, 26, 2, 28, 
    1, 63, 8, 71, 3, 26, 6, 82, 2, 33, 7, 42, 9, 24, 0, 67, 4, 83, 5, 88, 
    8, 37, 0, 27, 5, 71, 1, 62, 3, 52, 6, 38, 7, 43, 4, 71, 9, 81, 2, 48, 
    4, 63, 0, 64, 7, 46, 5, 99, 9,  7, 1, 17, 3, 30, 6, 63, 8, 13, 2, 28, 
    0, 29, 4, 55, 6, 40, 8, 89, 7, 91, 9, 89, 2, 98, 3, 99, 1, 16, 5, 81, 
    2, 53, 8, 33, 0, 85, 1, 49, 7, 52, 4, 64, 5, 60, 6, 36, 3, 71, 9, 48, 
    2, 50, 3, 41, 9, 97, 6, 92, 7, 16, 4, 51, 5,  8, 8, 38, 0, 33, 1, 78, 
    4, 27, 8, 37, 3, 78, 1, 21, 9, 21, 2, 37, 7, 68, 5, 79, 0, 20, 6, 93, 
    4, 77, 0, 80, 7, 28, 1, 68, 9, 47, 2, 84, 3,  6, 6, 91, 8, 80, 5,  6, 
    7, 34, 0, 75, 6, 82, 3,  5, 9, 47, 1, 97, 8,  1, 4, 22, 5, 97, 2, 59
  };
  const int r925[] = {
    10, 10, // Number of jobs and machines
    1, 26, 4,  9, 7, 25, 6, 91, 8, 56, 9,  4, 5, 31, 0, 77, 2, 11, 3, 28, 
    2, 79, 3, 96, 4, 62, 9, 80, 8,  1, 7, 23, 6, 34, 0, 74, 1, 60, 5, 37, 
    6, 49, 7, 76, 5, 28, 1, 29, 9, 62, 4, 69, 3, 55, 8, 62, 0, 71, 2, 77, 
    3, 12, 7, 63, 9,  7, 6, 51, 1, 82, 2, 88, 5, 70, 8, 46, 0, 52, 4, 12, 
    4, 39, 3,  9, 8, 23, 7, 53, 5, 79, 9, 86, 2, 97, 0, 22, 6, 59, 1, 64, 
    2, 26, 1, 26, 4, 50, 5, 27, 9, 11, 7, 48, 8, 61, 3, 57, 6,  3, 0, 86, 
    3, 46, 2, 42, 1, 41, 0, 89, 6,  5, 8, 86, 4, 33, 9, 75, 7, 48, 5, 18, 
    6, 74, 2, 84, 5, 17, 8, 42, 4, 19, 1, 73, 7, 46, 3, 31, 0, 78, 9, 66, 
    6, 43, 4, 59, 8, 43, 0, 74, 9, 17, 7, 78, 1, 19, 5, 26, 2, 47, 3, 37, 
    1, 79, 3, 21, 4, 91, 9, 93, 2, 48, 5,  3, 6, 12, 0, 63, 8, 16, 7, 81
  };
  const int r926[] = {
    10, 10, // Number of jobs and machines
    2, 69, 1, 37, 4, 89, 3, 45, 5, 24, 6, 42, 7, 93, 8, 16, 0, 86, 9, 49, 
    1, 84, 4, 14, 7, 79, 9, 57, 2, 24, 6,  1, 3, 92, 5, 65, 0, 69, 8, 45, 
    5,  3, 4, 39, 7, 19, 2, 67, 0, 20, 1, 39, 6, 73, 8, 49, 3,  8, 9, 85, 
    6, 64, 1, 81, 4, 89, 5, 55, 9,  6, 2, 87, 7, 56, 3,  4, 8, 87, 0, 57, 
    4, 54, 8, 29, 5, 76, 3, 91, 2, 94, 9, 95, 6, 28, 7, 17, 1, 17, 0, 46, 
    4, 28, 5, 85, 8, 50, 7, 14, 9, 81, 1, 63, 3, 89, 0, 42, 2, 38, 6, 25, 
    4, 37, 5, 60, 2, 31, 0, 64, 3, 64, 6, 27, 9, 64, 8,  8, 7, 93, 1, 40, 
    6, 43, 7, 97, 2, 70, 5, 63, 1,  6, 3, 44, 8, 17, 9, 69, 0, 49, 4, 19, 
    1, 83, 4, 24, 8, 76, 6, 97, 7, 49, 5, 47, 2, 19, 9, 22, 3, 66, 0, 30, 
    1, 36, 8, 70, 5, 96, 6, 72, 2,  3, 3, 92, 9, 24, 7, 32, 4, 69, 0, 90
  };
  const int r927[] = {
    10, 10, // Number of jobs and machines
    9, 81, 7, 20, 4, 18, 0, 82, 8, 88, 1,  1, 5, 57, 3, 29, 6, 31, 2, 62, 
    9, 17, 7, 83, 3, 67, 0,  8, 8, 59, 5, 14, 2,  1, 4, 60, 6, 43, 1, 96, 
    1,  1, 6, 99, 7, 83, 3, 49, 9, 74, 4, 92, 0, 15, 5, 72, 8, 37, 2, 61, 
    2, 14, 5, 31, 0,  8, 1, 50, 9, 51, 4, 69, 3,  5, 7, 31, 6, 59, 8,  7, 
    4, 37, 0, 76, 9,  9, 2, 96, 6, 73, 1, 29, 7, 28, 3, 45, 5, 30, 8, 94, 
    6, 41, 2, 38, 5, 93, 7, 99, 3, 68, 8, 63, 1, 53, 9, 96, 0,  7, 4, 11, 
    1, 88, 6, 31, 2, 93, 8, 35, 7, 42, 5, 11, 3, 58, 9, 28, 4, 18, 0, 20, 
    6, 33, 4, 95, 5, 14, 0, 62, 1, 13, 9, 25, 8, 67, 2, 81, 7, 66, 3, 13, 
    9, 48, 4, 73, 3, 33, 1, 27, 2,  4, 5,  4, 8, 30, 7, 67, 0, 48, 6, 99, 
    8, 94, 4,  1, 3, 60, 2, 20, 6, 57, 0, 21, 1, 55, 9, 99, 5, 94, 7, 28
  };
  const int r928[] = {
    10, 10, // Number of jobs and machines
    7, 12, 6, 84, 1,  1, 3, 51, 4, 82, 9, 40, 0, 58, 8, 27, 2, 39, 5,  5, 
    9, 19, 6, 29, 7, 19, 5, 35, 2, 13, 1, 61, 4, 13, 8, 53, 0, 33, 3, 22, 
    5, 30, 7, 93, 8, 49, 3, 19, 0, 97, 6, 47, 2,  1, 4,  3, 9,  6, 1, 99, 
    4, 15, 2, 78, 7, 95, 3, 83, 6, 76, 5,  2, 1, 37, 0, 51, 8, 40, 9, 72, 
    1, 24, 3, 19, 8, 58, 6, 78, 2, 17, 5,  2, 7, 33, 0, 45, 9, 46, 4, 39, 
    8, 27, 5, 18, 6, 12, 3, 30, 7, 22, 2, 29, 9, 34, 4, 12, 1, 74, 0, 64, 
    3, 87, 4, 64, 5, 62, 9, 33, 8, 40, 7, 30, 2, 70, 6, 34, 0, 21, 1, 38, 
    6, 32, 5, 86, 0,  5, 3, 78, 4,  4, 2, 69, 1, 97, 8, 58, 9, 19, 7, 31, 
    5, 31, 7, 69, 3, 29, 6, 25, 1, 37, 8, 31, 9,  3, 2, 64, 4,  1, 0, 23, 
    6, 28, 4, 51, 7, 13, 3, 61, 5, 18, 8, 11, 0, 42, 2, 36, 1, 39, 9, 66
  };
  const int r929[] = {
    10, 10, // Number of jobs and machines
    7, 21, 3, 20, 2, 74, 9, 40, 6, 80, 1, 22, 8, 77, 4, 12, 0, 11, 5, 77, 
    2, 75, 3, 50, 4, 34, 0, 79, 1, 54, 7, 54, 5, 41, 6, 35, 9, 50, 8, 93, 
    3, 62, 0, 59, 7, 46, 6, 95, 1, 96, 9, 30, 2, 35, 4, 44, 8, 57, 5, 46, 
    2, 37, 4, 92, 3, 40, 9, 25, 6, 31, 0, 59, 5, 10, 1, 15, 8, 17, 7, 42, 
    7, 24, 8,  7, 0, 78, 9, 53, 2, 52, 1,  8, 6, 11, 5, 71, 4, 21, 3, 42, 
    5, 28, 3, 71, 0, 46, 9, 82, 1, 66, 7, 29, 2, 93, 6, 69, 4, 34, 8, 66, 
    1, 99, 5, 65, 2, 42, 6, 70, 7, 56, 8, 64, 9, 98, 0, 89, 4,  2, 3, 38, 
    6, 71, 3, 75, 1, 67, 7, 58, 2, 85, 5, 38, 0, 90, 4, 62, 9, 55, 8, 68, 
    7, 75, 6, 90, 5, 47, 8, 39, 9, 76, 3, 80, 1, 26, 0, 61, 4, 42, 2, 97, 
    6, 80, 2, 48, 0, 80, 7, 34, 3, 96, 8, 34, 1, 52, 4, 45, 5,  2, 9, 69
  };
  const int r930[] = {
    10, 10, // Number of jobs and machines
    8, 49, 4, 55, 1, 76, 2, 88, 3, 32, 6, 87, 5, 80, 0, 99, 9, 10, 7, 38, 
    5, 16, 1,  9, 3, 84, 7, 49, 9, 45, 2, 10, 8, 67, 4, 46, 0, 60, 6,  2, 
    2,  8, 6,  6, 3, 42, 0, 72, 4, 10, 7, 46, 5, 78, 1,  8, 9, 18, 8, 26, 
    3, 20, 2, 79, 8, 32, 0, 61, 6, 41, 1, 84, 9, 46, 4, 27, 7, 83, 5, 82, 
    1, 10, 5, 57, 4, 33, 7, 75, 0,  5, 3, 97, 2, 14, 9, 17, 6, 80, 8, 72, 
    9, 46, 0, 33, 7, 24, 1,  1, 2, 26, 3, 23, 5, 74, 6, 52, 4, 44, 8, 64, 
    5, 13, 9, 20, 3, 97, 6, 82, 4, 60, 1, 45, 2, 81, 8, 33, 7, 70, 0, 34, 
    4,  8, 5, 17, 2, 70, 3, 37, 6, 74, 0, 87, 7, 28, 9, 31, 1, 55, 8, 93, 
    0, 69, 8, 13, 2, 17, 7,  1, 3, 27, 4,  7, 5, 74, 9, 11, 1, 44, 6, 13, 
    5, 58, 9, 15, 3,  3, 0, 22, 7, 74, 2, 38, 6, 26, 8, 87, 4, 76, 1, 18
  };
  const int r931[] = {
    10, 10, // Number of jobs and machines
    1, 75, 8, 19, 5, 13, 6, 64, 3, 11, 9, 91, 0, 64, 7, 95, 2, 32, 4, 15, 
    5, 45, 1, 82, 6, 97, 4, 19, 0, 57, 7, 21, 9, 19, 8, 64, 2, 95, 3, 57, 
    4, 86, 9, 53, 5, 46, 7, 81, 0, 79, 2, 91, 8, 79, 3, 55, 6, 87, 1, 69, 
    9, 34, 0, 47, 5, 65, 3, 61, 2, 84, 4, 35, 7, 90, 8, 58, 6, 42, 1, 87, 
    3, 16, 5, 10, 0, 70, 4,  6, 8, 99, 9, 59, 1, 34, 6, 17, 7, 52, 2, 61, 
    3, 99, 8,  8, 0, 93, 6,  7, 1, 58, 9,  1, 2, 56, 5, 98, 4, 39, 7, 20, 
    8, 46, 7, 81, 0, 70, 4, 34, 1, 17, 2, 42, 5, 27, 6, 11, 3, 38, 9,  5, 
    9,  7, 4, 21, 2, 23, 8, 74, 7, 66, 5, 48, 6, 46, 3,  8, 1, 42, 0, 58, 
    3, 34, 1, 90, 9,  4, 0, 17, 2, 93, 7, 71, 6, 99, 4,  1, 5, 91, 8,  8, 
    2,  9, 5, 97, 7,  3, 4, 83, 6, 96, 3, 54, 0, 38, 8, 56, 9, 35, 1, 55
  };
  const int r932[] = {
    10, 10, // Number of jobs and machines
    1, 87, 5, 92, 9, 68, 2, 64, 0, 92, 4, 80, 6, 14, 3, 76, 8, 55, 7, 55, 
    2, 23, 8, 58, 7, 43, 0, 93, 1, 46, 5, 21, 6, 30, 3, 59, 4, 31, 9, 91, 
    6, 43, 1, 90, 3, 64, 8, 17, 2, 92, 4, 82, 9, 65, 5, 52, 0, 56, 7, 49, 
    5, 55, 3, 58, 2, 62, 6, 77, 1,  8, 4, 75, 7, 57, 0, 79, 9, 32, 8, 51, 
    0, 56, 3, 32, 7, 83, 2, 33, 5, 94, 4, 28, 1, 34, 9, 70, 6, 94, 8, 93, 
    1,  7, 3, 85, 2, 37, 4, 14, 7,  3, 5, 45, 6, 48, 9, 24, 0, 59, 8, 70, 
    6, 37, 5, 84, 4, 85, 8, 37, 0,  1, 7,  4, 1, 18, 3, 58, 9, 23, 2, 65, 
    9, 44, 4, 26, 1, 14, 7,  8, 6,  3, 0, 81, 5, 98, 8, 25, 3, 26, 2, 13, 
    1, 97, 4, 23, 3, 62, 0, 33, 5, 61, 2, 35, 9, 13, 8, 61, 6,  7, 7, 89, 
    8, 21, 5, 23, 0, 93, 7,  3, 1, 55, 6, 78, 4, 34, 3, 66, 9, 89, 2, 13
  };
  const int r933[] = {
    10, 10, // Number of jobs and machines
    5, 57, 6, 17, 1, 85, 3, 78, 0, 86, 4, 92, 8, 28, 2, 63, 9, 92, 7, 49, 
    3, 86, 9, 57, 1, 99, 4, 78, 8, 14, 0, 60, 6, 43, 5, 49, 7, 32, 2, 77, 
    3, 73, 5, 99, 8, 55, 4, 52, 1, 39, 7, 76, 0, 65, 9, 99, 6, 89, 2, 92, 
    6, 68, 9, 94, 8, 59, 1, 16, 2, 18, 5, 51, 7, 25, 4, 29, 3, 41, 0, 12, 
    1, 30, 3, 75, 0, 62, 6, 27, 8, 77, 4, 67, 7, 62, 2, 61, 9,  6, 5, 22, 
    2,  6, 5, 81, 3, 48, 9, 65, 8, 95, 7,  5, 1, 44, 4, 26, 6,  1, 0, 43, 
    4, 85, 1, 80, 7, 38, 0, 72, 9, 45, 3, 22, 5, 71, 8, 74, 6, 21, 2, 21, 
    4, 78, 0, 11, 8, 23, 2, 83, 7, 75, 9, 82, 3,  7, 6, 92, 5, 21, 1, 28, 
    1, 48, 9, 58, 3, 44, 2, 45, 8, 39, 6, 55, 5, 84, 0, 35, 4, 76, 7, 14, 
    7, 78, 2, 21, 3, 25, 6, 61, 1, 46, 9,  8, 5, 73, 4, 69, 8, 99, 0, 17
  };
  const int r934[] = {
    10, 10, // Number of jobs and machines
    1, 17, 9, 58, 3, 52, 5, 91, 6, 77, 2, 48, 8, 25, 4, 95, 0, 20, 7, 79, 
    1, 48, 8, 26, 0, 81, 3, 78, 4, 91, 9,  9, 6, 83, 2, 79, 5, 63, 7, 28, 
    6, 32, 8, 30, 1, 56, 0, 61, 7, 62, 2, 54, 4, 45, 5, 27, 3,  7, 9, 37, 
    7, 47, 4, 54, 1, 75, 3, 28, 6, 65, 9, 41, 2, 73, 0, 21, 5, 64, 8, 82, 
    7, 36, 3, 39, 6, 57, 2, 66, 9, 64, 4, 51, 0, 62, 1, 54, 8, 38, 5, 51, 
    8, 61, 3,  4, 4, 12, 9,  1, 7, 23, 2, 48, 0, 29, 6, 69, 5, 40, 1, 99, 
    0, 15, 7, 51, 2, 98, 4, 30, 3, 78, 9, 21, 5,  1, 6, 26, 1, 13, 8, 60, 
    1, 14, 6, 25, 9, 17, 0, 74, 8, 11, 4,  5, 3, 20, 7, 78, 2, 26, 5, 79, 
    5, 45, 0, 88, 9, 73, 1, 95, 7, 74, 8, 88, 2, 63, 3, 68, 6, 39, 4, 83, 
    4, 29, 7,  1, 3, 12, 0, 93, 9, 29, 8,  7, 2, 98, 1, 56, 6, 93, 5, 38
  };
  const int r935[] = {
    10, 10, // Number of jobs and machines
    7, 78, 8, 72, 4,  7, 1, 97, 5, 38, 2, 92, 0, 51, 6, 28, 3, 70, 9, 86, 
    6, 79, 2, 91, 8, 84, 0, 89, 3, 37, 4, 22, 7, 83, 5,  1, 1, 55, 9, 85, 
    2, 86, 8, 45, 0, 95, 6, 91, 1, 76, 4, 45, 5, 65, 9, 61, 3, 52, 7, 54, 
    9,  3, 1, 41, 5, 76, 7, 70, 2, 21, 4, 16, 8, 11, 6, 12, 3, 76, 0, 50, 
    9, 43, 6, 38, 3, 98, 1, 82, 7, 74, 5, 32, 8, 98, 2, 19, 4, 91, 0, 44, 
    0, 63, 6, 74, 4,  1, 2,  5, 3,  1, 1, 20, 5, 47, 8,  9, 9,  5, 7, 34, 
    9, 98, 1, 74, 0, 51, 7, 57, 6, 96, 4,  3, 3, 99, 2, 30, 5, 37, 8, 48, 
    2, 34, 9, 26, 0, 41, 8,  8, 4, 50, 6,  3, 5, 55, 3, 57, 1,  8, 7, 94, 
    7, 76, 0, 16, 3, 60, 2, 42, 5, 31, 9,  6, 8, 77, 4, 93, 6, 55, 1, 56, 
    7, 36, 1, 10, 3, 41, 6, 39, 0,  2, 8, 87, 5, 42, 4,  2, 2, 73, 9, 84
  };
  const int r936[] = {
    10, 10, // Number of jobs and machines
    7, 79, 1, 53, 0, 47, 5, 46, 3, 87, 2, 72, 6, 73, 4, 12, 9, 53, 8, 64, 
    3, 58, 5, 12, 9, 18, 2, 81, 8, 16, 4, 83, 6, 33, 7,  6, 0,  1, 1, 20, 
    7, 44, 1, 16, 5, 23, 4, 52, 2, 84, 6, 10, 3, 49, 9, 45, 8, 67, 0,  1, 
    2, 60, 8,  2, 1, 56, 9, 22, 4, 12, 3, 66, 6, 46, 7, 64, 5, 40, 0, 22, 
    4, 87, 3, 56, 7,  4, 9, 90, 8, 43, 5, 34, 2, 81, 1, 95, 6, 59, 0, 21, 
    1, 50, 7, 44, 6, 55, 2, 42, 9, 52, 0, 95, 5, 87, 3, 78, 4, 79, 8,  3, 
    5, 34, 3, 81, 8,  3, 4, 54, 1, 35, 2, 41, 9, 24, 0, 87, 7, 65, 6, 77, 
    4, 73, 1, 79, 7, 84, 8, 12, 3, 19, 9, 36, 0, 34, 2, 53, 5, 64, 6, 93, 
    3, 44, 4, 14, 2, 64, 8, 62, 1, 17, 7, 37, 9, 48, 5, 68, 6, 10, 0, 41, 
    0, 60, 1, 18, 5, 77, 6, 83, 4, 55, 3, 67, 8, 12, 2, 26, 9, 38, 7, 22
  };
  const int r937[] = {
    10, 10, // Number of jobs and machines
    7, 44, 9, 18, 1, 87, 5, 64, 2,  4, 6, 89, 3, 44, 8, 64, 0, 86, 4, 64, 
    7, 81, 0, 70, 8, 22, 6, 30, 3, 68, 4, 52, 2, 36, 1,  7, 9, 42, 5, 96, 
    7, 98, 5, 72, 1, 40, 2, 77, 0, 91, 9, 47, 4, 61, 3, 58, 8, 10, 6, 75, 
    7, 60, 9, 56, 1,  7, 8, 31, 4, 94, 5, 89, 6,  9, 3, 53, 0, 47, 2, 90, 
    6, 69, 2, 22, 8,  8, 5, 66, 1, 43, 4, 12, 9, 20, 7, 55, 0, 78, 3, 70, 
    5, 91, 7, 61, 2,  4, 3, 19, 4, 44, 6, 44, 0, 62, 1, 29, 9, 74, 8, 98, 
    6, 29, 5, 89, 3, 53, 2, 95, 8, 57, 4, 51, 9, 70, 7, 25, 1,  1, 0, 89, 
    8, 53, 7, 94, 0, 93, 2, 47, 9, 57, 1, 99, 3, 89, 4, 63, 6, 14, 5, 11, 
    1, 69, 7, 93, 4, 56, 3, 90, 0, 82, 6, 20, 8, 17, 9, 10, 5, 89, 2, 95, 
    7,  8, 9,  2, 3, 56, 2,  6, 5, 39, 0, 23, 4, 31, 1, 53, 8, 87, 6, 12
  };
  const int r938[] = {
    10, 10, // Number of jobs and machines
    1, 79, 7, 73, 4, 13, 0,  7, 3, 67, 6, 94, 9, 11, 2, 36, 5, 88, 8, 53, 
    8, 38, 4, 65, 0, 48, 6, 16, 7, 69, 2, 81, 3, 16, 5, 81, 1, 81, 9, 70, 
    9,  9, 5, 68, 6, 96, 8, 37, 1, 89, 7,  6, 4,  3, 2, 78, 3, 59, 0, 64, 
    5, 27, 2, 10, 1, 79, 4, 68, 6, 45, 0, 39, 7, 70, 9, 19, 8, 74, 3,  7, 
    0,  9, 3,  9, 9, 32, 2, 96, 4, 45, 6, 62, 7, 41, 1, 37, 5, 84, 8,  5, 
    7,  3, 9, 53, 6, 88, 4, 87, 1, 47, 5, 34, 8, 23, 3, 57, 2, 61, 0, 74, 
    3,  3, 7, 14, 8, 48, 0, 68, 9,  3, 6, 79, 4, 40, 5, 32, 1, 12, 2, 29, 
    7, 42, 2, 10, 1, 50, 5, 68, 4, 88, 3, 16, 8, 53, 6, 35, 0, 73, 9, 25, 
    5,  3, 7, 24, 3, 33, 0, 84, 4, 30, 2, 91, 1, 66, 9, 27, 6, 14, 8, 43, 
    8, 76, 4, 42, 5, 30, 6,  8, 1,  7, 9, 36, 3, 38, 2, 69, 0, 83, 7, 94
  };
  const int r939[] = {
    10, 10, // Number of jobs and machines
    9, 86, 6,  3, 0, 84, 8, 26, 7, 89, 1, 40, 2, 78, 4, 11, 3, 58, 5, 87, 
    6, 49, 0, 56, 9, 76, 5, 16, 2, 65, 4, 29, 8, 37, 7, 26, 1,  1, 3, 77, 
    2, 85, 8, 22, 1, 30, 0, 52, 9, 94, 5, 36, 3, 39, 4,  2, 6, 93, 7, 72, 
    0,  3, 3, 39, 4, 46, 8, 48, 2, 53, 9, 19, 6, 26, 7, 82, 1, 28, 5, 49, 
    9, 40, 0, 15, 7, 71, 6, 51, 2,  1, 8, 40, 4, 16, 3, 80, 5, 43, 1, 92, 
    3, 97, 6,  5, 8, 33, 9, 94, 5, 93, 1, 85, 0, 12, 4, 64, 2, 84, 7, 89, 
    6, 96, 5,  9, 4, 51, 3, 18, 7, 57, 8, 89, 9, 18, 0, 57, 2, 64, 1, 35, 
    8, 51, 9, 84, 3,  3, 6, 61, 0, 65, 1, 52, 7, 17, 5, 88, 4, 64, 2, 42, 
    8, 27, 1, 37, 3, 89, 4, 34, 5, 93, 7, 16, 9, 82, 6, 70, 2, 80, 0, 65, 
    5, 89, 7, 69, 3,  8, 0, 75, 8, 76, 2, 25, 9, 49, 1, 29, 6, 56, 4, 28
  };
  const int r940[] = {
    10, 10, // Number of jobs and machines
    1, 45, 6, 67, 4, 37, 9, 57, 2,  9, 3, 98, 0, 65, 5, 86, 8, 96, 7, 41, 
    4, 93, 2, 86, 5, 92, 1, 46, 3,  9, 6, 36, 0, 57, 7, 13, 8, 90, 9, 31, 
    5, 53, 4, 35, 3, 92, 8, 97, 1,  6, 0, 94, 9, 16, 6, 59, 7, 22, 2, 40, 
    4, 80, 1, 44, 7, 50, 9, 23, 0, 84, 5, 98, 8, 65, 3, 31, 2, 98, 6, 11, 
    7, 22, 4, 86, 1, 86, 6, 13, 9, 42, 8, 36, 0,  5, 5, 63, 2, 96, 3, 62, 
    5, 37, 8, 99, 0,  6, 9, 47, 2, 60, 6, 75, 4, 14, 7, 47, 1,  8, 3, 73, 
    3, 54, 7, 11, 4, 36, 5, 18, 6, 26, 1, 29, 0, 49, 2, 66, 9,  2, 8, 44, 
    7, 11, 9, 79, 8, 21, 0, 17, 2, 67, 6, 71, 3, 29, 4, 80, 5, 54, 1, 13, 
    3,  3, 6, 87, 0, 87, 8, 37, 5, 82, 9, 94, 7, 98, 4, 41, 1, 74, 2, 54, 
    2, 96, 3, 93, 6, 30, 0, 68, 9, 45, 8, 57, 5, 71, 1, 19, 7, 79, 4, 81
  };
  const int r941[] = {
    10, 10, // Number of jobs and machines
    9, 65, 8, 84, 2, 33, 0, 57, 6, 25, 5, 26, 7,  7, 4, 85, 1, 41, 3, 26, 
    3, 79, 1, 72, 7, 37, 2, 33, 9, 76, 4, 64, 5, 58, 0, 45, 6, 10, 8, 40, 
    6, 85, 4, 91, 9,  8, 2, 16, 5, 90, 7, 39, 3, 26, 8, 68, 1, 53, 0, 73, 
    3, 43, 0, 30, 9, 37, 4,  4, 6, 43, 7, 74, 5, 55, 2, 15, 8, 88, 1,  8, 
    3, 40, 4, 24, 6,  7, 8, 79, 5, 45, 2,  6, 9, 84, 7, 92, 1,  5, 0, 85, 
    8, 29, 4, 96, 7, 97, 5, 27, 6, 34, 2, 54, 3, 13, 0, 44, 9, 97, 1, 65, 
    6, 58, 3, 67, 2, 70, 1, 40, 8, 68, 7, 43, 9, 97, 0, 42, 4, 62, 5, 50, 
    4,  2, 0, 36, 6, 55, 3, 77, 7, 68, 5, 41, 1, 71, 9, 24, 2, 49, 8, 34, 
    1,  9, 0, 35, 5, 23, 8, 94, 6, 90, 2, 47, 4, 68, 7, 22, 3, 26, 9, 20, 
    5, 80, 7, 93, 2, 40, 9, 48, 4, 53, 1, 29, 8, 68, 0, 45, 6, 36, 3, 13
  };
  const int r942[] = {
    10, 10, // Number of jobs and machines
    8, 74, 9, 10, 6, 84, 3, 38, 0, 41, 5, 88, 7, 77, 2, 17, 1, 28, 4, 82, 
    7, 76, 3, 95, 9, 27, 1, 75, 4, 22, 6, 31, 2, 11, 5, 88, 0,  8, 8, 32, 
    1, 47, 6, 72, 5, 89, 2, 39, 8, 91, 3,  2, 7, 58, 0, 12, 9, 75, 4, 45, 
    6, 64, 2, 15, 8, 19, 7, 10, 4, 63, 3, 10, 0,  8, 5,  7, 9, 65, 1, 90, 
    2, 29, 6, 43, 4, 94, 7,  8, 9, 38, 0, 93, 8, 21, 1, 11, 5,  1, 3, 86, 
    1,  9, 0, 56, 2, 50, 3,  9, 8, 66, 7, 92, 4, 92, 6, 45, 9, 15, 5, 47, 
    5, 49, 7, 68, 9, 71, 8, 90, 4, 48, 3, 29, 6, 22, 2, 50, 0, 12, 1,  4, 
    6,  1, 7, 62, 9, 81, 4, 90, 2, 42, 0, 46, 8, 55, 1, 53, 5, 69, 3, 43, 
    2, 91, 4, 12, 5, 34, 8, 13, 7, 28, 3, 72, 6, 30, 0, 57, 1, 74, 9, 88, 
    1, 35, 6, 30, 2, 66, 0, 54, 4, 97, 8, 78, 3, 95, 5, 86, 9, 13, 7, 81
  };
  const int r943[] = {
    10, 10, // Number of jobs and machines
    9, 78, 4, 16, 0, 34, 1, 99, 7, 28, 8, 37, 6, 87, 5, 73, 2, 70, 3, 81, 
    5, 39, 4, 40, 0, 93, 2, 33, 6, 36, 9, 73, 3,  2, 8, 67, 1, 16, 7, 79, 
    4, 83, 0, 74, 9, 67, 7, 87, 3, 13, 8, 79, 2, 47, 6,  7, 1,  5, 5, 99, 
    6, 98, 7, 10, 8, 13, 5, 49, 0, 59, 9, 47, 1, 98, 3,  8, 4, 22, 2, 85, 
    9, 64, 2, 33, 5, 64, 4, 18, 6, 33, 0, 74, 1, 89, 7,  1, 8, 20, 3, 11, 
    2, 81, 5, 31, 1, 24, 7, 86, 9, 43, 6,  9, 3, 42, 4, 73, 0,  1, 8, 49, 
    9, 17, 8, 13, 5, 78, 2, 23, 6, 87, 7, 86, 3, 10, 4, 52, 0, 72, 1,  8, 
    0,  3, 4, 47, 1, 23, 6, 95, 3,  6, 7, 91, 8, 45, 5,  2, 2,  8, 9, 51, 
    1, 35, 6, 64, 9, 96, 4, 75, 3, 83, 5, 55, 7, 26, 0, 38, 2,  7, 8, 18, 
    9, 27, 4, 39, 7, 54, 2, 91, 5, 94, 6, 94, 8, 87, 1, 72, 3, 40, 0,  3
  };
  const int r944[] = {
    10, 10, // Number of jobs and machines
    5, 82, 6, 62, 1, 37, 2, 99, 3, 21, 0, 77, 7, 98, 8, 96, 9,  2, 4, 16, 
    1, 35, 5,  4, 9, 96, 0,  2, 2, 20, 4, 39, 8, 53, 3, 64, 7, 32, 6, 65, 
    2, 53, 8, 45, 0,  4, 3, 96, 9, 40, 5, 15, 1, 35, 4, 65, 6, 67, 7, 94, 
    5, 94, 6, 75, 8, 31, 9, 42, 0, 43, 3, 43, 4, 12, 1, 58, 2,  6, 7, 85, 
    6, 34, 7, 63, 2, 66, 5, 36, 3, 52, 0, 48, 4,  5, 1, 14, 9, 10, 8, 53, 
    9, 20, 7, 26, 5, 88, 8, 69, 1, 45, 4, 39, 6, 95, 3, 78, 2, 63, 0, 29, 
    5, 33, 8, 35, 1, 97, 7, 46, 0, 58, 2, 83, 6, 46, 3,  1, 9, 35, 4, 28, 
    0, 67, 9, 96, 8, 13, 6, 63, 7, 58, 5, 42, 1, 68, 4, 80, 3, 66, 2, 18, 
    5, 52, 7, 27, 9, 46, 8, 68, 6, 17, 1, 94, 2, 85, 3, 45, 4, 61, 0, 55, 
    8, 70, 0, 89, 3, 90, 2, 26, 7, 70, 4, 83, 5, 96, 6, 83, 1, 36, 9, 72
  };
  const int r945[] = {
    10, 10, // Number of jobs and machines
    3, 58, 0, 28, 6, 36, 1, 53, 7, 83, 8, 91, 9,  7, 2, 46, 4, 82, 5, 19, 
    6, 57, 3,  1, 8, 90, 4, 15, 0, 71, 7, 88, 1, 88, 9, 72, 5, 17, 2, 85, 
    9, 46, 4, 28, 1, 36, 8, 57, 5, 89, 2, 50, 3, 28, 0, 83, 7, 71, 6, 65, 
    0, 98, 1,  7, 9, 42, 4, 11, 6,  1, 5, 24, 8, 28, 3, 85, 7,  3, 2, 31, 
    1, 48, 2, 50, 4, 58, 6, 41, 3, 97, 0, 26, 9, 73, 5, 40, 8, 27, 7, 58, 
    4, 26, 1, 77, 6, 38, 8, 87, 3, 88, 5, 59, 0, 68, 9, 13, 7, 91, 2, 35, 
    0,  2, 1, 49, 7, 15, 2, 99, 9, 94, 4, 35, 3, 71, 6, 59, 8, 39, 5, 18, 
    1, 32, 8, 13, 4, 24, 0, 19, 2, 19, 3, 98, 7, 19, 5, 12, 9,  7, 6, 37, 
    0, 88, 1, 40, 2, 68, 3, 18, 9, 24, 8, 64, 5, 73, 7, 79, 4, 51, 6, 90, 
    9, 40, 0, 79, 7, 22, 2, 25, 6, 50, 5, 53, 4, 59, 3, 50, 8, 74, 1, 82
  };
  const int r946[] = {
    10, 10, // Number of jobs and machines
    6, 32, 8, 50, 0, 52, 5,  9, 7, 22, 9, 77, 2, 24, 4, 54, 3, 29, 1,  4, 
    0, 28, 4,  2, 5, 51, 8, 56, 7, 37, 2, 40, 1, 33, 6, 13, 9,  1, 3, 64, 
    0, 53, 6, 93, 5, 46, 9, 49, 1, 78, 8, 89, 4, 83, 2, 26, 3, 85, 7, 38, 
    3, 60, 4, 21, 1, 37, 9, 86, 2, 64, 5, 83, 0, 87, 6, 86, 8, 43, 7, 44, 
    9, 68, 0, 47, 7, 71, 6, 91, 5, 92, 2, 36, 8, 28, 3,  7, 1, 56, 4, 34, 
    2, 78, 9, 53, 0, 55, 3, 70, 5, 55, 1, 69, 4, 46, 8, 86, 6,  5, 7, 21, 
    5, 40, 9, 45, 8,  9, 3, 53, 1, 47, 0, 98, 7,  3, 4, 74, 6, 49, 2, 76, 
    2, 51, 4, 15, 9, 96, 5, 54, 7,  3, 1, 17, 6, 61, 3,  4, 8, 22, 0, 55, 
    1, 71, 0, 20, 5, 26, 3, 98, 7, 44, 8, 31, 4, 86, 2, 26, 6, 93, 9, 53, 
    9, 51, 7, 12, 3,  5, 4, 28, 2, 99, 1, 76, 5, 87, 0, 51, 8, 99, 6, 20
  };
  const int r947[] = {
    10, 10, // Number of jobs and machines
    6, 69, 0, 81, 7, 74, 3, 47, 4,  5, 5, 50, 2, 89, 9, 65, 1,  9, 8, 59, 
    5, 85, 6, 69, 2, 43, 9, 17, 1, 12, 3, 84, 8, 19, 4, 92, 0, 60, 7, 25, 
    2, 46, 9, 60, 6, 80, 7, 30, 1, 73, 4, 52, 5, 14, 3, 69, 0, 48, 8, 14, 
    0, 48, 9, 75, 4, 37, 7,  1, 8, 44, 3, 26, 5, 74, 1, 46, 2, 32, 6,  4, 
    5, 86, 6, 34, 4, 63, 0, 26, 1, 56, 3, 65, 8, 82, 2, 13, 9, 75, 7, 80, 
    6, 25, 1, 31, 4,  8, 0, 69, 8, 71, 9, 87, 5, 31, 7, 45, 2, 25, 3, 27, 
    1, 79, 3, 29, 7, 31, 8, 11, 2, 87, 6, 90, 5, 99, 0,  5, 4, 84, 9, 33, 
    6, 32, 1, 24, 5, 80, 4, 94, 7, 91, 2, 21, 9, 39, 3, 19, 8, 67, 0, 38, 
    5, 70, 1, 34, 0, 45, 9,  9, 7, 96, 2, 91, 6, 25, 8, 89, 3, 25, 4, 66, 
    7, 46, 0, 49, 2, 44, 6, 81, 5, 63, 3, 57, 4, 51, 8, 58, 9, 93, 1, 34
  };
  const int r948[] = {
    10, 10, // Number of jobs and machines
    7, 70, 1, 51, 8, 72, 9, 93, 2, 57, 3, 62, 6, 27, 4, 95, 0,  8, 5, 72, 
    7, 63, 2, 51, 0, 33, 4, 65, 8, 22, 3, 68, 5, 83, 6, 55, 1, 99, 9, 19, 
    5,  3, 6, 70, 3, 44, 4, 91, 7, 42, 2,  1, 8, 76, 9, 81, 0, 66, 1, 79, 
    0, 65, 2, 25, 1, 94, 4, 15, 6,  6, 5, 37, 3, 36, 9, 72, 8, 14, 7, 36, 
    3, 52, 4, 64, 6, 66, 1, 52, 0,  5, 9, 73, 2, 77, 7, 62, 5, 65, 8, 67, 
    3, 43, 4, 49, 0, 19, 6, 38, 5, 53, 7, 98, 1, 34, 8, 25, 2, 17, 9, 24, 
    6, 15, 5, 83, 8, 15, 3, 82, 4, 21, 2,  8, 9,  8, 7, 20, 0, 81, 1, 24, 
    1, 82, 9, 96, 8, 14, 7,  7, 0,  7, 3,  8, 5, 95, 4, 37, 2, 94, 6, 21, 
    3, 12, 6, 58, 5, 18, 0, 68, 7, 56, 8, 66, 4, 87, 9, 84, 1, 28, 2, 74, 
    4, 94, 8, 41, 6,  4, 9, 58, 1, 26, 5, 96, 0, 18, 3, 65, 7, 75, 2, 25
  };
  const int r949[] = {
    10, 10, // Number of jobs and machines
    2, 53, 0, 84, 1, 49, 9, 37, 5, 67, 7, 21, 4, 34, 3, 88, 6, 92, 8, 65, 
    2, 92, 5, 38, 7, 38, 0, 95, 8, 82, 6, 27, 9, 27, 4, 23, 3, 48, 1, 80, 
    0, 71, 6, 64, 7, 13, 8, 82, 2, 60, 9, 93, 5, 61, 1,  8, 3,  3, 4, 70, 
    7, 85, 5, 66, 8, 83, 4, 62, 0, 77, 9, 41, 1, 54, 3, 13, 2,  6, 6, 83, 
    1, 47, 0, 48, 6, 35, 8, 53, 2, 41, 3, 45, 9, 86, 5, 55, 4, 18, 7, 43, 
    4, 74, 7, 73, 6, 82, 8, 27, 9, 82, 0, 63, 1, 36, 3, 64, 5, 38, 2, 59, 
    1, 93, 3, 62, 4, 95, 5, 30, 7, 72, 9, 14, 6, 22, 8, 45, 0, 28, 2, 36, 
    0, 92, 6,  1, 3, 20, 8, 42, 2, 63, 7, 91, 4, 72, 9, 56, 1, 75, 5, 31, 
    0, 10, 1, 19, 9, 84, 4, 57, 8, 77, 5, 63, 2, 55, 6, 70, 7, 46, 3, 44, 
    8, 17, 5, 69, 3, 19, 4, 10, 7, 18, 2, 99, 0, 67, 6, 29, 9, 40, 1, 33
  };
  const int r950[] = {
    10, 10, // Number of jobs and machines
    4, 28, 7, 78, 6, 97, 3,  1, 5, 72, 0,  9, 1, 97, 9, 18, 2, 87, 8, 39, 
    4, 79, 0, 92, 8,  2, 2, 59, 3, 87, 7, 26, 5,  3, 9, 45, 6, 70, 1, 63, 
    6, 60, 8, 11, 3, 52, 7, 52, 9, 82, 2, 91, 1,  6, 4, 70, 5, 40, 0, 66, 
    3, 67, 5, 57, 4, 43, 2, 28, 9, 94, 6, 96, 1, 58, 0,  3, 8, 69, 7, 17, 
    7, 13, 6, 65, 4, 85, 9, 51, 0, 15, 3, 36, 1, 24, 5, 50, 8, 53, 2, 21, 
    0, 29, 7, 15, 8, 25, 9, 23, 1, 13, 4, 53, 3, 34, 5, 95, 2, 11, 6, 61, 
    2, 17, 7, 62, 5, 88, 3, 81, 9, 26, 4,  4, 1, 64, 6, 93, 0, 33, 8,  3, 
    9, 63, 2, 24, 4, 17, 8, 35, 5, 65, 1, 60, 6, 87, 7, 65, 3, 56, 0, 34, 
    9, 16, 8, 63, 7, 72, 3, 69, 2, 67, 5, 60, 6,  7, 4, 80, 1, 88, 0, 44, 
    3, 22, 4, 75, 0, 73, 6, 66, 7, 63, 8, 85, 9, 64, 2, 14, 5, 62, 1, 54
  };
  const int r951[] = {
    10, 10, // Number of jobs and machines
    4, 73, 6, 65, 0, 34, 5,  2, 1, 75, 8, 15, 2,  6, 9, 91, 3, 12, 7, 63, 
    3, 58, 6, 65, 7, 64, 1, 26, 5, 27, 9, 61, 0, 24, 8, 86, 2,  1, 4, 51, 
    7, 45, 1, 25, 3, 86, 2, 92, 4, 68, 0, 40, 6, 78, 5, 62, 8, 87, 9, 95, 
    2, 51, 6, 45, 8, 42, 7, 96, 4, 48, 9, 38, 0, 85, 1, 49, 3, 29, 5, 64, 
    0, 12, 9, 68, 2, 82, 3, 56, 4, 34, 7, 47, 5, 77, 6, 62, 8, 91, 1, 60, 
    7, 56, 2,  9, 5, 33, 0, 28, 3, 11, 8, 97, 4, 78, 1, 52, 9, 60, 6, 43, 
    9, 58, 4, 12, 1, 26, 2, 62, 6, 51, 5, 44, 8, 71, 0, 77, 3, 84, 7, 77, 
    4, 23, 2, 37, 1, 76, 5, 27, 8, 44, 3, 85, 6, 51, 7, 94, 0, 76, 9, 69, 
    4, 14, 0, 23, 7, 29, 5, 67, 2, 75, 6, 82, 3, 82, 1, 61, 9, 49, 8, 42, 
    0,  7, 7, 60, 5, 75, 6, 74, 8, 23, 1, 71, 3, 56, 4,  1, 9, 43, 2, 80
  };
  const int r952[] = {
    10, 10, // Number of jobs and machines
    3, 39, 1, 81, 0,  1, 7, 53, 6, 55, 9, 29, 2, 24, 4, 63, 8, 67, 5, 62, 
    0, 71, 5, 59, 9, 85, 3, 30, 4, 24, 8, 60, 1,  7, 7, 72, 2,  8, 6, 85, 
    2, 46, 1, 93, 0, 35, 7, 11, 8, 90, 4, 26, 3, 42, 9, 46, 5, 47, 6, 67, 
    0, 74, 6, 55, 2, 65, 5, 14, 4,  2, 9, 82, 1, 39, 3, 39, 8,  2, 7, 52, 
    2, 42, 9, 30, 7, 68, 3, 34, 5, 54, 0, 80, 4, 18, 8, 23, 6, 63, 1, 37, 
    6, 83, 5, 58, 8, 94, 7, 45, 4, 15, 0, 89, 2, 11, 9, 82, 3, 38, 1, 69, 
    3, 27, 7, 89, 1, 95, 9, 39, 4, 30, 5, 99, 8, 93, 0, 98, 6, 64, 2, 48, 
    1, 64, 8, 37, 6, 57, 4,  4, 0, 46, 7, 93, 5, 64, 2, 15, 9,  6, 3, 51, 
    0, 58, 2, 86, 5, 75, 3, 29, 6, 73, 4, 42, 1, 95, 8, 80, 7, 87, 9, 64, 
    0, 31, 3, 18, 6, 87, 2, 34, 4, 13, 7, 59, 9, 10, 8, 17, 1, 43, 5,  1
  };
  const int r953[] = {
    10, 10, // Number of jobs and machines
    2, 64, 0, 77, 5, 96, 4, 48, 7, 75, 1, 10, 6, 95, 8, 31, 9, 41, 3, 84, 
    2, 76, 8, 90, 6,  7, 9, 12, 1, 60, 3, 40, 5, 36, 7, 15, 0, 13, 4, 18, 
    8,  5, 0, 96, 9, 74, 4, 85, 5, 50, 3, 97, 2,  2, 6, 75, 1, 10, 7, 54, 
    6, 49, 2, 46, 1, 56, 0, 39, 4, 87, 7, 96, 9, 40, 3, 22, 8, 62, 5,  9, 
    5, 56, 8, 53, 6, 32, 7, 17, 3, 75, 0, 79, 9, 24, 4, 90, 2, 14, 1, 40, 
    5, 44, 0, 79, 3, 45, 1, 87, 6, 20, 9, 53, 2, 52, 8,  4, 7, 59, 4, 29, 
    4, 10, 7,  3, 6, 12, 5, 20, 9, 95, 0, 32, 2, 11, 1,  9, 8, 57, 3, 76, 
    6, 29, 8,  3, 7, 54, 5, 56, 9, 79, 2, 22, 3, 97, 0, 31, 1, 45, 4, 71, 
    9, 89, 3,  6, 7, 95, 2, 77, 4, 55, 6, 87, 8, 56, 5, 88, 1, 49, 0,  4, 
    9, 22, 6, 49, 3,  3, 8, 13, 4, 60, 0, 84, 5, 21, 7, 96, 1,  9, 2, 88
  };
  const int r954[] = {
    10, 10, // Number of jobs and machines
    8, 12, 6, 94, 5, 51, 7, 28, 2,  1, 0, 91, 1, 32, 9, 47, 3, 79, 4, 28, 
    3, 46, 7, 66, 4, 88, 9, 45, 5, 91, 2, 21, 1, 87, 0, 20, 6, 40, 8, 27, 
    4, 95, 9,  7, 8, 70, 0, 80, 1, 23, 5, 48, 2, 13, 3, 39, 7, 38, 6, 79, 
    1,  6, 2, 93, 3, 96, 7, 94, 5,  5, 0, 36, 9, 67, 4, 89, 8, 15, 6, 84, 
    7, 37, 0, 38, 5, 64, 6, 48, 3, 21, 9, 97, 2, 51, 1, 41, 8, 16, 4, 59, 
    5,  2, 4, 71, 2, 80, 8, 48, 9, 42, 1, 36, 0, 18, 6, 38, 3, 99, 7, 97, 
    6, 60, 1, 94, 2, 81, 9, 30, 5, 66, 8, 97, 0, 16, 7, 30, 4, 98, 3, 43, 
    0, 85, 9, 28, 3, 73, 1, 68, 5, 45, 2, 73, 7, 32, 6, 78, 8,  8, 4, 52, 
    9, 34, 4, 95, 2, 55, 7, 79, 8, 22, 5,  1, 3, 18, 6, 33, 0, 56, 1, 61, 
    2, 61, 3, 43, 5, 22, 0, 20, 8, 15, 6, 26, 7, 22, 1, 13, 9, 59, 4, 39
  };
  const int r955[] = {
    10, 10, // Number of jobs and machines
    7, 70, 9, 75, 8,  5, 1, 46, 0, 49, 2,  7, 3, 95, 4, 95, 5, 27, 6, 91, 
    2, 72, 7, 14, 4, 92, 8,  5, 5, 10, 3, 20, 9, 29, 1, 59, 6, 82, 0, 15, 
    3, 37, 6, 56, 4, 40, 7, 33, 2, 45, 9,  1, 8, 75, 1, 81, 5,  5, 0,  6, 
    9, 58, 8, 97, 1, 13, 2, 76, 0, 61, 7, 77, 5,  7, 6, 28, 4, 25, 3, 90, 
    5, 71, 8, 74, 4, 39, 3, 67, 0, 11, 6,  9, 2, 57, 9, 43, 7, 43, 1, 29, 
    3, 56, 8, 14, 9, 64, 0, 13, 6, 23, 7, 93, 2, 69, 5, 71, 4, 50, 1, 65, 
    8, 96, 4, 49, 3, 94, 6, 96, 7, 49, 5, 53, 9, 91, 1, 43, 2, 51, 0, 74, 
    3, 92, 8,  5, 1, 46, 5, 86, 4, 68, 2, 79, 7, 60, 0, 74, 6, 24, 9, 35, 
    8, 34, 1, 95, 0, 62, 7, 89, 5, 83, 6, 26, 4,  3, 2,  8, 9, 89, 3,  2, 
    7, 96, 2, 74, 6, 26, 3, 27, 4, 32, 9, 21, 0, 34, 8, 61, 1, 89, 5,  7
  };
  const int r956[] = {
    10, 10, // Number of jobs and machines
    9, 39, 7, 68, 6, 73, 2, 85, 4, 96, 5, 84, 1, 45, 3, 85, 0, 40, 8, 54, 
    0, 46, 6, 93, 4, 84, 8, 79, 5,  1, 1, 40, 9, 81, 2, 78, 3, 42, 7, 88, 
    3, 60, 4, 21, 9, 91, 8, 22, 6, 41, 7, 30, 0, 93, 2, 98, 1, 21, 5, 64, 
    0, 89, 8, 71, 9, 36, 5,  5, 6, 19, 3, 79, 4, 85, 2, 29, 7, 85, 1, 30, 
    3, 57, 4, 31, 1, 42, 2, 84, 6, 67, 9, 90, 8, 30, 7, 67, 5, 36, 0, 93, 
    5, 25, 9, 48, 1, 63, 8, 94, 4, 24, 7, 89, 6, 83, 3, 50, 0, 99, 2, 91, 
    2, 39, 8, 32, 1, 10, 7, 31, 4, 13, 3, 11, 0,  6, 5, 18, 6, 30, 9, 86, 
    2, 27, 4, 78, 6, 59, 8, 24, 0, 32, 1, 54, 7, 72, 5, 70, 9, 40, 3, 11, 
    0, 75, 5, 32, 9, 89, 1, 55, 4, 95, 6, 15, 8, 92, 3,  8, 7,  2, 2, 10, 
    8, 68, 3, 58, 1, 17, 7, 79, 4, 32, 0, 40, 9, 24, 2,  8, 6, 62, 5, 95
  };
  const int r957[] = {
    10, 10, // Number of jobs and machines
    0, 68, 9, 51, 2, 95, 7, 49, 1, 63, 5, 62, 3, 49, 4, 92, 6, 77, 8, 85, 
    6, 65, 1, 65, 7, 93, 9, 37, 2, 18, 5, 22, 0, 92, 8, 63, 4, 33, 3, 21, 
    7, 82, 2, 46, 5, 80, 3, 80, 8, 52, 1, 60, 4, 73, 9, 86, 0, 91, 6, 37, 
    0, 90, 3, 83, 4, 86, 2,  9, 7, 99, 6, 12, 5, 25, 9, 49, 8, 42, 1, 37, 
    2, 43, 1, 73, 0, 92, 3, 11, 4, 47, 8, 85, 5,  7, 9, 99, 7, 55, 6, 26, 
    0,  7, 2, 68, 7, 57, 3, 22, 1, 38, 8, 38, 5, 42, 4, 70, 9, 61, 6, 51, 
    3, 30, 5, 49, 1, 22, 7, 94, 2, 13, 0, 81, 6, 71, 4, 71, 9, 50, 8, 32, 
    8, 34, 7,  6, 0, 51, 1, 30, 5, 51, 2, 32, 4, 98, 6, 95, 3, 38, 9, 32, 
    8, 36, 6, 60, 3, 48, 9, 70, 7, 41, 4, 84, 2, 69, 5,  2, 1,  6, 0, 26, 
    2, 70, 5, 64, 9, 27, 3, 37, 6, 85, 7, 49, 4, 92, 8, 38, 0, 21, 1, 94
  };
  const int r958[] = {
    10, 10, // Number of jobs and machines
    9, 55, 5, 75, 2, 15, 1, 69, 4, 12, 8, 94, 3, 34, 0, 54, 7,  3, 6, 66, 
    5, 52, 0, 78, 1,  3, 8, 98, 3, 80, 2, 10, 7, 85, 9, 14, 4, 10, 6, 46, 
    1,  5, 3, 39, 7, 74, 6, 20, 0, 70, 5, 15, 4, 30, 9,  3, 2, 34, 8, 11, 
    9, 90, 0, 13, 6, 88, 1,  5, 2, 62, 8, 54, 7, 93, 4, 28, 3, 34, 5, 86, 
    8, 77, 7, 85, 5, 71, 9, 64, 1, 75, 3, 51, 4, 28, 2, 27, 0, 66, 6, 50, 
    4, 42, 7, 71, 8, 21, 5, 21, 1, 27, 3, 90, 0, 60, 6, 76, 9, 42, 2, 32, 
    7, 30, 2, 19, 3,  4, 5, 80, 8, 76, 4, 46, 0, 13, 9, 45, 6, 49, 1, 22, 
    0, 45, 3, 56, 1, 93, 9,  5, 7, 20, 4, 50, 2, 44, 5, 58, 8, 63, 6, 38, 
    5, 96, 2, 65, 9, 97, 1, 22, 0, 37, 8, 17, 7, 36, 3, 27, 6, 53, 4, 86, 
    3, 44, 2, 18, 9, 62, 7,  6, 1, 59, 5, 52, 0, 34, 6, 59, 4, 10, 8, 40
  };
  const int r959[] = {
    10, 10, // Number of jobs and machines
    4, 79, 6, 62, 1, 35, 9, 41, 5, 95, 8, 25, 3, 43, 7, 45, 2,  3, 0, 61, 
    6, 68, 9,  5, 0,  3, 4, 73, 2, 44, 3, 95, 1, 80, 8, 67, 5, 71, 7, 12, 
    3, 60, 7, 79, 8, 43, 0, 54, 2, 87, 9, 50, 5, 97, 6,  8, 1, 26, 4, 71, 
    6, 38, 2, 89, 5, 80, 8, 95, 3,  4, 0, 27, 7,  8, 1, 59, 9, 90, 4, 13, 
    9, 86, 3, 74, 4, 84, 6, 81, 2, 28, 0,  3, 5, 11, 1, 61, 7, 39, 8, 70, 
    8, 37, 2, 79, 1, 10, 0, 51, 3, 56, 5, 18, 6, 68, 9, 44, 7, 29, 4, 31, 
    8, 14, 1, 17, 3, 69, 6, 64, 7, 17, 2, 82, 4, 43, 0, 43, 9, 29, 5, 10, 
    9, 18, 5,  6, 1, 48, 3, 62, 0, 65, 8, 81, 2, 26, 7, 66, 6, 89, 4, 52, 
    3,  1, 1, 57, 4, 77, 7, 86, 5, 85, 0, 85, 9,  7, 2, 70, 6, 29, 8, 12, 
    5, 11, 2, 63, 7,  7, 9, 34, 3, 39, 6, 26, 1, 41, 0, 65, 4, 32, 8, 81
  };
  const int r960[] = {
    10, 10, // Number of jobs and machines
    9, 56, 4, 48, 0, 12, 8, 60, 7, 28, 3, 97, 6, 30, 5,  3, 2, 52, 1, 76, 
    9, 84, 7, 80, 5, 37, 0, 93, 3, 80, 8, 77, 1, 51, 2, 36, 4, 49, 6, 79, 
    0, 92, 4, 59, 1,  4, 3, 42, 7,  2, 2, 29, 8, 23, 5, 74, 9, 39, 6, 70, 
    6,  7, 1, 37, 2, 24, 7, 70, 9, 99, 4, 66, 0, 14, 8,  5, 5, 50, 3, 72, 
    7, 68, 0, 70, 3, 24, 4, 10, 1, 86, 8, 74, 5, 29, 2, 87, 9, 26, 6, 46, 
    4, 73, 5, 39, 0, 64, 6, 43, 2, 96, 7, 30, 9, 61, 8, 60, 1, 47, 3, 30, 
    4, 94, 9, 47, 5, 74, 0, 18, 7, 69, 2, 59, 8, 10, 3, 77, 6, 17, 1, 88, 
    4,  1, 7, 16, 5, 11, 0, 13, 2, 44, 1, 44, 3, 31, 8, 40, 6, 70, 9,  3, 
    8, 14, 1, 11, 6, 20, 5, 86, 7, 20, 9, 96, 3,  7, 2, 38, 0, 28, 4, 45, 
    2,  2, 8,  6, 7,  8, 9, 62, 0, 92, 4, 70, 5, 23, 3, 87, 1, 97, 6, 87
  };
  const int r961[] = {
    10, 10, // Number of jobs and machines
    8, 28, 3,  6, 0, 65, 9, 51, 4, 14, 2, 29, 7, 46, 6, 87, 1, 51, 5, 45, 
    2, 65, 3, 10, 8, 72, 0, 93, 4, 50, 1, 72, 5, 92, 9, 52, 6, 96, 7,  7, 
    8, 63, 5, 87, 2, 52, 3, 31, 0,  6, 7, 61, 6,  5, 4, 58, 1, 24, 9, 63, 
    7, 72, 4, 12, 3, 34, 2, 24, 1, 22, 0, 22, 6, 46, 9, 42, 8, 60, 5, 77, 
    3, 62, 2, 46, 6, 95, 1, 68, 7, 36, 9, 63, 5, 33, 4, 12, 8, 16, 0, 10, 
    9, 16, 0, 30, 6,  1, 5, 60, 8, 47, 3, 69, 4,  5, 7, 77, 1,  9, 2, 79, 
    0, 27, 2, 36, 1, 21, 6, 44, 7,  2, 4, 22, 3, 66, 9, 76, 5, 45, 8, 28, 
    0, 50, 3, 45, 1, 64, 4, 87, 9, 19, 2, 48, 7,  7, 5, 16, 8, 98, 6, 96, 
    0, 39, 7, 69, 9, 16, 4,  9, 3, 11, 6, 90, 1, 34, 8,  9, 5, 97, 2,  8, 
    3,  7, 7, 94, 6, 22, 5, 42, 4, 25, 0, 20, 1,  2, 2, 91, 9, 42, 8, 84
  };
  const int r962[] = {
    10, 10, // Number of jobs and machines
    2, 91, 5, 41, 3, 85, 1, 94, 4, 14, 0, 48, 7, 77, 6, 16, 8, 20, 9, 74, 
    5, 79, 8, 89, 7, 97, 9, 66, 0, 83, 6, 60, 3,  1, 1, 78, 2, 69, 4, 34, 
    8, 93, 4, 69, 0, 75, 2, 59, 5, 26, 1, 71, 7, 45, 3, 74, 9, 28, 6, 42, 
    7, 58, 9, 55, 1, 91, 5, 94, 0, 82, 2, 76, 8, 30, 4, 90, 3, 46, 6, 96, 
    1, 70, 3,  1, 9, 49, 6, 75, 8, 18, 7, 29, 5, 53, 2, 78, 0, 16, 4, 28, 
    7, 96, 6, 47, 1,  7, 8, 93, 0, 56, 2,  8, 4, 15, 3, 97, 5, 61, 9, 77, 
    7, 60, 2, 81, 0, 34, 9,  2, 8, 30, 6, 72, 3, 88, 4, 29, 1, 96, 5, 17, 
    6, 52, 5, 41, 0,  9, 2, 99, 4, 27, 8, 99, 9, 94, 1, 64, 7, 17, 3, 40, 
    4, 29, 0, 91, 8, 65, 2, 60, 6, 88, 3, 61, 9, 22, 5, 90, 1, 43, 7, 57, 
    3, 79, 1, 13, 0, 62, 9, 47, 4, 38, 5, 71, 8, 22, 6, 36, 7, 51, 2,  2
  };
  const int r963[] = {
    10, 10, // Number of jobs and machines
    9, 96, 6, 88, 1, 87, 7, 50, 8, 30, 0, 15, 5, 82, 4, 34, 3, 68, 2, 46, 
    0, 82, 6, 46, 8,  7, 1, 18, 7, 69, 9, 85, 3, 83, 5, 14, 2, 66, 4, 61, 
    4, 51, 1, 62, 8, 26, 6, 16, 2, 32, 9, 38, 3, 69, 7, 53, 0, 50, 5, 22, 
    2, 33, 7, 66, 3, 13, 9, 54, 0, 37, 1, 65, 8, 98, 6, 42, 4, 35, 5, 45, 
    7, 35, 5,  3, 4, 32, 0, 40, 2, 50, 3, 38, 9, 46, 1, 46, 8, 84, 6, 99, 
    3,  4, 9, 88, 0, 85, 5, 83, 6, 19, 4, 32, 8, 83, 7, 88, 2, 56, 1, 66, 
    0, 80, 6, 97, 2,  2, 5, 46, 3, 96, 7,  9, 4, 71, 1, 69, 8, 22, 9, 82, 
    4, 39, 8, 69, 3, 98, 1,  3, 5, 38, 7, 40, 6, 27, 0, 41, 2, 18, 9, 64, 
    7, 33, 5,  2, 3, 63, 2, 57, 8, 26, 0, 27, 6, 44, 1, 65, 4, 57, 9, 35, 
    9, 66, 7, 91, 0, 50, 5, 34, 4, 30, 6, 97, 3, 70, 1, 74, 8, 86, 2, 33
  };
  const int r964[] = {
    10, 10, // Number of jobs and machines
    4, 29, 2, 67, 5, 63, 1, 54, 9, 45, 3, 76, 6, 91, 7, 45, 0, 85, 8, 50, 
    6, 43, 5, 29, 4,  5, 2, 11, 0, 26, 7, 45, 8, 53, 3, 81, 1, 15, 9, 83, 
    5, 87, 3, 75, 0, 91, 1, 68, 4, 58, 8, 60, 9,  4, 7, 93, 6, 18, 2, 50, 
    2, 59, 8, 74, 1, 64, 5, 56, 3, 47, 4, 76, 6, 11, 9, 41, 0, 16, 7, 44, 
    8, 21, 3, 20, 0, 14, 2, 92, 7, 67, 6, 92, 9, 64, 4, 24, 5, 60, 1, 47, 
    5, 47, 0,  4, 2, 40, 4, 79, 6,  8, 3, 43, 1, 52, 8, 49, 7, 57, 9, 93, 
    1, 24, 6, 40, 5, 26, 8, 81, 3, 24, 0, 84, 2, 49, 4,  2, 9, 91, 7, 27, 
    5, 88, 2, 44, 7, 10, 9, 35, 4, 90, 0, 20, 6, 54, 3, 10, 8, 12, 1, 92, 
    4, 27, 3, 24, 8, 10, 1, 46, 6, 12, 5, 91, 7, 53, 2, 18, 0, 19, 9,  7, 
    0, 56, 6, 94, 9, 29, 4, 21, 7, 39, 8, 36, 3, 86, 1, 92, 5, 73, 2, 13
  };
  const int r965[] = {
    10, 10, // Number of jobs and machines
    7, 46, 6, 19, 8, 93, 3, 25, 5, 24, 2, 59, 1, 66, 0, 20, 9,  2, 4, 27, 
    3, 97, 0, 28, 8, 63, 4, 21, 5, 40, 1, 94, 9, 98, 6, 85, 7, 73, 2, 40, 
    2, 20, 0, 38, 7, 20, 5, 25, 3, 75, 6, 10, 4, 93, 9, 13, 1, 65, 8, 86, 
    2, 97, 6,  2, 9, 72, 7, 56, 4, 70, 5,  3, 0, 29, 3, 59, 8, 99, 1, 71, 
    6, 25, 0, 18, 3, 73, 8, 37, 5, 35, 2, 99, 4, 52, 9, 34, 1, 41, 7, 65, 
    0, 81, 4, 24, 5, 91, 2, 94, 9, 69, 7, 96, 8, 67, 1, 47, 3, 31, 6, 48, 
    0, 81, 2, 24, 6, 73, 3, 33, 1, 47, 8, 13, 7, 52, 9, 80, 5, 66, 4, 62, 
    9, 53, 5, 31, 1, 34, 2, 72, 3,  7, 7, 40, 4, 22, 8, 53, 6, 88, 0, 19, 
    5, 10, 2, 53, 4, 59, 7, 63, 9, 76, 3,  3, 8, 87, 0, 44, 1, 17, 6, 19, 
    3, 78, 0, 15, 8, 76, 2, 18, 4, 40, 7, 90, 9, 58, 1, 64, 6, 10, 5, 90
  };
  const int r966[] = {
    10, 10, // Number of jobs and machines
    4, 52, 5, 22, 0, 10, 8,  1, 2, 67, 1, 26, 6,  3, 3, 95, 9, 93, 7, 70, 
    1, 14, 8, 83, 6,  9, 4, 10, 9,  5, 2, 83, 7, 87, 3,  3, 5, 93, 0, 96, 
    1, 89, 5, 43, 0, 73, 9, 19, 6, 62, 4, 55, 2, 32, 3, 66, 8, 22, 7, 93, 
    9, 23, 1, 57, 5, 34, 3, 18, 8, 91, 2, 94, 4, 95, 6, 55, 0, 44, 7, 16, 
    8, 29, 3, 88, 9, 13, 5, 80, 7, 39, 6, 81, 1, 69, 2, 57, 0, 85, 4, 95, 
    0, 31, 8, 99, 6, 89, 3, 92, 2, 74, 9,  4, 5, 10, 7, 79, 4, 19, 1, 67, 
    0, 23, 9, 32, 6, 84, 8, 96, 5, 86, 7, 82, 1, 30, 4, 14, 2, 47, 3, 21, 
    9, 31, 8, 56, 5, 13, 7, 94, 1, 93, 6, 90, 2, 38, 0, 18, 4,  5, 3, 10, 
    5, 64, 9, 68, 0, 92, 7, 34, 2, 45, 1, 75, 3, 99, 8, 84, 4,  6, 6, 33, 
    2, 23, 4, 51, 0, 35, 3, 63, 1, 42, 6, 53, 7,  3, 5,  4, 8, 19, 9, 18
  };
  const int r967[] = {
    10, 10, // Number of jobs and machines
    3, 88, 7, 59, 9, 63, 0, 11, 5, 71, 6, 80, 2, 20, 8, 90, 1, 83, 4, 13, 
    5, 16, 4, 43, 8, 60, 3, 47, 2, 98, 9, 76, 0, 32, 1, 85, 7, 41, 6, 65, 
    5, 19, 2, 62, 1, 45, 0, 89, 8, 43, 6,  4, 9, 35, 7, 76, 4, 74, 3, 72, 
    4, 77, 8, 21, 5, 62, 9, 36, 7, 30, 6,  5, 0, 87, 1, 12, 3, 17, 2,  3, 
    9, 96, 7, 16, 8, 21, 1, 63, 5,  1, 0, 19, 2, 77, 4,  6, 6,  3, 3, 76, 
    5, 42, 9, 57, 8,  2, 4, 57, 6, 91, 0, 32, 2, 15, 7, 59, 3, 41, 1, 12, 
    7, 95, 1, 65, 6, 82, 8, 88, 0, 43, 5, 87, 3, 59, 2, 91, 4, 87, 9, 90, 
    2, 18, 0, 84, 9, 62, 1, 25, 8, 73, 3, 29, 5, 80, 4, 84, 6, 54, 7, 50, 
    9, 16, 8, 61, 2, 89, 4, 68, 3, 85, 1, 81, 5, 48, 7,  7, 6, 57, 0, 31, 
    4, 36, 8, 33, 0, 38, 1, 57, 3, 88, 6, 80, 9, 66, 7, 94, 2, 35, 5, 16
  };
  const int r968[] = {
    10, 10, // Number of jobs and machines
    3,  4, 0, 86, 4, 49, 6, 56, 9, 61, 5, 80, 8, 79, 2, 62, 7, 85, 1, 19, 
    1, 98, 4, 51, 9, 61, 7, 23, 3,  9, 0, 50, 5, 44, 2, 71, 6, 82, 8,  5, 
    4, 68, 3, 94, 0, 64, 8,  1, 7, 51, 6, 36, 5, 76, 2, 63, 9, 35, 1, 62, 
    7, 63, 0, 75, 8, 41, 5, 34, 4, 44, 2, 93, 9, 41, 3, 88, 6, 29, 1, 96, 
    2, 14, 8, 43, 5, 78, 7,  7, 3, 78, 4, 25, 1, 53, 9, 89, 6,  9, 0,  9, 
    2, 53, 4, 39, 9, 59, 5, 56, 0, 15, 8, 12, 6, 28, 3, 54, 1, 28, 7, 11, 
    7, 12, 4,  1, 3, 77, 8, 70, 0, 57, 1, 24, 5, 77, 2,  3, 9, 95, 6,  7, 
    1, 32, 8, 69, 9, 82, 2, 14, 3, 45, 7, 13, 0, 90, 4, 69, 5, 25, 6, 87, 
    4, 95, 6, 81, 5, 16, 2, 78, 3, 95, 8, 59, 9, 71, 1, 54, 0, 47, 7, 22, 
    9, 38, 1, 51, 4, 47, 7, 15, 8,  8, 6,  8, 0,  9, 3, 45, 2, 35, 5, 55
  };
  const int r969[] = {
    10, 10, // Number of jobs and machines
    6, 41, 3, 35, 1,  4, 2, 64, 7, 38, 5, 85, 4, 67, 0, 44, 8, 66, 9, 13, 
    3, 17, 2, 58, 8, 64, 0, 68, 9, 39, 7, 74, 4, 29, 1, 54, 5, 66, 6, 52, 
    2, 91, 4,  6, 9, 27, 3, 23, 0, 91, 8,  5, 5, 40, 7, 42, 6, 46, 1, 44, 
    4, 85, 9, 17, 6, 83, 5, 24, 0, 51, 8, 33, 7, 40, 2, 20, 3, 94, 1, 52, 
    6, 41, 7, 50, 5, 58, 9, 74, 2, 45, 3, 71, 8, 22, 0, 56, 4, 17, 1, 90, 
    1, 94, 4, 79, 5, 70, 3, 62, 6, 38, 0, 58, 2,  8, 8, 88, 9, 51, 7, 96, 
    1, 78, 5, 35, 0, 66, 9, 68, 2, 21, 3,  6, 8, 84, 4, 73, 7, 52, 6, 24, 
    7, 98, 6, 18, 8, 67, 2, 72, 0, 66, 3, 97, 5, 71, 1, 45, 9, 18, 4, 71, 
    9,  2, 3, 61, 8, 45, 0,  7, 6, 63, 5, 75, 1, 30, 2,  6, 4, 10, 7, 51, 
    3, 65, 0, 47, 8, 47, 5, 63, 7, 38, 4, 20, 2, 50, 6, 34, 9, 37, 1, 19
  };
  const int r970[] = {
    10, 10, // Number of jobs and machines
    1, 81, 0, 54, 4, 53, 3, 99, 5, 78, 7, 22, 9, 11, 8, 93, 6, 97, 2, 78, 
    0, 48, 6, 59, 3, 51, 7, 44, 1, 50, 5, 30, 9, 22, 2, 98, 8, 74, 4, 13, 
    5, 55, 3, 71, 0, 67, 7, 88, 9, 92, 2, 99, 1, 98, 4, 56, 8, 65, 6, 53, 
    3, 86, 7, 25, 4, 99, 1, 26, 6, 50, 0, 56, 8, 75, 5,  9, 2, 59, 9, 39, 
    5, 25, 6, 34, 3, 28, 8,  7, 7, 91, 0, 89, 9, 71, 2,  7, 1, 48, 4, 97, 
    8, 32, 5, 80, 1, 39, 2, 51, 0, 15, 6, 43, 7, 79, 4, 80, 3, 65, 9, 93, 
    2, 45, 5, 36, 4, 96, 6, 65, 9, 64, 3, 97, 7, 82, 0,  5, 8, 99, 1, 56, 
    6, 78, 4, 86, 3, 24, 9, 81, 0, 37, 5, 50, 1, 86, 2,  3, 8, 30, 7, 15, 
    1, 56, 5, 24, 0, 98, 8, 60, 7, 70, 9, 32, 3,  9, 2, 75, 4, 39, 6, 15, 
    1, 16, 4, 43, 5, 32, 2, 50, 6, 20, 3, 79, 7, 31, 8, 67, 0, 69, 9, 12
  };
  const int r971[] = {
    10, 10, // Number of jobs and machines
    9, 53, 5, 78, 4, 28, 3, 14, 2, 14, 0, 59, 6, 58, 8, 83, 1, 64, 7, 24, 
    0, 50, 2, 35, 1, 54, 9, 61, 5, 43, 6, 70, 8, 95, 4, 30, 3, 47, 7, 15, 
    8,  9, 5, 32, 9, 39, 3, 66, 1, 27, 0, 89, 6, 57, 2, 90, 4, 39, 7, 36, 
    2, 24, 5, 16, 1, 98, 4, 18, 6, 54, 7,  8, 9, 45, 8, 33, 0, 27, 3, 61, 
    0, 27, 9, 10, 6,  3, 8, 99, 4, 47, 7, 72, 5, 86, 1, 81, 2, 88, 3, 77, 
    3, 66, 1, 91, 5, 51, 7, 29, 0, 20, 2, 23, 6, 56, 4, 58, 8, 57, 9, 21, 
    5, 87, 0, 94, 2, 56, 3, 69, 8, 15, 6, 77, 4, 78, 9, 81, 1, 97, 7, 57, 
    1, 97, 4, 54, 3, 48, 8, 97, 2, 55, 9, 63, 5, 93, 0, 85, 7, 48, 6, 47, 
    9, 48, 3, 73, 0, 74, 8, 60, 4, 38, 2, 63, 1, 98, 6, 85, 7, 18, 5, 17, 
    2,  5, 1, 47, 0, 15, 6,  9, 9, 19, 4, 85, 8, 19, 7, 91, 3, 48, 5, 61
  };
  const int r972[] = {
    10, 10, // Number of jobs and machines
    6, 51, 3,  9, 5, 64, 7, 62, 1, 58, 2, 47, 8, 83, 9, 12, 0, 48, 4, 73, 
    8, 65, 2, 69, 7, 13, 5, 83, 3, 97, 1,  1, 4,  7, 6, 91, 0, 49, 9, 18, 
    1, 14, 3,  3, 0, 65, 8, 45, 5, 10, 4, 66, 7, 31, 2, 38, 6, 22, 9, 91, 
    3, 33, 9, 14, 0, 22, 8, 16, 4, 36, 2, 20, 5,  8, 6, 17, 7, 87, 1, 36, 
    6, 47, 8, 51, 1, 12, 3, 38, 4, 79, 7, 71, 2, 17, 5, 18, 0, 39, 9, 24, 
    9, 88, 2, 42, 1, 24, 6, 94, 0, 50, 3, 35, 4,  4, 7, 10, 5, 58, 8, 17, 
    6, 64, 2, 93, 3, 84, 4, 54, 5, 20, 8, 28, 7, 34, 1, 81, 9, 73, 0,  1, 
    2, 14, 0, 10, 8, 78, 7, 42, 6, 70, 1, 10, 4, 98, 5, 68, 9, 29, 3, 51, 
    7,  4, 0, 62, 2, 53, 5, 66, 8, 67, 4, 72, 9, 58, 6, 81, 3, 88, 1, 83, 
    5, 74, 8, 22, 7, 76, 9, 89, 6, 92, 2, 58, 0,  6, 1, 35, 4,  8, 3, 55
  };
  const int r973[] = {
    10, 10, // Number of jobs and machines
    1, 80, 3, 19, 4, 14, 0, 17, 5, 52, 9, 10, 6,  2, 7, 38, 8, 73, 2,  6, 
    9, 58, 5, 62, 8, 15, 0, 37, 2, 65, 6, 12, 1, 23, 3, 75, 7, 44, 4, 92, 
    4, 97, 0, 18, 3, 54, 1,  6, 7, 47, 9, 83, 5, 59, 6, 45, 8, 96, 2, 36, 
    7, 38, 4, 53, 5, 37, 6, 82, 1,  9, 2, 36, 8, 72, 0, 32, 3, 49, 9, 61, 
    6, 74, 5, 63, 1, 51, 8,  8, 9, 80, 7, 28, 0, 92, 3, 39, 4, 94, 2, 37, 
    1, 10, 8, 98, 6, 15, 4, 80, 3, 80, 9, 91, 2, 98, 5, 59, 7, 11, 0, 81, 
    8, 52, 6, 92, 2, 22, 4, 91, 0, 12, 9, 70, 5, 50, 7, 18, 1, 20, 3, 23, 
    3, 14, 4, 86, 8, 32, 7,  5, 6, 85, 1, 79, 5, 88, 0, 53, 9, 80, 2, 61, 
    1, 80, 5, 56, 0, 60, 4, 86, 7, 20, 6, 12, 9, 30, 3, 11, 8, 31, 2, 45, 
    9, 20, 4, 42, 0, 71, 8, 74, 2, 91, 7, 36, 5, 76, 6, 61, 1, 12, 3, 57
  };
  const int r974[] = {
    10, 10, // Number of jobs and machines
    7, 26, 5, 47, 3, 91, 1, 72, 8, 92, 6, 19, 4, 52, 2, 62, 9,  1, 0,  2, 
    1,  8, 4, 38, 3, 56, 9, 29, 0, 75, 5, 72, 8, 86, 7, 41, 2, 61, 6, 43, 
    7, 88, 5, 21, 3, 75, 4, 47, 0, 19, 1, 28, 9, 13, 2, 98, 8, 13, 6,  9, 
    9,  4, 0, 88, 1, 61, 8, 47, 5, 15, 4, 30, 6, 16, 3, 46, 2, 60, 7, 23, 
    7, 99, 5, 91, 6, 64, 1, 14, 4, 47, 3, 70, 8, 61, 0, 27, 9, 55, 2, 53, 
    1, 33, 7, 43, 5, 44, 8, 41, 4, 98, 2, 87, 6, 40, 3, 75, 0, 49, 9, 55, 
    7, 41, 6, 30, 9, 81, 4, 92, 1, 62, 3, 52, 8, 23, 0, 97, 2,  6, 5, 61, 
    2,  6, 8, 21, 4, 30, 5, 96, 6, 92, 3, 42, 9, 82, 7, 12, 1, 99, 0, 75, 
    6, 68, 8, 60, 0,  8, 9, 72, 1, 83, 4, 58, 5, 77, 7,  9, 2, 75, 3, 81, 
    3, 46, 1, 44, 4, 94, 0, 53, 7, 79, 5, 40, 2, 30, 8, 81, 9, 60, 6, 34
  };
  const int r975[] = {
    10, 10, // Number of jobs and machines
    6, 31, 5, 61, 3, 12, 1, 32, 8, 44, 2, 25, 0, 40, 7, 56, 9, 56, 4, 91, 
    4, 87, 3, 26, 9,  7, 2, 73, 0, 76, 8,  6, 5, 27, 6, 57, 1, 15, 7, 79, 
    1, 78, 9, 84, 5, 87, 4, 13, 6, 28, 2, 78, 0, 18, 7, 76, 3, 98, 8, 71, 
    6, 92, 4, 42, 9, 13, 8, 49, 7, 85, 2, 58, 3, 15, 0, 40, 1, 63, 5, 80, 
    4, 95, 8, 59, 3, 77, 9, 97, 0, 52, 7, 65, 1, 88, 5, 71, 6, 48, 2,  9, 
    2,  3, 8, 56, 6, 29, 0, 24, 9, 41, 5, 23, 1, 16, 7, 50, 3, 44, 4, 94, 
    2, 86, 6, 76, 8,  9, 0, 85, 9, 48, 4, 36, 1, 56, 7, 11, 5, 31, 3, 70, 
    7, 65, 1, 68, 4, 48, 5, 20, 8, 15, 6, 13, 0, 46, 3, 27, 2, 29, 9, 89, 
    5, 28, 7, 38, 1, 61, 6, 94, 8,  5, 0, 94, 2, 33, 9,  1, 3, 78, 4, 91, 
    7, 25, 5, 89, 4, 44, 9, 95, 2, 69, 1, 68, 3, 83, 8, 53, 6, 70, 0, 14
  };
  const int r976[] = {
    10, 10, // Number of jobs and machines
    2, 21, 1, 73, 9, 16, 0, 58, 6, 40, 8, 79, 3, 76, 4, 35, 5, 42, 7, 52, 
    8, 47, 4, 57, 3,  1, 7, 60, 1,  9, 2, 68, 5, 99, 9, 90, 6, 83, 0, 14, 
    9, 70, 7, 84, 6, 90, 3, 32, 2, 72, 1, 26, 4, 57, 8, 97, 0, 23, 5, 28, 
    2, 66, 0, 41, 7, 83, 8, 46, 3, 78, 9, 14, 6,  4, 5, 18, 4,  2, 1, 77, 
    5, 32, 8, 23, 1, 35, 0, 94, 3, 20, 9, 92, 7, 54, 4, 63, 6, 36, 2, 74, 
    2, 48, 8,  9, 6, 29, 1, 83, 9, 93, 3, 66, 7, 63, 0, 47, 5, 88, 4, 40, 
    3, 82, 2, 17, 4, 97, 9, 24, 7, 96, 6, 39, 5,  4, 1,  4, 8, 46, 0,  5, 
    5, 11, 1, 44, 6, 19, 8, 51, 4, 16, 3, 98, 7, 89, 0, 54, 2, 34, 9,  1, 
    9, 92, 8, 39, 1, 55, 0, 26, 4, 69, 2, 68, 7, 52, 6, 22, 3, 92, 5, 41, 
    6, 45, 8, 45, 1, 27, 0, 74, 3, 70, 2, 36, 9, 69, 7, 74, 5, 75, 4, 95
  };
  const int r977[] = {
    10, 10, // Number of jobs and machines
    4, 10, 8, 71, 5, 93, 9, 54, 0, 73, 3, 64, 2, 40, 1, 90, 6, 59, 7, 74, 
    6, 83, 2, 23, 5, 90, 9, 47, 8, 85, 1, 18, 0, 58, 7, 97, 4, 23, 3, 68, 
    3, 55, 0, 16, 9,  1, 6, 80, 5, 63, 2, 36, 4, 39, 8, 53, 1, 35, 7, 53, 
    7, 53, 3, 72, 2,  5, 8, 93, 6, 20, 0, 63, 1, 29, 9, 77, 4, 65, 5, 25, 
    9, 77, 3, 27, 5, 90, 7, 95, 6, 51, 2, 91, 4, 79, 0, 71, 1, 16, 8, 73, 
    8, 71, 9, 57, 6, 27, 0, 85, 1, 42, 5, 28, 7, 25, 4, 24, 2, 28, 3, 32, 
    1, 32, 2,  4, 9, 80, 7, 39, 0, 48, 5, 92, 4, 95, 3, 34, 6, 46, 8, 23, 
    4, 20, 3, 17, 6, 59, 5, 54, 7, 32, 8, 44, 0, 44, 2, 51, 9,  3, 1, 52, 
    2, 19, 3, 42, 1, 89, 0,  7, 6, 53, 7, 87, 8, 72, 9, 48, 4, 29, 5, 92, 
    2,  6, 9,  1, 8, 61, 3, 99, 6, 34, 5, 88, 4,  2, 7, 61, 1, 63, 0, 97
  };
  const int r978[] = {
    10, 10, // Number of jobs and machines
    0, 73, 6, 84, 8, 71, 7, 22, 9, 37, 3, 71, 1, 91, 5, 59, 4, 38, 2, 50, 
    3, 85, 5, 89, 2, 30, 9, 39, 4, 85, 1, 59, 7, 49, 0, 58, 6, 56, 8, 13, 
    0, 23, 8, 28, 4, 35, 9, 87, 3,  1, 2, 60, 1, 46, 7, 41, 5, 22, 6, 80, 
    0,  3, 3, 87, 7, 33, 2, 45, 5,  6, 4, 57, 1, 64, 6, 56, 9, 72, 8,  6, 
    2, 26, 7, 18, 5, 46, 1, 39, 6, 55, 4, 84, 9, 18, 8,  8, 3,  1, 0,  6, 
    5, 81, 9,  5, 6, 94, 2, 87, 7, 23, 4, 71, 0, 81, 1, 76, 8, 75, 3,  9, 
    2, 65, 1, 45, 5,  8, 4, 78, 0, 84, 3,  9, 9, 27, 7, 46, 8, 14, 6, 10, 
    7, 17, 8,  5, 0, 99, 2, 64, 1, 42, 9,  7, 4, 68, 6, 25, 5, 86, 3, 78, 
    4, 87, 8, 19, 2, 21, 9, 15, 7, 44, 5, 56, 6, 65, 3, 79, 1, 40, 0, 24, 
    1, 34, 5, 70, 2,  1, 0, 62, 7, 52, 9, 43, 4, 48, 8, 20, 6, 74, 3, 60
  };
  const int r979[] = {
    10, 10, // Number of jobs and machines
    5, 14, 6, 94, 1,  4, 9, 73, 8,  2, 2, 92, 7, 40, 4, 91, 3, 17, 0, 69, 
    3, 60, 5, 74, 1, 48, 6, 24, 7, 73, 0, 50, 9, 43, 2, 11, 8, 32, 4, 27, 
    2, 42, 9, 23, 3, 66, 7, 21, 1, 88, 5, 88, 6, 12, 4, 54, 8, 28, 0, 40, 
    9, 77, 1, 58, 5, 24, 0, 36, 8, 16, 6, 91, 3, 84, 7, 23, 2, 74, 4, 78, 
    4, 30, 9, 39, 7, 62, 5, 50, 1,  5, 3, 15, 6, 15, 0, 88, 2, 95, 8, 46, 
    7, 39, 0, 46, 4, 76, 1, 57, 5, 63, 6, 39, 9, 62, 2, 31, 3, 54, 8, 88, 
    9, 98, 7, 18, 0,  7, 2, 65, 4, 64, 6, 40, 5, 22, 8, 40, 3,  1, 1, 16, 
    7, 27, 6, 90, 5, 18, 1, 58, 9, 14, 3, 76, 2,  2, 8, 51, 0, 81, 4,  3, 
    6, 91, 7, 48, 4, 14, 2, 59, 1, 57, 8, 63, 3, 17, 9, 34, 0, 99, 5, 50, 
    3, 87, 0, 25, 5, 64, 8, 98, 6, 98, 9, 68, 7, 53, 1, 50, 2, 29, 4, 78
  };
  const int r980[] = {
    10, 10, // Number of jobs and machines
    1, 75, 7, 78, 3, 18, 5, 83, 4, 44, 2,  7, 8, 82, 9, 41, 0, 41, 6, 15, 
    4, 95, 5, 72, 0, 66, 1, 60, 6, 21, 7, 42, 8, 36, 3, 79, 9, 99, 2, 40, 
    3, 93, 9, 71, 8, 12, 7, 57, 2, 34, 5, 50, 6, 76, 4, 85, 0, 68, 1, 51, 
    3, 14, 6, 11, 2, 33, 1, 30, 7, 58, 8, 20, 9, 38, 5, 18, 0, 47, 4, 49, 
    8, 16, 3, 80, 2, 39, 7, 14, 1, 88, 6, 87, 5, 32, 4, 83, 9, 23, 0, 56, 
    5, 40, 1, 64, 4,  2, 9, 54, 2, 47, 3, 56, 8,  4, 0, 60, 7, 88, 6, 30, 
    0, 15, 6, 57, 3, 92, 8, 22, 5, 51, 2, 43, 4, 82, 7, 95, 9,  1, 1, 68, 
    5, 51, 6, 11, 2, 66, 1, 27, 3, 63, 0, 78, 8, 74, 4, 71, 9, 49, 7, 97, 
    7, 95, 2, 61, 9, 40, 6, 51, 8, 66, 5, 42, 4, 59, 0, 33, 1, 41, 3, 91, 
    7, 22, 8, 44, 9, 77, 5, 15, 3,  8, 1, 33, 0, 21, 6, 80, 4, 56, 2, 58
  };
  const int r981[] = {
    10, 10, // Number of jobs and machines
    5,  8, 9, 91, 0, 78, 4, 44, 3, 24, 6, 84, 1, 31, 2, 88, 8,  7, 7, 88, 
    6, 39, 3, 49, 5, 32, 4, 36, 1, 48, 2, 93, 7, 16, 8, 51, 9, 61, 0, 94, 
    7, 31, 3,  7, 1,  7, 2, 55, 4, 83, 8, 78, 6, 86, 9, 28, 0, 32, 5, 85, 
    8, 37, 7, 91, 3, 14, 2, 18, 4, 11, 9, 17, 1,  8, 5, 35, 0, 98, 6, 52, 
    8, 87, 2, 44, 5, 46, 3, 16, 7, 73, 4, 51, 9, 47, 6, 47, 1, 70, 0, 32, 
    6,  8, 9,  7, 3, 63, 8, 89, 7, 18, 2, 63, 1, 64, 0, 89, 4, 25, 5, 28, 
    7, 88, 8, 42, 4, 36, 0, 40, 1, 67, 9, 81, 5,  3, 3, 49, 2,  2, 6, 73, 
    4, 32, 8, 69, 9, 31, 5, 81, 1, 16, 3, 78, 2, 27, 6, 25, 7, 52, 0, 67, 
    7, 99, 3, 62, 6, 32, 9, 98, 2, 90, 1, 98, 5, 82, 0, 54, 8, 99, 4, 24, 
    3, 13, 4, 54, 1, 10, 8, 88, 6, 19, 7, 62, 0, 16, 5, 10, 2, 13, 9, 44
  };
  const int r982[] = {
    10, 10, // Number of jobs and machines
    2, 75, 7, 99, 1, 49, 5, 30, 0, 37, 9, 61, 8, 27, 6,  4, 4,  2, 3, 67, 
    8, 48, 5, 72, 3, 34, 2, 16, 7, 15, 6, 82, 0, 35, 1, 97, 4, 54, 9, 21, 
    8, 71, 7, 40, 0, 25, 3, 57, 6, 67, 9, 93, 5, 25, 1,  6, 4, 78, 2, 38, 
    0, 88, 3,  9, 7, 37, 8, 79, 5, 77, 4, 74, 9, 76, 1, 34, 6, 37, 2, 83, 
    9, 96, 1, 43, 6, 59, 8, 72, 7, 96, 3, 96, 4, 17, 5, 96, 2, 13, 0, 76, 
    5, 58, 9, 79, 4, 21, 8, 83, 7, 26, 0, 65, 2, 17, 3, 34, 6,  9, 1, 51, 
    8, 52, 3, 98, 7, 25, 6, 98, 0, 23, 2, 44, 1, 75, 4, 43, 9, 72, 5, 34, 
    1, 32, 5, 67, 4, 37, 9, 49, 3, 41, 2, 53, 7, 70, 6, 35, 0, 33, 8, 89, 
    2, 61, 7, 86, 3, 41, 4, 74, 6, 13, 5,  7, 0, 31, 9,  5, 1, 54, 8, 97, 
    7, 65, 0, 51, 4, 73, 1, 78, 3, 41, 5, 96, 8, 32, 6, 33, 2, 26, 9, 75
  };
  const int r983[] = {
    10, 10, // Number of jobs and machines
    4, 53, 9, 58, 2,  4, 7, 86, 8, 47, 5,  6, 6, 65, 3, 85, 0, 38, 1, 62, 
    8, 22, 2, 30, 3, 99, 6, 13, 4, 42, 9, 32, 7, 20, 5, 45, 0, 76, 1, 83, 
    0, 50, 6, 74, 9, 13, 1, 78, 7,  4, 2, 23, 8, 87, 4,  4, 5, 29, 3, 52, 
    4, 32, 8,  6, 5, 58, 6, 43, 3,  8, 9, 72, 0, 64, 1, 63, 2, 46, 7, 29, 
    7, 47, 8, 28, 0, 27, 3, 67, 6, 41, 9,  6, 4, 91, 5, 70, 1, 98, 2, 47, 
    5, 51, 0, 14, 6, 77, 9, 55, 2, 13, 7, 96, 1, 99, 3, 28, 8, 53, 4, 60, 
    4, 87, 3, 78, 2, 73, 8, 79, 5, 49, 9,  5, 0, 77, 6, 76, 1, 40, 7, 42, 
    7, 31, 8, 26, 1, 66, 2, 20, 0,  6, 3, 75, 6, 54, 4, 59, 5, 77, 9, 68, 
    3, 16, 9, 74, 2, 20, 4, 59, 6,  8, 1, 62, 8, 25, 7, 95, 0, 46, 5, 20, 
    5,  1, 0, 67, 7, 65, 2, 87, 3, 17, 1, 15, 9, 79, 6, 94, 4, 36, 8, 98
  };
  const int r984[] = {
    10, 10, // Number of jobs and machines
    0,  8, 9, 14, 6,  1, 1, 38, 3,  1, 7, 47, 5, 56, 8, 36, 2, 79, 4, 66, 
    7, 74, 1, 18, 6, 93, 9, 10, 4, 98, 8, 71, 5, 75, 3, 55, 0, 15, 2, 23, 
    6, 39, 8, 65, 7, 57, 0, 82, 9, 77, 4, 87, 2, 87, 3,  9, 1, 46, 5,  9, 
    4, 71, 5, 17, 3, 95, 8, 25, 1, 60, 0, 13, 9, 29, 2, 22, 7, 10, 6, 25, 
    6, 38, 5, 81, 2, 76, 0, 37, 4, 63, 7, 53, 3, 89, 8, 53, 9, 55, 1, 18, 
    8, 83, 1, 82, 6, 22, 3, 37, 7, 14, 9, 23, 5, 78, 2, 26, 4, 13, 0, 81, 
    2, 64, 4, 89, 1, 91, 0, 22, 9, 22, 5,  9, 6, 93, 3,  4, 7, 59, 8, 40, 
    0, 79, 5, 62, 4, 20, 3, 58, 2, 73, 6, 32, 8, 42, 7, 57, 1, 51, 9, 10, 
    5, 10, 6, 90, 2, 39, 1, 43, 8, 68, 3, 65, 9, 46, 4, 20, 7, 25, 0, 32, 
    6,  1, 0, 69, 2, 89, 3, 29, 9, 90, 8, 24, 7, 62, 5, 88, 4, 73, 1, 29
  };
  const int r985[] = {
    10, 10, // Number of jobs and machines
    8, 37, 4, 15, 7, 99, 9,  2, 5,  3, 3, 15, 2, 33, 6, 94, 1, 58, 0, 58, 
    5, 36, 4, 10, 2, 35, 9, 29, 1, 25, 3, 89, 6, 57, 8, 34, 0, 36, 7, 30, 
    3,  1, 6, 47, 4, 42, 5, 17, 7, 82, 0, 10, 9, 21, 2, 76, 8, 94, 1, 47, 
    4, 73, 8, 56, 7, 27, 0, 59, 6, 93, 3, 86, 9, 86, 1, 72, 5, 12, 2, 11, 
    0,  2, 9, 17, 2, 19, 8, 63, 1, 70, 5, 44, 4, 47, 7, 99, 3, 98, 6, 46, 
    2, 80, 9,  3, 4, 74, 8, 97, 1, 98, 0, 33, 3, 38, 7, 56, 6, 46, 5, 93, 
    6, 24, 7, 28, 8, 82, 4, 15, 3, 36, 2, 69, 9, 33, 5, 43, 1, 81, 0, 32, 
    0, 65, 8, 82, 2, 90, 3, 85, 4, 87, 9, 67, 7,  2, 1, 42, 6,  1, 5,  9, 
    6, 20, 8, 63, 3,  5, 1, 99, 2, 75, 5, 74, 9, 27, 4, 45, 7, 16, 0, 64, 
    6, 72, 4, 53, 3, 15, 7, 49, 0, 57, 8, 77, 1, 36, 2, 81, 9, 76, 5, 19
  };
  const int r986[] = {
    10, 10, // Number of jobs and machines
    4, 98, 1,  6, 0, 43, 7, 10, 2, 73, 9, 92, 5, 20, 6,  7, 8, 62, 3,  8, 
    1, 74, 8, 36, 9,  7, 6, 99, 0, 60, 2, 70, 4, 80, 5, 15, 7, 66, 3, 66, 
    0, 17, 1, 53, 2, 36, 7, 20, 6, 16, 3, 32, 8, 35, 9, 18, 5, 13, 4, 98, 
    8, 98, 4, 91, 0, 43, 1, 41, 5, 41, 6, 75, 2,  3, 7, 83, 9, 95, 3, 58, 
    6, 91, 9, 88, 8, 83, 0, 29, 3, 16, 5, 45, 2, 49, 1, 25, 7, 46, 4,  8, 
    9, 52, 8, 45, 6, 79, 4, 48, 2, 80, 0,  5, 5, 55, 3, 53, 7, 62, 1, 60, 
    4, 28, 7, 76, 1, 37, 6, 46, 8, 86, 9, 69, 2, 66, 0, 91, 5, 18, 3, 94, 
    5, 62, 6, 44, 0, 81, 8, 68, 2, 30, 7,  6, 3, 66, 1, 10, 4, 57, 9, 75, 
    7, 95, 3, 82, 1, 57, 9, 70, 6, 28, 5, 94, 2, 50, 0, 77, 8, 60, 4, 66, 
    1, 48, 5, 59, 3, 21, 9, 77, 8, 88, 0, 15, 2, 29, 7, 30, 6, 68, 4, 39
  };
  const int r987[] = {
    10, 10, // Number of jobs and machines
    3, 74, 7, 33, 9, 74, 4, 93, 6, 10, 2, 95, 8, 41, 0, 64, 1, 85, 5, 67, 
    3, 13, 7, 81, 6, 45, 0, 51, 4, 94, 1,  9, 5, 57, 9, 25, 2, 61, 8,  1, 
    9, 26, 7, 24, 2, 42, 1, 18, 6, 35, 3, 25, 0, 37, 8, 87, 5, 48, 4, 88, 
    4, 55, 2, 60, 8, 63, 3,  3, 9, 67, 5, 32, 1,  6, 0, 64, 7, 89, 6,  2, 
    5, 64, 7, 79, 9,  7, 2, 13, 0, 80, 3, 89, 4, 34, 6, 30, 8, 50, 1, 45, 
    0, 89, 7, 78, 2, 15, 1, 85, 3, 73, 6, 66, 4, 63, 8, 65, 9, 57, 5, 13, 
    1, 92, 8, 57, 0, 75, 4, 84, 2,  3, 5, 61, 3, 84, 9, 97, 6, 67, 7, 84, 
    5,  6, 1,  3, 8, 51, 6, 72, 0, 68, 4,  2, 3, 66, 7, 38, 2, 34, 9, 80, 
    2, 75, 7, 87, 8, 17, 9, 56, 6, 12, 4, 97, 1, 11, 5, 67, 0, 18, 3, 29, 
    1, 81, 2, 76, 7, 63, 4, 94, 6, 12, 3, 87, 0, 29, 5, 91, 9, 27, 8, 88
  };
  const int r988[] = {
    10, 10, // Number of jobs and machines
    2, 81, 7, 30, 1, 81, 8, 46, 6, 28, 4, 84, 0, 58, 9, 66, 3, 69, 5, 81, 
    5, 15, 7, 68, 4, 97, 9,  6, 6, 76, 8, 58, 0, 90, 3, 97, 2, 65, 1, 50, 
    1, 21, 5, 73, 8, 49, 0, 94, 9,  4, 6, 28, 2, 89, 3, 50, 4, 25, 7, 40, 
    7, 80, 6, 80, 1, 16, 8, 58, 0, 72, 4, 42, 5, 53, 9, 50, 3, 75, 2, 75, 
    7, 18, 8, 82, 3,  5, 9, 37, 0, 83, 6, 60, 5, 79, 2, 50, 4, 21, 1, 20, 
    4, 94, 0, 56, 6,  5, 1, 13, 8, 35, 5, 17, 2, 93, 3, 27, 7, 53, 9, 21, 
    8, 78, 7, 74, 4, 89, 0, 84, 6, 82, 1, 69, 9, 71, 2, 71, 5, 33, 3, 93, 
    6, 22, 2, 10, 4, 67, 5,  7, 8, 33, 9, 47, 1,  1, 0, 55, 7, 76, 3, 14, 
    1, 41, 6, 68, 5, 27, 4, 96, 3, 94, 7, 11, 8, 58, 0, 25, 9, 16, 2, 89, 
    4, 86, 5, 43, 8, 87, 3, 79, 6, 84, 9, 83, 2, 82, 1, 85, 7, 14, 0, 75
  };
  const int r989[] = {
    10, 10, // Number of jobs and machines
    5, 11, 9, 67, 8, 62, 1, 15, 7, 72, 3, 26, 4, 33, 0, 35, 6,  1, 2, 89, 
    8, 41, 9,  2, 0, 22, 3, 47, 4, 57, 5,  7, 1, 43, 2, 58, 6, 50, 7, 28, 
    2, 54, 3, 84, 7, 47, 6, 13, 8, 29, 4, 66, 9, 55, 0,  5, 1, 13, 5,  5, 
    7, 65, 1, 84, 0, 61, 9, 56, 6, 57, 8, 79, 3, 67, 5, 68, 4, 53, 2, 43, 
    4, 21, 7, 85, 2, 83, 3, 29, 6,  1, 1, 27, 8, 98, 5, 46, 0, 20, 9, 70, 
    9, 44, 8, 31, 6, 41, 0, 13, 2, 90, 7, 31, 5, 12, 4, 96, 1, 57, 3, 91, 
    5, 80, 8, 69, 6, 99, 3, 39, 4, 94, 9, 68, 7, 82, 0, 90, 2, 16, 1, 27, 
    9, 60, 0, 35, 8, 80, 3,  4, 4, 50, 7, 38, 2, 71, 5, 44, 1,  5, 6, 86, 
    4, 37, 5, 80, 6, 36, 2, 29, 0, 59, 3, 39, 8, 43, 9, 87, 7, 63, 1, 66, 
    6, 96, 3, 39, 7, 34, 8, 83, 2, 28, 0, 65, 4, 76, 1, 56, 5, 86, 9, 85
  };
  const int r990[] = {
    10, 10, // Number of jobs and machines
    8, 97, 1, 37, 3,  3, 5, 72, 2, 30, 7,  1, 4, 46, 6, 63, 0, 77, 9, 55, 
    4, 73, 3, 78, 8, 90, 1, 51, 7, 71, 9,  5, 6, 80, 2, 51, 0,  2, 5, 65, 
    0, 27, 5, 87, 3, 97, 4, 16, 8, 53, 9, 36, 7, 98, 1, 92, 2, 86, 6, 95, 
    4, 56, 3, 68, 7,  5, 9, 15, 2, 25, 0, 55, 5, 34, 1, 34, 8,  5, 6, 21, 
    1, 67, 3, 18, 4, 52, 2, 40, 6, 43, 9,  1, 8, 85, 0, 79, 7, 33, 5, 58, 
    4, 70, 6, 61, 5, 48, 0, 32, 8,  5, 2, 37, 7, 86, 9, 34, 1, 83, 3, 35, 
    9, 22, 7, 32, 8, 34, 5, 37, 0, 83, 4, 76, 2, 57, 3, 67, 1, 42, 6, 85, 
    9, 56, 7, 78, 6, 30, 1, 39, 2, 46, 8,  1, 3, 95, 5, 20, 4, 94, 0, 65, 
    6, 65, 4, 57, 5, 63, 8, 55, 1, 52, 3, 36, 9, 58, 7, 31, 2, 54, 0, 91, 
    8, 44, 0, 13, 3,  6, 7, 15, 9, 95, 6, 80, 5, 77, 4, 74, 1, 52, 2, 65
  };
  const int r991[] = {
    10, 10, // Number of jobs and machines
    9, 13, 7, 86, 2, 23, 5, 88, 3, 12, 0, 97, 6, 84, 1, 52, 4, 37, 8, 71, 
    6, 26, 4, 87, 8, 64, 7,  9, 1, 98, 2, 97, 5,  9, 9, 42, 3, 12, 0, 71, 
    5,  5, 2, 14, 3, 31, 0, 97, 4, 37, 1, 29, 8, 59, 7, 76, 9, 88, 6, 66, 
    4, 51, 0, 96, 7, 86, 1, 91, 6, 56, 5, 66, 8, 68, 2, 45, 9, 12, 3, 90, 
    0, 36, 8, 60, 7,  8, 4, 19, 6, 73, 9, 69, 3, 41, 1, 46, 5, 20, 2, 18, 
    9, 79, 0, 34, 3, 72, 1, 61, 7, 39, 4, 65, 5,  4, 2, 69, 8, 72, 6, 85, 
    8, 58, 9, 63, 4, 53, 6, 43, 0, 14, 2, 46, 1, 78, 7, 70, 3, 98, 5, 52, 
    9, 81, 1, 77, 7, 31, 2, 12, 4, 66, 0, 64, 3, 62, 6, 35, 5, 85, 8, 29, 
    7, 55, 6, 11, 5, 98, 8, 74, 4,  2, 1, 74, 3, 46, 2, 71, 9, 80, 0, 69, 
    8, 44, 7, 56, 9,  5, 0, 12, 2, 61, 1, 66, 6, 69, 4, 71, 5, 13, 3, 99
  };
  const int r992[] = {
    10, 10, // Number of jobs and machines
    8,  3, 0,  7, 9, 26, 2, 64, 6, 75, 7, 93, 4,  3, 3, 69, 5, 74, 1, 70, 
    8, 49, 0, 56, 4, 45, 3, 73, 5, 44, 2, 50, 7, 79, 6, 61, 9, 79, 1, 52, 
    9,  2, 8, 93, 2, 20, 7, 96, 6, 53, 3, 82, 4, 57, 0, 31, 5, 56, 1,  5, 
    6, 42, 2, 43, 1,  9, 8, 37, 0, 30, 5, 57, 9, 18, 4, 48, 7,  2, 3, 53, 
    4, 67, 6, 26, 0,  3, 7,  9, 3, 84, 5, 11, 9, 55, 8,  2, 2, 92, 1, 29, 
    2, 66, 4, 87, 6, 16, 0, 13, 3, 50, 7,  7, 1, 84, 8, 73, 9, 47, 5, 56, 
    2, 88, 5, 83, 8, 93, 1, 21, 7, 58, 0, 79, 3, 55, 6, 71, 9, 18, 4,  2, 
    0, 82, 4, 54, 2, 46, 3, 42, 9, 85, 5, 81, 1, 84, 8, 58, 7, 11, 6, 95, 
    4, 93, 6,  9, 1,  3, 9, 84, 7, 35, 3, 10, 8, 64, 0, 72, 2, 22, 5, 71, 
    5, 44, 4, 45, 6, 18, 8, 65, 2, 30, 9,  7, 3, 30, 0, 92, 1, 54, 7, 91
  };
  const int r993[] = {
    10, 10, // Number of jobs and machines
    0, 38, 3, 45, 2, 17, 6, 55, 9, 53, 1, 64, 8, 95, 5,  4, 4, 47, 7, 49, 
    5, 13, 9, 46, 8, 67, 4,  4, 7, 11, 0, 97, 6, 15, 3, 16, 2, 61, 1, 69, 
    7, 71, 2, 95, 6, 29, 1, 43, 9, 69, 4, 77, 8, 28, 0, 78, 5,  2, 3, 99, 
    3, 83, 4, 94, 6, 78, 0, 35, 5, 45, 7, 18, 8, 60, 2, 24, 1, 76, 9, 58, 
    0, 35, 2, 35, 1, 47, 9, 55, 5, 58, 4, 48, 7, 50, 3,  1, 6, 98, 8, 38, 
    2, 62, 7, 11, 1, 33, 8, 82, 4,  4, 5, 49, 6,  2, 9, 30, 0, 73, 3, 78, 
    4, 36, 6, 56, 3,  1, 5, 17, 8, 65, 7, 21, 0, 80, 2, 27, 1, 15, 9, 85, 
    4, 13, 9,  7, 6, 37, 8, 87, 1, 67, 2, 92, 0, 61, 5, 42, 7, 13, 3,  7, 
    6, 95, 9, 82, 8, 62, 4, 62, 3, 18, 1, 86, 7, 73, 5, 91, 2, 61, 0, 49, 
    0, 70, 8, 97, 5, 17, 7, 35, 1, 94, 4, 78, 2,  9, 3, 63, 9, 63, 6, 29
  };
  const int r994[] = {
    10, 10, // Number of jobs and machines
    2, 78, 0, 95, 9,  9, 1, 36, 6, 31, 4, 61, 8, 32, 3, 80, 7, 78, 5, 22, 
    6, 25, 8, 58, 2, 93, 9, 55, 0, 48, 7, 98, 3, 48, 1, 85, 5, 29, 4, 80, 
    9, 44, 3, 94, 2, 52, 4, 91, 7, 79, 0, 61, 8, 52, 5, 21, 6, 49, 1, 31, 
    9, 66, 7, 75, 3, 89, 6, 74, 4, 83, 5, 11, 2, 44, 8, 59, 0, 21, 1, 73, 
    8, 75, 9, 74, 7, 19, 0, 20, 3, 18, 4, 16, 2, 53, 5, 31, 6, 20, 1, 93, 
    6, 12, 2, 95, 0, 30, 3, 88, 1, 94, 7, 94, 8, 85, 4, 78, 9, 36, 5,  5, 
    0, 50, 7, 93, 9, 56, 5,  1, 2, 55, 3,  7, 8, 75, 4, 15, 6, 37, 1, 94, 
    2,  4, 3, 35, 5, 55, 1, 40, 0, 82, 7, 34, 9, 46, 4, 21, 6, 81, 8, 46, 
    4, 86, 6, 21, 5, 15, 3, 74, 2, 31, 7, 26, 0, 74, 9, 60, 1, 11, 8, 62, 
    2, 86, 8, 34, 0, 17, 7, 86, 1, 17, 3, 23, 5, 60, 4, 24, 9, 30, 6, 69
  };
  const int r995[] = {
    10, 10, // Number of jobs and machines
    1, 65, 2, 42, 5, 18, 7, 88, 9, 69, 6, 34, 3, 49, 4, 19, 8, 52, 0, 96, 
    5, 22, 9, 35, 4, 28, 8, 23, 1, 92, 7, 40, 6, 90, 0,  1, 2, 12, 3, 52, 
    5, 57, 2, 54, 0, 25, 9, 51, 7, 45, 8, 56, 1, 98, 4, 59, 6, 24, 3, 25, 
    0,  7, 9, 84, 7, 13, 8,  5, 5, 16, 6, 11, 3,  2, 4, 94, 1, 44, 2, 66, 
    6, 13, 3, 93, 8,  1, 2, 11, 7, 21, 9, 15, 4, 78, 0, 84, 5, 44, 1, 35, 
    7, 68, 3, 32, 2, 61, 8, 39, 4, 89, 1, 78, 6, 59, 9, 29, 0, 19, 5, 16, 
    5, 12, 0, 90, 9, 52, 6, 55, 4, 79, 3, 84, 7, 12, 2, 46, 1, 71, 8, 41, 
    8, 59, 9, 80, 6, 50, 4, 67, 1, 56, 0, 79, 2,  7, 3, 36, 7, 69, 5, 59, 
    9, 10, 8, 97, 1, 15, 6, 48, 5, 71, 4, 65, 2, 61, 7, 99, 3, 95, 0, 13, 
    9, 27, 0, 94, 6, 25, 8,  8, 4, 87, 7, 13, 5, 85, 3, 70, 2, 82, 1, 38
  };
  const int r996[] = {
    10, 10, // Number of jobs and machines
    2, 19, 1, 37, 0, 72, 4, 34, 9, 14, 6,  5, 7, 72, 3, 42, 8, 44, 5, 25, 
    1, 32, 8, 40, 5, 64, 7, 82, 4, 95, 3, 88, 0, 28, 9, 48, 6, 63, 2, 16, 
    8, 78, 6, 56, 5, 85, 0, 99, 4, 68, 2, 46, 1, 71, 3, 13, 7, 25, 9, 62, 
    5, 15, 4, 57, 1, 61, 7, 82, 3, 25, 8, 79, 6, 23, 2, 36, 0, 99, 9, 59, 
    4, 51, 7, 19, 8, 94, 1, 28, 9, 77, 2, 44, 3,  8, 0, 24, 6, 21, 5,  4, 
    9,  2, 1, 93, 5, 50, 8, 13, 4, 61, 0, 95, 3, 84, 2, 97, 6, 60, 7, 51, 
    8, 71, 7, 13, 4,  7, 3, 62, 5, 69, 1, 65, 6, 97, 0, 96, 2, 82, 9, 98, 
    3, 29, 5, 44, 6, 30, 7, 69, 0, 30, 9, 34, 4, 87, 2, 12, 8, 90, 1, 56, 
    4, 98, 0, 75, 5, 38, 9, 96, 8, 50, 1,  9, 6, 48, 2, 20, 7, 69, 3, 59, 
    6,  2, 2, 94, 7, 31, 5, 30, 9, 60, 3, 22, 1, 61, 0, 58, 8, 50, 4, 46
  };
  const int r997[] = {
    10, 10, // Number of jobs and machines
    1, 46, 6, 80, 3,  4, 2, 16, 7, 80, 5, 57, 9, 76, 0, 28, 8, 69, 4, 19, 
    1, 49, 8, 61, 6, 25, 3, 24, 5, 90, 4, 85, 9, 87, 0, 48, 2, 95, 7, 23, 
    3, 36, 4, 10, 8, 98, 6, 35, 9, 62, 0, 57, 2, 82, 7, 87, 5, 41, 1, 70, 
    0, 98, 6,  8, 5, 85, 2, 63, 1, 91, 4, 92, 8, 52, 3, 47, 7, 61, 9, 93, 
    4, 60, 6, 65, 9, 37, 3, 74, 2, 34, 8, 44, 1, 69, 0, 25, 7, 60, 5, 41, 
    3, 23, 9, 90, 0, 42, 6, 77, 2,  2, 4,  1, 5,  2, 7, 90, 1, 73, 8, 78, 
    0, 17, 6,  2, 9, 16, 7,  8, 3, 52, 2, 89, 4, 73, 8, 82, 5, 93, 1, 85, 
    5, 32, 2, 68, 3, 46, 8, 74, 9, 64, 0, 53, 6, 69, 1, 48, 4, 35, 7, 30, 
    9, 17, 4, 29, 2, 59, 7, 11, 6,  6, 3, 86, 8,  7, 1, 43, 5, 59, 0, 36, 
    7, 63, 4, 14, 2, 47, 5, 26, 6, 52, 9, 59, 0, 95, 1, 54, 8, 71, 3, 25
  };
  const int r998[] = {
    10, 10, // Number of jobs and machines
    2, 70, 5, 49, 3, 29, 1, 91, 7, 96, 0, 45, 9, 10, 4, 25, 6, 20, 8, 80, 
    5, 57, 1, 16, 6, 31, 8, 41, 7, 13, 2, 60, 3, 61, 9, 82, 0, 10, 4,  4, 
    7, 39, 3, 66, 4, 77, 8, 33, 5, 39, 0, 23, 6, 74, 9, 93, 1, 51, 2, 22, 
    0, 92, 6, 38, 9, 25, 3, 47, 1,  2, 7, 17, 4, 85, 5, 69, 2, 74, 8,  8, 
    0, 88, 5, 21, 1,  1, 3, 94, 7, 56, 4, 67, 6, 91, 8, 55, 2, 96, 9, 38, 
    2,  6, 9, 29, 1, 10, 5, 12, 8, 53, 3, 54, 4, 40, 6, 22, 7, 68, 0, 19, 
    2, 24, 5, 74, 3, 90, 9, 59, 0, 79, 6, 17, 4, 81, 8, 52, 1, 36, 7, 85, 
    9, 22, 2, 60, 1, 98, 3, 82, 4,  4, 0, 71, 5, 30, 7, 76, 6, 68, 8, 53, 
    5, 57, 3, 59, 8, 32, 7,  3, 1, 76, 4, 16, 0, 77, 9, 22, 6, 52, 2, 98, 
    3, 78, 6, 13, 0, 33, 1, 39, 2, 49, 4, 57, 8, 68, 5, 61, 7, 70, 9, 24
  };
  const int r999[] = {
    10, 10, // Number of jobs and machines
    2, 55, 0, 50, 5, 46, 1, 60, 7, 83, 6, 63, 9,  5, 8, 58, 3, 98, 4, 12, 
    5, 54, 1, 51, 8, 19, 4, 81, 2, 41, 0, 22, 3, 66, 6, 85, 7,  5, 9, 47, 
    9, 41, 4, 33, 3, 92, 0, 74, 8, 25, 7, 67, 6, 29, 5, 53, 1, 72, 2, 23, 
    2, 76, 1, 66, 3, 61, 8, 81, 5, 75, 0, 68, 4, 38, 6, 46, 7, 90, 9, 65, 
    0, 74, 2, 17, 3, 75, 9, 73, 5,  8, 8, 62, 7, 79, 6, 79, 1, 72, 4,  2, 
    6, 82, 3, 26, 1, 59, 4, 76, 8, 23, 7, 92, 5,  3, 0, 42, 9,  6, 2, 85, 
    4, 70, 2, 97, 6, 26, 7,  3, 0, 90, 8, 13, 1, 32, 9, 60, 5, 74, 3, 40, 
    9, 56, 4, 97, 7, 58, 3, 48, 0, 14, 1, 81, 5, 57, 2, 20, 8,  4, 6, 43, 
    3, 39, 1, 23, 2, 24, 9, 49, 7, 85, 5, 36, 8, 73, 6, 76, 0, 27, 4, 30, 
    0, 65, 2, 20, 7, 89, 8, 48, 3, 78, 1,  3, 5, 10, 6, 38, 4, 75, 9, 22
  };

  /*
   * Generated random instances
   *
   * The machine permutations have been chosen uniformly from all
   * possible permutations and the durations are also uniformly
   * randomly distributed in a range from 1 to 100.
   *
   */
  const int q0000[] = {
    9, 9, // Number of jobs and machines
    4, 25, 2, 94, 0, 83, 5, 10, 7, 62, 6, 76, 3, 65, 8, 51, 1, 90, 
    3, 22, 1, 39, 7, 62, 6, 25, 4, 25, 5, 33, 2, 20, 0, 55, 8, 38, 
    6,  6, 0, 13, 3, 15, 4, 99, 8, 45, 1, 82, 2, 69, 7, 32, 5, 64, 
    8, 40, 7, 62, 5, 97, 2, 68, 3, 94, 6, 76, 1, 97, 0, 13, 4, 16, 
    0, 13, 3, 76, 4, 55, 2, 93, 6, 25, 7, 71, 1, 95, 5, 61, 8, 19, 
    5, 72, 1, 26, 8, 27, 0, 83, 7, 45, 3, 53, 2, 23, 4, 14, 6, 94, 
    4, 85, 5, 49, 7, 58, 0, 33, 8, 46, 6,  2, 1, 99, 2, 57, 3, 50, 
    5, 78, 7, 86, 3, 10, 0, 62, 4, 56, 1, 89, 2, 89, 8, 22, 6, 12, 
    8, 26, 7, 13, 5, 96, 4, 85, 3, 71, 0, 30, 6, 77, 1, 75, 2, 79
  };
  const int q0001[] = {
    9, 9, // Number of jobs and machines
    1, 24, 4, 79, 0, 58, 5,  4, 7, 76, 6, 85, 3, 81, 2, 14, 8, 35, 
    7, 97, 6, 94, 4, 31, 5,  6, 1, 35, 2, 80, 8, 52, 0, 75, 3,  3, 
    8, 29, 2, 59, 3, 34, 5, 97, 0, 80, 4, 44, 6, 74, 1, 72, 7, 50, 
    3, 18, 4, 36, 2, 75, 7, 72, 8, 23, 0, 64, 6, 80, 5, 18, 1, 62, 
    8, 60, 0, 91, 1, 42, 7, 94, 2, 89, 4, 50, 6, 13, 3, 29, 5,  3, 
    8, 23, 6, 90, 5, 38, 3, 90, 4, 51, 0, 88, 7, 35, 1, 31, 2, 81, 
    4, 77, 7, 69, 0, 41, 5, 58, 1, 79, 6, 25, 3, 96, 2, 14, 8, 71, 
    3, 23, 4, 84, 5, 16, 8,  3, 6, 44, 1, 23, 2, 46, 0, 36, 7, 88, 
    3, 39, 0, 11, 2, 29, 4, 51, 8, 47, 1, 47, 5, 67, 7, 87, 6, 81
  };
  const int q0002[] = {
    9, 9, // Number of jobs and machines
    2, 76, 0,  1, 3, 88, 8, 31, 4, 95, 5, 33, 6, 68, 7, 32, 1, 85, 
    2, 82, 7, 28, 1, 22, 4, 26, 0, 56, 5,  1, 8, 16, 6, 47, 3, 29, 
    4, 39, 6, 74, 0,  9, 2, 68, 3, 75, 1, 60, 8, 44, 7, 91, 5,  1, 
    8, 36, 4, 70, 7, 91, 3, 25, 6, 66, 2, 40, 5, 52, 0, 47, 1, 47, 
    8, 48, 5, 38, 6, 66, 2, 44, 3, 29, 7, 29, 4, 99, 1, 43, 0, 39, 
    3,  3, 6, 85, 1,  4, 4, 62, 0, 32, 2, 94, 8, 30, 5,  9, 7, 12, 
    4, 79, 5, 47, 8, 73, 1, 58, 0, 61, 6, 28, 3, 91, 2,  8, 7, 98, 
    3, 84, 2, 85, 7, 35, 4, 67, 8,  6, 6, 87, 1,  3, 5, 78, 0, 27, 
    3, 91, 5, 29, 6, 55, 7, 41, 2, 48, 1, 43, 0,  6, 4, 10, 8,  2
  };
  const int q0003[] = {
    9, 9, // Number of jobs and machines
    7, 39, 5, 81, 2, 88, 8, 90, 0, 68, 4,  8, 1, 68, 3,  4, 6, 83, 
    1, 34, 2, 49, 0, 52, 6, 43, 3, 51, 5,  8, 4, 21, 8, 22, 7, 95, 
    0,  8, 4, 75, 5,  8, 1, 63, 8, 66, 6, 35, 7,  8, 3, 53, 2, 72, 
    8, 80, 0, 92, 2, 69, 5, 38, 6, 62, 1, 87, 7,  9, 3, 82, 4, 15, 
    5, 91, 6,  3, 8, 52, 7, 98, 3, 44, 1, 32, 2, 35, 0, 45, 4, 74, 
    1, 79, 6, 29, 5, 24, 7, 62, 3, 62, 4, 58, 0, 33, 8, 64, 2, 21, 
    7, 22, 3,  7, 4, 56, 2, 86, 1, 20, 6, 57, 0, 20, 5, 41, 8, 30, 
    6, 36, 5, 63, 0, 84, 1, 47, 8, 87, 2, 13, 4, 52, 3, 59, 7, 46, 
    2, 38, 4, 70, 6, 95, 8, 26, 1, 72, 3, 95, 0,  9, 5, 34, 7, 15
  };
  const int q0004[] = {
    9, 9, // Number of jobs and machines
    5, 96, 7, 44, 0, 20, 3, 14, 6,  7, 1, 79, 4, 55, 8, 29, 2, 26, 
    7, 81, 2, 50, 3,  8, 8, 64, 6, 82, 1, 93, 5, 50, 4, 52, 0, 18, 
    6, 19, 1, 84, 8, 41, 0, 19, 5, 58, 4,  2, 3, 28, 7, 99, 2, 82, 
    4, 30, 2, 23, 8, 97, 3, 66, 7, 13, 5, 52, 1, 33, 6, 68, 0, 16, 
    2, 64, 7, 50, 3, 22, 8, 92, 1, 39, 4, 14, 5, 32, 6, 22, 0, 88, 
    3, 27, 0, 34, 7, 48, 4, 10, 6, 74, 1,  9, 5, 15, 8, 91, 2, 69, 
    3, 33, 4, 20, 8, 74, 5,  1, 2, 74, 1, 42, 6, 20, 7, 28, 0,  6, 
    5, 67, 7, 86, 1, 37, 8, 32, 6, 15, 2, 17, 0, 20, 3, 75, 4, 24, 
    2,  6, 6, 42, 7, 78, 8, 99, 5, 60, 1, 62, 3, 47, 0, 87, 4,  4
  };
  const int q0005[] = {
    9, 9, // Number of jobs and machines
    7, 56, 4, 85, 3, 23, 2, 58, 5, 70, 1, 41, 8, 16, 0, 67, 6,  1, 
    6, 23, 7, 24, 2, 50, 8, 99, 4, 86, 1, 38, 0, 32, 5, 60, 3, 46, 
    8, 51, 3, 27, 7,  1, 5, 99, 0, 77, 6, 43, 1, 67, 2, 24, 4, 88, 
    7, 64, 2, 54, 1, 80, 4, 49, 5, 17, 0, 56, 3, 50, 6, 70, 8,  1, 
    4, 50, 5, 72, 7, 32, 3, 22, 2, 59, 1, 47, 8, 13, 6, 44, 0, 37, 
    3, 77, 0, 92, 4, 43, 6,  7, 8, 98, 2, 72, 1, 89, 7, 92, 5, 96, 
    5, 86, 6, 30, 3, 22, 7,  8, 2,  4, 4, 55, 0, 58, 1, 75, 8, 40, 
    5, 18, 4, 77, 0, 92, 8, 20, 7, 49, 6, 97, 2, 62, 3, 84, 1, 14, 
    2, 28, 6, 71, 5, 61, 0, 64, 4, 85, 8, 91, 3, 38, 7, 11, 1, 37
  };
  const int q0006[] = {
    9, 9, // Number of jobs and machines
    4, 89, 2, 31, 6, 99, 0, 60, 8, 97, 3, 36, 7, 17, 5, 81, 1, 58, 
    0, 79, 2, 13, 3, 85, 5, 21, 6, 61, 1, 96, 4, 90, 7, 89, 8, 82, 
    0, 64, 8, 90, 6, 44, 4, 22, 1, 23, 5, 64, 2, 93, 3, 95, 7, 85, 
    7, 11, 4, 90, 2, 86, 1, 18, 5, 33, 3, 86, 8, 59, 6, 37, 0,  6, 
    8, 14, 7, 30, 2, 16, 6, 52, 0, 66, 4, 78, 1, 25, 5, 11, 3, 79, 
    3, 65, 8, 22, 0, 54, 1, 92, 6, 97, 5, 21, 7, 40, 2, 53, 4, 25, 
    4, 74, 5, 54, 2, 42, 0, 41, 6, 40, 8,  5, 7,  9, 3, 61, 1, 47, 
    4, 81, 5, 27, 7, 39, 8,  3, 3, 79, 6, 20, 2, 33, 1, 34, 0,  3, 
    3, 47, 1, 99, 8,  4, 6, 32, 0, 14, 5, 11, 7, 49, 4, 86, 2, 79
  };
  const int q0007[] = {
    9, 9, // Number of jobs and machines
    2, 25, 6, 38, 1, 81, 4, 27, 5, 33, 7,  9, 0, 22, 8, 51, 3, 65, 
    1, 70, 0, 94, 5, 94, 7, 94, 2, 81, 6, 88, 8, 97, 4, 43, 3, 87, 
    7, 74, 4, 66, 0, 79, 8,  5, 3, 94, 6, 36, 2, 92, 5, 39, 1, 99, 
    7, 44, 1,  9, 3, 31, 5, 28, 2, 87, 0, 82, 6, 20, 4, 42, 8, 21, 
    0, 59, 1, 96, 2, 49, 7, 56, 5, 34, 6, 85, 4, 75, 3, 13, 8,  4, 
    8, 34, 5,  5, 3, 59, 6, 12, 0, 51, 4, 10, 7, 24, 2, 47, 1, 25, 
    7, 14, 2, 75, 8, 10, 4, 74, 0, 28, 5, 86, 1, 80, 3, 49, 6, 24, 
    0, 58, 6, 14, 1, 88, 4, 59, 2,  8, 8, 69, 7, 46, 3, 88, 5, 52, 
    3, 11, 8, 39, 2, 22, 5, 23, 4, 10, 1, 62, 6, 12, 7, 80, 0, 51
  };
  const int q0008[] = {
    9, 9, // Number of jobs and machines
    2, 30, 1,  7, 5,  5, 6, 30, 3, 17, 7, 24, 0, 14, 4, 93, 8, 48, 
    2, 84, 0, 23, 4, 72, 3, 82, 8, 88, 6,  8, 5, 86, 1, 63, 7, 82, 
    2, 19, 0, 19, 7, 34, 4,  2, 6, 46, 5, 42, 3, 64, 1, 46, 8, 63, 
    2,  2, 0, 73, 4, 94, 7, 29, 5, 42, 3, 48, 8, 36, 1, 10, 6, 76, 
    6, 95, 2, 93, 8, 11, 5,  3, 1, 54, 4, 22, 7, 73, 0, 70, 3, 66, 
    8, 30, 3, 55, 7, 55, 1, 39, 0, 14, 4, 84, 6,  6, 5, 53, 2, 94, 
    1, 95, 8,  4, 6, 42, 2, 33, 0, 34, 4, 32, 5, 12, 3,  8, 7, 73, 
    2, 90, 3,  8, 6, 25, 7, 69, 4, 29, 8, 91, 0, 12, 5, 82, 1, 59, 
    8, 66, 7, 41, 1, 24, 2, 82, 6, 98, 0, 32, 5, 82, 3, 56, 4, 92
  };
  const int q0009[] = {
    9, 9, // Number of jobs and machines
    8, 16, 6, 38, 1, 33, 4,  6, 5, 66, 3, 90, 7, 52, 2, 92, 0, 35, 
    3, 30, 5, 33, 7, 60, 0, 47, 4, 29, 8, 95, 2, 96, 6, 37, 1, 49, 
    5, 83, 3, 43, 7,  3, 1,  1, 8, 89, 6, 58, 2, 20, 4, 71, 0, 46, 
    5, 51, 6, 40, 3, 63, 0, 79, 4, 23, 7, 18, 1, 43, 8, 74, 2, 52, 
    3, 18, 7, 76, 5, 21, 1, 46, 4, 46, 6, 24, 0, 13, 2, 10, 8, 65, 
    6, 27, 3,  5, 7, 70, 1, 53, 2, 68, 0, 28, 8,  3, 5, 54, 4, 26, 
    5, 95, 7,  6, 1, 61, 4, 90, 8, 72, 2, 23, 6, 55, 0, 75, 3, 20, 
    3, 92, 0, 26, 5, 63, 6, 46, 4, 42, 7, 95, 8, 63, 1,  5, 2, 21, 
    1, 13, 8, 50, 3, 69, 7, 36, 2, 61, 0, 68, 5, 48, 4, 77, 6, 54
  };
  const int q0010[] = {
    9, 9, // Number of jobs and machines
    8,  9, 5, 14, 2, 79, 1, 42, 6, 80, 4, 37, 7, 90, 0, 35, 3, 23, 
    5,  8, 2, 30, 8, 69, 0, 65, 7, 29, 3,  2, 4, 74, 6, 96, 1, 18, 
    7, 54, 8, 47, 2, 56, 0,  9, 3, 35, 1, 75, 5, 42, 4,  8, 6, 83, 
    8, 39, 1,  8, 3, 72, 6, 94, 2, 51, 7, 90, 0, 60, 5, 15, 4, 58, 
    3, 28, 6, 60, 7, 87, 0, 72, 5, 42, 1,  9, 2, 35, 8, 50, 4, 30, 
    2, 26, 6, 60, 1, 19, 4, 67, 8, 85, 0, 47, 3, 98, 7, 21, 5,  4, 
    0, 12, 3,  8, 7, 99, 8, 19, 5, 63, 1, 10, 4, 41, 6, 66, 2, 12, 
    6,  9, 2, 71, 4, 18, 8,  5, 0, 30, 1, 63, 5,  5, 3, 83, 7, 15, 
    1, 25, 8, 41, 4, 71, 5, 57, 0, 44, 7, 47, 6, 39, 2, 58, 3, 50
  };
  const int q0011[] = {
    9, 9, // Number of jobs and machines
    0, 60, 6, 23, 8, 30, 4, 41, 7, 60, 2, 92, 1,  4, 5, 18, 3, 47, 
    6, 91, 5, 58, 2, 80, 3, 67, 8, 59, 7, 91, 1, 91, 0, 91, 4, 14, 
    4, 15, 3, 44, 2,  6, 8, 51, 0, 47, 7, 36, 5, 96, 1, 11, 6, 29, 
    1, 42, 4,  5, 2, 55, 5, 78, 6, 22, 0, 63, 8, 46, 7, 44, 3, 77, 
    4, 80, 6, 85, 3, 83, 1, 45, 2, 86, 7, 62, 5, 81, 0, 23, 8, 81, 
    1, 95, 0, 10, 6, 79, 7,  7, 3, 83, 8, 89, 4, 65, 5,  9, 2, 67, 
    3, 88, 5, 83, 4, 77, 7, 99, 8, 11, 0, 90, 1, 76, 2, 35, 6, 20, 
    2, 44, 3, 46, 6, 31, 7, 64, 4, 82, 8, 37, 0, 34, 1, 78, 5,  5, 
    0, 28, 2, 76, 3, 26, 8,  4, 5, 19, 7, 42, 6, 71, 4,  9, 1, 79
  };
  const int q0012[] = {
    9, 9, // Number of jobs and machines
    5, 57, 8, 98, 1, 10, 6, 88, 3, 32, 2, 28, 0, 39, 4, 75, 7, 16, 
    7, 31, 4, 29, 6, 80, 3,  8, 1, 51, 8,  1, 0,  6, 5,  3, 2, 33, 
    4,  7, 6, 19, 2, 25, 5,  5, 7, 63, 1, 12, 3,  7, 0, 23, 8, 69, 
    8, 79, 5, 58, 3,  7, 0, 85, 4, 27, 7, 14, 2,  4, 6,  3, 1, 22, 
    4, 81, 2, 89, 8, 67, 5, 25, 7,  9, 1, 49, 3, 68, 6,  2, 0, 82, 
    6, 97, 7, 24, 8, 16, 2, 40, 5, 62, 3, 48, 4, 62, 0, 23, 1,  7, 
    0, 38, 2, 75, 6, 16, 5, 35, 4, 78, 1, 26, 7, 32, 8,  3, 3, 60, 
    5,  9, 7, 96, 6, 14, 0, 24, 4, 82, 1, 21, 2, 29, 8, 46, 3, 40, 
    6, 99, 3, 30, 0,  6, 2, 90, 1, 27, 8, 45, 4, 90, 7, 45, 5, 63
  };
  const int q0013[] = {
    9, 9, // Number of jobs and machines
    6, 87, 5, 41, 3, 53, 4, 14, 2, 12, 0, 21, 1, 93, 7, 61, 8, 92, 
    5, 29, 6, 97, 2, 77, 1, 65, 7, 63, 3, 44, 8, 14, 0, 67, 4,  3, 
    7, 29, 0, 66, 4, 56, 1, 80, 2, 84, 8, 81, 5, 76, 3, 48, 6, 92, 
    7, 89, 5, 92, 8,  4, 0, 58, 2, 34, 3, 63, 1, 42, 4, 10, 6, 73, 
    4, 53, 0,  4, 5, 83, 6, 40, 8, 95, 3, 46, 2, 22, 1, 45, 7, 36, 
    2, 32, 5, 69, 6, 88, 1, 57, 3, 13, 4, 10, 8, 52, 7, 77, 0, 47, 
    0, 49, 5, 32, 4, 77, 2, 39, 1, 97, 3, 90, 6, 88, 8, 71, 7, 74, 
    5, 70, 3, 38, 1,  5, 2, 12, 6, 47, 4, 94, 8, 67, 0, 60, 7, 17, 
    6, 23, 3, 14, 5, 98, 7, 79, 8, 19, 0, 31, 1, 64, 2, 78, 4, 22
  };
  const int q0014[] = {
    9, 9, // Number of jobs and machines
    3, 64, 4, 74, 8,  8, 1, 38, 0, 20, 6, 35, 7, 12, 5, 21, 2, 96, 
    5, 20, 6, 91, 8, 81, 0, 54, 7, 49, 3, 33, 4, 16, 2, 88, 1, 79, 
    4, 51, 1, 76, 5, 48, 0,  8, 2, 86, 8, 79, 3, 27, 6, 93, 7, 54, 
    6, 61, 1, 27, 8, 50, 3, 50, 7, 66, 4, 16, 0, 77, 5,  5, 2, 89, 
    4, 43, 5, 28, 2, 66, 8, 39, 3, 58, 7, 64, 1, 79, 6, 42, 0, 19, 
    7, 43, 2, 18, 3, 18, 1, 95, 6, 90, 5, 53, 0, 67, 4, 99, 8,  8, 
    1, 61, 8,  1, 5, 59, 6, 88, 2, 34, 7, 73, 3,  6, 0, 70, 4, 45, 
    5, 36, 2, 97, 7, 35, 6, 94, 4, 82, 1,  6, 0, 53, 3, 22, 8, 24, 
    1, 87, 5, 79, 2, 37, 8, 46, 3, 30, 7,  6, 6, 90, 0, 19, 4, 73
  };
  const int q0015[] = {
    9, 9, // Number of jobs and machines
    0, 73, 8, 90, 7, 64, 4, 40, 3, 21, 6, 20, 5, 32, 2, 70, 1, 40, 
    2, 36, 5,  4, 0, 77, 7, 45, 3, 13, 8, 24, 6, 22, 4, 87, 1, 59, 
    0, 50, 2, 84, 6, 48, 5, 58, 1,  3, 8, 64, 7,  9, 3, 37, 4, 58, 
    4, 52, 5, 30, 6, 75, 2, 91, 1, 31, 8, 42, 0, 62, 7,  1, 3, 94, 
    4, 56, 5, 85, 1, 58, 2, 84, 8, 62, 3, 59, 6, 17, 0, 58, 7, 47, 
    3, 39, 1, 30, 0, 65, 7, 88, 4, 90, 6, 62, 2, 85, 5, 20, 8, 76, 
    6, 80, 1, 70, 3, 66, 7, 15, 0, 91, 5, 60, 8, 16, 4, 56, 2, 20, 
    8, 43, 3,  5, 4, 49, 0, 98, 1, 88, 5, 95, 7,  9, 2, 16, 6, 76, 
    4, 96, 6, 27, 8, 97, 2, 88, 1, 22, 3, 66, 5, 75, 0, 76, 7, 46
  };
  const int q0016[] = {
    9, 9, // Number of jobs and machines
    1, 84, 7, 15, 4, 41, 5, 57, 3, 27, 2, 64, 8, 95, 0, 27, 6, 31, 
    6, 26, 8, 83, 5, 79, 1, 73, 0, 45, 3, 41, 2, 90, 4, 15, 7, 55, 
    2,  2, 3, 49, 8, 75, 1, 52, 0, 96, 5, 41, 7, 13, 4,  9, 6, 46, 
    4, 20, 8, 77, 0, 61, 3, 52, 5, 93, 1, 52, 6, 52, 7, 20, 2, 77, 
    8, 51, 1,  8, 4, 11, 7, 40, 6,  9, 2, 31, 3, 48, 0, 90, 5, 86, 
    8,  1, 7, 41, 6, 56, 0, 95, 2, 51, 3, 12, 1, 61, 4, 63, 5, 96, 
    7, 33, 0, 76, 6, 76, 3, 46, 5, 15, 1, 78, 4, 78, 8, 45, 2, 42, 
    1,  5, 8, 61, 0,  3, 4, 41, 7, 58, 2, 13, 6, 67, 5, 40, 3, 14, 
    3, 38, 1, 10, 2, 66, 8, 64, 6, 19, 5, 60, 7, 70, 4, 21, 0, 37
  };
  const int q0017[] = {
    9, 9, // Number of jobs and machines
    2,  8, 0,  8, 7, 51, 8, 32, 1, 22, 6, 22, 3, 79, 5, 20, 4, 85, 
    1, 77, 4, 91, 3, 49, 7, 46, 8, 96, 6, 16, 0, 48, 5, 87, 2, 53, 
    2, 37, 7, 85, 0, 18, 1, 71, 3, 61, 6, 21, 5, 74, 4, 48, 8, 82, 
    6, 94, 5, 68, 3, 15, 7, 29, 0, 86, 2, 73, 1, 42, 8, 59, 4, 56, 
    3, 53, 5, 26, 2, 32, 0, 76, 7, 36, 1, 67, 6,  5, 4, 60, 8,  8, 
    3, 67, 8, 51, 6, 26, 2, 67, 1, 85, 5, 88, 4, 16, 7,  2, 0, 78, 
    8, 55, 6, 32, 7,  5, 3, 81, 1, 27, 2, 56, 4, 64, 5, 70, 0, 68, 
    2, 86, 3, 23, 7, 44, 8, 59, 4, 49, 6, 83, 1, 32, 5, 81, 0, 34, 
    0, 75, 8, 48, 1, 11, 2, 56, 7, 39, 3, 50, 4, 65, 5, 85, 6, 83
  };
  const int q0018[] = {
    9, 9, // Number of jobs and machines
    8, 98, 0, 58, 6, 59, 3, 13, 4, 81, 7, 58, 5, 97, 2, 20, 1, 42, 
    3,  4, 2, 10, 7, 34, 8, 77, 0, 64, 5, 17, 1, 15, 4, 22, 6, 92, 
    5, 88, 3, 88, 2, 86, 8, 83, 4, 30, 7, 32, 1, 38, 6, 98, 0, 97, 
    1, 26, 6, 62, 8, 91, 0, 98, 2, 21, 7, 55, 4, 88, 3, 20, 5,  2, 
    1, 94, 2, 34, 4,  1, 8, 11, 5, 98, 7, 25, 3, 91, 0, 44, 6, 56, 
    4, 26, 3, 80, 1, 90, 8, 80, 6, 99, 5, 84, 7, 96, 2, 13, 0, 56, 
    3, 67, 4, 11, 5, 62, 7, 31, 6, 50, 0, 96, 1, 69, 2, 70, 8, 21, 
    4, 74, 3, 75, 0, 99, 5, 56, 6, 36, 7,  3, 8, 79, 1, 93, 2, 41, 
    3, 39, 5, 21, 7, 35, 4,  4, 1, 61, 0, 66, 2, 84, 6, 48, 8, 55
  };
  const int q0019[] = {
    9, 9, // Number of jobs and machines
    2, 37, 5, 64, 8, 67, 7, 62, 0, 97, 1, 36, 3, 94, 4,  4, 6, 94, 
    4, 25, 1,  4, 7, 20, 2, 60, 5,  9, 6, 17, 0, 80, 3, 76, 8, 89, 
    4, 38, 1, 12, 0, 48, 8, 76, 6, 48, 3, 30, 7, 71, 5, 20, 2, 82, 
    0, 29, 2, 41, 6, 98, 5,  3, 4, 98, 8, 53, 3, 93, 7, 75, 1, 39, 
    8, 92, 5, 97, 1, 95, 2, 90, 6, 23, 0, 13, 3, 34, 4, 60, 7, 38, 
    1, 47, 5, 60, 8, 72, 2, 40, 4, 88, 7, 79, 0, 91, 3, 70, 6, 53, 
    6, 20, 3, 37, 8, 46, 4, 42, 0, 96, 2, 79, 7, 24, 1, 45, 5, 89, 
    2, 71, 6, 90, 5, 67, 7, 80, 4, 72, 1, 90, 3, 91, 8, 34, 0, 32, 
    6, 99, 1, 99, 8, 57, 0, 22, 3, 68, 5, 93, 2, 25, 4, 90, 7,  6
  };
  const int q0020[] = {
    9, 9, // Number of jobs and machines
    4, 12, 8, 53, 2, 94, 3, 63, 7, 29, 6, 87, 5, 11, 0, 93, 1, 41, 
    4, 63, 6, 44, 0, 56, 1,  5, 5, 81, 7, 79, 2,  1, 8, 48, 3, 22, 
    8, 42, 7, 56, 4,  5, 6, 49, 0, 31, 5, 24, 1, 97, 3, 75, 2, 42, 
    1, 70, 0, 52, 8, 19, 4, 48, 3, 23, 2, 72, 7, 23, 5, 46, 6, 78, 
    8, 25, 4, 14, 2, 83, 1, 61, 7, 93, 5, 86, 3, 66, 6, 76, 0, 97, 
    4, 87, 0, 66, 8, 81, 7, 45, 6, 39, 1,  5, 3, 93, 2, 87, 5, 93, 
    7, 23, 5, 93, 0, 58, 2, 63, 3, 50, 1, 22, 4, 36, 6, 54, 8, 41, 
    0, 33, 5, 44, 7,  7, 6, 64, 1, 68, 8, 83, 3, 26, 2, 17, 4, 49, 
    3, 61, 1, 58, 0, 30, 2, 71, 6, 34, 5, 77, 4, 64, 7, 53, 8,  7
  };
  const int q0021[] = {
    9, 9, // Number of jobs and machines
    2, 48, 7, 87, 0, 92, 4, 38, 6, 75, 8, 27, 1, 47, 3, 11, 5, 48, 
    0, 12, 6, 48, 7,  8, 2, 17, 3,  1, 5, 75, 4,  5, 1, 27, 8, 88, 
    6, 75, 8, 92, 5, 15, 3, 21, 1, 29, 2, 15, 0, 95, 7, 10, 4, 26, 
    5, 43, 2, 59, 6, 26, 0, 82, 1, 37, 8, 54, 7, 11, 3, 29, 4, 52, 
    3,  6, 2, 36, 8,  3, 6, 28, 1, 29, 7,  7, 0, 85, 4, 48, 5, 66, 
    5, 65, 2, 54, 3, 71, 0, 64, 4, 80, 1, 85, 6, 35, 7, 79, 8, 34, 
    7, 60, 6, 46, 4, 15, 5, 45, 3, 10, 2, 65, 1, 94, 8, 42, 0, 72, 
    6, 61, 3, 34, 5, 29, 2, 31, 1, 11, 7, 51, 0, 32, 4, 20, 8, 34, 
    2, 26, 1, 83, 7, 85, 0, 88, 6, 59, 8, 34, 5, 63, 3, 77, 4, 75
  };
  const int q0022[] = {
    9, 9, // Number of jobs and machines
    3, 26, 2, 23, 5, 63, 4, 22, 0, 21, 1, 48, 7, 80, 8, 42, 6, 27, 
    8, 27, 1, 77, 2, 51, 5, 45, 4, 81, 7, 81, 0, 49, 6, 23, 3, 74, 
    8, 79, 3, 14, 4, 55, 0, 73, 6, 49, 7, 27, 2, 94, 1,  9, 5, 64, 
    4, 25, 6, 10, 8, 94, 5, 36, 3, 70, 1, 61, 7, 19, 0, 37, 2, 62, 
    5, 37, 6, 11, 3, 22, 0, 49, 4, 86, 2, 68, 7,  1, 8, 44, 1, 64, 
    3, 56, 4, 18, 5,  8, 2, 98, 1, 88, 8, 55, 7, 41, 6, 75, 0, 17, 
    6, 37, 2,  8, 1, 86, 4,  5, 3, 68, 8, 10, 0, 31, 7, 71, 5, 96, 
    4, 77, 3, 10, 5, 61, 6, 49, 7, 59, 8, 82, 0, 47, 1, 37, 2, 16, 
    3, 41, 7, 75, 4, 87, 1, 95, 0, 57, 2, 74, 5, 23, 8, 34, 6, 63
  };
  const int q0023[] = {
    9, 9, // Number of jobs and machines
    6, 70, 5, 72, 8, 65, 2, 84, 1, 25, 0, 23, 4, 34, 3, 75, 7, 48, 
    3, 21, 2, 88, 8, 60, 5, 48, 7,  8, 1, 24, 6, 67, 0, 83, 4, 70, 
    2, 94, 6, 69, 7, 15, 5,  8, 4, 11, 0, 29, 8, 84, 1, 17, 3, 52, 
    8, 68, 1, 60, 3, 45, 2, 90, 7, 37, 0, 81, 5, 13, 4, 68, 6, 91, 
    6, 60, 2, 32, 0, 87, 5, 79, 4,  5, 7, 30, 8, 44, 3, 98, 1, 63, 
    4, 30, 7, 70, 6, 73, 5, 83, 8,  1, 3, 94, 2, 64, 0,  3, 1, 44, 
    6, 13, 1, 50, 8, 10, 4, 18, 0, 43, 7, 27, 2, 23, 5, 41, 3, 37, 
    1, 57, 2, 20, 6, 16, 5, 90, 0, 37, 7, 75, 4, 64, 3, 31, 8, 52, 
    4, 52, 3, 28, 2, 40, 0, 30, 7, 80, 5, 80, 1, 45, 8,  9, 6, 65
  };
  const int q0024[] = {
    9, 9, // Number of jobs and machines
    8, 24, 7, 44, 4, 18, 3, 69, 0, 50, 1, 20, 2, 15, 5, 36, 6, 41, 
    3, 48, 2, 68, 5, 37, 7, 50, 0, 41, 6, 56, 8, 12, 1, 81, 4,  7, 
    2, 35, 6, 90, 0, 43, 3, 64, 5, 63, 4, 38, 1, 23, 8, 83, 7, 33, 
    3, 68, 1, 34, 5, 80, 0, 20, 2, 84, 4, 21, 8, 47, 7,  5, 6, 87, 
    0, 20, 1, 53, 3, 31, 5, 70, 7, 95, 4, 88, 8, 69, 6, 56, 2, 14, 
    7, 36, 6, 37, 8, 35, 1,  1, 4, 16, 2, 23, 0,  3, 3, 55, 5, 35, 
    0, 17, 7, 89, 4, 36, 8, 51, 2, 91, 1, 70, 6, 33, 3, 97, 5, 91, 
    0, 26, 7, 37, 1,  2, 2, 24, 8, 77, 6, 52, 3, 81, 5, 82, 4, 41, 
    7, 48, 4, 66, 2, 96, 6, 72, 3, 69, 8, 73, 0, 99, 5, 12, 1,  9
  };
  const int q0025[] = {
    9, 9, // Number of jobs and machines
    3, 49, 1, 10, 7, 81, 0, 96, 5, 44, 4, 23, 8, 25, 2, 43, 6, 17, 
    7, 57, 4, 83, 6, 72, 2, 93, 3, 71, 0, 73, 1, 16, 5, 14, 8, 28, 
    2, 52, 1,  9, 8, 31, 0,  2, 4, 58, 5, 64, 3, 69, 7, 69, 6, 67, 
    0,  5, 8, 62, 5, 69, 1, 13, 2, 60, 7, 16, 6, 98, 4, 37, 3,  2, 
    3, 60, 6, 79, 0, 68, 7, 22, 1, 33, 5, 50, 8, 87, 2,  5, 4, 14, 
    2, 56, 1, 38, 0, 43, 8, 32, 5, 26, 3, 73, 6, 51, 4, 73, 7, 71, 
    5, 74, 6, 97, 1, 58, 4, 46, 3, 28, 0, 57, 8, 63, 7,  7, 2, 17, 
    5, 56, 1, 80, 2, 87, 0, 79, 8, 71, 3, 19, 4,  7, 6, 19, 7, 94, 
    8,  3, 5, 96, 4, 82, 6, 25, 3, 71, 7, 60, 0,  2, 2, 77, 1, 61
  };
  const int q0026[] = {
    9, 9, // Number of jobs and machines
    8, 38, 7, 94, 2, 48, 4, 75, 1, 63, 0, 36, 3, 93, 5, 86, 6, 63, 
    5,  2, 4, 22, 1, 11, 2, 52, 3, 67, 6, 12, 7, 99, 8, 93, 0, 17, 
    4, 76, 7, 88, 3, 92, 2, 24, 0, 68, 5, 35, 1, 84, 6, 43, 8, 47, 
    7, 86, 3, 46, 4, 44, 1, 15, 6, 47, 5, 29, 8, 83, 2, 68, 0,  5, 
    0, 27, 6,  3, 3, 15, 5, 32, 1, 46, 2, 28, 8, 71, 4,  6, 7,  4, 
    8, 74, 6, 95, 0, 11, 3, 62, 1, 53, 4, 39, 2, 97, 5, 63, 7, 33, 
    0, 88, 4, 30, 1, 92, 5, 14, 8, 92, 7, 21, 3,  3, 2,  5, 6,  2, 
    4, 37, 7, 99, 5, 36, 1, 57, 8,  6, 0, 14, 6, 53, 3, 20, 2, 91, 
    3, 81, 6,  3, 7,  7, 0, 94, 1, 66, 4, 27, 5, 94, 8, 55, 2, 35
  };
  const int q0027[] = {
    9, 9, // Number of jobs and machines
    0, 21, 1,  2, 5, 13, 7, 35, 2, 61, 3, 42, 6, 83, 8,  3, 4, 20, 
    6, 55, 8, 22, 0, 18, 3, 43, 7, 67, 2, 73, 4, 77, 1, 30, 5, 57, 
    4, 28, 1, 38, 0, 54, 6, 16, 7, 35, 3, 28, 5, 21, 8, 38, 2, 15, 
    0, 18, 1, 74, 5, 53, 4, 35, 6, 16, 3, 90, 8, 40, 7, 64, 2, 36, 
    4,  4, 3, 87, 8, 45, 0, 56, 2, 43, 5,  7, 7, 53, 1, 45, 6, 78, 
    8, 94, 2, 21, 5, 32, 4, 64, 7, 11, 3, 37, 1,  9, 6, 30, 0, 80, 
    6, 24, 7, 91, 1,  3, 0, 81, 8, 99, 2, 63, 4, 30, 5,  6, 3, 25, 
    4, 38, 2, 80, 6, 59, 8, 26, 1, 33, 7,  5, 5, 37, 3, 61, 0, 24, 
    6,  8, 3, 10, 8, 19, 1, 46, 2, 20, 5, 18, 4, 74, 0, 11, 7, 54
  };
  const int q0028[] = {
    9, 9, // Number of jobs and machines
    3, 87, 7, 29, 2, 80, 6, 23, 0, 33, 4, 62, 1, 69, 8, 43, 5, 30, 
    8, 42, 5,  7, 4,  4, 2, 47, 7, 29, 6, 85, 3, 39, 1, 60, 0, 62, 
    6, 99, 4,  4, 2, 61, 0, 11, 5, 81, 8, 19, 3,  7, 1, 15, 7, 74, 
    4, 79, 0, 95, 6, 21, 2, 32, 8, 51, 7, 48, 5, 58, 3, 13, 1, 72, 
    3,  8, 8, 43, 7, 83, 0, 20, 4, 87, 2, 64, 6, 98, 5, 93, 1, 53, 
    3, 22, 6, 20, 5, 83, 8, 13, 4,  8, 7, 31, 1, 44, 2, 36, 0, 11, 
    6, 63, 2, 48, 3, 52, 8, 48, 7, 98, 0, 52, 5, 32, 4, 63, 1, 58, 
    4, 93, 2, 79, 1, 20, 0, 70, 6, 10, 5, 62, 7, 23, 8, 71, 3, 11, 
    3, 50, 2, 47, 7, 62, 1, 50, 6, 18, 0, 34, 8, 27, 4, 86, 5, 25
  };
  const int q0029[] = {
    9, 9, // Number of jobs and machines
    8, 74, 7, 53, 0, 62, 3, 61, 5, 42, 6, 39, 2, 40, 4, 83, 1, 54, 
    0, 74, 5, 86, 4, 95, 7, 32, 8, 28, 2,  7, 3, 89, 1, 69, 6,  3, 
    7, 13, 0,  2, 3, 78, 5, 69, 8, 91, 1, 96, 6,  3, 2, 79, 4, 35, 
    8, 35, 3, 22, 2, 79, 4, 74, 7, 89, 5, 78, 0, 90, 6, 96, 1,  1, 
    5,  6, 7, 84, 1, 33, 3, 71, 2, 72, 6, 24, 8, 35, 4, 58, 0, 99, 
    3, 13, 1, 77, 8, 10, 0, 69, 4, 23, 6, 80, 7, 84, 2, 79, 5, 92, 
    2, 60, 4,  9, 3, 21, 8,  9, 1, 62, 7, 32, 0, 65, 6, 71, 5, 65, 
    8,  2, 4, 71, 0, 32, 3, 47, 5, 10, 2, 62, 1, 78, 7, 22, 6, 29, 
    0, 33, 1, 81, 8, 15, 5, 40, 4, 90, 7, 45, 6, 25, 3, 67, 2, 61
  };
  const int q0030[] = {
    9, 9, // Number of jobs and machines
    0, 67, 4, 64, 8, 74, 1, 50, 3, 44, 2, 40, 7, 84, 6, 77, 5, 90, 
    4, 16, 8, 45, 7, 49, 0,  3, 6, 43, 3, 52, 1, 37, 2, 64, 5,  3, 
    5, 65, 6, 39, 2,  9, 4, 57, 1, 33, 3, 74, 7, 76, 8, 80, 0, 91, 
    8, 58, 1, 35, 6, 99, 5, 56, 0, 22, 7, 77, 4, 82, 3, 74, 2, 81, 
    4, 22, 0, 25, 2, 24, 5, 99, 6, 54, 8, 13, 1, 54, 3, 51, 7, 60, 
    4, 85, 5,  2, 2, 24, 8, 62, 7, 65, 0, 40, 3, 93, 6, 56, 1, 70, 
    5, 19, 6, 78, 8, 71, 0, 54, 2, 90, 3, 49, 4, 26, 1, 68, 7, 52, 
    2, 28, 0, 65, 1, 81, 5, 65, 4, 36, 8, 85, 7, 69, 6, 58, 3, 96, 
    3, 84, 2, 55, 5, 59, 1, 82, 6, 54, 0, 80, 7, 94, 4, 32, 8, 34
  };
  const int q0031[] = {
    9, 9, // Number of jobs and machines
    6, 74, 7, 93, 5, 44, 4, 81, 3, 20, 8, 19, 1, 30, 0,  5, 2, 60, 
    8, 99, 4, 16, 7,  4, 3, 61, 6, 12, 0, 45, 5, 50, 2, 41, 1, 61, 
    6, 78, 2,  7, 1, 55, 0, 53, 8, 13, 4, 30, 7, 30, 5, 67, 3, 23, 
    6, 99, 8,  7, 7, 16, 2, 21, 5, 69, 4, 97, 0, 22, 1, 61, 3, 84, 
    4, 45, 1, 81, 0, 73, 7, 43, 5, 86, 2, 59, 6, 58, 8, 91, 3, 95, 
    6, 25, 1, 57, 0, 70, 3, 94, 4, 87, 8, 83, 5,  9, 7, 73, 2, 38, 
    8,  8, 4, 55, 3, 69, 7, 95, 0, 39, 1, 43, 5, 30, 6, 25, 2, 53, 
    4, 24, 7, 64, 5, 15, 0, 71, 2,  5, 3, 82, 6,  5, 1, 60, 8, 44, 
    3,  2, 4, 21, 6,  1, 7,  1, 2, 21, 8, 76, 0,  8, 1, 26, 5,  2
  };
  const int q0032[] = {
    9, 9, // Number of jobs and machines
    6, 94, 0, 70, 3,  7, 5, 73, 2, 22, 8, 97, 7, 94, 1, 59, 4, 24, 
    7, 21, 5, 61, 0, 55, 2, 31, 1, 83, 4, 31, 6, 83, 3, 44, 8, 75, 
    7, 47, 4,  2, 3, 19, 5, 77, 2, 47, 1, 76, 6, 77, 8, 92, 0,  7, 
    0, 33, 5, 72, 6, 46, 2, 63, 1, 21, 4, 68, 7, 75, 3, 55, 8,  3, 
    3, 98, 7, 97, 6, 13, 0, 61, 5, 83, 8, 36, 4, 96, 1, 31, 2,  4, 
    6, 31, 2, 62, 3, 26, 1, 74, 0, 13, 5, 84, 4, 85, 8, 14, 7, 89, 
    0, 87, 4, 86, 5, 75, 3, 81, 6, 15, 7, 83, 1, 88, 2, 44, 8, 39, 
    6, 15, 2, 10, 4, 90, 7, 65, 5, 97, 3, 57, 0, 35, 1, 89, 8, 73, 
    2, 35, 3,  9, 7, 30, 1, 51, 4, 75, 0, 78, 6, 48, 5,  2, 8, 79
  };
  const int q0033[] = {
    9, 9, // Number of jobs and machines
    5,  3, 1, 17, 2, 29, 3, 39, 6, 64, 4, 75, 0, 93, 7, 31, 8, 65, 
    2, 56, 4, 66, 0, 33, 7, 66, 3, 17, 6, 36, 5, 55, 8, 28, 1, 52, 
    4, 89, 5, 91, 7, 49, 1,  6, 6, 19, 3, 65, 0,  6, 2, 50, 8, 50, 
    1, 69, 6, 67, 2, 62, 7, 74, 8, 26, 0, 43, 3, 73, 4, 72, 5, 58, 
    3, 42, 7, 31, 0, 43, 5, 52, 4, 24, 2,  8, 8, 82, 6,  1, 1, 59, 
    3, 31, 4, 24, 5,  2, 8, 26, 6, 94, 0, 55, 2, 30, 1, 59, 7, 63, 
    4, 38, 5,  6, 3, 88, 2, 87, 8, 32, 7, 18, 0, 88, 1, 25, 6, 17, 
    3, 27, 7, 38, 4, 59, 8, 96, 2, 23, 1, 41, 6, 63, 5, 93, 0, 57, 
    6,  9, 5, 73, 1, 56, 0, 35, 7, 17, 4, 29, 8, 18, 2,  8, 3, 91
  };
  const int q0034[] = {
    9, 9, // Number of jobs and machines
    7,  3, 0, 82, 3, 88, 5, 67, 2, 90, 4, 21, 1, 59, 8,  2, 6, 65, 
    6, 37, 1, 62, 0, 24, 8, 84, 7, 11, 5, 62, 3, 53, 4, 64, 2,  4, 
    6, 25, 1, 96, 7, 53, 3, 90, 0, 57, 5, 52, 4, 72, 8, 53, 2, 48, 
    1, 51, 6, 82, 8, 27, 7, 32, 0, 36, 4, 84, 5, 58, 2, 52, 3, 68, 
    0, 43, 1, 70, 8, 23, 6, 90, 7, 79, 4, 82, 3, 47, 5, 33, 2, 88, 
    7, 36, 4, 21, 6, 80, 8, 28, 5, 51, 3, 17, 2,  3, 1,  2, 0, 96, 
    0, 17, 2, 25, 6, 73, 3, 14, 4, 37, 8, 23, 7, 67, 5, 62, 1, 44, 
    7, 16, 5, 94, 2, 13, 1, 92, 8, 71, 3, 34, 6, 52, 4, 31, 0,  7, 
    2, 40, 3, 12, 8, 39, 7, 68, 6, 15, 5, 81, 1, 45, 4, 99, 0, 95
  };
  const int q0035[] = {
    9, 9, // Number of jobs and machines
    8, 55, 0, 79, 2, 95, 1, 35, 5, 65, 3,  2, 7, 66, 4, 87, 6, 69, 
    6, 11, 8, 94, 4, 37, 2, 66, 3, 65, 5, 51, 7, 29, 1,  6, 0, 54, 
    8, 49, 1, 33, 7, 59, 2, 28, 3, 46, 5, 13, 0,  3, 4, 46, 6, 67, 
    3, 10, 1, 77, 0, 96, 6, 30, 8, 22, 2, 56, 5,  7, 7, 38, 4,  6, 
    1, 53, 4, 16, 3, 52, 6, 83, 0, 47, 7, 60, 5, 16, 2, 48, 8, 14, 
    4, 87, 8, 18, 3, 26, 0, 71, 1, 83, 5, 48, 2, 45, 6, 26, 7, 85, 
    4, 69, 3, 64, 6, 81, 7, 56, 8, 36, 5, 36, 0, 88, 1, 81, 2, 79, 
    7, 65, 8, 78, 6, 59, 4, 46, 0, 13, 1,  2, 3, 99, 2, 42, 5, 69, 
    0, 83, 7, 63, 1,  5, 8, 38, 2, 88, 6, 11, 3, 80, 4, 24, 5, 30
  };
  const int q0036[] = {
    9, 9, // Number of jobs and machines
    1, 23, 8, 36, 3, 73, 7, 24, 4, 62, 2,  1, 6, 46, 5, 16, 0, 41, 
    2, 70, 3, 10, 8, 59, 7, 79, 5, 68, 6, 14, 1, 91, 0, 98, 4,  9, 
    6, 78, 5, 83, 2, 87, 4, 37, 1, 46, 3, 91, 0, 90, 7, 23, 8, 85, 
    0, 88, 2, 51, 3,  3, 7, 92, 6, 16, 1, 71, 8, 85, 4, 45, 5, 61, 
    2, 71, 6, 83, 3, 17, 5,  8, 0, 84, 4, 75, 7, 36, 1, 39, 8, 85, 
    4, 78, 0, 59, 8, 65, 2, 94, 3, 63, 5, 17, 1, 50, 7,  3, 6, 32, 
    5, 33, 7, 47, 3, 82, 6, 87, 4, 58, 1, 98, 0, 71, 8, 35, 2, 75, 
    3, 48, 6, 99, 5,  7, 2, 41, 7, 84, 8, 83, 1, 61, 4, 80, 0, 26, 
    6, 62, 4, 62, 3, 29, 8, 78, 2, 98, 7, 16, 0, 30, 1, 56, 5, 83
  };
  const int q0037[] = {
    9, 9, // Number of jobs and machines
    7, 32, 0, 85, 4, 58, 6, 27, 5, 18, 8, 74, 1, 23, 2, 29, 3, 65, 
    8, 30, 5, 52, 0, 44, 4, 67, 2, 25, 7, 24, 3, 12, 1, 43, 6, 92, 
    0, 75, 7, 63, 2, 89, 8, 21, 4, 67, 6, 31, 1, 74, 5, 48, 3, 99, 
    7, 22, 8, 98, 5, 38, 3, 26, 1, 80, 2, 14, 4,  5, 0, 49, 6, 76, 
    7, 58, 1,  7, 0, 49, 6, 97, 2, 64, 4, 39, 3, 53, 8,  9, 5, 69, 
    6, 32, 4, 59, 1, 90, 3, 30, 8, 19, 0, 82, 2,  5, 7, 68, 5, 36, 
    2, 72, 1, 98, 4, 83, 8, 56, 5, 58, 0,  9, 3, 83, 7, 81, 6, 15, 
    6, 83, 7,  5, 0, 36, 4, 92, 8, 25, 1, 86, 5, 40, 3,  1, 2, 84, 
    4, 90, 7, 54, 0, 96, 8, 43, 1, 86, 2, 31, 3,  2, 5, 83, 6, 19
  };
  const int q0038[] = {
    9, 9, // Number of jobs and machines
    3, 19, 6, 36, 7, 71, 0,  3, 8, 30, 1, 95, 5, 32, 2, 69, 4, 67, 
    4, 36, 0, 88, 1, 22, 3, 38, 8, 42, 5, 52, 6,  2, 7, 63, 2,  5, 
    1, 76, 5,  9, 8, 73, 2, 45, 0, 30, 6, 44, 7, 54, 3, 46, 4, 86, 
    1, 84, 5, 99, 2, 44, 0, 23, 3, 76, 8, 29, 4, 59, 7,  4, 6, 28, 
    5, 44, 7, 48, 2, 41, 0,  4, 8, 65, 6, 32, 1, 54, 4, 15, 3, 17, 
    4, 34, 0, 40, 6, 67, 2, 23, 3,  6, 1, 36, 7, 93, 8,  8, 5,  7, 
    8, 15, 6, 63, 0, 68, 7,  7, 2, 38, 1, 33, 5, 19, 4, 82, 3, 59, 
    8, 77, 0, 35, 7, 31, 4, 16, 2, 20, 5, 75, 3, 37, 1, 83, 6, 63, 
    0, 65, 4, 73, 3, 16, 8, 75, 1, 46, 6, 84, 7, 69, 2, 36, 5, 87
  };
  const int q0039[] = {
    9, 9, // Number of jobs and machines
    4, 46, 1, 94, 2, 20, 6, 22, 8, 82, 7, 51, 0, 43, 5, 52, 3, 21, 
    0, 41, 1, 64, 4, 85, 3, 37, 6, 86, 7, 24, 5, 79, 8, 61, 2, 65, 
    8, 58, 7, 94, 2, 72, 6, 56, 3, 21, 0, 23, 5, 79, 4, 80, 1, 21, 
    5,  1, 6, 75, 2, 99, 8, 64, 3, 82, 7, 39, 1, 96, 0, 40, 4, 46, 
    5, 90, 3, 42, 4,  9, 8, 93, 2, 57, 6, 95, 1, 55, 7, 62, 0, 78, 
    3, 43, 0, 35, 4, 87, 2,  1, 6, 96, 5, 80, 8, 22, 1, 70, 7, 10, 
    3, 89, 0, 82, 5, 73, 1, 99, 8, 93, 7, 31, 4, 29, 6, 27, 2, 69, 
    2, 69, 6,  7, 1, 69, 7, 70, 4, 63, 5, 88, 8, 20, 0, 28, 3, 35, 
    8,  4, 2, 38, 5, 81, 3, 88, 0, 45, 7, 38, 4, 69, 1, 34, 6, 45
  };
  const int q0040[] = {
    9, 9, // Number of jobs and machines
    3, 68, 0, 25, 4, 16, 5, 47, 8, 90, 1, 45, 2, 93, 7, 86, 6,  1, 
    2, 50, 5, 71, 1, 94, 7, 46, 0,  4, 8, 61, 4, 80, 6, 42, 3, 55, 
    7, 66, 6, 11, 2,  2, 0, 70, 5,  3, 4, 23, 8, 24, 3, 64, 1, 67, 
    6, 63, 0, 27, 3, 43, 1, 35, 2, 60, 8, 64, 7, 68, 4, 60, 5, 52, 
    3, 37, 2, 93, 7,  5, 4, 18, 0, 64, 8,  3, 5, 31, 6, 24, 1, 44, 
    4, 68, 1, 72, 3, 25, 5, 98, 7, 13, 0, 95, 2, 96, 6, 33, 8, 54, 
    2, 26, 5, 31, 7, 80, 0, 13, 1, 70, 3, 83, 8, 69, 6,  9, 4, 75, 
    3, 32, 4, 88, 2, 35, 0, 23, 8, 66, 6, 78, 1, 48, 7, 92, 5, 43, 
    6, 77, 2, 86, 7, 46, 1, 74, 8, 84, 3, 73, 0, 14, 4, 41, 5, 34
  };
  const int q0041[] = {
    9, 9, // Number of jobs and machines
    1, 47, 0, 50, 3, 55, 7, 33, 2, 96, 4, 26, 5, 73, 8, 54, 6, 17, 
    1, 95, 4, 64, 8, 27, 3, 69, 2, 81, 5, 32, 0, 36, 7, 92, 6, 38, 
    6, 88, 4, 87, 7, 55, 0, 57, 5, 77, 3, 85, 2, 28, 8, 21, 1, 34, 
    4, 53, 8, 20, 6, 94, 7,  6, 2, 76, 1, 90, 0, 59, 5, 25, 3, 36, 
    0, 65, 2, 49, 3, 49, 7, 94, 6, 25, 5, 77, 8, 52, 1, 28, 4, 73, 
    5, 90, 4, 77, 6, 83, 8, 93, 1, 42, 3, 20, 7, 25, 0, 89, 2, 38, 
    4, 43, 3, 69, 1, 70, 6, 34, 8, 76, 5, 23, 2, 93, 7,  1, 0, 79, 
    1, 67, 7, 77, 3, 78, 5,  1, 2,  6, 8,  3, 6, 94, 4, 99, 0, 98, 
    0, 19, 8, 62, 4, 47, 6, 28, 7, 60, 1,  7, 3, 17, 5, 51, 2, 38
  };
  const int q0042[] = {
    9, 9, // Number of jobs and machines
    2, 52, 5, 73, 7, 12, 1, 16, 8, 58, 3, 85, 4, 64, 6, 72, 0, 36, 
    0,  2, 2, 28, 5, 43, 8, 32, 4, 85, 7, 72, 1, 87, 3, 39, 6, 69, 
    8, 86, 6, 61, 4,  1, 3, 74, 7, 39, 5, 16, 1, 17, 0, 69, 2, 49, 
    5, 31, 4, 11, 8, 52, 7, 10, 3, 64, 2, 77, 0, 61, 6, 69, 1, 58, 
    5, 89, 7, 36, 3, 85, 4, 70, 6,  5, 0, 38, 2, 58, 8, 54, 1,  1, 
    1, 21, 2, 39, 3, 64, 7, 19, 5, 44, 0, 66, 4,  3, 8, 53, 6, 42, 
    4,  8, 2, 37, 5, 14, 7, 27, 3, 57, 1,  2, 6, 56, 8, 54, 0, 60, 
    2, 30, 3, 58, 0, 13, 8, 96, 7, 18, 4, 90, 6, 17, 5, 88, 1, 19, 
    1, 67, 4, 30, 0, 93, 7, 35, 3, 38, 2, 52, 8, 25, 6, 21, 5, 54
  };
  const int q0043[] = {
    9, 9, // Number of jobs and machines
    3, 41, 4, 40, 8, 81, 6, 22, 0, 51, 2, 31, 1, 90, 5, 15, 7, 53, 
    1, 83, 0, 85, 3, 72, 7, 80, 4,  3, 8,  4, 5, 71, 2, 88, 6, 46, 
    5, 72, 0,  1, 6, 97, 2, 40, 3, 79, 8, 10, 4, 62, 1, 36, 7, 51, 
    5, 51, 6,  5, 8, 57, 2, 90, 4, 37, 0, 78, 3, 51, 7, 84, 1, 84, 
    8, 37, 0, 58, 4, 53, 7, 52, 5, 72, 1, 73, 6, 32, 2, 24, 3, 42, 
    7, 39, 4, 75, 2, 59, 5, 83, 0, 63, 8, 67, 6, 63, 3, 93, 1, 88, 
    7, 79, 2, 59, 1, 35, 8, 60, 3, 52, 4, 11, 5, 39, 6, 33, 0,  6, 
    4, 18, 5, 68, 3, 95, 7, 85, 8, 42, 6, 50, 1, 21, 0, 57, 2, 28, 
    8, 86, 1, 74, 6, 57, 3, 94, 0, 16, 7, 78, 5, 67, 2, 18, 4, 40
  };
  const int q0044[] = {
    9, 9, // Number of jobs and machines
    0, 37, 2,  7, 4, 26, 5, 66, 1, 73, 8, 50, 7, 34, 6, 84, 3, 39, 
    4, 18, 7, 20, 5, 84, 3, 19, 1, 12, 0, 23, 2, 12, 6, 73, 8,  8, 
    6, 31, 7, 98, 2, 74, 1, 33, 0, 60, 5, 34, 3, 41, 4, 21, 8, 65, 
    3, 32, 4, 63, 2, 54, 8, 21, 6, 74, 7,  6, 0, 57, 5, 13, 1, 18, 
    7, 21, 0, 39, 6, 70, 3, 23, 4,  9, 5, 27, 2, 45, 8,  6, 1, 81, 
    1, 52, 4, 88, 3, 47, 5, 27, 8, 21, 0, 45, 7, 74, 6, 85, 2, 21, 
    4, 34, 2, 14, 5, 57, 6, 13, 0, 70, 7, 40, 3, 26, 1,  8, 8, 89, 
    8,  5, 3, 49, 2, 58, 5,  5, 6, 73, 7, 87, 4, 37, 0, 51, 1, 28, 
    8, 67, 2, 58, 3, 86, 7, 31, 0,  7, 6, 90, 1, 75, 5, 87, 4, 97
  };
  const int q0045[] = {
    9, 9, // Number of jobs and machines
    6, 10, 1, 81, 7, 59, 0,  4, 8, 36, 5,  9, 3, 13, 2, 70, 4, 62, 
    3, 48, 1, 82, 2, 58, 0, 62, 5, 49, 8, 54, 7, 47, 4, 64, 6, 12, 
    5, 33, 4, 54, 2, 88, 7, 76, 6, 23, 3, 66, 0, 40, 1, 35, 8, 84, 
    5, 56, 4, 66, 6, 77, 2, 42, 7, 11, 1,  1, 0, 10, 8, 89, 3,  8, 
    8, 23, 0, 10, 6, 64, 4, 64, 7, 49, 5, 19, 3, 48, 2,  1, 1, 85, 
    8,  4, 2, 33, 0, 66, 1, 90, 7, 44, 6, 62, 3, 89, 5, 17, 4, 18, 
    7, 31, 3, 99, 6, 44, 4, 69, 5, 78, 0, 57, 2, 45, 8, 23, 1, 61, 
    6,  7, 8, 83, 4, 53, 0, 75, 1, 16, 2,  3, 5, 79, 3, 74, 7, 62, 
    1, 30, 5, 49, 2, 83, 8, 59, 6, 36, 4, 37, 7, 28, 3, 83, 0, 10
  };
  const int q0046[] = {
    9, 9, // Number of jobs and machines
    1, 84, 2, 48, 8, 46, 3, 54, 4, 92, 7, 23, 5, 81, 0, 19, 6, 34, 
    0, 47, 1, 57, 5, 27, 6, 68, 4, 69, 3, 82, 7, 21, 8, 74, 2, 40, 
    5, 54, 6, 22, 8, 24, 2, 87, 7, 80, 3,  9, 4, 51, 1, 68, 0, 79, 
    5, 56, 4, 82, 3, 87, 0, 24, 8, 57, 2, 23, 7,  8, 6, 80, 1, 67, 
    3, 50, 8, 28, 2, 96, 1, 85, 0, 27, 7, 99, 6, 42, 4, 84, 5, 67, 
    3, 19, 5, 83, 0,  5, 6, 66, 8, 55, 4,  5, 1, 66, 2, 43, 7, 57, 
    1, 46, 2, 20, 4, 99, 5, 13, 6, 63, 8, 63, 0, 56, 3,  4, 7, 86, 
    4, 48, 1, 53, 6, 40, 5, 52, 7, 40, 8, 65, 3, 59, 0, 54, 2, 66, 
    4, 97, 1, 28, 6, 11, 2, 70, 3, 29, 5, 95, 7, 54, 8, 60, 0, 97
  };
  const int q0047[] = {
    9, 9, // Number of jobs and machines
    3, 82, 1, 52, 7, 75, 2, 80, 4, 14, 6, 13, 8, 46, 0, 68, 5, 19, 
    0,  1, 4, 91, 8,  5, 1, 69, 2, 32, 5,  9, 3,  9, 6,  5, 7, 51, 
    4, 11, 7, 78, 0, 73, 5, 57, 3, 58, 8, 74, 1, 29, 6, 23, 2, 30, 
    1, 59, 5, 97, 0, 85, 4, 62, 7, 58, 6, 62, 3, 51, 2, 70, 8, 99, 
    6, 11, 1, 35, 0, 90, 5,  5, 2, 17, 8, 97, 3, 51, 7, 93, 4, 20, 
    4, 51, 5, 23, 8,  5, 2, 39, 1, 73, 7, 61, 3, 78, 6, 27, 0, 87, 
    3, 24, 1, 32, 2,  1, 0, 21, 8, 53, 6, 98, 4, 68, 7, 32, 5, 20, 
    1, 36, 4, 62, 6,  2, 7, 35, 0,  5, 3, 37, 5,  5, 8, 68, 2, 97, 
    6, 79, 0, 51, 8, 32, 4,  5, 2, 84, 5, 30, 3, 68, 1, 10, 7, 55
  };
  const int q0048[] = {
    9, 9, // Number of jobs and machines
    2, 62, 1,  7, 3, 68, 0, 19, 8, 75, 6,  1, 4, 31, 7, 33, 5, 60, 
    8, 91, 1, 52, 5, 31, 0, 30, 2, 98, 3,  8, 6, 77, 4, 33, 7, 56, 
    4, 50, 6, 17, 5, 97, 2, 88, 1,  5, 7,  1, 3,  8, 0, 17, 8, 87, 
    3, 94, 7, 55, 2, 95, 0, 21, 4, 39, 1, 74, 8, 95, 6, 77, 5, 87, 
    4, 94, 2, 21, 5, 56, 3, 39, 6, 10, 7, 23, 0, 26, 8, 12, 1, 98, 
    3, 60, 7, 45, 1, 88, 0, 60, 5, 62, 4, 65, 8, 62, 6, 43, 2, 62, 
    1, 85, 8, 24, 6, 59, 0, 55, 5, 42, 4, 53, 3, 11, 2, 66, 7, 86, 
    5, 15, 7,  8, 6, 24, 0, 31, 8, 43, 1, 23, 4, 53, 2, 99, 3, 41, 
    3, 63, 2, 28, 7, 95, 8,  6, 4, 52, 1, 59, 0, 78, 6, 30, 5, 17
  };
  const int q0049[] = {
    9, 9, // Number of jobs and machines
    4, 14, 8, 45, 7, 69, 1, 19, 5, 93, 6,  7, 2, 67, 3, 48, 0, 29, 
    5, 38, 6, 15, 2, 62, 0, 76, 7, 80, 1, 49, 4, 25, 8, 31, 3, 27, 
    1, 34, 2,  4, 6, 87, 4, 25, 7, 43, 3, 22, 0, 54, 8, 99, 5, 70, 
    7, 13, 1, 92, 4, 46, 6, 53, 2, 25, 3,  2, 8, 60, 5, 11, 0, 28, 
    0, 11, 7, 73, 5, 26, 2, 96, 1, 81, 4,  4, 6, 97, 3, 25, 8, 91, 
    5, 82, 1, 20, 8, 64, 4, 51, 6, 22, 0, 90, 7, 24, 3, 85, 2,  6, 
    3, 87, 8, 17, 5, 52, 2, 59, 0, 94, 6, 53, 7, 13, 4, 59, 1, 72, 
    4,  1, 7, 90, 2, 18, 6, 81, 8, 40, 0, 58, 5, 23, 3,  3, 1, 29, 
    2, 49, 0, 22, 8, 53, 5,  6, 7, 68, 6, 70, 3,  6, 1, 72, 4, 86
  };
  const int q0050[] = {
    9, 9, // Number of jobs and machines
    0, 29, 8, 90, 4, 10, 3,  1, 5, 46, 2, 62, 7, 32, 1, 26, 6, 90, 
    4, 30, 2, 86, 8, 33, 1, 18, 0, 97, 5, 20, 6, 55, 3, 25, 7, 69, 
    5, 28, 1, 26, 2, 75, 6,  1, 8, 12, 7, 94, 3, 21, 0, 67, 4, 77, 
    6, 44, 3, 14, 4, 45, 8,  9, 7, 37, 0, 34, 5, 63, 1, 17, 2,  5, 
    8, 10, 5, 96, 7, 37, 3, 59, 0, 52, 4,  1, 6, 61, 1, 87, 2, 74, 
    6, 39, 2, 59, 0, 91, 8, 89, 4, 18, 3,  3, 7, 97, 1, 42, 5,  1, 
    1, 84, 7, 87, 4, 99, 8, 10, 2, 44, 3, 71, 6,  1, 0, 32, 5, 90, 
    3, 49, 8, 90, 1,  1, 7, 66, 4, 34, 0, 10, 5, 40, 6, 14, 2, 53, 
    6, 81, 7, 82, 2,  2, 5, 92, 4, 58, 0, 65, 3, 92, 8, 38, 1, 86
  };
  const int q0051[] = {
    9, 9, // Number of jobs and machines
    0, 35, 6, 47, 2, 72, 7, 60, 1, 42, 3, 42, 4, 48, 8, 59, 5, 78, 
    4, 47, 3, 41, 2, 34, 5, 45, 1, 71, 0, 61, 8, 97, 6, 24, 7, 83, 
    5, 99, 8, 73, 0, 40, 6, 91, 7, 68, 4,  9, 2,  7, 3, 50, 1, 40, 
    2, 10, 8, 65, 0, 92, 3, 50, 7, 71, 5, 13, 1, 97, 6, 37, 4, 14, 
    1, 20, 7, 61, 4, 21, 3, 29, 2, 25, 5, 25, 8, 17, 0, 68, 6, 47, 
    8, 40, 2, 66, 0,  2, 5, 94, 1,  8, 6, 81, 7, 34, 3,  2, 4, 20, 
    7, 38, 0, 55, 2, 69, 4, 56, 6, 76, 8, 40, 5, 77, 3,  8, 1, 49, 
    3, 80, 2, 22, 5, 11, 8, 80, 1, 32, 0,  4, 7, 48, 4, 70, 6, 97, 
    7, 37, 8, 14, 2, 85, 6, 14, 5, 58, 4, 27, 3, 77, 1, 18, 0, 71
  };
  const int q0052[] = {
    9, 9, // Number of jobs and machines
    4, 76, 5, 20, 0, 43, 1, 19, 2, 55, 3, 62, 8, 70, 6,  6, 7, 34, 
    3, 20, 7, 54, 1, 72, 0, 87, 8, 57, 5, 49, 6, 52, 2, 67, 4, 92, 
    1, 20, 3, 26, 5, 20, 4, 91, 7, 24, 8,  7, 6, 46, 0, 51, 2, 76, 
    0, 94, 5, 15, 3, 47, 6, 41, 1, 63, 8, 12, 2, 50, 7, 70, 4, 63, 
    7, 86, 6, 27, 4, 92, 3, 92, 2, 68, 1, 14, 8, 78, 0, 71, 5, 69, 
    7, 41, 6, 32, 3, 71, 0, 21, 5, 65, 2, 38, 4, 72, 8, 27, 1, 10, 
    1, 44, 8, 79, 3, 36, 2, 92, 7, 70, 5, 60, 6, 40, 0, 50, 4, 13, 
    2,  1, 7, 49, 1, 63, 3, 62, 5, 21, 6, 59, 0, 18, 8, 13, 4, 68, 
    8, 24, 3, 44, 4, 71, 7, 77, 5, 61, 1, 18, 0, 50, 2, 46, 6, 82
  };
  const int q0053[] = {
    9, 9, // Number of jobs and machines
    1, 37, 2, 33, 0, 16, 4, 53, 7,  8, 5, 42, 6, 91, 3, 62, 8, 92, 
    1,  2, 4, 75, 2, 13, 3,  6, 7, 75, 8, 58, 6, 35, 0, 22, 5, 85, 
    0,  1, 5, 90, 7, 68, 4, 79, 1, 82, 2, 37, 6, 31, 8, 97, 3, 55, 
    5, 31, 2, 42, 7, 82, 0, 62, 1, 87, 3, 59, 8, 36, 6, 39, 4, 45, 
    2, 17, 5, 21, 6, 90, 3, 82, 8, 11, 7, 77, 1, 55, 0, 21, 4, 91, 
    4, 16, 0, 87, 2, 85, 1, 34, 6, 42, 5, 77, 7, 40, 3, 88, 8,  6, 
    5, 90, 3, 28, 4, 30, 7, 95, 0,  6, 2, 57, 1,  6, 6, 98, 8, 73, 
    7, 30, 0, 14, 6, 27, 8, 68, 4, 93, 2, 29, 3, 73, 1,  5, 5, 69, 
    0, 21, 3, 47, 5,  1, 7, 43, 4, 22, 2, 24, 1, 92, 6, 53, 8, 17
  };
  const int q0054[] = {
    9, 9, // Number of jobs and machines
    4, 67, 1, 65, 5,  5, 6, 41, 3, 71, 8, 52, 2, 60, 7, 57, 0, 27, 
    5, 48, 4, 60, 7, 59, 0, 19, 6, 48, 8, 72, 1, 64, 3, 59, 2, 86, 
    1, 38, 8, 68, 2, 80, 0,  5, 7,  4, 6, 67, 3, 71, 5, 46, 4, 74, 
    6, 30, 5, 56, 1, 14, 4, 76, 0, 85, 3, 31, 7, 67, 8, 98, 2, 98, 
    2, 95, 4,  4, 0, 21, 5,  3, 3,  9, 8, 78, 1, 41, 6, 63, 7, 33, 
    3, 61, 4,  4, 5, 38, 8, 64, 1, 30, 6, 10, 7, 65, 2, 11, 0, 88, 
    0, 93, 4, 67, 8, 54, 1, 47, 6, 75, 5, 30, 7, 44, 2, 16, 3, 88, 
    3, 53, 8, 56, 7, 38, 5, 85, 0, 16, 6, 24, 1, 23, 4, 64, 2, 52, 
    0,  9, 5, 32, 1, 86, 7, 88, 6, 47, 8, 43, 3, 73, 4, 19, 2, 69
  };
  const int q0055[] = {
    9, 9, // Number of jobs and machines
    2, 81, 0, 67, 1,  5, 7, 93, 4, 46, 6, 54, 5, 90, 8, 94, 3, 72, 
    0, 58, 5, 77, 8, 25, 2, 93, 1, 86, 7, 34, 6, 97, 4, 12, 3, 40, 
    1, 78, 3, 77, 2, 79, 0, 23, 4,  7, 6, 28, 5, 57, 7, 70, 8, 42, 
    7, 41, 5, 96, 2,  9, 6, 92, 1, 83, 3, 84, 8,  4, 4, 68, 0,  1, 
    8, 27, 3, 70, 2,  1, 6, 88, 4, 70, 0, 31, 1, 18, 7, 41, 5, 86, 
    8, 12, 5, 64, 6, 36, 7, 64, 4, 39, 1, 53, 3, 86, 2, 66, 0,  2, 
    1, 49, 6, 65, 4, 15, 8, 44, 3, 31, 5, 33, 2, 34, 0, 17, 7, 59, 
    5, 32, 2, 38, 1, 57, 7, 62, 0, 69, 4, 52, 3, 72, 6, 94, 8, 20, 
    8, 96, 2, 53, 7, 25, 5, 39, 0, 33, 1, 29, 6, 25, 4, 88, 3, 90
  };
  const int q0056[] = {
    9, 9, // Number of jobs and machines
    6, 81, 1, 90, 2, 79, 5, 59, 4,  1, 0,  2, 3, 87, 7, 64, 8, 33, 
    2, 60, 6, 47, 5, 77, 8, 47, 7,  7, 4, 12, 0, 34, 3, 66, 1, 57, 
    6, 71, 7, 12, 0, 58, 4, 77, 8, 26, 2,  4, 3, 81, 1,  8, 5, 11, 
    8, 90, 0,  6, 5, 19, 3,  5, 7, 90, 2,  9, 1, 97, 4, 66, 6, 48, 
    5, 96, 1, 31, 8, 76, 2, 51, 6, 52, 4, 20, 3, 23, 7, 72, 0, 66, 
    4, 37, 1, 47, 7, 20, 3,  2, 5,  5, 8, 54, 2, 48, 0, 84, 6,  5, 
    7, 14, 6, 80, 2, 68, 5, 78, 0, 20, 1, 29, 3, 78, 8, 78, 4, 73, 
    1, 63, 6, 43, 5, 22, 0, 87, 3, 60, 4, 15, 2, 36, 7, 42, 8, 10, 
    1, 50, 7,  7, 2, 48, 0, 55, 8, 67, 5, 88, 3, 64, 6, 94, 4, 38
  };
  const int q0057[] = {
    9, 9, // Number of jobs and machines
    6, 91, 7, 70, 3, 32, 2,  1, 0, 82, 8, 54, 5, 88, 4, 89, 1, 67, 
    0, 66, 2, 74, 1, 46, 8, 66, 5, 13, 7, 64, 3, 46, 4, 83, 6, 18, 
    6, 67, 4, 42, 0, 24, 2, 80, 1, 37, 3, 45, 5, 40, 7, 35, 8, 84, 
    3, 82, 4, 64, 1, 67, 6, 18, 7, 99, 8, 46, 0, 55, 2, 93, 5, 26, 
    0, 33, 5, 16, 7, 43, 6, 92, 2, 40, 8, 65, 3, 31, 1, 74, 4, 82, 
    7, 97, 5, 52, 2, 80, 6, 20, 0,  5, 1, 97, 8, 15, 3, 67, 4, 38, 
    7, 90, 2, 14, 3, 87, 0, 70, 6, 79, 5,  9, 1, 46, 8,  5, 4, 36, 
    0, 48, 2, 80, 1, 38, 3, 30, 8, 84, 7, 14, 5, 83, 4, 62, 6, 10, 
    7, 28, 5, 11, 3, 14, 4, 93, 8, 30, 1, 92, 6, 35, 2, 94, 0, 98
  };
  const int q0058[] = {
    9, 9, // Number of jobs and machines
    7, 70, 5, 19, 8,  9, 2, 40, 0, 87, 4, 66, 6, 21, 3,  3, 1, 24, 
    7, 45, 4,  9, 8, 35, 0, 25, 6, 47, 3, 57, 1, 95, 5, 16, 2, 50, 
    5, 74, 7, 16, 0, 15, 3, 75, 6, 15, 1, 91, 4, 56, 2, 86, 8, 46, 
    6, 96, 8,  2, 4, 11, 3, 57, 1, 66, 2, 88, 5,  7, 0, 46, 7,  9, 
    5, 88, 0, 59, 1, 16, 4, 56, 7, 44, 6, 99, 3, 36, 8, 72, 2, 21, 
    4, 51, 8, 82, 1, 98, 6, 47, 5, 68, 7,  1, 2, 44, 3, 46, 0, 70, 
    4,  8, 2, 66, 0, 88, 3, 35, 7, 95, 8,  7, 1, 77, 5, 49, 6, 12, 
    0,  6, 5, 80, 4, 18, 8, 26, 7,  7, 2, 31, 6, 59, 3, 26, 1, 13, 
    8,  6, 2, 66, 4, 76, 0, 47, 6, 32, 3, 34, 5,  6, 1, 18, 7, 43
  };
  const int q0059[] = {
    9, 9, // Number of jobs and machines
    7, 77, 3, 82, 4, 64, 5,  8, 0, 36, 8, 71, 6, 10, 2, 72, 1, 35, 
    3, 21, 8, 84, 0, 30, 7, 21, 1, 91, 4, 26, 5, 55, 2, 40, 6, 89, 
    6, 41, 7, 54, 1, 89, 0, 55, 2,  3, 4, 45, 8, 48, 3, 20, 5, 52, 
    2,  5, 8, 13, 4, 84, 7, 39, 1, 57, 3, 91, 5, 16, 0, 66, 6, 97, 
    7, 26, 5, 91, 4, 72, 3, 37, 1,  9, 2, 67, 8, 46, 0, 82, 6, 78, 
    8, 13, 5, 34, 0, 87, 6, 75, 1, 82, 2, 74, 3, 68, 7, 31, 4, 50, 
    0, 79, 2, 14, 3, 64, 6, 18, 5,  2, 7, 86, 8, 95, 1, 71, 4, 28, 
    6, 89, 2, 64, 4, 86, 8, 56, 1, 25, 7, 81, 0, 78, 5, 32, 3, 39, 
    4, 10, 6, 37, 1, 72, 8, 66, 3,  5, 5, 23, 2, 25, 7,  7, 0, 51
  };
  const int q0060[] = {
    9, 9, // Number of jobs and machines
    7, 28, 5, 61, 4, 24, 1, 88, 8, 91, 3, 56, 2, 18, 0, 46, 6, 72, 
    8, 69, 4, 77, 3, 21, 2, 21, 5, 16, 6, 49, 7, 60, 1, 13, 0, 89, 
    7, 15, 0,  6, 2, 44, 4, 63, 6, 52, 3, 70, 5, 63, 8,  2, 1, 59, 
    6, 53, 0, 15, 4, 28, 7, 47, 8, 69, 5, 70, 1, 59, 2, 29, 3, 94, 
    8, 29, 1, 87, 3, 29, 4, 18, 2, 76, 5, 75, 6, 75, 0, 34, 7, 94, 
    4, 77, 2, 39, 1, 92, 0, 87, 7, 43, 6, 60, 8,  8, 3, 32, 5, 19, 
    1, 32, 4, 73, 3, 77, 7, 51, 6, 72, 2, 88, 5, 37, 0, 99, 8, 73, 
    5, 66, 8,  8, 3,  9, 0, 60, 7, 23, 6, 19, 1, 44, 2, 84, 4, 71, 
    6, 52, 1, 37, 2, 18, 4, 82, 5, 62, 0, 47, 3, 84, 8, 47, 7, 99
  };
  const int q0061[] = {
    9, 9, // Number of jobs and machines
    5, 41, 6, 52, 2, 92, 0, 55, 8, 82, 7, 21, 3, 56, 1, 29, 4, 98, 
    5, 39, 1, 43, 3, 28, 7, 21, 0, 97, 2, 42, 8, 61, 4, 32, 6, 79, 
    8, 73, 3, 15, 0, 58, 1,  5, 4,  5, 2, 94, 5, 99, 6, 90, 7, 10, 
    8, 42, 2, 44, 4, 64, 3, 85, 6, 71, 0, 24, 7, 67, 5, 91, 1, 55, 
    4, 73, 3, 53, 7, 97, 5, 61, 1, 73, 6, 67, 8, 48, 0, 68, 2, 53, 
    8, 60, 4, 47, 7, 40, 5, 49, 6, 34, 1, 61, 0,  4, 3, 34, 2, 83, 
    7,  4, 5, 27, 8, 76, 6, 77, 0, 79, 3, 97, 4, 75, 1, 47, 2,  2, 
    4, 40, 1, 69, 6,  4, 5, 71, 3, 45, 8, 20, 0, 95, 2, 97, 7, 68, 
    0, 71, 4, 64, 7, 30, 6, 19, 5, 12, 3, 70, 2, 86, 1, 36, 8,  1
  };
  const int q0062[] = {
    9, 9, // Number of jobs and machines
    4, 72, 3, 94, 0, 16, 1, 36, 8, 11, 6, 39, 7, 17, 2, 21, 5, 83, 
    1, 90, 3, 23, 5, 76, 7, 17, 2,  9, 6, 20, 0, 91, 4, 99, 8, 78, 
    7,  3, 5,  4, 4, 82, 2, 45, 3, 64, 1, 50, 0, 87, 8, 96, 6, 13, 
    8, 41, 5, 86, 2, 73, 6, 26, 3,  1, 0, 61, 4, 94, 7,  8, 1, 54, 
    1, 26, 7, 63, 2, 81, 6, 63, 4, 35, 0, 10, 3, 32, 8, 16, 5, 53, 
    7,  2, 5, 16, 2, 53, 8, 13, 4, 34, 1, 56, 3, 93, 0, 43, 6, 57, 
    4, 83, 7, 19, 0, 97, 6,  9, 5, 21, 3, 33, 2, 35, 8, 89, 1, 21, 
    7, 25, 2, 60, 3, 33, 4, 38, 8, 75, 0, 34, 5, 19, 1, 83, 6, 54, 
    5, 83, 4, 28, 2, 75, 8,  5, 3, 72, 7, 51, 6, 37, 0, 42, 1, 91
  };
  const int q0063[] = {
    9, 9, // Number of jobs and machines
    1, 99, 8, 36, 3, 65, 2, 65, 5, 29, 4, 99, 7, 34, 6, 99, 0, 91, 
    3, 90, 2, 87, 6, 31, 7, 16, 4, 43, 8, 69, 1, 58, 5,  1, 0, 52, 
    8, 92, 7,  1, 0, 78, 1, 78, 2, 43, 6, 36, 3, 73, 4, 63, 5, 82, 
    7, 67, 0, 16, 8, 47, 1, 68, 5, 31, 3, 41, 2, 74, 4, 86, 6,  5, 
    8, 79, 2,  4, 1, 46, 4, 84, 6, 52, 5, 58, 3, 25, 7, 12, 0, 59, 
    5, 49, 2,  9, 6, 87, 1, 98, 7, 59, 4, 28, 3, 23, 8, 39, 0, 47, 
    4,  3, 7, 40, 1,  9, 6, 33, 0, 78, 5,  7, 2, 22, 8, 65, 3, 85, 
    5, 52, 7, 55, 1, 90, 3, 22, 6, 13, 2, 87, 0, 72, 4, 97, 8, 89, 
    2, 42, 5,  2, 3, 97, 8, 19, 6, 29, 7, 27, 4, 89, 0, 79, 1, 49
  };
  const int q0064[] = {
    9, 9, // Number of jobs and machines
    8, 41, 3, 76, 7,  6, 6, 55, 5,  8, 1, 55, 2, 97, 0, 41, 4, 97, 
    4, 83, 0, 23, 6,  6, 8, 47, 2, 69, 1,  7, 5, 27, 7, 84, 3, 43, 
    8, 67, 4, 77, 0,  7, 7, 53, 1, 15, 5, 51, 2, 34, 6, 77, 3, 32, 
    3, 16, 1, 32, 5, 63, 6, 49, 2, 36, 7, 27, 4, 31, 0, 88, 8, 17, 
    3,  8, 5, 53, 4, 57, 8, 25, 1, 28, 2, 99, 0, 27, 6, 92, 7, 11, 
    0, 14, 8, 40, 5,  9, 1, 60, 4, 60, 7, 94, 3, 26, 6, 22, 2, 90, 
    2,  2, 1, 41, 8, 34, 5,  2, 7, 96, 6, 64, 3, 12, 4, 42, 0, 31, 
    8, 35, 1, 55, 2, 78, 5, 72, 6, 37, 0, 38, 4, 48, 3,  9, 7, 46, 
    4, 73, 0,  4, 1, 90, 8, 92, 3, 87, 7, 50, 2, 49, 6, 29, 5, 77
  };
  const int q0065[] = {
    9, 9, // Number of jobs and machines
    0, 77, 8, 79, 2, 68, 3, 21, 6, 20, 7, 24, 4, 83, 1, 88, 5, 13, 
    7, 40, 1, 65, 6, 32, 4, 87, 0, 37, 2, 75, 5,  5, 3,  4, 8, 19, 
    1, 87, 4, 90, 2, 61, 7, 67, 5, 16, 3, 21, 0, 47, 8, 39, 6, 94, 
    5,  3, 4, 56, 3, 78, 8, 77, 2, 52, 1, 34, 7, 28, 6, 13, 0, 63, 
    4, 52, 5,  8, 0, 78, 2, 56, 7, 45, 8, 26, 6, 37, 1, 46, 3, 98, 
    7,  7, 4, 58, 5, 86, 6, 36, 0, 94, 2, 43, 3, 32, 8, 14, 1, 17, 
    1, 94, 0, 96, 5, 82, 6, 90, 4, 35, 3, 69, 2, 52, 8, 87, 7, 44, 
    5, 12, 3, 64, 2, 35, 1, 53, 6, 92, 4, 44, 0, 27, 8, 81, 7, 24, 
    1, 11, 5, 29, 8, 91, 7, 16, 4, 13, 0, 63, 3, 89, 6, 79, 2, 44
  };
  const int q0066[] = {
    9, 9, // Number of jobs and machines
    6, 15, 2, 52, 4, 56, 7, 32, 0, 45, 5, 79, 1, 15, 3, 66, 8, 38, 
    0, 92, 8, 26, 2, 21, 7, 23, 6, 22, 3, 15, 4, 14, 1, 61, 5, 56, 
    1, 26, 0, 80, 3, 95, 7, 57, 8, 78, 2, 65, 4, 34, 6, 64, 5, 92, 
    8, 83, 2, 37, 6, 89, 5, 54, 3,  2, 0, 12, 7, 63, 4, 89, 1, 64, 
    7, 38, 2, 96, 4, 82, 1, 58, 3, 36, 6, 38, 0, 61, 8, 14, 5, 48, 
    8, 84, 5, 73, 4, 54, 7, 17, 3, 27, 6, 53, 2,  8, 0, 25, 1,  7, 
    6, 16, 2, 67, 7, 95, 4, 10, 3, 95, 1, 97, 5, 40, 8, 20, 0, 32, 
    2,  4, 7, 99, 5, 26, 3, 69, 1, 89, 4, 83, 0, 37, 6, 35, 8, 91, 
    0, 29, 1, 58, 8, 53, 6,  8, 5, 82, 7,  4, 4, 79, 3, 53, 2, 88
  };
  const int q0067[] = {
    9, 9, // Number of jobs and machines
    2, 63, 1, 99, 4, 83, 5, 53, 7, 46, 8, 26, 6,  1, 0,  7, 3, 83, 
    0, 66, 8, 91, 2,  4, 4, 44, 1, 83, 6, 21, 7, 62, 3,  1, 5, 17, 
    5, 73, 6, 73, 0, 93, 1, 94, 2, 37, 7, 10, 4, 89, 8, 65, 3, 36, 
    7, 39, 2, 65, 3, 95, 5, 66, 6,  7, 8, 17, 1, 83, 4, 18, 0, 19, 
    6, 81, 8, 23, 0, 42, 3, 84, 5, 61, 2, 82, 4, 96, 1, 22, 7,  9, 
    8, 39, 7, 48, 2, 68, 1, 86, 6, 44, 0, 35, 4, 55, 3, 44, 5, 53, 
    8, 26, 3, 18, 6, 98, 1, 57, 4, 78, 5, 48, 7, 60, 2,  3, 0, 75, 
    2, 12, 7, 79, 5, 69, 4, 39, 3, 66, 6,  4, 0, 21, 8, 95, 1,  2, 
    3, 20, 1, 98, 8, 13, 7, 96, 6, 12, 4, 76, 2, 90, 5, 59, 0, 43
  };
  const int q0068[] = {
    9, 9, // Number of jobs and machines
    7, 32, 6, 57, 2,  9, 0, 44, 3, 53, 5, 18, 8, 59, 1, 88, 4,  1, 
    7, 15, 3, 89, 5, 59, 8, 33, 0, 77, 4, 90, 2, 27, 1, 90, 6,  7, 
    2, 35, 8, 96, 0, 66, 3, 70, 6, 89, 4, 14, 1, 76, 7, 23, 5, 19, 
    0, 48, 7, 80, 2, 84, 4, 13, 6,  3, 1,  1, 5, 20, 8, 85, 3, 57, 
    7, 86, 0, 71, 4, 45, 2, 71, 6, 74, 8, 34, 3, 16, 5, 90, 1, 44, 
    8, 90, 1, 76, 2, 57, 0, 52, 5, 10, 3, 48, 4, 44, 6, 79, 7, 64, 
    6, 22, 0,  1, 4, 39, 2, 70, 8, 98, 7, 52, 3,  5, 5, 97, 1, 81, 
    8, 33, 5, 57, 6, 11, 3, 35, 4, 60, 2, 99, 1, 81, 0, 94, 7, 56, 
    7, 29, 1, 76, 8, 86, 5, 26, 3, 84, 2, 71, 6, 36, 0, 94, 4, 69
  };
  const int q0069[] = {
    9, 9, // Number of jobs and machines
    3, 86, 1, 35, 2, 81, 5, 30, 4,  2, 0, 70, 8, 53, 6, 67, 7, 14, 
    7, 15, 2, 42, 5, 43, 8, 64, 0, 56, 4, 97, 6, 16, 1, 91, 3, 22, 
    1, 62, 4, 72, 0, 95, 7, 26, 8, 29, 3, 29, 6, 35, 5, 47, 2, 37, 
    8, 16, 4, 11, 6, 11, 2, 19, 7, 21, 5, 32, 0, 48, 1, 85, 3, 82, 
    0, 89, 4, 93, 3, 72, 5, 75, 1,  4, 6, 70, 2, 83, 7, 91, 8,  7, 
    6, 50, 8, 43, 5, 76, 1, 27, 7, 58, 3, 59, 4, 71, 0, 12, 2, 82, 
    6, 36, 8, 91, 3, 33, 5, 24, 1, 15, 4, 90, 2,  1, 0, 62, 7, 72, 
    8,  8, 5, 48, 7, 40, 0, 75, 4, 10, 6, 16, 3, 86, 1, 37, 2, 90, 
    5, 67, 2, 24, 7, 78, 0, 32, 1, 33, 4, 87, 8, 20, 3, 20, 6, 76
  };
  const int q0070[] = {
    9, 9, // Number of jobs and machines
    8,  6, 1, 63, 2, 17, 7, 19, 6, 51, 0, 21, 3, 20, 5, 62, 4, 47, 
    0, 43, 4, 23, 3, 76, 7, 38, 6, 93, 8, 91, 2, 37, 5, 49, 1, 56, 
    7, 23, 0, 16, 8, 95, 4, 93, 1, 82, 5, 64, 3, 45, 6, 38, 2, 87, 
    5,  3, 7, 92, 1, 23, 4, 42, 6, 98, 3, 68, 2, 70, 0, 72, 8, 29, 
    6, 92, 0, 31, 5, 90, 7, 94, 2, 27, 8,  6, 1, 15, 3, 30, 4, 51, 
    1,  4, 6, 93, 0, 83, 7, 14, 2, 34, 8, 92, 4, 88, 5, 45, 3,  2, 
    1, 35, 7, 46, 0, 99, 2, 64, 8, 59, 6, 14, 4,  2, 5, 18, 3, 18, 
    2, 51, 7, 36, 3, 70, 0, 19, 6, 45, 8, 37, 4, 51, 5, 28, 1, 60, 
    8, 19, 6, 93, 1, 59, 2, 10, 4, 81, 3, 38, 5,  3, 0, 50, 7, 38
  };
  const int q0071[] = {
    9, 9, // Number of jobs and machines
    4, 94, 6, 49, 3, 17, 2, 55, 1, 73, 7, 80, 0, 11, 8, 80, 5, 61, 
    8, 59, 3, 10, 0, 81, 1, 31, 5, 58, 4, 29, 2, 28, 7, 43, 6, 74, 
    0,  8, 8,  5, 6, 84, 1, 46, 2, 81, 4, 81, 5, 49, 3, 11, 7, 23, 
    5, 77, 4,  2, 6, 71, 3, 14, 8, 37, 7, 23, 1, 95, 2, 88, 0, 41, 
    2, 65, 3, 54, 7, 28, 0, 25, 5, 46, 4, 85, 8, 56, 6, 59, 1, 49, 
    5, 98, 7, 78, 2, 61, 0, 23, 3, 61, 8, 43, 6, 94, 4, 38, 1, 75, 
    7, 35, 5, 75, 4, 80, 1, 68, 0, 89, 6, 79, 2, 72, 8, 31, 3, 65, 
    6, 20, 2, 19, 3, 51, 7, 82, 4, 36, 8, 60, 0, 59, 5, 57, 1, 96, 
    4, 75, 0, 49, 5, 59, 6, 61, 3, 39, 7, 24, 1, 70, 8,  6, 2, 13
  };
  const int q0072[] = {
    9, 9, // Number of jobs and machines
    8, 79, 4, 11, 1, 41, 5, 49, 6, 29, 0, 73, 2, 24, 7, 16, 3, 98, 
    6, 70, 2, 15, 1,  1, 4, 47, 5, 70, 8, 87, 3, 98, 0, 98, 7, 57, 
    2, 30, 7, 40, 8, 93, 1, 90, 5, 98, 3,  2, 6, 88, 4,  8, 0, 16, 
    8, 43, 5, 40, 7, 25, 6,  8, 0, 31, 2,  4, 3, 73, 1, 71, 4, 43, 
    1, 44, 3, 14, 5, 82, 4, 46, 8, 83, 2, 90, 0, 13, 7, 24, 6, 44, 
    2, 76, 5, 43, 1, 19, 3, 43, 0, 68, 8, 39, 7,  5, 4, 73, 6, 63, 
    3, 88, 0, 80, 4, 94, 1, 61, 5, 91, 6, 68, 7, 58, 8, 21, 2,  5, 
    3, 49, 8, 94, 1, 45, 4, 97, 6, 91, 0, 63, 7, 87, 5, 96, 2, 55, 
    4, 11, 0, 35, 2, 25, 8, 13, 5, 71, 6, 11, 7, 89, 3, 38, 1, 45
  };
  const int q0073[] = {
    9, 9, // Number of jobs and machines
    1, 92, 0,  1, 7, 73, 4, 11, 2, 95, 5, 84, 6, 46, 8, 25, 3, 38, 
    6, 61, 3, 14, 1, 85, 0,  3, 8, 53, 2, 29, 7, 59, 4, 38, 5, 20, 
    2, 49, 4, 93, 3, 81, 6, 39, 1, 49, 8, 99, 0, 37, 5, 87, 7, 15, 
    3, 77, 6,  7, 4, 64, 8, 98, 1, 49, 0, 15, 7, 75, 5, 73, 2, 63, 
    0,  2, 1, 36, 2, 41, 3, 65, 6, 79, 5, 46, 8, 83, 7, 40, 4, 14, 
    4, 30, 7, 11, 3, 21, 2, 90, 5, 57, 8,  1, 0, 22, 1, 51, 6, 15, 
    3, 30, 6,  3, 1, 98, 2, 88, 8, 59, 0, 50, 7, 89, 4, 34, 5, 97, 
    8, 20, 4, 35, 7, 72, 3, 20, 5, 63, 1, 37, 0, 72, 2, 65, 6, 21, 
    3,  1, 5, 30, 6, 91, 1, 45, 8, 72, 0, 40, 7, 82, 4, 29, 2,  2
  };
  const int q0074[] = {
    9, 9, // Number of jobs and machines
    6, 35, 8, 13, 2, 12, 0, 73, 5, 24, 1, 19, 4, 30, 3, 81, 7, 50, 
    3, 59, 0, 47, 5, 63, 7,  2, 1, 34, 8,  3, 4, 56, 6, 46, 2, 41, 
    3, 64, 8, 24, 5, 52, 0, 13, 6, 50, 7, 67, 1, 47, 2, 27, 4, 74, 
    4, 59, 8, 19, 7, 33, 2, 58, 3, 60, 5, 27, 1, 68, 0, 60, 6, 33, 
    3, 85, 1, 71, 6, 86, 2, 26, 8, 11, 5, 41, 7, 17, 4, 36, 0, 21, 
    4, 68, 6, 18, 7, 48, 2, 65, 3, 67, 0, 78, 1, 91, 8, 12, 5, 23, 
    6, 44, 4, 96, 8, 88, 1, 85, 3, 85, 7,  1, 2, 47, 5, 82, 0, 85, 
    1, 19, 2, 48, 7, 51, 6, 94, 4, 93, 5, 36, 8, 78, 0, 57, 3,  9, 
    0, 49, 3, 67, 6, 44, 2, 48, 8, 76, 1, 10, 5, 39, 4, 62, 7,  7
  };
  const int q0075[] = {
    9, 9, // Number of jobs and machines
    0, 48, 6, 30, 7, 63, 1, 63, 4, 85, 8, 81, 2,  2, 3, 81, 5, 81, 
    5, 11, 3, 35, 1, 88, 8, 93, 4, 48, 6, 49, 0, 51, 2, 90, 7, 14, 
    3,  6, 1, 59, 8, 97, 0, 70, 2, 22, 5, 67, 4,  4, 7, 76, 6, 57, 
    3, 25, 2, 67, 4, 82, 7,  9, 5,  8, 0,  1, 8, 93, 6, 79, 1, 49, 
    7, 66, 2, 19, 4, 54, 1, 63, 3, 65, 0, 26, 8, 24, 5,  6, 6, 32, 
    3, 81, 6, 86, 1, 46, 7, 47, 8, 73, 4, 60, 0, 46, 5, 63, 2, 58, 
    1, 87, 2, 85, 4, 11, 5, 69, 0,  4, 7, 30, 3, 74, 8, 45, 6, 35, 
    4, 82, 6, 80, 1, 59, 3, 36, 2, 69, 8, 17, 0, 87, 7, 77, 5, 41, 
    4, 66, 6, 79, 0, 52, 5, 57, 3, 63, 1, 72, 7, 66, 8, 66, 2, 97
  };
  const int q0076[] = {
    9, 9, // Number of jobs and machines
    8, 60, 7, 81, 6, 52, 3, 25, 5, 22, 1, 55, 2,  1, 4, 67, 0, 55, 
    3, 53, 5, 76, 7, 55, 2, 68, 4, 66, 8,  5, 0, 89, 1, 55, 6, 39, 
    6, 37, 7, 63, 4, 64, 8, 11, 0, 85, 1, 31, 5, 58, 2, 23, 3, 83, 
    2, 81, 5, 30, 3, 24, 8, 74, 7, 64, 0, 54, 4,  8, 1, 67, 6, 40, 
    5, 34, 0,  7, 1, 75, 2, 91, 8, 92, 6, 23, 7, 31, 4, 73, 3,  1, 
    4, 43, 7,  9, 1, 73, 2, 89, 0, 92, 8, 50, 3,  6, 5, 28, 6, 32, 
    8, 89, 3,  9, 1, 87, 2, 29, 4, 78, 5,  4, 7, 47, 0, 80, 6, 91, 
    2, 39, 6, 90, 5, 59, 1, 51, 0, 19, 8, 47, 7, 33, 4, 24, 3, 73, 
    3, 55, 4, 83, 8, 56, 6, 43, 7, 78, 2,  9, 5, 32, 0, 90, 1, 16
  };
  const int q0077[] = {
    9, 9, // Number of jobs and machines
    4, 33, 6, 65, 7, 92, 3, 63, 2, 77, 1, 34, 8, 44, 0,  3, 5, 56, 
    5, 33, 2, 23, 1, 92, 3, 93, 6, 87, 7, 20, 0, 25, 4, 98, 8,  3, 
    3, 54, 7, 86, 2, 75, 0, 69, 1, 85, 4, 81, 5, 36, 8,  8, 6, 67, 
    1, 93, 2, 88, 4, 72, 0, 52, 5, 30, 6, 54, 3, 73, 8, 39, 7, 68, 
    1, 65, 3, 97, 2, 60, 6, 75, 4,  3, 7, 86, 5, 76, 8, 92, 0, 85, 
    3, 85, 4, 16, 8, 74, 6, 16, 7, 74, 0,  9, 5,  5, 1, 33, 2, 73, 
    2, 77, 3, 45, 6, 91, 0, 69, 5, 81, 4, 80, 8, 15, 1, 72, 7, 75, 
    5, 45, 7, 70, 8, 52, 4, 95, 6, 37, 2, 35, 1, 67, 0, 19, 3, 34, 
    1, 80, 4,  9, 0, 16, 3, 52, 5,  9, 7, 39, 6, 22, 2, 15, 8, 63
  };
  const int q0078[] = {
    9, 9, // Number of jobs and machines
    6, 28, 0,  3, 5, 53, 8,  5, 1, 62, 3, 91, 7,  2, 4, 61, 2, 18, 
    4, 93, 7, 60, 6, 61, 5, 70, 2, 74, 1, 10, 8, 45, 0, 78, 3, 50, 
    4, 68, 3, 62, 0, 62, 6,  4, 1, 99, 7, 49, 8, 58, 2, 17, 5, 56, 
    8, 68, 5, 27, 1, 49, 0, 20, 6, 36, 3, 33, 2, 44, 7, 36, 4, 98, 
    1, 53, 5, 79, 6, 20, 3, 99, 2, 34, 4, 51, 8, 28, 0, 55, 7, 21, 
    3,  7, 7, 13, 6, 63, 4, 39, 0, 33, 5, 86, 8, 46, 1, 24, 2, 41, 
    8, 10, 5, 10, 6, 82, 4, 51, 0,  2, 7, 28, 1, 45, 2, 50, 3, 28, 
    5, 45, 2, 40, 7, 59, 6, 50, 1, 10, 8, 68, 4, 83, 0, 17, 3, 67, 
    2, 57, 7, 41, 1, 80, 3, 95, 6, 39, 5, 55, 8, 36, 4, 23, 0, 62
  };
  const int q0079[] = {
    9, 9, // Number of jobs and machines
    0, 40, 2, 10, 4, 76, 6, 93, 1, 77, 3, 17, 5, 16, 8, 11, 7, 90, 
    2, 55, 8, 62, 1, 48, 4, 80, 7, 36, 0, 73, 3,  3, 6, 80, 5, 97, 
    3, 72, 1,  3, 6, 35, 4,  1, 2, 54, 7, 47, 5, 23, 8, 59, 0, 27, 
    5, 98, 3, 41, 2, 71, 8, 11, 6, 48, 0, 78, 4, 73, 1, 48, 7, 33, 
    4, 68, 7, 89, 5, 12, 0, 41, 6, 27, 8, 61, 1, 72, 2, 21, 3, 35, 
    7, 84, 8, 66, 6, 26, 3, 44, 2, 44, 1, 28, 5, 51, 4, 14, 0, 25, 
    8, 94, 1, 69, 3, 27, 0,  8, 4, 70, 6, 57, 5, 59, 2, 94, 7, 32, 
    2, 87, 3, 58, 5, 33, 4, 86, 6, 61, 7, 96, 8, 48, 0, 54, 1, 83, 
    2, 94, 4,  4, 5, 36, 6, 41, 3, 36, 1, 48, 7, 36, 8, 87, 0, 88
  };
  const int q0080[] = {
    9, 9, // Number of jobs and machines
    2, 44, 3, 20, 4, 86, 7, 89, 1,  4, 8, 72, 5, 69, 0, 78, 6, 79, 
    0, 16, 7, 69, 3, 42, 2, 86, 1, 42, 5, 43, 8, 48, 4, 74, 6, 74, 
    4, 19, 3, 16, 2, 62, 8, 72, 1, 45, 6, 52, 7, 88, 0, 45, 5, 88, 
    5, 21, 6, 60, 7, 59, 8, 89, 3,  8, 4,  9, 1, 86, 0, 87, 2, 16, 
    6, 43, 7, 72, 1, 36, 4, 60, 8,  4, 3, 57, 0, 73, 2, 56, 5, 13, 
    2, 88, 7, 85, 0, 73, 4, 21, 6, 95, 5, 10, 8, 42, 1, 26, 3, 22, 
    2, 39, 6, 63, 5, 13, 0, 95, 4, 79, 7,  7, 8, 72, 1, 64, 3, 44, 
    2, 44, 7,  8, 1, 99, 5, 71, 8, 23, 6, 61, 0, 32, 3, 28, 4, 90, 
    3, 60, 1, 66, 4,  2, 5, 60, 8, 53, 2, 26, 7, 81, 6, 58, 0, 83
  };
  const int q0081[] = {
    9, 9, // Number of jobs and machines
    8, 85, 3, 13, 4, 17, 5,  9, 2, 26, 7, 11, 6, 42, 0, 66, 1, 47, 
    5, 13, 3, 91, 7, 97, 1, 89, 6, 77, 0, 68, 2, 64, 8, 11, 4, 96, 
    6,  4, 2, 84, 5, 44, 0,  7, 7, 47, 1, 62, 3, 47, 8, 49, 4, 39, 
    4, 29, 3, 64, 6, 68, 7, 42, 5, 68, 8, 60, 2, 94, 0, 85, 1, 24, 
    6, 20, 5, 38, 3, 59, 2, 76, 8,  8, 4, 30, 1, 19, 0, 73, 7, 72, 
    2, 78, 3, 64, 1, 52, 4, 16, 7, 99, 8, 17, 6, 40, 5, 76, 0, 94, 
    0,  1, 1, 79, 5, 45, 6, 66, 3, 93, 7, 97, 8, 47, 2, 62, 4, 62, 
    5, 33, 6, 41, 0,  4, 7, 89, 2, 91, 4, 76, 1, 73, 8, 14, 3, 63, 
    5, 41, 4, 53, 1,  4, 7, 18, 6, 31, 3, 77, 2, 98, 0, 71, 8, 12
  };
  const int q0082[] = {
    9, 9, // Number of jobs and machines
    4, 49, 6,  7, 0, 75, 5, 70, 2, 43, 3,  2, 7, 25, 1, 62, 8, 36, 
    5,  5, 7, 55, 3, 13, 1, 37, 0, 73, 4, 29, 6, 70, 2, 32, 8, 63, 
    5, 80, 2,  2, 4, 84, 1,  7, 6, 23, 7, 81, 8,  9, 0, 20, 3,  4, 
    2, 88, 3, 75, 1, 93, 7, 76, 6, 21, 0, 88, 5, 56, 8, 91, 4,  1, 
    5, 62, 6, 23, 7,  2, 0, 54, 2, 80, 3, 25, 1, 50, 4, 19, 8, 16, 
    7, 34, 6, 32, 2, 18, 0, 55, 5, 79, 4, 77, 8, 54, 1, 61, 3, 68, 
    5, 47, 0, 31, 6, 29, 4, 96, 7, 65, 3, 98, 1, 65, 8, 50, 2, 64, 
    1, 91, 5, 43, 2, 45, 6, 10, 0, 21, 3, 92, 7, 46, 4, 12, 8, 59, 
    4, 16, 8, 64, 6, 69, 1, 80, 7,  9, 0, 29, 3,  2, 5, 78, 2, 57
  };
  const int q0083[] = {
    9, 9, // Number of jobs and machines
    8, 14, 3, 29, 1, 45, 7, 97, 2, 85, 4, 48, 5, 46, 6, 75, 0, 47, 
    6, 13, 7, 86, 4, 45, 5, 97, 1, 76, 0, 92, 8, 33, 2, 59, 3, 65, 
    8, 86, 7, 55, 4, 23, 5, 77, 2, 43, 1, 10, 3, 66, 0, 40, 6, 95, 
    8, 69, 2, 36, 0, 70, 5, 62, 4, 30, 1, 41, 3, 19, 6, 20, 7, 17, 
    5, 19, 6, 88, 8, 74, 4, 12, 0, 13, 1, 59, 2, 15, 3, 44, 7, 79, 
    2, 86, 1, 46, 6, 92, 0, 36, 3, 27, 7, 40, 8, 43, 5, 84, 4,  9, 
    3, 52, 5, 18, 1, 79, 4, 60, 8, 38, 7,  8, 6, 64, 2, 96, 0, 18, 
    0, 97, 2, 53, 3, 16, 5, 29, 4, 69, 7, 57, 6, 88, 1, 48, 8, 38, 
    7, 30, 6,  7, 5, 71, 0, 29, 3, 77, 8, 87, 1, 20, 4, 69, 2, 66
  };
  const int q0084[] = {
    9, 9, // Number of jobs and machines
    0, 93, 6, 29, 2, 68, 5, 88, 8,  9, 4, 78, 7, 39, 1, 20, 3, 74, 
    3, 68, 1, 82, 5, 95, 0, 11, 8, 60, 4, 70, 6, 68, 7, 80, 2, 43, 
    7, 30, 8, 28, 3,  3, 2, 33, 5, 48, 6,  7, 1, 79, 0, 71, 4, 14, 
    3, 92, 4, 36, 7, 16, 2, 61, 5, 40, 8,  1, 0, 55, 1,  3, 6, 17, 
    4, 22, 3, 67, 0, 24, 5, 44, 8, 70, 6, 27, 7, 23, 2, 68, 1, 93, 
    6, 36, 4, 86, 1, 79, 3,  6, 2, 75, 5, 27, 8, 87, 0, 92, 7, 69, 
    6, 79, 8, 71, 3, 41, 7, 77, 5, 83, 1, 39, 2, 77, 4, 28, 0, 33, 
    5, 61, 2, 17, 3, 96, 1, 89, 6,  7, 7, 10, 8,  3, 4, 71, 0, 83, 
    3, 98, 0, 72, 4, 62, 7, 64, 1,  2, 2, 11, 6, 14, 5, 86, 8,  1
  };
  const int q0085[] = {
    9, 9, // Number of jobs and machines
    2,  9, 3, 22, 1, 90, 5, 71, 8, 39, 6,  4, 4, 45, 0, 60, 7, 32, 
    7, 91, 8, 63, 0, 74, 4,  2, 5, 92, 1, 22, 3, 45, 6,  3, 2, 85, 
    6, 43, 5, 75, 7, 88, 4,  2, 1, 91, 0, 21, 2, 59, 3, 43, 8, 22, 
    6, 76, 2, 35, 5, 80, 0, 46, 3,  7, 1, 46, 7, 12, 4, 96, 8, 86, 
    3, 57, 7, 14, 0, 73, 8, 19, 2, 99, 1, 19, 4, 98, 6, 15, 5, 17, 
    7,  4, 2, 92, 4,  8, 6, 86, 3, 15, 8, 68, 5, 84, 0, 53, 1, 21, 
    3,  2, 1, 58, 6, 17, 7, 33, 8, 21, 0, 28, 2, 52, 5, 62, 4, 42, 
    0, 76, 3, 60, 6, 79, 4, 47, 7, 79, 1,  5, 8, 73, 5, 28, 2, 71, 
    8, 45, 1, 93, 5, 80, 0,  3, 4,  2, 2, 46, 7,  4, 6, 79, 3, 82
  };
  const int q0086[] = {
    9, 9, // Number of jobs and machines
    0, 66, 5, 42, 8, 99, 1, 18, 7, 69, 2, 57, 4,  9, 3,  8, 6, 82, 
    5,  2, 7, 14, 2,  3, 1, 85, 4,  7, 0, 73, 6, 13, 8, 93, 3, 38, 
    1,  1, 8,  1, 4,  2, 2,  3, 6, 92, 3, 86, 0, 29, 5, 34, 7, 41, 
    8, 71, 6, 86, 7, 52, 3, 57, 2,  7, 1,  6, 5,  7, 4, 98, 0, 45, 
    6, 65, 3, 93, 2, 71, 8, 32, 7, 94, 0, 82, 1, 45, 5, 79, 4, 13, 
    8, 45, 5, 77, 1, 13, 4, 77, 6, 39, 0, 37, 7, 84, 2, 45, 3, 79, 
    4, 79, 3, 71, 0, 52, 6, 71, 8, 94, 2,  7, 7, 77, 5, 76, 1, 74, 
    0,  5, 8, 56, 2, 96, 7, 14, 4, 94, 6,  1, 5, 68, 3, 18, 1, 35, 
    4, 42, 5, 91, 1, 65, 6, 85, 7, 49, 8, 66, 2, 86, 3, 37, 0, 58
  };
  const int q0087[] = {
    9, 9, // Number of jobs and machines
    3, 71, 0, 50, 8, 17, 6, 21, 1, 96, 5, 95, 7, 58, 4, 26, 2, 72, 
    0, 40, 7, 47, 8, 75, 1, 86, 5, 65, 2, 69, 3, 21, 4, 83, 6, 38, 
    4, 36, 5, 40, 0, 29, 8, 12, 2, 16, 6, 91, 1, 97, 3, 64, 7,  6, 
    5, 11, 7, 15, 6, 26, 0, 94, 2, 25, 8, 34, 1, 62, 4, 48, 3, 68, 
    6, 82, 1, 35, 5, 22, 7, 62, 0, 72, 2, 14, 3, 98, 4,  9, 8, 43, 
    2, 40, 1, 52, 8, 23, 5, 58, 6, 15, 0, 13, 7, 99, 4, 52, 3, 36, 
    0, 80, 5, 79, 7, 82, 3, 20, 4, 75, 2,  9, 6, 73, 8, 36, 1, 61, 
    0, 72, 2,  5, 7, 47, 4, 11, 5, 78, 3, 54, 8,  4, 6, 20, 1, 90, 
    5, 98, 0, 99, 4, 97, 2, 89, 8, 71, 1,  4, 3, 66, 6, 67, 7, 35
  };
  const int q0088[] = {
    9, 9, // Number of jobs and machines
    3,  1, 0, 98, 5, 36, 4, 38, 1, 70, 6, 88, 2, 96, 7, 65, 8, 38, 
    4, 39, 0, 96, 2, 15, 5, 96, 6, 90, 7, 54, 1, 30, 8, 57, 3,  2, 
    6, 46, 5, 81, 8,  5, 0, 99, 1, 68, 4, 69, 2, 36, 7,  7, 3, 75, 
    2, 90, 1, 96, 6, 42, 8, 63, 0, 63, 5,  7, 4, 42, 7, 94, 3, 55, 
    2, 51, 8, 74, 4, 42, 5, 64, 7, 15, 3, 23, 6, 44, 1, 28, 0, 96, 
    1, 50, 4, 95, 6, 36, 8, 17, 5, 89, 3,  5, 0, 84, 7, 95, 2, 45, 
    8, 36, 2, 63, 7, 28, 5,  8, 6, 88, 1, 64, 3, 47, 0, 49, 4, 49, 
    6, 46, 4, 88, 0,  5, 5, 40, 7, 96, 1, 46, 3, 25, 2, 60, 8, 76, 
    4, 10, 6, 17, 5, 40, 0, 49, 2, 58, 7, 49, 1, 18, 8, 75, 3, 13
  };
  const int q0089[] = {
    9, 9, // Number of jobs and machines
    2, 56, 0, 44, 6, 93, 8, 80, 5, 86, 1,  4, 4,  6, 7, 64, 3, 86, 
    0, 31, 7, 45, 5, 27, 4, 20, 6, 76, 2, 43, 1, 46, 3, 82, 8, 24, 
    3, 47, 1, 16, 0, 75, 6, 60, 7, 69, 2, 82, 8,  8, 4, 87, 5, 78, 
    3, 12, 6, 92, 7, 36, 4,  7, 0, 80, 1, 22, 8, 64, 2, 25, 5, 53, 
    7, 95, 5, 32, 0, 55, 6, 43, 1, 63, 4, 97, 2, 12, 3, 40, 8, 58, 
    0, 10, 3,  5, 8, 77, 4, 48, 2, 73, 6, 77, 7, 49, 1,  2, 5, 13, 
    8, 89, 0, 93, 2, 90, 5, 25, 4, 73, 7, 72, 6, 69, 1, 68, 3, 16, 
    2, 22, 4, 82, 7, 84, 0, 23, 5, 25, 8,  4, 3,  4, 1, 87, 6, 57, 
    7,  5, 5, 28, 4, 45, 2,  7, 6, 21, 1, 33, 0, 71, 3, 52, 8,  8
  };
  const int q0090[] = {
    9, 9, // Number of jobs and machines
    2, 30, 6, 56, 0, 47, 4, 66, 1, 81, 5, 79, 7, 95, 3, 78, 8, 22, 
    7, 91, 5, 38, 1, 22, 0, 59, 4, 85, 2, 16, 3, 82, 8, 48, 6, 96, 
    2, 45, 5, 23, 6, 79, 4, 92, 3, 76, 0,  1, 8, 83, 1, 56, 7, 93, 
    4, 65, 3, 76, 8, 62, 2, 48, 5, 67, 1, 75, 0, 72, 6, 74, 7, 35, 
    4, 31, 1, 46, 7, 87, 2, 76, 6, 86, 5, 89, 8,  6, 0, 25, 3, 79, 
    2, 55, 1, 49, 6, 60, 0, 67, 3, 51, 7, 51, 8, 77, 4, 37, 5, 69, 
    8, 16, 1, 42, 5, 97, 6, 58, 3, 19, 2, 53, 0, 74, 4, 51, 7, 89, 
    7, 38, 6, 97, 4, 21, 3, 77, 1, 26, 2, 53, 0, 85, 5, 14, 8, 58, 
    8, 85, 5, 58, 3, 79, 7, 50, 6, 32, 0, 22, 2, 19, 1, 55, 4, 12
  };
  const int q0091[] = {
    9, 9, // Number of jobs and machines
    8, 70, 3, 27, 5, 78, 7, 78, 4, 78, 6, 26, 2, 19, 1, 39, 0, 74, 
    3, 89, 7, 90, 2, 11, 6, 76, 5,  8, 0, 98, 1,  9, 8, 80, 4, 46, 
    0, 45, 5, 89, 3, 24, 1, 40, 2, 54, 4, 41, 8, 24, 7, 49, 6, 27, 
    5, 93, 2,  4, 7, 34, 3, 91, 1, 33, 8, 32, 6, 97, 4, 23, 0, 48, 
    0,  4, 7, 82, 5, 66, 4, 22, 6, 37, 1, 57, 2, 88, 3, 34, 8, 62, 
    8, 13, 2, 25, 7, 47, 3, 17, 4, 33, 5, 55, 1, 80, 6,  8, 0,  7, 
    1, 74, 5, 90, 8, 49, 4, 24, 2, 29, 0, 59, 6, 44, 3, 39, 7, 99, 
    1, 68, 8, 73, 5, 32, 2, 89, 3, 45, 7,  6, 0, 30, 6, 18, 4, 21, 
    2, 98, 4, 75, 0, 74, 1, 63, 7, 28, 5, 40, 3, 20, 8, 70, 6, 83
  };
  const int q0092[] = {
    9, 9, // Number of jobs and machines
    4, 62, 7, 81, 3, 91, 0, 89, 2, 65, 6, 37, 1,  2, 8, 11, 5, 94, 
    6, 93, 3, 30, 7, 25, 8,  6, 1, 25, 0, 43, 2, 19, 4, 88, 5,  5, 
    0, 25, 3, 87, 4, 21, 2, 45, 5, 16, 7, 27, 8, 56, 6, 87, 1, 87, 
    5, 81, 6,  3, 8, 31, 7, 96, 1,  3, 3, 62, 4, 13, 0, 70, 2, 30, 
    2,  3, 3,  3, 5,  1, 0, 79, 8, 90, 4, 19, 7, 49, 6, 27, 1, 42, 
    2, 60, 0, 29, 1, 14, 5,  8, 6,  4, 4, 28, 7, 69, 3,  9, 8, 14, 
    0, 60, 8, 23, 6, 74, 5, 21, 3, 70, 4, 17, 2,  4, 7, 90, 1,  4, 
    6, 93, 2, 89, 3, 25, 7, 21, 0, 13, 8, 27, 5, 68, 4, 24, 1, 10, 
    4, 25, 3, 79, 2, 13, 1, 72, 5, 97, 8, 49, 6, 39, 7, 90, 0, 73
  };
  const int q0093[] = {
    9, 9, // Number of jobs and machines
    2, 64, 0, 79, 7, 58, 8, 16, 6, 35, 5, 75, 4, 37, 3, 45, 1, 12, 
    0,  2, 3, 88, 6, 82, 2, 74, 1, 33, 5, 87, 7, 70, 8,  2, 4,  7, 
    0, 21, 6,  4, 7, 49, 4, 23, 5, 49, 3, 72, 2, 95, 1, 33, 8, 21, 
    8, 88, 4, 75, 6, 80, 3, 71, 1, 55, 7, 96, 0, 41, 5,  7, 2, 46, 
    3, 82, 8, 86, 6, 22, 0, 37, 4, 88, 7, 81, 5, 21, 2, 67, 1, 26, 
    7, 66, 6,  5, 2, 27, 1, 69, 0,  2, 3, 80, 8, 37, 5,  1, 4, 77, 
    7,  6, 3,  3, 2, 36, 4, 10, 5, 64, 6, 54, 8, 21, 1, 92, 0, 69, 
    7, 63, 1, 17, 5, 57, 3, 42, 2, 76, 4, 51, 0, 20, 8, 75, 6,  9, 
    8, 64, 5, 88, 0, 82, 3, 23, 1,  5, 6, 71, 7, 13, 4, 49, 2, 97
  };
  const int q0094[] = {
    9, 9, // Number of jobs and machines
    6, 98, 8, 42, 5,  4, 1, 21, 2, 64, 0, 37, 4, 11, 3, 11, 7, 61, 
    0, 55, 7, 41, 6, 54, 3, 92, 4, 37, 5, 48, 1, 82, 8, 11, 2,  3, 
    8, 22, 0, 95, 2, 24, 4, 55, 3, 17, 6, 14, 1, 78, 5, 68, 7, 87, 
    5, 57, 4,  3, 7, 14, 0, 98, 8, 78, 2, 87, 1, 12, 3, 43, 6, 82, 
    3, 62, 2, 84, 4, 28, 6, 56, 1, 88, 0, 85, 5, 55, 8, 62, 7, 38, 
    7, 62, 0, 43, 4, 49, 5, 58, 3, 99, 2, 85, 1, 63, 6, 69, 8, 32, 
    6, 26, 5, 51, 7, 81, 1, 86, 8, 89, 0, 28, 3, 89, 2, 27, 4, 91, 
    3, 45, 7, 30, 2, 94, 5, 81, 6,  7, 4, 25, 1,  8, 8, 18, 0, 10, 
    0, 18, 2, 94, 5, 26, 7, 74, 4,  7, 3, 44, 8, 56, 1, 34, 6,  8
  };
  const int q0095[] = {
    9, 9, // Number of jobs and machines
    8, 72, 3, 69, 6, 44, 1, 53, 2, 50, 5, 86, 0, 19, 7, 83, 4, 23, 
    8, 90, 4,  7, 3, 86, 0, 88, 1, 81, 5, 98, 6, 31, 2, 82, 7, 14, 
    3, 57, 5, 82, 6, 53, 7, 94, 8, 26, 1, 58, 0, 86, 2, 72, 4, 25, 
    1,  5, 5, 25, 2,  3, 4, 89, 7, 98, 3, 85, 0, 18, 8, 90, 6, 71, 
    0,  8, 6, 33, 4, 55, 2, 60, 1, 55, 5, 90, 7, 64, 3, 26, 8, 70, 
    6, 55, 5, 86, 4, 37, 0, 38, 7, 15, 8, 31, 3, 51, 1, 14, 2,  9, 
    2, 39, 5, 86, 8, 99, 6, 34, 1, 57, 3, 56, 0, 63, 4, 11, 7, 83, 
    3, 64, 0, 78, 8, 73, 6, 63, 4, 50, 5, 37, 1, 13, 7, 59, 2, 44, 
    2, 84, 5, 73, 0, 64, 3, 50, 4, 61, 6, 44, 1, 73, 7, 66, 8, 68
  };
  const int q0096[] = {
    9, 9, // Number of jobs and machines
    7, 73, 8, 59, 0, 85, 6, 97, 1, 78, 5, 18, 2, 94, 4, 35, 3, 74, 
    4, 28, 8, 39, 3, 66, 5, 88, 7, 52, 1, 47, 2, 24, 0, 98, 6, 19, 
    5, 13, 7, 44, 4,  4, 2, 37, 1, 23, 6, 75, 3, 79, 0, 18, 8, 39, 
    7, 24, 3, 96, 0, 65, 1, 58, 6, 96, 2, 95, 8, 81, 4, 21, 5, 88, 
    7, 97, 1,  3, 5, 99, 3, 71, 2, 91, 4, 82, 6, 16, 8, 22, 0,  8, 
    4,  6, 8, 95, 0, 30, 1, 24, 7, 95, 5, 87, 6, 92, 3, 68, 2, 72, 
    6, 55, 1, 14, 0, 30, 4, 66, 7, 59, 5, 11, 2,  6, 3,  1, 8, 92, 
    7, 22, 5, 77, 8, 53, 3, 73, 0, 81, 4, 83, 6,  1, 1, 49, 2, 30, 
    2, 78, 4, 79, 8, 48, 1, 12, 7,  4, 0, 47, 5, 94, 6, 53, 3, 43
  };
  const int q0097[] = {
    9, 9, // Number of jobs and machines
    4, 23, 8, 10, 7, 79, 0, 78, 1, 40, 5,  1, 2, 17, 6, 20, 3, 52, 
    4,  1, 6, 14, 2, 60, 1, 25, 0, 25, 3,  8, 7, 55, 8, 66, 5, 29, 
    1, 14, 2, 40, 8, 13, 0, 69, 7, 80, 5, 58, 4, 34, 3, 40, 6, 66, 
    8, 99, 5, 15, 4, 84, 1, 43, 0, 22, 6, 69, 7, 21, 2, 42, 3, 89, 
    2, 89, 5, 85, 7, 74, 4, 70, 3, 13, 8, 53, 0,  2, 1, 98, 6, 74, 
    3, 51, 1, 29, 4, 20, 0, 35, 5, 90, 2, 52, 7, 30, 6, 46, 8, 20, 
    3, 72, 1, 47, 4, 75, 6, 81, 5, 24, 2, 56, 0, 72, 7,  1, 8, 66, 
    3, 79, 8, 71, 4, 30, 7, 48, 6, 57, 5,  6, 0, 58, 1, 16, 2, 77, 
    8, 53, 6, 93, 7, 66, 0, 88, 4, 11, 1, 80, 2, 27, 5, 30, 3, 76
  };
  const int q0098[] = {
    9, 9, // Number of jobs and machines
    7, 10, 6, 10, 8, 88, 0, 62, 3, 31, 1, 22, 5, 58, 2, 82, 4, 12, 
    5, 79, 3, 31, 7, 60, 4, 96, 2, 39, 0, 51, 6, 41, 1, 93, 8, 62, 
    4, 85, 3,  4, 8, 96, 6,  9, 0, 69, 1, 51, 7, 83, 5, 50, 2, 88, 
    8, 99, 4, 87, 0, 64, 6, 19, 2, 14, 1, 30, 3, 56, 5, 96, 7,  5, 
    0, 75, 6, 76, 3, 95, 8, 61, 2,  3, 5, 78, 4, 74, 1, 35, 7, 85, 
    4, 70, 6,  4, 7, 12, 5, 51, 3, 62, 1, 39, 8, 40, 0,  6, 2, 38, 
    5, 38, 1, 39, 0,  5, 8, 25, 3, 75, 7, 45, 4, 42, 6, 58, 2, 33, 
    2, 23, 0,  2, 7, 17, 3, 87, 6, 64, 5, 59, 4,  7, 1,  4, 8,  5, 
    2,  7, 3, 75, 5,  7, 1, 87, 4,  1, 0, 48, 8, 18, 7,  9, 6, 44
  };
  const int q0099[] = {
    9, 9, // Number of jobs and machines
    3, 98, 0, 77, 6, 99, 2, 71, 7, 93, 1, 98, 4, 18, 8, 42, 5, 47, 
    6, 19, 4, 98, 8, 53, 7, 75, 0, 14, 5, 18, 1, 62, 2,  5, 3,  9, 
    3,  8, 5, 77, 6, 10, 2, 22, 4, 64, 0, 37, 1, 61, 7, 38, 8, 61, 
    8, 27, 2,  3, 6, 86, 7,  5, 4,  5, 3, 52, 1, 27, 0, 61, 5, 83, 
    1, 53, 0, 22, 6, 56, 5, 94, 3, 98, 4, 24, 8, 15, 2, 44, 7, 54, 
    8,  1, 4,  3, 1, 11, 2, 37, 3, 95, 6, 15, 0, 75, 5, 25, 7, 17, 
    8,  1, 4, 40, 0, 35, 6, 30, 7,  2, 5, 64, 2, 87, 3, 95, 1, 77, 
    0, 39, 3, 23, 2,  7, 4, 86, 8, 51, 1, 34, 6, 13, 7,  3, 5, 87, 
    4, 37, 7, 34, 2, 89, 8, 31, 6, 82, 5, 71, 3, 98, 1, 83, 0, 37
  };
  const int q0100[] = {
    9, 9, // Number of jobs and machines
    4, 52, 6, 67, 3, 59, 8, 57, 2, 66, 0, 34, 7, 41, 1, 24, 5, 42, 
    7, 61, 0, 88, 4, 36, 5, 32, 8, 17, 2, 95, 6, 72, 3, 90, 1, 28, 
    1, 42, 5, 67, 4, 12, 3, 56, 0,  3, 2, 98, 6, 70, 8, 23, 7, 49, 
    6, 31, 3, 17, 2, 63, 4, 35, 0, 20, 8, 17, 1, 94, 7, 81, 5,  9, 
    6, 46, 2, 22, 1, 92, 0, 17, 3, 58, 5, 89, 8, 41, 7, 26, 4, 74, 
    5, 32, 8, 23, 6,  9, 7, 16, 1, 29, 2, 65, 3, 88, 4, 59, 0, 70, 
    7, 55, 6, 86, 8,  8, 2, 61, 5, 42, 1, 70, 4, 68, 0, 90, 3, 79, 
    2,  2, 7, 41, 4, 49, 1, 82, 8, 98, 6, 11, 0, 96, 5,  2, 3, 91, 
    3,  8, 7, 52, 8, 92, 4, 94, 6, 57, 1, 80, 0, 81, 2, 30, 5, 71
  };
  const int q0101[] = {
    9, 9, // Number of jobs and machines
    4, 91, 8, 94, 0, 86, 6, 89, 3, 33, 7, 80, 1, 40, 5, 24, 2, 40, 
    7, 99, 2, 70, 3, 87, 5, 92, 8, 59, 6,  9, 0, 15, 4, 42, 1, 29, 
    2, 15, 0, 11, 3, 73, 6, 40, 8, 65, 4, 34, 7, 83, 1, 65, 5, 89, 
    8, 97, 1, 11, 2, 94, 0, 52, 7, 27, 5, 32, 3, 24, 6,  2, 4, 66, 
    6, 60, 5, 91, 2,  1, 4, 36, 3, 35, 8, 61, 7, 10, 0, 70, 1, 49, 
    2, 15, 5, 37, 4, 64, 3, 11, 0, 78, 6,  2, 7, 90, 8, 96, 1, 12, 
    2, 18, 3, 11, 7, 13, 8, 95, 5, 53, 1, 88, 6, 94, 0, 43, 4, 98, 
    2, 70, 1, 60, 7, 28, 6, 22, 8, 22, 3, 22, 5, 51, 0, 77, 4, 62, 
    8, 75, 2, 91, 3, 54, 7, 15, 4,  8, 1, 46, 5, 65, 0, 62, 6, 39
  };
  const int q0102[] = {
    9, 9, // Number of jobs and machines
    8, 31, 2,  1, 7, 28, 1, 65, 6, 72, 4, 47, 5, 64, 3, 48, 0, 18, 
    0,  9, 7, 44, 5, 12, 6, 19, 8, 64, 2, 64, 1, 19, 4, 49, 3, 82, 
    2, 95, 6, 37, 5, 58, 7, 11, 0, 25, 1, 20, 4, 48, 3, 96, 8, 30, 
    5, 43, 6, 98, 3, 73, 8, 41, 7, 41, 4, 84, 0, 54, 2, 86, 1, 18, 
    2, 96, 4, 79, 8, 66, 0, 92, 6, 20, 5,  7, 7, 80, 1, 77, 3, 32, 
    3, 73, 5, 64, 8, 90, 7, 11, 2, 44, 4,  4, 0,  5, 6, 98, 1, 38, 
    1, 43, 8, 78, 4, 92, 7, 96, 3, 94, 6, 82, 0, 77, 5, 75, 2,  8, 
    0, 90, 3, 43, 8, 23, 7, 62, 2,  4, 5, 51, 6, 93, 4, 70, 1, 81, 
    7, 21, 1, 38, 6, 19, 2, 85, 5, 79, 8, 22, 3, 22, 4, 24, 0, 29
  };
  const int q0103[] = {
    9, 9, // Number of jobs and machines
    8, 47, 0, 86, 4, 59, 3,  6, 1, 78, 6, 37, 5, 34, 7,  4, 2, 71, 
    0, 36, 6, 14, 5, 65, 8, 80, 3, 17, 2, 91, 4, 58, 1, 83, 7, 30, 
    8, 44, 0, 60, 1, 73, 6, 83, 4,  1, 5, 11, 7, 19, 3, 86, 2,  3, 
    1, 77, 5,  4, 8, 72, 3, 81, 6,  5, 7, 54, 2, 76, 0, 64, 4, 44, 
    6, 63, 0, 41, 3, 25, 8, 39, 4, 87, 7, 91, 1, 11, 2, 59, 5, 78, 
    7, 15, 2, 52, 3,  6, 6,  5, 1, 42, 0, 53, 8, 95, 4, 31, 5, 66, 
    8, 95, 1,  1, 0, 80, 4, 84, 3, 91, 5, 37, 2, 23, 6, 53, 7, 40, 
    0, 62, 6, 49, 5, 43, 2, 71, 3, 62, 8, 30, 1, 13, 4, 62, 7,  4, 
    6, 53, 5, 91, 8, 88, 7,  5, 3, 88, 1, 31, 0, 59, 2, 22, 4, 19
  };
  const int q0104[] = {
    9, 9, // Number of jobs and machines
    1, 56, 5, 64, 2, 95, 7, 73, 3, 51, 8, 39, 4, 57, 6, 21, 0, 68, 
    2, 88, 6, 54, 0, 33, 8,  1, 4, 53, 5, 78, 3, 36, 1, 80, 7, 16, 
    0, 51, 3, 74, 4, 98, 8, 61, 7, 40, 1, 22, 5, 29, 2, 35, 6, 97, 
    5, 27, 1, 21, 4, 64, 0, 23, 2, 53, 6, 47, 7,  8, 3,  9, 8, 32, 
    4, 49, 1, 49, 0, 29, 3, 42, 8, 12, 5, 25, 6, 49, 2, 67, 7, 83, 
    1, 91, 7, 75, 4, 57, 5, 23, 6,  2, 0, 86, 2, 54, 8, 57, 3, 84, 
    0,  4, 2, 47, 3,  4, 1, 46, 6, 99, 5, 96, 7,  8, 8, 23, 4, 56, 
    2,  9, 5,  2, 0, 58, 8, 67, 3,  2, 6, 12, 7,  8, 1, 51, 4, 38, 
    0, 81, 1, 11, 8, 55, 5, 60, 6, 26, 2, 77, 4, 92, 7, 66, 3, 44
  };
  const int q0105[] = {
    9, 9, // Number of jobs and machines
    6, 85, 2,  7, 0,  2, 3,  5, 1, 44, 8, 43, 4, 37, 7, 59, 5, 10, 
    8, 90, 0,  7, 7, 30, 5, 91, 1, 53, 6, 19, 2, 66, 3, 84, 4, 36, 
    5,  3, 7, 90, 3, 17, 4, 77, 1, 40, 6, 13, 8, 92, 2, 47, 0, 17, 
    5, 47, 8, 35, 6, 85, 4, 19, 0, 86, 2,  1, 3,  4, 1, 14, 7, 85, 
    7, 51, 6, 18, 4,  3, 0, 46, 3, 24, 1, 79, 8, 98, 2, 42, 5, 22, 
    7, 62, 1, 36, 3, 91, 6, 66, 8, 79, 5, 12, 4, 23, 2, 64, 0, 69, 
    2, 70, 4, 52, 3, 55, 1,  6, 7,  5, 5, 43, 0,  7, 6, 42, 8, 97, 
    7, 48, 3, 48, 2, 22, 4, 35, 0, 61, 1,  3, 5, 77, 8, 10, 6, 92, 
    3, 42, 5,  7, 0, 15, 7,  6, 4, 54, 6, 29, 2, 38, 8, 27, 1, 29
  };
  const int q0106[] = {
    9, 9, // Number of jobs and machines
    3, 11, 7, 62, 2, 69, 4, 54, 8, 70, 5, 32, 6, 54, 0, 93, 1, 76, 
    1, 21, 2, 94, 0, 69, 5, 94, 3, 21, 7, 31, 6, 90, 4, 62, 8, 95, 
    3, 14, 4, 92, 5, 23, 7,  8, 8, 58, 1, 91, 6, 41, 2, 63, 0, 64, 
    0, 74, 8, 93, 3, 96, 7, 39, 2,  5, 4, 19, 1, 41, 5, 43, 6, 61, 
    4, 65, 0, 39, 5, 42, 8, 52, 6, 49, 1,  6, 7, 81, 2, 92, 3, 26, 
    8, 77, 3, 13, 7, 32, 5, 67, 4, 24, 2, 51, 0,  6, 6, 77, 1, 20, 
    5, 71, 1, 42, 6, 47, 8, 78, 3, 37, 0, 84, 7, 79, 2, 40, 4, 10, 
    4, 94, 3, 13, 0, 76, 7, 47, 8, 23, 1, 87, 6, 87, 2, 93, 5, 46, 
    7, 28, 5, 87, 2, 51, 1, 97, 6, 60, 3, 28, 0, 86, 4, 20, 8, 32
  };
  const int q0107[] = {
    9, 9, // Number of jobs and machines
    6, 12, 8,  4, 3, 46, 7, 13, 5, 46, 2, 73, 1, 19, 4,  4, 0, 40, 
    3, 73, 0, 89, 4, 22, 5, 90, 7,  7, 8, 91, 1, 82, 6, 66, 2, 44, 
    6, 21, 1, 58, 7, 76, 0, 93, 2, 17, 3, 87, 5, 14, 8, 48, 4, 18, 
    2, 37, 6, 67, 8, 66, 4, 18, 7, 46, 5, 66, 3, 19, 1, 22, 0, 41, 
    5, 23, 2, 88, 0, 26, 1, 52, 7, 65, 3, 42, 4, 24, 6, 96, 8, 34, 
    4, 32, 1, 23, 8, 81, 0, 19, 2, 59, 7, 97, 3, 47, 5, 79, 6, 20, 
    5, 80, 6, 28, 3, 11, 2, 12, 1,  6, 7, 55, 0, 26, 8, 58, 4, 39, 
    2, 53, 7, 88, 5, 89, 1,  5, 3,  1, 8, 18, 6, 68, 0, 60, 4, 40, 
    5,  7, 4, 88, 3, 23, 0, 52, 8, 98, 1, 28, 7, 89, 6, 37, 2, 63
  };
  const int q0108[] = {
    9, 9, // Number of jobs and machines
    6, 24, 8, 54, 3, 89, 2, 12, 4, 99, 1, 30, 5, 88, 7, 37, 0, 98, 
    7, 18, 4, 45, 0, 87, 3,  9, 2, 44, 1, 28, 8,  4, 6, 25, 5, 71, 
    4,  3, 8, 47, 1, 75, 0, 97, 3, 11, 6, 42, 7, 55, 5, 37, 2,  4, 
    6, 45, 4, 38, 5, 36, 0, 85, 7, 83, 3, 16, 8, 29, 1,  7, 2, 71, 
    0, 92, 2, 86, 7, 98, 3, 56, 4, 52, 6, 81, 5, 19, 1, 50, 8, 20, 
    4, 22, 0, 31, 5, 36, 3, 51, 6, 27, 7, 36, 2, 90, 8, 13, 1, 42, 
    2, 51, 1,  1, 7, 60, 6,  5, 4, 59, 8, 95, 0, 84, 5,  7, 3, 82, 
    1, 45, 0, 46, 8, 75, 7, 73, 3, 56, 2, 97, 6,  7, 5, 63, 4, 89, 
    6,  5, 0, 42, 4, 65, 3, 74, 2, 29, 1, 78, 7, 34, 5, 90, 8, 96
  };
  const int q0109[] = {
    9, 9, // Number of jobs and machines
    7, 38, 0, 53, 6, 44, 5, 38, 8,  9, 1,  6, 3,  6, 2, 43, 4, 69, 
    1, 16, 8, 33, 4,  2, 2, 59, 0,  4, 3, 25, 5, 92, 7, 43, 6, 30, 
    3, 22, 5, 43, 2, 22, 4, 29, 1, 51, 6, 40, 8, 84, 0, 26, 7, 52, 
    4, 69, 1, 19, 5, 84, 8, 38, 7, 91, 2, 87, 6, 80, 0, 91, 3,  4, 
    0, 50, 3, 98, 8, 99, 1, 49, 2, 32, 4, 95, 6, 53, 7, 98, 5, 59, 
    5, 12, 6, 22, 8, 76, 4, 60, 2, 81, 3, 38, 1, 71, 0, 27, 7, 26, 
    6, 68, 7, 33, 4, 90, 5, 82, 2, 30, 1, 55, 3, 44, 0, 49, 8, 59, 
    3, 11, 5, 65, 7, 38, 6, 93, 1, 41, 8, 71, 0, 60, 4, 91, 2,  8, 
    8, 89, 3, 25, 7, 13, 6, 64, 1, 66, 2, 76, 5, 55, 4, 45, 0, 39
  };
  const int q0110[] = {
    9, 9, // Number of jobs and machines
    1, 70, 7,  9, 4, 52, 5, 92, 0, 90, 2, 59, 3, 90, 6, 46, 8, 37, 
    6, 74, 2, 56, 0, 64, 3, 34, 7, 21, 4, 52, 5, 53, 1, 60, 8,  3, 
    0, 39, 5, 12, 6, 28, 8, 65, 4, 80, 2, 61, 7, 14, 3,  9, 1, 37, 
    4, 73, 3, 29, 1, 63, 5, 52, 7, 50, 6, 74, 0, 38, 2,  5, 8, 13, 
    7, 62, 5, 88, 3, 63, 6, 66, 4, 46, 8, 98, 1, 84, 2, 20, 0, 83, 
    6,  8, 5, 83, 2, 21, 4, 25, 0, 12, 7, 99, 3, 98, 8, 86, 1, 54, 
    0, 56, 8, 79, 1, 87, 3, 64, 4,  4, 6, 98, 2, 92, 7, 25, 5, 79, 
    2, 36, 8, 91, 5, 74, 3, 93, 4,  7, 6, 86, 1, 81, 0, 28, 7,  7, 
    2, 39, 3, 85, 1, 86, 4, 10, 6,  8, 8, 17, 7,  7, 0, 39, 5, 32
  };
  const int q0111[] = {
    9, 9, // Number of jobs and machines
    2, 86, 4, 41, 7, 44, 8, 17, 6, 98, 1, 48, 5, 87, 0, 18, 3, 57, 
    7, 85, 2, 21, 0, 45, 8, 98, 6, 53, 4, 13, 3, 87, 5, 28, 1, 50, 
    5, 12, 6, 29, 2,  7, 1, 23, 3, 64, 0, 87, 4, 64, 8, 48, 7, 70, 
    4, 98, 6, 79, 2, 45, 3,  6, 0, 17, 1, 68, 8, 35, 5, 15, 7, 31, 
    5, 30, 4,  5, 0, 67, 7, 74, 1, 80, 8, 78, 2, 55, 6, 74, 3, 55, 
    1, 10, 3, 92, 2, 76, 5, 38, 0,  6, 6, 79, 4, 47, 8, 85, 7, 95, 
    5,  1, 6, 67, 8, 51, 7, 86, 0, 22, 4, 57, 2, 65, 1, 11, 3, 60, 
    8, 85, 4,  3, 5,  3, 2, 36, 3, 16, 7,  2, 1, 49, 6, 56, 0, 68, 
    3, 51, 2,  3, 6, 15, 8, 63, 4, 15, 7, 93, 1, 45, 0, 56, 5, 73
  };
  const int q0112[] = {
    9, 9, // Number of jobs and machines
    6, 34, 4, 65, 5, 16, 7,  1, 2, 18, 1, 56, 0, 55, 8, 50, 3, 71, 
    3, 51, 1, 69, 2, 93, 7, 84, 8, 61, 0, 95, 4, 85, 5, 87, 6, 51, 
    0, 54, 6, 87, 8, 30, 3, 50, 2, 23, 7, 87, 4, 78, 5, 44, 1, 61, 
    8, 59, 4, 10, 7, 18, 5, 35, 1, 66, 0, 49, 3,  6, 6, 53, 2, 34, 
    6, 66, 7, 92, 0, 34, 2, 94, 8, 27, 3, 66, 5, 66, 1, 37, 4, 47, 
    0, 19, 2, 12, 1, 61, 5,  4, 6, 18, 4, 11, 8, 95, 3, 42, 7, 77, 
    2, 86, 1, 85, 7, 27, 8, 74, 6, 60, 5, 88, 0, 65, 4, 60, 3, 98, 
    0, 20, 1, 23, 4, 17, 5, 86, 3, 76, 7, 80, 6, 10, 8, 17, 2, 28, 
    1, 20, 2, 91, 3, 24, 5, 98, 6, 36, 4, 83, 0, 89, 8, 84, 7, 38
  };
  const int q0113[] = {
    9, 9, // Number of jobs and machines
    4, 68, 1, 18, 0, 78, 3,  7, 7, 42, 2, 20, 5, 84, 6,  1, 8, 98, 
    0,  7, 5, 46, 6, 58, 3, 71, 7, 21, 4, 18, 8, 88, 1, 90, 2, 51, 
    8, 50, 2, 18, 7, 53, 4, 71, 5, 68, 0,  5, 1, 81, 3, 75, 6, 10, 
    5, 68, 4, 39, 1, 68, 0, 86, 2, 80, 7, 49, 6, 60, 3, 40, 8, 26, 
    8, 28, 7, 81, 5, 32, 6, 32, 4, 58, 1, 34, 2, 92, 0, 32, 3, 90, 
    2, 28, 4, 46, 6, 12, 5, 68, 1, 61, 3, 39, 8, 45, 7, 97, 0, 62, 
    0, 18, 7, 71, 8, 84, 5, 45, 6, 49, 1, 96, 3, 12, 2, 77, 4, 75, 
    4, 93, 0, 50, 2, 26, 5, 10, 6, 49, 1, 76, 7, 67, 3, 30, 8, 69, 
    8, 48, 6, 46, 7, 78, 2, 48, 0, 98, 5,  5, 3, 21, 4,  4, 1, 25
  };
  const int q0114[] = {
    9, 9, // Number of jobs and machines
    2, 16, 1, 19, 3, 63, 8, 23, 0, 96, 4, 82, 6, 35, 7, 39, 5, 28, 
    5,  9, 7, 80, 0,  3, 6, 81, 8, 83, 2, 80, 1, 76, 4, 59, 3, 41, 
    3, 46, 0, 81, 4, 89, 1, 10, 7, 89, 2, 63, 6, 66, 8, 55, 5, 83, 
    4, 69, 0, 83, 6,  9, 3, 13, 5, 48, 7, 98, 2, 75, 8, 48, 1, 47, 
    4, 70, 5, 15, 7, 84, 3, 23, 1, 69, 0, 41, 6, 37, 8, 63, 2,  8, 
    2,  5, 1, 61, 3, 54, 0, 50, 7, 95, 6, 50, 8, 71, 4, 57, 5, 50, 
    6, 81, 0, 45, 4, 30, 1, 64, 2, 13, 3, 31, 8, 42, 5, 70, 7, 96, 
    0, 30, 5, 60, 4, 37, 6, 87, 7, 95, 8, 40, 3, 92, 2, 59, 1, 18, 
    6,  5, 0, 74, 7, 92, 3, 99, 1, 30, 2, 42, 5,  5, 4, 19, 8, 26
  };
  const int q0115[] = {
    9, 9, // Number of jobs and machines
    3, 48, 6, 56, 4, 70, 7, 81, 2, 16, 5, 93, 8, 53, 0, 65, 1, 62, 
    7,  9, 2, 64, 6, 50, 5, 61, 0, 17, 1, 42, 8, 36, 4, 67, 3, 95, 
    7, 58, 8, 64, 1, 69, 3,  8, 4, 10, 6, 51, 5, 21, 2, 94, 0,  1, 
    2, 96, 4, 60, 1, 28, 6, 49, 7, 62, 3, 53, 0,  3, 8, 55, 5, 66, 
    4, 17, 2, 72, 5, 25, 1, 41, 8, 43, 7, 11, 0, 45, 3,  8, 6, 95, 
    5, 31, 4, 67, 3, 68, 2, 43, 8, 46, 7, 60, 0, 98, 1, 45, 6, 94, 
    1, 95, 4, 88, 6, 54, 7, 80, 2, 92, 8, 66, 5, 39, 0, 68, 3, 47, 
    3, 72, 4, 32, 6, 85, 7, 29, 2, 87, 0, 16, 1,  1, 5, 88, 8, 34, 
    3, 15, 5, 88, 7, 49, 4, 24, 6, 48, 8, 25, 0, 74, 2, 91, 1, 45
  };
  const int q0116[] = {
    9, 9, // Number of jobs and machines
    8,  3, 4, 48, 6, 25, 3,  2, 2, 25, 0, 54, 7, 46, 5, 81, 1, 47, 
    1, 50, 2, 91, 4, 94, 6, 98, 5, 42, 0, 18, 7, 84, 3, 44, 8, 50, 
    7, 36, 1, 94, 4,  7, 2, 70, 0, 83, 6, 83, 5, 33, 3, 70, 8, 97, 
    7, 74, 2, 55, 5, 44, 6, 22, 1, 72, 4, 56, 0, 68, 3, 62, 8, 36, 
    7, 11, 2,  6, 3,  2, 0, 29, 4, 56, 5, 20, 1, 57, 8, 22, 6,  8, 
    4, 63, 0, 93, 8, 48, 3, 14, 7, 42, 1,  5, 2, 98, 6, 28, 5, 26, 
    0, 19, 6, 77, 3, 68, 7, 44, 8, 73, 5, 58, 4, 12, 2, 28, 1, 37, 
    6, 62, 5,  7, 7, 94, 1, 79, 0, 49, 3, 99, 4, 36, 2, 67, 8, 32, 
    2, 20, 0, 28, 6, 30, 8, 58, 4,  5, 1, 88, 7, 70, 5,  3, 3, 75
  };
  const int q0117[] = {
    9, 9, // Number of jobs and machines
    5, 18, 3, 14, 4, 63, 2, 89, 6, 71, 7, 13, 1, 43, 0, 81, 8, 66, 
    0, 42, 3, 43, 2, 35, 7, 71, 4, 86, 8, 23, 6, 93, 5,  8, 1, 31, 
    7, 76, 4, 51, 0, 14, 1, 57, 3, 31, 6, 83, 5, 31, 8, 48, 2, 93, 
    1, 34, 6, 33, 0, 74, 2, 83, 4, 76, 3, 40, 5, 62, 7, 87, 8, 55, 
    7, 43, 6, 83, 5, 72, 4, 48, 1, 65, 2, 14, 0, 37, 3, 91, 8, 12, 
    2, 89, 8,  6, 1, 89, 4, 49, 3, 62, 6, 20, 0, 33, 5, 14, 7, 61, 
    8, 46, 1, 92, 6, 47, 4, 20, 2, 56, 3, 97, 5, 79, 7, 81, 0, 97, 
    6, 21, 3,  7, 7, 67, 0, 75, 1, 87, 2, 26, 5, 72, 4, 76, 8, 74, 
    2, 11, 5, 48, 6, 19, 1, 12, 7, 42, 8, 13, 0,  1, 3, 91, 4,  1
  };
  const int q0118[] = {
    9, 9, // Number of jobs and machines
    2, 29, 1, 15, 0, 62, 6, 80, 7, 12, 4, 32, 3, 72, 8, 31, 5,  8, 
    0, 65, 1, 46, 3, 93, 8, 41, 2, 33, 7, 39, 6, 53, 5, 57, 4, 77, 
    0, 50, 8, 44, 2, 25, 7, 45, 1, 63, 3, 30, 6, 15, 5, 93, 4, 74, 
    4, 29, 3, 39, 0, 56, 5, 52, 7, 24, 6, 62, 8, 58, 2, 98, 1, 44, 
    6, 85, 5, 30, 1, 31, 3, 80, 4, 76, 7, 23, 8, 42, 0, 25, 2, 96, 
    5, 69, 8, 71, 6,  7, 4, 96, 2, 14, 3, 34, 1, 25, 7, 45, 0, 66, 
    1, 23, 8, 98, 3, 91, 7, 39, 4, 52, 6, 95, 0, 10, 2, 56, 5, 77, 
    4, 47, 3,  1, 1, 48, 7, 95, 2, 27, 6, 38, 0, 49, 5,  3, 8, 55, 
    8, 44, 1, 36, 0, 73, 3, 69, 5,  2, 6, 16, 2, 12, 4, 54, 7, 48
  };
  const int q0119[] = {
    9, 9, // Number of jobs and machines
    0, 79, 5, 97, 4, 23, 6, 56, 1, 86, 2, 42, 8, 33, 7, 59, 3, 99, 
    0, 84, 3, 80, 1, 71, 7,  8, 5, 65, 6, 40, 8, 67, 4, 63, 2, 79, 
    0, 24, 8, 79, 1, 84, 6, 41, 7, 32, 5, 48, 4, 98, 2, 72, 3, 39, 
    5, 47, 8, 77, 1, 69, 0, 92, 4, 13, 6, 50, 3, 89, 2, 24, 7, 87, 
    3, 85, 7, 57, 2, 21, 1, 36, 5, 99, 0, 58, 4, 75, 8, 77, 6, 53, 
    5, 79, 4, 50, 7, 52, 2, 84, 3, 63, 6, 84, 0, 25, 1, 17, 8, 62, 
    3, 86, 2, 60, 5, 66, 0, 53, 1, 74, 7, 60, 4, 45, 6, 84, 8, 61, 
    3, 79, 2, 30, 0, 50, 1, 92, 8, 35, 6, 70, 7, 16, 5, 56, 4,  8, 
    6, 69, 4, 90, 0, 20, 7, 21, 8, 69, 1, 68, 3, 97, 2, 29, 5, 60
  };
  const int q0120[] = {
    9, 9, // Number of jobs and machines
    6, 23, 2, 62, 1, 39, 7, 56, 0, 98, 8, 77, 4, 64, 3, 88, 5, 87, 
    4, 71, 0, 31, 6, 92, 1, 16, 7, 84, 5, 88, 8, 74, 3, 99, 2, 27, 
    8,  5, 4, 26, 6, 33, 3, 43, 2, 56, 0, 29, 5, 60, 1, 11, 7, 82, 
    0, 37, 4, 36, 1, 77, 3, 28, 8, 18, 6, 26, 2, 19, 5, 39, 7, 13, 
    6, 99, 4, 89, 5, 85, 3, 24, 2, 99, 0, 42, 1,  6, 8, 63, 7, 34, 
    4, 59, 1, 95, 5, 58, 7, 90, 2, 41, 0, 88, 3, 88, 6, 17, 8, 41, 
    2, 53, 4, 43, 7, 62, 0, 98, 1, 61, 5, 81, 8, 37, 3, 60, 6, 66, 
    4, 99, 8, 52, 6, 20, 5, 51, 7,  3, 0, 67, 2, 85, 1,  6, 3, 64, 
    4, 80, 3, 77, 5, 24, 2, 66, 7, 99, 1, 41, 8, 26, 6, 49, 0, 99
  };
  const int q0121[] = {
    9, 9, // Number of jobs and machines
    4, 22, 5, 84, 2, 29, 6, 67, 1, 17, 8, 47, 0, 51, 7, 26, 3, 78, 
    4, 75, 5, 32, 6, 73, 2, 99, 0, 22, 1, 45, 3, 59, 7, 84, 8,  3, 
    6, 36, 4, 43, 1, 39, 7, 20, 2, 13, 8, 24, 5,  6, 0, 46, 3, 61, 
    8, 55, 7, 61, 3, 69, 5, 43, 1, 47, 2, 21, 4, 42, 6, 51, 0, 26, 
    6, 27, 1, 91, 4, 22, 2, 68, 7, 23, 3, 68, 8, 79, 5, 39, 0, 31, 
    3, 11, 4, 36, 5, 18, 6, 48, 0,  2, 1, 42, 2, 22, 8, 16, 7, 86, 
    2, 87, 0, 24, 3, 43, 5, 85, 4, 98, 7, 96, 1, 73, 6, 96, 8, 27, 
    4, 32, 8, 12, 0, 81, 3, 38, 2, 50, 6, 29, 5, 80, 1, 54, 7, 13, 
    7, 78, 2, 99, 1, 84, 8, 55, 0, 78, 3, 74, 5, 66, 6, 12, 4, 99
  };
  const int q0122[] = {
    9, 9, // Number of jobs and machines
    0, 59, 1, 51, 8, 21, 7, 82, 4, 16, 6, 28, 2, 94, 5, 85, 3, 24, 
    2, 96, 8, 98, 4, 35, 3, 17, 0, 34, 1, 40, 6, 53, 7, 71, 5, 38, 
    2, 58, 0, 28, 1, 98, 7, 85, 8, 98, 5, 40, 6, 68, 3, 44, 4, 32, 
    3, 21, 8, 58, 0, 20, 1, 59, 5, 61, 4, 96, 7, 58, 6, 95, 2, 59, 
    1, 65, 0,  1, 8, 88, 5, 88, 6, 49, 2, 62, 7, 94, 4, 49, 3, 29, 
    6, 53, 1, 91, 5, 43, 3, 94, 4, 74, 2, 74, 0, 51, 7, 55, 8, 18, 
    3, 97, 2, 65, 8, 23, 6, 66, 4, 94, 5, 57, 7, 57, 1, 37, 0,  7, 
    3, 85, 6, 48, 7, 29, 0, 22, 5, 10, 8, 31, 1, 35, 2, 18, 4, 82, 
    7,  8, 5, 23, 3, 16, 6, 81, 1, 33, 0, 43, 8, 42, 2, 39, 4, 18
  };
  const int q0123[] = {
    9, 9, // Number of jobs and machines
    4, 41, 3, 70, 8, 83, 0, 28, 7, 75, 6, 45, 1, 46, 2, 93, 5, 82, 
    1, 33, 6, 24, 0, 90, 4, 39, 8, 75, 3, 84, 2, 51, 5, 40, 7, 51, 
    6, 18, 3, 49, 2, 43, 7, 14, 4, 22, 0, 52, 8, 57, 1, 87, 5, 39, 
    5, 42, 6, 45, 4, 83, 3, 94, 2, 72, 0, 21, 7, 74, 1, 34, 8, 52, 
    3, 18, 7,  1, 1, 56, 4, 41, 8, 47, 5, 73, 0, 78, 6,  3, 2, 73, 
    2, 91, 5, 62, 6, 58, 0, 10, 4, 68, 1, 97, 7, 48, 3, 22, 8, 23, 
    0, 69, 1, 88, 4, 96, 3, 88, 7, 79, 5,  4, 2, 52, 8, 22, 6, 74, 
    7, 30, 6, 43, 3, 59, 8, 12, 0, 41, 2, 81, 5,  6, 1, 82, 4, 71, 
    4, 72, 1, 67, 5, 14, 0, 24, 7, 84, 2, 95, 6,  8, 8, 53, 3, 34
  };
  const int q0124[] = {
    9, 9, // Number of jobs and machines
    5, 79, 8, 70, 1, 74, 4,  6, 2, 63, 3, 97, 6, 14, 0, 73, 7, 80, 
    5, 46, 4, 80, 7, 78, 1, 58, 8, 14, 2, 43, 3, 50, 0, 58, 6, 98, 
    5, 11, 7, 90, 3, 11, 4, 94, 0, 98, 8, 18, 2, 31, 6, 31, 1, 23, 
    6, 90, 7, 24, 2, 57, 3, 68, 1,  3, 0, 62, 4, 92, 8, 41, 5, 77, 
    0, 85, 7, 68, 3, 49, 8, 72, 5, 26, 2, 42, 6, 96, 1, 71, 4, 52, 
    6, 48, 2, 26, 3, 87, 0,  6, 7, 25, 5, 30, 8, 93, 1, 64, 4, 29, 
    2, 55, 6, 50, 3, 86, 0, 14, 5, 55, 4, 87, 1, 74, 7, 27, 8, 98, 
    4, 52, 0, 67, 6, 30, 7, 31, 1, 86, 8,  7, 2, 79, 5, 88, 3, 39, 
    1, 73, 0, 12, 2, 47, 3, 12, 8,  4, 4, 97, 7, 22, 6, 95, 5, 63
  };
  const int q0125[] = {
    9, 9, // Number of jobs and machines
    4, 23, 8, 82, 0, 98, 6, 65, 1, 29, 3, 48, 5, 58, 2, 21, 7, 77, 
    6, 66, 8, 99, 4, 63, 0, 28, 3, 34, 1, 40, 2, 30, 5, 47, 7, 73, 
    4, 57, 1, 55, 0, 15, 6, 61, 2, 50, 7, 18, 5, 44, 8, 63, 3, 93, 
    0, 43, 3, 82, 2, 46, 4, 38, 6, 97, 7, 73, 8, 64, 1, 38, 5, 85, 
    0, 21, 4,  9, 1, 97, 7, 58, 6, 90, 8, 76, 2, 35, 5, 58, 3, 59, 
    6, 33, 1, 18, 2, 66, 7, 97, 4,  5, 0, 91, 8,  2, 5, 15, 3, 37, 
    1, 27, 0, 34, 6, 16, 8, 70, 3, 91, 4, 10, 5, 86, 7, 94, 2, 66, 
    8, 38, 4, 93, 3, 69, 5, 84, 2, 53, 1, 65, 0, 79, 6, 66, 7, 90, 
    0, 65, 7, 85, 2, 19, 1, 13, 6,  3, 8, 76, 3, 51, 5, 53, 4, 50
  };
  const int q0126[] = {
    9, 9, // Number of jobs and machines
    0, 91, 7, 13, 4, 70, 8, 56, 6,  3, 1,  5, 5, 58, 2, 10, 3, 69, 
    7,  3, 4, 36, 8, 24, 1, 22, 6, 84, 3, 93, 0, 79, 5, 86, 2, 89, 
    0, 80, 7, 29, 3, 30, 5, 46, 8, 49, 6, 14, 4, 16, 1, 60, 2, 72, 
    7, 37, 5, 14, 4, 33, 8, 54, 2, 74, 1, 94, 6, 95, 0, 19, 3, 36, 
    8, 14, 2, 61, 5, 75, 6, 66, 0, 99, 3, 98, 4, 89, 7, 89, 1, 30, 
    2, 38, 5, 78, 4, 97, 1, 77, 8, 14, 6, 20, 7, 43, 0, 61, 3, 37, 
    0, 17, 3, 13, 2, 74, 4, 30, 5, 77, 7, 23, 8, 42, 6, 46, 1,  8, 
    5, 21, 4, 70, 8, 69, 7, 28, 1, 77, 2,  9, 3, 91, 0, 26, 6,  5, 
    8, 78, 1, 93, 6, 53, 5, 34, 3, 11, 2, 39, 0, 51, 4, 53, 7, 26
  };
  const int q0127[] = {
    9, 9, // Number of jobs and machines
    4, 64, 2, 92, 3, 45, 1, 47, 0,  1, 8,  8, 5, 24, 7, 38, 6, 53, 
    7, 78, 4, 84, 6, 17, 5, 71, 8,  4, 0, 83, 1, 87, 3, 37, 2,  3, 
    0, 67, 6, 34, 8, 92, 2, 99, 4, 96, 7, 43, 5, 97, 1, 11, 3, 98, 
    2, 74, 8, 58, 3, 11, 5, 46, 4, 81, 1, 43, 7, 54, 6, 44, 0, 24, 
    8, 95, 3, 70, 7, 18, 4, 25, 2, 39, 1, 69, 6, 54, 5, 94, 0, 72, 
    7, 21, 2, 13, 0, 55, 5, 95, 8, 55, 1, 55, 4, 29, 3, 95, 6, 94, 
    1, 19, 4, 66, 6, 54, 8, 37, 2, 58, 5, 57, 0, 65, 7, 14, 3, 94, 
    1, 44, 5, 24, 8, 41, 2, 79, 0,  5, 7, 53, 6, 85, 3, 68, 4, 72, 
    3, 72, 5, 89, 4, 99, 0,  3, 1, 32, 7, 53, 6, 41, 2, 17, 8, 19
  };
  const int q0128[] = {
    9, 9, // Number of jobs and machines
    6, 92, 8, 64, 1, 28, 5, 55, 2, 83, 0,  5, 7, 87, 4, 22, 3,  7, 
    6, 82, 4, 67, 1, 31, 5, 53, 3,  1, 7, 59, 0, 77, 2,  5, 8, 77, 
    1, 84, 4, 78, 7, 88, 3, 49, 2, 28, 8, 92, 0, 49, 5,  9, 6, 53, 
    1, 27, 8, 42, 3, 60, 0, 60, 7, 78, 5,  4, 2, 66, 4, 81, 6, 29, 
    6, 59, 5,  6, 4, 74, 3,  4, 2, 12, 7, 53, 1, 66, 0, 63, 8,  5, 
    7, 32, 3, 99, 0, 46, 5, 93, 6, 42, 2, 66, 1, 87, 8, 91, 4, 21, 
    5, 18, 3, 90, 6, 64, 1, 86, 8, 22, 2, 91, 0, 38, 7, 76, 4, 79, 
    0, 28, 4, 15, 2, 94, 6, 76, 5, 61, 8, 60, 3, 18, 1, 26, 7, 75, 
    1, 48, 6, 39, 8, 72, 4, 91, 3, 82, 0, 22, 7, 98, 2, 53, 5, 89
  };
  const int q0129[] = {
    9, 9, // Number of jobs and machines
    4, 45, 2, 27, 3, 93, 7, 19, 8, 81, 0,  3, 6, 32, 5, 17, 1,  3, 
    8, 19, 5, 35, 7, 47, 0, 47, 6, 38, 3, 95, 4, 28, 2, 14, 1,  7, 
    2, 54, 5, 14, 1, 45, 0, 72, 4, 93, 8, 18, 3, 80, 6, 69, 7, 98, 
    0, 52, 3, 33, 4,  5, 8, 21, 2, 29, 6, 99, 7, 48, 1, 79, 5, 20, 
    8, 79, 0, 63, 4,  6, 5, 15, 1, 48, 7, 66, 3, 69, 6, 30, 2, 19, 
    6, 35, 2, 49, 1, 46, 7, 90, 3,  1, 0, 55, 8, 30, 4, 37, 5, 87, 
    5, 15, 6, 15, 7, 33, 8, 38, 0, 52, 3, 82, 2, 17, 1, 57, 4, 62, 
    1, 58, 8, 39, 3, 85, 5, 94, 7, 62, 0, 59, 2, 13, 6, 45, 4,  2, 
    7, 86, 0,  9, 3, 94, 8, 42, 4, 27, 5, 69, 2,  6, 6, 78, 1, 63
  };
  const int q0130[] = {
    9, 9, // Number of jobs and machines
    4, 96, 3, 52, 8, 25, 2, 73, 1, 56, 0, 45, 5, 86, 6, 84, 7, 65, 
    2, 89, 5, 68, 3, 38, 1, 37, 8, 37, 4, 15, 6,  8, 7, 99, 0,  7, 
    5, 75, 8, 97, 6, 69, 2, 28, 3, 34, 1, 52, 7, 75, 4, 26, 0,  8, 
    6, 68, 8, 32, 5, 82, 1, 23, 3, 48, 7, 66, 0, 33, 2, 82, 4,  9, 
    0, 35, 7, 16, 5, 39, 2, 31, 1, 18, 4, 49, 8, 75, 3, 38, 6, 13, 
    8, 16, 5, 83, 3,  3, 0, 13, 6, 86, 7, 27, 4, 57, 2, 87, 1, 55, 
    4, 55, 3, 35, 6, 41, 5, 19, 1,  1, 7, 26, 2, 34, 8, 38, 0, 94, 
    8,  6, 7, 15, 4, 68, 5, 52, 0, 88, 1, 86, 6, 96, 2, 59, 3, 45, 
    1, 64, 6,  2, 8, 26, 7, 95, 4, 88, 3, 27, 2, 76, 0, 12, 5, 67
  };
  const int q0131[] = {
    9, 9, // Number of jobs and machines
    3,  6, 5,  9, 2, 77, 4, 43, 8, 46, 1,  2, 0, 89, 7, 58, 6, 31, 
    0, 13, 2, 97, 1, 37, 5, 52, 7, 66, 6, 20, 3, 76, 8, 19, 4, 32, 
    3, 97, 1, 46, 8,  7, 5, 25, 2, 13, 7, 32, 4, 87, 6, 33, 0, 21, 
    2, 53, 4, 86, 8, 62, 1, 80, 6, 75, 5, 27, 0,  3, 3, 73, 7, 50, 
    6, 96, 3, 77, 5, 19, 1, 90, 0, 88, 8, 43, 2, 46, 7, 19, 4, 62, 
    4, 55, 5, 97, 3, 48, 8, 40, 1, 91, 0, 22, 2, 88, 6, 21, 7, 10, 
    3, 32, 5, 41, 8, 31, 7, 79, 1, 28, 4, 17, 6, 29, 2, 36, 0, 83, 
    0, 68, 4, 20, 6, 73, 8, 10, 1,  8, 3, 70, 5, 86, 2, 13, 7, 66, 
    4, 92, 2, 18, 5, 15, 8, 60, 6, 82, 1, 63, 3, 44, 0, 22, 7, 28
  };
  const int q0132[] = {
    9, 9, // Number of jobs and machines
    2, 48, 7, 71, 0, 53, 6, 17, 3, 70, 4, 66, 8, 10, 1, 74, 5, 64, 
    6, 47, 8, 35, 1, 44, 3, 32, 4, 14, 5, 61, 2, 15, 0, 81, 7, 45, 
    4, 29, 1, 64, 8,  8, 2, 75, 0, 87, 5, 24, 3, 52, 7, 17, 6, 32, 
    1, 49, 2, 59, 0, 94, 7, 69, 6, 11, 5, 25, 3, 52, 4, 19, 8, 95, 
    0, 29, 7, 90, 1, 39, 2, 99, 4, 81, 8, 19, 6, 48, 5,  5, 3, 88, 
    2, 39, 6, 50, 4, 21, 3, 17, 7, 57, 0, 34, 1, 20, 5, 90, 8, 63, 
    6, 54, 4,  4, 8,  5, 7, 94, 1, 69, 3, 16, 2, 21, 5, 17, 0, 82, 
    1, 30, 5, 53, 0, 76, 3, 19, 6, 22, 4, 66, 7, 78, 8, 39, 2, 79, 
    2, 79, 4, 10, 1, 71, 5, 29, 0, 69, 8, 58, 3, 31, 7, 37, 6, 87
  };
  const int q0133[] = {
    9, 9, // Number of jobs and machines
    7, 15, 4, 43, 6, 39, 5, 40, 8, 59, 1, 32, 2, 37, 0, 25, 3, 79, 
    1, 65, 7, 11, 2, 16, 4, 51, 3, 21, 8, 47, 5, 52, 0,  2, 6, 58, 
    5, 51, 6, 66, 7, 31, 4, 64, 1, 72, 8, 96, 3, 29, 2, 15, 0, 29, 
    4, 16, 3, 34, 8, 99, 5, 99, 6, 96, 0, 63, 1, 64, 7, 99, 2, 16, 
    2, 65, 6, 41, 8, 24, 1, 17, 0, 96, 5, 67, 3, 64, 4, 17, 7, 29, 
    2, 63, 7, 19, 6, 27, 8, 24, 3, 43, 5,  8, 4, 18, 0, 10, 1, 45, 
    3, 41, 5, 59, 7, 30, 8, 78, 0,  5, 4, 82, 2, 96, 1, 69, 6, 34, 
    8, 39, 0, 93, 6,  7, 3, 63, 4,  2, 2, 76, 1, 33, 5,  5, 7, 63, 
    6, 41, 5,  1, 2, 43, 1, 90, 4, 77, 0,  3, 7,  6, 3, 87, 8, 31
  };
  const int q0134[] = {
    9, 9, // Number of jobs and machines
    6, 59, 2, 99, 3, 17, 7,  3, 1, 59, 5, 94, 4, 95, 0, 29, 8, 39, 
    7, 86, 5, 98, 0, 93, 6, 69, 3,  6, 2, 35, 1, 18, 8, 50, 4, 78, 
    2, 85, 7, 27, 5, 85, 3, 87, 0, 84, 1, 97, 8, 77, 6, 62, 4, 32, 
    2, 53, 1, 35, 5, 99, 8, 77, 0, 45, 3, 66, 4,  5, 7, 27, 6, 48, 
    4, 13, 8, 30, 5, 23, 6, 48, 1, 44, 2, 12, 3, 34, 7, 56, 0, 52, 
    8, 48, 0, 79, 5, 82, 7, 36, 6, 67, 3, 54, 4, 53, 1, 68, 2, 40, 
    1, 56, 4, 59, 5, 94, 6, 18, 3, 31, 8, 30, 7, 76, 2,  9, 0,  9, 
    0, 95, 7, 96, 6, 79, 4, 21, 1, 69, 5, 78, 2, 20, 3, 22, 8, 94, 
    0, 25, 5, 38, 6, 98, 7, 34, 2, 53, 3, 14, 4, 98, 1, 53, 8, 17
  };
  const int q0135[] = {
    9, 9, // Number of jobs and machines
    7, 66, 4,  2, 2, 43, 3, 67, 1, 47, 0, 78, 8, 47, 6, 76, 5, 83, 
    5, 70, 6, 48, 4, 94, 7, 66, 3, 79, 0, 77, 1, 94, 8,  9, 2, 62, 
    0, 81, 5, 84, 8, 69, 1,  1, 3, 15, 2, 46, 4, 41, 6, 34, 7, 15, 
    0, 21, 2, 66, 3, 28, 8, 95, 7,  5, 5, 35, 4, 83, 1, 59, 6, 30, 
    0, 14, 8, 99, 4, 94, 5, 86, 1, 76, 3, 62, 6, 38, 2, 13, 7, 73, 
    3, 50, 7, 40, 4, 71, 0, 52, 5, 72, 1, 48, 6, 64, 8, 38, 2, 17, 
    2, 81, 7,  8, 1, 65, 4, 70, 3, 89, 0, 67, 5, 94, 6, 71, 8, 18, 
    2, 57, 1,  9, 6, 98, 5, 61, 0, 28, 4, 21, 3, 42, 7, 62, 8, 11, 
    3, 36, 6, 15, 5, 10, 2,  1, 8, 47, 4, 73, 0, 21, 1, 30, 7, 12
  };
  const int q0136[] = {
    9, 9, // Number of jobs and machines
    3, 93, 6, 10, 0, 15, 2, 83, 8, 53, 5, 50, 1, 27, 7, 59, 4, 49, 
    7, 95, 0, 51, 1, 10, 2, 41, 3, 38, 6, 32, 8, 75, 5, 60, 4, 10, 
    6, 87, 3, 85, 8, 13, 2, 67, 5, 27, 4, 53, 1, 59, 7, 98, 0, 30, 
    3, 58, 8, 15, 5, 79, 7, 86, 4, 15, 2, 46, 6, 40, 1, 43, 0, 47, 
    7, 30, 5, 51, 0, 85, 3, 58, 8, 54, 1, 76, 6, 33, 2, 96, 4, 11, 
    8,  3, 4, 20, 5, 68, 7, 60, 3, 60, 6, 76, 2,  8, 0, 72, 1, 27, 
    2, 32, 3, 19, 4, 19, 8, 47, 6, 93, 7, 14, 1, 34, 5,  7, 0, 98, 
    5, 99, 1, 86, 2, 58, 4, 12, 7, 41, 3, 62, 8, 13, 6, 97, 0,  4, 
    8,  7, 3,  6, 2, 69, 0, 66, 5, 28, 1, 91, 6, 11, 7, 62, 4, 52
  };
  const int q0137[] = {
    9, 9, // Number of jobs and machines
    5, 69, 4, 91, 0, 19, 2, 75, 3, 28, 6,  9, 7, 10, 8, 35, 1,  9, 
    4, 37, 6, 28, 7, 78, 1, 27, 2, 68, 3, 17, 8, 28, 5, 37, 0,  8, 
    8, 37, 1, 64, 4,  2, 7, 69, 3,  9, 6, 77, 2, 37, 5, 45, 0, 63, 
    6, 83, 7, 17, 5, 36, 2, 39, 4,  3, 0, 48, 3,  4, 8,  6, 1, 95, 
    6, 31, 7,  3, 1, 85, 0, 30, 8, 50, 3, 60, 2, 92, 5, 46, 4, 81, 
    8, 85, 4, 67, 0, 92, 6, 76, 5, 29, 7, 10, 3, 96, 2, 29, 1, 98, 
    8, 70, 2, 14, 3, 73, 6, 74, 5, 49, 0, 17, 7, 28, 1, 61, 4, 81, 
    3,  2, 1,  7, 2, 51, 7, 88, 6, 74, 8, 61, 5, 76, 4, 82, 0, 90, 
    3,  9, 5, 41, 7, 27, 4, 95, 0, 81, 6, 52, 8, 68, 1,  2, 2, 16
  };
  const int q0138[] = {
    9, 9, // Number of jobs and machines
    5, 24, 7, 59, 3, 98, 0, 45, 6, 58, 8, 17, 2, 92, 1, 83, 4, 78, 
    4, 26, 8, 24, 0, 99, 2, 55, 5, 36, 7,  5, 3, 75, 1, 65, 6, 54, 
    2, 67, 5, 28, 7, 48, 3, 41, 6, 81, 8, 42, 0, 43, 1, 73, 4, 71, 
    5, 93, 4, 91, 8, 26, 6, 19, 2, 27, 3,  7, 1, 15, 7, 68, 0, 91, 
    2, 35, 0, 62, 1, 71, 7, 79, 8, 77, 4,  5, 3, 42, 6, 95, 5, 17, 
    4, 36, 1, 43, 6,  9, 0, 68, 7,  4, 2, 35, 5, 47, 3, 59, 8, 54, 
    0, 66, 5, 74, 6, 78, 3, 65, 4, 44, 1, 39, 7,  9, 2,  3, 8, 73, 
    3, 41, 5, 58, 4, 97, 1, 34, 7,  7, 2, 84, 8, 27, 0, 28, 6, 28, 
    2, 50, 4, 33, 7, 65, 8, 17, 5,  3, 3,  6, 0, 28, 1, 27, 6, 23
  };
  const int q0139[] = {
    9, 9, // Number of jobs and machines
    5, 60, 3, 39, 4, 29, 2, 84, 8, 25, 7, 54, 0, 23, 6, 89, 1, 11, 
    8, 54, 0, 66, 5, 19, 6, 31, 2, 79, 3, 94, 1, 88, 4, 96, 7, 71, 
    5, 97, 4, 27, 1, 92, 6, 29, 3,  7, 7, 14, 8, 73, 0, 58, 2, 98, 
    3,  4, 1, 84, 6, 77, 4,  5, 2, 58, 5, 35, 0, 30, 7, 26, 8, 16, 
    8, 99, 2, 46, 3, 79, 6, 28, 7, 52, 1, 60, 5, 40, 4, 36, 0, 26, 
    1, 57, 7, 58, 5, 25, 4, 80, 2, 80, 8, 14, 6, 52, 0, 23, 3, 93, 
    2, 78, 8, 94, 6, 77, 3, 84, 5, 81, 4, 81, 1, 31, 0, 17, 7, 89, 
    3, 55, 1, 71, 4, 95, 2, 17, 6,  3, 7, 44, 5, 91, 0, 38, 8, 46, 
    8,  4, 1, 16, 7, 11, 3, 53, 6, 21, 2, 80, 0, 25, 5, 52, 4, 85
  };
  const int q0140[] = {
    9, 9, // Number of jobs and machines
    8, 79, 7, 88, 5, 29, 1, 39, 0, 56, 6, 29, 2, 77, 3, 28, 4, 64, 
    4, 82, 6, 37, 3, 20, 7, 44, 1, 37, 0, 30, 5, 15, 2, 11, 8, 26, 
    2,  1, 8, 45, 7, 89, 1, 47, 0, 21, 4, 14, 3, 59, 6, 19, 5, 57, 
    5, 39, 7, 80, 2, 13, 4, 57, 1, 76, 0, 19, 6, 55, 3, 50, 8, 49, 
    4, 22, 8, 90, 1, 38, 0, 86, 2, 48, 5, 68, 3, 74, 7, 60, 6, 52, 
    7, 38, 8, 77, 6, 39, 1,  7, 4, 97, 0, 75, 3, 17, 5, 13, 2, 28, 
    2, 16, 7,  1, 8, 36, 3, 87, 0, 13, 6, 55, 1, 73, 4, 74, 5, 39, 
    7, 38, 5, 42, 1, 43, 4, 57, 0, 44, 3, 48, 6, 99, 2, 47, 8, 75, 
    7, 54, 8, 45, 1, 50, 2, 18, 4, 25, 5, 12, 0, 75, 3, 39, 6, 82
  };
  const int q0141[] = {
    9, 9, // Number of jobs and machines
    6, 10, 0, 43, 5, 18, 7, 14, 1,  1, 8, 42, 3,  2, 2, 58, 4, 62, 
    3, 85, 6, 68, 2, 65, 0, 77, 1, 32, 5, 27, 4, 69, 8,  6, 7, 12, 
    6, 55, 3, 88, 7, 93, 2, 35, 4, 30, 5, 64, 0, 23, 8,  7, 1, 62, 
    8, 70, 1, 26, 6, 33, 5, 52, 7, 89, 0, 71, 2, 96, 4, 72, 3, 75, 
    3, 41, 0, 74, 6, 52, 7,  6, 4, 45, 2, 55, 8, 37, 5, 77, 1, 68, 
    3, 50, 8,  2, 2, 42, 4, 23, 7, 42, 6, 15, 0, 68, 1, 10, 5, 33, 
    4, 37, 7, 87, 2, 67, 6, 33, 5, 61, 8, 27, 1, 31, 0,  5, 3, 16, 
    5, 54, 8, 47, 1, 10, 2, 50, 6,  7, 3, 83, 4,  7, 7, 54, 0, 75, 
    6, 76, 8, 21, 7, 41, 4,  6, 5, 71, 3, 88, 2, 45, 1, 94, 0, 78
  };
  const int q0142[] = {
    9, 9, // Number of jobs and machines
    2, 13, 8, 33, 0, 61, 6, 98, 1, 43, 4, 41, 3, 71, 7, 90, 5,  5, 
    1, 75, 4, 75, 0, 90, 8, 35, 7, 42, 5, 93, 3, 63, 2, 54, 6, 42, 
    7,  1, 4, 52, 8, 87, 1, 94, 0, 12, 3, 81, 5, 25, 2, 69, 6, 98, 
    7, 80, 8, 78, 6, 34, 5,  5, 2, 13, 4, 96, 0, 52, 3, 21, 1, 14, 
    5, 96, 0,  6, 8, 54, 2, 25, 6, 61, 3, 24, 4,  1, 1,  9, 7, 88, 
    7, 45, 4, 62, 1, 45, 0, 21, 3, 71, 8, 11, 5, 40, 6, 85, 2, 34, 
    4, 52, 1, 26, 2,  5, 7, 24, 0, 80, 6, 55, 5, 47, 8, 58, 3, 49, 
    3, 79, 5, 83, 8, 16, 4, 68, 1, 42, 0, 56, 2, 75, 7, 42, 6, 84, 
    8, 26, 5, 85, 2, 90, 3, 41, 6, 34, 0, 52, 4, 48, 7, 32, 1, 32
  };
  const int q0143[] = {
    9, 9, // Number of jobs and machines
    5, 84, 7, 33, 3,  5, 8, 29, 2, 97, 0, 63, 6, 93, 4, 24, 1, 90, 
    7, 10, 6, 80, 5, 73, 8, 74, 4, 79, 0, 14, 1, 87, 3, 81, 2, 50, 
    2, 30, 0,  4, 8, 56, 5,  2, 7, 11, 4, 14, 3, 67, 1, 79, 6, 15, 
    7, 97, 8,  6, 5, 31, 3,  3, 2,  2, 0, 14, 4,  8, 1, 16, 6,  4, 
    3, 22, 1, 35, 8, 34, 6, 44, 4, 66, 7, 48, 2, 92, 5, 50, 0, 49, 
    4, 32, 1, 28, 8, 97, 2, 80, 6, 97, 7, 19, 0, 48, 5, 15, 3, 81, 
    2, 27, 4, 24, 5,  6, 7,  7, 6, 68, 0, 11, 3, 21, 1, 80, 8, 23, 
    4, 86, 6, 17, 8, 68, 5, 24, 2, 26, 1, 48, 3, 26, 0, 29, 7, 88, 
    2, 42, 5, 99, 4, 49, 8, 49, 7, 30, 3,  4, 1, 42, 6, 22, 0, 85
  };
  const int q0144[] = {
    9, 9, // Number of jobs and machines
    4, 36, 0, 72, 2, 36, 5, 47, 1, 46, 3, 52, 7, 60, 8, 28, 6, 22, 
    3, 24, 8, 80, 1, 81, 6, 60, 5, 22, 0, 15, 7, 72, 2, 17, 4, 94, 
    0, 11, 8, 25, 2, 52, 5, 30, 4, 36, 3, 92, 1, 83, 7, 33, 6, 82, 
    3, 94, 1, 43, 6, 20, 7, 15, 8, 88, 2,  3, 4, 63, 0, 57, 5, 88, 
    8, 99, 3, 95, 4, 32, 7, 52, 0, 97, 2, 72, 1, 20, 6,  2, 5, 84, 
    0, 61, 1, 63, 5, 62, 7, 25, 6, 77, 2, 94, 4, 91, 3, 57, 8, 83, 
    8, 68, 1, 39, 7, 81, 6, 12, 4, 82, 0, 92, 3, 49, 5, 11, 2, 22, 
    1, 57, 0, 84, 7, 95, 8, 15, 4, 40, 3, 51, 2, 98, 6, 31, 5, 15, 
    2, 42, 6, 44, 7, 11, 4, 16, 1, 59, 3, 94, 0, 91, 8, 14, 5, 49
  };
  const int q0145[] = {
    9, 9, // Number of jobs and machines
    6, 22, 0,  1, 4, 31, 8, 42, 7, 56, 2,  5, 3, 93, 1, 57, 5, 19, 
    1, 83, 5, 52, 6, 62, 2,  1, 4, 83, 7, 57, 0, 84, 3, 13, 8, 38, 
    8, 64, 7, 48, 6, 81, 1, 43, 2, 72, 0, 38, 3, 60, 5, 24, 4, 75, 
    5, 19, 2, 16, 1, 89, 0, 43, 6, 96, 4, 11, 3, 59, 7, 96, 8, 19, 
    6, 84, 7, 32, 5, 66, 0, 94, 1, 69, 8, 56, 4,  7, 3, 93, 2, 28, 
    1,  9, 2, 57, 7, 34, 8,  5, 4, 44, 5, 54, 3, 12, 6, 39, 0, 78, 
    7, 76, 1,  9, 0, 67, 8, 72, 3, 94, 6, 78, 2, 73, 4, 67, 5, 30, 
    7, 24, 3, 27, 2,  9, 6, 55, 8, 69, 1, 83, 4, 79, 0, 40, 5, 16, 
    4, 54, 6, 15, 0, 82, 3, 89, 1, 89, 2, 73, 8, 87, 7, 73, 5, 89
  };
  const int q0146[] = {
    9, 9, // Number of jobs and machines
    5, 61, 0, 26, 2, 51, 7, 82, 3, 99, 1, 70, 8, 35, 6, 83, 4, 66, 
    8, 82, 6, 68, 3, 14, 7, 15, 1, 77, 0, 89, 5, 95, 2, 85, 4, 77, 
    1, 60, 3, 60, 8, 13, 2,  7, 7, 86, 4, 92, 6, 49, 0,  6, 5, 86, 
    5, 23, 8, 55, 7, 55, 1, 86, 3, 29, 0, 22, 4, 51, 6, 37, 2, 16, 
    8, 69, 2,  8, 0, 54, 4, 57, 3, 34, 7, 11, 1, 63, 6,  2, 5, 28, 
    2, 90, 6, 64, 0, 57, 5, 12, 8, 73, 3, 72, 4, 73, 1, 85, 7,  7, 
    0, 71, 8, 54, 5, 75, 4, 25, 3, 91, 1, 38, 2, 87, 6, 55, 7, 52, 
    0, 53, 6, 48, 5, 94, 4, 87, 3, 78, 8, 94, 1, 53, 2, 28, 7, 56, 
    2, 51, 6, 36, 7, 58, 0,  3, 1, 85, 4, 44, 8, 40, 5, 55, 3, 45
  };
  const int q0147[] = {
    9, 9, // Number of jobs and machines
    3, 99, 0, 85, 5, 50, 7, 16, 2, 30, 1, 12, 4, 30, 6, 70, 8, 49, 
    7, 34, 5, 71, 3, 97, 0, 28, 2, 16, 6, 56, 1, 72, 4, 66, 8, 68, 
    3, 86, 7, 43, 1, 32, 6, 59, 0, 31, 8, 50, 5, 41, 4, 61, 2, 27, 
    6, 27, 4, 73, 8, 87, 2, 48, 7, 92, 0, 67, 1, 25, 3, 21, 5, 18, 
    0,  5, 3, 79, 4, 81, 2, 61, 6,  8, 7, 61, 8, 86, 1, 78, 5,  3, 
    4, 96, 1, 11, 6, 55, 8, 89, 0, 34, 2, 83, 5, 67, 7, 86, 3, 68, 
    5, 45, 7, 89, 8,  8, 0, 30, 1, 33, 3,  7, 2, 85, 6, 16, 4, 61, 
    6, 95, 5, 62, 3, 95, 1,  1, 2, 76, 7,  3, 8, 18, 0, 54, 4, 50, 
    8, 39, 2, 25, 1, 27, 7, 70, 3,  1, 6, 81, 5, 51, 0, 44, 4, 92
  };
  const int q0148[] = {
    9, 9, // Number of jobs and machines
    4, 46, 7, 19, 1, 57, 2, 60, 5, 75, 6, 70, 0, 15, 8, 26, 3, 97, 
    7, 96, 0, 49, 1,  4, 6, 82, 5, 52, 2, 23, 4, 38, 8, 64, 3, 36, 
    5, 27, 1,  4, 6, 33, 7, 12, 4, 94, 8, 71, 2, 86, 0,  8, 3, 40, 
    8, 85, 1, 37, 3, 74, 7, 10, 4, 78, 0, 52, 6, 23, 2, 17, 5, 23, 
    8, 16, 2,  5, 5, 16, 6,  5, 0, 82, 7, 88, 4, 82, 3, 41, 1, 40, 
    3, 46, 2, 43, 6, 88, 1, 54, 7, 93, 4, 68, 0, 12, 8, 23, 5, 29, 
    6, 91, 0, 21, 3, 74, 4,  5, 2, 86, 7, 69, 8, 89, 1, 84, 5, 42, 
    1, 89, 8, 52, 6, 78, 3, 10, 0, 10, 5, 48, 7, 96, 4, 41, 2, 21, 
    0, 64, 3, 45, 5, 38, 2, 94, 8, 24, 7, 14, 6, 19, 1, 98, 4, 97
  };
  const int q0149[] = {
    9, 9, // Number of jobs and machines
    0, 71, 1, 96, 7, 18, 3, 44, 5, 35, 6, 85, 2, 41, 4, 26, 8, 81, 
    0, 87, 5, 93, 1, 87, 8, 90, 6, 73, 4, 53, 7, 18, 3, 90, 2, 17, 
    8, 88, 6, 42, 4, 82, 0, 64, 3, 93, 5, 66, 2, 24, 7, 51, 1,  7, 
    7, 21, 4, 22, 8, 45, 5, 61, 1, 80, 0, 85, 3, 76, 2, 45, 6, 72, 
    8, 52, 1, 83, 5, 46, 0, 77, 7, 10, 2, 76, 6,  5, 3, 73, 4,  4, 
    3, 15, 5, 55, 2, 60, 6, 53, 8, 93, 0, 30, 4, 92, 7,  3, 1,  5, 
    4,  8, 2, 72, 1,  9, 5, 23, 6, 76, 7, 97, 0, 31, 8, 13, 3, 93, 
    8, 85, 0, 97, 6, 36, 3, 73, 2, 97, 4, 13, 7, 92, 5, 83, 1, 55, 
    1, 82, 7, 26, 8, 89, 4, 69, 6, 21, 2, 97, 3, 73, 5, 76, 0, 57
  };
  const int q0150[] = {
    9, 9, // Number of jobs and machines
    7,  3, 8, 13, 5, 61, 0, 40, 1, 17, 2, 19, 4, 87, 3,  3, 6,  8, 
    2, 44, 0, 14, 1, 72, 3, 84, 6,  1, 8, 13, 5,  2, 7, 33, 4, 23, 
    6, 44, 3, 25, 4, 61, 7, 55, 1, 17, 0, 66, 2, 82, 8, 60, 5, 83, 
    7, 90, 3, 61, 4, 38, 5, 18, 6, 22, 8, 96, 1, 60, 2, 78, 0,  4, 
    4, 91, 8,  2, 7, 63, 6, 45, 5, 92, 0, 18, 1, 75, 3, 51, 2, 55, 
    8, 45, 3, 18, 6, 20, 2, 53, 5, 46, 7, 73, 0, 40, 4, 18, 1, 82, 
    6, 96, 8, 76, 7, 64, 4, 68, 0, 13, 3, 39, 5, 62, 2, 40, 1, 15, 
    7, 31, 5, 52, 8, 33, 1, 78, 0, 81, 4, 38, 2, 94, 3, 63, 6, 95, 
    8, 67, 1,  3, 0, 76, 2, 87, 3, 68, 5, 57, 4, 62, 7, 60, 6, 11
  };
  const int q0151[] = {
    9, 9, // Number of jobs and machines
    0, 41, 5, 14, 8, 94, 7, 96, 1,  7, 6, 19, 2,  3, 4,  7, 3, 59, 
    7, 26, 1, 45, 2, 85, 8, 92, 3, 35, 4, 33, 5, 98, 0, 27, 6, 49, 
    1, 27, 6, 83, 3, 26, 5, 78, 4, 26, 0, 67, 7, 49, 2, 41, 8, 86, 
    4, 28, 0, 54, 1, 21, 7, 55, 3, 40, 2, 41, 5,  6, 8, 81, 6, 97, 
    5, 73, 8, 64, 6,  7, 7, 91, 0, 11, 1,  8, 3,  5, 4, 43, 2, 38, 
    2, 68, 8, 99, 3, 10, 1, 76, 6, 50, 4, 87, 0, 93, 5, 84, 7, 82, 
    6, 14, 0,  2, 5, 35, 4, 27, 8, 67, 2,  2, 3, 96, 7, 60, 1, 76, 
    4,  1, 5, 34, 7, 35, 1, 80, 8, 76, 6, 54, 2,  4, 3, 28, 0, 81, 
    1, 27, 3, 29, 6, 18, 5, 49, 2, 42, 4, 94, 7, 44, 0, 57, 8, 61
  };
  const int q0152[] = {
    9, 9, // Number of jobs and machines
    1, 47, 8, 10, 7, 63, 3, 61, 5, 89, 0, 94, 2, 27, 6, 28, 4, 10, 
    0, 29, 3, 51, 7, 23, 2, 64, 5, 33, 1, 34, 4, 16, 8, 65, 6, 59, 
    3, 10, 7, 61, 5, 93, 0, 63, 4,  3, 6, 72, 2, 44, 8, 92, 1, 28, 
    6, 22, 3, 66, 2, 66, 8, 23, 4, 81, 7, 50, 0, 57, 1,  1, 5, 20, 
    0, 59, 7, 85, 2, 91, 4, 88, 3, 98, 5, 18, 1, 98, 6, 39, 8, 62, 
    0, 97, 1, 99, 4, 14, 8, 17, 5, 36, 7, 35, 2, 64, 3, 45, 6, 73, 
    5, 47, 8, 85, 4, 98, 6, 60, 7, 60, 0,  3, 3, 41, 2, 34, 1, 29, 
    7, 65, 2, 10, 3, 20, 5, 76, 8, 75, 4, 29, 6, 80, 1, 40, 0, 27, 
    8, 90, 1, 31, 4, 10, 3, 61, 2, 19, 6, 57, 5, 69, 7, 75, 0, 93
  };
  const int q0153[] = {
    9, 9, // Number of jobs and machines
    8, 45, 4,  3, 6, 81, 7, 93, 1, 61, 0, 12, 3, 23, 5, 86, 2, 36, 
    5,  7, 8, 44, 3, 44, 7, 21, 2, 55, 1, 81, 0, 71, 6, 42, 4, 39, 
    1, 18, 6, 29, 8, 97, 5,  7, 2, 94, 3, 83, 7, 45, 4, 69, 0, 23, 
    4, 68, 5, 90, 3, 81, 0, 67, 2, 63, 6,  4, 8, 65, 7, 37, 1, 62, 
    1, 25, 6,  8, 4,  4, 8, 75, 3,  3, 0, 96, 5, 53, 2, 16, 7, 60, 
    2, 75, 7, 38, 6, 34, 0, 96, 5, 43, 1, 70, 3, 89, 4, 52, 8, 60, 
    8, 12, 1,  7, 6, 54, 3, 86, 4, 67, 5, 54, 2,  6, 7, 11, 0, 20, 
    4, 21, 1, 89, 8, 51, 2, 45, 0, 11, 7, 50, 6, 18, 3, 90, 5, 73, 
    3, 66, 6, 57, 8,  4, 2, 66, 7, 44, 5, 99, 4, 64, 1, 74, 0, 72
  };
  const int q0154[] = {
    9, 9, // Number of jobs and machines
    8, 53, 2, 79, 6, 87, 3, 95, 7, 41, 1, 41, 4, 80, 5, 48, 0, 71, 
    6,  7, 8, 76, 3, 60, 4, 63, 1, 79, 0, 61, 7, 55, 5, 15, 2, 90, 
    7,  5, 5, 94, 4, 56, 1, 44, 0, 36, 3, 18, 8, 57, 6, 78, 2, 96, 
    5, 63, 6, 85, 8, 53, 1, 93, 2, 62, 0, 37, 3, 16, 4, 72, 7, 54, 
    3, 95, 7, 96, 4, 84, 8, 66, 6, 31, 0, 31, 1, 32, 2, 13, 5, 12, 
    8, 75, 3, 58, 0,  3, 1,  2, 7, 42, 2, 27, 5, 38, 6, 89, 4, 93, 
    0, 59, 5, 44, 7, 75, 8, 99, 2, 27, 4, 99, 1, 10, 6, 48, 3, 69, 
    5, 47, 7, 49, 1, 71, 2, 31, 0, 37, 6, 88, 3, 86, 8,  5, 4, 92, 
    0, 34, 4, 69, 6, 76, 3, 65, 7, 71, 8, 85, 5, 89, 1, 70, 2, 61
  };
  const int q0155[] = {
    9, 9, // Number of jobs and machines
    2, 45, 1, 99, 0, 14, 3, 95, 7,  6, 5, 17, 8, 38, 4, 55, 6, 12, 
    1,  2, 3, 91, 4, 26, 7,  7, 5, 47, 6, 89, 2, 48, 0, 68, 8, 18, 
    0, 78, 4, 28, 8,  9, 7, 83, 5, 53, 3, 66, 2, 90, 1,  7, 6, 82, 
    0, 16, 7, 77, 2, 70, 6,  4, 8, 90, 4, 77, 3, 37, 5, 11, 1, 85, 
    1, 46, 5,  4, 4, 56, 3, 59, 8, 50, 7, 53, 0, 54, 2, 54, 6, 74, 
    6, 99, 4, 85, 5, 74, 7, 19, 0, 71, 1, 50, 3, 89, 2, 17, 8, 30, 
    0, 91, 3, 95, 1, 37, 7, 31, 5, 90, 4, 74, 8, 58, 2, 12, 6, 18, 
    2, 24, 1, 38, 7, 43, 8, 17, 4, 81, 5, 20, 3, 92, 0, 48, 6, 21, 
    6, 80, 0, 61, 2, 50, 1, 83, 7, 29, 4, 90, 8,  4, 3, 22, 5, 59
  };
  const int q0156[] = {
    9, 9, // Number of jobs and machines
    3, 75, 4,  9, 1, 70, 7, 65, 6, 14, 8, 30, 0, 67, 2, 99, 5, 29, 
    2, 45, 0, 92, 7, 39, 1, 60, 8, 14, 4, 47, 3, 35, 6, 33, 5, 26, 
    2, 48, 5, 97, 7, 67, 4, 68, 0, 21, 6, 53, 1, 29, 3, 70, 8, 11, 
    6, 77, 5, 68, 0, 42, 2, 90, 8, 17, 1, 36, 4, 29, 3, 95, 7, 57, 
    7, 69, 8, 47, 3, 66, 4, 15, 5, 71, 0, 38, 6, 40, 2, 26, 1, 85, 
    2, 24, 0, 64, 6, 83, 3, 97, 1, 28, 8, 90, 5,  4, 4, 25, 7, 10, 
    1, 60, 3, 97, 6, 33, 7, 81, 5, 65, 0,  3, 8, 41, 4, 23, 2, 52, 
    8, 14, 0, 22, 5, 97, 1, 23, 3,  9, 7, 88, 2, 25, 4, 24, 6, 57, 
    5, 13, 3, 70, 4, 15, 7, 52, 6, 96, 2, 38, 1, 40, 8, 35, 0, 73
  };
  const int q0157[] = {
    9, 9, // Number of jobs and machines
    8, 12, 6, 66, 0, 36, 1, 27, 2, 30, 3, 40, 4, 81, 7, 11, 5, 18, 
    5, 24, 8, 57, 3, 78, 4, 12, 1, 56, 2, 29, 6, 79, 7, 27, 0, 20, 
    3, 75, 2, 25, 1, 25, 0, 54, 6, 40, 8, 12, 7, 33, 5, 51, 4, 51, 
    0, 47, 6, 16, 7, 38, 5, 33, 2, 77, 4, 65, 8, 85, 1, 43, 3, 63, 
    6, 95, 5, 54, 4, 31, 1, 65, 8, 80, 7, 68, 3, 14, 0, 54, 2, 97, 
    5, 28, 0, 41, 7, 96, 1, 76, 3, 66, 6, 77, 8,  5, 2, 10, 4, 97, 
    3, 30, 2, 16, 1, 24, 4, 76, 8, 62, 5, 45, 0, 56, 6,  9, 7, 28, 
    4, 43, 5, 47, 1, 79, 3, 58, 8, 26, 2, 78, 0, 27, 6, 72, 7, 73, 
    2, 62, 6, 62, 0, 37, 3, 86, 8, 44, 1, 94, 4, 73, 5, 85, 7, 35
  };
  const int q0158[] = {
    9, 9, // Number of jobs and machines
    8, 88, 3, 54, 5, 84, 6, 31, 7, 72, 1, 92, 0, 67, 4, 98, 2, 57, 
    4,  4, 8, 74, 0, 15, 6, 53, 3, 66, 2, 70, 7,  3, 1, 17, 5, 44, 
    3, 54, 0, 25, 6, 71, 7, 14, 2, 15, 1, 83, 8, 84, 4, 89, 5, 29, 
    5, 49, 4, 85, 8, 33, 1, 22, 7, 76, 6, 85, 0, 73, 2, 78, 3, 87, 
    4, 68, 6, 79, 3, 17, 8, 61, 2, 48, 7, 58, 5, 47, 1, 23, 0, 30, 
    8, 58, 3, 70, 6, 80, 4, 35, 5, 91, 7, 61, 0, 58, 1,  2, 2, 87, 
    6,  1, 2, 44, 5, 49, 8,  7, 7, 81, 1, 89, 0, 81, 3, 67, 4, 78, 
    7, 37, 6, 79, 1, 18, 3, 84, 8, 35, 2, 81, 4, 66, 5, 27, 0, 14, 
    1,  2, 8, 69, 2, 21, 6, 55, 5, 43, 0,  7, 4, 65, 7,  5, 3, 76
  };
  const int q0159[] = {
    9, 9, // Number of jobs and machines
    3, 37, 0, 97, 6, 72, 5, 18, 4, 26, 2, 47, 8, 54, 1, 17, 7, 26, 
    2, 26, 8, 28, 3, 50, 0, 94, 7, 21, 5, 31, 4, 68, 6, 44, 1, 74, 
    3, 15, 6, 88, 4, 47, 8, 26, 1, 73, 2, 60, 7, 53, 5, 14, 0, 25, 
    4, 91, 0, 90, 6, 61, 1, 45, 2, 67, 7, 60, 5, 20, 8, 75, 3, 48, 
    0, 36, 5, 13, 1, 95, 8, 96, 7, 41, 6, 36, 4, 96, 3, 84, 2, 99, 
    0, 41, 7, 61, 1, 26, 6,  8, 2, 81, 5, 92, 3, 95, 4, 65, 8, 43, 
    2, 45, 6, 82, 1, 31, 4, 37, 8, 81, 0, 61, 7, 77, 3, 46, 5, 60, 
    7, 33, 6, 35, 4, 76, 8, 57, 0, 57, 1, 73, 3, 89, 2, 27, 5, 42, 
    0, 93, 2, 26, 1, 86, 6,  9, 3, 24, 5,  9, 8, 50, 4, 26, 7, 32
  };
  const int q0160[] = {
    9, 9, // Number of jobs and machines
    1, 59, 0, 28, 2, 43, 5, 82, 4, 74, 6, 69, 7, 17, 8, 63, 3, 51, 
    4,  1, 7, 43, 1, 46, 0, 23, 6, 59, 8, 81, 3, 82, 2, 28, 5, 83, 
    7, 32, 4, 92, 8, 93, 1, 57, 3, 51, 6, 44, 2, 52, 0, 46, 5, 46, 
    8, 97, 0, 86, 7,  1, 3, 76, 1, 14, 2, 78, 4, 76, 5, 45, 6, 17, 
    0, 91, 4, 13, 3, 71, 2, 94, 1, 67, 6, 34, 7, 44, 5,  5, 8, 57, 
    1, 96, 4,  1, 2, 68, 6, 88, 3, 48, 7, 88, 0, 15, 5,  6, 8, 51, 
    4, 24, 5, 62, 2, 33, 3, 11, 6, 21, 7, 41, 8, 88, 0, 72, 1, 30, 
    4, 36, 2, 33, 7, 86, 8, 29, 6, 38, 5, 73, 1, 18, 3, 62, 0, 73, 
    8, 52, 5, 60, 4, 34, 1,  9, 7, 87, 0, 92, 6, 36, 3, 80, 2, 62
  };
  const int q0161[] = {
    9, 9, // Number of jobs and machines
    8, 58, 6, 91, 7, 44, 2, 66, 4, 76, 1, 75, 0, 82, 3, 61, 5, 34, 
    8, 43, 7, 77, 1,  3, 5, 90, 2, 36, 0, 88, 4, 18, 6, 91, 3, 92, 
    2, 24, 3,  8, 4, 64, 5, 63, 8, 67, 1, 61, 7, 94, 0, 75, 6,  7, 
    6, 74, 2, 75, 1, 37, 8, 15, 0, 72, 4, 57, 5, 15, 7,  4, 3, 36, 
    4, 47, 5, 56, 6, 16, 3, 69, 1, 69, 2, 48, 0, 38, 8, 77, 7, 11, 
    8, 48, 5, 36, 7, 96, 0, 14, 4, 50, 6, 85, 2, 86, 1, 19, 3, 36, 
    2, 15, 6, 51, 0, 85, 7, 84, 8, 47, 5,  1, 4, 74, 1, 55, 3, 32, 
    7, 46, 2, 33, 3, 69, 6, 13, 0,  8, 5, 88, 8, 26, 1, 14, 4, 67, 
    6, 21, 8, 44, 3, 13, 5, 15, 7, 65, 1, 86, 0, 14, 4, 67, 2, 43
  };
  const int q0162[] = {
    9, 9, // Number of jobs and machines
    4, 21, 8,  5, 2,  9, 0, 31, 6, 83, 1, 47, 3, 63, 5, 30, 7, 55, 
    3, 97, 5, 92, 0,  9, 4, 11, 7, 38, 2, 64, 8, 48, 1, 27, 6,  3, 
    1, 13, 7, 87, 8,  9, 6, 59, 2, 93, 4, 72, 3,  2, 0, 14, 5, 12, 
    2, 95, 4, 46, 3, 18, 5, 31, 7, 26, 8, 95, 6, 41, 0, 87, 1, 53, 
    8, 28, 7, 30, 2, 88, 1, 67, 3, 83, 5, 88, 0, 37, 6, 26, 4, 13, 
    3, 51, 5,  9, 4, 25, 8, 97, 1, 47, 7, 24, 2, 76, 0, 36, 6, 16, 
    5, 43, 0,  1, 1, 89, 3, 32, 8, 39, 7, 20, 6, 56, 4, 25, 2, 66, 
    3,  5, 8, 38, 5, 53, 0, 20, 1,  5, 6, 82, 4, 79, 2, 92, 7,  4, 
    4, 18, 0, 64, 5, 98, 7, 14, 8, 69, 1, 40, 3, 24, 6, 54, 2, 96
  };
  const int q0163[] = {
    9, 9, // Number of jobs and machines
    3, 93, 5, 31, 7, 46, 2, 77, 8, 23, 0, 53, 1, 91, 4,  3, 6, 71, 
    0, 84, 2, 19, 7, 33, 4, 24, 3, 81, 1, 51, 6, 68, 5, 66, 8, 83, 
    2, 24, 1, 85, 6, 51, 8,  8, 5, 35, 3, 30, 7, 36, 0, 41, 4, 17, 
    3, 40, 7, 44, 1, 58, 2, 43, 5, 80, 8, 38, 4, 99, 0, 50, 6, 69, 
    0, 44, 3,  1, 8, 49, 5, 99, 1, 25, 7, 15, 2, 52, 4, 43, 6, 23, 
    4,  4, 3, 87, 1, 44, 2, 14, 6, 41, 5, 59, 0,  6, 7, 28, 8, 76, 
    8, 37, 7, 87, 2, 32, 4, 92, 6, 21, 1, 64, 3, 25, 5, 31, 0, 18, 
    5, 77, 0, 53, 2, 74, 7,  7, 8, 13, 4, 35, 3, 14, 6, 94, 1, 51, 
    8, 10, 2, 41, 0, 83, 7, 28, 1, 19, 4, 53, 3, 34, 5, 52, 6, 92
  };
  const int q0164[] = {
    9, 9, // Number of jobs and machines
    6, 93, 8, 17, 4, 79, 5, 71, 0, 14, 3, 29, 2,  4, 1,  7, 7, 22, 
    7, 58, 8, 21, 1, 66, 0, 71, 4, 99, 6, 60, 5, 97, 2, 53, 3, 85, 
    6, 29, 4, 16, 3, 63, 0, 38, 8, 37, 7,  8, 1, 27, 2, 15, 5, 68, 
    0, 69, 4, 98, 1, 64, 2, 84, 8, 25, 7, 14, 5, 78, 6, 87, 3, 11, 
    1, 29, 3, 22, 8, 31, 5, 34, 7, 59, 4, 16, 2, 45, 0, 63, 6,  5, 
    0, 68, 6, 55, 3, 28, 8, 83, 4, 96, 2, 40, 7, 49, 5, 82, 1, 89, 
    1,  8, 6, 72, 0,  9, 8, 20, 2, 59, 3, 52, 4, 94, 5,  7, 7, 98, 
    4, 65, 7, 62, 5, 66, 0, 14, 1, 18, 8, 86, 6, 13, 3, 58, 2, 78, 
    3,  9, 7, 75, 0, 50, 2, 10, 5, 77, 1, 88, 8, 34, 4, 72, 6, 27
  };
  const int q0165[] = {
    9, 9, // Number of jobs and machines
    6, 72, 2, 46, 8, 52, 5, 30, 4, 40, 1, 27, 3, 32, 0, 71, 7, 67, 
    6, 71, 4, 90, 2, 40, 3,  9, 7, 54, 8, 83, 5, 68, 0, 48, 1, 77, 
    7, 69, 2, 84, 1, 65, 5, 71, 8, 23, 4, 31, 3, 16, 0, 67, 6, 73, 
    7, 58, 8, 17, 0, 13, 4,  4, 5, 34, 2, 12, 1, 67, 6, 29, 3, 76, 
    4, 54, 1, 75, 0, 48, 3, 57, 8, 88, 6, 94, 2, 69, 7, 48, 5, 92, 
    1, 92, 0, 51, 5, 65, 3, 41, 8, 71, 7,  4, 6,  1, 2, 88, 4, 44, 
    0, 63, 5, 48, 2, 44, 1, 65, 7, 38, 3, 22, 4, 69, 6, 50, 8,  2, 
    8, 77, 6, 94, 0, 10, 1, 99, 7, 71, 2, 13, 3, 75, 5, 81, 4, 93, 
    1, 84, 2, 49, 0, 50, 3, 90, 6, 95, 8,  2, 4, 99, 5, 64, 7, 46
  };
  const int q0166[] = {
    9, 9, // Number of jobs and machines
    1, 50, 3, 15, 0, 47, 5, 89, 2, 70, 6, 77, 8, 76, 4, 12, 7, 26, 
    6, 35, 7, 97, 3, 15, 5, 99, 1, 78, 2, 87, 0, 25, 8, 32, 4, 78, 
    7, 83, 4,  4, 2, 45, 3, 72, 1, 46, 8, 75, 0, 11, 5, 65, 6, 37, 
    0, 57, 5, 30, 7, 71, 8, 43, 1,  3, 6, 22, 3, 97, 4, 50, 2, 51, 
    1, 13, 8, 16, 0, 52, 3, 11, 2, 72, 4, 52, 7, 98, 5, 87, 6, 65, 
    4, 83, 1, 56, 0, 81, 7, 39, 3,  6, 8, 51, 6, 49, 2,  6, 5, 96, 
    3, 69, 7, 70, 8, 23, 2,  3, 1, 70, 4, 85, 0, 53, 6,  6, 5, 47, 
    3, 69, 1,  8, 6, 52, 5, 57, 8,  8, 4, 55, 2, 83, 7, 51, 0, 55, 
    6,  8, 1, 63, 0, 19, 8, 44, 7, 82, 2, 84, 3, 80, 4, 30, 5, 70
  };
  const int q0167[] = {
    9, 9, // Number of jobs and machines
    5, 76, 2, 31, 7, 50, 3, 39, 8, 18, 4,  1, 1, 38, 6, 88, 0, 56, 
    0, 30, 3, 71, 1, 19, 7, 11, 8, 29, 5, 98, 6, 39, 4, 12, 2, 62, 
    1, 13, 5, 49, 3, 82, 6, 49, 7, 41, 8, 41, 4, 73, 0,  2, 2, 27, 
    7, 70, 5, 72, 2, 93, 1, 58, 0, 12, 8, 30, 4, 12, 3,  2, 6, 36, 
    4, 84, 5,  8, 8, 15, 7, 69, 0,  4, 2, 80, 3, 48, 6, 99, 1, 92, 
    0, 78, 6, 73, 4, 41, 1, 37, 8, 73, 7, 47, 5, 36, 2, 66, 3, 24, 
    1, 13, 8, 45, 3, 92, 5,  3, 2, 51, 0, 30, 4, 10, 6, 89, 7, 62, 
    4,  7, 3,  7, 2, 17, 5,  2, 1, 23, 6, 11, 0, 20, 8, 41, 7, 71, 
    0, 22, 5, 63, 3, 96, 1, 61, 4, 79, 6,  3, 8, 51, 2, 23, 7, 17
  };
  const int q0168[] = {
    9, 9, // Number of jobs and machines
    7,  3, 0, 12, 3, 10, 5, 77, 8, 53, 1,  9, 6, 41, 2, 76, 4, 98, 
    3,  2, 4,  9, 8,  3, 2, 51, 0, 92, 6, 19, 5, 87, 1, 98, 7, 30, 
    3, 86, 8, 55, 6,  4, 7, 95, 2, 85, 0, 74, 5, 37, 4, 15, 1, 71, 
    7,  3, 8,  2, 5, 45, 2, 22, 0, 97, 3, 90, 6, 54, 1, 91, 4, 11, 
    4,  1, 7, 45, 6, 97, 8, 91, 1, 31, 2, 77, 5, 25, 3, 17, 0, 26, 
    6, 38, 3, 90, 0, 12, 4, 87, 5, 29, 8, 79, 1, 44, 2, 39, 7, 96, 
    0, 78, 4, 61, 3, 52, 8, 25, 1, 24, 2, 77, 6, 61, 5, 64, 7, 46, 
    8, 22, 4, 71, 5, 69, 3, 68, 6, 31, 0, 93, 2, 61, 1, 58, 7, 24, 
    0, 76, 4,  8, 6, 73, 3,  4, 5, 48, 1,  5, 2, 20, 8, 86, 7, 66
  };
  const int q0169[] = {
    9, 9, // Number of jobs and machines
    2, 15, 5, 57, 8, 44, 7, 31, 4, 43, 0,  6, 6, 74, 3, 15, 1, 19, 
    0, 20, 4, 81, 6, 69, 5, 88, 7, 92, 2, 11, 8, 49, 3, 26, 1, 98, 
    6, 54, 5, 80, 2, 30, 0, 35, 8, 36, 4, 86, 7, 49, 3, 71, 1, 54, 
    3, 77, 7, 31, 4,  6, 5, 35, 2, 16, 1, 89, 6, 91, 8, 82, 0, 63, 
    2, 37, 1, 22, 4, 90, 3, 76, 7, 99, 6, 59, 8, 25, 0, 70, 5,  1, 
    2, 74, 5,  2, 6, 95, 0, 80, 1,  2, 4, 27, 3, 83, 7, 27, 8, 79, 
    3, 15, 1, 25, 4, 47, 2, 50, 8, 53, 5, 68, 6, 19, 7, 78, 0, 43, 
    6, 12, 3, 50, 8,  6, 1, 19, 7, 63, 2,  1, 0, 59, 5, 40, 4, 86, 
    5,  4, 8, 21, 3, 16, 4, 12, 1, 96, 0, 88, 2, 13, 7, 40, 6, 28
  };
  const int q0170[] = {
    9, 9, // Number of jobs and machines
    5, 33, 6,  1, 2, 21, 3, 37, 0,  2, 4, 85, 7, 56, 8,  1, 1,  5, 
    1, 20, 2, 82, 5, 26, 3, 72, 0, 67, 7, 20, 8, 78, 6, 98, 4, 57, 
    3, 66, 0, 75, 8, 65, 6, 50, 4, 41, 2, 16, 7, 81, 5, 90, 1, 98, 
    5, 73, 7, 45, 0, 44, 6, 42, 1, 79, 2, 97, 3,  7, 8, 59, 4, 75, 
    0, 40, 3, 88, 4,  9, 6, 85, 1, 38, 2, 60, 7,  9, 5, 37, 8, 78, 
    7, 45, 5, 74, 0, 22, 4, 77, 3, 67, 2, 94, 1, 29, 6, 73, 8, 77, 
    6,  5, 5, 96, 7, 14, 2, 20, 3,  4, 8, 44, 1, 55, 4, 74, 0, 76, 
    3, 53, 5, 32, 1, 55, 0, 97, 4, 83, 6, 39, 8, 83, 2, 64, 7, 86, 
    8, 84, 0, 42, 3, 29, 1, 39, 2, 95, 5, 13, 4, 11, 6, 22, 7,  3
  };
  const int q0171[] = {
    9, 9, // Number of jobs and machines
    5, 69, 1, 73, 4, 35, 7, 25, 0, 46, 3, 42, 6, 68, 2, 96, 8, 23, 
    2, 97, 5, 59, 8, 34, 3, 10, 6, 31, 7,  5, 1, 19, 4, 19, 0,  4, 
    7, 70, 0, 90, 4,  2, 5, 65, 8, 77, 6, 59, 2, 98, 1, 85, 3, 69, 
    0, 76, 3, 67, 7, 76, 6, 80, 8, 57, 4, 81, 2, 66, 1, 78, 5, 33, 
    7, 24, 2, 60, 3, 88, 8, 71, 4,  4, 5, 68, 1, 36, 0, 95, 6, 33, 
    3, 63, 4, 62, 1, 95, 5, 73, 7, 54, 6,  4, 2, 27, 0, 21, 8, 57, 
    2, 54, 5, 72, 3, 58, 1, 71, 8, 75, 7,  9, 6, 30, 4, 37, 0, 34, 
    0, 29, 6, 73, 1, 29, 3, 48, 2, 23, 5, 92, 4, 63, 8, 86, 7, 19, 
    1,  1, 7, 79, 8, 99, 5, 92, 4, 85, 6, 41, 3, 11, 2, 21, 0, 76
  };
  const int q0172[] = {
    9, 9, // Number of jobs and machines
    4, 48, 8, 96, 7, 50, 1, 91, 0, 55, 5, 97, 6, 73, 2, 93, 3, 65, 
    3,  5, 2, 60, 7, 37, 0, 48, 4, 84, 1, 82, 6, 67, 8,  9, 5, 57, 
    7, 68, 8, 14, 2, 74, 5, 81, 4, 78, 1,  9, 0, 73, 3, 11, 6, 87, 
    1, 55, 4, 53, 8, 74, 5, 11, 6, 90, 0,  3, 2, 80, 7, 85, 3, 42, 
    4, 66, 2, 73, 3, 72, 6, 61, 8, 83, 0, 38, 1, 47, 7, 38, 5, 25, 
    6, 75, 4, 12, 0, 89, 3, 30, 5, 23, 8, 13, 2, 62, 1, 43, 7, 70, 
    0, 55, 8, 87, 6, 10, 2, 87, 7, 48, 4, 52, 1, 63, 3, 59, 5, 31, 
    6, 75, 4, 64, 3, 12, 0, 30, 7, 78, 8,  5, 2, 51, 5, 34, 1, 43, 
    4, 75, 2, 59, 1, 70, 6, 61, 0, 12, 3, 21, 8, 35, 7, 80, 5, 24
  };
  const int q0173[] = {
    9, 9, // Number of jobs and machines
    4, 18, 7, 91, 1, 13, 6, 26, 8, 54, 2, 33, 5, 37, 0, 24, 3, 85, 
    8, 50, 7, 67, 3, 39, 0, 23, 6, 58, 5, 50, 2, 83, 4, 22, 1, 43, 
    4, 58, 3,  7, 7, 90, 6,  5, 0, 48, 8,  7, 1, 46, 5, 17, 2, 93, 
    5, 54, 8,  3, 4, 41, 7, 47, 1, 51, 6, 38, 0, 98, 3, 44, 2,  5, 
    4, 91, 3, 31, 8, 43, 0, 48, 6, 23, 2, 88, 1, 29, 7, 20, 5, 47, 
    6, 29, 4, 80, 0, 23, 1, 34, 2, 84, 8, 42, 5, 89, 7, 18, 3, 14, 
    2, 31, 7, 95, 5, 87, 8, 54, 1, 81, 3, 20, 4, 86, 6, 11, 0, 45, 
    8, 89, 3, 99, 1, 16, 4, 46, 7, 21, 6, 94, 2, 14, 0, 11, 5, 79, 
    2,  4, 5, 93, 1, 45, 7, 43, 3, 98, 8, 16, 6,  4, 4, 60, 0,  6
  };
  const int q0174[] = {
    9, 9, // Number of jobs and machines
    7, 16, 4, 36, 3,  3, 6, 67, 2, 69, 8,  3, 5, 94, 0, 91, 1, 51, 
    7, 83, 3,  3, 0, 20, 4, 33, 8, 98, 6,  4, 5, 92, 2,  1, 1, 85, 
    8, 92, 4,  2, 1, 99, 0, 60, 6, 72, 2, 28, 5, 95, 3, 86, 7, 91, 
    8, 30, 7, 40, 0, 58, 1, 91, 6, 17, 4, 78, 3, 36, 5, 84, 2, 18, 
    5, 29, 0, 35, 4,  6, 6, 34, 1, 92, 7, 13, 8, 64, 3, 68, 2, 94, 
    8, 85, 0, 72, 1, 15, 3, 53, 4,  3, 6, 50, 7, 59, 5, 57, 2, 22, 
    2, 80, 4, 24, 0, 93, 5, 76, 6, 39, 7, 98, 3,  2, 1, 57, 8, 32, 
    3, 12, 0,  8, 5, 57, 2, 69, 1, 31, 8, 11, 7, 39, 4, 78, 6, 28, 
    4, 91, 2, 73, 1, 10, 0, 67, 5, 30, 7, 90, 6, 67, 8, 56, 3, 61
  };
  const int q0175[] = {
    9, 9, // Number of jobs and machines
    8, 36, 0, 47, 3, 19, 1,  3, 7, 55, 2, 57, 5, 53, 4, 20, 6, 37, 
    1, 73, 3, 18, 8, 93, 6, 82, 5, 38, 4, 61, 0, 19, 7, 70, 2, 89, 
    1, 21, 4, 21, 0, 83, 7, 22, 3, 13, 8, 34, 6, 95, 5, 80, 2, 10, 
    2, 14, 3, 19, 5, 61, 8, 17, 7, 50, 4, 65, 1, 27, 0,  1, 6, 93, 
    6, 97, 0, 18, 2,  7, 1, 55, 3,  3, 7, 19, 8, 47, 4, 67, 5, 85, 
    1, 35, 2, 49, 6, 15, 4, 48, 7, 25, 5, 70, 3, 15, 8, 10, 0, 60, 
    6, 97, 3, 14, 1, 76, 8, 19, 0, 74, 4, 12, 2, 98, 5, 60, 7, 22, 
    0, 76, 3, 31, 8, 71, 4,  9, 2, 23, 1, 40, 5, 97, 6, 41, 7, 35, 
    4, 33, 1, 14, 8, 33, 7, 60, 2, 46, 6, 84, 3, 77, 0, 29, 5, 97
  };
  const int q0176[] = {
    9, 9, // Number of jobs and machines
    2, 39, 1, 77, 4, 48, 8, 90, 3, 99, 7, 75, 0, 46, 6, 80, 5, 50, 
    0, 11, 6, 38, 2, 48, 7, 30, 5, 13, 8, 88, 3,  3, 1, 62, 4, 10, 
    1, 91, 6, 77, 8, 22, 4, 71, 3,  8, 5, 31, 0, 37, 7, 53, 2, 34, 
    0, 90, 5, 86, 8, 56, 2, 29, 3, 59, 4, 93, 1, 55, 6, 43, 7, 29, 
    6, 36, 3, 15, 2, 59, 7, 80, 1, 52, 5, 40, 0, 40, 4, 15, 8, 10, 
    1, 71, 2, 11, 8, 30, 0, 63, 7, 44, 5, 78, 6, 43, 3, 66, 4, 99, 
    4, 13, 1, 62, 7, 83, 0, 78, 2,  8, 5, 62, 3, 69, 6, 60, 8, 71, 
    5, 59, 6, 30, 1, 49, 4, 37, 2, 90, 0, 61, 8, 51, 7, 29, 3, 61, 
    2, 45, 1, 73, 3, 45, 6,  4, 5, 12, 4, 99, 0,  3, 8, 72, 7, 38
  };
  const int q0177[] = {
    9, 9, // Number of jobs and machines
    2, 71, 5, 56, 8, 85, 6, 39, 0, 80, 4, 17, 1, 48, 7, 95, 3, 92, 
    8, 97, 7,  6, 3, 14, 4, 88, 5, 76, 2, 14, 0, 42, 1, 93, 6, 73, 
    1, 94, 0, 81, 6, 43, 2, 93, 7, 94, 4, 50, 3, 26, 5, 17, 8, 69, 
    6, 97, 4, 78, 8, 89, 1, 97, 2, 13, 5, 42, 0,  4, 3, 80, 7, 21, 
    7, 29, 4, 50, 3, 73, 2, 69, 8, 12, 5, 74, 1, 43, 6, 81, 0, 38, 
    7, 44, 8, 74, 3, 94, 0, 82, 5, 29, 1, 17, 2,  8, 6, 35, 4, 65, 
    7, 32, 5, 59, 6,  9, 2, 72, 3, 98, 8, 46, 1, 76, 4, 78, 0, 27, 
    0,  8, 5, 63, 4, 12, 2, 49, 7, 80, 1, 27, 8, 73, 6, 25, 3, 19, 
    5, 61, 7, 65, 6, 27, 2, 74, 1, 78, 4, 94, 3, 51, 0, 38, 8, 39
  };
  const int q0178[] = {
    9, 9, // Number of jobs and machines
    0, 16, 8,  8, 7, 74, 2, 91, 5,  6, 4, 29, 6, 17, 1, 11, 3, 22, 
    1, 99, 5, 80, 0, 31, 8,  4, 7, 68, 6, 88, 3, 68, 4, 12, 2, 58, 
    8, 80, 0, 66, 3, 63, 4, 48, 5, 99, 1, 80, 2,  6, 6, 10, 7, 86, 
    0, 47, 3, 46, 7, 87, 5, 64, 2, 57, 4, 21, 8, 37, 1, 54, 6,  7, 
    3, 65, 6, 79, 5,  5, 0,  1, 4, 32, 2, 78, 1, 76, 8, 50, 7, 49, 
    5, 58, 2,  7, 1, 29, 7, 21, 3, 69, 4, 65, 0, 99, 6, 47, 8, 20, 
    0,  6, 8, 61, 2, 59, 3,  9, 6, 82, 7, 98, 5, 19, 1, 95, 4, 72, 
    6, 47, 2, 78, 3, 80, 8, 49, 4, 38, 7, 61, 5, 42, 0, 94, 1, 46, 
    0, 11, 7, 38, 3, 74, 2, 39, 1, 74, 8, 65, 5, 85, 4, 91, 6, 87
  };
  const int q0179[] = {
    9, 9, // Number of jobs and machines
    5, 38, 3, 45, 6, 21, 8, 78, 0, 94, 7, 81, 4, 20, 2, 88, 1, 20, 
    8, 33, 6, 38, 2, 59, 0, 38, 7, 60, 3, 21, 4, 48, 1, 56, 5, 23, 
    2, 29, 0, 14, 8, 69, 6, 28, 3,  2, 7, 21, 4, 13, 1, 21, 5, 84, 
    8, 24, 4, 41, 6, 92, 2, 48, 5, 43, 7, 16, 1, 80, 3, 68, 0, 51, 
    7, 94, 0,  4, 4, 42, 3, 66, 1, 34, 6, 72, 2, 32, 8, 87, 5,  3, 
    6, 26, 1, 50, 8, 42, 2, 35, 7, 16, 4, 99, 3, 88, 0, 59, 5, 30, 
    0, 27, 1, 64, 2, 52, 8,  8, 5, 46, 7,  2, 6, 66, 3, 71, 4, 35, 
    6,  4, 3, 18, 7, 86, 4, 17, 1, 95, 2, 66, 0, 92, 8, 44, 5, 85, 
    2, 53, 6, 18, 3, 18, 8, 90, 5, 31, 1, 16, 0, 19, 4, 71, 7, 13
  };
  const int q0180[] = {
    9, 9, // Number of jobs and machines
    8,  7, 3, 27, 2, 83, 7, 67, 5, 21, 1, 50, 4,  5, 6,  6, 0, 99, 
    3, 71, 6, 73, 8, 64, 4, 20, 1, 43, 5, 42, 0, 17, 2, 95, 7, 33, 
    6, 12, 8, 48, 3, 73, 0, 44, 2, 38, 4, 37, 1, 26, 7, 12, 5,  4, 
    7, 88, 1, 57, 5,  7, 0, 16, 4, 38, 2, 88, 3,  6, 6,  4, 8, 21, 
    6, 35, 0, 74, 3, 76, 1, 85, 4, 35, 8, 49, 7, 62, 2, 33, 5, 35, 
    6, 33, 3,  9, 1,  1, 8, 85, 7, 45, 2, 59, 5, 51, 4, 88, 0, 67, 
    0, 90, 3, 32, 4, 17, 5, 69, 7,  4, 8, 41, 1,  7, 6, 56, 2,  8, 
    4, 96, 8, 58, 3, 93, 0, 62, 1, 72, 2, 26, 6, 62, 5, 53, 7,  9, 
    3, 43, 8, 15, 0,  4, 7, 27, 5, 72, 2, 56, 4,  9, 6, 12, 1, 67
  };
  const int q0181[] = {
    9, 9, // Number of jobs and machines
    1, 60, 3, 77, 8, 93, 0, 60, 7, 10, 6,  4, 4, 92, 2, 16, 5, 30, 
    4, 14, 2, 18, 1, 33, 8, 33, 0, 18, 6, 49, 7, 43, 3, 68, 5, 31, 
    4, 79, 2, 32, 1, 44, 8, 64, 7, 22, 3, 77, 0, 25, 6, 59, 5, 68, 
    1, 87, 8, 89, 2, 37, 0, 49, 4,  7, 7, 70, 3, 38, 5, 33, 6, 74, 
    7, 25, 0, 71, 4,  7, 1, 98, 2, 87, 5, 86, 3, 71, 6, 51, 8, 34, 
    4, 66, 6, 37, 8, 92, 3, 47, 0,  7, 5, 91, 7, 55, 1, 81, 2, 15, 
    2, 45, 0, 38, 6, 88, 4,  2, 3, 21, 5, 77, 1, 28, 8, 62, 7, 97, 
    8, 80, 7, 96, 3, 15, 2, 35, 5, 90, 4, 71, 0, 52, 6, 60, 1, 69, 
    6,  6, 0, 75, 3, 71, 2,  6, 4, 27, 5, 41, 8, 49, 7, 97, 1, 48
  };
  const int q0182[] = {
    9, 9, // Number of jobs and machines
    0, 18, 4, 61, 2, 53, 5, 78, 1, 99, 8, 77, 3, 88, 7, 62, 6, 60, 
    4, 84, 6, 55, 2,  9, 0, 80, 5, 41, 7, 84, 1, 93, 3, 58, 8, 53, 
    1, 42, 0, 21, 4, 93, 5, 51, 6, 64, 3, 80, 7,  7, 2, 15, 8, 10, 
    0, 72, 4, 71, 8, 44, 2,  3, 1, 65, 7, 97, 5, 69, 6, 39, 3, 31, 
    2, 41, 6, 50, 3, 92, 5, 31, 7, 16, 0, 67, 8, 26, 1, 93, 4, 20, 
    2, 53, 0, 67, 6, 43, 8, 99, 3, 97, 5, 40, 7, 94, 1, 43, 4, 14, 
    3, 13, 6, 58, 2,  7, 8, 86, 1, 11, 5, 25, 4, 13, 7, 23, 0, 95, 
    1, 25, 0,  8, 4, 41, 2, 14, 5, 87, 3, 72, 8,  4, 6, 49, 7, 77, 
    2, 93, 0, 23, 6, 21, 4, 60, 5, 63, 7, 52, 3, 98, 1,  7, 8, 96
  };
  const int q0183[] = {
    9, 9, // Number of jobs and machines
    8, 43, 6, 49, 1, 96, 7, 55, 2, 78, 3, 94, 0,  8, 5, 89, 4,  5, 
    6,  7, 4, 63, 0, 20, 8, 43, 5, 69, 7, 97, 1, 61, 2, 91, 3, 12, 
    0, 95, 4, 60, 5, 30, 8, 50, 6, 17, 2, 21, 7, 91, 3, 61, 1,  3, 
    0, 53, 3, 67, 2, 16, 1, 41, 5, 85, 7, 76, 4, 36, 8, 17, 6, 16, 
    7,  7, 3, 52, 4,  4, 5, 85, 0, 56, 8, 30, 1, 35, 2, 43, 6, 52, 
    6, 52, 1, 19, 4, 89, 3, 74, 0, 93, 5, 22, 8, 74, 7,  1, 2, 14, 
    2, 30, 3, 22, 4, 26, 8, 55, 0, 86, 7,  2, 5,  9, 1, 10, 6, 10, 
    7, 69, 0, 61, 3, 69, 5, 35, 6, 44, 2,  7, 8, 94, 1, 77, 4, 92, 
    5, 18, 1, 59, 7, 17, 4, 23, 3, 22, 8, 39, 6, 94, 2, 32, 0, 23
  };
  const int q0184[] = {
    9, 9, // Number of jobs and machines
    4, 30, 2, 45, 5, 51, 1,  8, 8, 41, 3, 11, 7, 64, 6, 24, 0, 59, 
    0, 82, 6, 66, 3, 77, 5, 59, 2, 37, 1, 43, 8, 26, 7, 86, 4, 71, 
    7, 13, 5,  8, 1,  8, 3, 17, 6, 85, 8, 11, 2, 60, 4,  4, 0, 46, 
    2, 78, 3, 85, 0, 71, 1, 57, 4, 69, 8, 38, 6,  7, 5, 95, 7, 26, 
    7, 51, 6, 59, 1, 20, 3, 70, 8, 40, 0, 18, 4, 27, 2, 28, 5, 74, 
    6, 97, 3, 36, 2, 37, 7, 45, 8, 55, 0, 31, 1, 26, 5, 51, 4, 91, 
    6, 90, 2, 46, 4, 72, 1, 27, 7, 91, 3,  2, 5, 90, 8, 36, 0, 16, 
    7, 18, 2, 87, 4, 23, 1, 93, 0,  1, 6, 85, 5, 61, 3, 47, 8, 22, 
    7,  6, 1, 58, 2, 90, 3, 11, 6, 29, 8, 12, 5, 24, 4, 91, 0, 70
  };
  const int q0185[] = {
    9, 9, // Number of jobs and machines
    4, 74, 6,  8, 1, 99, 8, 45, 0, 74, 7, 55, 2, 59, 3,  4, 5, 43, 
    5, 52, 3, 38, 6, 30, 0, 34, 1, 74, 4, 75, 2, 16, 7, 17, 8, 43, 
    5, 66, 7, 53, 1, 34, 0, 15, 4, 39, 3, 43, 8, 27, 6, 49, 2, 79, 
    1, 31, 4, 81, 7, 40, 6, 10, 8, 29, 2, 96, 3, 59, 0, 45, 5,  8, 
    3,  4, 7,  4, 5, 71, 2, 93, 8, 88, 1, 76, 4, 84, 6, 20, 0, 48, 
    3, 15, 6, 51, 2, 79, 1, 69, 8, 23, 0, 76, 4, 65, 7, 81, 5, 98, 
    8, 15, 3, 74, 6, 51, 5, 16, 7, 94, 0,  7, 1, 39, 4, 22, 2, 45, 
    6, 46, 3, 76, 0, 90, 4, 85, 5, 25, 7, 22, 8, 56, 1, 41, 2,  4, 
    0, 18, 5, 95, 3, 96, 7, 82, 8, 62, 4, 88, 1, 44, 6, 60, 2, 51
  };
  const int q0186[] = {
    9, 9, // Number of jobs and machines
    0, 45, 4, 70, 3, 97, 1, 72, 7, 22, 5, 68, 2, 40, 8, 24, 6, 65, 
    3, 15, 1, 80, 8, 76, 5, 64, 7, 59, 6, 12, 0, 76, 4, 13, 2, 21, 
    3, 88, 7, 51, 4, 47, 0, 56, 6, 55, 1,  7, 2, 27, 5, 20, 8, 57, 
    6, 79, 1, 36, 3, 36, 5, 55, 4, 50, 2, 84, 0,  1, 7, 37, 8,  5, 
    0, 37, 4, 62, 6, 25, 1, 36, 3, 95, 5, 87, 2, 22, 8, 72, 7, 96, 
    8, 43, 2, 10, 7, 19, 5,  2, 3, 85, 0,  4, 1,  1, 4,  9, 6,  7, 
    0, 19, 1, 83, 7, 11, 6, 77, 3, 51, 5, 86, 4, 62, 8,  3, 2, 83, 
    5, 36, 4,  4, 3,  4, 6, 13, 0, 89, 2, 10, 8, 12, 1, 72, 7, 92, 
    3, 56, 4, 33, 6, 73, 2, 93, 8, 29, 0, 49, 1, 45, 5, 16, 7, 83
  };
  const int q0187[] = {
    9, 9, // Number of jobs and machines
    2, 84, 5, 14, 1, 78, 8, 58, 3, 20, 7, 82, 6, 35, 0, 91, 4,  1, 
    4, 54, 0, 28, 2, 17, 7, 64, 5, 40, 3, 94, 6, 92, 1, 15, 8, 37, 
    7, 59, 0, 60, 6, 55, 1,  5, 8, 61, 5, 91, 4, 41, 3, 51, 2,  4, 
    2, 69, 1, 67, 8, 67, 4, 48, 5, 97, 0, 46, 3, 59, 7, 79, 6, 58, 
    5, 89, 6, 93, 0, 68, 8, 76, 1, 46, 7, 83, 3, 28, 2, 33, 4, 64, 
    6,  5, 8, 29, 5, 91, 0, 58, 1, 67, 7, 96, 3, 54, 2, 93, 4, 57, 
    3, 27, 5, 90, 4, 39, 6, 82, 2, 76, 1, 61, 8, 50, 0, 22, 7, 21, 
    5, 43, 1, 27, 3, 79, 2, 11, 6, 10, 8, 94, 4, 52, 7, 75, 0, 22, 
    3, 88, 4, 78, 8, 97, 7, 66, 1, 76, 6, 21, 5, 92, 0,  4, 2, 71
  };
  const int q0188[] = {
    9, 9, // Number of jobs and machines
    4, 50, 1, 59, 2, 68, 8, 18, 0, 97, 6, 53, 3, 63, 7, 54, 5, 21, 
    7, 32, 8, 82, 5, 93, 4, 19, 6, 19, 2, 48, 3, 83, 0, 27, 1, 24, 
    3, 65, 7, 18, 4, 35, 1, 10, 0,  5, 5, 12, 2, 34, 6, 17, 8, 18, 
    0, 60, 5, 83, 1, 68, 6, 94, 4, 44, 2,  3, 8, 92, 7, 60, 3, 13, 
    2, 93, 7, 10, 6, 73, 4, 64, 5, 59, 0, 15, 1, 30, 8, 94, 3, 77, 
    6, 52, 2, 58, 0,  2, 3, 26, 7, 37, 5,  6, 4, 74, 8,  1, 1, 31, 
    5, 56, 2, 32, 7, 36, 1, 61, 6, 60, 4, 61, 3, 69, 8, 17, 0, 77, 
    8, 44, 5, 69, 0, 64, 4, 60, 1, 10, 7, 83, 6, 77, 3, 53, 2, 79, 
    7, 63, 1, 20, 5, 58, 3, 53, 0, 27, 4, 89, 2, 65, 8, 99, 6, 16
  };
  const int q0189[] = {
    9, 9, // Number of jobs and machines
    1, 31, 2, 44, 0, 56, 6, 65, 5, 96, 3, 16, 4, 44, 8, 91, 7, 63, 
    2, 65, 3, 96, 4, 20, 1,  9, 7,  2, 6, 96, 8, 80, 5, 55, 0, 49, 
    1, 10, 2, 75, 3, 39, 8, 38, 4, 96, 6, 64, 0,  8, 7, 13, 5, 96, 
    6, 39, 4, 14, 5, 79, 1, 55, 2, 62, 7,  3, 8, 31, 0, 42, 3, 53, 
    2, 34, 8, 68, 7, 22, 1, 93, 5, 95, 0, 39, 3, 11, 4, 33, 6, 14, 
    5, 43, 3,  8, 6, 60, 2,  1, 4, 36, 7, 75, 8, 88, 0, 25, 1, 63, 
    4, 66, 3,  5, 0, 96, 5, 60, 6, 29, 1, 97, 8, 67, 7,  6, 2, 62, 
    8, 36, 5, 99, 0, 54, 2, 11, 7, 52, 4, 28, 1,  6, 3, 23, 6, 70, 
    3, 55, 7, 52, 4, 33, 2,  8, 8, 52, 1, 10, 0, 29, 6, 88, 5, 28
  };
  const int q0190[] = {
    9, 9, // Number of jobs and machines
    8, 39, 3, 16, 0, 95, 2, 38, 6, 48, 1, 77, 4, 55, 5, 64, 7,  8, 
    6,  7, 3, 12, 2, 35, 1, 50, 8, 11, 0, 72, 7, 60, 4, 79, 5, 35, 
    6, 64, 4, 46, 3, 42, 8, 48, 2, 63, 1, 96, 0,  5, 7, 70, 5, 94, 
    2, 61, 1, 22, 8, 70, 3, 28, 4, 51, 6, 68, 0, 25, 5, 86, 7, 82, 
    6, 59, 4, 36, 5, 71, 1, 70, 2, 22, 3, 37, 0, 97, 8, 22, 7, 82, 
    4,  3, 2, 75, 3, 73, 8, 95, 7, 54, 0, 33, 5, 58, 1, 32, 6,  8, 
    3, 39, 7,  1, 5, 54, 4, 24, 8,  3, 0, 11, 6, 10, 1, 33, 2, 16, 
    0,  1, 2, 57, 3, 31, 5, 53, 7, 94, 6, 13, 8, 16, 4, 18, 1, 37, 
    3, 95, 1, 64, 7, 75, 8, 47, 0, 64, 6, 76, 5, 58, 4, 99, 2, 97
  };
  const int q0191[] = {
    9, 9, // Number of jobs and machines
    5, 13, 0,  6, 6, 65, 2, 34, 7,  3, 8, 73, 1,  6, 4, 86, 3, 58, 
    0,  2, 3, 45, 8, 26, 5,  1, 1, 92, 7, 49, 4, 30, 2, 28, 6, 12, 
    7, 72, 3, 71, 0, 12, 5, 45, 1, 68, 4, 56, 6, 26, 8,  9, 2, 21, 
    1, 94, 5, 53, 0,  6, 4, 11, 3, 82, 7, 53, 2, 49, 8, 65, 6, 79, 
    6, 97, 7, 79, 3, 56, 5, 31, 1, 57, 8, 23, 4, 41, 2, 63, 0, 18, 
    3, 14, 0, 80, 4,  2, 1, 33, 7, 40, 5, 21, 6, 32, 8, 79, 2, 28, 
    3, 30, 0, 52, 6, 16, 4, 69, 5, 81, 8, 57, 7, 28, 1, 52, 2, 32, 
    3, 33, 2, 45, 4, 62, 7,  8, 8, 24, 0, 44, 5, 95, 1, 29, 6, 94, 
    6,  8, 0, 85, 4,  5, 5, 64, 1, 18, 8, 67, 3, 21, 2, 46, 7, 19
  };
  const int q0192[] = {
    9, 9, // Number of jobs and machines
    8, 14, 1, 24, 5,  8, 6, 79, 4,  5, 2, 15, 7, 93, 3, 89, 0, 14, 
    0, 66, 1, 24, 5, 31, 3, 13, 7, 98, 8, 78, 2, 32, 4, 65, 6, 62, 
    3, 39, 0, 88, 8, 94, 6, 76, 2, 43, 4, 31, 1, 55, 7, 44, 5, 92, 
    3, 99, 7, 86, 6, 32, 5,  3, 2, 97, 0, 15, 8, 27, 1, 53, 4, 25, 
    1, 63, 6, 78, 0,  7, 3, 57, 5,  3, 7, 75, 4, 93, 2,  8, 8, 91, 
    4, 87, 7, 38, 5, 19, 8, 11, 2,  6, 1, 22, 6, 75, 0, 83, 3, 73, 
    4, 41, 2, 68, 0, 50, 8,  1, 3, 98, 6, 92, 5, 80, 1, 85, 7, 19, 
    6, 23, 5, 33, 0, 39, 1,  6, 2, 22, 7, 41, 8, 37, 4, 55, 3, 38, 
    7, 83, 8, 43, 0, 89, 1, 64, 6, 52, 5, 35, 4, 29, 2, 71, 3, 95
  };
  const int q0193[] = {
    9, 9, // Number of jobs and machines
    7, 88, 0, 61, 8, 11, 2, 84, 5,  8, 6, 64, 1, 67, 4, 82, 3, 79, 
    3, 40, 5, 43, 2, 21, 8, 76, 7, 40, 6, 56, 1, 36, 4, 86, 0, 15, 
    2, 65, 7,  7, 1,  4, 0, 25, 4, 44, 3, 61, 5, 20, 6, 39, 8, 76, 
    4, 92, 2, 77, 7, 56, 5, 67, 0,  1, 3, 60, 1, 76, 8, 51, 6, 53, 
    1, 47, 7, 28, 2, 45, 4, 23, 8, 87, 5, 85, 3, 28, 0, 84, 6, 34, 
    5, 71, 4, 36, 3, 26, 0, 48, 8, 95, 7, 12, 1, 22, 2, 52, 6, 60, 
    8, 41, 2, 57, 5, 64, 7, 80, 0,  5, 6, 79, 3, 48, 4, 76, 1, 12, 
    3, 43, 6, 44, 5,  7, 0, 52, 1, 95, 4, 90, 7, 65, 2, 81, 8, 65, 
    1, 67, 8, 17, 2, 46, 0, 29, 3,  4, 5, 91, 6, 29, 4, 19, 7, 61
  };
  const int q0194[] = {
    9, 9, // Number of jobs and machines
    0, 28, 7, 42, 8, 21, 3, 38, 6,  2, 2, 24, 1, 16, 4, 16, 5, 77, 
    3, 71, 0, 35, 5, 22, 1, 39, 6, 38, 2, 86, 7, 36, 4, 68, 8, 47, 
    5, 64, 4, 17, 1, 58, 8, 71, 6, 38, 0, 49, 2, 26, 7, 18, 3, 73, 
    1,  4, 4,  4, 7, 47, 0, 49, 8, 16, 6, 41, 2, 88, 3,  6, 5,  8, 
    5, 32, 6, 85, 8,  2, 4, 78, 7, 26, 1, 62, 2, 37, 3, 31, 0, 41, 
    0, 35, 2, 70, 1, 15, 3, 38, 6, 22, 4, 14, 7, 28, 8, 88, 5,  8, 
    2, 33, 1, 87, 4, 49, 6, 68, 3, 58, 7, 15, 5, 27, 8, 70, 0, 37, 
    3, 14, 1, 78, 8, 85, 4, 46, 5,  4, 6, 94, 7, 85, 0, 48, 2, 16, 
    7, 69, 1, 77, 2, 85, 0, 36, 8, 28, 6, 74, 5, 31, 3,  7, 4, 17
  };
  const int q0195[] = {
    9, 9, // Number of jobs and machines
    5, 76, 3, 91, 8, 61, 6, 77, 0, 69, 7, 45, 4, 18, 1, 17, 2, 92, 
    3, 76, 6, 42, 2, 72, 1, 19, 0, 91, 7, 43, 4, 51, 5, 69, 8, 80, 
    8, 75, 5, 89, 1, 13, 3,  6, 6,  5, 4, 29, 7, 13, 2, 81, 0, 13, 
    0, 79, 2, 32, 5, 71, 3, 28, 7, 28, 4,  2, 1, 68, 8, 30, 6, 84, 
    6, 35, 0, 51, 1,  6, 5, 63, 4, 62, 7, 25, 3, 38, 8, 66, 2, 23, 
    3, 44, 6, 95, 7, 81, 0,  6, 5, 49, 8, 62, 1,  1, 2, 48, 4, 37, 
    1, 79, 8, 93, 2, 78, 6, 29, 5,  4, 0, 27, 4, 47, 7, 77, 3, 74, 
    7, 64, 6, 27, 8, 84, 2, 96, 3, 66, 0, 88, 5, 35, 4, 60, 1, 10, 
    2, 62, 7, 32, 6,  3, 4, 70, 1, 74, 0, 10, 8, 94, 5, 28, 3, 51
  };
  const int q0196[] = {
    9, 9, // Number of jobs and machines
    3, 49, 5, 98, 6, 49, 7, 88, 0, 43, 4,  3, 1, 59, 2, 48, 8, 33, 
    1, 45, 0, 43, 3, 43, 6, 61, 2, 43, 8, 88, 4, 17, 5, 48, 7, 88, 
    3, 69, 6, 95, 0, 99, 1, 78, 7, 58, 8, 42, 2, 18, 5,  1, 4, 46, 
    3, 88, 6, 62, 2, 10, 5, 36, 4, 93, 7, 51, 0, 98, 8, 97, 1, 65, 
    4, 73, 7,  5, 0,  3, 6, 47, 1, 83, 2, 99, 5, 42, 3, 23, 8, 92, 
    0, 38, 4, 11, 6, 21, 1,  1, 2, 26, 5, 35, 7, 47, 8, 53, 3,  8, 
    6, 89, 5, 96, 0, 70, 8, 28, 3, 71, 2, 20, 1, 20, 4, 43, 7, 89, 
    2,  6, 4, 61, 1, 35, 7, 18, 8, 70, 6, 58, 3,  2, 0, 93, 5, 98, 
    6, 50, 1,  5, 2, 10, 3, 51, 5, 68, 4, 69, 7, 40, 8, 76, 0, 97
  };
  const int q0197[] = {
    9, 9, // Number of jobs and machines
    4, 35, 2, 55, 6,  1, 0, 76, 1, 63, 5, 95, 7,  3, 8, 58, 3,  3, 
    2, 53, 4,  3, 1, 95, 7, 68, 8, 90, 5, 35, 0, 53, 6, 87, 3, 10, 
    8, 34, 2, 55, 5, 42, 7, 18, 4,  2, 3, 79, 1, 71, 6, 56, 0, 34, 
    5, 45, 0, 39, 7, 90, 3,  1, 8, 22, 4, 81, 6, 95, 1, 28, 2, 14, 
    6, 34, 1, 43, 3, 20, 2, 74, 4, 90, 0, 75, 7, 68, 8, 19, 5, 71, 
    1, 24, 5, 63, 6,  2, 0, 18, 2, 54, 4,  5, 3, 34, 8, 79, 7, 27, 
    7, 49, 2, 71, 4, 52, 3, 79, 1, 34, 8,  6, 5, 99, 6, 48, 0, 45, 
    6, 88, 4, 84, 1, 79, 2,  7, 5, 97, 3, 26, 0, 39, 8, 20, 7, 31, 
    3, 73, 8, 77, 1, 44, 4, 99, 0, 34, 2, 47, 5, 80, 6, 61, 7, 86
  };
  const int q0198[] = {
    9, 9, // Number of jobs and machines
    3, 10, 6, 84, 2, 42, 4, 12, 0, 48, 1, 59, 7, 53, 8, 63, 5, 81, 
    8, 82, 6, 65, 3, 15, 4, 10, 0, 49, 7, 76, 2, 61, 5, 94, 1, 41, 
    5, 56, 7, 77, 2, 43, 8, 87, 6, 48, 1,  8, 0, 70, 4, 78, 3, 42, 
    0,  6, 2, 28, 5, 46, 1, 42, 8, 32, 3, 95, 7, 41, 6,  1, 4, 28, 
    4, 56, 6, 96, 0, 44, 8, 56, 7, 51, 2, 49, 3, 48, 1, 80, 5, 19, 
    1, 75, 5, 93, 6, 63, 7, 62, 3, 64, 4, 15, 8, 38, 0, 61, 2, 82, 
    4, 81, 0, 78, 3, 73, 6, 75, 5, 96, 1, 66, 2, 32, 8, 54, 7, 90, 
    3, 54, 1, 32, 4, 32, 8, 82, 6, 23, 7, 26, 0, 50, 2, 52, 5, 31, 
    4,  2, 5, 96, 6, 47, 2, 60, 0, 43, 8, 93, 3, 48, 1, 30, 7, 67
  };
  const int q0199[] = {
    9, 9, // Number of jobs and machines
    6, 71, 2, 13, 1, 10, 5, 66, 7, 44, 0, 58, 8, 98, 4, 46, 3,  1, 
    5, 88, 6, 40, 0, 32, 8,  1, 7, 42, 2, 71, 1, 66, 3, 82, 4, 89, 
    5, 14, 3, 17, 6, 97, 2, 78, 0, 95, 1, 58, 4, 13, 8, 10, 7, 10, 
    4, 30, 0, 13, 1, 56, 3, 61, 5, 48, 8, 31, 6, 80, 2, 91, 7, 49, 
    4, 26, 1, 90, 8, 77, 0, 58, 7, 46, 2, 45, 3, 90, 6, 92, 5, 15, 
    7, 36, 1, 92, 5, 78, 8, 91, 4, 30, 0, 92, 6, 31, 3,  6, 2, 44, 
    6, 42, 3, 55, 8, 87, 7, 11, 4, 41, 5, 79, 0, 70, 1, 55, 2, 16, 
    7,  8, 1, 68, 4, 11, 5,  7, 0, 66, 6,  5, 8,  9, 2, 54, 3, 67, 
    2, 90, 4, 27, 3, 73, 7, 56, 1, 84, 6, 40, 0, 51, 8, 68, 5, 18
  };
  const int q0200[] = {
    9, 9, // Number of jobs and machines
    0, 67, 3, 97, 7, 11, 6, 92, 2, 79, 1, 36, 4, 53, 5, 94, 8, 63, 
    2, 49, 8, 91, 1, 46, 0, 49, 7, 94, 6, 63, 3, 81, 5, 27, 4, 62, 
    8, 48, 1, 66, 2, 31, 6, 29, 0, 80, 5, 16, 4, 96, 7, 83, 3, 91, 
    1, 12, 2, 41, 8, 94, 5, 35, 7, 74, 3, 78, 4, 71, 0, 97, 6, 45, 
    8, 24, 6, 92, 7, 77, 3,  3, 1,  7, 5, 14, 2, 44, 4, 74, 0, 16, 
    6, 91, 5,  6, 8, 72, 2, 87, 4, 54, 0, 14, 7, 33, 1, 44, 3, 66, 
    7,  9, 8, 52, 0, 62, 2, 46, 4, 95, 6, 62, 5, 10, 1, 56, 3, 88, 
    0, 15, 3,  9, 4, 16, 1, 44, 8, 51, 5, 55, 7, 48, 6, 53, 2, 52, 
    0, 69, 8,  2, 1,  4, 5, 31, 3, 56, 2, 82, 6, 40, 4, 72, 7, 40
  };
  const int q0201[] = {
    9, 9, // Number of jobs and machines
    0, 27, 2, 25, 3, 25, 7, 62, 5, 22, 4, 85, 1, 99, 8, 32, 6, 71, 
    2,  7, 8, 90, 7, 64, 0, 90, 6, 33, 3, 95, 4, 95, 5, 99, 1, 51, 
    7, 69, 5, 70, 3, 70, 2, 12, 4, 50, 8, 18, 6, 86, 1, 95, 0, 66, 
    1, 54, 0, 31, 8, 27, 4, 66, 7, 53, 6, 41, 2, 76, 3, 92, 5, 73, 
    0, 12, 5, 10, 7, 27, 1, 67, 4, 13, 2, 79, 3, 78, 6, 56, 8,  1, 
    4, 48, 3, 75, 7, 32, 6, 53, 1,  9, 8, 11, 0, 12, 5, 79, 2, 91, 
    7, 65, 1, 42, 4, 47, 3, 43, 6, 74, 5, 92, 2, 89, 0, 93, 8, 54, 
    5, 44, 6, 31, 3, 10, 8, 39, 7, 28, 1, 50, 4, 25, 2, 50, 0, 58, 
    2, 94, 7, 97, 4, 79, 6, 18, 0, 28, 8, 46, 5, 13, 1, 33, 3, 20
  };
  const int q0202[] = {
    9, 9, // Number of jobs and machines
    2, 97, 7, 38, 6,  8, 5, 61, 3, 43, 8, 59, 0, 81, 4, 69, 1, 50, 
    4, 19, 1, 18, 2, 28, 3, 47, 5, 94, 0, 89, 7,  7, 8, 46, 6, 28, 
    8, 88, 2, 54, 5, 43, 3, 33, 4, 55, 1, 65, 6, 20, 7, 55, 0, 24, 
    7, 85, 8, 97, 4, 14, 0, 63, 3, 97, 1, 94, 5, 51, 6, 58, 2, 62, 
    8, 56, 6, 80, 1, 95, 7, 57, 2, 24, 3, 74, 0, 33, 5, 30, 4, 77, 
    4, 89, 2, 55, 1, 64, 0, 98, 8, 60, 7, 88, 5, 33, 3, 40, 6, 68, 
    0, 10, 1, 95, 4, 29, 7,  6, 2,  5, 5, 49, 8, 69, 3, 32, 6, 55, 
    5, 90, 2, 65, 8, 44, 7,  8, 0, 12, 1, 20, 3, 59, 4, 54, 6, 43, 
    6, 54, 7,  4, 8,  3, 1, 59, 0, 20, 3, 41, 2, 31, 5, 76, 4, 24
  };
  const int q0203[] = {
    9, 9, // Number of jobs and machines
    0,  5, 2, 45, 4, 28, 6, 44, 5, 16, 3, 66, 8, 51, 7, 17, 1, 47, 
    2, 80, 4, 93, 6, 66, 1, 15, 3, 27, 0, 95, 5, 88, 7, 39, 8, 77, 
    7, 81, 1, 17, 6, 91, 4, 27, 8, 87, 2, 45, 0, 65, 5, 13, 3, 62, 
    0, 11, 6, 23, 3, 15, 8, 11, 4, 75, 7, 79, 2, 13, 5, 36, 1, 97, 
    5, 69, 3, 94, 7, 80, 4, 90, 2, 13, 6, 69, 8, 25, 1, 84, 0, 70, 
    6, 41, 2,  7, 0, 60, 8,  9, 3, 98, 5, 90, 4, 52, 1, 59, 7, 50, 
    4, 57, 7, 83, 5, 71, 2, 42, 0, 69, 1, 64, 8, 55, 3, 97, 6, 89, 
    3, 37, 0, 81, 4, 37, 7, 26, 8, 76, 1, 64, 5, 38, 2, 79, 6, 21, 
    2, 67, 0, 94, 4,  9, 7, 94, 8, 39, 1, 18, 5, 52, 6, 95, 3, 92
  };
  const int q0204[] = {
    9, 9, // Number of jobs and machines
    1, 70, 0, 47, 2, 11, 7, 61, 4, 71, 6, 95, 8, 47, 3, 91, 5, 12, 
    5, 81, 0, 61, 2, 90, 7, 38, 3, 77, 8, 22, 4, 36, 1, 59, 6, 35, 
    6, 79, 2, 54, 3, 39, 8, 23, 7, 38, 5, 92, 1, 16, 0,  1, 4, 56, 
    1, 32, 3, 68, 6,  9, 7, 43, 5, 73, 4, 50, 2, 53, 0, 29, 8, 61, 
    4, 50, 2, 75, 8, 35, 0, 53, 3, 84, 1, 27, 6, 27, 5, 62, 7, 56, 
    7, 81, 8, 21, 3, 67, 5, 20, 4, 91, 0, 17, 1, 12, 6, 24, 2, 80, 
    0, 36, 6, 70, 1, 36, 5, 59, 8, 22, 3,  9, 4, 95, 7, 51, 2, 70, 
    8, 73, 4, 37, 1, 25, 3, 25, 5, 88, 7, 39, 0, 33, 6, 27, 2,  1, 
    1, 11, 5, 27, 3, 44, 6, 31, 7,  1, 4, 44, 2, 93, 8, 13, 0,  6
  };
  const int q0205[] = {
    9, 9, // Number of jobs and machines
    4, 82, 0, 88, 2, 80, 8, 72, 6, 63, 5, 18, 3, 20, 7, 95, 1, 70, 
    8, 50, 3, 41, 2, 86, 4, 40, 1, 85, 7, 90, 5, 89, 0, 85, 6,  6, 
    2,  5, 4, 28, 0, 94, 1, 29, 6, 30, 3, 17, 5, 19, 8, 28, 7, 14, 
    1, 36, 7, 54, 8, 15, 4,  5, 3, 36, 0, 24, 5, 89, 2,  4, 6, 19, 
    4, 33, 7, 31, 1, 90, 3, 48, 6, 90, 0, 56, 2, 77, 8, 33, 5,  8, 
    6, 93, 2, 58, 5, 51, 4,  5, 1,  8, 7, 18, 8,  3, 3, 55, 0, 39, 
    0, 27, 4, 57, 6, 89, 2, 41, 1, 11, 5, 97, 7, 43, 3, 14, 8, 32, 
    4, 25, 7, 41, 3, 12, 6, 69, 8, 87, 5, 61, 0, 75, 2, 30, 1, 88, 
    8,  5, 2, 90, 6, 58, 5,  9, 1,  8, 3, 54, 0, 99, 4, 54, 7, 26
  };
  const int q0206[] = {
    9, 9, // Number of jobs and machines
    5, 17, 2, 83, 4, 10, 8, 84, 6, 31, 1,  7, 0, 76, 3, 91, 7, 83, 
    7, 62, 3, 32, 0, 47, 2, 39, 1, 55, 4, 49, 6, 69, 5, 65, 8, 30, 
    2, 34, 4, 13, 8, 22, 1, 95, 6, 23, 5, 12, 7, 14, 3, 73, 0, 64, 
    1, 67, 8, 73, 4, 37, 3, 70, 0, 17, 5, 52, 6, 38, 2, 34, 7, 13, 
    3,  1, 6, 61, 8, 97, 5, 32, 7, 34, 0, 42, 2, 39, 4, 83, 1, 51, 
    7, 96, 3, 42, 8, 36, 0, 56, 6,  1, 5, 71, 4, 78, 2, 41, 1, 38, 
    1, 63, 0, 29, 3, 88, 6, 81, 2,  7, 7, 72, 8, 15, 4, 81, 5, 53, 
    2, 26, 1, 40, 3, 20, 4, 97, 6, 96, 0, 18, 5, 40, 7, 16, 8, 54, 
    5, 10, 2, 66, 8, 53, 7, 57, 6, 72, 1, 11, 4, 42, 3, 57, 0,  7
  };
  const int q0207[] = {
    9, 9, // Number of jobs and machines
    6, 73, 2, 79, 7, 81, 1, 17, 8, 48, 5, 28, 0, 14, 4, 75, 3, 92, 
    3, 42, 8, 64, 5, 33, 0, 63, 1, 38, 7, 11, 2, 29, 6, 67, 4, 55, 
    3,  2, 4, 99, 1, 81, 2, 10, 7, 31, 5, 10, 0, 27, 6, 73, 8, 71, 
    8, 47, 1, 25, 0, 10, 2, 49, 6, 97, 4, 50, 7, 93, 3, 52, 5, 56, 
    4, 95, 0, 35, 5, 41, 2, 39, 6, 17, 3, 19, 7, 76, 1, 16, 8, 68, 
    0, 10, 1, 30, 2, 86, 7, 60, 4, 50, 3, 68, 8, 43, 6, 25, 5, 97, 
    6, 33, 7, 47, 4, 89, 0, 43, 3, 62, 2, 29, 1, 86, 8, 28, 5, 41, 
    3, 79, 7, 35, 1, 94, 2, 86, 5, 93, 0, 53, 4,  6, 8,  7, 6, 21, 
    5, 70, 1, 56, 6, 59, 4, 30, 7, 90, 8, 60, 2, 70, 3, 20, 0, 44
  };
  const int q0208[] = {
    9, 9, // Number of jobs and machines
    3, 53, 4, 27, 1, 49, 7, 44, 8, 15, 6, 51, 2, 55, 5, 50, 0, 57, 
    4, 43, 1, 55, 0, 28, 2, 68, 5, 89, 8,  3, 3, 36, 7,  1, 6, 91, 
    7,  6, 6, 97, 2, 51, 4, 50, 1, 34, 0, 42, 8, 89, 3, 45, 5, 21, 
    7, 61, 3, 11, 6,  4, 2, 24, 4, 84, 1, 50, 5, 80, 8, 82, 0, 53, 
    1,  8, 2, 66, 6, 98, 4, 62, 5, 47, 0, 51, 3, 93, 8, 99, 7,  7, 
    2, 22, 0, 37, 8, 32, 4, 69, 3, 34, 7, 61, 1, 37, 5,  3, 6, 74, 
    1, 67, 6, 45, 7, 20, 2, 22, 5, 18, 8, 50, 3, 47, 0, 83, 4, 56, 
    1, 21, 5, 83, 0, 26, 3, 62, 4, 90, 8, 45, 6, 98, 2, 86, 7, 49, 
    6, 78, 8, 52, 5, 78, 4, 58, 7, 72, 0, 25, 3, 58, 2, 78, 1,  8
  };
  const int q0209[] = {
    9, 9, // Number of jobs and machines
    6, 85, 7, 71, 4, 82, 3,  7, 8, 37, 0, 67, 1, 29, 2, 69, 5, 22, 
    4, 88, 7, 68, 2, 46, 3, 67, 5, 87, 6, 40, 1,  7, 0, 55, 8, 97, 
    8, 74, 4,  1, 6, 77, 5, 15, 0, 24, 1, 37, 3, 27, 2, 83, 7, 61, 
    1, 73, 7,  3, 2, 81, 8, 25, 4, 28, 3,  2, 0, 13, 6, 41, 5,  2, 
    7, 85, 6, 42, 1, 77, 2, 99, 8, 54, 5, 63, 0,  3, 4, 89, 3, 85, 
    2,  2, 7, 47, 1,  5, 6, 55, 3, 48, 0, 73, 4, 25, 5, 25, 8, 10, 
    5, 97, 0, 58, 8,  2, 3, 89, 2, 13, 6, 45, 4, 31, 7, 42, 1, 25, 
    2, 34, 7, 59, 3, 89, 8, 39, 0, 80, 5, 86, 4, 21, 6, 69, 1, 46, 
    5, 64, 3, 33, 2, 89, 4, 55, 6, 80, 8, 51, 1, 93, 7, 98, 0, 81
  };
  const int q0210[] = {
    9, 9, // Number of jobs and machines
    6, 24, 3, 16, 5, 71, 4, 71, 1, 61, 7, 99, 0, 57, 8, 89, 2, 51, 
    1, 23, 8, 57, 7, 80, 5, 25, 3, 18, 2, 28, 6, 13, 0, 50, 4, 35, 
    2,  2, 1, 83, 4, 39, 3, 85, 8,  1, 0,  1, 7, 41, 6,  8, 5, 42, 
    5, 78, 6, 80, 1, 59, 4, 31, 0, 63, 7,  5, 3, 92, 2, 23, 8, 65, 
    3, 22, 6, 55, 8, 88, 2, 68, 4,  9, 5, 78, 7, 41, 0, 35, 1, 64, 
    4, 53, 5, 25, 2, 63, 7, 42, 8, 99, 1, 66, 3, 77, 0, 87, 6, 82, 
    6, 83, 2, 10, 4, 68, 3, 45, 8, 53, 5, 53, 7, 62, 0, 79, 1, 28, 
    6, 84, 3, 98, 5, 49, 4,  5, 0, 63, 2, 53, 7, 12, 8, 49, 1, 49, 
    4, 46, 3,  4, 1, 14, 7, 62, 0, 85, 2, 44, 5, 13, 6, 85, 8, 92
  };
  const int q0211[] = {
    9, 9, // Number of jobs and machines
    1, 83, 3, 94, 2, 34, 7, 51, 5, 67, 4, 30, 0, 65, 8, 80, 6,  4, 
    0, 70, 8, 64, 6, 13, 2, 56, 1, 62, 3, 94, 7, 69, 5, 54, 4, 22, 
    1, 25, 3, 84, 4, 58, 0, 76, 5, 13, 2, 55, 6, 66, 8,  7, 7, 63, 
    0,  2, 2, 47, 6, 16, 1, 63, 8, 21, 5, 99, 7, 38, 3, 97, 4, 10, 
    2, 57, 8, 95, 4, 43, 5, 51, 6, 51, 1, 26, 0, 62, 7, 64, 3, 97, 
    8, 81, 0,  7, 6,  4, 3, 97, 7, 31, 5, 41, 2,  9, 1, 24, 4, 45, 
    5, 19, 0, 75, 8, 32, 1, 37, 7,  1, 2, 61, 6,  5, 3, 49, 4, 59, 
    7, 85, 4, 85, 8, 82, 0, 89, 3, 47, 1, 92, 2, 51, 5, 93, 6, 50, 
    6, 73, 4, 55, 3, 17, 1, 72, 2, 97, 0, 31, 5, 24, 7, 52, 8, 85
  };
  const int q0212[] = {
    9, 9, // Number of jobs and machines
    1, 74, 6, 20, 8, 89, 4, 15, 2,  9, 0, 69, 5, 82, 3, 25, 7, 12, 
    8, 77, 2, 51, 3, 75, 1, 18, 0, 33, 5, 71, 4, 79, 7, 29, 6, 58, 
    1, 70, 8, 25, 5, 81, 0, 47, 4, 17, 2, 93, 6, 26, 7, 79, 3, 95, 
    0, 98, 6, 58, 2, 52, 7, 21, 3, 40, 1, 37, 8, 72, 4, 44, 5, 91, 
    1, 49, 7, 85, 0,  6, 3, 87, 2, 22, 6, 21, 5, 60, 4, 55, 8, 59, 
    4,  6, 0, 14, 3, 30, 2, 85, 8, 20, 5, 61, 6,  5, 7, 78, 1, 99, 
    7, 35, 3, 13, 4, 31, 5,  2, 6, 49, 1, 19, 0, 88, 8, 88, 2, 17, 
    8, 76, 3, 71, 5, 59, 0, 87, 4, 87, 2, 90, 7, 54, 6, 79, 1, 44, 
    6, 34, 3, 96, 5, 43, 2, 45, 7, 78, 0, 71, 1, 29, 8, 26, 4, 19
  };
  const int q0213[] = {
    9, 9, // Number of jobs and machines
    7, 82, 8, 43, 1, 59, 3, 47, 0,  9, 5, 38, 4, 36, 6, 64, 2, 59, 
    5, 49, 6, 30, 8, 68, 2, 39, 4, 28, 1, 63, 0, 26, 7, 70, 3, 53, 
    6, 85, 4, 44, 3, 35, 0, 29, 1, 32, 2, 88, 8, 45, 5,  8, 7, 13, 
    5, 96, 1, 72, 4, 18, 2, 76, 3, 35, 8, 62, 7, 40, 0,  6, 6, 55, 
    6, 42, 8, 59, 0, 96, 1, 14, 5, 34, 4, 51, 3, 48, 2, 27, 7, 67, 
    4, 64, 0,  5, 3, 80, 1, 11, 8, 16, 2, 48, 6, 28, 5, 46, 7, 77, 
    7, 89, 1, 45, 0,  1, 8, 85, 2, 36, 3, 19, 6,  8, 4, 21, 5, 56, 
    1, 53, 8, 90, 2, 32, 0, 21, 3, 68, 5, 91, 4, 37, 7, 39, 6, 91, 
    7,  1, 8, 14, 2, 33, 1, 18, 4, 66, 6, 27, 5, 68, 3, 91, 0, 14
  };
  const int q0214[] = {
    9, 9, // Number of jobs and machines
    4, 90, 6, 71, 1, 45, 3, 36, 7,  5, 2, 66, 0, 84, 5, 92, 8, 71, 
    3, 17, 6, 73, 5, 29, 7, 42, 0, 28, 8,  1, 1, 34, 2, 39, 4, 51, 
    4,  8, 7, 81, 1, 86, 5, 41, 3, 10, 0, 41, 2, 94, 8, 51, 6, 15, 
    6, 53, 0, 60, 1, 97, 4, 15, 5, 26, 7, 80, 3, 13, 2, 83, 8, 33, 
    4, 75, 3, 24, 0, 42, 1, 60, 6, 74, 5, 46, 2, 69, 8, 20, 7, 75, 
    1, 60, 6, 10, 3, 35, 0, 72, 8, 89, 7, 63, 5, 91, 2, 66, 4,  7, 
    5, 12, 4,  8, 1, 40, 7, 80, 0,  2, 8, 60, 6, 12, 3, 15, 2, 99, 
    1, 97, 4, 48, 2, 46, 5, 58, 8, 87, 7, 61, 0,  3, 3, 21, 6, 38, 
    0, 85, 4, 63, 1, 28, 2, 88, 3, 11, 7, 50, 8,  7, 5, 33, 6, 18
  };
  const int q0215[] = {
    9, 9, // Number of jobs and machines
    4,  7, 7, 26, 1, 44, 5, 21, 6, 46, 8, 34, 0, 77, 3, 77, 2, 33, 
    1, 69, 4, 44, 7, 24, 6, 15, 3, 90, 0, 84, 5, 97, 2, 31, 8, 19, 
    4, 47, 5,  2, 2, 74, 3, 25, 7, 67, 0,  9, 1, 95, 6, 17, 8, 73, 
    1, 39, 6, 70, 8, 78, 5, 24, 4, 50, 3, 76, 7, 27, 2,  6, 0, 23, 
    0, 30, 5, 39, 3, 54, 8, 48, 4, 43, 2, 96, 6, 26, 7, 95, 1, 73, 
    1, 53, 4, 57, 6, 59, 8, 72, 0, 70, 5, 42, 7, 43, 2, 66, 3, 44, 
    3, 79, 6, 58, 8, 73, 2, 67, 4, 15, 0, 60, 5,  6, 7, 85, 1, 87, 
    5, 55, 0, 46, 7, 54, 2, 41, 8,  9, 1, 87, 6, 99, 3, 99, 4, 81, 
    2, 78, 7, 64, 8,  7, 4, 48, 5, 20, 1, 86, 3, 18, 6, 34, 0,  2
  };
  const int q0216[] = {
    9, 9, // Number of jobs and machines
    5, 43, 6,  8, 0,  3, 8, 64, 7, 19, 3, 92, 1, 99, 2, 66, 4, 54, 
    4, 82, 7, 69, 5,  9, 6, 80, 3, 39, 1, 42, 2, 32, 0, 31, 8,  6, 
    5, 47, 3, 40, 6, 29, 4, 38, 7, 73, 1, 18, 2, 72, 8, 70, 0, 70, 
    0, 74, 8, 16, 2, 62, 7, 23, 3, 50, 4, 45, 6, 21, 1, 70, 5, 25, 
    8, 61, 7, 74, 3,  8, 0, 46, 4,  8, 6, 73, 1, 17, 5, 37, 2, 13, 
    5, 82, 0, 21, 3, 64, 2, 18, 6, 98, 7, 55, 1,  1, 4, 88, 8, 79, 
    7, 51, 1, 90, 2,  7, 3, 99, 6, 27, 5,  1, 0, 66, 4, 80, 8, 19, 
    8, 28, 6, 39, 7, 31, 5, 93, 0, 25, 3, 87, 1, 40, 4, 12, 2, 75, 
    0, 86, 8, 46, 3, 57, 2, 99, 4, 92, 7, 53, 1, 47, 5, 23, 6, 50
  };
  const int q0217[] = {
    9, 9, // Number of jobs and machines
    1, 56, 2, 47, 6, 56, 0, 29, 7, 76, 5, 77, 8, 86, 4, 71, 3, 34, 
    6, 69, 8, 93, 2,  7, 7, 74, 1, 77, 4, 45, 0, 88, 5, 93, 3, 83, 
    2, 46, 0, 34, 7, 13, 5, 93, 4, 28, 3, 79, 6, 96, 1, 78, 8, 32, 
    2, 72, 4, 94, 5, 92, 6, 65, 0, 38, 7, 86, 3, 95, 1, 33, 8, 38, 
    1, 30, 0, 74, 2, 23, 7, 95, 8, 66, 4, 68, 6, 48, 3, 86, 5, 55, 
    3, 29, 8, 62, 7, 83, 1, 45, 4, 57, 0, 47, 2, 53, 6, 71, 5, 10, 
    3,  4, 4, 62, 2, 44, 5, 70, 0, 45, 6,  3, 7, 84, 8, 78, 1, 57, 
    4, 35, 5, 74, 3, 49, 0, 77, 2, 70, 7, 14, 1, 92, 8,  2, 6, 97, 
    0, 27, 6, 99, 2, 84, 7,  7, 8, 28, 1, 55, 4, 61, 3, 44, 5, 38
  };
  const int q0218[] = {
    9, 9, // Number of jobs and machines
    0, 72, 3, 56, 1, 62, 5, 90, 4, 34, 8, 13, 2, 39, 7, 79, 6, 35, 
    2, 74, 3, 54, 4, 97, 0, 37, 7, 93, 1, 42, 5, 11, 8, 15, 6,  8, 
    6,  6, 7, 99, 5, 39, 0, 87, 8, 76, 2, 28, 1, 24, 3, 49, 4, 48, 
    4,  5, 5, 98, 2, 29, 7, 44, 1, 60, 8, 56, 6, 87, 3, 17, 0, 51, 
    1, 32, 0, 95, 5,  6, 6, 44, 3, 15, 2, 71, 7, 47, 4, 30, 8, 67, 
    4, 59, 0, 47, 2, 78, 1, 87, 7, 65, 8, 81, 5, 92, 6, 55, 3, 38, 
    4, 52, 3, 36, 0, 37, 6, 50, 2, 34, 7, 22, 5, 73, 1, 51, 8, 80, 
    7, 48, 8, 78, 3, 22, 2,  7, 1, 71, 5, 15, 4, 17, 0, 33, 6,  1, 
    4, 30, 2, 93, 0, 15, 1, 37, 8, 22, 6, 32, 5,  4, 3, 21, 7, 59
  };
  const int q0219[] = {
    9, 9, // Number of jobs and machines
    8, 87, 0, 83, 3, 41, 7, 67, 4, 59, 6,  3, 5, 59, 1, 63, 2, 73, 
    4, 82, 5, 85, 6, 49, 3, 91, 8, 19, 2, 66, 7, 57, 1, 33, 0, 84, 
    5, 14, 0, 66, 4,  1, 6,  7, 7,  9, 8, 60, 3, 60, 2, 81, 1, 82, 
    1, 65, 0, 16, 5, 89, 3, 19, 4, 95, 6, 25, 8,  6, 7, 30, 2, 30, 
    6, 83, 3,  8, 0,  9, 1, 25, 2, 46, 4, 77, 5, 64, 7, 63, 8, 10, 
    2, 10, 0, 22, 5, 83, 6, 35, 3, 70, 1, 93, 7, 66, 8, 22, 4, 86, 
    6,  4, 0, 57, 3, 91, 1, 33, 7, 11, 4, 25, 2, 42, 5, 83, 8, 63, 
    2,  1, 0,  5, 6, 98, 3, 56, 4, 59, 5, 57, 8, 61, 1, 35, 7, 60, 
    4, 93, 7,  7, 2, 87, 3,  2, 5,  5, 0, 29, 1, 96, 6, 97, 8, 15
  };
  const int q0220[] = {
    9, 9, // Number of jobs and machines
    5, 58, 6, 35, 0, 12, 4, 91, 3, 45, 2, 34, 1, 54, 7, 36, 8, 79, 
    2, 70, 6, 45, 5, 10, 0, 56, 3,  4, 7,  3, 8, 15, 4, 10, 1, 55, 
    1, 96, 7, 80, 0, 42, 2, 62, 8, 19, 6, 58, 5, 49, 4,  6, 3, 24, 
    0, 18, 5, 45, 1, 11, 4, 78, 8, 76, 2, 69, 3,  3, 7, 82, 6, 54, 
    5, 87, 4, 27, 1,  7, 7, 94, 6, 74, 8, 74, 2, 49, 0, 73, 3, 97, 
    7, 19, 0, 26, 4, 86, 2, 51, 6, 89, 3, 95, 8, 39, 5, 31, 1, 85, 
    0, 99, 2, 43, 1, 86, 7, 11, 5, 99, 3, 94, 4, 79, 8, 99, 6, 27, 
    2,  9, 7, 63, 3, 30, 4, 32, 1, 28, 8, 30, 6, 40, 0, 75, 5, 51, 
    8, 22, 2, 87, 4, 11, 6,  3, 7, 95, 0, 71, 5, 87, 3, 37, 1, 25
  };
  const int q0221[] = {
    9, 9, // Number of jobs and machines
    1, 36, 8, 73, 6,  5, 2, 87, 7, 88, 5, 11, 3, 92, 4, 15, 0, 82, 
    2, 91, 3,  1, 1, 41, 6, 68, 0, 88, 4, 83, 8, 87, 7, 61, 5, 66, 
    1, 66, 7, 48, 2, 82, 0, 82, 3, 13, 5, 58, 6, 35, 8, 43, 4, 55, 
    4, 71, 3, 43, 7, 45, 8, 26, 2, 96, 0, 78, 6, 97, 1, 81, 5, 64, 
    1, 42, 6,  4, 5, 46, 2, 58, 0, 25, 3,  4, 7, 43, 8, 14, 4, 26, 
    3, 39, 8, 56, 0, 81, 5, 95, 2, 82, 6, 76, 1, 77, 7, 90, 4, 50, 
    0, 11, 7, 74, 3, 38, 6, 93, 5, 71, 2, 28, 1, 71, 4, 91, 8, 11, 
    7, 79, 0, 12, 4, 65, 8, 91, 1, 82, 3, 40, 2, 24, 6, 87, 5, 59, 
    4, 57, 2, 53, 7, 35, 8, 21, 0, 65, 3, 30, 5, 15, 6, 23, 1, 81
  };
  const int q0222[] = {
    9, 9, // Number of jobs and machines
    5, 34, 8, 99, 3, 59, 0, 16, 1,  6, 6,  3, 2, 61, 7, 90, 4, 67, 
    2,  2, 6, 99, 5, 59, 0, 35, 3, 73, 7, 63, 8, 75, 4, 30, 1, 59, 
    7,  2, 3, 64, 6, 90, 1,  1, 2, 84, 8,  7, 0,  2, 5, 82, 4, 85, 
    2, 79, 6, 74, 7,  9, 0, 52, 1, 65, 5, 83, 3, 86, 8, 87, 4, 81, 
    2,  6, 5, 67, 1, 12, 8, 24, 6, 48, 4, 53, 3, 40, 7, 75, 0, 82, 
    6, 85, 2,  1, 5, 40, 7, 73, 3, 30, 1, 67, 8, 84, 4, 51, 0,  7, 
    6, 85, 5, 46, 7, 23, 8, 58, 1, 60, 4, 20, 0, 48, 3, 65, 2, 24, 
    3, 67, 8, 84, 5, 38, 4, 19, 7, 55, 1, 52, 2, 91, 6, 78, 0, 20, 
    5, 76, 8, 39, 7, 52, 3, 21, 4, 65, 0, 52, 1, 85, 6, 27, 2, 42
  };
  const int q0223[] = {
    9, 9, // Number of jobs and machines
    2, 52, 1, 95, 8, 29, 5, 23, 3, 10, 0, 30, 4, 46, 6, 18, 7, 63, 
    4, 90, 3, 21, 0, 96, 8, 97, 5, 32, 7, 95, 1, 67, 6,  6, 2, 97, 
    4, 72, 0,  9, 2, 49, 3, 32, 1, 78, 7, 48, 8, 36, 5,  1, 6, 29, 
    8, 23, 2, 83, 6, 24, 7, 32, 1, 49, 4, 38, 5, 63, 0, 16, 3, 38, 
    0, 47, 2,  1, 4, 37, 5, 58, 1, 70, 6, 99, 8, 87, 7, 54, 3, 88, 
    0, 48, 4, 97, 2, 32, 6, 91, 3, 44, 7, 53, 8, 59, 1, 88, 5, 12, 
    8, 59, 4, 58, 6,  3, 0, 23, 7, 66, 1, 76, 3, 80, 2, 15, 5, 92, 
    3, 56, 0,  4, 5, 33, 7,  8, 8, 99, 4, 87, 2, 26, 6, 65, 1, 92, 
    6, 24, 0, 19, 3, 97, 7, 16, 2,  2, 5, 53, 4, 18, 1, 50, 8, 51
  };
  const int q0224[] = {
    9, 9, // Number of jobs and machines
    1, 23, 6, 99, 0, 74, 7, 11, 8, 33, 5, 14, 2, 79, 3, 46, 4, 39, 
    4, 22, 8, 92, 3, 79, 7,  7, 6, 57, 1, 27, 2, 47, 5, 71, 0, 85, 
    3, 15, 0, 71, 2, 95, 1, 22, 4, 27, 7, 54, 5, 91, 8, 92, 6, 40, 
    8, 46, 2, 23, 0, 58, 7, 77, 4, 57, 3, 18, 1, 34, 6, 61, 5, 88, 
    7, 53, 4, 63, 5,  9, 1, 31, 0, 75, 8, 87, 6, 67, 2, 35, 3, 86, 
    1, 56, 6, 46, 0,  8, 8, 58, 5, 26, 3, 53, 2, 82, 4, 16, 7, 48, 
    2, 50, 1,  9, 5, 95, 4, 28, 8, 42, 0, 47, 3, 76, 6, 82, 7, 61, 
    0, 26, 7, 63, 4, 42, 1, 83, 3, 51, 5, 48, 6, 83, 2, 71, 8, 64, 
    5, 85, 4, 36, 1, 76, 8, 66, 2, 43, 3, 67, 0, 78, 6, 21, 7, 30
  };
  const int q0225[] = {
    9, 9, // Number of jobs and machines
    2, 74, 6, 62, 3, 16, 4, 62, 5, 88, 8, 37, 0, 68, 7,  4, 1, 46, 
    3,  7, 7, 66, 8, 53, 0, 96, 2, 36, 4, 34, 5, 18, 1, 14, 6,  2, 
    4,  4, 2, 47, 6, 31, 0, 86, 7,  2, 1, 32, 5, 51, 3, 41, 8, 90, 
    3, 13, 4, 93, 7, 31, 6, 31, 2, 59, 1, 24, 0, 75, 5, 81, 8, 10, 
    6, 66, 7, 79, 2, 46, 4, 88, 5, 67, 1,  3, 3, 80, 8, 56, 0, 59, 
    2, 99, 0, 45, 8, 29, 7, 13, 6, 78, 4, 51, 1, 27, 5, 56, 3, 50, 
    8, 91, 7, 53, 2, 59, 1,  8, 0, 26, 4, 38, 3, 63, 6, 62, 5, 42, 
    5, 74, 7, 11, 1, 55, 4, 38, 3, 48, 0, 47, 8, 93, 6, 16, 2, 12, 
    7, 89, 2, 12, 5, 89, 6, 34, 8, 23, 4, 31, 0, 80, 1, 91, 3, 73
  };
  const int q0226[] = {
    9, 9, // Number of jobs and machines
    1, 26, 7,  1, 6, 70, 4, 44, 3, 53, 5, 55, 0, 67, 8, 52, 2, 98, 
    8, 88, 3, 96, 6, 13, 7, 84, 5, 23, 0, 33, 4, 91, 2, 11, 1, 58, 
    0, 85, 6, 52, 8,  6, 7, 59, 3, 48, 5, 53, 2, 52, 1, 82, 4, 99, 
    2,  9, 6, 41, 0, 74, 5, 81, 1, 61, 7, 79, 8, 52, 3, 19, 4,  2, 
    6,  3, 0, 87, 8, 98, 2,  9, 4,  2, 7, 98, 3, 63, 5, 47, 1, 88, 
    5, 12, 2, 31, 7, 86, 8, 13, 1, 93, 3, 53, 6, 36, 4,  6, 0, 86, 
    6, 98, 7, 60, 2, 60, 0,  6, 4, 84, 3, 43, 5,  7, 8, 88, 1, 69, 
    7, 17, 8, 68, 0, 21, 3,  9, 1, 77, 5, 10, 4,  1, 6, 36, 2,  3, 
    1, 94, 5, 55, 8, 83, 4, 70, 6, 42, 7, 39, 3, 25, 0, 55, 2, 88
  };
  const int q0227[] = {
    9, 9, // Number of jobs and machines
    1, 57, 7, 68, 2, 67, 5, 50, 0, 59, 6, 77, 4, 21, 3, 57, 8, 52, 
    6, 80, 4, 61, 8, 50, 1,  4, 0, 49, 3, 19, 2, 64, 5, 10, 7, 30, 
    4, 64, 2, 35, 0, 96, 5, 98, 8, 48, 3, 21, 7, 60, 1, 33, 6, 45, 
    1, 33, 5, 59, 7, 54, 8, 11, 4, 31, 2, 87, 6, 54, 3, 72, 0, 59, 
    3, 67, 2, 63, 5, 26, 6, 78, 7, 50, 0, 22, 8, 94, 1, 82, 4, 72, 
    2, 64, 5, 42, 8, 46, 7, 56, 1,  8, 0, 90, 3, 64, 4, 98, 6, 78, 
    3, 83, 7, 95, 6, 99, 8, 22, 1, 74, 0, 30, 5, 77, 2, 34, 4,  9, 
    4, 95, 7,  1, 3, 79, 8, 67, 0, 99, 6,  7, 2, 53, 5, 53, 1, 89, 
    5, 56, 6, 38, 2, 59, 1, 46, 7, 90, 8, 76, 4, 54, 3, 55, 0, 35
  };
  const int q0228[] = {
    9, 9, // Number of jobs and machines
    3, 74, 1, 87, 7, 99, 6, 31, 0, 54, 2, 51, 4, 24, 5,  6, 8, 75, 
    6, 95, 4, 91, 3, 55, 0,  4, 8, 41, 2, 44, 7, 55, 5, 89, 1,  6, 
    5, 70, 4,  4, 6, 86, 0, 88, 8, 93, 1, 30, 3, 50, 7, 82, 2, 52, 
    8, 96, 1, 74, 5, 50, 3, 35, 2, 38, 7, 35, 0, 57, 4, 92, 6, 17, 
    1, 16, 0, 55, 3, 67, 6, 20, 2,  1, 8, 38, 5, 72, 7, 44, 4, 45, 
    7, 12, 8, 68, 5, 74, 3,  5, 4, 59, 2, 47, 6, 34, 1, 69, 0, 44, 
    7, 50, 2, 24, 0, 95, 4, 68, 5, 87, 3, 34, 1, 29, 6, 58, 8, 51, 
    4, 20, 5, 85, 6, 49, 0, 38, 1, 91, 8, 42, 3, 33, 2, 82, 7, 82, 
    5, 17, 6,  6, 2, 15, 3, 16, 1,  2, 7, 16, 0, 76, 8, 53, 4, 49
  };
  const int q0229[] = {
    9, 9, // Number of jobs and machines
    0, 53, 3,  1, 1, 98, 7, 42, 4, 35, 5, 12, 6, 50, 8, 35, 2, 38, 
    3, 97, 0, 35, 7, 30, 5, 76, 1, 59, 2, 56, 6, 36, 8, 33, 4, 34, 
    2, 31, 8, 91, 7, 75, 4, 33, 6, 48, 5, 96, 3, 59, 0, 19, 1, 39, 
    7, 39, 8, 82, 1, 94, 3, 81, 6, 60, 5, 99, 2, 79, 0, 38, 4, 25, 
    6, 57, 2, 45, 7, 95, 4, 25, 5, 66, 8, 97, 0, 40, 3, 11, 1, 58, 
    5,  4, 3, 93, 8, 65, 4, 53, 6, 54, 7, 54, 1, 95, 2, 17, 0, 63, 
    3, 56, 1,  1, 8, 72, 4, 53, 0, 17, 5, 76, 7, 79, 2, 87, 6, 57, 
    2, 30, 5, 78, 0, 53, 4, 69, 3, 57, 6, 99, 8, 87, 7, 49, 1, 61, 
    3, 93, 1, 86, 7, 40, 2, 11, 6, 64, 0, 12, 5, 56, 8, 54, 4, 65
  };
  const int q0230[] = {
    9, 9, // Number of jobs and machines
    7, 25, 6, 85, 8, 25, 4, 79, 5, 55, 3, 16, 0, 31, 1, 58, 2, 27, 
    7, 79, 5, 46, 1, 66, 0, 61, 2, 88, 8, 18, 4, 70, 6, 21, 3, 64, 
    1, 73, 7, 14, 6, 29, 4, 71, 2, 52, 8, 27, 3, 49, 5,  5, 0, 16, 
    8, 57, 0, 29, 7, 73, 6, 16, 1, 92, 4, 20, 3, 59, 2, 54, 5, 71, 
    1, 37, 2, 48, 0, 54, 6,  7, 5, 98, 8, 48, 3, 24, 7, 51, 4, 58, 
    2, 75, 5, 72, 8, 61, 0, 35, 3, 83, 7, 76, 4,  1, 6,  4, 1, 98, 
    8, 30, 7, 43, 0, 30, 4,  6, 1, 81, 3, 82, 5, 92, 6,  6, 2, 16, 
    2, 82, 0, 59, 4, 78, 1,  8, 7, 68, 8, 16, 6, 54, 3, 56, 5, 63, 
    6, 91, 7, 33, 2, 34, 1, 19, 0, 83, 5, 47, 4, 50, 8, 52, 3, 69
  };
  const int q0231[] = {
    9, 9, // Number of jobs and machines
    8, 17, 3, 35, 0, 95, 7, 16, 1,  6, 5,  8, 6, 85, 2, 18, 4, 23, 
    8, 67, 0, 18, 2, 20, 4, 83, 6, 46, 5, 17, 1, 64, 3, 37, 7, 32, 
    2, 93, 5, 16, 7, 87, 6,  8, 8, 66, 1, 83, 3, 59, 4, 75, 0, 68, 
    1, 70, 2, 97, 7, 89, 6, 98, 0, 58, 5, 32, 3, 58, 4, 84, 8, 66, 
    6, 77, 5, 30, 2, 39, 7, 50, 3, 48, 8, 82, 0, 83, 4, 73, 1, 82, 
    3, 68, 5, 61, 1, 69, 8, 29, 6, 64, 7, 59, 0, 49, 4, 71, 2, 66, 
    1, 56, 8, 18, 5, 24, 3,  6, 6, 12, 0, 78, 4,  4, 2, 13, 7, 38, 
    4, 22, 2, 98, 1, 52, 0, 44, 7, 11, 8, 64, 3, 21, 6, 62, 5, 88, 
    8, 63, 7, 40, 0, 30, 1,  3, 4, 77, 2, 11, 3, 30, 6, 52, 5, 19
  };
  const int q0232[] = {
    9, 9, // Number of jobs and machines
    5,  4, 0, 28, 7, 31, 4, 65, 1, 64, 6, 84, 2, 38, 8, 44, 3, 90, 
    4, 55, 8, 59, 3, 21, 5, 31, 6, 72, 7, 14, 0, 71, 1, 48, 2, 67, 
    4,  6, 5, 36, 7,  1, 8, 68, 2, 16, 0, 99, 3, 36, 6, 94, 1, 37, 
    1, 87, 4, 72, 2, 89, 7, 52, 6, 11, 5, 98, 8, 30, 3, 76, 0, 68, 
    1, 41, 0, 85, 2, 27, 7, 10, 4, 45, 8, 32, 3, 78, 5, 42, 6,  2, 
    4, 13, 7,  2, 0, 30, 6, 60, 2, 72, 3, 82, 1, 50, 8, 24, 5,  9, 
    3, 76, 6, 82, 1, 44, 8, 13, 5, 58, 0, 63, 2, 97, 7, 12, 4, 63, 
    4, 85, 2, 66, 5, 89, 0, 88, 3, 26, 7, 19, 6, 34, 1, 56, 8, 98, 
    8, 83, 1, 99, 4, 75, 0, 29, 5, 61, 7, 52, 6, 31, 2, 77, 3, 85
  };
  const int q0233[] = {
    9, 9, // Number of jobs and machines
    0, 71, 5, 23, 6, 80, 3,  7, 1, 28, 4, 73, 7, 22, 8, 90, 2,  9, 
    7, 61, 0, 46, 2, 16, 5,  9, 3,  1, 4, 64, 8, 44, 6, 68, 1, 98, 
    2,  7, 5, 95, 6, 87, 7, 39, 8, 23, 4, 44, 1, 23, 0, 65, 3, 23, 
    0, 52, 3, 25, 8, 99, 5, 26, 7, 59, 2, 43, 1, 82, 6,  7, 4, 10, 
    4, 84, 5, 92, 7, 40, 6, 87, 8,  2, 2, 64, 3, 51, 1, 45, 0, 94, 
    8, 55, 1, 47, 5, 77, 2, 22, 0, 67, 6, 91, 7, 81, 3, 65, 4,  4, 
    2, 58, 7, 52, 6, 28, 5, 59, 4, 12, 0, 46, 3,  1, 1, 62, 8, 62, 
    4, 23, 3, 86, 6, 53, 5, 31, 1, 17, 0, 43, 2, 48, 7, 98, 8, 42, 
    1,  8, 5, 76, 8, 99, 7,  9, 2, 33, 3, 82, 0, 59, 4, 69, 6, 91
  };
  const int q0234[] = {
    9, 9, // Number of jobs and machines
    0, 68, 4, 54, 6, 79, 2, 31, 8, 12, 1, 39, 3, 62, 5,  2, 7, 47, 
    6, 31, 0, 76, 8, 95, 7, 77, 3, 75, 2, 37, 1, 52, 4, 70, 5, 99, 
    7, 40, 1, 31, 3, 89, 5, 62, 6, 53, 8, 82, 0, 89, 2,  2, 4, 70, 
    1, 48, 0, 89, 5, 57, 3, 22, 2, 10, 6, 82, 7, 54, 8, 82, 4, 95, 
    0, 97, 7, 96, 2, 97, 8,  7, 6, 47, 5, 98, 4, 62, 3, 84, 1, 92, 
    3,  1, 2, 77, 0, 15, 6, 26, 7, 42, 5, 61, 4, 15, 1, 10, 8, 56, 
    0, 18, 6,  5, 8, 10, 5, 28, 3,  5, 2, 85, 1, 25, 7, 30, 4, 45, 
    3, 34, 7, 56, 4, 99, 5, 44, 1, 75, 2,  7, 6, 71, 0, 49, 8, 83, 
    0, 26, 5, 83, 8, 97, 2, 88, 7, 90, 6, 82, 4, 79, 3, 75, 1, 41
  };
  const int q0235[] = {
    9, 9, // Number of jobs and machines
    0, 37, 6, 34, 5, 58, 8, 26, 1, 51, 7, 49, 4, 39, 3, 45, 2, 17, 
    7, 31, 2, 22, 3, 61, 0, 81, 4, 62, 6, 45, 8,  7, 1, 34, 5, 16, 
    4, 36, 2,  4, 5, 50, 1, 60, 7, 47, 6, 29, 3, 14, 8, 48, 0, 28, 
    6,  4, 5, 71, 4, 66, 0, 24, 7, 67, 3, 17, 8, 15, 2, 95, 1, 87, 
    8, 43, 5, 38, 4,  8, 3, 89, 2, 52, 1, 38, 0, 31, 7, 35, 6,  7, 
    7, 30, 1,  5, 5, 18, 4, 42, 2, 82, 8, 70, 3, 98, 6, 58, 0, 71, 
    3, 38, 6, 59, 1, 23, 5, 33, 2, 97, 8, 20, 4, 79, 7, 44, 0, 73, 
    8, 43, 7, 12, 0, 96, 3, 75, 4, 85, 6,  7, 5, 85, 1, 47, 2, 91, 
    8, 75, 7, 47, 0, 81, 4, 92, 5, 15, 6, 36, 3, 44, 1, 40, 2, 79
  };
  const int q0236[] = {
    9, 9, // Number of jobs and machines
    7, 96, 3, 65, 6, 26, 4,  8, 2, 70, 5, 30, 0, 24, 8, 94, 1, 92, 
    1, 71, 2,  1, 8, 13, 3, 87, 7, 67, 5, 69, 6, 81, 4, 42, 0, 17, 
    3, 31, 8, 13, 5, 14, 6, 25, 7, 10, 4, 98, 1, 10, 0, 14, 2,  6, 
    4, 64, 3, 90, 2, 83, 1, 69, 0, 23, 6, 76, 5, 21, 7, 36, 8, 70, 
    1, 86, 4, 24, 2, 79, 8,  8, 6, 69, 0, 91, 3, 13, 5, 98, 7, 33, 
    4, 32, 2, 18, 0, 41, 7, 82, 6,  5, 5, 46, 3, 93, 1, 72, 8, 46, 
    0, 68, 4, 65, 7,  5, 8, 46, 6, 30, 1,  1, 3, 75, 2, 63, 5, 40, 
    0, 34, 7,  5, 2, 72, 4, 75, 1, 89, 8, 75, 3, 59, 6, 34, 5, 62, 
    8, 38, 4, 67, 0, 62, 2, 27, 6, 37, 1, 33, 5, 47, 3, 80, 7, 21
  };
  const int q0237[] = {
    9, 9, // Number of jobs and machines
    5, 11, 3, 21, 2, 52, 8, 99, 6, 19, 7, 89, 1, 22, 4, 53, 0, 12, 
    1, 63, 0, 59, 5, 96, 6, 56, 4, 35, 7, 26, 8, 72, 3, 98, 2, 89, 
    2, 55, 0,  5, 7, 47, 4, 64, 3, 64, 1, 86, 5, 41, 8,  6, 6, 99, 
    8, 40, 5, 35, 6, 59, 0, 30, 7, 43, 2, 27, 3, 96, 4, 75, 1, 91, 
    1, 80, 0, 12, 4, 45, 3, 86, 6,  7, 5, 50, 2, 60, 8, 96, 7,  1, 
    0, 45, 5, 65, 6, 55, 8, 43, 1, 55, 7, 91, 2, 52, 4, 65, 3, 37, 
    6,  3, 4, 59, 1, 98, 3, 41, 0, 48, 2, 18, 5, 89, 7, 48, 8, 85, 
    7, 76, 1, 48, 5,  9, 2, 76, 0,  4, 6, 72, 8, 10, 4, 66, 3, 42, 
    1, 37, 3, 40, 8, 46, 6, 26, 7, 63, 2, 32, 0,  1, 4, 66, 5, 38
  };
  const int q0238[] = {
    9, 9, // Number of jobs and machines
    0, 82, 8, 86, 4, 14, 7, 90, 3, 92, 6, 22, 5, 61, 1, 33, 2, 55, 
    5, 29, 4, 88, 0,  6, 7, 60, 3,  3, 2,  4, 8,  1, 6, 90, 1, 21, 
    6, 70, 8, 35, 2, 77, 7, 70, 3, 50, 5, 72, 4, 29, 1, 74, 0, 70, 
    3, 72, 5, 84, 4, 81, 6, 30, 0,  5, 2, 10, 8, 76, 1, 74, 7, 19, 
    7, 25, 8, 29, 6, 20, 5, 17, 3, 43, 1, 88, 0, 25, 4, 71, 2, 10, 
    4, 89, 7, 75, 5, 70, 3, 38, 6,  5, 1, 99, 2, 96, 8,  9, 0, 78, 
    6, 85, 2, 75, 1,  5, 8, 31, 5, 59, 3, 18, 4, 77, 7, 60, 0, 69, 
    6, 44, 8,  5, 7, 23, 4, 59, 2, 95, 3, 48, 1, 38, 5, 95, 0, 80, 
    2, 31, 5, 24, 4, 94, 1, 83, 7, 99, 6, 37, 3, 31, 0, 67, 8, 22
  };
  const int q0239[] = {
    9, 9, // Number of jobs and machines
    2, 55, 5, 64, 0, 17, 3, 17, 6, 31, 4, 64, 7, 41, 1, 68, 8,  9, 
    1, 58, 8, 26, 7,  7, 0, 41, 5, 83, 4, 33, 3, 64, 6, 97, 2, 74, 
    8, 76, 0, 57, 5, 74, 4, 59, 7, 72, 6, 42, 1, 27, 2,  4, 3, 60, 
    6, 10, 1, 98, 4, 16, 8,  9, 0, 30, 5, 45, 3, 67, 7, 68, 2, 60, 
    0, 78, 6, 10, 3, 85, 1, 37, 4, 85, 2, 56, 8, 88, 5, 62, 7, 99, 
    4, 70, 7, 68, 6, 39, 3, 87, 8, 95, 1, 62, 0, 73, 2, 10, 5, 65, 
    0, 24, 7,  1, 1, 23, 3, 67, 5, 50, 8, 30, 4, 25, 2, 67, 6, 72, 
    0, 45, 4, 75, 5, 64, 7, 87, 8, 33, 6,  3, 3, 12, 1, 73, 2, 98, 
    8, 64, 5, 81, 2, 28, 7, 40, 0, 27, 6,  7, 1, 85, 3, 25, 4, 20
  };
  const int q0240[] = {
    9, 9, // Number of jobs and machines
    5, 16, 7, 25, 1, 65, 3, 89, 2, 38, 0,  4, 4, 13, 8, 51, 6, 50, 
    4,  1, 7, 36, 5, 26, 0, 48, 3, 86, 1, 41, 2,  6, 8, 24, 6, 92, 
    6, 59, 7, 99, 8, 33, 0, 65, 5, 76, 4,  2, 1, 50, 3, 38, 2, 98, 
    8, 94, 1,  7, 4, 48, 0, 92, 5, 55, 3, 91, 2,  3, 6,  1, 7, 76, 
    6, 73, 1, 44, 5,  5, 8, 28, 0, 55, 2, 24, 4, 92, 3, 59, 7, 55, 
    1, 12, 6, 24, 2, 91, 4, 20, 5, 92, 0, 90, 8, 11, 3, 46, 7, 71, 
    2, 36, 6, 18, 4, 89, 5, 71, 8, 90, 3, 75, 1, 26, 0, 46, 7, 23, 
    2, 19, 1, 20, 4, 23, 7, 33, 5, 66, 6, 81, 3, 17, 8, 82, 0,  9, 
    0, 22, 3, 52, 7, 99, 4, 44, 8, 45, 5,  6, 6, 89, 2, 42, 1, 37
  };
  const int q0241[] = {
    9, 9, // Number of jobs and machines
    8, 11, 4, 77, 6,  7, 7, 84, 3, 23, 2, 23, 0, 92, 1, 78, 5, 68, 
    4, 55, 8, 19, 0, 20, 2, 35, 3, 62, 5, 81, 6, 47, 7, 94, 1, 75, 
    7, 23, 5, 99, 0, 24, 2, 40, 6, 75, 3, 20, 4, 91, 1, 96, 8,  6, 
    2, 35, 5, 15, 7, 10, 3, 99, 1, 78, 0, 47, 8, 48, 6, 99, 4, 88, 
    2, 81, 3, 94, 7, 12, 5, 16, 1,  4, 4, 42, 0, 16, 8, 26, 6, 62, 
    8, 39, 3, 94, 7, 99, 1, 38, 5, 11, 6, 84, 2,  3, 0,  9, 4, 66, 
    0, 69, 8, 87, 6, 61, 7, 53, 3, 50, 1, 95, 2, 29, 4, 92, 5, 63, 
    4, 24, 3, 61, 0, 54, 8, 21, 2, 22, 1, 20, 7, 96, 5, 61, 6, 62, 
    7, 98, 0, 84, 3,  6, 2, 80, 6, 93, 1,  8, 5, 39, 8, 33, 4,  9
  };
  const int q0242[] = {
    9, 9, // Number of jobs and machines
    6, 42, 0, 88, 3, 43, 4, 82, 5, 35, 2,  1, 7, 92, 8, 56, 1, 31, 
    7, 56, 3, 17, 4, 48, 0,  3, 5, 34, 6, 50, 2, 59, 8, 91, 1, 37, 
    2, 93, 3, 38, 8, 35, 4, 46, 1, 95, 7, 72, 6, 97, 0, 43, 5, 86, 
    3, 15, 8, 21, 2, 41, 7, 88, 0, 58, 6, 56, 1,  8, 4, 59, 5, 94, 
    5, 70, 0, 29, 1, 45, 2, 39, 4, 13, 8, 64, 6, 81, 7,  1, 3, 46, 
    0, 48, 3, 81, 1, 26, 6, 97, 8, 83, 4, 51, 2, 52, 7, 16, 5,  4, 
    8, 19, 4, 71, 2, 63, 1, 87, 0,  7, 7, 54, 6, 22, 3, 54, 5, 79, 
    7, 76, 6, 45, 5, 26, 8, 38, 1, 18, 2, 73, 4, 77, 3, 98, 0, 45, 
    7, 12, 5, 72, 6, 75, 2, 59, 8, 36, 1, 64, 0, 82, 3, 57, 4, 71
  };
  const int q0243[] = {
    9, 9, // Number of jobs and machines
    8, 92, 2, 76, 0, 56, 6, 55, 3, 73, 7, 46, 4, 72, 1, 84, 5, 91, 
    5, 50, 1, 83, 4, 22, 0, 75, 2, 37, 6, 24, 3, 67, 8, 87, 7, 12, 
    5, 27, 2, 60, 0, 56, 6, 44, 8, 46, 7, 98, 4, 81, 3, 78, 1, 76, 
    2, 75, 4, 26, 3, 84, 1, 65, 0, 46, 6,  2, 7, 88, 5, 87, 8, 11, 
    5, 19, 0, 34, 3, 33, 1, 33, 6, 13, 7, 57, 4, 48, 2, 10, 8, 47, 
    5, 32, 7, 99, 1, 60, 4, 55, 2, 47, 0, 27, 6, 93, 8, 54, 3, 19, 
    6, 98, 4, 26, 8, 84, 3, 53, 0, 62, 1, 93, 2, 23, 5,  5, 7, 46, 
    4, 29, 1, 57, 3, 71, 5, 39, 8, 65, 6, 37, 7, 41, 2, 87, 0, 11, 
    6, 55, 1, 16, 4, 55, 5, 58, 7, 90, 0,  4, 2,  4, 3, 14, 8, 62
  };
  const int q0244[] = {
    9, 9, // Number of jobs and machines
    5, 81, 3,  1, 6, 42, 0, 47, 4, 18, 2, 11, 8, 55, 7, 58, 1, 16, 
    3, 46, 2, 41, 7, 60, 1, 10, 6, 26, 0, 15, 5, 71, 4, 95, 8, 12, 
    4, 87, 7,  2, 6,  4, 8, 38, 2, 47, 0, 17, 5, 90, 3, 18, 1, 16, 
    2, 96, 0, 27, 8, 15, 6, 60, 7, 41, 1, 13, 3, 62, 4,  8, 5, 75, 
    7, 92, 1, 48, 6, 27, 5, 96, 3, 56, 8, 34, 4, 19, 2, 41, 0, 13, 
    6, 83, 2, 69, 8, 72, 4, 43, 5, 51, 0, 29, 3, 24, 1, 12, 7,  5, 
    5, 67, 7, 41, 2, 64, 1, 33, 8, 22, 4, 70, 0, 78, 6, 96, 3, 56, 
    4, 74, 1, 55, 7, 88, 0, 63, 6, 95, 2, 47, 5,  6, 8, 31, 3, 58, 
    5, 37, 3, 80, 7, 52, 4, 40, 8, 35, 6, 77, 1, 71, 0, 34, 2, 84
  };
  const int q0245[] = {
    9, 9, // Number of jobs and machines
    6, 63, 8, 44, 4,  8, 7,  1, 3, 96, 0, 50, 1, 18, 2, 46, 5, 52, 
    5, 26, 6, 16, 2, 24, 3,  8, 4, 86, 7, 96, 0, 25, 1,  3, 8, 28, 
    7, 80, 6, 89, 3, 84, 4, 90, 5, 53, 0, 34, 8, 23, 1, 90, 2, 29, 
    8, 38, 3, 68, 7, 19, 6, 88, 5, 97, 2, 69, 0, 32, 1, 64, 4, 91, 
    4, 71, 3,  1, 7, 27, 0, 33, 8, 79, 6, 73, 5, 45, 1, 77, 2, 87, 
    2, 87, 1, 54, 5, 54, 4, 27, 8, 15, 6, 91, 0, 88, 7, 69, 3, 79, 
    8, 41, 2, 87, 4, 52, 3, 44, 7, 63, 5,  2, 0, 90, 1, 21, 6, 98, 
    8, 26, 1, 70, 0, 26, 7, 89, 5, 90, 3, 83, 2,  3, 4, 30, 6,  7, 
    5, 54, 0, 18, 4, 56, 2, 75, 8, 63, 1, 24, 3, 91, 6, 17, 7, 49
  };
  const int q0246[] = {
    9, 9, // Number of jobs and machines
    0, 51, 6, 72, 2, 78, 4, 62, 5, 60, 8, 88, 1, 74, 3,  1, 7, 15, 
    5, 47, 1, 38, 6, 84, 7, 84, 0, 41, 4, 70, 2, 92, 8, 65, 3,  8, 
    2, 88, 7, 53, 3,  2, 6, 13, 5, 54, 0, 42, 4, 33, 8, 48, 1, 84, 
    1, 23, 0, 14, 3, 94, 6, 35, 8, 66, 5, 73, 7, 70, 4,  8, 2, 75, 
    3, 29, 4, 34, 8, 16, 1, 18, 5, 73, 0, 56, 7, 38, 6, 57, 2, 36, 
    7, 37, 5, 76, 4, 67, 1, 42, 0, 43, 3, 77, 2, 20, 6, 41, 8, 79, 
    2, 33, 5, 14, 6, 93, 4, 23, 8, 61, 7, 10, 3, 88, 0, 79, 1, 54, 
    3, 73, 4, 39, 5, 75, 2, 42, 7, 59, 1, 24, 8, 89, 0, 72, 6,  7, 
    6, 23, 1, 35, 7, 67, 0, 88, 5, 93, 2, 59, 8, 65, 3, 46, 4, 90
  };
  const int q0247[] = {
    9, 9, // Number of jobs and machines
    1, 43, 2, 51, 5, 85, 6, 32, 3, 53, 7, 70, 0,  7, 4, 78, 8, 15, 
    4, 17, 7, 47, 8, 74, 0, 82, 1, 98, 3, 16, 6, 19, 2, 71, 5, 74, 
    8, 38, 3, 67, 1, 52, 7, 38, 2, 78, 4, 19, 0, 45, 6, 30, 5, 48, 
    3, 58, 8, 50, 0, 21, 7, 13, 1, 60, 5, 85, 2, 14, 4, 90, 6, 68, 
    6, 75, 0, 90, 5, 10, 7, 57, 3, 61, 4, 33, 1, 37, 2,  7, 8, 68, 
    6, 87, 5, 72, 0, 90, 8, 34, 7, 48, 1, 88, 2, 91, 3, 31, 4, 23, 
    6, 76, 3, 12, 0, 20, 7, 97, 4,  7, 1, 99, 2, 69, 5, 26, 8, 47, 
    6, 76, 4, 72, 8, 29, 0, 30, 3, 98, 5, 71, 2, 44, 7, 35, 1, 49, 
    2, 32, 8,  2, 5, 13, 7, 85, 4, 62, 0,  2, 3, 40, 6, 94, 1, 85
  };
  const int q0248[] = {
    9, 9, // Number of jobs and machines
    4, 50, 3, 35, 8, 72, 5, 77, 6, 46, 0, 39, 7, 46, 1, 67, 2, 17, 
    5, 38, 8, 53, 7, 56, 0, 70, 1, 11, 6, 32, 2, 26, 4, 67, 3, 77, 
    0, 69, 1, 93, 5, 35, 4, 27, 3, 39, 8, 93, 6, 62, 2, 50, 7, 96, 
    6,  4, 4, 61, 1, 91, 5, 22, 0, 36, 7, 99, 2, 34, 8, 77, 3, 74, 
    4, 33, 6, 31, 1,  1, 0, 81, 2, 73, 7, 94, 3, 87, 5, 90, 8, 14, 
    5, 53, 6, 28, 8, 65, 3, 82, 2, 38, 0, 22, 4, 40, 1, 42, 7, 26, 
    8, 98, 1,  8, 5, 27, 6, 35, 0, 42, 4, 48, 2,  2, 7, 95, 3, 96, 
    1, 95, 4,  9, 5, 88, 2, 55, 6, 53, 0, 69, 3, 25, 7, 75, 8, 79, 
    4,  5, 7, 29, 0, 91, 8, 94, 6, 31, 1, 21, 2, 67, 5, 44, 3, 66
  };
  const int q0249[] = {
    9, 9, // Number of jobs and machines
    7, 44, 0, 58, 3, 37, 2, 86, 6,  8, 1, 32, 5, 39, 8, 56, 4, 39, 
    3, 99, 5, 11, 7, 99, 2, 38, 6, 84, 8, 92, 1, 34, 0, 48, 4, 16, 
    2, 52, 4, 43, 7, 27, 0, 87, 3, 54, 1, 13, 8, 64, 6, 50, 5, 41, 
    5, 30, 3, 65, 7, 30, 2, 38, 6, 34, 0, 73, 8, 38, 4, 81, 1, 84, 
    6, 56, 5, 58, 1, 68, 3,  9, 8, 59, 7,  6, 0, 18, 4, 67, 2, 17, 
    4, 99, 2, 29, 7,  7, 6, 36, 5, 73, 0, 30, 3, 99, 8, 73, 1, 94, 
    5, 46, 0, 11, 3,  3, 8, 45, 4,  5, 1, 86, 2, 28, 6, 85, 7, 78, 
    4, 68, 6, 63, 0, 15, 7, 51, 2, 80, 1, 28, 5, 77, 8, 42, 3, 37, 
    2, 69, 0, 48, 4, 69, 5, 41, 7, 88, 6, 11, 8,  5, 3, 51, 1, 28
  };
  const int q0250[] = {
    9, 9, // Number of jobs and machines
    1, 41, 6, 83, 8, 54, 3, 93, 5, 48, 4, 15, 2, 38, 7, 38, 0, 93, 
    4, 52, 0, 73, 6, 54, 2, 47, 8, 26, 3, 48, 7, 44, 1,  1, 5, 31, 
    6, 53, 5, 95, 1, 20, 3, 17, 7, 66, 2, 50, 0, 64, 4, 72, 8, 12, 
    2, 12, 0, 62, 5, 62, 8,  5, 4, 31, 3, 15, 7, 96, 1, 36, 6, 29, 
    4, 16, 0, 82, 5, 12, 3, 45, 1, 63, 7, 29, 2, 31, 6, 52, 8, 21, 
    2, 13, 1, 91, 6, 36, 5, 36, 8, 42, 7, 75, 0, 29, 4, 34, 3, 84, 
    8, 44, 0, 94, 5, 93, 3, 99, 2, 10, 1,  4, 7, 84, 6, 53, 4, 35, 
    7, 83, 1, 62, 2, 49, 5, 46, 3, 38, 0, 39, 6, 12, 4, 31, 8, 89, 
    0, 62, 2, 92, 8,  5, 1, 36, 7, 58, 4, 94, 3,  4, 5, 82, 6, 87
  };
  const int q0251[] = {
    9, 9, // Number of jobs and machines
    1,  1, 7, 40, 3, 19, 8, 91, 6, 92, 2, 21, 5, 21, 4, 50, 0, 81, 
    4, 43, 5, 15, 0, 41, 7, 14, 6, 98, 3,  9, 2, 29, 8, 83, 1, 71, 
    3, 41, 8, 88, 5, 61, 7, 13, 2, 70, 4, 94, 0, 27, 1, 51, 6, 72, 
    8, 79, 7, 18, 3, 88, 2, 17, 6, 62, 0, 95, 4, 95, 5, 26, 1, 84, 
    5, 59, 0, 20, 3, 18, 8, 47, 4, 26, 7, 33, 1, 44, 2, 19, 6, 38, 
    2, 28, 7, 34, 0, 69, 4, 11, 1, 96, 8, 36, 6, 79, 5, 25, 3, 52, 
    3, 31, 8, 61, 7, 93, 1, 35, 6, 56, 5,  6, 4, 75, 2, 13, 0, 98, 
    5, 62, 1, 36, 0, 37, 8, 23, 2, 65, 3, 32, 7, 19, 4, 19, 6,  4, 
    6, 98, 4, 63, 1, 72, 7, 27, 3, 17, 0,  3, 8, 64, 5, 16, 2, 82
  };
  const int q0252[] = {
    9, 9, // Number of jobs and machines
    0, 44, 6, 32, 3,  6, 1, 85, 2, 57, 4, 25, 5, 96, 8, 38, 7, 86, 
    7, 85, 2, 45, 5, 87, 0, 66, 3, 35, 6, 73, 4, 52, 1, 77, 8, 78, 
    6, 86, 3, 91, 5, 64, 7, 84, 1, 78, 8, 33, 2, 71, 4, 94, 0, 80, 
    5, 86, 2,  1, 4, 28, 1, 45, 0, 59, 7, 93, 6, 30, 3, 14, 8, 85, 
    1, 49, 0, 61, 2, 85, 8, 38, 7, 66, 5, 37, 4,  3, 6,  4, 3, 80, 
    6, 70, 7, 29, 1, 79, 2,  2, 3, 16, 0, 85, 4, 63, 8, 35, 5, 68, 
    3, 56, 0, 20, 2, 93, 8,  7, 5, 17, 4, 73, 7, 95, 6, 60, 1, 58, 
    8, 20, 2, 47, 5, 66, 4,  9, 6, 17, 0, 39, 3, 50, 7, 94, 1, 46, 
    4, 83, 5, 19, 1, 33, 2, 17, 6, 67, 7, 79, 8, 42, 0, 65, 3, 50
  };
  const int q0253[] = {
    9, 9, // Number of jobs and machines
    3, 21, 4, 39, 7, 27, 2,  9, 6, 90, 1, 20, 5, 26, 8, 24, 0, 52, 
    8, 82, 3, 24, 2, 91, 4, 10, 0, 46, 5, 21, 1, 84, 6, 38, 7, 85, 
    3, 89, 4, 35, 5, 42, 8, 45, 7,  5, 6, 32, 1, 36, 0, 74, 2, 29, 
    7, 61, 0, 57, 6, 64, 4, 19, 8, 69, 3, 15, 1, 10, 5, 99, 2, 22, 
    5, 60, 7, 15, 4, 28, 3, 50, 0, 85, 6, 99, 2, 87, 8, 86, 1, 51, 
    0, 63, 3, 44, 5, 15, 1, 71, 4, 78, 8, 88, 6, 19, 7, 82, 2, 48, 
    7,  3, 2, 25, 6, 20, 4, 90, 8, 14, 0, 24, 1, 15, 5, 63, 3, 39, 
    1, 41, 7, 16, 8,  6, 0, 94, 2, 87, 6, 74, 3,  2, 5, 40, 4, 62, 
    0, 86, 8, 75, 7, 35, 1, 20, 5, 66, 2, 34, 3, 30, 6, 83, 4, 79
  };
  const int q0254[] = {
    9, 9, // Number of jobs and machines
    0, 70, 5, 30, 1, 39, 8, 58, 3, 90, 4, 60, 2, 20, 7,  3, 6, 21, 
    6, 94, 0, 32, 2, 81, 4, 70, 7, 83, 5, 26, 3, 83, 8, 86, 1, 60, 
    7, 86, 6, 11, 0, 39, 1,  5, 3, 39, 8, 71, 4, 46, 2, 30, 5, 72, 
    7, 49, 5, 75, 6, 57, 1, 18, 2, 32, 3, 49, 4, 47, 0, 19, 8, 22, 
    3, 35, 8, 25, 7, 12, 1,  3, 5,  3, 2, 12, 6, 77, 0,  5, 4, 95, 
    5, 13, 8, 28, 1, 87, 6, 16, 7, 60, 3, 52, 0, 85, 2, 22, 4, 80, 
    3, 91, 6, 28, 7, 79, 5, 68, 1, 68, 4, 98, 8, 23, 2, 63, 0, 26, 
    1, 88, 5, 90, 4, 28, 3, 24, 0, 17, 2, 58, 7, 64, 8, 23, 6, 84, 
    8, 45, 7, 15, 0, 31, 4, 29, 6, 50, 1, 94, 2, 85, 5, 99, 3,  9
  };
  const int q0255[] = {
    9, 9, // Number of jobs and machines
    0, 62, 7, 42, 2, 18, 1, 38, 3, 71, 8, 64, 5, 51, 4, 97, 6,  7, 
    2, 60, 6, 57, 3, 96, 8, 29, 4, 49, 7, 67, 0, 52, 5, 92, 1, 98, 
    3, 49, 6, 57, 7, 31, 2, 91, 8, 40, 0, 38, 1, 65, 5, 13, 4, 81, 
    7,  3, 0, 20, 4, 55, 6, 72, 5, 53, 3, 49, 8, 36, 1, 19, 2, 65, 
    8, 37, 4, 49, 1, 80, 0, 25, 2, 53, 6, 77, 5, 47, 3, 96, 7, 68, 
    6, 55, 1, 26, 0, 91, 7, 73, 4, 61, 3, 61, 2, 10, 8, 20, 5, 78, 
    8, 90, 4, 37, 3, 73, 7, 68, 0, 63, 1, 47, 6,  8, 2, 47, 5, 53, 
    4,  8, 3, 59, 1, 79, 7, 85, 2, 30, 0, 10, 5, 58, 6, 76, 8, 72, 
    2, 55, 7, 48, 4, 31, 0, 80, 5, 38, 1, 80, 3, 82, 8, 29, 6, 52
  };
  const int q0256[] = {
    9, 9, // Number of jobs and machines
    7, 68, 2, 63, 8, 62, 3, 36, 4, 14, 0,  4, 1, 54, 6, 41, 5, 19, 
    4, 74, 6, 48, 5,  4, 0, 83, 1, 21, 3, 52, 8, 86, 7, 16, 2, 90, 
    7, 62, 4, 34, 3, 86, 1, 72, 6, 20, 2, 84, 8, 23, 0, 77, 5, 68, 
    8, 86, 1, 45, 7, 39, 2, 40, 3, 25, 6, 68, 4, 30, 5,  5, 0, 30, 
    2, 37, 4, 11, 6, 12, 7, 59, 1, 26, 0, 52, 5, 17, 8, 52, 3, 69, 
    5, 37, 1, 85, 3, 72, 0, 74, 8, 78, 4, 82, 2, 71, 7, 64, 6, 10, 
    3,  3, 0, 61, 8,  2, 7, 97, 6, 32, 1, 61, 2, 59, 5,  1, 4, 94, 
    0, 86, 4, 83, 3, 90, 2, 48, 5, 71, 1, 49, 8, 63, 7, 24, 6, 56, 
    0, 99, 2, 53, 8, 60, 7, 19, 4, 35, 5, 21, 1, 91, 6, 41, 3, 99
  };
  const int q0257[] = {
    9, 9, // Number of jobs and machines
    7, 24, 6, 78, 5, 71, 8, 92, 1, 66, 2, 52, 4, 85, 3, 52, 0, 42, 
    0, 77, 2, 76, 6,  1, 5, 55, 8, 26, 4, 90, 1, 74, 3, 52, 7, 12, 
    4, 54, 6, 42, 0, 13, 3, 78, 1, 91, 2, 59, 5, 27, 8,  3, 7, 28, 
    0, 44, 8, 78, 6,  7, 1, 77, 4, 90, 7, 66, 3, 66, 2, 69, 5, 69, 
    7, 67, 4,  3, 5, 28, 2, 14, 3, 31, 0, 65, 1, 28, 8, 68, 6,  9, 
    1, 19, 6, 55, 0,  2, 2, 76, 5, 52, 3, 17, 8, 98, 7, 54, 4, 22, 
    3, 66, 1,  2, 2, 96, 7, 99, 0, 52, 5, 55, 8, 29, 4, 18, 6, 13, 
    4, 23, 0, 31, 6, 35, 1, 47, 8, 67, 2, 55, 5,  9, 3, 66, 7,  2, 
    3, 73, 8, 56, 0,  6, 4, 84, 1, 85, 2, 24, 6, 76, 5, 28, 7, 58
  };
  const int q0258[] = {
    9, 9, // Number of jobs and machines
    2, 20, 4, 67, 5, 41, 3, 80, 0, 81, 7, 76, 1, 52, 8, 13, 6, 44, 
    0, 57, 5, 21, 7,  5, 1, 37, 2, 17, 8, 27, 4, 66, 6, 47, 3, 98, 
    0, 16, 5, 46, 6, 36, 7, 13, 2, 39, 1, 48, 3, 70, 4, 66, 8,  8, 
    2, 74, 4, 99, 0, 92, 5, 85, 7, 37, 6, 22, 1, 76, 3, 95, 8, 95, 
    4, 11, 1, 22, 8, 46, 5, 33, 6, 90, 3,  5, 0, 55, 7,  5, 2, 65, 
    5, 28, 1, 80, 6, 98, 8, 57, 4, 31, 0, 63, 2, 43, 7, 75, 3, 97, 
    8, 51, 2, 33, 4, 75, 1, 68, 6, 38, 7, 10, 3, 68, 5, 36, 0, 22, 
    1, 27, 0, 12, 3, 53, 6, 87, 5, 31, 4,  2, 7, 25, 2, 29, 8, 49, 
    0, 22, 7, 18, 4,  8, 6, 94, 5, 43, 3, 36, 1, 84, 2, 98, 8, 23
  };
  const int q0259[] = {
    9, 9, // Number of jobs and machines
    5, 32, 3, 57, 4, 52, 0, 53, 6, 14, 7, 53, 2, 37, 1, 48, 8, 95, 
    8, 25, 7, 21, 0,  1, 5, 58, 2, 39, 3,  1, 1, 34, 4, 83, 6, 65, 
    6, 34, 4,  3, 5, 86, 8, 14, 3, 25, 2, 33, 1, 48, 7, 50, 0, 11, 
    0, 10, 3, 54, 4, 92, 5, 98, 7, 93, 8, 39, 1, 79, 2, 82, 6, 16, 
    5, 49, 4, 40, 1, 84, 8, 40, 0,  3, 2, 82, 3, 82, 7, 50, 6, 16, 
    2, 48, 0, 25, 8, 98, 3, 43, 7, 89, 5, 93, 1, 52, 4, 89, 6, 20, 
    4,  4, 2, 84, 6, 51, 8, 65, 0, 41, 3, 19, 7,  7, 1, 52, 5, 56, 
    4,  4, 7, 93, 8, 10, 0, 37, 2,  1, 1, 65, 6, 74, 3, 67, 5,  8, 
    6, 62, 7,  5, 8, 52, 0, 56, 4, 47, 3, 63, 5, 40, 1, 44, 2, 63
  };
  const int q0260[] = {
    9, 9, // Number of jobs and machines
    8, 99, 7, 15, 4,  6, 1, 42, 6, 42, 5, 90, 2, 94, 3, 26, 0, 50, 
    8, 52, 2, 94, 4, 32, 3, 69, 0, 18, 6, 92, 1, 16, 5, 28, 7, 51, 
    0, 86, 7, 15, 8, 26, 4, 63, 5, 35, 6, 48, 3, 27, 2, 93, 1, 42, 
    5, 90, 0, 18, 6, 34, 2, 39, 7, 36, 3, 46, 8, 80, 4, 71, 1, 14, 
    8, 29, 0, 79, 7, 90, 4,  6, 2, 60, 6, 44, 1, 84, 3, 43, 5, 61, 
    3, 41, 7, 50, 2, 49, 6, 45, 4,  5, 0, 76, 8, 48, 5, 83, 1, 92, 
    0, 70, 5, 32, 6, 27, 8, 82, 3, 38, 2, 22, 7, 63, 1, 47, 4, 73, 
    7, 28, 2, 56, 8, 62, 1, 96, 0, 51, 5, 66, 4, 70, 3, 40, 6, 25, 
    7, 96, 5, 29, 8, 90, 2, 52, 0, 36, 3,  5, 4, 93, 6, 13, 1, 16
  };
  const int q0261[] = {
    9, 9, // Number of jobs and machines
    7, 11, 6, 41, 8, 32, 5, 85, 0, 14, 4, 98, 2, 84, 3, 99, 1, 22, 
    6,  3, 5,  8, 4, 15, 3, 77, 8, 87, 7, 92, 1,  1, 0, 18, 2, 67, 
    0,  8, 7, 94, 8, 97, 2, 27, 3, 61, 4, 50, 6, 44, 5, 13, 1, 82, 
    2, 51, 7, 58, 0, 54, 4, 47, 1, 52, 8, 77, 6, 84, 5, 50, 3, 13, 
    5, 19, 7, 71, 1, 86, 4, 90, 8,  1, 3,  5, 0, 49, 2,  6, 6, 83, 
    5, 56, 4,  9, 8, 91, 3, 93, 2, 57, 7, 20, 0, 81, 1, 32, 6, 34, 
    6, 31, 2, 82, 4, 56, 8, 63, 0, 94, 1, 47, 7, 29, 3, 81, 5, 59, 
    7, 76, 6, 98, 2, 97, 4, 43, 3, 82, 0, 76, 1, 90, 8, 61, 5, 34, 
    7, 17, 6, 37, 5, 24, 1, 11, 0, 85, 8, 20, 3, 77, 4, 32, 2, 61
  };
  const int q0262[] = {
    9, 9, // Number of jobs and machines
    8, 60, 7, 81, 5, 84, 1, 30, 0, 70, 4, 68, 6, 33, 3, 67, 2, 47, 
    2, 74, 6, 44, 7, 92, 0, 77, 5, 51, 4, 44, 8, 64, 3,  6, 1, 90, 
    4, 67, 8, 84, 0, 71, 1, 43, 7, 15, 6, 95, 3, 30, 5, 73, 2, 88, 
    0, 91, 2,  8, 7, 51, 6, 31, 8,  7, 1, 70, 3, 13, 5, 67, 4, 57, 
    6, 48, 4, 84, 2, 86, 7, 77, 3, 51, 5, 27, 8, 92, 0,  5, 1, 78, 
    2, 71, 7, 41, 0, 13, 6,  9, 4, 40, 3, 77, 8, 64, 1, 56, 5, 16, 
    8, 57, 4,  8, 2, 81, 3, 31, 0, 41, 1, 64, 6, 71, 5, 11, 7, 92, 
    2, 68, 5,  2, 4, 11, 3, 10, 8, 22, 7, 88, 1, 83, 0, 42, 6, 73, 
    6, 95, 2, 32, 0,  5, 7, 30, 8, 40, 4, 88, 1, 96, 3, 19, 5, 43
  };
  const int q0263[] = {
    9, 9, // Number of jobs and machines
    0, 87, 5, 31, 8, 66, 7, 66, 1, 39, 6, 44, 3, 46, 2, 91, 4, 34, 
    3, 89, 8, 83, 1, 80, 2, 98, 4, 35, 6, 32, 7, 55, 0, 75, 5, 80, 
    1, 51, 4, 49, 5, 11, 3, 83, 0, 97, 2, 87, 8, 14, 7, 95, 6, 25, 
    1, 97, 3, 10, 8, 77, 6, 81, 4, 26, 0, 19, 5, 19, 2, 45, 7, 87, 
    6, 18, 1, 79, 7, 39, 0, 36, 2, 40, 5, 11, 8, 91, 4, 33, 3, 79, 
    7, 73, 5,  8, 6,  9, 4, 73, 0, 36, 8, 39, 3,  4, 1, 19, 2, 36, 
    6, 53, 4, 30, 5, 14, 0, 97, 2, 55, 3, 11, 7, 47, 8, 69, 1, 17, 
    7, 17, 8, 85, 4, 14, 0, 78, 2, 34, 5, 27, 6, 24, 3, 87, 1, 86, 
    5, 68, 3, 80, 2, 45, 0, 77, 6, 19, 8, 46, 1, 20, 7, 80, 4, 67
  };
  const int q0264[] = {
    9, 9, // Number of jobs and machines
    4, 12, 3, 49, 7, 42, 0, 48, 2, 12, 5, 37, 1, 14, 8, 48, 6, 41, 
    4, 42, 8, 35, 0, 42, 3, 72, 6, 16, 7, 97, 1,  8, 2, 71, 5, 17, 
    6, 62, 0, 41, 2, 57, 8,  2, 3, 69, 1, 47, 5, 50, 4, 77, 7, 13, 
    5,  5, 0, 45, 1, 74, 6, 53, 8, 95, 4, 48, 2, 31, 3, 30, 7, 76, 
    3,  6, 5, 62, 2, 62, 1, 41, 4, 17, 8, 10, 7, 53, 0, 94, 6,  1, 
    7,  4, 0, 49, 3, 56, 2, 51, 4, 40, 8, 12, 5, 83, 1, 26, 6, 96, 
    1, 84, 6, 68, 3, 94, 8, 19, 2, 83, 0, 17, 7, 97, 4, 52, 5, 49, 
    4, 90, 1, 46, 6, 67, 3, 30, 2, 19, 7, 74, 0, 80, 8, 20, 5, 35, 
    5, 46, 8, 52, 6, 85, 4, 33, 0, 98, 7, 68, 1, 65, 3, 54, 2, 99
  };
  const int q0265[] = {
    9, 9, // Number of jobs and machines
    0, 20, 5, 61, 2, 33, 1, 84, 6, 91, 8, 47, 7, 16, 3, 15, 4, 37, 
    6, 46, 1, 80, 7,  2, 8, 20, 0, 31, 5, 75, 2, 14, 3, 96, 4, 35, 
    3, 76, 5, 36, 6, 13, 8, 43, 0, 94, 2, 92, 7, 92, 4, 35, 1, 25, 
    5, 62, 2, 14, 0, 47, 1, 73, 3, 55, 8, 57, 4, 95, 7, 55, 6, 50, 
    5, 45, 0, 48, 1, 60, 4, 60, 7,  6, 3, 91, 6, 18, 2, 37, 8, 61, 
    8, 82, 7, 83, 6, 60, 5, 68, 1,  4, 3, 20, 2, 41, 4, 76, 0,  1, 
    3, 34, 6, 48, 7, 19, 8, 95, 2, 11, 5,  8, 4, 95, 0, 74, 1, 37, 
    6, 26, 7, 67, 0, 69, 2, 68, 1, 69, 8,  9, 3, 31, 5,  8, 4, 26, 
    6, 11, 0, 53, 5, 65, 2, 89, 7, 71, 4, 76, 3, 48, 1, 75, 8, 88
  };
  const int q0266[] = {
    9, 9, // Number of jobs and machines
    1, 44, 3, 64, 0, 29, 7, 99, 8, 64, 2, 58, 6, 27, 4, 30, 5,  9, 
    4, 30, 5, 60, 3, 72, 2, 21, 1, 60, 6, 59, 8, 60, 7, 46, 0, 49, 
    3, 46, 5, 52, 8, 96, 6, 76, 1, 34, 4, 47, 0, 66, 7, 67, 2, 58, 
    3, 43, 5, 86, 6, 36, 1, 50, 7, 95, 0, 93, 4, 30, 2, 59, 8, 20, 
    5, 65, 7, 48, 1, 30, 4, 96, 6, 91, 2, 23, 3, 89, 0, 46, 8,  4, 
    1, 72, 5, 94, 4,  4, 3, 95, 2, 27, 8, 58, 6, 34, 7, 97, 0, 90, 
    6, 55, 5, 24, 8, 96, 7, 42, 1, 27, 0, 29, 3, 50, 4, 35, 2, 93, 
    5, 46, 0, 89, 8,  9, 6,  4, 1, 12, 3, 48, 2, 64, 7, 26, 4,  1, 
    2, 16, 3, 22, 0, 90, 7, 13, 1, 61, 8, 28, 5, 60, 4, 10, 6, 94
  };
  const int q0267[] = {
    9, 9, // Number of jobs and machines
    2, 64, 0, 73, 8, 62, 6, 47, 7,  8, 5, 14, 4, 96, 3, 64, 1, 48, 
    2,  4, 3, 95, 0, 51, 8, 17, 6, 59, 5, 64, 4, 25, 1, 45, 7, 63, 
    6, 46, 5, 30, 7, 65, 1, 21, 2, 18, 8, 32, 0, 80, 4, 72, 3,  4, 
    8, 21, 3,  2, 7, 15, 1, 19, 2, 91, 5, 21, 4, 33, 6, 41, 0, 30, 
    3, 19, 1, 32, 7, 94, 4, 79, 0, 48, 8, 82, 2, 26, 6, 71, 5,  4, 
    7, 77, 8, 12, 1, 88, 0, 17, 4,  2, 5, 84, 6, 27, 2, 63, 3, 29, 
    3, 57, 1, 62, 6, 57, 4, 86, 5, 93, 8, 83, 7, 64, 2, 45, 0, 58, 
    2, 84, 5, 64, 1,  7, 3, 14, 8,  8, 4, 27, 7, 32, 0, 25, 6, 10, 
    0, 47, 7, 39, 3, 96, 5, 22, 8, 51, 1, 51, 4, 32, 2, 86, 6, 77
  };
  const int q0268[] = {
    9, 9, // Number of jobs and machines
    4, 97, 5, 85, 2, 88, 1, 36, 7, 60, 6, 68, 0, 36, 3, 26, 8, 42, 
    0, 65, 8, 48, 3, 59, 1,  6, 7, 68, 6, 48, 5,  1, 2, 95, 4, 76, 
    3, 60, 4, 47, 2,  2, 6, 17, 0, 69, 1, 18, 7, 30, 8, 32, 5, 22, 
    6, 80, 3,  7, 2, 99, 8, 59, 7, 64, 0,  8, 1, 59, 5, 50, 4,  5, 
    0, 58, 5, 62, 3, 67, 2, 94, 7, 83, 4, 20, 6, 99, 8, 14, 1,  9, 
    4, 42, 8, 80, 3, 15, 1, 14, 0, 62, 2, 84, 6, 82, 7, 40, 5, 36, 
    1, 66, 3, 14, 4, 26, 6, 77, 5, 99, 0, 40, 7, 71, 8, 95, 2, 42, 
    4, 53, 2, 33, 7,  6, 8, 79, 6, 83, 0, 13, 3, 80, 5, 73, 1, 15, 
    2, 47, 1, 93, 5, 44, 6, 56, 8,  1, 4, 23, 3, 15, 0, 87, 7, 97
  };
  const int q0269[] = {
    9, 9, // Number of jobs and machines
    8,  8, 4, 89, 7, 38, 1, 75, 6,  4, 3, 12, 2, 57, 0, 46, 5, 22, 
    2, 21, 3, 89, 4, 92, 7, 87, 0, 74, 6, 90, 1,  5, 8, 20, 5, 10, 
    5, 56, 3, 56, 1, 70, 2, 62, 7, 26, 6, 78, 8, 87, 0, 29, 4, 23, 
    7, 52, 5, 84, 1, 26, 2, 39, 6, 23, 4, 97, 8, 13, 0, 86, 3, 68, 
    7, 49, 0, 82, 3, 74, 2, 37, 5, 94, 1, 31, 8, 35, 4, 33, 6, 21, 
    4, 93, 8, 51, 1, 41, 3, 28, 7, 86, 2, 26, 5, 75, 6, 79, 0,  9, 
    4, 11, 7, 92, 0, 15, 5, 17, 1, 72, 6, 47, 8, 83, 2, 35, 3, 27, 
    4, 40, 6, 90, 7, 82, 2, 80, 3, 98, 1,  2, 5, 22, 8, 10, 0, 17, 
    1, 61, 8, 45, 3, 87, 0, 56, 2, 27, 6, 62, 7, 64, 4, 40, 5, 60
  };
  const int q0270[] = {
    9, 9, // Number of jobs and machines
    3, 90, 6, 48, 0, 25, 8, 91, 4, 39, 7, 11, 5, 69, 2, 85, 1, 29, 
    0, 30, 1, 91, 8, 87, 7,  5, 5, 56, 3, 77, 2, 51, 4, 39, 6, 21, 
    0, 12, 3, 36, 6, 17, 5, 36, 1, 43, 8, 81, 2, 13, 4, 88, 7, 69, 
    4, 87, 3, 63, 6, 98, 0, 32, 8, 18, 5, 22, 7, 60, 1, 61, 2, 42, 
    5, 29, 8, 17, 1, 13, 2,  4, 6, 28, 3, 11, 0, 82, 7, 63, 4, 40, 
    4, 51, 2, 89, 5,  6, 3, 71, 1, 58, 7, 51, 8, 45, 0, 59, 6, 43, 
    4, 55, 8, 52, 3, 23, 2, 76, 1, 21, 0, 40, 7, 30, 6, 33, 5, 79, 
    8, 17, 2,  1, 6,  2, 1, 20, 3, 67, 0, 51, 7, 44, 5, 66, 4, 75, 
    5,  5, 6, 68, 8, 61, 0, 38, 4,  3, 3, 75, 2, 64, 1, 23, 7, 59
  };
  const int q0271[] = {
    9, 9, // Number of jobs and machines
    8, 82, 0, 82, 1, 24, 5, 14, 2, 75, 7, 49, 6, 50, 4,  2, 3, 31, 
    4, 34, 0, 36, 7, 12, 8, 16, 5, 13, 2, 78, 6, 63, 1, 56, 3, 28, 
    2, 69, 5, 80, 7, 94, 3, 69, 1, 64, 6, 87, 4, 27, 0, 20, 8, 13, 
    8, 29, 2, 29, 3, 24, 0,  1, 5, 21, 1, 72, 4, 94, 6, 54, 7, 15, 
    0, 12, 2, 84, 4, 36, 5, 74, 1, 30, 7, 41, 3, 71, 6, 92, 8,  1, 
    4, 79, 0, 11, 2,  3, 5,  5, 6, 17, 1, 59, 3, 30, 7, 84, 8, 37, 
    6, 69, 1, 54, 2, 50, 4, 25, 5, 82, 3, 69, 0, 43, 8, 45, 7, 89, 
    2, 60, 8, 65, 7, 63, 1, 87, 6, 91, 3,  3, 4, 90, 0, 33, 5, 48, 
    8, 50, 5, 48, 3, 76, 6, 47, 1, 50, 2, 51, 7, 75, 4, 37, 0, 30
  };
  const int q0272[] = {
    9, 9, // Number of jobs and machines
    1, 44, 3, 83, 0, 59, 7, 69, 5, 91, 6, 61, 8, 14, 2, 93, 4, 70, 
    0, 65, 4, 10, 6, 89, 7, 35, 5, 81, 8, 26, 1, 79, 2, 98, 3, 31, 
    1, 65, 7, 12, 0, 55, 8, 47, 4, 23, 2,  8, 3, 82, 6, 88, 5, 98, 
    3, 57, 6, 52, 5, 70, 2, 29, 8, 99, 0, 80, 7, 22, 1, 63, 4, 53, 
    2, 40, 7, 95, 5, 90, 3, 92, 8, 10, 1, 25, 0, 69, 6, 28, 4, 12, 
    7, 14, 4, 12, 6, 67, 8, 44, 0, 27, 5, 92, 1, 31, 3, 62, 2, 64, 
    5, 35, 3, 95, 7, 42, 0, 81, 8, 73, 2, 23, 4, 45, 1, 27, 6, 67, 
    7, 71, 0, 35, 3, 16, 4, 28, 2, 26, 6, 61, 1, 15, 5, 10, 8, 54, 
    1, 90, 7, 34, 5, 39, 6, 92, 0, 25, 3, 62, 2, 17, 8, 92, 4, 93
  };
  const int q0273[] = {
    9, 9, // Number of jobs and machines
    4, 22, 8, 57, 7, 13, 6, 55, 0, 48, 5, 38, 2, 28, 3, 80, 1, 42, 
    4, 61, 0, 65, 5,  9, 1, 83, 8, 32, 6, 92, 3, 41, 7, 76, 2, 77, 
    7, 83, 6, 35, 8, 90, 2, 19, 3, 53, 1, 14, 0, 36, 5, 68, 4, 23, 
    6, 12, 4, 19, 2, 56, 7, 89, 1, 47, 3, 67, 0, 35, 5, 94, 8, 93, 
    2, 88, 3, 65, 4, 90, 1, 96, 7, 63, 8, 42, 0, 64, 5, 41, 6, 90, 
    3,  6, 2, 82, 4, 17, 5, 61, 1, 12, 0, 33, 8, 84, 7, 86, 6, 62, 
    2, 79, 1, 53, 7, 82, 3, 65, 8, 23, 0, 77, 6, 69, 5,  6, 4, 34, 
    6, 50, 1, 76, 3, 82, 0, 40, 7, 60, 4,  9, 2, 61, 8, 68, 5, 31, 
    4, 77, 7, 45, 5, 68, 1, 36, 0, 58, 3, 32, 8, 95, 2, 64, 6,  2
  };
  const int q0274[] = {
    9, 9, // Number of jobs and machines
    1, 25, 4, 91, 0, 76, 7, 42, 3, 25, 2, 89, 8, 12, 6, 60, 5, 92, 
    4,  6, 8, 47, 2, 86, 6, 41, 5, 81, 7, 68, 3,  8, 1, 57, 0, 69, 
    0, 27, 2, 43, 1, 47, 7, 71, 8,  1, 6, 53, 4, 97, 3, 73, 5, 39, 
    6, 84, 8, 45, 0, 34, 3,  3, 5, 23, 2, 27, 4, 68, 7, 25, 1, 82, 
    7, 55, 2, 27, 0, 50, 6, 83, 1, 79, 5, 85, 8, 98, 3, 58, 4, 99, 
    8, 53, 0,  1, 5, 43, 2, 31, 1, 29, 7, 60, 6, 95, 4, 41, 3, 22, 
    4, 35, 2, 98, 0, 80, 7, 63, 6, 55, 1, 49, 8, 59, 3, 98, 5, 95, 
    2, 55, 5, 24, 6, 89, 1, 10, 4, 81, 3,  7, 7, 26, 0, 95, 8, 53, 
    0,  2, 1, 25, 6, 48, 3,  5, 8, 32, 5, 13, 4, 56, 7, 21, 2, 73
  };
  const int q0275[] = {
    9, 9, // Number of jobs and machines
    2, 29, 3, 97, 1, 77, 6, 24, 8, 12, 4, 41, 0, 89, 5, 94, 7, 69, 
    1, 79, 0, 26, 3,  8, 7, 56, 6, 55, 8, 63, 5,  1, 2, 12, 4,  3, 
    6, 93, 1,  2, 8, 87, 5,  5, 7, 93, 2, 18, 3, 14, 0, 40, 4, 26, 
    5, 75, 6, 33, 0, 41, 4, 87, 3, 70, 1, 49, 7, 24, 2, 90, 8, 37, 
    0, 32, 2,  5, 1, 34, 5, 83, 7, 40, 6, 75, 4, 12, 8, 42, 3,  7, 
    6, 56, 0, 11, 3, 62, 5,  2, 2, 94, 7, 94, 4, 19, 1, 52, 8, 86, 
    7,  1, 6, 66, 5, 97, 2, 68, 0, 53, 4, 72, 3, 23, 8, 16, 1,  5, 
    7,  6, 3, 76, 0, 56, 4, 71, 1, 83, 6,  7, 8, 40, 5, 95, 2,  5, 
    4, 20, 2, 68, 5, 13, 1, 76, 0,  5, 7, 79, 8, 13, 3, 25, 6, 81
  };
  const int q0276[] = {
    9, 9, // Number of jobs and machines
    1, 62, 3, 13, 5, 87, 0, 12, 7,  6, 8, 31, 4, 73, 6, 27, 2, 27, 
    2, 53, 6, 53, 7, 19, 4, 94, 5, 12, 3, 53, 0, 98, 1, 67, 8, 73, 
    3,  8, 0, 84, 2, 16, 6, 12, 4, 83, 1, 47, 7, 33, 8,  9, 5, 27, 
    6, 68, 4, 99, 7, 85, 5, 89, 8, 63, 3, 93, 2, 77, 1, 67, 0, 88, 
    7, 70, 0, 18, 1, 37, 5, 57, 2, 35, 6, 29, 8, 21, 4, 52, 3, 94, 
    6, 63, 4,  9, 2,  7, 1, 47, 0, 90, 7, 73, 8, 20, 3, 80, 5, 97, 
    6,  8, 8, 94, 0, 72, 2, 50, 7,  6, 4, 55, 1, 79, 5, 13, 3, 66, 
    6, 74, 4, 98, 5, 46, 2, 18, 3, 91, 0, 92, 7, 57, 1, 61, 8, 60, 
    3, 80, 7, 15, 4, 83, 6, 24, 1, 45, 8, 53, 0, 41, 5, 56, 2, 77
  };
  const int q0277[] = {
    9, 9, // Number of jobs and machines
    2, 71, 0,  3, 3, 76, 6, 80, 1, 98, 7, 28, 4, 60, 8, 58, 5, 73, 
    0, 67, 7, 66, 1, 13, 8, 16, 6, 57, 3, 43, 4, 70, 2, 16, 5, 27, 
    2, 68, 1, 85, 4, 48, 8, 56, 3, 56, 7, 13, 5, 75, 6,  3, 0, 30, 
    2, 70, 3, 99, 0,  7, 8,  5, 1, 77, 4, 93, 7, 37, 6,  1, 5,  6, 
    4, 67, 7, 46, 5, 92, 2, 48, 0, 49, 3, 70, 6, 17, 8, 50, 1,  8, 
    7, 26, 6, 19, 0, 70, 3, 42, 5, 12, 1, 67, 8, 97, 4, 76, 2,  1, 
    6, 82, 4, 68, 2, 24, 0, 58, 3, 43, 5, 81, 7, 11, 1,  1, 8, 95, 
    5, 33, 2, 22, 4, 82, 3, 82, 6, 21, 0, 10, 7, 26, 8, 19, 1, 20, 
    0,  8, 2, 51, 4,  8, 6, 64, 7, 63, 3, 17, 5, 88, 8, 83, 1, 15
  };
  const int q0278[] = {
    9, 9, // Number of jobs and machines
    0, 39, 7, 40, 2, 53, 3, 53, 1, 90, 6, 79, 8, 72, 4, 12, 5,  6, 
    4, 97, 0,  6, 8, 39, 5, 76, 2, 75, 3, 50, 1, 49, 6, 81, 7, 80, 
    2, 77, 8, 49, 3, 34, 0, 96, 6,  1, 5,  5, 1, 93, 4, 46, 7,  4, 
    1, 35, 3, 25, 0, 21, 8, 93, 2,  2, 6, 73, 7, 83, 5, 19, 4, 64, 
    2, 51, 5,  5, 1, 17, 7, 56, 0, 98, 6, 49, 8, 77, 4, 13, 3, 91, 
    3, 20, 4, 87, 6, 11, 8,  9, 1, 57, 0, 49, 5,  5, 2, 64, 7, 19, 
    5, 70, 0, 51, 3, 27, 8, 97, 2, 85, 4, 88, 7, 63, 1, 69, 6, 65, 
    2, 41, 7, 34, 8, 30, 0, 99, 4, 73, 3, 76, 6, 68, 1, 39, 5, 72, 
    0, 55, 7, 55, 1, 72, 2, 84, 4, 82, 5, 36, 6, 92, 3, 86, 8, 29
  };
  const int q0279[] = {
    9, 9, // Number of jobs and machines
    8, 17, 4,  9, 5, 48, 7, 63, 3, 98, 2, 71, 6, 73, 1, 97, 0, 90, 
    6, 68, 7, 82, 4, 83, 2, 67, 1, 64, 3, 97, 5, 16, 8, 29, 0, 17, 
    1, 68, 8, 48, 2, 16, 7,  1, 6,  8, 3, 56, 4, 79, 5, 78, 0, 51, 
    7, 50, 0, 79, 5, 30, 8, 65, 2,  4, 1, 79, 6, 48, 3, 82, 4, 87, 
    4, 68, 3, 10, 0, 76, 1, 78, 8, 70, 2, 78, 7, 38, 6, 41, 5, 52, 
    7, 78, 5, 13, 0, 10, 1, 22, 6, 25, 4, 12, 3, 58, 2, 29, 8, 24, 
    5, 50, 2, 83, 0, 23, 1, 27, 6, 74, 8, 69, 3, 69, 4, 64, 7, 10, 
    4, 98, 2, 91, 3, 37, 1, 65, 7, 55, 6, 30, 8, 47, 5, 94, 0, 92, 
    4, 10, 6, 92, 2, 64, 1, 92, 0, 16, 3, 34, 7,  4, 5, 54, 8, 19
  };
  const int q0280[] = {
    9, 9, // Number of jobs and machines
    4, 18, 6, 72, 1, 49, 0, 70, 2, 41, 5, 62, 7, 85, 3,  6, 8, 66, 
    5, 20, 4, 59, 2, 21, 6,  9, 0, 17, 8, 26, 3, 57, 1, 72, 7, 64, 
    3, 10, 5, 71, 7, 95, 1, 14, 2, 60, 4, 20, 8,  4, 0, 85, 6, 73, 
    5, 84, 0, 20, 6, 54, 1, 71, 4, 28, 8, 39, 3, 20, 2, 15, 7, 88, 
    3,  5, 8, 30, 4, 76, 1, 87, 5,  2, 2, 34, 7,  3, 6, 56, 0, 25, 
    8, 76, 4, 20, 1, 19, 3, 21, 5, 98, 2, 89, 7, 56, 6, 15, 0, 87, 
    4, 88, 8, 11, 2,  1, 7, 45, 1, 22, 0, 89, 3,  5, 5, 45, 6, 12, 
    0, 69, 1, 61, 4, 78, 5, 98, 8, 97, 6, 57, 7, 89, 3, 21, 2, 14, 
    1, 26, 2, 11, 6, 91, 3, 26, 0, 95, 8, 51, 7,  3, 4, 89, 5, 13
  };
  const int q0281[] = {
    9, 9, // Number of jobs and machines
    2, 21, 5, 69, 4, 49, 3, 53, 0,  5, 8, 53, 7, 72, 6, 50, 1, 43, 
    0, 77, 1, 70, 7, 91, 2, 47, 3,  3, 4, 43, 8, 52, 6, 35, 5, 34, 
    8, 33, 6, 85, 4, 15, 5, 16, 2, 98, 1, 95, 3, 72, 7, 36, 0, 91, 
    5,  2, 7, 68, 8, 56, 3, 11, 4, 45, 6, 22, 0, 87, 2, 75, 1, 87, 
    2, 43, 6, 23, 4, 84, 8, 97, 5, 93, 1, 19, 3, 74, 0,  1, 7, 23, 
    0, 81, 7, 85, 5, 41, 6, 66, 1, 10, 2, 60, 4, 79, 8, 71, 3, 44, 
    6, 27, 2, 52, 8, 27, 7, 30, 0, 47, 3, 14, 4, 22, 5, 52, 1, 22, 
    8, 87, 1, 90, 0, 14, 4, 31, 2, 55, 3, 89, 5, 43, 6, 97, 7, 30, 
    5, 15, 7, 46, 1, 36, 0, 91, 4, 14, 3, 23, 8, 64, 6, 51, 2, 87
  };
  const int q0282[] = {
    9, 9, // Number of jobs and machines
    1,  3, 5, 99, 0, 48, 8, 70, 2, 66, 3, 87, 4, 45, 7, 57, 6, 61, 
    1,  3, 6, 38, 8, 54, 3,  3, 2, 20, 4, 59, 5, 42, 7, 39, 0, 19, 
    6, 45, 8, 68, 3, 39, 5, 67, 1, 59, 7, 56, 2, 53, 0, 76, 4, 47, 
    5, 93, 4, 91, 2, 29, 3, 14, 7, 97, 6, 15, 8, 35, 0, 45, 1, 63, 
    6, 64, 3, 69, 8, 53, 2, 56, 7, 68, 5, 54, 1,  2, 4, 95, 0,  2, 
    7,  8, 6, 29, 3, 93, 5, 87, 8, 11, 4, 33, 2, 29, 1,  5, 0, 41, 
    0, 88, 4, 30, 3, 32, 1, 67, 7, 38, 5, 39, 2, 27, 6, 65, 8, 15, 
    0, 40, 3, 37, 6, 16, 8, 35, 2, 98, 7, 54, 1, 73, 5, 96, 4, 52, 
    1, 56, 3, 44, 8, 27, 4, 37, 0, 38, 5, 94, 2, 39, 6, 34, 7, 56
  };
  const int q0283[] = {
    9, 9, // Number of jobs and machines
    7, 76, 2, 25, 3, 96, 4, 53, 6,  1, 1, 75, 5, 71, 8, 69, 0,  3, 
    7, 32, 2, 98, 0, 69, 8, 17, 1, 68, 4, 16, 6, 78, 3, 28, 5, 81, 
    5,  1, 4, 87, 8, 78, 6, 28, 2, 55, 3, 16, 1,  9, 0, 38, 7, 14, 
    0, 30, 8,  9, 2, 70, 3, 23, 6, 45, 5, 21, 4, 58, 7, 58, 1, 72, 
    6, 70, 5, 66, 3, 39, 4, 55, 0, 44, 1, 95, 2, 96, 7, 51, 8, 95, 
    2, 51, 4, 23, 7, 62, 1, 48, 8, 36, 0, 80, 6, 51, 5, 57, 3, 97, 
    0,  8, 6, 43, 7, 10, 1, 99, 5, 98, 2, 14, 4, 28, 3, 18, 8, 81, 
    2, 14, 4, 76, 7, 83, 8, 55, 3, 82, 1, 45, 5, 42, 0, 65, 6, 77, 
    5, 33, 8, 30, 1, 47, 2, 23, 4, 46, 7, 56, 0, 31, 6, 23, 3, 22
  };
  const int q0284[] = {
    9, 9, // Number of jobs and machines
    6, 85, 7, 52, 2, 87, 1, 85, 5, 20, 3, 17, 8, 71, 4, 89, 0, 40, 
    2, 16, 5, 20, 8, 96, 7, 60, 0, 14, 4, 97, 6, 29, 1,  6, 3, 33, 
    3, 91, 6,  3, 7, 85, 5, 32, 4, 96, 1, 17, 0, 56, 2, 24, 8, 90, 
    2, 90, 1, 37, 4, 34, 6, 46, 7, 18, 0, 37, 3, 17, 5, 47, 8,  7, 
    0, 51, 3, 33, 1, 38, 8,  4, 5, 33, 2, 32, 7, 40, 6, 62, 4, 33, 
    5, 76, 7, 97, 1,  9, 4, 34, 2, 17, 3, 24, 8, 61, 6, 78, 0, 66, 
    8, 31, 0, 80, 7, 78, 1, 77, 4, 30, 3,  3, 2,  4, 6, 84, 5, 45, 
    2, 14, 8, 15, 7, 73, 0, 48, 3, 29, 1, 88, 4,  7, 5, 36, 6, 19, 
    8, 29, 3, 86, 0, 56, 6, 70, 4, 27, 2,  5, 5, 50, 7, 35, 1,  8
  };
  const int q0285[] = {
    9, 9, // Number of jobs and machines
    5, 65, 1, 85, 8, 16, 6, 90, 4, 61, 7, 82, 0, 19, 2, 26, 3,  6, 
    4, 95, 5, 63, 8, 43, 6, 52, 7, 73, 1, 47, 0, 66, 3, 83, 2, 88, 
    5, 45, 1, 12, 8, 98, 3, 31, 4, 44, 0, 10, 6, 41, 7, 19, 2,  5, 
    3, 72, 5, 16, 8, 11, 4, 23, 7, 54, 6, 32, 1, 37, 0, 88, 2, 44, 
    6, 81, 1, 34, 5,  5, 0,  5, 2, 66, 8, 25, 3, 93, 7, 65, 4, 43, 
    1, 25, 7, 13, 4, 62, 6, 14, 8, 71, 0, 76, 5, 98, 2, 71, 3, 31, 
    2, 94, 4, 46, 3, 75, 8, 75, 5,  3, 6,  5, 1, 82, 0, 40, 7, 33, 
    7,  9, 8,  9, 0, 35, 6, 43, 5, 30, 3, 59, 4, 48, 1, 38, 2,  9, 
    1, 45, 0, 49, 5, 42, 4, 40, 3, 49, 8, 73, 2, 70, 6, 27, 7, 18
  };
  const int q0286[] = {
    9, 9, // Number of jobs and machines
    3, 62, 8,  6, 2, 46, 0,  8, 6, 96, 1, 18, 5, 25, 7, 66, 4, 75, 
    8, 33, 3, 75, 1, 22, 6, 46, 5, 96, 4, 88, 7, 88, 2, 86, 0, 10, 
    4,  8, 5, 36, 6, 22, 3, 53, 7, 74, 0, 83, 1,  6, 2, 94, 8, 13, 
    1, 44, 8, 24, 2, 92, 0, 24, 5, 41, 3,  7, 6,  9, 4, 64, 7, 49, 
    5, 43, 7, 65, 6, 18, 1, 33, 0, 17, 2, 34, 8, 50, 4, 84, 3, 41, 
    7, 14, 4, 61, 6, 27, 3, 25, 5, 66, 8, 16, 1, 37, 0, 56, 2, 25, 
    7, 51, 5, 88, 1, 49, 6, 47, 0, 52, 4, 71, 8, 28, 3, 11, 2, 75, 
    1, 67, 0, 54, 4, 90, 6, 25, 7, 89, 8, 26, 2, 81, 3, 72, 5, 22, 
    6, 43, 5, 68, 7, 94, 1, 43, 3, 69, 2, 58, 4, 33, 0, 65, 8, 74
  };
  const int q0287[] = {
    9, 9, // Number of jobs and machines
    7, 16, 6, 66, 2, 18, 5, 20, 0, 94, 8, 37, 3, 63, 1, 44, 4, 41, 
    3, 55, 4, 74, 2,  9, 5, 35, 7,  5, 0, 89, 8, 14, 1, 41, 6,  6, 
    0, 80, 5, 68, 4, 61, 2, 57, 7, 16, 6, 73, 1, 96, 8,  1, 3, 35, 
    1, 49, 8, 24, 0, 85, 2, 71, 6,  9, 4, 14, 7, 15, 5, 77, 3,  5, 
    6, 34, 7, 46, 8, 25, 2, 33, 5,  3, 0, 86, 3, 37, 4, 46, 1, 74, 
    2, 97, 1, 90, 0, 89, 7, 21, 6, 83, 3, 10, 4,  1, 8, 40, 5,  9, 
    7, 49, 0, 79, 5, 24, 1, 93, 2, 39, 8, 39, 3, 11, 6, 43, 4, 97, 
    1, 35, 5, 94, 7, 57, 3, 33, 0, 12, 8, 96, 4, 30, 6, 19, 2, 91, 
    8, 65, 5, 76, 2, 74, 1, 84, 0, 91, 3, 94, 4, 34, 6, 37, 7, 91
  };
  const int q0288[] = {
    9, 9, // Number of jobs and machines
    5, 13, 7, 43, 2, 60, 0, 18, 3, 10, 8, 80, 6, 62, 1, 49, 4, 58, 
    6, 35, 3, 43, 8, 85, 4, 71, 7, 84, 2, 83, 5, 25, 1, 24, 0, 14, 
    1, 63, 0, 12, 7, 21, 4, 64, 6, 94, 2, 40, 5, 96, 8, 49, 3, 25, 
    6, 46, 3, 77, 1, 28, 7, 75, 4, 48, 5, 15, 0, 74, 8, 63, 2, 45, 
    4, 69, 3, 92, 0, 13, 8, 80, 6, 28, 5, 70, 1, 56, 7, 11, 2,  2, 
    2,  2, 4, 18, 6, 15, 5, 97, 7, 10, 0, 48, 8, 47, 1, 45, 3, 49, 
    7, 45, 0, 69, 4,  2, 2, 13, 3,  1, 6, 15, 8, 63, 5, 47, 1, 22, 
    1, 12, 0, 22, 7, 54, 5, 75, 8, 49, 4, 79, 6, 89, 3, 55, 2, 94, 
    6, 15, 1, 94, 0,  8, 5, 90, 7, 15, 3, 55, 4, 44, 2, 61, 8, 67
  };
  const int q0289[] = {
    9, 9, // Number of jobs and machines
    0, 76, 2, 77, 4,  4, 8,  5, 6, 39, 1, 26, 3, 42, 7, 77, 5, 43, 
    8, 63, 7, 91, 3, 74, 5, 18, 6, 32, 2, 27, 0, 18, 1, 55, 4, 84, 
    0, 93, 2, 13, 5, 46, 8, 63, 1, 89, 4, 39, 3, 76, 6, 99, 7, 52, 
    4, 60, 3, 70, 5, 26, 8, 49, 2, 54, 6,  4, 7, 78, 1, 85, 0, 74, 
    7, 72, 8, 69, 2,  3, 4, 52, 3, 82, 6,  7, 0, 68, 5, 72, 1, 59, 
    6, 40, 7, 57, 4, 19, 5, 46, 2,  4, 3, 18, 0, 31, 8, 36, 1, 42, 
    7, 93, 6, 90, 3, 37, 2, 64, 4, 62, 5, 86, 0, 99, 1, 60, 8, 37, 
    4, 43, 5,  5, 3, 24, 7, 11, 8, 26, 1, 85, 0, 63, 2, 81, 6, 11, 
    2, 63, 8, 14, 4, 39, 6, 28, 0, 55, 7,  3, 5, 72, 1, 10, 3, 42
  };
  const int q0290[] = {
    9, 9, // Number of jobs and machines
    7, 30, 6, 18, 2, 49, 4, 53, 3, 33, 5, 25, 0,  5, 8, 79, 1, 19, 
    8, 23, 7, 87, 2, 79, 3, 84, 5, 78, 0, 29, 1, 54, 6, 37, 4, 67, 
    8, 38, 2, 65, 4, 99, 0, 53, 7, 99, 3, 27, 1, 68, 6, 54, 5, 10, 
    7, 38, 3, 83, 6, 18, 2, 38, 0, 66, 4,  5, 1, 70, 5, 46, 8, 85, 
    2, 45, 7, 19, 5, 94, 6, 50, 1, 82, 4, 47, 0,  4, 8, 19, 3, 84, 
    1, 56, 7,  8, 5, 38, 3, 35, 8, 73, 6,  7, 4,  2, 0,  1, 2,  9, 
    4, 89, 5, 10, 1, 91, 6, 90, 0, 32, 2, 41, 8, 63, 7, 66, 3, 29, 
    6, 47, 7, 78, 5, 64, 3, 12, 8, 41, 4, 47, 0,  7, 1, 74, 2, 35, 
    7, 19, 1, 85, 2, 79, 3, 81, 6, 99, 4, 82, 8, 90, 0, 57, 5, 46
  };
  const int q0291[] = {
    9, 9, // Number of jobs and machines
    5, 95, 2, 53, 1,  9, 4, 81, 0, 77, 6, 37, 3, 73, 8, 12, 7, 67, 
    6, 26, 7, 87, 2, 57, 4, 25, 8, 85, 5, 48, 1, 95, 0, 82, 3, 94, 
    2, 42, 5, 93, 0, 52, 3, 93, 8, 76, 1, 67, 6, 49, 7,  1, 4, 51, 
    7, 85, 2, 20, 4, 17, 5, 95, 0, 15, 3, 24, 8, 39, 6, 74, 1, 40, 
    8, 88, 5, 66, 7, 93, 2, 94, 3, 17, 4, 31, 1, 30, 6,  1, 0, 68, 
    8,  4, 7, 95, 2,  7, 0, 87, 3, 37, 4,  5, 1, 22, 5, 94, 6, 17, 
    8, 11, 5,  6, 3, 23, 4, 17, 7, 26, 2, 20, 1, 94, 6, 81, 0, 13, 
    4, 34, 7, 89, 8, 18, 1, 22, 0, 36, 3, 13, 5, 91, 2, 19, 6, 72, 
    2, 51, 4, 49, 3, 76, 7, 77, 0, 11, 1,  4, 8, 17, 5, 32, 6, 27
  };
  const int q0292[] = {
    9, 9, // Number of jobs and machines
    2, 60, 7, 19, 3, 36, 1,  7, 5, 64, 6, 27, 8, 83, 0, 42, 4, 39, 
    1, 51, 7, 81, 4, 94, 6,  7, 0, 70, 2, 26, 5,  6, 3, 55, 8, 94, 
    3, 63, 0, 98, 8,  7, 5, 75, 4, 84, 2, 47, 7, 22, 1, 36, 6, 82, 
    3,  1, 2, 26, 0, 46, 6, 19, 7, 90, 4, 65, 8, 19, 5, 98, 1, 14, 
    1, 41, 4, 33, 7, 12, 6, 48, 0, 70, 5, 29, 3, 76, 2, 93, 8, 83, 
    2, 53, 7,  9, 4, 60, 0, 53, 8, 14, 5, 11, 6, 99, 1, 27, 3, 66, 
    6, 59, 2, 25, 7, 33, 5, 79, 1, 64, 0, 28, 8, 12, 4, 37, 3, 70, 
    1, 79, 6, 89, 2, 47, 0, 68, 8, 15, 3, 51, 7, 79, 4, 17, 5, 16, 
    4, 69, 7, 39, 1, 77, 0, 90, 3, 22, 8, 31, 2, 95, 6, 26, 5, 84
  };
  const int q0293[] = {
    9, 9, // Number of jobs and machines
    6, 28, 5, 41, 4, 85, 0, 40, 1, 85, 7, 97, 2, 74, 3, 82, 8, 84, 
    6, 87, 4, 30, 0, 67, 3, 41, 8, 82, 1, 45, 2, 61, 5, 38, 7,  3, 
    5, 40, 0, 70, 2, 91, 8, 54, 7,  4, 3,  8, 1,  3, 6, 30, 4, 84, 
    6, 91, 8, 76, 1, 72, 4, 19, 5, 39, 3, 31, 7, 13, 2, 28, 0, 45, 
    2, 63, 0, 70, 4, 22, 7, 44, 3, 56, 5, 65, 8, 76, 6, 81, 1, 45, 
    2, 82, 6, 51, 8,  4, 4, 95, 3, 48, 1, 33, 5,  1, 0, 97, 7, 12, 
    4, 40, 2, 93, 6, 88, 5, 24, 0, 44, 3, 71, 8, 89, 1, 21, 7, 97, 
    6, 41, 7, 79, 0, 92, 8,  4, 4, 78, 2,  9, 1, 46, 3, 94, 5, 12, 
    2, 11, 6, 72, 1, 63, 0, 89, 4, 22, 5, 58, 7, 89, 8, 24, 3, 47
  };
  const int q0294[] = {
    9, 9, // Number of jobs and machines
    7, 15, 0, 46, 4, 59, 3, 92, 6, 27, 5, 93, 1, 99, 8, 43, 2,  3, 
    8, 52, 2, 92, 4, 16, 5, 42, 3, 85, 0, 42, 6, 99, 1, 46, 7, 38, 
    5, 76, 6, 35, 0,  2, 1,  6, 4, 61, 2, 10, 7, 69, 8, 22, 3, 48, 
    8, 85, 3, 89, 2, 15, 4,  3, 5, 34, 7, 58, 6, 45, 1, 90, 0, 93, 
    5,  9, 6, 23, 1, 60, 3, 95, 0, 61, 8, 60, 4,  3, 7, 67, 2, 57, 
    8, 86, 6, 79, 7, 17, 4, 93, 2, 37, 3, 75, 5, 55, 1, 86, 0, 90, 
    7, 69, 4, 53, 6, 90, 1, 61, 2,  1, 5, 23, 8, 80, 3, 83, 0, 65, 
    3, 53, 0, 90, 8, 99, 6, 48, 1, 45, 2, 71, 4, 39, 5, 43, 7, 36, 
    1, 24, 4, 90, 7, 26, 6, 77, 5, 82, 3, 64, 0, 58, 2, 47, 8, 20
  };
  const int q0295[] = {
    9, 9, // Number of jobs and machines
    0,  9, 3, 28, 4, 80, 1, 81, 2, 60, 8, 44, 7, 62, 6, 77, 5, 94, 
    5, 56, 4, 71, 7, 19, 6,  2, 1,  2, 8, 42, 2, 57, 0,  7, 3, 73, 
    5, 31, 4, 54, 1, 75, 6, 70, 7, 26, 0,  6, 3, 27, 2, 47, 8, 43, 
    4, 65, 3, 61, 2, 30, 6, 57, 1, 16, 5, 27, 7, 51, 8, 99, 0, 74, 
    0, 73, 8, 95, 3, 33, 7, 41, 5, 20, 6, 57, 4, 56, 1, 10, 2, 93, 
    5, 46, 4, 35, 2, 81, 0, 39, 7, 44, 8, 97, 3, 42, 1, 56, 6, 11, 
    2,  1, 1, 40, 4, 81, 7, 54, 0, 72, 8,  3, 6, 88, 5, 61, 3, 35, 
    6, 80, 7, 40, 4, 67, 3, 20, 2, 92, 1, 89, 8, 49, 0, 96, 5,  6, 
    2, 68, 4, 40, 5,  8, 0, 84, 3, 21, 6, 94, 7,  4, 8, 21, 1, 79
  };
  const int q0296[] = {
    9, 9, // Number of jobs and machines
    1, 44, 6, 64, 3, 98, 7, 21, 8,  4, 4, 15, 2, 24, 5, 91, 0, 93, 
    3, 57, 5, 94, 4, 90, 8, 99, 0,  3, 6, 88, 7, 26, 2,  9, 1, 47, 
    7, 31, 2, 72, 6, 71, 5, 99, 4, 56, 3, 39, 1, 45, 0, 51, 8, 42, 
    7, 21, 2, 33, 3, 31, 5, 34, 6, 85, 8, 68, 0, 38, 4, 33, 1, 47, 
    8, 83, 3, 28, 1, 27, 6, 39, 0, 67, 7, 55, 4, 82, 2, 35, 5, 31, 
    2, 51, 6, 34, 5, 33, 4, 44, 7, 78, 8, 32, 0, 32, 3, 65, 1, 39, 
    0, 93, 5, 33, 7, 23, 2, 11, 1, 51, 4, 72, 3,  9, 8, 37, 6, 56, 
    3, 10, 5, 50, 6, 31, 4, 92, 2, 14, 0, 50, 8, 66, 1, 17, 7, 77, 
    5, 60, 7, 82, 6, 11, 2, 31, 0, 98, 4, 48, 3, 58, 8, 80, 1, 87
  };
  const int q0297[] = {
    9, 9, // Number of jobs and machines
    8, 41, 0, 84, 6, 55, 5, 25, 2, 37, 4, 32, 1, 23, 3, 18, 7, 55, 
    3,  4, 8, 99, 4,  7, 5, 58, 0, 78, 7, 96, 6, 70, 2, 55, 1, 17, 
    8, 14, 1, 87, 3, 32, 0,  9, 4, 54, 5, 51, 7, 53, 2, 67, 6, 42, 
    0, 86, 5, 65, 4, 57, 3, 94, 7, 61, 2, 81, 6, 81, 8, 91, 1, 19, 
    1, 26, 3, 19, 4, 97, 7, 35, 5, 16, 2, 13, 0, 27, 8, 83, 6, 58, 
    7, 90, 6, 88, 2,  9, 0, 90, 8, 64, 4, 99, 1, 30, 5, 79, 3, 30, 
    8, 87, 2, 76, 1,  3, 4, 78, 3, 54, 5, 36, 7, 28, 6, 37, 0, 83, 
    7, 92, 6,  7, 1, 59, 4, 72, 3, 57, 8, 90, 0,  6, 5, 36, 2,  4, 
    8, 87, 7, 18, 6, 28, 5, 38, 2, 23, 0, 23, 3, 25, 1, 92, 4, 83
  };
  const int q0298[] = {
    9, 9, // Number of jobs and machines
    0, 53, 2,  9, 1, 92, 4,  3, 7, 11, 8, 47, 3, 67, 5, 61, 6, 44, 
    3, 14, 2, 56, 5, 58, 1, 22, 4, 84, 8, 24, 0, 66, 6, 70, 7, 54, 
    8,  3, 1, 53, 3, 44, 6, 97, 7,  6, 2, 74, 0, 20, 5, 46, 4, 30, 
    6, 13, 5, 49, 1, 66, 8, 33, 2, 10, 0, 53, 4, 73, 7, 98, 3, 51, 
    5, 78, 4, 22, 2,  8, 8, 11, 0, 73, 6, 50, 3, 45, 1, 49, 7, 25, 
    0,  3, 8, 41, 3, 91, 6, 12, 5, 18, 7, 48, 1, 37, 4, 89, 2, 89, 
    0,  3, 2, 22, 5, 42, 8, 28, 4, 84, 6, 69, 1, 81, 3, 77, 7, 79, 
    4, 73, 7, 39, 3, 53, 1, 73, 6, 69, 2, 16, 5, 61, 8, 75, 0, 98, 
    3, 26, 2, 88, 7, 88, 6, 71, 4, 71, 5, 72, 8, 48, 1, 82, 0, 52
  };
  const int q0299[] = {
    9, 9, // Number of jobs and machines
    7, 95, 2, 85, 5, 17, 6, 51, 8, 35, 1, 99, 0, 99, 3, 93, 4, 64, 
    4, 26, 6, 81, 2, 86, 8, 59, 3, 33, 1, 18, 0, 44, 5, 17, 7, 20, 
    6, 30, 5, 66, 7, 16, 8, 64, 0, 37, 4, 72, 1, 73, 3, 32, 2, 16, 
    4, 96, 3, 60, 1, 54, 0, 63, 7,  3, 6, 41, 5, 33, 2, 27, 8, 55, 
    6, 20, 3, 37, 0, 84, 2, 67, 5,  7, 4,  3, 1, 19, 8, 66, 7, 70, 
    0, 69, 6, 87, 3, 81, 2, 73, 4,  1, 1, 14, 8, 30, 7,  2, 5, 52, 
    5, 49, 2, 44, 7, 70, 1, 37, 3, 38, 8, 41, 6, 56, 0,  5, 4, 41, 
    5, 86, 2, 19, 1, 58, 6, 55, 0, 31, 4, 27, 7, 19, 3, 27, 8, 22, 
    4, 56, 5, 39, 2, 74, 1, 32, 3, 30, 6, 46, 8, 75, 7, 30, 0, 38
  };
  const int q0300[] = {
    9, 9, // Number of jobs and machines
    1, 31, 6, 75, 0, 64, 2, 68, 4, 91, 7, 82, 8, 33, 3, 68, 5, 28, 
    0, 56, 1, 49, 6, 68, 7, 48, 3, 90, 4, 66, 5,  1, 2,  7, 8, 18, 
    5,  8, 0, 54, 7, 23, 1, 73, 6, 71, 2,  9, 4, 67, 8, 58, 3, 32, 
    8, 90, 3, 96, 2, 29, 5, 71, 6, 49, 4, 32, 1, 25, 7, 34, 0, 97, 
    0, 62, 8, 69, 7, 30, 6, 89, 4, 25, 3, 39, 2, 91, 5, 48, 1, 81, 
    7, 23, 1, 59, 4, 82, 8,  5, 2, 89, 5, 60, 3,  1, 0, 20, 6, 44, 
    3,  3, 8, 87, 2, 42, 7, 41, 0, 76, 5, 30, 4,  8, 6, 46, 1, 46, 
    6, 18, 3, 98, 8, 56, 5, 18, 1,  2, 0, 87, 7, 97, 4, 56, 2, 24, 
    5, 92, 7, 75, 6, 76, 2, 86, 1, 48, 3, 54, 8, 52, 4, 76, 0, 76
  };
  const int q0301[] = {
    9, 9, // Number of jobs and machines
    7, 59, 8, 82, 2, 41, 4,  1, 3,  6, 1, 52, 5, 78, 6,  9, 0, 94, 
    0, 36, 1, 85, 2, 16, 5,  8, 3,  7, 6, 56, 8, 20, 7, 16, 4, 88, 
    7, 43, 8, 74, 5, 26, 2, 24, 0, 88, 6, 54, 3, 65, 1, 52, 4, 30, 
    2, 97, 1,  6, 4, 37, 3, 40, 6, 69, 5, 97, 0, 13, 8, 96, 7, 21, 
    1, 78, 2, 84, 3, 55, 0, 85, 4, 40, 5, 67, 7, 35, 6, 96, 8, 68, 
    6, 44, 8, 41, 2, 31, 7, 38, 3, 68, 5, 62, 4, 41, 1, 15, 0, 84, 
    2, 72, 1, 83, 8,  7, 0, 43, 5, 29, 7, 61, 6, 53, 4, 99, 3, 84, 
    0, 54, 8, 79, 2, 97, 3, 45, 4, 41, 1, 41, 5, 46, 6, 46, 7,  5, 
    7, 49, 2, 18, 8, 58, 5, 62, 3, 13, 1, 66, 4, 87, 6, 21, 0, 57
  };
  const int q0302[] = {
    9, 9, // Number of jobs and machines
    4, 22, 2, 24, 0, 11, 1, 38, 5, 32, 3, 97, 8, 10, 7,  4, 6, 72, 
    6, 89, 8, 81, 7,  6, 3, 81, 0,  5, 1, 92, 4,  7, 5, 70, 2, 86, 
    3,  7, 7, 52, 2,  3, 4, 61, 6, 22, 1, 53, 0, 49, 8, 62, 5, 72, 
    2, 66, 4, 56, 8, 62, 5, 84, 6, 68, 3,  7, 0, 31, 1, 66, 7, 98, 
    3, 93, 8, 43, 1, 11, 0, 39, 7, 91, 4, 48, 5, 45, 2, 62, 6, 55, 
    3, 61, 7, 33, 5, 40, 1, 93, 2, 44, 6, 46, 0,  5, 4, 66, 8, 39, 
    4, 67, 5, 27, 8, 13, 7, 36, 3, 12, 1, 91, 0, 87, 2, 29, 6, 66, 
    2, 70, 1, 52, 8, 92, 3, 48, 7, 95, 6, 48, 5, 75, 4, 97, 0, 56, 
    1, 60, 3, 76, 2, 53, 0, 84, 5, 12, 8, 50, 6, 77, 4,  6, 7, 87
  };
  const int q0303[] = {
    9, 9, // Number of jobs and machines
    3, 45, 4, 96, 6, 30, 7, 74, 1, 36, 0, 72, 8, 30, 2, 99, 5, 22, 
    1, 33, 0, 57, 4, 95, 5, 32, 6, 82, 8, 43, 7, 72, 2, 40, 3, 93, 
    3, 99, 5, 27, 8, 74, 0, 38, 1, 28, 7, 60, 6, 59, 2, 68, 4, 36, 
    4, 64, 1, 38, 7, 96, 8, 98, 3, 68, 5, 41, 0, 42, 2, 17, 6,  5, 
    1, 82, 0, 26, 5, 16, 7, 71, 8, 57, 6,  8, 2,  6, 3, 49, 4, 60, 
    6, 74, 5, 34, 8, 42, 4, 62, 3, 17, 2, 88, 0, 24, 7, 97, 1,  1, 
    5, 98, 2,  3, 6, 63, 4, 13, 0, 67, 3, 76, 7, 43, 1, 55, 8, 56, 
    7, 44, 0, 70, 2, 31, 5, 96, 6, 56, 1, 35, 4, 74, 3, 51, 8,  5, 
    2, 53, 5, 75, 0, 72, 4, 89, 8, 56, 7, 20, 1, 13, 3, 29, 6, 36
  };
  const int q0304[] = {
    9, 9, // Number of jobs and machines
    4, 41, 2, 54, 0, 56, 6, 81, 3, 66, 7,  5, 8, 30, 1, 80, 5, 53, 
    1, 27, 5, 59, 7, 74, 3, 46, 2, 24, 0, 56, 8, 35, 4, 63, 6, 98, 
    1,  1, 8,  1, 6, 22, 3, 46, 7, 77, 2, 36, 4, 38, 0, 67, 5, 22, 
    8, 85, 5, 38, 6, 43, 2, 48, 7, 52, 0, 54, 1, 14, 4, 75, 3, 16, 
    0, 14, 4, 35, 5, 26, 3, 49, 1, 71, 2, 50, 8, 84, 7, 18, 6, 27, 
    6,  9, 5, 31, 1, 72, 3, 15, 4, 91, 7, 12, 0, 50, 8, 29, 2,  5, 
    1, 22, 3, 67, 8, 46, 4, 87, 6, 47, 7, 30, 0, 35, 2, 88, 5, 34, 
    2, 66, 0, 72, 7, 89, 1, 65, 6,  1, 5, 23, 8, 57, 3, 54, 4, 67, 
    3, 20, 6, 50, 7,  3, 4, 48, 0, 36, 5, 70, 2, 32, 8, 38, 1, 21
  };
  const int q0305[] = {
    9, 9, // Number of jobs and machines
    7, 11, 8, 35, 3, 22, 6, 34, 4, 58, 0, 96, 5, 64, 1, 23, 2, 67, 
    6, 66, 4, 97, 3,  5, 0, 42, 2, 33, 5,  8, 7, 13, 8, 10, 1,  6, 
    6, 96, 4, 73, 1, 78, 2, 21, 7, 39, 0, 13, 3,  8, 5, 88, 8, 73, 
    8, 79, 4, 42, 0, 15, 5, 40, 3, 87, 7, 25, 1, 41, 2, 46, 6, 99, 
    1, 38, 4, 54, 7, 37, 5, 26, 3,  8, 6, 67, 8, 21, 0, 46, 2, 73, 
    5, 54, 0, 14, 1, 99, 2, 61, 8, 16, 4, 83, 6, 11, 7, 87, 3, 64, 
    0,  3, 8, 31, 4, 46, 3, 75, 1, 95, 5, 17, 6, 67, 7, 35, 2, 52, 
    1, 18, 6, 75, 2,  8, 8, 94, 7, 93, 4, 61, 0, 65, 5, 42, 3, 34, 
    5, 62, 8, 80, 7, 48, 4, 75, 3, 10, 1, 18, 6,  7, 2, 10, 0, 41
  };
  const int q0306[] = {
    9, 9, // Number of jobs and machines
    2, 17, 8, 22, 0, 51, 4, 59, 7, 78, 1, 80, 5, 80, 6, 44, 3, 64, 
    7, 57, 5, 24, 1, 95, 0, 90, 6, 50, 2,  6, 8, 64, 3, 47, 4,  5, 
    5, 32, 2, 52, 8, 91, 7, 13, 6, 26, 4, 63, 1,  6, 3, 72, 0, 16, 
    8, 96, 2, 91, 3, 41, 6, 28, 7, 36, 1, 27, 5, 69, 0, 42, 4, 54, 
    0, 31, 8, 49, 4, 60, 2, 49, 3, 20, 6, 58, 5, 31, 1,  5, 7, 29, 
    4, 97, 0, 74, 2, 57, 1, 19, 6, 12, 8, 11, 7, 50, 3, 93, 5, 30, 
    5, 89, 1, 80, 6, 31, 3, 73, 8, 35, 2, 91, 0,  1, 4, 86, 7,  8, 
    4, 41, 6,  6, 5,  9, 3, 26, 2, 74, 8, 37, 7, 74, 1, 19, 0, 32, 
    6, 49, 1, 38, 4,  5, 2, 17, 0, 76, 8, 81, 5, 89, 7, 81, 3, 22
  };
  const int q0307[] = {
    9, 9, // Number of jobs and machines
    6, 89, 3, 45, 5, 24, 1, 87, 4, 31, 2, 96, 8, 92, 0, 80, 7,  7, 
    3, 51, 5,  1, 4, 97, 6, 21, 1, 37, 8, 68, 7,  7, 0, 78, 2, 41, 
    2, 76, 4, 84, 5,  3, 8, 96, 0,  9, 6,  2, 3, 39, 7, 98, 1,  5, 
    3, 82, 2, 71, 7, 75, 6, 21, 1, 26, 0, 11, 5, 86, 4, 26, 8, 80, 
    6, 73, 7, 32, 8, 45, 4,  4, 0, 27, 2, 72, 1, 92, 3, 10, 5, 28, 
    0, 52, 3, 67, 4, 81, 7, 97, 5, 31, 1, 54, 8, 77, 2, 76, 6, 29, 
    8, 34, 2, 11, 6, 34, 7, 35, 0, 66, 5, 94, 3, 98, 4, 36, 1, 90, 
    8,  5, 1,  2, 3, 98, 0, 85, 2, 98, 4,  5, 7, 38, 5,  5, 6, 85, 
    8, 85, 2, 88, 1, 75, 4, 10, 5, 25, 0,  9, 3, 67, 6, 43, 7, 22
  };
  const int q0308[] = {
    9, 9, // Number of jobs and machines
    2, 76, 1, 90, 6, 65, 7, 12, 5, 29, 3, 82, 4, 51, 0, 98, 8, 39, 
    7, 13, 1, 33, 2, 60, 0,  3, 6, 25, 3, 76, 5, 61, 4,  3, 8, 14, 
    6, 52, 4, 79, 0, 43, 3, 71, 5, 14, 1, 68, 2, 54, 7, 14, 8, 94, 
    5, 43, 8, 91, 7, 27, 4, 23, 6, 77, 1,  8, 0, 16, 3, 97, 2, 65, 
    7, 90, 2, 53, 0, 27, 4, 45, 1, 73, 6, 62, 8, 17, 5, 54, 3, 84, 
    1, 63, 3, 41, 2, 47, 7, 64, 0, 45, 6, 14, 5, 58, 4, 24, 8, 29, 
    8, 93, 5, 69, 3, 93, 1, 99, 4, 71, 0, 53, 2, 32, 7, 49, 6, 19, 
    1, 96, 0,  2, 5, 28, 2, 69, 6, 40, 3, 41, 7, 79, 4, 96, 8, 31, 
    2, 23, 0, 47, 8, 11, 3, 61, 7, 28, 5, 45, 1, 12, 4, 96, 6, 77
  };
  const int q0309[] = {
    9, 9, // Number of jobs and machines
    2, 29, 3,  9, 1, 63, 8, 75, 4, 48, 0, 98, 6, 95, 5,  1, 7, 44, 
    0, 77, 4, 49, 1, 24, 5, 95, 2, 65, 6, 97, 3, 23, 7, 93, 8, 23, 
    7, 87, 8,  6, 5, 14, 1, 52, 3, 19, 6, 69, 2,  4, 0, 33, 4,  1, 
    2, 76, 0, 59, 1, 36, 8,  9, 7, 75, 6,  9, 3, 23, 5, 44, 4, 33, 
    8, 12, 2, 17, 3, 28, 6, 62, 5, 56, 1, 51, 0, 28, 4, 20, 7, 68, 
    8, 94, 2, 84, 4, 91, 3,  8, 1, 52, 5, 75, 6, 82, 0, 63, 7, 93, 
    1, 73, 5, 51, 3, 44, 7, 61, 2, 84, 8, 11, 6, 78, 0, 90, 4, 55, 
    0,  4, 8, 86, 4, 70, 1, 42, 2, 42, 5, 63, 7, 73, 6, 10, 3, 63, 
    3, 69, 7, 28, 2, 90, 0, 12, 4,  9, 1, 57, 8, 12, 5, 47, 6, 15
  };
  const int q0310[] = {
    9, 9, // Number of jobs and machines
    7, 69, 4, 86, 2, 74, 5, 74, 1, 17, 3, 16, 8, 80, 6, 10, 0, 10, 
    6, 52, 4, 42, 8, 35, 5,  4, 1, 49, 0, 13, 2, 44, 3, 82, 7, 54, 
    7, 97, 3, 13, 4, 37, 5, 79, 8, 88, 6, 23, 1, 58, 2, 49, 0,  5, 
    3, 29, 6, 66, 2, 63, 7, 55, 8, 90, 4, 71, 0, 20, 1, 11, 5, 84, 
    4, 69, 6, 48, 5,  6, 2, 20, 0, 29, 8, 81, 3, 62, 1, 32, 7, 64, 
    6, 62, 8, 58, 1, 54, 0, 65, 7, 89, 2, 90, 4, 61, 3, 42, 5, 60, 
    5, 25, 6, 90, 3, 76, 2, 45, 1, 42, 4, 54, 0, 64, 7, 96, 8, 44, 
    0, 58, 7, 67, 8, 37, 3, 14, 5, 26, 6,  7, 4, 43, 1, 99, 2, 77, 
    7, 78, 3, 43, 8, 96, 0, 40, 2, 59, 5, 89, 1, 22, 4, 29, 6, 12
  };
  const int q0311[] = {
    9, 9, // Number of jobs and machines
    2, 25, 0, 53, 7, 79, 8, 82, 4,  4, 1, 71, 6,  2, 3, 95, 5, 10, 
    8, 99, 5, 40, 3, 73, 4, 99, 1, 78, 2, 48, 0, 50, 7, 58, 6, 34, 
    7, 70, 2, 89, 1, 70, 3, 92, 5, 63, 0, 32, 4, 17, 8, 87, 6, 29, 
    8, 73, 3,  9, 4, 32, 6,  8, 5, 54, 7, 80, 0, 34, 2,  7, 1, 28, 
    7, 51, 8, 47, 6, 70, 5, 21, 2, 63, 0, 98, 4, 14, 1, 56, 3, 20, 
    0, 32, 1, 53, 7, 75, 2, 30, 5, 90, 8, 31, 4, 47, 3, 53, 6, 99, 
    0, 42, 1, 32, 6, 67, 4, 29, 2, 17, 5, 81, 7, 98, 8, 23, 3, 87, 
    3, 44, 1, 19, 0, 30, 7, 97, 8, 46, 5, 74, 4, 83, 2,  9, 6,  3, 
    0, 97, 5, 29, 8, 35, 4, 21, 1, 20, 2, 74, 7, 54, 6, 37, 3, 92
  };
  const int q0312[] = {
    9, 9, // Number of jobs and machines
    5, 77, 4, 55, 8, 22, 1, 31, 6, 98, 2, 26, 3, 75, 7, 83, 0, 99, 
    1, 19, 6, 85, 3, 83, 4, 10, 2, 67, 7,  9, 8, 59, 0, 50, 5, 19, 
    0, 44, 6, 50, 7,  8, 2, 43, 3, 43, 1, 34, 4, 92, 5, 76, 8,  3, 
    2,  5, 1, 75, 0, 29, 6,  7, 8, 64, 5, 82, 3, 41, 4, 13, 7, 52, 
    1, 39, 5,  6, 4, 89, 3, 34, 0, 62, 2, 28, 6, 94, 8, 86, 7,  9, 
    3, 37, 0, 44, 8, 73, 1, 63, 7, 51, 4, 94, 6, 37, 5,  8, 2, 57, 
    4,  8, 2, 34, 3, 51, 8, 26, 5, 46, 7,  6, 6, 95, 0, 63, 1,  1, 
    4, 16, 7, 70, 3, 90, 2, 31, 0,  4, 5, 17, 1, 45, 8, 55, 6, 77, 
    0, 92, 8, 70, 7, 69, 4, 64, 5, 40, 3, 50, 2, 25, 1, 10, 6, 77
  };
  const int q0313[] = {
    9, 9, // Number of jobs and machines
    3, 23, 0, 31, 1, 49, 6, 80, 4, 87, 2, 75, 8, 77, 5, 29, 7,  1, 
    5, 45, 7, 26, 2, 62, 8, 14, 4, 60, 0, 56, 1, 19, 3,  2, 6, 23, 
    6, 63, 4, 81, 2, 33, 1, 21, 3, 70, 7, 52, 0, 37, 5, 32, 8, 46, 
    3, 15, 1, 33, 5, 63, 4, 18, 6, 89, 7, 69, 8, 49, 2, 33, 0, 51, 
    7, 74, 0, 33, 3, 72, 6, 17, 8, 22, 2, 10, 5, 31, 1, 18, 4, 15, 
    2, 44, 5, 24, 6, 19, 3, 47, 1, 88, 4, 92, 7, 41, 0, 85, 8, 50, 
    3, 55, 6, 49, 0, 87, 8, 22, 2, 15, 1, 54, 7, 50, 5, 47, 4, 98, 
    0, 77, 7, 78, 5, 72, 2, 18, 6, 89, 8, 49, 4, 61, 3, 33, 1, 37, 
    7, 12, 5, 78, 0,  5, 3, 98, 6, 11, 1, 40, 2, 81, 8, 19, 4, 20
  };
  const int q0314[] = {
    9, 9, // Number of jobs and machines
    0, 62, 8, 25, 3, 55, 7, 46, 5, 40, 6, 67, 1, 58, 4,  7, 2, 87, 
    5, 80, 0,  6, 7, 93, 3, 33, 6, 74, 2, 28, 1, 82, 8, 89, 4,  6, 
    5, 29, 0, 73, 6, 92, 2, 79, 3, 87, 8, 38, 4, 18, 1, 50, 7, 74, 
    6, 12, 7, 43, 3, 79, 8, 91, 5, 58, 1, 26, 4, 39, 0, 44, 2, 87, 
    6, 69, 7, 34, 2, 93, 1, 61, 8, 55, 3, 39, 4, 69, 0,  1, 5, 94, 
    4, 55, 7,  2, 8, 91, 2, 98, 3, 87, 1, 12, 0, 65, 6, 40, 5, 46, 
    4, 15, 7, 95, 8, 60, 6,  5, 5, 77, 0,  6, 3, 81, 1, 61, 2, 17, 
    8, 17, 7, 13, 4, 16, 3, 88, 2, 77, 0, 71, 1, 40, 6, 29, 5, 59, 
    5, 83, 3, 59, 6, 26, 7, 96, 1, 93, 8, 16, 4, 28, 0,  3, 2, 18
  };
  const int q0315[] = {
    9, 9, // Number of jobs and machines
    7, 87, 8, 84, 0, 71, 3, 97, 4, 96, 1, 65, 5,  1, 2, 42, 6, 21, 
    8, 29, 4, 27, 3, 23, 7, 89, 6,  8, 0, 63, 1, 39, 5, 78, 2, 94, 
    3,  5, 0, 29, 7, 39, 1, 19, 4, 37, 5, 96, 6, 97, 8,  9, 2, 56, 
    8, 11, 7, 37, 4, 52, 2, 72, 5, 94, 3, 34, 1, 97, 0, 48, 6,  1, 
    2, 34, 8, 50, 4, 98, 6,  2, 1, 73, 3, 33, 7, 38, 0, 13, 5, 89, 
    6, 56, 0, 70, 8, 57, 4, 92, 2, 88, 5, 22, 3, 18, 7, 46, 1, 80, 
    0, 97, 7, 69, 1, 58, 5, 13, 2, 83, 8, 37, 6, 30, 3, 98, 4, 27, 
    8,  5, 3, 96, 4, 40, 7, 56, 0, 69, 6, 73, 2, 21, 1, 34, 5, 14, 
    0, 85, 7, 65, 4, 70, 8, 38, 2, 14, 3, 62, 6, 74, 5, 35, 1, 94
  };
  const int q0316[] = {
    9, 9, // Number of jobs and machines
    0, 62, 8, 55, 4, 78, 7, 16, 6, 11, 1, 89, 3,  4, 5, 76, 2, 89, 
    4, 72, 8, 29, 2, 40, 3,  8, 5, 23, 6, 43, 7, 46, 1, 60, 0, 97, 
    2, 78, 1, 95, 5, 98, 0, 21, 3, 79, 7, 55, 6, 67, 4, 84, 8, 68, 
    1,  1, 4, 82, 6, 21, 7, 28, 8, 54, 2, 39, 0, 51, 5, 27, 3, 11, 
    7, 81, 3, 50, 4, 55, 1, 97, 2, 91, 0, 70, 5, 74, 6, 83, 8, 97, 
    3, 65, 1,  3, 8, 25, 4, 76, 5, 61, 2, 70, 0,  9, 7,  8, 6, 25, 
    4, 37, 6, 76, 5, 65, 7, 37, 2, 78, 0, 38, 1, 80, 8, 31, 3, 34, 
    2, 56, 0, 79, 1, 46, 8, 52, 4, 44, 6, 92, 3, 60, 5, 37, 7, 63, 
    6,  1, 1, 41, 0,  2, 3,  6, 5, 21, 8, 92, 4, 57, 7, 33, 2, 79
  };
  const int q0317[] = {
    9, 9, // Number of jobs and machines
    5, 12, 6,  8, 1, 15, 3, 55, 0, 26, 8, 36, 4, 18, 7, 47, 2, 73, 
    8, 53, 4, 86, 3,  6, 7, 42, 2, 92, 1,  2, 5, 25, 6, 34, 0, 66, 
    3, 44, 0, 13, 6, 14, 1, 86, 7, 56, 2, 57, 5, 73, 4, 59, 8, 17, 
    8, 68, 1, 90, 2, 96, 6, 48, 5, 27, 0,  3, 3,  7, 7,  9, 4, 37, 
    5,  1, 0, 87, 4, 46, 2, 34, 1, 90, 8, 85, 6, 21, 7, 28, 3,  6, 
    5, 41, 8, 44, 2, 18, 6, 97, 4,  3, 3, 33, 7,  3, 0, 64, 1, 60, 
    6, 95, 1, 51, 8, 55, 2, 42, 5,  6, 0, 28, 7, 71, 3,  2, 4, 12, 
    3, 89, 5, 64, 6, 56, 7, 71, 2, 15, 4, 73, 1, 43, 0, 65, 8, 65, 
    1, 64, 6, 21, 8, 23, 2, 22, 3, 41, 4, 10, 7, 76, 5, 81, 0, 24
  };
  const int q0318[] = {
    9, 9, // Number of jobs and machines
    7, 74, 2, 98, 4,  6, 6, 49, 0, 15, 8, 70, 1,  4, 3, 21, 5, 14, 
    8, 17, 3, 88, 5, 79, 6, 19, 4, 15, 0, 93, 2,  4, 7, 50, 1, 87, 
    8, 11, 0, 64, 2, 99, 5, 41, 4, 82, 7, 83, 1, 33, 6, 33, 3, 14, 
    1, 44, 4, 67, 2, 75, 0, 17, 5, 85, 6, 28, 8, 82, 7, 33, 3, 39, 
    2, 68, 5, 88, 4, 46, 3,  8, 1, 91, 6, 22, 0, 19, 7, 87, 8, 23, 
    5, 42, 0, 86, 4, 55, 8, 43, 3, 26, 6, 20, 2, 98, 7, 67, 1, 77, 
    4, 59, 2, 90, 6, 86, 0, 50, 1, 89, 8, 79, 3, 37, 7, 72, 5, 78, 
    3, 41, 0, 74, 5, 42, 2,  7, 6,  7, 4, 31, 7, 55, 1, 16, 8, 53, 
    1, 23, 7, 73, 0, 36, 8, 61, 3, 82, 2, 26, 5, 16, 6, 42, 4,  6
  };
  const int q0319[] = {
    9, 9, // Number of jobs and machines
    8, 35, 5, 13, 2, 59, 1, 67, 7, 83, 4, 36, 6, 84, 3, 87, 0, 48, 
    3, 75, 7, 19, 1,  2, 0, 17, 5, 11, 8, 28, 2, 21, 6, 49, 4, 70, 
    8, 47, 0, 62, 5, 12, 7,  5, 6, 46, 1, 60, 3, 16, 4, 38, 2, 90, 
    3,  6, 0, 52, 4, 39, 7, 69, 8, 26, 6, 71, 2,  1, 5, 53, 1, 35, 
    0, 34, 8, 43, 1, 56, 6, 32, 2, 51, 4, 94, 3, 31, 7, 82, 5, 82, 
    6, 67, 5, 81, 8, 36, 3, 15, 2, 96, 4, 95, 7, 81, 0, 47, 1, 85, 
    1, 44, 3, 34, 8,  3, 4,  2, 7, 41, 0, 32, 2, 18, 5,  1, 6, 30, 
    8, 36, 4,  8, 3, 74, 6, 97, 1, 35, 7, 39, 5, 40, 2, 20, 0, 14, 
    3, 87, 6, 28, 8, 55, 2, 93, 1, 42, 7,  3, 4, 85, 0,  1, 5, 81
  };
  const int q0320[] = {
    9, 9, // Number of jobs and machines
    2, 86, 8,  3, 0, 35, 5, 60, 1, 38, 4,  5, 6, 24, 7, 29, 3, 81, 
    5, 94, 6, 16, 7, 89, 0, 89, 2, 93, 3, 10, 8, 94, 1,  2, 4, 52, 
    3, 98, 4, 40, 7, 15, 5, 49, 0, 23, 8, 13, 2, 45, 1, 29, 6, 56, 
    6, 72, 2, 15, 7, 96, 0, 95, 5, 74, 3,  1, 8, 82, 4, 99, 1, 60, 
    2, 52, 1, 54, 3, 36, 6, 85, 5, 63, 0,  5, 4, 13, 8, 76, 7, 60, 
    4, 98, 8, 60, 2, 57, 1, 66, 6, 47, 3, 86, 7, 84, 0, 45, 5, 58, 
    3, 59, 0, 95, 7, 12, 6, 67, 8, 99, 1,  5, 5,  3, 4,  5, 2, 91, 
    2, 77, 6, 28, 4, 24, 7, 42, 1, 48, 5, 67, 3, 74, 0, 81, 8, 43, 
    7, 50, 1, 92, 0, 99, 4, 87, 5, 83, 6, 51, 2, 55, 8, 83, 3, 72
  };
  const int q0321[] = {
    9, 9, // Number of jobs and machines
    0, 63, 6, 64, 4, 46, 5, 85, 3, 48, 7, 39, 1, 75, 2, 32, 8, 42, 
    8, 47, 3, 51, 6, 68, 5, 23, 2, 74, 4, 16, 7, 30, 0, 38, 1, 22, 
    4, 55, 2, 35, 3, 47, 7, 16, 1, 87, 8, 63, 6, 83, 0,  8, 5,  4, 
    8, 70, 6,  7, 0, 65, 3, 54, 2, 51, 4, 55, 7, 34, 1, 28, 5, 54, 
    1, 48, 4, 48, 8, 71, 6, 91, 3, 73, 7, 45, 0, 38, 5, 11, 2, 93, 
    4, 18, 2, 17, 8, 80, 0,  5, 5, 31, 7, 82, 1, 52, 6, 38, 3, 28, 
    6,  2, 4, 40, 8, 74, 5, 91, 3, 82, 0, 27, 1, 83, 7, 46, 2, 40, 
    2, 38, 5, 23, 4, 60, 3, 28, 6,  4, 7, 13, 8, 30, 0, 15, 1, 85, 
    0, 11, 5, 56, 7, 81, 6, 48, 3, 20, 2, 93, 8, 73, 4, 13, 1,  9
  };
  const int q0322[] = {
    9, 9, // Number of jobs and machines
    0, 26, 8, 69, 6, 98, 5, 92, 1, 78, 4,  8, 2,  4, 3, 93, 7, 79, 
    5,  3, 2,  2, 3, 17, 0, 67, 1, 68, 8, 93, 4, 22, 7, 50, 6, 62, 
    5, 66, 1, 21, 0, 55, 8, 78, 7, 48, 2, 62, 3, 11, 4,  2, 6, 74, 
    0,  5, 5, 62, 7, 85, 1, 21, 3, 49, 8, 87, 6, 21, 2, 35, 4, 30, 
    0, 69, 1, 57, 3, 78, 4, 36, 6, 14, 8, 37, 5, 34, 7, 51, 2, 84, 
    2, 48, 3, 21, 5, 93, 0, 60, 7, 69, 4, 69, 6, 47, 1, 72, 8, 89, 
    6, 47, 8, 93, 3,  6, 7, 45, 2, 87, 4, 91, 5, 15, 0, 51, 1, 68, 
    3, 51, 0, 40, 6, 26, 5, 21, 8, 83, 2, 33, 4, 72, 1, 23, 7,  3, 
    4, 64, 3, 81, 5, 54, 6, 15, 8, 66, 7, 25, 0, 51, 1, 31, 2, 95
  };
  const int q0323[] = {
    9, 9, // Number of jobs and machines
    8, 82, 6, 74, 5, 49, 2, 42, 1, 27, 0, 11, 3,  2, 4, 80, 7, 82, 
    8,  8, 0, 40, 6, 16, 2,  5, 7,  5, 1, 89, 3, 71, 5, 33, 4, 91, 
    7, 24, 4, 19, 5, 51, 6, 23, 2, 41, 1, 98, 0, 86, 8, 55, 3, 96, 
    0, 93, 8, 87, 1, 23, 3, 41, 7, 60, 5, 91, 2, 90, 6,  5, 4, 47, 
    5, 66, 6, 16, 7, 71, 4, 86, 1, 80, 3, 43, 2, 70, 8, 35, 0, 73, 
    0, 81, 4, 12, 6, 17, 3, 78, 5, 72, 1, 28, 2, 18, 8, 81, 7, 20, 
    6, 39, 5, 67, 3, 61, 8, 80, 7, 93, 4, 71, 2, 25, 0, 40, 1,  9, 
    6, 55, 0, 71, 2, 31, 7, 52, 8, 54, 4, 78, 3, 37, 1, 86, 5, 46, 
    2, 45, 8, 28, 6, 86, 1, 27, 5, 15, 7, 87, 3, 65, 4, 58, 0, 66
  };
  const int q0324[] = {
    9, 9, // Number of jobs and machines
    7, 24, 1, 45, 0, 24, 6, 75, 8, 78, 4, 68, 2, 52, 5, 32, 3,  3, 
    2, 54, 3, 25, 8, 28, 6,  2, 1,  6, 4, 38, 0, 96, 7,  8, 5, 85, 
    3, 83, 7, 79, 2, 58, 4, 16, 8, 56, 6, 92, 0, 77, 1, 63, 5, 98, 
    0, 70, 5, 13, 7, 52, 3, 47, 2, 56, 6, 83, 8, 96, 4, 51, 1, 48, 
    6, 66, 3, 78, 5,  5, 2, 68, 4, 21, 7, 43, 1, 50, 8, 53, 0,  7, 
    6, 79, 4, 84, 2, 61, 7, 77, 0, 46, 5, 10, 1, 56, 8, 22, 3,  8, 
    1,  5, 3, 93, 2, 10, 4, 44, 8, 64, 5, 11, 7, 68, 0, 73, 6, 95, 
    7, 10, 6, 73, 2, 36, 3, 21, 4, 26, 5, 45, 8,  2, 1,  2, 0, 74, 
    1, 15, 2, 35, 5, 78, 6, 56, 3, 66, 7, 37, 8, 36, 0,  6, 4,  5
  };
  const int q0325[] = {
    9, 9, // Number of jobs and machines
    8, 22, 1, 97, 7,  9, 4, 77, 6, 64, 2, 97, 5, 15, 0, 65, 3,  4, 
    0, 72, 4, 92, 2, 25, 8, 49, 7, 75, 5, 80, 6, 99, 3, 46, 1, 18, 
    4, 73, 7, 89, 6, 47, 3, 44, 1, 50, 0, 50, 2, 88, 5, 90, 8, 32, 
    6, 58, 7,  5, 3, 19, 8, 96, 2, 75, 0, 32, 4, 97, 1, 90, 5, 45, 
    0,  6, 8, 45, 3, 18, 5, 42, 7,  4, 2,  2, 4, 74, 6, 80, 1, 76, 
    3, 87, 2, 29, 8, 54, 4, 29, 5,  3, 7, 26, 6,  1, 0, 56, 1, 69, 
    7, 98, 5, 74, 1, 19, 6,  8, 8,  9, 3, 83, 4,  8, 0, 75, 2, 52, 
    7, 83, 5,  7, 0, 77, 8, 48, 2, 36, 1, 47, 3, 79, 4, 25, 6, 77, 
    5, 54, 0, 59, 6, 48, 3, 84, 8, 25, 7, 38, 4, 37, 1, 78, 2,  6
  };
  const int q0326[] = {
    9, 9, // Number of jobs and machines
    8, 98, 5, 40, 7, 11, 2, 16, 4,  1, 1, 17, 6, 21, 0, 52, 3, 23, 
    1, 97, 5, 79, 4, 85, 2,  4, 6, 67, 8, 59, 3, 92, 7, 65, 0, 75, 
    7, 68, 0, 71, 3, 62, 5, 75, 6, 94, 2, 22, 1, 25, 4, 59, 8, 59, 
    8, 43, 1, 85, 0, 46, 2, 19, 7, 73, 3, 53, 4, 96, 5, 67, 6, 79, 
    2, 63, 1, 36, 3, 91, 0, 14, 5, 22, 7, 88, 6, 91, 4, 62, 8, 43, 
    2,  3, 0, 64, 1, 56, 8, 58, 5, 84, 7, 26, 4, 56, 6, 65, 3, 78, 
    5, 41, 6, 26, 1, 83, 8, 69, 4, 46, 3, 44, 0,  2, 7, 65, 2, 98, 
    6, 81, 8, 76, 0, 17, 1, 22, 2, 61, 3, 92, 5, 66, 7, 11, 4, 94, 
    5, 39, 3, 13, 4, 99, 0, 61, 8, 65, 2, 96, 1, 45, 7, 51, 6, 75
  };
  const int q0327[] = {
    9, 9, // Number of jobs and machines
    0, 32, 1, 41, 4, 75, 7, 64, 5, 16, 2, 53, 8, 99, 6, 85, 3, 19, 
    5, 41, 3, 49, 8, 34, 2, 16, 7, 82, 1, 52, 4, 77, 6,  9, 0, 28, 
    7, 75, 0, 36, 3, 16, 5, 64, 1, 71, 8, 78, 6, 78, 2, 87, 4, 81, 
    2, 68, 6, 32, 1, 54, 3, 37, 4, 43, 5, 81, 0, 56, 7, 61, 8, 40, 
    3, 97, 5, 59, 8, 56, 4, 23, 7, 38, 1, 77, 6, 11, 0, 12, 2, 35, 
    6, 78, 3, 87, 7, 72, 8, 11, 4, 81, 1, 10, 2, 59, 0, 33, 5, 22, 
    5, 56, 7,  3, 6, 95, 1, 13, 3, 99, 8,  3, 4, 33, 2, 83, 0, 60, 
    2,  3, 7, 54, 1,  3, 0, 99, 3, 98, 4, 41, 5, 81, 6, 80, 8, 58, 
    1, 41, 8, 71, 5, 55, 6, 21, 3, 79, 2, 20, 0, 79, 7, 54, 4, 68
  };
  const int q0328[] = {
    9, 9, // Number of jobs and machines
    8,  9, 1, 74, 0,  1, 4, 80, 5, 70, 7, 70, 3, 17, 2, 64, 6, 24, 
    8, 39, 6, 40, 5, 26, 2, 97, 1, 15, 4, 24, 0, 67, 3,  1, 7, 65, 
    7, 97, 2,  7, 8, 86, 1, 42, 5, 38, 3, 18, 0, 79, 4, 31, 6, 31, 
    7, 77, 5,  6, 2,  6, 1, 81, 8, 39, 3, 74, 6, 95, 4, 33, 0, 59, 
    7, 38, 6, 80, 2, 29, 4, 13, 5, 92, 1, 61, 3, 49, 8,  3, 0, 79, 
    8, 92, 6, 49, 4, 68, 7, 58, 0, 47, 5, 83, 2, 12, 1, 96, 3, 53, 
    4, 63, 5, 50, 3, 30, 7, 61, 2, 73, 0, 56, 6, 69, 8, 18, 1,  5, 
    1, 45, 6,  1, 8, 83, 5, 47, 2, 28, 0, 29, 7,  5, 4, 33, 3, 32, 
    3, 83, 5, 69, 2, 88, 1, 58, 8, 80, 0, 83, 7, 99, 4, 50, 6, 27
  };
  const int q0329[] = {
    9, 9, // Number of jobs and machines
    7, 26, 5, 55, 3, 97, 1, 89, 4, 86, 6, 98, 0, 64, 2, 26, 8, 54, 
    3, 43, 7, 47, 5, 68, 6, 42, 2, 34, 1, 94, 0, 58, 8,  7, 4, 14, 
    0, 70, 5, 97, 2, 70, 3, 92, 7, 75, 8, 76, 1, 89, 6, 38, 4, 98, 
    2, 31, 8, 27, 5, 67, 4, 97, 3, 27, 7, 65, 1, 46, 6,  6, 0, 78, 
    5, 62, 3, 61, 8, 52, 2, 71, 0, 45, 1, 87, 7, 95, 6, 61, 4,  3, 
    4, 69, 8, 85, 2, 52, 1, 62, 5, 26, 0, 52, 7, 86, 3, 71, 6,  8, 
    8, 56, 1, 20, 7, 34, 6, 24, 5, 68, 3,  4, 2, 41, 4, 73, 0, 90, 
    3, 89, 5, 93, 1, 95, 2, 57, 4, 58, 7, 23, 8, 59, 6, 62, 0, 76, 
    0, 92, 4, 42, 5, 69, 7, 90, 2, 31, 3, 67, 8, 97, 1, 11, 6, 27
  };
  const int q0330[] = {
    9, 9, // Number of jobs and machines
    0, 73, 5, 26, 8, 16, 1, 74, 2, 61, 4, 84, 3, 38, 6, 17, 7, 28, 
    3, 87, 4, 40, 5, 28, 2, 48, 0, 80, 8, 30, 7, 82, 1, 60, 6, 97, 
    1, 65, 7, 52, 8, 54, 0, 80, 3, 59, 4, 64, 2, 36, 5, 44, 6, 76, 
    0, 96, 8, 21, 5, 61, 4, 44, 1, 86, 3, 28, 2, 91, 6,  2, 7, 35, 
    4,  1, 1, 96, 6,  4, 8, 51, 3, 68, 0, 25, 7, 97, 5, 74, 2, 93, 
    8, 10, 4, 54, 2, 28, 1, 62, 5, 17, 6, 93, 0, 22, 7,  9, 3, 56, 
    0, 31, 4, 66, 5, 68, 6,  4, 7, 79, 3,  1, 2,  5, 8, 15, 1, 28, 
    8, 56, 2, 56, 4,  9, 5, 55, 3, 37, 1, 81, 6, 92, 0, 41, 7, 26, 
    5,  4, 0, 21, 2, 40, 1, 54, 8, 70, 4, 90, 6, 45, 3,  4, 7, 54
  };
  const int q0331[] = {
    9, 9, // Number of jobs and machines
    4, 24, 5, 72, 2, 70, 6, 29, 1, 67, 8, 92, 7, 65, 3, 55, 0, 35, 
    4, 75, 8, 88, 6, 14, 3, 63, 7, 85, 0, 40, 5, 20, 2, 26, 1,  3, 
    4, 32, 0, 81, 5, 81, 1, 95, 3, 67, 2, 49, 7, 56, 8, 14, 6, 99, 
    0, 69, 7, 48, 3, 23, 8, 10, 6, 47, 1, 63, 2, 23, 5, 37, 4,  3, 
    2, 73, 7, 20, 3, 47, 5, 37, 4, 41, 1, 16, 6, 55, 0, 50, 8, 32, 
    3, 18, 7, 58, 4, 42, 2, 58, 0, 66, 6, 15, 5, 47, 8, 75, 1, 22, 
    5, 15, 2, 40, 8, 11, 3, 19, 0, 64, 7, 84, 4, 81, 1, 56, 6, 63, 
    1, 42, 0, 28, 2, 18, 4, 50, 5, 30, 3, 68, 8, 72, 6, 43, 7, 39, 
    8, 59, 2, 43, 3, 42, 6,  7, 5,  3, 7, 56, 1, 55, 0, 87, 4, 17
  };
  const int q0332[] = {
    9, 9, // Number of jobs and machines
    1,  9, 2, 52, 4, 44, 5, 49, 6,  7, 8, 35, 3, 29, 7, 18, 0, 61, 
    2, 80, 7, 20, 5, 24, 1, 91, 4, 28, 8, 15, 0, 48, 6, 27, 3, 60, 
    5, 90, 7, 92, 3, 21, 8, 78, 2, 97, 4,  6, 6, 67, 0, 29, 1, 68, 
    6, 46, 1, 91, 8, 14, 3, 69, 4, 93, 7, 13, 2, 35, 5, 91, 0, 89, 
    4, 79, 5, 72, 2, 45, 3, 57, 6, 70, 0, 35, 7, 81, 1, 37, 8, 71, 
    1, 67, 0, 85, 4, 15, 6, 77, 7, 59, 3, 21, 8, 80, 5,  9, 2, 58, 
    1, 47, 5, 38, 6, 49, 4,  1, 3, 41, 0, 43, 8, 32, 7, 82, 2, 68, 
    5, 66, 7,  2, 3, 56, 2,  2, 4, 65, 6, 76, 8, 49, 1, 10, 0, 39, 
    7, 27, 8, 74, 0, 17, 4, 60, 2, 83, 6, 96, 5,  8, 3, 25, 1, 90
  };
  const int q0333[] = {
    9, 9, // Number of jobs and machines
    7, 52, 6, 66, 4, 38, 1, 25, 5, 86, 8, 23, 0, 65, 3,  1, 2, 78, 
    2, 65, 7, 12, 1, 70, 4, 87, 5, 94, 8, 86, 3, 17, 6, 24, 0, 31, 
    2,  1, 4, 94, 3, 25, 6, 17, 8, 53, 0, 36, 7, 36, 1, 51, 5, 48, 
    0, 87, 7, 38, 6, 27, 8, 34, 4, 93, 5, 13, 2, 22, 1,  6, 3, 72, 
    8, 64, 7,  7, 3, 60, 1, 77, 4, 92, 5,  2, 6, 44, 0, 83, 2, 20, 
    4, 14, 0, 29, 6, 40, 5, 16, 8, 19, 2,  9, 7, 50, 1, 52, 3, 52, 
    3, 94, 1, 94, 4, 64, 6, 92, 2, 15, 5, 29, 8, 32, 7, 41, 0, 93, 
    5, 29, 7, 28, 0, 67, 3, 22, 1, 16, 8, 43, 2, 20, 4, 14, 6,  3, 
    2, 70, 6, 36, 3, 33, 5, 92, 0, 43, 4, 39, 7, 67, 1, 87, 8, 59
  };
  const int q0334[] = {
    9, 9, // Number of jobs and machines
    4, 71, 8, 71, 7, 76, 1, 20, 0, 89, 2, 88, 6, 68, 5,  9, 3,  2, 
    1,  4, 8, 93, 0, 12, 2, 49, 7,  8, 4, 54, 3,  4, 5, 48, 6,  3, 
    1, 40, 2, 31, 7, 69, 0, 79, 4, 80, 8, 18, 6, 52, 5, 39, 3, 71, 
    1, 36, 5, 26, 2, 48, 6, 14, 8, 13, 3, 14, 0, 20, 7, 93, 4, 33, 
    0, 69, 4, 20, 1, 26, 7, 19, 2, 51, 3, 34, 5, 94, 6, 71, 8, 38, 
    4, 60, 0, 65, 5, 24, 6, 27, 1, 51, 2, 46, 8,  5, 3,  5, 7, 25, 
    4, 86, 6, 46, 2, 20, 5, 10, 8, 36, 1, 12, 3, 17, 7, 26, 0, 15, 
    4, 38, 7, 79, 6, 64, 5, 80, 8, 72, 0, 49, 3, 46, 1,  7, 2, 16, 
    0, 63, 1, 19, 3,  5, 2, 58, 4, 56, 8, 28, 6, 20, 5, 34, 7,  2
  };
  const int q0335[] = {
    9, 9, // Number of jobs and machines
    2, 52, 8,  4, 0,  5, 5, 14, 7, 89, 1, 87, 3, 77, 6, 37, 4, 58, 
    2, 49, 0, 10, 3, 42, 6, 37, 8, 29, 1, 39, 7, 78, 5,  7, 4, 34, 
    7, 49, 8, 42, 2, 99, 4, 22, 5, 91, 3, 64, 6, 59, 0, 85, 1, 92, 
    8, 58, 1, 59, 7, 67, 3, 13, 2, 88, 5, 37, 4, 71, 0, 33, 6, 61, 
    4, 88, 7, 50, 8, 44, 0, 32, 5, 83, 3, 95, 6,  8, 2, 95, 1, 48, 
    7, 88, 3, 99, 6, 13, 5, 82, 0, 53, 8, 86, 1, 52, 4, 52, 2, 20, 
    2,  7, 0, 42, 1,  9, 7, 14, 4, 98, 5, 43, 8, 60, 3, 24, 6, 32, 
    8, 43, 4, 90, 0, 14, 6, 85, 5, 96, 3, 83, 7, 42, 1, 81, 2, 46, 
    5, 20, 2, 49, 0, 80, 7, 39, 6, 44, 3, 93, 1, 45, 4, 91, 8, 12
  };
  const int q0336[] = {
    9, 9, // Number of jobs and machines
    6, 17, 4, 91, 8, 21, 1, 63, 5, 56, 2, 32, 0, 25, 3, 41, 7, 20, 
    0, 23, 6, 70, 1, 88, 8, 53, 4, 36, 2, 32, 5, 79, 7, 82, 3, 57, 
    1, 97, 3, 19, 4, 70, 8, 43, 6, 35, 0, 47, 7,  6, 2, 74, 5, 62, 
    6, 87, 5, 80, 2, 19, 3,  9, 4, 10, 7, 48, 1, 81, 0, 42, 8, 41, 
    7, 90, 5, 28, 1, 19, 2, 40, 8, 94, 3, 97, 0, 80, 6, 76, 4, 94, 
    5, 37, 0, 27, 7, 30, 2, 87, 8, 63, 4, 98, 3, 62, 6, 83, 1, 22, 
    6, 11, 2, 16, 7, 54, 1, 98, 8, 10, 4, 78, 3, 48, 5, 34, 0, 80, 
    2, 21, 3, 43, 7, 74, 6, 93, 4, 72, 8, 95, 5, 95, 0, 91, 1, 43, 
    4,  1, 5, 65, 6, 92, 8, 38, 3, 83, 1, 87, 7,  3, 2, 34, 0, 53
  };
  const int q0337[] = {
    9, 9, // Number of jobs and machines
    0, 89, 1, 64, 5, 58, 4, 35, 2, 42, 6, 12, 8, 98, 3,  3, 7, 14, 
    3,  9, 6, 74, 1, 95, 2,  1, 0,  2, 5,  1, 8, 24, 7, 95, 4, 94, 
    6, 56, 2, 97, 4, 23, 7, 12, 0, 86, 3, 42, 8, 41, 5, 14, 1, 19, 
    1, 64, 0, 54, 2, 45, 5, 31, 6, 98, 7, 58, 4, 33, 8, 43, 3, 19, 
    1, 84, 0, 44, 4,  4, 2, 67, 5, 51, 6, 86, 7,  8, 8,  4, 3, 50, 
    2, 87, 0, 24, 5, 28, 4,  1, 3, 73, 7, 60, 1, 94, 6, 45, 8, 89, 
    6, 34, 5, 93, 1, 18, 7, 47, 3, 72, 0, 27, 2,  6, 4, 86, 8,  1, 
    4, 62, 0, 52, 5, 31, 7, 47, 8,  9, 3, 26, 2, 53, 1, 71, 6,  1, 
    8, 87, 2, 66, 6, 51, 3, 21, 4,  9, 7, 93, 5, 14, 0, 41, 1,  4
  };
  const int q0338[] = {
    9, 9, // Number of jobs and machines
    7, 15, 1, 80, 3, 93, 0, 26, 2, 71, 5, 97, 4, 88, 6, 95, 8, 14, 
    7, 40, 0, 43, 8, 29, 1, 86, 4, 36, 6, 45, 3, 65, 2, 27, 5, 31, 
    6,  5, 1, 17, 0, 34, 2,  4, 5, 59, 3, 56, 7, 29, 8, 89, 4, 37, 
    7, 22, 0, 81, 4, 17, 2, 75, 6, 71, 5, 28, 3, 67, 8, 71, 1, 91, 
    0,  7, 5, 98, 2, 14, 7, 32, 4,  2, 6, 68, 1, 18, 3, 60, 8, 69, 
    3,  4, 0, 27, 7, 52, 2,  7, 4, 34, 6, 67, 1, 36, 8, 69, 5, 88, 
    8, 55, 5, 53, 4,  4, 3, 87, 2, 25, 0, 33, 6, 72, 7, 22, 1, 68, 
    1, 73, 8, 68, 4, 38, 0, 57, 7, 29, 3, 15, 2, 70, 5, 31, 6, 48, 
    6, 22, 5, 12, 1, 41, 8, 72, 4, 65, 7, 52, 3, 23, 0,  3, 2, 95
  };
  const int q0339[] = {
    9, 9, // Number of jobs and machines
    1, 89, 4, 36, 2, 61, 3, 95, 0, 83, 8, 16, 6,  5, 5,  2, 7, 83, 
    5, 77, 2, 28, 6, 24, 3, 32, 8, 46, 1, 41, 4, 37, 7, 79, 0, 79, 
    4, 16, 8, 53, 2, 57, 0, 34, 1, 40, 6, 32, 7, 89, 3, 78, 5,  9, 
    4, 89, 3, 34, 1,  1, 7, 93, 5, 70, 0, 75, 2, 95, 6, 51, 8,  7, 
    5, 10, 1,  3, 4,  7, 6, 36, 3, 75, 2, 35, 8, 86, 0, 23, 7, 10, 
    5, 41, 8, 15, 3, 69, 0, 26, 6, 23, 7, 17, 4, 36, 2, 91, 1, 42, 
    0, 91, 8, 48, 7, 28, 5, 48, 6, 27, 4, 67, 1, 88, 3, 90, 2, 21, 
    8, 46, 6, 79, 5, 78, 1, 53, 7, 70, 4, 58, 0, 62, 3, 49, 2, 66, 
    7, 62, 2, 72, 0, 16, 5, 42, 6,  8, 1, 78, 3, 13, 8, 99, 4, 81
  };
  const int q0340[] = {
    9, 9, // Number of jobs and machines
    0,  8, 4, 15, 6, 88, 7, 43, 3, 63, 2, 46, 5, 47, 8, 57, 1,  2, 
    0, 51, 8, 79, 6, 20, 3,  5, 5, 50, 1, 55, 4, 15, 7, 13, 2, 94, 
    5, 66, 7, 79, 2, 63, 0, 24, 3, 41, 8, 39, 6, 79, 4, 27, 1, 36, 
    1, 83, 6, 46, 3, 25, 0, 49, 4, 88, 2, 49, 5, 66, 8, 17, 7,  2, 
    7, 56, 0, 44, 8, 32, 4, 53, 2, 83, 3, 79, 1, 72, 6, 37, 5, 76, 
    8, 63, 4, 37, 2, 77, 6, 64, 5, 19, 3, 44, 7, 13, 0, 36, 1, 83, 
    4, 21, 1, 52, 5, 32, 3, 57, 0,  1, 6, 18, 8, 28, 7, 16, 2,  2, 
    1,  3, 6, 35, 3, 14, 0, 48, 7, 54, 5, 69, 8, 15, 4, 45, 2, 56, 
    0, 23, 3, 64, 2, 27, 6, 52, 5, 89, 4, 40, 7, 59, 1, 52, 8,  2
  };
  const int q0341[] = {
    9, 9, // Number of jobs and machines
    3, 41, 5, 72, 2, 29, 6, 53, 1, 46, 7, 18, 4, 83, 0, 15, 8, 93, 
    3, 89, 2, 35, 6, 41, 7, 87, 4,  4, 1, 67, 8, 91, 0, 78, 5, 62, 
    7, 33, 5,  8, 0, 28, 6, 36, 3, 16, 1, 50, 4, 26, 8, 86, 2, 97, 
    3, 97, 6, 46, 2, 13, 7, 46, 4,  2, 0, 12, 8, 49, 1, 80, 5, 30, 
    1,  8, 2, 51, 0,  5, 3, 53, 4, 44, 7, 12, 5, 48, 6, 74, 8, 41, 
    5, 99, 4, 60, 8, 29, 6, 45, 1, 39, 3,  4, 2,  1, 0, 31, 7, 91, 
    1, 54, 5, 17, 0, 68, 3,  5, 4, 12, 2, 14, 8, 50, 6,  5, 7, 32, 
    6, 76, 7,  1, 8, 61, 2, 86, 1, 42, 0, 31, 4,  3, 5, 78, 3, 63, 
    7, 50, 6, 70, 5, 98, 3, 44, 8, 41, 4, 58, 1, 78, 2, 17, 0, 20
  };
  const int q0342[] = {
    9, 9, // Number of jobs and machines
    6, 39, 4, 29, 0, 71, 2, 38, 1, 33, 3, 60, 7, 78, 5, 14, 8, 13, 
    2, 79, 8, 32, 7,  7, 5, 56, 1, 78, 3, 51, 4, 62, 0, 16, 6, 83, 
    0, 53, 8, 57, 1, 26, 7, 62, 6, 41, 3,  2, 5, 60, 2, 11, 4, 57, 
    5,  6, 7, 20, 0, 18, 1, 68, 4, 95, 2, 29, 3, 84, 6, 22, 8, 27, 
    8, 51, 1, 10, 3, 87, 2, 67, 6, 42, 0, 81, 5, 40, 4, 89, 7, 76, 
    6, 22, 8, 39, 2, 19, 3, 72, 1, 77, 7, 90, 5, 39, 0, 50, 4, 32, 
    0, 67, 6, 58, 2, 35, 5,  2, 7, 33, 3, 53, 8, 19, 4, 40, 1, 73, 
    3, 70, 4,  6, 5, 62, 7, 17, 0, 86, 2, 91, 8, 28, 6, 77, 1, 76, 
    1,  3, 6, 82, 7, 45, 2, 14, 0, 60, 4, 19, 5,  5, 3, 28, 8, 38
  };
  const int q0343[] = {
    9, 9, // Number of jobs and machines
    3,  5, 0, 55, 1, 80, 4, 66, 8, 33, 5, 52, 6, 91, 7, 96, 2, 20, 
    4, 37, 3, 81, 8, 96, 6, 47, 0, 36, 1, 11, 2, 91, 7, 77, 5,  5, 
    4, 47, 5, 29, 0, 82, 2, 64, 6, 96, 8, 63, 3, 26, 1, 86, 7, 14, 
    6, 95, 3, 34, 5, 58, 4, 82, 2, 69, 8, 21, 7, 24, 0, 48, 1, 33, 
    1, 72, 4, 22, 7, 82, 2, 75, 3, 97, 6, 41, 0, 64, 8, 42, 5, 58, 
    8, 11, 3, 64, 1,  3, 5, 15, 7, 65, 0, 52, 6, 90, 2, 32, 4, 85, 
    6, 90, 1, 84, 3, 77, 2, 31, 4, 53, 7, 48, 5, 63, 0, 14, 8,  7, 
    5, 90, 8, 75, 0, 94, 2, 98, 1, 73, 6, 90, 4, 85, 7, 37, 3, 13, 
    4, 58, 1, 72, 2, 77, 5, 59, 7, 96, 3, 63, 0, 79, 6, 10, 8, 53
  };
  const int q0344[] = {
    9, 9, // Number of jobs and machines
    0, 91, 1, 99, 4, 63, 7, 34, 3, 63, 5, 95, 6, 20, 8, 53, 2, 75, 
    3,  9, 0, 56, 5, 78, 1, 20, 6, 55, 7, 61, 2, 11, 4, 26, 8,  9, 
    7,  7, 1,  3, 5, 56, 6, 17, 2, 12, 3, 68, 0, 30, 8, 76, 4, 89, 
    2, 44, 1, 60, 5, 48, 8, 54, 7, 38, 3, 86, 6, 14, 0, 49, 4, 11, 
    1, 61, 3, 85, 4, 69, 0, 37, 7, 23, 8, 71, 5, 26, 6, 26, 2, 60, 
    4, 93, 2, 27, 5, 41, 6, 55, 0, 97, 7, 58, 8, 71, 3,  4, 1, 92, 
    8, 53, 4, 40, 2, 69, 7, 99, 0, 97, 6, 63, 5, 92, 3, 30, 1, 72, 
    4, 62, 2, 63, 1, 32, 0, 26, 7, 26, 5, 44, 6, 78, 3, 62, 8, 44, 
    5, 70, 1, 69, 3, 53, 4, 63, 0, 75, 7, 66, 8, 96, 2,  4, 6,  8
  };
  const int q0345[] = {
    9, 9, // Number of jobs and machines
    5, 27, 0, 83, 2, 53, 3, 19, 6, 34, 8, 13, 4, 54, 1, 41, 7, 17, 
    5, 77, 7, 41, 2, 50, 3, 20, 8, 74, 6, 42, 0, 10, 4, 15, 1, 25, 
    2, 49, 8, 23, 5, 84, 6, 68, 0,  5, 1, 75, 3, 55, 7, 42, 4, 52, 
    2, 30, 7, 48, 8, 44, 1, 49, 0, 64, 4,  7, 5, 42, 3,  1, 6, 23, 
    8, 35, 3, 16, 2, 34, 0, 17, 5, 54, 4, 47, 6, 16, 7, 67, 1, 45, 
    6, 62, 8, 60, 4, 21, 5, 79, 1, 11, 7, 36, 3, 13, 2, 55, 0, 59, 
    3, 94, 2, 57, 7, 95, 4, 34, 0, 76, 5, 72, 1, 48, 6, 89, 8, 11, 
    3, 25, 7, 83, 2, 70, 4, 49, 6, 84, 8, 62, 0, 51, 5, 10, 1,  8, 
    5, 58, 6, 94, 8, 17, 0, 38, 1, 99, 2, 55, 7, 27, 4, 58, 3,  3
  };
  const int q0346[] = {
    9, 9, // Number of jobs and machines
    2, 27, 1, 29, 5, 51, 8, 14, 6, 39, 0, 94, 3, 25, 7, 26, 4, 17, 
    4,  3, 0, 55, 1, 51, 6,  6, 8, 79, 2, 22, 3, 27, 5, 41, 7, 95, 
    4, 88, 8, 87, 3, 93, 6, 78, 7, 20, 5, 77, 2, 10, 1, 14, 0, 75, 
    5, 49, 1, 12, 4, 23, 2, 60, 8, 46, 3, 12, 7,  5, 0, 68, 6, 88, 
    0, 61, 1, 98, 4, 29, 2,  4, 7, 28, 5, 81, 8, 78, 6, 75, 3, 93, 
    4, 24, 2, 41, 6, 13, 8, 10, 0, 28, 5, 97, 1, 80, 3, 39, 7, 49, 
    7, 15, 1, 40, 4, 27, 5, 57, 6, 11, 3, 52, 2, 13, 0, 32, 8, 86, 
    8, 71, 0, 44, 7, 61, 6, 24, 1, 53, 5, 65, 4, 28, 3, 70, 2, 35, 
    7, 59, 2, 61, 0, 69, 3, 17, 1, 62, 5,  4, 4, 12, 6, 14, 8, 42
  };
  const int q0347[] = {
    9, 9, // Number of jobs and machines
    2, 66, 6, 74, 0, 83, 8, 81, 5, 57, 3, 10, 4,  4, 7, 26, 1, 23, 
    2, 71, 0,  4, 8, 79, 1, 23, 4, 60, 5, 18, 7, 41, 6, 55, 3, 12, 
    8, 89, 3, 84, 5, 64, 6, 74, 0, 83, 1, 84, 2, 92, 4, 96, 7, 87, 
    3, 82, 0, 73, 4, 39, 1, 76, 8, 76, 7, 27, 5, 52, 6, 72, 2, 20, 
    1, 23, 3, 41, 4, 44, 5, 56, 8, 24, 0, 11, 7, 28, 6, 91, 2, 14, 
    3, 65, 4, 74, 1, 57, 6, 47, 0, 17, 5, 65, 2, 46, 8, 44, 7, 85, 
    4, 39, 8, 66, 5, 78, 2,  9, 6, 35, 0, 56, 1, 39, 3, 94, 7, 18, 
    3, 95, 8, 43, 5, 27, 1, 88, 0, 10, 6, 91, 4, 78, 7, 52, 2,  9, 
    0, 46, 4, 17, 8, 99, 5, 95, 7, 45, 2,  5, 1, 18, 6, 49, 3, 60
  };
  const int q0348[] = {
    9, 9, // Number of jobs and machines
    1, 34, 8, 88, 0, 59, 5, 55, 3, 74, 2, 52, 6, 52, 7,  8, 4, 35, 
    1, 48, 0, 42, 8, 24, 7, 65, 5, 53, 2, 95, 3, 98, 4, 86, 6, 32, 
    4, 73, 7, 83, 5, 28, 1, 72, 3, 57, 8, 77, 2, 69, 0, 45, 6, 18, 
    7,  9, 5, 28, 4, 99, 8, 80, 3, 71, 6, 20, 2, 59, 0, 52, 1, 52, 
    5, 78, 0, 89, 3, 65, 7, 64, 4, 43, 6, 49, 8, 10, 1, 73, 2, 15, 
    7, 50, 2, 74, 5, 31, 1, 43, 4, 97, 8, 39, 6, 20, 0, 48, 3, 79, 
    7, 47, 5, 41, 4, 27, 6, 80, 0, 97, 1, 35, 3, 71, 2, 32, 8, 80, 
    7, 34, 8, 12, 6, 71, 1,  6, 3, 60, 0, 69, 5, 31, 2, 81, 4,  5, 
    2, 71, 1, 69, 3, 16, 7, 20, 4, 56, 5, 77, 6, 85, 0, 52, 8, 54
  };
  const int q0349[] = {
    9, 9, // Number of jobs and machines
    2, 60, 1, 29, 0, 74, 6, 52, 5, 28, 4, 75, 8, 89, 3, 14, 7, 71, 
    8, 45, 1, 47, 3, 91, 7, 52, 2, 81, 5, 35, 4, 51, 6, 35, 0, 56, 
    8, 71, 4, 10, 3, 48, 7, 99, 0,  2, 1, 86, 5, 43, 6, 41, 2, 48, 
    4, 43, 0, 28, 3, 33, 2, 58, 8, 80, 6, 81, 5,  1, 7, 17, 1, 96, 
    3, 66, 5, 35, 2, 77, 4,  4, 8, 35, 6, 60, 0, 15, 1, 48, 7, 29, 
    2, 85, 4, 96, 1,  7, 8, 97, 6, 46, 5, 12, 7, 13, 3, 16, 0, 64, 
    6, 16, 1, 89, 5, 51, 8, 71, 0, 19, 7,  8, 3, 39, 4, 71, 2, 49, 
    0, 10, 4, 46, 1, 38, 7, 32, 3,  1, 5, 83, 6, 72, 8, 51, 2, 47, 
    5, 34, 8, 40, 4, 48, 0,  7, 3, 92, 6, 80, 7, 74, 2, 86, 1, 82
  };
  const int q0350[] = {
    9, 9, // Number of jobs and machines
    5, 84, 8, 44, 7, 35, 6, 18, 3, 35, 1, 80, 4, 48, 2, 76, 0,  3, 
    5, 10, 1, 51, 2, 97, 4, 19, 8, 15, 0, 47, 7, 92, 6, 11, 3, 74, 
    8, 28, 4, 78, 7, 99, 1, 90, 2, 51, 5, 97, 0, 42, 6, 59, 3, 68, 
    2, 85, 3, 98, 5, 66, 8, 84, 1,  9, 4, 97, 0, 10, 6, 12, 7, 31, 
    6, 29, 8, 96, 2, 95, 5, 17, 0, 47, 3,  6, 1, 31, 4,  6, 7, 12, 
    4, 71, 0, 68, 2, 24, 8, 10, 7, 10, 6, 77, 1, 57, 5,  2, 3, 51, 
    1, 72, 6, 13, 5, 93, 4,  5, 7,  6, 3, 28, 8, 49, 2, 25, 0, 95, 
    2, 55, 5, 95, 4, 91, 7, 58, 3, 29, 6, 37, 0, 30, 8, 30, 1, 67, 
    2, 82, 4, 63, 7, 93, 5, 64, 3, 39, 0, 11, 6, 80, 8, 40, 1,  8
  };
  const int q0351[] = {
    9, 9, // Number of jobs and machines
    6, 96, 2, 92, 3, 30, 7,  8, 4, 96, 0,  2, 8, 23, 1, 58, 5, 30, 
    3, 36, 4, 21, 6, 86, 5, 27, 7, 77, 0,  1, 1, 77, 8, 39, 2, 18, 
    2, 58, 4,  1, 6, 83, 3, 10, 1, 58, 5, 93, 7, 94, 0, 53, 8, 97, 
    7, 50, 5, 70, 0, 14, 3, 38, 4, 67, 1, 19, 6, 63, 8, 17, 2,  2, 
    2, 58, 6, 90, 5, 59, 1, 90, 8, 29, 7, 61, 4, 29, 3, 37, 0, 26, 
    5, 63, 1, 57, 6, 35, 3, 96, 2, 73, 8, 83, 0, 47, 7, 31, 4, 83, 
    3, 93, 6, 86, 2,  6, 1, 21, 8, 24, 5, 50, 7, 23, 4, 17, 0, 72, 
    8, 39, 0,  1, 4, 16, 7, 46, 3, 48, 1, 66, 2, 44, 6, 66, 5, 75, 
    1, 46, 8, 37, 0, 48, 6, 39, 3, 34, 7, 65, 4, 36, 2, 21, 5, 97
  };
  const int q0352[] = {
    9, 9, // Number of jobs and machines
    8, 49, 7, 26, 5, 75, 6, 52, 1, 65, 0, 99, 2, 81, 3, 72, 4, 45, 
    8,  1, 4, 49, 6, 11, 2, 27, 0, 16, 7, 68, 5, 87, 1, 90, 3, 90, 
    1, 46, 5, 12, 3, 92, 7, 16, 4, 90, 6, 87, 0,  1, 8, 85, 2, 78, 
    0, 61, 4, 14, 5, 33, 7, 59, 8, 32, 2, 72, 3, 43, 1, 64, 6, 51, 
    1, 70, 0, 22, 4, 90, 6, 76, 2,  7, 5, 13, 8, 90, 7, 76, 3, 66, 
    6, 73, 1, 79, 3, 14, 4, 72, 7, 18, 8, 97, 0, 54, 2, 10, 5, 40, 
    1, 71, 6, 74, 2, 60, 7, 78, 5, 98, 0, 35, 3, 36, 4,  7, 8, 66, 
    2, 23, 0, 23, 7, 74, 3, 12, 4, 92, 1, 58, 5, 27, 6, 12, 8, 61, 
    4, 63, 8, 45, 5, 45, 1, 90, 2, 89, 6, 78, 0, 20, 3, 75, 7, 17
  };
  const int q0353[] = {
    9, 9, // Number of jobs and machines
    1, 93, 3, 88, 4, 72, 0, 18, 5, 58, 8, 98, 2, 95, 6, 72, 7, 61, 
    7, 22, 0, 31, 3, 66, 4, 92, 1,  1, 8, 91, 6, 44, 5,  2, 2, 90, 
    2, 54, 3, 46, 4, 37, 8, 81, 7, 13, 0, 16, 6, 71, 5, 51, 1,  8, 
    7, 81, 6, 55, 3, 83, 2, 97, 4, 35, 0, 97, 1, 72, 8, 58, 5, 91, 
    2,  4, 4, 86, 5, 50, 3, 44, 1, 16, 0, 74, 6, 81, 7, 92, 8, 74, 
    7, 48, 3, 50, 2, 50, 6, 17, 5,  1, 0, 46, 8, 48, 1, 20, 4, 14, 
    2, 11, 4, 26, 0, 31, 7, 65, 3, 87, 5, 39, 1, 37, 8, 44, 6, 69, 
    6, 12, 0, 71, 3, 12, 7, 30, 8, 56, 2, 95, 4, 27, 1, 53, 5, 78, 
    1, 35, 0, 19, 7, 29, 3, 68, 5, 44, 4, 23, 6, 38, 8, 98, 2, 25
  };
  const int q0354[] = {
    9, 9, // Number of jobs and machines
    5, 89, 8, 11, 4, 56, 2, 33, 0, 97, 1,  7, 3,  1, 6, 61, 7, 73, 
    5, 36, 8, 75, 4, 61, 0, 73, 6, 64, 2, 80, 3, 13, 7, 43, 1, 56, 
    3,  5, 6, 60, 2, 80, 8, 45, 7, 91, 1, 44, 4, 49, 0, 10, 5, 30, 
    3, 27, 6, 32, 8, 64, 4, 45, 0, 29, 7, 48, 5, 25, 1, 85, 2, 74, 
    1, 75, 2, 91, 3, 58, 8, 74, 7, 17, 5, 90, 0, 62, 6,  6, 4, 81, 
    4, 98, 3, 49, 1, 39, 2, 53, 8, 69, 0, 79, 6, 85, 5, 71, 7, 15, 
    5, 31, 0, 79, 3, 15, 2, 61, 6,  1, 8, 23, 1, 40, 7, 51, 4, 57, 
    3, 60, 2,  7, 1,  4, 5, 39, 4, 37, 0, 88, 6, 17, 7, 35, 8, 46, 
    6, 90, 1, 14, 7, 57, 0, 12, 5, 10, 8, 68, 3, 93, 2, 41, 4, 69
  };
  const int q0355[] = {
    9, 9, // Number of jobs and machines
    1, 18, 4, 13, 8, 99, 3, 33, 0, 69, 7, 61, 6, 34, 5, 95, 2, 98, 
    5, 88, 0, 29, 4, 67, 7, 71, 8, 45, 1, 97, 3, 43, 6, 87, 2, 61, 
    7, 18, 6, 47, 5, 54, 1, 84, 2, 77, 8, 27, 4, 74, 3, 54, 0, 77, 
    2, 59, 5, 75, 4, 57, 7, 62, 1, 55, 6, 28, 0, 65, 8, 83, 3, 22, 
    0, 60, 8, 13, 4,  4, 3, 48, 6, 23, 1, 45, 7, 26, 5, 88, 2, 78, 
    8, 41, 7, 56, 4, 63, 0, 81, 5,  8, 2, 59, 1, 78, 6, 73, 3, 40, 
    4,  4, 5, 18, 1, 63, 8, 41, 2, 38, 0, 97, 3, 33, 7, 10, 6, 22, 
    1, 68, 4, 60, 0, 72, 6, 97, 3, 65, 5, 94, 2, 91, 8, 98, 7, 82, 
    8, 77, 5, 24, 0, 18, 2, 31, 1,  6, 4, 31, 3, 26, 7, 26, 6, 25
  };
  const int q0356[] = {
    9, 9, // Number of jobs and machines
    7, 15, 5,  4, 6,  7, 3, 80, 8, 79, 1,  3, 2, 69, 0, 47, 4, 71, 
    3, 62, 7, 26, 1, 80, 0, 50, 4, 76, 2, 50, 6, 28, 8, 63, 5, 34, 
    4, 40, 8,  2, 2, 79, 3, 80, 5, 20, 1, 15, 7, 93, 6, 63, 0, 78, 
    7, 11, 4, 53, 8, 68, 0, 40, 3, 46, 1, 93, 6, 59, 2, 50, 5, 64, 
    8, 31, 4, 12, 5, 59, 7, 55, 1, 55, 2, 68, 6, 19, 3, 20, 0, 49, 
    5, 65, 1, 87, 3, 81, 4, 11, 2, 43, 7, 47, 6, 62, 0, 59, 8, 91, 
    4, 50, 5, 88, 0, 99, 7, 97, 6, 61, 3, 83, 8, 42, 1,  4, 2, 39, 
    8,  6, 3, 71, 1, 73, 0, 74, 2, 21, 7, 45, 6, 53, 4, 28, 5, 84, 
    3, 60, 5, 46, 8, 19, 1, 57, 0, 17, 7, 89, 2, 83, 6, 78, 4, 58
  };
  const int q0357[] = {
    9, 9, // Number of jobs and machines
    2, 18, 3, 76, 5, 40, 4, 14, 7, 17, 6, 60, 8, 30, 0, 73, 1,  9, 
    6, 94, 4, 63, 1, 17, 0, 23, 7, 24, 5, 77, 8, 69, 3, 26, 2, 89, 
    3, 20, 7, 88, 8, 43, 4,  3, 2, 65, 5, 98, 6, 75, 1, 97, 0,  9, 
    7, 37, 2,  8, 8, 30, 3, 32, 5, 75, 6, 88, 1, 46, 0,  1, 4, 75, 
    1, 74, 6, 89, 7, 46, 2, 13, 5, 65, 4, 54, 8,  9, 3, 83, 0, 48, 
    7, 57, 2, 23, 5, 30, 3, 73, 0, 22, 6, 27, 4, 12, 1, 71, 8, 59, 
    7, 74, 5, 48, 1, 51, 3, 34, 0, 56, 2, 68, 4, 23, 8, 93, 6, 88, 
    0, 20, 3, 46, 2, 10, 4, 71, 1, 20, 6, 41, 8, 89, 5,  3, 7, 84, 
    2, 75, 1, 25, 7, 41, 0, 91, 5, 16, 8, 27, 6, 55, 3,  3, 4, 53
  };
  const int q0358[] = {
    9, 9, // Number of jobs and machines
    7, 89, 5, 56, 0, 23, 8, 36, 1, 98, 2, 87, 3, 83, 6, 50, 4, 76, 
    7, 98, 4, 99, 0, 95, 1, 88, 2, 96, 5, 88, 3, 72, 6, 62, 8, 35, 
    6, 55, 0,  2, 8, 45, 4, 19, 3, 95, 5, 81, 7, 32, 2, 73, 1, 11, 
    0, 75, 6, 81, 4, 96, 1, 83, 3, 84, 8, 36, 2, 58, 7, 73, 5, 77, 
    8, 77, 4, 67, 7, 99, 1, 59, 5, 23, 6, 22, 0, 19, 2, 96, 3, 12, 
    7, 10, 0, 55, 5, 99, 2, 39, 1, 61, 3, 41, 8, 91, 6, 94, 4, 92, 
    1, 92, 6, 40, 2, 96, 8, 98, 0, 65, 3, 80, 7, 16, 4, 76, 5, 58, 
    0, 78, 6, 13, 7,  5, 2, 13, 3, 57, 4, 80, 8, 89, 1, 94, 5, 39, 
    1, 68, 3, 85, 0,  7, 7, 66, 8, 45, 4, 11, 5, 75, 6, 49, 2, 88
  };
  const int q0359[] = {
    9, 9, // Number of jobs and machines
    1, 19, 8,  6, 7, 39, 0, 32, 4, 28, 6, 20, 3, 29, 5, 13, 2, 89, 
    0, 86, 7, 78, 2, 96, 8, 82, 5, 34, 1, 74, 6, 98, 4, 54, 3, 22, 
    5, 44, 3, 21, 7, 70, 8,  1, 6, 75, 1, 43, 4, 11, 0, 27, 2, 56, 
    4,  8, 1, 14, 8, 70, 5, 99, 3, 99, 7, 55, 0, 99, 6, 54, 2, 55, 
    7, 45, 3, 93, 1, 92, 5, 36, 4, 99, 0, 26, 6, 73, 8, 57, 2, 16, 
    0, 27, 3, 26, 1, 49, 2, 34, 5, 99, 8,  1, 7, 11, 6, 59, 4, 68, 
    4, 23, 8, 68, 5, 42, 3, 50, 1, 20, 6, 76, 0, 82, 2, 15, 7, 25, 
    4, 73, 1, 67, 7, 84, 6, 83, 3, 41, 8, 70, 5, 68, 2, 45, 0, 31, 
    2, 22, 8, 30, 3, 76, 5,  5, 6, 22, 1, 84, 7, 55, 4, 42, 0, 11
  };
  const int q0360[] = {
    9, 9, // Number of jobs and machines
    1, 31, 0, 15, 7, 94, 4, 77, 8, 87, 5, 75, 6, 67, 2, 16, 3, 22, 
    8, 20, 2, 68, 7, 20, 3, 58, 0, 92, 4, 58, 1,  9, 5, 34, 6, 43, 
    7, 91, 1, 91, 8,  6, 6, 45, 4, 25, 3, 63, 2, 75, 5, 72, 0, 81, 
    7, 20, 8, 62, 0, 78, 4, 37, 3, 57, 2, 42, 6, 58, 5, 31, 1, 61, 
    4, 40, 5, 50, 7, 61, 1,  5, 2, 63, 6, 64, 3, 24, 8, 50, 0,  1, 
    5,  8, 7, 53, 3, 81, 1, 33, 4,  8, 8, 25, 6, 63, 0, 90, 2, 60, 
    5, 21, 1, 36, 8, 62, 4, 73, 3, 44, 0,  7, 2, 53, 7, 73, 6, 41, 
    5, 13, 1, 51, 3, 69, 6, 54, 8, 36, 7, 85, 4, 23, 0, 33, 2, 73, 
    7, 79, 6, 62, 0, 90, 1, 82, 8, 87, 4, 49, 2, 58, 3, 87, 5, 45
  };
  const int q0361[] = {
    9, 9, // Number of jobs and machines
    0, 35, 2, 88, 8, 48, 3, 98, 4, 77, 1, 65, 7, 10, 6, 38, 5, 38, 
    2, 28, 6, 44, 1, 57, 0, 76, 5, 42, 4, 94, 3, 20, 8, 63, 7,  3, 
    8,  5, 2,  9, 0, 77, 5, 27, 3,  2, 1, 72, 4, 51, 7, 27, 6, 45, 
    7,  3, 1, 59, 0, 34, 3, 41, 4, 11, 2,  5, 6, 17, 8, 58, 5, 89, 
    3, 19, 5, 31, 0, 28, 1, 76, 8, 29, 7, 94, 4, 77, 2, 49, 6, 98, 
    7,  8, 5, 10, 6, 35, 0, 93, 3, 14, 1, 27, 8,  4, 2, 11, 4, 91, 
    4, 89, 2, 99, 5, 79, 3, 39, 6, 64, 1, 94, 8, 45, 0, 33, 7,  5, 
    1,  7, 3, 11, 5, 68, 8, 77, 0, 77, 7, 48, 6,  7, 2, 89, 4, 66, 
    6, 77, 2, 19, 1, 80, 3, 42, 5, 50, 0, 99, 7, 83, 8, 32, 4, 53
  };
  const int q0362[] = {
    9, 9, // Number of jobs and machines
    1, 49, 0, 96, 5, 90, 8, 20, 7, 89, 3,  9, 2, 72, 4, 21, 6, 89, 
    8, 31, 0,  4, 7, 17, 6, 68, 3, 33, 2, 16, 4, 36, 1, 13, 5, 12, 
    3, 67, 5, 79, 2, 36, 7, 92, 6, 59, 1,  1, 4, 85, 8, 91, 0, 96, 
    7, 36, 5, 27, 1, 26, 6, 53, 3,  3, 8, 72, 2, 34, 4, 22, 0, 38, 
    5,  8, 7, 89, 8,  5, 1, 66, 0, 85, 2, 62, 4, 86, 3, 27, 6, 64, 
    6, 74, 3, 64, 0, 86, 4, 33, 8, 26, 7, 14, 2, 56, 1, 47, 5, 25, 
    8, 64, 5, 17, 4, 63, 3, 24, 2, 94, 1, 50, 0, 95, 7, 45, 6, 38, 
    1, 65, 2,  2, 8, 61, 0,  3, 5, 44, 7, 79, 6, 70, 4, 43, 3, 10, 
    8, 88, 5, 70, 7, 77, 4, 46, 1, 38, 0, 46, 6, 93, 2, 95, 3, 27
  };
  const int q0363[] = {
    9, 9, // Number of jobs and machines
    2, 44, 0, 35, 5, 67, 4, 49, 8, 87, 6, 49, 7,  4, 3, 74, 1, 37, 
    8, 81, 5, 42, 4, 17, 6,  5, 7, 78, 2,  5, 3,  5, 1, 19, 0, 67, 
    7, 26, 3, 67, 2, 88, 4, 65, 6, 43, 0, 21, 8, 65, 1, 33, 5, 83, 
    4, 99, 5, 31, 8, 62, 0, 75, 1, 45, 7, 45, 6, 91, 3, 87, 2,  9, 
    2, 32, 8, 73, 3,  8, 7, 96, 1, 81, 5, 72, 6, 50, 4, 23, 0, 18, 
    6, 25, 8, 96, 3, 97, 4, 39, 1, 73, 0, 23, 5, 18, 2, 86, 7, 12, 
    2, 28, 8, 29, 6, 19, 5, 37, 0, 37, 3, 49, 4, 77, 7, 35, 1, 96, 
    2, 23, 3, 85, 8, 59, 4, 47, 0, 41, 1, 65, 7, 98, 5, 86, 6, 96, 
    7, 72, 8, 30, 6, 75, 3, 76, 5, 38, 2, 60, 4, 57, 1, 15, 0, 84
  };
  const int q0364[] = {
    9, 9, // Number of jobs and machines
    4,  8, 3, 53, 5, 83, 8, 36, 1, 58, 2,  6, 7, 97, 6, 35, 0,  8, 
    5, 83, 3, 72, 2, 22, 1, 98, 0, 47, 8, 90, 4, 87, 6, 72, 7,  6, 
    6, 82, 5, 74, 4, 23, 1, 91, 0, 89, 7, 60, 8, 29, 3, 72, 2,  7, 
    3, 68, 1, 17, 0, 25, 6,  3, 7, 72, 5, 37, 4, 42, 2, 36, 8, 46, 
    2,  8, 4, 20, 6, 42, 1, 18, 8, 27, 0, 96, 5, 81, 3, 49, 7, 37, 
    4, 64, 0,  8, 7, 20, 6, 24, 3, 49, 5, 96, 8, 51, 2,  4, 1, 68, 
    7, 93, 5, 77, 0, 88, 8, 16, 4, 42, 1, 40, 3, 49, 6, 96, 2,  3, 
    4, 96, 5,  2, 1, 88, 8, 42, 6,  8, 0, 52, 3, 75, 7, 91, 2, 99, 
    7, 80, 2, 12, 5, 52, 8, 27, 3, 37, 4, 53, 1, 16, 6, 12, 0, 27
  };
  const int q0365[] = {
    9, 9, // Number of jobs and machines
    5,  7, 3, 28, 0, 84, 7, 16, 8, 73, 1, 55, 6, 71, 4, 69, 2, 59, 
    1, 86, 3, 91, 7, 49, 2, 24, 4, 50, 8, 35, 6, 68, 0, 82, 5, 98, 
    0, 31, 5, 79, 2, 88, 7, 58, 8, 15, 3, 38, 6, 59, 4, 35, 1, 84, 
    0, 39, 8, 56, 2, 39, 6, 70, 4, 98, 5, 79, 1, 64, 7, 21, 3,  1, 
    7, 51, 2, 50, 1, 48, 6, 63, 8, 90, 4, 37, 5, 52, 3, 61, 0, 79, 
    6, 88, 2, 90, 4, 14, 0, 63, 5, 47, 3, 22, 7, 37, 8, 50, 1, 15, 
    1, 28, 8, 35, 2, 91, 3, 29, 0, 19, 5, 23, 4, 33, 7, 10, 6, 90, 
    3, 10, 8, 20, 2, 68, 6,  5, 5, 61, 1, 32, 0, 40, 4,  4, 7, 75, 
    5, 70, 8,  9, 2, 75, 6, 47, 7, 78, 1,  1, 0, 52, 4,  9, 3, 72
  };
  const int q0366[] = {
    9, 9, // Number of jobs and machines
    3, 20, 1, 39, 7, 20, 0, 88, 8, 72, 6,  4, 4, 17, 2,  2, 5, 15, 
    4, 21, 8, 53, 6, 97, 2, 68, 3, 75, 1, 74, 0, 33, 7, 10, 5,  6, 
    2,  9, 7, 34, 3, 39, 6, 17, 4, 49, 1, 69, 8, 94, 5, 71, 0, 83, 
    0, 87, 1, 63, 3, 44, 8, 58, 7, 98, 2, 51, 6, 51, 5, 11, 4,  8, 
    6, 52, 7,  5, 1, 38, 0, 43, 5, 21, 3, 27, 2, 29, 8, 88, 4, 35, 
    6, 27, 2, 56, 4, 96, 3, 12, 7, 64, 5, 33, 1, 46, 8, 49, 0, 84, 
    7, 28, 4, 64, 3,  6, 2, 53, 8, 70, 0, 65, 6, 41, 5, 80, 1, 28, 
    1, 85, 6,  3, 4, 53, 7,  2, 2, 93, 8, 16, 0, 67, 3,  1, 5, 13, 
    6, 36, 7, 43, 4, 38, 0, 39, 5,  4, 8, 51, 3, 13, 1, 31, 2, 44
  };
  const int q0367[] = {
    9, 9, // Number of jobs and machines
    1, 58, 4, 65, 8, 20, 3, 35, 7, 67, 2, 43, 5, 16, 0, 73, 6, 67, 
    4, 73, 7, 19, 1, 49, 5, 26, 3, 79, 2, 90, 0, 27, 8, 82, 6, 19, 
    3, 49, 2, 67, 8, 62, 0, 56, 4, 40, 1, 61, 6,  9, 7, 21, 5, 14, 
    6, 20, 0, 85, 1,  4, 3, 12, 2, 34, 4, 17, 5, 88, 7, 91, 8, 34, 
    8, 98, 1, 82, 5, 29, 4, 99, 6,  5, 0, 52, 3,  5, 2, 55, 7, 30, 
    0, 33, 4, 94, 5, 91, 6,  1, 3, 81, 2,  4, 7,  8, 8, 95, 1, 15, 
    6, 61, 1, 23, 7, 53, 4, 50, 0, 41, 2, 35, 8, 53, 5, 12, 3, 88, 
    7,  6, 4, 18, 8, 97, 0,  4, 6, 93, 3, 16, 1, 26, 5, 91, 2, 19, 
    6, 10, 4, 87, 7,  4, 1, 61, 3, 88, 2, 30, 8, 94, 0,  8, 5, 97
  };
  const int q0368[] = {
    9, 9, // Number of jobs and machines
    0, 28, 1, 73, 3, 47, 8, 79, 5, 53, 2, 66, 6, 96, 7,  3, 4, 32, 
    7, 20, 2, 39, 4, 12, 0, 68, 6, 61, 1, 86, 3,  3, 8, 93, 5, 41, 
    8, 49, 7, 34, 1, 81, 5, 35, 6, 20, 0, 41, 2, 32, 4, 51, 3, 89, 
    4, 27, 6, 63, 8, 12, 7, 70, 1, 19, 2, 64, 3, 16, 5, 62, 0, 91, 
    5, 63, 7, 12, 6, 64, 0, 33, 2,  9, 3, 75, 1, 77, 8, 62, 4, 97, 
    4, 89, 8, 25, 3, 37, 5, 78, 2, 26, 6, 15, 1, 53, 0, 65, 7, 22, 
    7, 57, 5, 45, 1, 20, 3, 14, 0, 13, 8, 31, 6, 23, 2, 18, 4, 46, 
    3, 38, 7, 38, 8, 64, 6, 75, 1, 65, 5, 47, 2, 24, 4, 43, 0, 55, 
    6, 65, 8, 78, 2, 72, 1, 75, 7, 91, 3, 56, 0, 55, 5, 38, 4, 34
  };
  const int q0369[] = {
    9, 9, // Number of jobs and machines
    6, 47, 3, 95, 8, 55, 4, 18, 0, 97, 1, 19, 7, 81, 2, 40, 5, 20, 
    2, 16, 0, 53, 3, 25, 1, 39, 4, 72, 6, 97, 8, 45, 7,  9, 5, 79, 
    6, 84, 1, 89, 8, 19, 3,  7, 4, 66, 5, 23, 0, 88, 7, 92, 2,  9, 
    6, 66, 7, 45, 0, 90, 5, 24, 1,  9, 8,  9, 3, 70, 4, 78, 2, 55, 
    7, 54, 2, 98, 4, 60, 1, 97, 5, 40, 3, 69, 0, 34, 6, 65, 8,  9, 
    3, 21, 5, 10, 1, 90, 7, 78, 0, 55, 8, 53, 4, 14, 6, 30, 2, 75, 
    1, 77, 3, 27, 5, 64, 6, 54, 8, 95, 7, 62, 0, 84, 2, 75, 4, 42, 
    6, 60, 5, 83, 1, 43, 8, 63, 2, 55, 0,  9, 3, 76, 4, 74, 7,  5, 
    1, 24, 0, 31, 2,  3, 7, 68, 8, 19, 6, 96, 5, 40, 4, 60, 3, 39
  };
  const int q0370[] = {
    9, 9, // Number of jobs and machines
    7, 36, 2, 85, 3, 31, 6, 41, 0, 20, 8,  7, 1, 17, 5, 78, 4, 97, 
    4, 16, 1,  1, 0, 55, 2,  7, 8, 90, 3, 35, 7, 96, 5, 57, 6, 96, 
    7, 83, 3, 83, 8, 73, 4, 62, 6,  8, 0, 46, 2, 76, 5, 62, 1, 45, 
    4, 46, 5, 92, 0, 70, 2, 43, 3, 90, 8, 92, 1, 44, 6, 51, 7, 86, 
    0, 80, 6, 48, 1, 78, 8,  4, 3, 46, 7, 43, 5, 73, 4, 18, 2, 34, 
    0, 63, 7, 37, 1, 41, 8, 13, 4, 96, 5, 99, 6, 40, 2, 77, 3, 34, 
    1, 57, 6, 74, 0, 57, 4, 26, 3, 27, 2, 74, 8, 26, 5, 14, 7, 79, 
    5, 94, 8, 33, 4, 18, 1, 80, 0, 36, 7, 70, 6, 36, 2, 65, 3, 63, 
    3, 34, 8, 28, 2, 62, 7, 83, 0, 27, 1, 52, 6, 89, 4, 55, 5, 88
  };
  const int q0371[] = {
    9, 9, // Number of jobs and machines
    7, 55, 1, 82, 0, 13, 3, 25, 2, 18, 4, 35, 5, 18, 8, 50, 6, 88, 
    4, 68, 7, 64, 5, 52, 6, 14, 8,  3, 1, 82, 0, 44, 3, 27, 2, 58, 
    2, 36, 1, 77, 8, 30, 4, 88, 5, 24, 0, 66, 6, 39, 7, 39, 3, 84, 
    2, 10, 6, 14, 4, 11, 1, 28, 8, 26, 0, 11, 5, 95, 7, 66, 3, 77, 
    3, 48, 2, 36, 6, 86, 7, 88, 8, 66, 5, 95, 1, 80, 4, 65, 0, 84, 
    8, 54, 5, 51, 1,  9, 3,  4, 2, 66, 6,  8, 0, 25, 7, 21, 4, 69, 
    1, 61, 2, 81, 7, 16, 4, 90, 8, 26, 0, 21, 5, 93, 3, 46, 6,  9, 
    5, 27, 6,  1, 7, 98, 4, 21, 0, 32, 1, 97, 2, 20, 8, 35, 3, 41, 
    4, 60, 5, 53, 2, 80, 3, 59, 8,  7, 1, 30, 7,  1, 0, 84, 6, 83
  };
  const int q0372[] = {
    9, 9, // Number of jobs and machines
    7, 52, 0, 84, 8, 11, 5, 38, 3, 63, 6, 68, 2, 96, 4, 25, 1, 67, 
    6,  8, 5, 21, 0, 20, 1, 69, 2, 97, 4, 20, 3, 64, 7, 95, 8, 91, 
    4, 29, 0, 47, 7, 17, 1, 60, 2, 53, 8, 14, 6, 72, 3, 73, 5, 77, 
    1, 22, 7, 55, 0,  7, 5, 51, 3, 79, 8, 97, 6, 42, 4, 13, 2, 24, 
    5, 50, 2, 45, 3, 68, 8, 94, 0, 12, 1, 40, 7, 25, 6, 31, 4, 38, 
    5, 67, 6, 73, 1, 28, 0, 10, 3, 73, 7, 95, 2, 69, 4, 31, 8, 46, 
    4, 68, 3, 10, 7, 82, 2, 55, 5, 78, 0, 45, 8, 88, 6, 56, 1, 34, 
    6, 11, 4, 47, 1, 42, 0, 33, 5, 87, 8, 71, 3, 29, 2, 89, 7, 69, 
    1, 85, 7, 59, 0, 92, 4, 60, 5, 95, 3, 31, 6, 37, 2, 16, 8, 14
  };
  const int q0373[] = {
    9, 9, // Number of jobs and machines
    7, 36, 6, 22, 2, 88, 3, 75, 1, 58, 8, 26, 0, 54, 5, 10, 4, 26, 
    4, 90, 7, 81, 2, 89, 5, 80, 8, 19, 0, 18, 1, 53, 6, 83, 3, 87, 
    5, 21, 4, 68, 3, 60, 0, 30, 1, 62, 6, 48, 2, 97, 8, 57, 7, 92, 
    3, 90, 2, 37, 6, 64, 5, 24, 0, 33, 8, 82, 7,  6, 4, 98, 1, 11, 
    7,  4, 1, 80, 3, 87, 8, 30, 0, 60, 2, 61, 6, 40, 5, 42, 4, 95, 
    5, 35, 3,  1, 6, 10, 1, 37, 7, 56, 2, 82, 0, 87, 4, 87, 8, 63, 
    8, 83, 3, 63, 7, 70, 6, 26, 2,  9, 4, 51, 1, 33, 0,  1, 5, 46, 
    5, 10, 7, 49, 6, 43, 2, 35, 1, 63, 4, 73, 0, 56, 8, 10, 3, 47, 
    4, 18, 6, 85, 8, 72, 7, 74, 1, 10, 0, 87, 3, 40, 2, 75, 5, 69
  };
  const int q0374[] = {
    9, 9, // Number of jobs and machines
    7, 68, 6, 95, 5,  4, 0, 98, 8, 79, 1, 92, 2, 77, 3, 26, 4, 33, 
    3, 45, 0, 15, 8, 26, 6, 21, 1, 74, 2, 74, 7, 43, 5, 21, 4, 32, 
    4, 76, 3, 99, 6, 39, 1, 57, 5, 51, 2, 75, 8, 34, 0, 58, 7, 97, 
    7, 19, 3, 51, 6, 42, 5, 80, 0, 33, 8, 22, 2, 74, 1, 58, 4, 93, 
    2, 89, 3, 94, 4, 91, 1, 89, 7, 81, 0, 26, 8, 27, 5, 41, 6, 34, 
    7, 91, 6, 43, 2, 42, 5, 99, 1,  6, 3,  5, 0, 87, 8, 66, 4, 92, 
    4, 42, 0, 52, 2, 54, 8, 76, 1, 93, 7,  7, 3, 79, 6, 17, 5, 25, 
    3, 57, 6, 97, 0, 84, 8, 19, 7, 91, 1, 58, 5, 56, 2, 21, 4,  4, 
    4, 38, 7,  5, 1, 62, 5, 24, 0, 39, 3, 28, 2, 98, 8, 71, 6,  1
  };
  const int q0375[] = {
    9, 9, // Number of jobs and machines
    1, 24, 4, 30, 2, 34, 6, 18, 3, 53, 5, 11, 0, 54, 8, 29, 7, 17, 
    7, 60, 8, 16, 4, 60, 2, 14, 5,  8, 0, 51, 6, 24, 1, 63, 3, 41, 
    8, 85, 2, 97, 1, 83, 4, 70, 6, 34, 5, 86, 7, 67, 3, 47, 0, 13, 
    8, 91, 2, 57, 4, 56, 6, 50, 7,  3, 5, 81, 0, 32, 1, 28, 3, 36, 
    8, 39, 7, 44, 5, 83, 0, 50, 3, 57, 1,  9, 6, 83, 4, 74, 2, 39, 
    0, 82, 8, 12, 1, 17, 7, 88, 4, 49, 3, 84, 2, 63, 5, 85, 6, 78, 
    2, 80, 3, 21, 5, 36, 4, 34, 1, 46, 8, 72, 7, 51, 0, 20, 6,  9, 
    3, 35, 2, 53, 5, 13, 8, 96, 1, 18, 4, 12, 6,  6, 0, 28, 7, 81, 
    8, 67, 3, 27, 4, 75, 6, 25, 2, 18, 7, 15, 5, 48, 0, 50, 1, 35
  };
  const int q0376[] = {
    9, 9, // Number of jobs and machines
    5, 58, 1, 48, 7, 82, 2, 95, 0, 69, 4, 93, 6, 20, 3, 77, 8, 27, 
    3, 22, 5, 15, 8, 11, 7, 88, 1, 84, 2, 48, 6, 75, 4, 24, 0, 96, 
    2, 99, 3, 23, 0, 67, 8, 58, 7, 55, 5, 26, 4, 24, 1, 41, 6, 65, 
    0, 44, 1,  5, 2, 66, 4, 66, 7, 88, 5, 14, 8, 59, 3, 47, 6, 38, 
    8, 52, 0, 33, 7, 16, 4, 45, 2,  7, 1,  8, 6, 45, 5, 78, 3, 46, 
    4, 24, 6, 79, 1, 80, 3, 98, 2, 58, 8, 49, 0,  1, 5, 38, 7, 12, 
    4, 53, 5, 28, 2, 17, 3, 92, 0, 52, 6, 20, 8, 69, 7, 33, 1, 43, 
    1, 20, 7, 43, 4, 10, 0, 79, 5, 87, 6, 87, 3, 10, 8, 17, 2, 32, 
    8, 65, 7, 77, 6, 68, 5, 32, 1, 35, 3, 74, 0, 48, 2, 69, 4, 63
  };
  const int q0377[] = {
    9, 9, // Number of jobs and machines
    7, 65, 4, 60, 2, 46, 5, 38, 8, 40, 6, 67, 1, 21, 0,  6, 3, 94, 
    3, 40, 4, 73, 5,  1, 6, 93, 0, 40, 7, 78, 1, 57, 2, 16, 8, 94, 
    6, 68, 7, 18, 4,  3, 0, 74, 1, 72, 2, 13, 5, 35, 8, 16, 3, 74, 
    7, 63, 2,  2, 3, 13, 5, 13, 1, 58, 0, 82, 4, 80, 8, 65, 6, 58, 
    3, 36, 4, 89, 0, 69, 2, 78, 1, 94, 8, 91, 5, 28, 7, 63, 6, 85, 
    5, 25, 4, 56, 7, 36, 8,  6, 3,  4, 0, 68, 1, 67, 6, 97, 2,  2, 
    4, 89, 8,  8, 6, 50, 7, 81, 0, 73, 5,  6, 3, 86, 1, 98, 2, 81, 
    6, 53, 4, 32, 0, 35, 3, 89, 7, 38, 5, 65, 2, 71, 1, 18, 8, 45, 
    7, 78, 3, 53, 0,  2, 8, 29, 6,  5, 1, 46, 5, 58, 4,  9, 2, 38
  };
  const int q0378[] = {
    9, 9, // Number of jobs and machines
    0, 27, 6, 70, 8, 80, 3, 87, 2, 65, 4, 82, 7, 30, 5, 86, 1, 78, 
    8, 45, 0, 16, 5, 90, 4, 37, 2, 11, 7, 19, 1, 90, 6, 75, 3, 98, 
    4, 83, 7, 82, 6, 85, 0, 73, 3, 53, 5, 19, 8,  5, 2, 48, 1, 16, 
    7, 23, 4, 30, 0, 79, 6, 83, 2, 65, 3, 95, 5, 26, 1, 12, 8, 21, 
    2, 15, 3, 90, 5, 24, 1, 30, 0, 60, 4, 29, 6, 30, 7, 74, 8, 11, 
    6, 90, 1, 90, 8, 19, 0, 76, 5, 90, 4, 82, 7, 67, 3, 65, 2, 48, 
    8, 73, 3, 53, 6, 59, 0, 22, 1, 87, 5, 53, 2, 51, 7, 27, 4,  7, 
    5, 53, 1, 61, 8, 40, 0, 32, 3, 17, 6, 22, 2, 76, 7, 82, 4, 58, 
    4, 83, 7, 43, 0, 53, 2, 14, 3, 55, 6, 90, 1, 13, 8,  3, 5, 66
  };
  const int q0379[] = {
    9, 9, // Number of jobs and machines
    1, 90, 4, 60, 8, 70, 3,  2, 5, 57, 0, 51, 6, 48, 7, 50, 2, 49, 
    8, 59, 3, 58, 0, 15, 7, 86, 4, 13, 6, 45, 1, 12, 2, 36, 5, 96, 
    1, 26, 6, 93, 3, 34, 4, 58, 5, 12, 2, 52, 7, 28, 0, 69, 8, 65, 
    0, 46, 7, 69, 2, 74, 4, 70, 5, 67, 3, 24, 8, 69, 1, 73, 6, 84, 
    5, 57, 8, 81, 3, 79, 0, 55, 2, 34, 7, 40, 1, 99, 4, 61, 6, 38, 
    6, 33, 8,  4, 5, 65, 2, 93, 3, 46, 1, 75, 7,  2, 0, 18, 4, 31, 
    2, 21, 3, 80, 0, 18, 7, 27, 5, 84, 4, 18, 1, 80, 6, 27, 8, 88, 
    2, 95, 8, 31, 7, 50, 6, 49, 0, 83, 4,  5, 1, 55, 3, 30, 5, 46, 
    8, 84, 6, 29, 2,  4, 0, 95, 7, 73, 1, 19, 5, 61, 4, 45, 3, 90
  };
  const int q0380[] = {
    9, 9, // Number of jobs and machines
    7, 87, 1, 95, 4, 53, 3, 28, 2, 62, 8, 77, 5, 12, 0, 14, 6, 91, 
    1, 83, 6,  9, 7, 51, 8, 18, 0, 51, 5, 73, 3, 59, 4, 40, 2, 79, 
    1, 99, 4, 75, 5, 13, 2, 33, 7, 17, 3, 28, 6, 39, 8, 21, 0, 16, 
    2, 76, 5, 93, 7, 13, 4,  2, 8, 97, 3, 42, 1, 31, 0, 76, 6, 50, 
    3, 10, 5, 68, 2, 91, 8,  9, 6, 24, 7, 19, 0, 19, 4, 43, 1, 63, 
    3, 90, 6, 78, 0, 34, 2, 66, 1,  8, 8,  8, 7, 88, 4, 99, 5, 53, 
    0, 92, 8, 63, 7, 75, 6, 84, 1,  6, 5, 51, 3, 17, 2, 26, 4, 14, 
    2, 58, 0, 29, 5, 28, 4, 83, 8, 41, 3, 43, 1, 47, 7, 27, 6, 80, 
    8, 26, 0, 91, 3,  9, 4, 62, 2, 42, 5,  1, 1, 75, 7, 17, 6, 44
  };
  const int q0381[] = {
    9, 9, // Number of jobs and machines
    8, 26, 6, 69, 1, 10, 0, 85, 5, 76, 2,  4, 3, 92, 4, 99, 7, 31, 
    2, 56, 8, 67, 7, 98, 0, 75, 5, 87, 6,  6, 3, 61, 1, 47, 4, 72, 
    6, 93, 2, 25, 0, 13, 8, 73, 3, 32, 5, 76, 7, 41, 4, 37, 1,  3, 
    0, 26, 3, 43, 4, 28, 2, 59, 1, 92, 7, 12, 8, 78, 5, 63, 6, 86, 
    0, 37, 3, 41, 8, 11, 2, 73, 7, 57, 6, 40, 1, 92, 5, 70, 4, 16, 
    6, 33, 5,  7, 8, 96, 1, 89, 4, 29, 3, 42, 0, 81, 2,  6, 7, 18, 
    0,  7, 3, 64, 4, 18, 5,  3, 1, 33, 8, 66, 6, 94, 7,  7, 2, 46, 
    2, 59, 4, 13, 5, 53, 8, 16, 7, 20, 6, 72, 1, 51, 0, 34, 3, 27, 
    6, 25, 5, 75, 3, 53, 0, 17, 4, 48, 2, 22, 7, 41, 1, 65, 8, 29
  };
  const int q0382[] = {
    9, 9, // Number of jobs and machines
    3, 74, 2,  5, 5, 45, 0, 99, 6, 23, 7, 69, 8, 44, 4, 96, 1, 53, 
    2, 58, 7, 81, 5, 62, 1,  7, 0, 14, 6, 36, 8, 73, 3, 27, 4, 34, 
    4, 74, 5, 30, 6, 89, 2,  1, 7,  8, 1, 55, 3, 68, 0,  8, 8,  2, 
    2, 98, 4, 54, 0, 99, 7, 76, 3, 54, 8, 88, 1, 18, 5, 86, 6, 61, 
    6, 75, 5,  1, 2, 38, 7, 19, 1, 32, 0, 41, 4, 86, 3, 96, 8, 34, 
    2, 79, 8, 75, 7,  6, 6, 26, 3, 65, 5, 66, 4, 62, 0, 83, 1, 11, 
    6, 41, 8, 33, 3, 52, 2, 60, 4, 68, 7, 29, 5, 22, 0, 98, 1, 81, 
    5, 93, 1, 81, 7, 55, 0, 19, 6, 44, 8, 34, 2, 92, 3,  3, 4, 40, 
    4, 98, 2, 12, 6, 46, 8, 19, 3, 99, 1, 22, 5, 92, 0,  1, 7, 80
  };
  const int q0383[] = {
    9, 9, // Number of jobs and machines
    5, 63, 0, 62, 8,  1, 1, 34, 4, 12, 2,  3, 7,  6, 6, 18, 3, 18, 
    7, 20, 2, 92, 4, 26, 5,  2, 3, 43, 8,  5, 6,  7, 0, 88, 1, 79, 
    8, 58, 5, 61, 2, 51, 4, 46, 0, 21, 7, 80, 6, 40, 3, 58, 1, 52, 
    5, 48, 3,  5, 7, 76, 1, 19, 0, 35, 4, 79, 6, 64, 8, 22, 2, 60, 
    0, 24, 5, 52, 8, 88, 3, 66, 4, 26, 6, 11, 2, 31, 1, 89, 7,  6, 
    2, 20, 8,  7, 5, 11, 3, 32, 1, 86, 7, 99, 4, 76, 6, 56, 0, 34, 
    6,  6, 8, 66, 1, 90, 4, 34, 7, 80, 0, 87, 2, 27, 3, 10, 5, 23, 
    0, 74, 6, 58, 4, 17, 8, 69, 7, 19, 3, 39, 5, 33, 2,  3, 1,  2, 
    0, 16, 6, 85, 4, 28, 1,  7, 5, 96, 2, 30, 3, 13, 8, 59, 7, 44
  };
  const int q0384[] = {
    9, 9, // Number of jobs and machines
    5, 44, 3, 62, 4, 79, 7, 80, 2, 86, 6, 70, 8, 45, 0,  6, 1, 39, 
    7, 92, 2, 15, 5, 40, 4,  9, 3,  6, 8, 65, 1, 18, 6, 62, 0,  7, 
    0, 20, 5, 79, 1, 67, 8,  1, 2, 63, 4, 32, 6, 31, 7, 65, 3, 59, 
    8, 77, 6, 28, 4, 66, 1, 89, 2, 95, 0, 99, 7,  5, 5, 28, 3, 68, 
    3, 78, 2, 32, 4, 25, 0, 34, 6, 49, 7, 28, 5, 73, 1, 28, 8, 17, 
    6, 26, 1, 90, 8, 83, 2, 61, 4, 26, 0,  2, 3, 33, 7, 38, 5, 48, 
    1, 24, 5, 99, 7, 58, 8, 69, 0, 46, 3, 88, 4, 25, 6, 32, 2, 66, 
    7, 32, 8, 70, 1, 49, 6, 95, 0, 96, 3, 92, 5, 25, 2, 24, 4, 43, 
    1, 43, 7, 70, 0, 55, 4, 92, 8, 85, 5, 83, 6, 30, 3, 22, 2, 12
  };
  const int q0385[] = {
    9, 9, // Number of jobs and machines
    3, 79, 2, 97, 4, 81, 6,  6, 8, 24, 5, 60, 1, 94, 0, 73, 7, 71, 
    8, 35, 5, 26, 6, 22, 0, 81, 2,  8, 4, 30, 3, 12, 7, 11, 1, 16, 
    4, 33, 5, 56, 1, 12, 3, 47, 8, 69, 2, 40, 7, 26, 0, 89, 6, 38, 
    8,  7, 5, 91, 6,  7, 0, 38, 3, 29, 4, 48, 7, 63, 2, 13, 1, 58, 
    7,  2, 4, 80, 5, 53, 3, 80, 0, 22, 6, 21, 1, 41, 8, 55, 2, 12, 
    5, 76, 4, 84, 7,  4, 1, 80, 2,  2, 6, 56, 8, 53, 0, 36, 3, 58, 
    5, 51, 0, 26, 1, 80, 7, 31, 2, 96, 8, 78, 3, 95, 4, 50, 6, 55, 
    5, 92, 7, 20, 2,  4, 8, 69, 0, 61, 4,  3, 6, 70, 1, 38, 3, 43, 
    0,  8, 6, 87, 4, 83, 7, 32, 2, 14, 3, 21, 8, 77, 5, 29, 1, 49
  };
  const int q0386[] = {
    9, 9, // Number of jobs and machines
    1, 30, 7, 71, 2, 45, 8, 26, 6, 58, 4, 54, 0, 83, 5, 38, 3, 64, 
    5, 88, 8, 47, 6,  6, 4, 83, 1, 59, 3, 28, 0, 63, 7, 61, 2, 11, 
    7, 45, 0, 62, 8, 90, 2, 98, 5, 12, 6,  6, 1,  9, 3, 74, 4, 38, 
    4, 71, 5,  8, 1,  6, 8, 38, 2, 54, 6,  6, 7, 31, 0, 17, 3, 22, 
    6, 33, 2, 93, 5, 20, 3, 54, 8, 72, 7, 67, 0, 45, 1, 88, 4, 26, 
    8, 41, 5, 72, 7, 54, 4, 78, 0, 64, 3, 50, 6, 28, 2, 32, 1, 13, 
    8, 36, 6, 50, 5, 47, 1, 67, 4, 35, 7, 53, 2, 87, 0, 19, 3, 29, 
    5, 28, 3, 42, 1, 67, 8, 26, 7, 69, 6, 77, 4, 87, 2, 42, 0, 26, 
    2,  1, 8, 63, 0, 70, 7,  7, 3, 47, 5,  5, 6, 37, 1, 42, 4,  8
  };
  const int q0387[] = {
    9, 9, // Number of jobs and machines
    1, 58, 3, 40, 6, 73, 8, 77, 5, 70, 7, 46, 4,  6, 2, 79, 0,  8, 
    6, 78, 4, 11, 0, 12, 8, 89, 1,  1, 3, 11, 7, 14, 5, 68, 2, 70, 
    5, 31, 7, 94, 8, 11, 6, 71, 4, 24, 3, 18, 2, 75, 0, 45, 1, 31, 
    1, 23, 8, 60, 5, 76, 0, 98, 2,  9, 4, 67, 7, 26, 3,  2, 6, 82, 
    6, 59, 7, 29, 3, 70, 0, 10, 1, 69, 4, 69, 2, 34, 5, 72, 8, 11, 
    8, 13, 3, 58, 5, 29, 7, 16, 2, 25, 6, 86, 4, 57, 1, 50, 0, 47, 
    5,  4, 2, 45, 4,  6, 7, 60, 6, 31, 1, 45, 8, 60, 0, 66, 3, 62, 
    0, 91, 4, 93, 6,  5, 3,  7, 5, 72, 7, 51, 2, 64, 8, 72, 1, 59, 
    7, 49, 8,  6, 3, 96, 0, 12, 5, 83, 1, 37, 2, 77, 6, 51, 4, 77
  };
  const int q0388[] = {
    9, 9, // Number of jobs and machines
    1, 69, 5, 19, 7, 36, 8,  7, 2, 48, 6, 80, 3, 12, 4, 76, 0, 13, 
    7, 45, 1, 36, 0, 82, 5, 75, 6, 90, 8, 90, 4, 71, 2, 27, 3, 85, 
    3, 56, 7, 70, 2, 68, 4, 77, 5,  5, 1, 93, 8, 29, 6, 61, 0, 54, 
    2, 13, 3, 67, 7,  1, 4, 14, 1, 19, 6, 92, 8, 94, 5,  6, 0, 87, 
    7, 12, 6, 36, 4, 32, 2, 15, 3, 21, 5, 45, 0, 17, 8, 28, 1, 66, 
    1, 81, 4, 36, 6, 36, 8, 92, 0, 17, 2, 85, 3, 90, 5, 24, 7, 76, 
    7, 59, 4, 46, 2, 60, 1, 15, 6,  5, 0, 65, 5, 36, 8, 18, 3, 95, 
    4, 32, 5, 27, 2, 11, 0, 99, 7, 28, 6, 67, 8, 60, 1,  3, 3, 39, 
    1, 80, 3, 67, 8, 26, 5, 48, 6, 32, 2, 20, 7, 51, 4, 62, 0,  3
  };
  const int q0389[] = {
    9, 9, // Number of jobs and machines
    5, 11, 0, 34, 7, 22, 1, 79, 6, 67, 4, 46, 2, 22, 8, 69, 3, 59, 
    2,  4, 8, 32, 4, 20, 0, 47, 1, 98, 6, 53, 3, 69, 5, 80, 7, 23, 
    0, 14, 5, 24, 4, 18, 8, 19, 6, 39, 7, 89, 1, 71, 2, 13, 3, 22, 
    0, 62, 1, 38, 2, 97, 7, 28, 5, 13, 3, 12, 8, 96, 6, 33, 4, 69, 
    7, 96, 2,  2, 6, 96, 4, 77, 5, 66, 3, 96, 0, 65, 1, 35, 8, 78, 
    2,  4, 0, 20, 6, 51, 1, 68, 8, 80, 5, 96, 7, 18, 4, 67, 3, 70, 
    8, 90, 5, 35, 6,  8, 4, 42, 2, 78, 3, 87, 0, 43, 7, 75, 1, 76, 
    1, 29, 8, 43, 3, 15, 5, 32, 6, 86, 4, 44, 7, 77, 2, 40, 0, 89, 
    3, 97, 0, 11, 8, 81, 7,  5, 2, 13, 4, 92, 6, 39, 1, 59, 5, 97
  };
  const int q0390[] = {
    9, 9, // Number of jobs and machines
    0, 47, 5, 66, 8, 89, 2, 75, 6, 41, 1, 46, 3, 95, 4,  9, 7, 31, 
    7, 91, 6, 70, 8, 53, 2, 28, 5, 24, 3,  5, 0,  9, 1, 72, 4, 22, 
    1, 26, 4,  6, 6, 93, 0, 18, 7, 26, 3, 88, 8, 70, 2,  5, 5, 45, 
    4, 41, 2, 39, 0, 25, 6, 92, 8,  8, 3, 24, 1, 83, 5,  7, 7, 56, 
    3, 56, 0, 87, 1, 16, 4, 43, 5, 29, 6, 26, 7, 45, 2, 58, 8, 25, 
    0, 92, 8, 82, 2, 26, 7,  1, 5, 84, 1, 48, 3, 85, 6, 75, 4, 45, 
    7, 74, 4,  8, 6, 13, 0, 31, 8, 18, 5, 30, 1,  7, 2, 64, 3, 37, 
    4, 37, 3, 79, 2,  7, 5, 40, 1, 44, 6, 80, 8, 12, 7, 93, 0, 26, 
    3, 46, 6, 71, 2, 79, 0, 75, 1,  9, 8,  7, 7, 80, 5,  4, 4, 97
  };
  const int q0391[] = {
    9, 9, // Number of jobs and machines
    8, 43, 4, 34, 5, 72, 7, 26, 0, 94, 2, 75, 3, 91, 6, 62, 1,  4, 
    8,  3, 3, 13, 2, 11, 1, 24, 5, 72, 6, 74, 0, 76, 4, 23, 7,  6, 
    5, 43, 0, 42, 1, 19, 7, 57, 6, 18, 4, 36, 2, 28, 3,  6, 8, 61, 
    3, 44, 8, 27, 7, 45, 4, 40, 0, 58, 5, 87, 1, 71, 6,  6, 2, 33, 
    7,  3, 4, 77, 1, 21, 5, 59, 6, 12, 0,  1, 8, 59, 3, 93, 2, 56, 
    0, 80, 7, 54, 6, 75, 8, 74, 4, 45, 3,  2, 1, 99, 2, 89, 5,  5, 
    7, 21, 5, 84, 6, 32, 8, 56, 4, 22, 3, 25, 0, 11, 1, 72, 2, 11, 
    8, 86, 0, 70, 3, 62, 2, 79, 6, 13, 4, 37, 1, 99, 7,  4, 5, 72, 
    0, 92, 7, 50, 5, 78, 4, 55, 8, 16, 2, 32, 6, 44, 1, 34, 3, 86
  };
  const int q0392[] = {
    9, 9, // Number of jobs and machines
    5, 89, 2, 71, 4, 81, 8, 53, 7, 99, 6, 17, 0, 84, 3, 53, 1,  6, 
    1, 33, 2, 33, 7, 41, 5, 64, 6, 49, 8, 42, 4, 63, 0, 24, 3, 45, 
    4, 57, 0, 56, 8, 17, 1, 48, 3, 96, 6, 23, 5,  3, 7,  1, 2, 88, 
    7,  9, 4, 77, 5, 81, 6, 29, 3, 10, 8, 48, 0, 89, 1, 93, 2, 80, 
    4, 71, 8, 96, 6, 28, 5, 35, 0, 26, 3, 20, 2, 62, 7,  6, 1, 51, 
    1, 54, 4, 65, 7, 36, 5, 11, 6, 25, 2,  3, 3, 65, 0, 61, 8, 90, 
    7, 82, 3, 68, 5, 89, 2, 44, 6, 11, 1, 60, 0, 46, 8, 39, 4, 42, 
    3, 60, 5, 28, 1, 30, 6, 24, 2, 18, 0,  5, 8, 79, 7, 38, 4, 71, 
    2, 24, 3, 62, 7, 80, 1, 74, 5, 31, 6, 25, 4, 92, 8,  5, 0, 85
  };
  const int q0393[] = {
    9, 9, // Number of jobs and machines
    4, 54, 5,  1, 1, 55, 0, 47, 3, 60, 2, 89, 7, 62, 8, 23, 6, 53, 
    8, 99, 4, 46, 0, 32, 1,  9, 6,  5, 5, 68, 3, 92, 2, 30, 7, 44, 
    8, 97, 4, 90, 6, 98, 0, 26, 5, 76, 3, 96, 7, 91, 2, 11, 1, 63, 
    1, 75, 0, 33, 2, 34, 3, 72, 6,  9, 7, 35, 8, 88, 4, 63, 5, 36, 
    3, 86, 2, 48, 7, 62, 6, 77, 8, 44, 5,  9, 4, 27, 1, 65, 0, 30, 
    6, 10, 1, 47, 2, 22, 8, 43, 4, 91, 3, 51, 5, 93, 0, 72, 7, 39, 
    3, 68, 2, 73, 1, 57, 7, 55, 5, 40, 0,  6, 4, 56, 6, 72, 8, 50, 
    5, 15, 0, 28, 8, 81, 1, 79, 6,  6, 2, 53, 4, 22, 3,  8, 7, 36, 
    6, 79, 0, 10, 3, 37, 1, 84, 7, 47, 2, 60, 5, 35, 8, 51, 4, 80
  };
  const int q0394[] = {
    9, 9, // Number of jobs and machines
    1, 60, 5, 45, 8, 20, 7, 84, 4,  4, 0, 84, 3, 39, 6, 40, 2, 56, 
    0, 10, 1, 39, 4, 58, 6, 64, 8, 90, 3, 57, 2,  6, 7, 36, 5, 74, 
    3, 47, 8, 97, 4, 83, 1, 71, 6, 18, 2, 54, 5, 41, 7, 60, 0, 97, 
    5, 24, 0,  7, 6, 25, 2, 63, 3, 76, 1, 51, 8, 23, 7, 48, 4, 78, 
    6, 57, 8, 46, 2, 43, 3, 56, 1, 71, 5, 40, 7, 63, 4, 44, 0, 33, 
    7,  8, 5, 22, 1, 98, 3, 39, 0, 63, 6, 26, 4, 67, 2, 75, 8, 93, 
    3, 27, 6, 85, 0, 78, 1, 45, 7, 30, 4, 15, 2, 16, 8,  5, 5,  5, 
    4,  3, 1, 54, 7,  2, 8, 80, 6, 90, 5, 37, 2,  9, 3, 58, 0, 98, 
    2, 84, 3, 98, 0,  6, 1, 12, 8, 60, 4, 51, 7, 11, 5, 79, 6, 56
  };
  const int q0395[] = {
    9, 9, // Number of jobs and machines
    5, 73, 8,  5, 1, 94, 7, 34, 0, 65, 4, 89, 6, 98, 3, 26, 2, 85, 
    0, 45, 8, 36, 6,  3, 3, 70, 4, 68, 1, 48, 2, 55, 5, 99, 7, 25, 
    5, 49, 3, 39, 2, 31, 1, 54, 0, 80, 4, 18, 7, 66, 8, 44, 6, 76, 
    6, 84, 4, 75, 3, 27, 1, 16, 7,  5, 0, 57, 5, 23, 2, 17, 8, 96, 
    3, 59, 1, 55, 2,  8, 5, 74, 4, 86, 6, 28, 8, 12, 7, 25, 0, 54, 
    2, 69, 4, 84, 7, 96, 1, 80, 5, 28, 0, 30, 3, 99, 8, 17, 6, 58, 
    4, 47, 8,  9, 1, 79, 2, 80, 6, 22, 0, 60, 7, 70, 5, 77, 3, 55, 
    5,  2, 1, 91, 7, 18, 2, 44, 3,  5, 8,  9, 0, 25, 6, 53, 4, 35, 
    2, 17, 1, 12, 7, 38, 6, 77, 4, 97, 3, 26, 8, 76, 0, 88, 5, 21
  };
  const int q0396[] = {
    9, 9, // Number of jobs and machines
    1, 55, 5, 67, 0, 35, 8, 11, 7, 88, 3, 45, 4, 33, 6, 85, 2, 90, 
    4, 22, 7, 58, 1, 88, 8, 79, 5, 13, 6,  1, 0, 77, 2, 99, 3, 26, 
    3, 62, 6, 44, 1, 88, 8, 50, 7, 42, 5, 49, 2, 97, 0, 16, 4, 88, 
    3, 94, 5,  2, 2, 15, 4,  2, 7, 32, 8, 80, 0, 43, 1, 17, 6, 61, 
    0, 55, 5, 67, 1, 41, 3, 14, 6, 18, 8, 85, 7, 60, 2, 25, 4, 61, 
    2, 83, 4, 30, 5, 87, 0, 68, 8, 41, 6, 32, 1, 96, 7, 76, 3, 43, 
    8, 10, 1, 38, 4, 67, 0, 20, 3, 33, 7, 95, 6, 39, 2, 44, 5, 36, 
    3, 66, 0, 26, 2, 75, 1, 33, 7, 57, 6, 46, 8, 80, 4, 80, 5, 17, 
    5, 45, 8, 62, 1, 37, 7, 14, 0, 40, 6, 95, 4, 28, 3, 33, 2, 96
  };
  const int q0397[] = {
    9, 9, // Number of jobs and machines
    7, 35, 1, 10, 3, 76, 0,  1, 4, 95, 5, 61, 8, 58, 6, 86, 2, 17, 
    1, 89, 8, 81, 2, 64, 5, 64, 4, 34, 3,  6, 7, 55, 0, 52, 6, 70, 
    8, 70, 4,  5, 0,  5, 1, 85, 7, 54, 2, 32, 3,  9, 5, 33, 6, 30, 
    1, 84, 8, 78, 6,  7, 4, 54, 3, 76, 7, 60, 5, 50, 2, 82, 0, 11, 
    2, 77, 1, 16, 5, 63, 3, 73, 4, 89, 7, 16, 0, 94, 6, 65, 8, 74, 
    3, 10, 8, 86, 7, 21, 2, 36, 5, 83, 4, 45, 1, 55, 6, 90, 0, 90, 
    8, 65, 5, 25, 6, 51, 4, 92, 7,  2, 0, 75, 2, 42, 3, 53, 1, 34, 
    6, 95, 7, 90, 5, 24, 1, 56, 3, 15, 0, 80, 4, 29, 2, 88, 8, 13, 
    7, 94, 8, 89, 3, 64, 5, 92, 1, 98, 6, 90, 0, 34, 2, 81, 4, 17
  };
  const int q0398[] = {
    9, 9, // Number of jobs and machines
    8, 18, 6, 45, 3, 55, 2,  2, 1, 82, 5, 89, 4,  1, 0, 43, 7, 26, 
    7, 97, 4, 52, 1, 55, 2, 76, 5,  9, 0, 21, 8, 26, 3, 22, 6, 82, 
    7, 55, 5, 17, 6, 26, 3, 67, 4, 38, 1, 98, 2, 13, 8, 83, 0, 14, 
    4, 80, 3, 61, 5, 40, 7, 30, 1, 48, 8, 13, 6, 33, 2, 75, 0, 16, 
    2, 73, 4, 52, 8,  6, 0, 73, 1, 81, 5, 53, 6, 74, 7, 24, 3,  9, 
    4, 35, 2, 21, 7,  1, 0, 17, 8, 52, 1, 29, 6, 19, 5, 55, 3, 27, 
    2,  1, 8,  5, 3, 32, 7, 82, 5,  5, 0, 36, 1, 17, 4, 37, 6, 81, 
    4, 75, 7, 56, 5, 32, 2, 90, 8, 97, 1, 91, 0, 90, 3, 51, 6, 55, 
    0, 30, 6, 10, 7, 65, 1, 37, 3,  2, 2, 46, 5, 76, 8, 32, 4, 72
  };
  const int q0399[] = {
    9, 9, // Number of jobs and machines
    7, 93, 8, 48, 3, 43, 1, 38, 5, 11, 6, 96, 2, 86, 0, 30, 4, 84, 
    2, 36, 3,  9, 5,  3, 0, 14, 4, 34, 7, 27, 8, 46, 1, 32, 6, 12, 
    7, 57, 1, 74, 4, 43, 2, 56, 3, 11, 5, 99, 0, 85, 6, 62, 8, 72, 
    2, 21, 0, 82, 5, 52, 1, 36, 4, 54, 8, 42, 6, 71, 7, 55, 3, 10, 
    7, 25, 0, 23, 8, 44, 3, 99, 2, 56, 5, 87, 4, 18, 6, 99, 1, 83, 
    4, 11, 6, 61, 5, 35, 7, 99, 3, 82, 0, 11, 2,  9, 1, 70, 8, 66, 
    4, 20, 2, 38, 6,  9, 8, 53, 1, 48, 5, 34, 7, 30, 0, 19, 3, 11, 
    7, 28, 5, 57, 2, 49, 1, 27, 0, 60, 8, 41, 3, 68, 6, 29, 4, 79, 
    0,  5, 8, 10, 4, 23, 1, 53, 6, 33, 3, 45, 2, 14, 5, 43, 7, 91
  };
  const int q0400[] = {
    9, 9, // Number of jobs and machines
    8,  3, 5, 68, 6, 44, 0, 47, 7, 55, 3, 17, 1, 73, 4, 80, 2, 85, 
    6, 15, 7, 80, 8, 51, 5, 95, 1, 39, 3, 57, 2, 35, 0, 42, 4, 97, 
    4, 29, 0, 27, 6, 64, 3, 13, 8, 17, 1, 83, 7, 86, 5, 47, 2, 37, 
    3, 71, 2, 61, 6,  7, 8, 16, 4, 14, 7, 30, 5, 30, 1, 79, 0, 40, 
    7, 69, 4, 97, 8, 70, 6, 52, 0, 29, 3, 76, 2, 92, 1, 24, 5, 52, 
    8, 35, 1, 25, 6,  5, 7, 19, 5, 61, 0,  5, 3, 24, 2, 94, 4, 53, 
    2, 41, 1, 53, 5, 94, 8, 91, 0, 72, 4, 30, 3, 47, 7, 62, 6, 47, 
    1, 43, 4, 75, 7, 41, 5, 76, 8, 93, 6, 75, 3, 94, 2, 94, 0, 30, 
    3, 47, 6, 12, 4, 32, 1, 91, 5, 27, 0, 57, 8, 92, 7, 23, 2, 77
  };
  const int q0401[] = {
    9, 9, // Number of jobs and machines
    3, 12, 1,  5, 2, 44, 4, 96, 8, 89, 6, 28, 0, 68, 5, 26, 7, 75, 
    0, 72, 7, 47, 2, 54, 4, 26, 1, 47, 6, 66, 5, 65, 8, 17, 3, 25, 
    5, 99, 2,  8, 3, 25, 0, 79, 6, 57, 1, 29, 4, 77, 8, 64, 7, 46, 
    0,  8, 3, 11, 5, 38, 6, 24, 7, 69, 8, 20, 1, 17, 4, 25, 2, 34, 
    3, 89, 7, 43, 0, 91, 2,  2, 8, 64, 5, 80, 1, 11, 4, 39, 6, 27, 
    8, 95, 5, 31, 0, 53, 1, 20, 2, 58, 4, 38, 7, 70, 6,  5, 3, 11, 
    0, 25, 7, 27, 5, 19, 1, 42, 2,  2, 6, 63, 3, 19, 4, 34, 8, 44, 
    2, 69, 6, 33, 0, 16, 8, 54, 5, 34, 3, 28, 1, 91, 4, 24, 7, 27, 
    1, 67, 8, 54, 4, 65, 7, 24, 2,  6, 3, 38, 6, 61, 0, 62, 5, 46
  };
  const int q0402[] = {
    9, 9, // Number of jobs and machines
    1, 81, 3, 60, 5, 54, 4, 71, 8, 45, 0, 86, 2, 69, 6, 82, 7, 14, 
    8, 69, 1, 66, 6, 99, 2, 72, 0, 51, 3, 24, 4, 38, 5, 92, 7, 89, 
    6, 36, 4, 78, 8, 15, 5,  4, 1, 84, 2, 57, 3, 47, 7, 47, 0, 61, 
    3, 85, 5, 39, 7, 42, 4, 49, 2, 89, 6, 35, 0,  8, 1,  8, 8, 89, 
    7, 60, 6, 64, 3, 16, 5, 18, 8, 69, 2,  3, 0, 16, 1, 67, 4, 99, 
    4, 31, 6, 63, 7, 20, 8, 35, 2, 73, 1, 87, 0, 86, 3, 91, 5, 93, 
    8, 82, 5, 51, 4, 94, 0, 19, 3, 84, 1, 23, 2, 61, 6, 25, 7, 38, 
    2, 32, 4, 78, 1, 60, 3, 54, 7, 75, 6, 66, 8, 38, 5, 12, 0, 19, 
    3, 42, 8, 77, 0, 26, 2, 16, 7, 60, 1, 77, 4, 43, 6, 19, 5, 83
  };
  const int q0403[] = {
    9, 9, // Number of jobs and machines
    0, 38, 1, 54, 3, 90, 7, 47, 6, 18, 5,  1, 8, 57, 2, 86, 4, 70, 
    7, 83, 3, 78, 2, 51, 1, 44, 0, 18, 4, 31, 6, 93, 8, 94, 5, 16, 
    0, 46, 7, 84, 6, 30, 8,  8, 3, 45, 5,  5, 1, 68, 2, 76, 4, 37, 
    5, 13, 7, 83, 8, 44, 6, 37, 3, 91, 0,  6, 4,  3, 1, 55, 2, 68, 
    6, 74, 0, 30, 8,  2, 5, 75, 2, 63, 3,  4, 1, 81, 4, 77, 7, 96, 
    1, 26, 3, 59, 2, 13, 4, 40, 7, 13, 5, 51, 6, 24, 8, 38, 0, 11, 
    8, 74, 4, 24, 7, 11, 1, 95, 5, 94, 6, 92, 0, 64, 3, 70, 2, 56, 
    3, 99, 0, 15, 1, 53, 6, 44, 7, 96, 4, 41, 2, 61, 5, 87, 8, 71, 
    8, 76, 1, 26, 0,  7, 4, 52, 5, 64, 2, 31, 3, 12, 7, 76, 6, 82
  };
  const int q0404[] = {
    9, 9, // Number of jobs and machines
    1, 22, 7, 27, 2, 57, 5, 26, 8, 90, 3, 67, 0, 51, 4, 65, 6, 34, 
    2, 25, 0, 57, 4, 47, 7, 39, 1,  9, 6, 57, 8,  3, 5, 89, 3, 44, 
    7, 62, 8, 11, 1, 53, 4, 79, 5, 40, 6, 50, 0, 61, 2, 36, 3,  7, 
    3, 29, 8, 69, 5,  4, 1, 80, 4, 28, 6, 30, 0, 84, 2, 32, 7, 26, 
    2, 20, 6, 19, 1, 74, 4, 79, 8, 67, 0, 20, 7, 57, 5, 63, 3,  6, 
    5, 72, 1, 30, 8, 88, 4, 14, 2, 63, 6, 92, 7, 47, 0, 11, 3, 20, 
    6, 98, 3, 12, 1, 33, 8, 71, 4, 44, 7, 47, 5, 59, 0, 38, 2, 33, 
    2, 58, 3, 25, 8,  2, 0, 93, 6, 49, 7, 58, 5, 16, 4, 33, 1, 54, 
    8, 21, 1, 73, 5, 22, 6, 55, 0, 51, 4, 36, 2,  3, 7,  4, 3, 24
  };
  const int q0405[] = {
    9, 9, // Number of jobs and machines
    2, 86, 1, 50, 0, 71, 3, 29, 5, 28, 4, 76, 8, 85, 7, 79, 6,  5, 
    7, 64, 2, 45, 3, 88, 1, 25, 4, 95, 6, 67, 5, 98, 8, 91, 0, 51, 
    8, 99, 3, 98, 2, 60, 7, 50, 0, 30, 5, 74, 6, 67, 1, 23, 4, 53, 
    2, 74, 1, 52, 0,  2, 5,  4, 7, 66, 6, 83, 4, 18, 3, 67, 8, 39, 
    4, 31, 3, 89, 1, 82, 8, 68, 7, 85, 6, 80, 0, 55, 2, 44, 5, 25, 
    4, 98, 5, 76, 1,  7, 2, 48, 7, 44, 6, 53, 8, 56, 3, 42, 0, 68, 
    2, 20, 1, 30, 0, 72, 8, 88, 6, 95, 4, 11, 7, 99, 5, 20, 3, 21, 
    1, 21, 2, 76, 0, 75, 4, 53, 8, 73, 6, 93, 3, 92, 7, 63, 5, 98, 
    8, 99, 5,  2, 0, 40, 3, 47, 1, 28, 7, 31, 2, 74, 4,  9, 6,  3
  };
  const int q0406[] = {
    9, 9, // Number of jobs and machines
    1, 65, 0, 32, 5, 55, 8, 10, 6, 94, 4, 78, 7, 55, 2, 40, 3, 81, 
    4, 12, 0, 76, 3, 41, 6, 17, 8, 47, 5, 12, 7, 22, 2, 49, 1, 30, 
    5, 15, 0, 91, 4, 36, 6, 73, 1, 65, 7, 21, 8, 75, 3, 14, 2, 31, 
    4, 53, 1, 27, 6, 10, 5, 82, 2, 28, 8, 62, 0, 32, 3, 40, 7, 19, 
    3, 38, 5, 56, 2, 96, 7, 18, 6, 91, 1, 33, 0, 43, 8, 42, 4, 47, 
    0, 77, 4, 37, 1, 49, 2, 48, 3, 73, 5, 65, 6, 44, 7, 25, 8,  8, 
    1, 48, 2, 21, 4, 98, 3, 39, 6, 67, 5, 79, 0, 83, 7, 39, 8, 97, 
    5, 46, 4, 10, 6, 82, 2, 73, 3, 23, 0, 88, 7, 68, 8, 54, 1, 43, 
    1,  6, 2, 34, 8, 43, 7, 46, 3, 50, 6, 75, 5, 98, 4, 49, 0, 57
  };
  const int q0407[] = {
    9, 9, // Number of jobs and machines
    2,  9, 5, 73, 0, 65, 4, 66, 6, 59, 3, 51, 7, 49, 1, 59, 8, 99, 
    1, 49, 2, 72, 7, 25, 6, 68, 4, 35, 0, 26, 3, 44, 8, 87, 5, 19, 
    2, 20, 3, 59, 1, 35, 8, 59, 4, 82, 5, 19, 0, 99, 7,  7, 6, 38, 
    8, 86, 4, 76, 2, 84, 6, 72, 0, 66, 5, 57, 3, 35, 7, 86, 1, 72, 
    3, 82, 5, 60, 6, 93, 4,  7, 7, 76, 8, 75, 0, 97, 1, 96, 2, 74, 
    0, 81, 8, 10, 3, 67, 5, 92, 2,  9, 6, 92, 1, 72, 7, 56, 4, 11, 
    8, 65, 5, 93, 3, 65, 1, 15, 7, 80, 0, 11, 2, 52, 6, 67, 4, 54, 
    0, 11, 8, 40, 4, 66, 2, 72, 6, 38, 1, 93, 5, 10, 7, 33, 3, 10, 
    8, 88, 6, 96, 5, 23, 1, 43, 4,  8, 2, 30, 0, 29, 3, 93, 7,  8
  };
  const int q0408[] = {
    9, 9, // Number of jobs and machines
    5, 42, 7, 29, 2, 58, 4,  6, 8, 19, 1, 55, 0, 48, 3, 27, 6,  8, 
    1, 16, 4, 63, 7, 43, 5, 28, 8, 44, 0, 51, 2, 54, 3, 28, 6, 50, 
    2, 92, 0,  3, 1, 84, 4, 76, 8, 62, 7, 43, 3, 55, 6, 20, 5, 78, 
    0, 89, 2, 64, 5, 66, 8, 10, 3,  4, 4, 73, 6, 91, 7, 83, 1, 67, 
    8, 98, 2, 45, 3, 49, 6, 52, 1, 26, 0, 63, 4, 80, 7, 13, 5, 86, 
    6, 72, 5, 35, 4, 67, 2, 83, 3, 92, 0, 48, 7, 28, 1, 31, 8, 74, 
    7,  4, 6, 28, 0, 13, 3, 63, 5, 61, 1, 26, 8, 79, 2,  3, 4, 71, 
    0, 82, 4, 28, 2, 53, 1, 45, 5, 17, 6, 86, 8, 98, 3, 27, 7, 77, 
    7,  7, 3, 13, 0, 63, 4, 48, 6, 56, 2, 25, 1, 82, 5, 75, 8,  9
  };
  const int q0409[] = {
    9, 9, // Number of jobs and machines
    6, 15, 2, 15, 0, 76, 8, 54, 1, 67, 7,  5, 5, 14, 3, 51, 4, 50, 
    3, 88, 5, 77, 1, 65, 2,  3, 0, 62, 8, 55, 7, 43, 4, 55, 6, 42, 
    6, 25, 8, 53, 7, 21, 3, 68, 4, 32, 5, 91, 2, 75, 0, 54, 1, 42, 
    1, 54, 5, 30, 4, 50, 2, 67, 0, 27, 8, 62, 6, 27, 3, 47, 7, 46, 
    6, 27, 0, 62, 4,  2, 8,  9, 5, 60, 1, 62, 7, 53, 3, 33, 2, 22, 
    6, 20, 4,  7, 5,  8, 0, 34, 2, 33, 7, 91, 1, 95, 8, 29, 3, 76, 
    0, 84, 6, 47, 5, 66, 3, 58, 1, 42, 7, 79, 4, 22, 2, 70, 8, 69, 
    2, 41, 4, 39, 1, 28, 6, 58, 5, 96, 7, 21, 8, 25, 3, 18, 0, 48, 
    2, 98, 8, 58, 1, 75, 0, 33, 4, 24, 5, 89, 3, 83, 6, 69, 7, 51
  };
  const int q0410[] = {
    9, 9, // Number of jobs and machines
    7, 44, 6, 37, 4, 11, 8,  3, 2,  5, 1, 66, 5, 75, 0, 42, 3, 25, 
    7, 22, 4, 81, 5,  5, 3, 31, 8, 22, 0, 95, 1, 97, 2, 60, 6, 73, 
    7, 47, 2, 18, 0, 73, 3, 42, 8, 60, 6, 99, 1, 15, 4, 13, 5, 15, 
    2, 11, 8, 37, 1, 60, 6,  7, 0, 70, 5, 73, 3, 79, 7, 34, 4, 91, 
    2,  8, 8, 92, 4, 38, 7, 43, 1, 12, 5, 27, 0, 42, 3,  2, 6, 46, 
    5, 56, 8, 44, 7,  7, 1, 89, 6, 66, 0, 30, 2, 55, 3, 58, 4, 44, 
    1, 60, 6, 21, 4,  3, 7, 30, 5, 93, 8, 77, 3, 61, 0, 53, 2, 18, 
    7, 41, 8, 93, 3, 33, 6, 47, 4, 79, 0, 31, 2, 19, 1, 76, 5, 87, 
    4, 19, 3, 85, 6, 89, 8, 78, 1, 78, 0, 94, 5, 64, 7, 58, 2, 13
  };
  const int q0411[] = {
    9, 9, // Number of jobs and machines
    4,  8, 1, 47, 0, 57, 3, 41, 2, 74, 5, 12, 7, 41, 8, 42, 6, 66, 
    3,  7, 8, 55, 1, 25, 5, 55, 6, 49, 7,  3, 0, 85, 2, 23, 4, 27, 
    8,  8, 3, 65, 2, 76, 5, 99, 7, 32, 6, 24, 4, 12, 0, 88, 1,  7, 
    3, 50, 0, 80, 5, 63, 1, 13, 6, 33, 2,  5, 8, 72, 7,  2, 4, 59, 
    4, 56, 5, 92, 6, 29, 3, 61, 0, 70, 1, 45, 2, 31, 8, 80, 7, 90, 
    2, 96, 1, 65, 5, 79, 6, 34, 0, 11, 7, 47, 8, 39, 4,  2, 3, 53, 
    5, 26, 3,  1, 7, 52, 1, 41, 4, 27, 8, 57, 2, 11, 6, 93, 0, 21, 
    0, 61, 4, 68, 7, 50, 3, 29, 5, 59, 8, 75, 1, 50, 2, 31, 6, 64, 
    2, 70, 4, 72, 1, 45, 3, 28, 6, 94, 0, 50, 7, 34, 5, 22, 8, 55
  };
  const int q0412[] = {
    9, 9, // Number of jobs and machines
    0, 80, 6, 40, 7, 18, 8, 85, 1, 12, 2, 58, 3, 31, 5, 29, 4, 47, 
    7, 45, 0, 83, 6,  8, 1, 27, 5, 78, 3, 78, 4, 75, 2, 38, 8,  1, 
    0, 29, 5, 70, 1, 27, 4, 64, 7, 62, 2, 62, 6, 52, 3, 61, 8, 89, 
    1, 53, 2,  8, 4, 68, 6, 58, 8, 77, 3, 26, 0, 14, 7, 46, 5, 32, 
    3, 65, 6,  6, 2, 56, 1, 62, 0, 65, 8, 18, 7, 84, 5, 51, 4, 23, 
    2,  3, 5, 73, 6, 53, 4, 92, 7, 22, 3, 48, 8, 29, 0, 61, 1,  4, 
    8, 62, 1, 64, 2, 69, 3, 55, 6, 26, 7, 36, 0, 53, 4, 91, 5,  1, 
    5, 69, 2, 45, 4, 63, 7, 45, 6, 27, 8,  9, 3, 86, 1, 30, 0, 90, 
    8, 24, 0, 26, 7, 45, 2, 66, 1, 21, 3, 24, 4, 20, 6, 42, 5, 89
  };
  const int q0413[] = {
    9, 9, // Number of jobs and machines
    1, 38, 5, 33, 6, 74, 3, 31, 8, 20, 4, 54, 7, 78, 0, 90, 2, 12, 
    2, 30, 6, 90, 4, 81, 3, 64, 0, 25, 1,  5, 5, 54, 7, 35, 8, 67, 
    8, 13, 1, 67, 5, 44, 3, 37, 7, 91, 2, 45, 0, 28, 6, 99, 4, 30, 
    7, 69, 3, 99, 8, 48, 5,  6, 2, 26, 6, 53, 1, 15, 4, 70, 0, 70, 
    8, 13, 2, 72, 6, 14, 1, 78, 4, 15, 7, 64, 3, 70, 0, 49, 5, 89, 
    6, 75, 3, 31, 7, 57, 1, 76, 8, 82, 5, 85, 0, 86, 2, 63, 4, 10, 
    7, 26, 4, 45, 8,  5, 6,  3, 2, 63, 5,  3, 0, 99, 1, 38, 3, 63, 
    5, 41, 6, 78, 4, 47, 3,  7, 0, 70, 8, 14, 2, 30, 1, 88, 7,  7, 
    2,  7, 8, 58, 0,  3, 6, 64, 5, 92, 3, 79, 4, 33, 1, 65, 7, 76
  };
  const int q0414[] = {
    9, 9, // Number of jobs and machines
    7, 62, 4, 50, 0, 76, 3, 65, 5, 89, 1, 15, 2, 31, 8, 37, 6, 23, 
    8, 76, 6, 66, 2, 57, 1, 50, 0, 32, 4, 30, 3, 22, 5, 66, 7, 75, 
    2, 75, 5, 64, 1,  6, 7, 69, 0, 60, 3, 64, 4, 19, 6, 85, 8, 16, 
    1, 53, 3, 52, 7,  8, 0, 96, 6, 60, 2, 44, 5, 80, 8,  2, 4, 75, 
    6, 16, 3, 62, 1, 34, 7, 40, 2, 45, 5, 68, 8, 38, 0, 48, 4,  9, 
    3, 97, 7, 52, 4, 42, 8, 40, 5,  7, 6, 45, 2, 65, 0, 41, 1, 82, 
    1, 54, 6, 33, 3, 69, 8, 48, 7, 44, 2, 31, 4, 76, 5, 11, 0, 91, 
    3, 80, 7, 27, 1, 23, 5, 19, 0, 11, 6, 24, 4, 26, 8, 19, 2, 69, 
    1, 14, 8, 77, 7, 76, 6, 32, 5, 64, 4, 93, 2, 87, 3, 29, 0, 78
  };
  const int q0415[] = {
    9, 9, // Number of jobs and machines
    3, 51, 7, 96, 2, 91, 4,  8, 5,  4, 1, 99, 0, 70, 6, 65, 8, 71, 
    0, 52, 6,  3, 3,  1, 5, 18, 7, 40, 8, 58, 1, 90, 4, 81, 2, 50, 
    5, 69, 7, 30, 3, 52, 6, 72, 1, 21, 0, 17, 4, 14, 8, 25, 2,  6, 
    8, 68, 5, 44, 2,  3, 0, 35, 1, 80, 3,  3, 7, 99, 4, 77, 6, 59, 
    7, 18, 6, 90, 5, 28, 4,  4, 3, 84, 0, 15, 8, 63, 2, 57, 1, 71, 
    5, 77, 7, 10, 2, 37, 8, 96, 1, 16, 6, 67, 3, 57, 0, 45, 4, 38, 
    5, 87, 3, 61, 6, 19, 4, 15, 0, 11, 8, 98, 7,  5, 1, 85, 2, 78, 
    6, 57, 5, 75, 3,  6, 1, 13, 4, 93, 2, 90, 8, 60, 0, 26, 7, 40, 
    2, 83, 1, 35, 5, 19, 8, 83, 6, 72, 7, 57, 4, 17, 0, 69, 3, 67
  };
  const int q0416[] = {
    9, 9, // Number of jobs and machines
    8, 15, 6, 30, 2, 15, 3, 54, 7, 77, 5, 96, 4, 76, 1, 37, 0, 99, 
    1, 36, 2, 54, 7, 58, 3, 41, 0, 78, 5, 80, 6, 95, 4, 21, 8,  7, 
    8,  5, 7, 73, 2,  1, 0, 94, 6, 88, 5, 62, 1, 14, 3, 14, 4, 29, 
    6, 13, 4, 87, 2, 79, 0, 21, 1, 79, 5, 26, 8, 33, 3, 43, 7, 67, 
    6, 89, 0, 71, 4, 26, 2, 34, 3,  1, 5, 13, 8, 30, 7, 39, 1, 89, 
    1, 54, 4, 85, 6, 62, 2, 19, 7, 33, 5, 36, 8, 41, 0, 40, 3, 57, 
    4, 75, 5, 60, 2, 71, 7, 93, 8, 34, 3, 61, 0, 21, 1, 73, 6, 95, 
    5, 94, 2, 51, 0,  7, 1, 17, 7, 33, 8, 22, 4, 98, 6, 20, 3, 66, 
    3, 48, 5, 82, 8, 76, 0, 95, 6, 79, 7, 84, 2,  6, 4, 66, 1, 23
  };
  const int q0417[] = {
    9, 9, // Number of jobs and machines
    2, 43, 3, 44, 4, 79, 5,  8, 0, 40, 1, 30, 6, 27, 7, 92, 8, 41, 
    6, 65, 8,  4, 7, 88, 1, 37, 0,  6, 4, 73, 3, 11, 2, 63, 5, 44, 
    0, 41, 2, 87, 6, 66, 1, 18, 3, 58, 7, 51, 5, 13, 4, 15, 8, 41, 
    6,  7, 7, 95, 3, 66, 2, 77, 5, 94, 8, 62, 4,  7, 1, 61, 0, 70, 
    8, 32, 6, 83, 4, 60, 2, 57, 3, 20, 5, 62, 7,  4, 0, 54, 1,  6, 
    0, 73, 6, 17, 7, 43, 1, 20, 2, 42, 8, 93, 4, 34, 3, 98, 5,  3, 
    4, 10, 6, 65, 8, 66, 3, 95, 7, 26, 2, 43, 1, 88, 5, 62, 0,  8, 
    2, 90, 7, 79, 1, 67, 8,  1, 4, 16, 0, 23, 3, 66, 5, 15, 6, 57, 
    3, 45, 2, 53, 1, 57, 0, 45, 8,  5, 4, 30, 5, 94, 7, 92, 6, 59
  };
  const int q0418[] = {
    9, 9, // Number of jobs and machines
    2, 48, 7, 59, 5,  6, 0, 41, 6, 60, 1, 96, 3, 51, 4, 88, 8, 96, 
    6, 33, 2, 45, 4,  7, 5, 47, 7, 87, 3, 79, 8, 30, 0, 16, 1, 58, 
    8, 79, 5, 28, 0, 21, 1, 92, 3, 34, 2, 48, 6, 21, 4, 14, 7, 23, 
    4, 42, 1, 55, 7, 72, 3, 41, 8, 39, 6, 40, 0, 51, 2, 80, 5, 96, 
    2, 81, 5, 79, 8, 73, 1, 27, 4, 96, 6, 64, 3, 78, 7, 40, 0, 72, 
    2, 65, 0,  8, 5, 52, 1, 65, 7, 55, 8,  5, 6, 90, 4, 34, 3, 96, 
    8,  6, 5, 28, 3,  6, 4, 61, 2, 56, 0, 81, 1, 86, 6, 84, 7, 86, 
    0, 33, 6, 75, 4, 43, 8, 79, 1, 58, 7, 23, 5, 62, 2,  7, 3, 76, 
    6, 83, 8, 69, 4,  6, 2, 61, 5, 78, 0, 36, 1, 28, 7, 91, 3, 14
  };
  const int q0419[] = {
    9, 9, // Number of jobs and machines
    4, 98, 2, 14, 7, 60, 0,  4, 1, 54, 3, 26, 8, 53, 5, 84, 6, 43, 
    1, 12, 2, 12, 5, 89, 3, 28, 0, 95, 4, 15, 8, 71, 6, 98, 7, 23, 
    2, 14, 1, 13, 0,  9, 8, 57, 4, 32, 7, 56, 5, 41, 3, 95, 6, 61, 
    6, 31, 8, 22, 3, 53, 4, 15, 5, 75, 0, 14, 2,  8, 1, 88, 7, 13, 
    6, 83, 2,  7, 8, 42, 5, 51, 0, 65, 1, 63, 7, 80, 3, 95, 4, 40, 
    8, 75, 2, 45, 0, 91, 7,  4, 3, 21, 6, 15, 5, 15, 1, 23, 4, 63, 
    2, 64, 8, 20, 3, 16, 5, 77, 4, 53, 7, 24, 1, 42, 0,  6, 6, 81, 
    1, 35, 2, 86, 4, 15, 7,  9, 5,  2, 6, 89, 8, 20, 3, 19, 0, 47, 
    5, 26, 6, 78, 3, 88, 7,  1, 0, 75, 4, 52, 8, 56, 1, 80, 2, 10
  };
  const int q0420[] = {
    9, 9, // Number of jobs and machines
    5, 56, 4, 85, 8, 74, 0, 18, 1, 41, 6, 27, 2, 48, 3, 21, 7, 37, 
    1, 45, 2, 31, 0, 99, 5, 48, 4, 91, 8, 76, 6,  4, 3, 90, 7, 16, 
    2, 94, 3, 99, 1, 97, 7, 14, 0, 15, 4, 89, 8, 36, 5, 60, 6, 21, 
    0, 31, 5,  5, 6, 44, 2, 51, 8, 80, 4, 28, 7, 22, 3, 51, 1, 38, 
    6, 20, 2, 27, 8, 61, 1, 71, 0, 24, 5, 68, 7,  7, 3, 97, 4, 67, 
    4, 76, 5, 35, 3, 97, 0, 74, 2, 69, 1, 10, 6, 77, 8, 68, 7, 90, 
    3,  3, 7, 50, 6, 41, 4, 46, 2, 57, 8, 37, 1, 21, 0, 65, 5, 12, 
    2,  9, 4, 35, 6, 83, 7, 68, 5, 78, 0, 85, 3, 50, 8, 78, 1, 75, 
    4, 78, 2,  1, 1, 17, 5, 10, 3, 10, 8, 56, 7, 42, 6, 95, 0, 57
  };
  const int q0421[] = {
    9, 9, // Number of jobs and machines
    0, 91, 8, 92, 3, 11, 6, 36, 7, 79, 4, 18, 5, 29, 1, 47, 2,  2, 
    1, 97, 6, 47, 3,  5, 8, 89, 2, 46, 0, 26, 5, 69, 4, 40, 7, 30, 
    6, 99, 2, 91, 8, 36, 7, 28, 5, 98, 3, 69, 1, 26, 0, 49, 4, 68, 
    6, 16, 0,  5, 5, 62, 2, 26, 3, 83, 1,  8, 7, 37, 4,  3, 8, 97, 
    0, 79, 6, 67, 2, 76, 5, 91, 3,  3, 7, 63, 1, 49, 8,  9, 4,  5, 
    0, 74, 4, 51, 3, 52, 5, 29, 2, 45, 6, 15, 8,  8, 7, 53, 1, 19, 
    0, 89, 6, 24, 4, 73, 7, 48, 5, 33, 2, 92, 1, 72, 8, 72, 3, 70, 
    0, 34, 7,  7, 1, 15, 8, 77, 4, 48, 5, 12, 6, 92, 3, 54, 2, 53, 
    8, 96, 4, 59, 2, 38, 7, 78, 3, 62, 1, 13, 6, 43, 0, 50, 5, 20
  };
  const int q0422[] = {
    9, 9, // Number of jobs and machines
    2,  6, 1, 75, 3, 26, 7, 65, 0, 41, 5, 39, 6, 11, 4, 65, 8,  2, 
    0, 20, 3,  6, 1, 75, 2, 52, 6,  1, 5, 33, 8, 14, 7, 50, 4, 16, 
    0, 53, 2, 40, 4, 45, 8, 39, 3, 70, 6, 62, 5, 55, 7, 56, 1, 25, 
    3,  9, 0, 91, 7, 18, 4, 20, 8,  4, 5, 88, 1, 36, 2, 94, 6, 69, 
    2, 94, 7, 80, 1, 55, 0, 56, 3, 55, 8, 48, 4, 49, 6, 81, 5, 37, 
    5, 51, 6, 45, 2, 92, 4, 69, 3, 66, 1, 86, 7, 94, 8, 61, 0, 47, 
    0,  9, 6, 65, 1, 75, 4, 71, 8, 84, 7, 90, 3, 12, 5, 70, 2, 50, 
    6, 12, 7, 55, 5, 17, 2, 66, 1, 51, 0,  7, 4, 74, 8, 18, 3, 33, 
    6, 20, 5, 80, 4, 92, 7, 23, 8, 73, 3, 16, 0, 96, 2, 97, 1, 69
  };
  const int q0423[] = {
    9, 9, // Number of jobs and machines
    8, 33, 7, 69, 0, 24, 6, 46, 4, 69, 1, 35, 3, 83, 5, 57, 2, 98, 
    5, 32, 7, 15, 8, 20, 6, 88, 0, 38, 4, 87, 3, 73, 2, 30, 1, 86, 
    7, 24, 5, 85, 4, 23, 1, 61, 0, 67, 2, 49, 8,  3, 3, 54, 6, 97, 
    7, 42, 1, 21, 4, 11, 2, 48, 3, 33, 0, 84, 8, 63, 5, 66, 6, 82, 
    1, 81, 7, 16, 2, 33, 8, 88, 0, 10, 4,  3, 6, 42, 5, 19, 3, 23, 
    8, 23, 7, 25, 1, 10, 5, 51, 2, 24, 4, 60, 3, 57, 6, 26, 0, 34, 
    8, 58, 5, 86, 3, 34, 7, 70, 4, 45, 0, 58, 2, 63, 1, 23, 6, 59, 
    8, 47, 5, 45, 6,  6, 4, 71, 1, 75, 2, 23, 3, 57, 0, 60, 7, 10, 
    6, 69, 7, 41, 3, 82, 8, 91, 5, 21, 2, 10, 0, 26, 1, 70, 4, 14
  };
  const int q0424[] = {
    9, 9, // Number of jobs and machines
    4, 83, 1, 45, 5, 66, 0, 48, 8, 26, 3, 69, 7,  5, 6, 53, 2, 91, 
    4, 66, 6, 73, 8, 54, 0, 96, 1, 13, 7, 66, 2, 27, 5, 81, 3, 37, 
    8, 86, 1, 97, 5, 33, 7, 97, 6, 21, 4, 35, 2,  3, 3, 67, 0, 64, 
    4, 64, 1, 46, 7, 40, 2, 12, 8, 53, 6, 73, 3, 70, 0, 29, 5,  9, 
    1, 85, 8, 17, 4,  9, 0, 90, 7, 88, 6, 79, 3,  4, 2, 20, 5, 69, 
    2, 92, 6, 11, 7, 33, 0,  4, 1, 90, 8, 20, 3, 96, 5, 81, 4, 96, 
    4, 75, 2, 69, 1, 43, 6,  2, 7,  7, 0, 24, 5, 90, 8, 74, 3, 88, 
    5, 20, 1, 26, 3, 47, 8, 94, 0, 65, 7, 94, 6, 52, 4, 54, 2, 64, 
    5, 17, 3, 39, 8, 14, 2, 27, 1, 77, 4, 86, 0, 58, 6, 78, 7, 73
  };
  const int q0425[] = {
    9, 9, // Number of jobs and machines
    8, 57, 6, 89, 7, 92, 0, 27, 1, 50, 2, 16, 3, 33, 4, 28, 5, 27, 
    2, 31, 7, 16, 5, 35, 4, 96, 3,  6, 0, 24, 1, 24, 8, 18, 6, 82, 
    7, 25, 0, 14, 4, 65, 6,  7, 5, 20, 2, 76, 3, 43, 1, 98, 8, 62, 
    4, 52, 3, 95, 7, 10, 6, 65, 5, 78, 2, 27, 0, 58, 8,  6, 1, 63, 
    6, 54, 1, 51, 4, 68, 5,  7, 2, 83, 7,  4, 0, 24, 8, 57, 3, 54, 
    4,  4, 7, 82, 2, 29, 0, 71, 5, 32, 6, 72, 3, 11, 1, 25, 8, 31, 
    0, 69, 4, 78, 1,  1, 6, 84, 5, 55, 7, 83, 8, 42, 2, 63, 3,  9, 
    5, 89, 6, 86, 2, 19, 7, 83, 3, 68, 0, 26, 8, 46, 4,  8, 1, 80, 
    8, 82, 5, 20, 3, 77, 4, 50, 1, 85, 2, 46, 7, 31, 0, 43, 6, 81
  };
  const int q0426[] = {
    9, 9, // Number of jobs and machines
    5, 75, 0, 85, 1, 83, 2,  5, 7, 29, 3, 45, 4, 60, 8, 68, 6, 42, 
    2, 87, 8,  1, 6, 36, 3, 50, 7, 48, 0, 34, 5, 84, 1, 78, 4, 53, 
    4, 33, 2, 11, 1, 72, 8, 58, 7, 10, 3, 84, 5, 97, 0, 68, 6, 21, 
    8, 28, 2, 33, 1, 52, 3, 53, 5, 74, 0, 40, 7, 95, 6, 24, 4, 50, 
    5, 64, 8, 97, 1, 57, 3, 70, 0, 51, 7, 21, 4, 61, 2, 30, 6, 68, 
    4, 11, 2,  7, 6, 27, 7, 76, 8,  6, 0, 12, 1, 68, 3, 81, 5,  3, 
    7, 13, 4, 18, 0, 63, 3, 63, 5,  4, 2, 49, 8, 41, 1, 12, 6, 48, 
    6, 23, 1,  8, 7, 76, 2,  7, 3, 39, 4, 29, 8, 88, 0, 88, 5, 57, 
    1, 99, 7, 96, 2, 55, 6, 52, 3, 84, 5, 71, 8, 19, 0, 56, 4, 74
  };
  const int q0427[] = {
    9, 9, // Number of jobs and machines
    2, 84, 0, 88, 3, 98, 6,  9, 4, 19, 5, 74, 1,  1, 8, 20, 7, 72, 
    3, 38, 2, 60, 5, 46, 0,  7, 1, 51, 8, 43, 4, 57, 7, 18, 6, 49, 
    0, 95, 1, 19, 7, 27, 5, 10, 2,  1, 3, 15, 6, 44, 8,  8, 4, 96, 
    6, 43, 7, 22, 4, 47, 1, 33, 3, 83, 2, 29, 5, 17, 0, 19, 8, 89, 
    0, 27, 1, 24, 6, 81, 3, 59, 4,  8, 5, 50, 2, 18, 8, 48, 7, 85, 
    3,  4, 2, 38, 7, 57, 1, 12, 8, 40, 6, 82, 5, 91, 4, 71, 0, 96, 
    1,  4, 4,  9, 6, 20, 8, 83, 5, 50, 0, 85, 7, 69, 2, 59, 3, 94, 
    3, 11, 5,  8, 6, 23, 1, 35, 7,  1, 0, 26, 8, 98, 2, 68, 4, 87, 
    1, 38, 4, 36, 2, 75, 8, 49, 6, 97, 3, 35, 0, 94, 7, 47, 5, 46
  };
  const int q0428[] = {
    9, 9, // Number of jobs and machines
    6, 73, 2, 87, 5, 74, 1, 20, 4, 42, 8, 91, 7, 27, 0, 70, 3, 36, 
    0, 60, 3, 71, 6, 40, 1, 75, 4, 92, 2, 63, 8, 14, 5, 49, 7, 77, 
    7, 85, 0, 45, 5, 11, 2, 24, 4, 33, 8, 77, 1, 83, 6, 52, 3, 82, 
    5, 97, 0,  9, 3, 86, 2, 63, 6, 71, 7, 99, 8,  5, 1, 26, 4, 76, 
    7, 36, 3, 46, 1, 43, 8, 82, 6, 14, 0, 40, 5, 65, 2, 43, 4,  2, 
    2, 19, 6, 31, 5, 54, 3, 65, 8, 85, 7, 39, 4, 94, 0, 19, 1, 35, 
    3, 40, 6, 94, 4, 28, 5, 97, 8, 67, 2, 31, 7, 29, 1, 38, 0, 29, 
    7, 86, 1, 84, 3, 47, 5, 44, 4, 45, 6, 40, 8, 77, 2, 24, 0, 19, 
    5, 37, 4, 41, 8,  7, 7, 31, 6, 43, 1, 11, 3, 32, 2, 90, 0,  3
  };
  const int q0429[] = {
    9, 9, // Number of jobs and machines
    0, 35, 7, 84, 8, 70, 1, 26, 4, 49, 3, 18, 5, 78, 6, 82, 2, 74, 
    0, 91, 4, 36, 5, 97, 2, 30, 3, 58, 6, 57, 8, 70, 7, 34, 1, 93, 
    4, 80, 3, 67, 0, 21, 6,  1, 7, 91, 5, 20, 8, 53, 2,  7, 1, 91, 
    2, 84, 5, 28, 8, 61, 7, 32, 0, 39, 4, 33, 1, 21, 6, 22, 3, 89, 
    8, 82, 6, 47, 5, 40, 7, 58, 1, 96, 2, 14, 0, 53, 4, 29, 3, 27, 
    0, 59, 5, 34, 8, 96, 1, 13, 6, 20, 3,  7, 2, 70, 4, 85, 7, 87, 
    6, 19, 7, 79, 2, 69, 3,  8, 8, 13, 0, 78, 1, 24, 5, 47, 4, 91, 
    7, 64, 2, 97, 8, 86, 6, 47, 0, 47, 4, 98, 5, 44, 3, 75, 1, 28, 
    0, 28, 5, 46, 3, 60, 2, 47, 7, 64, 8,  4, 6, 67, 4, 25, 1, 32
  };
  const int q0430[] = {
    9, 9, // Number of jobs and machines
    5, 33, 6,  4, 0, 20, 1, 79, 7, 58, 2, 32, 4, 76, 8, 68, 3, 50, 
    3, 76, 5, 81, 6,  2, 2, 80, 7, 79, 4, 82, 8, 14, 1, 19, 0, 86, 
    0, 35, 3, 90, 2, 89, 8, 76, 4, 79, 6, 69, 1, 49, 5, 84, 7, 71, 
    6, 32, 3, 81, 4,  3, 0,  4, 8, 87, 1, 44, 7,  8, 2, 74, 5, 49, 
    3, 25, 8, 58, 0, 91, 7, 24, 4, 45, 2, 52, 5, 42, 6,  5, 1, 93, 
    8, 10, 5, 68, 2, 32, 7, 74, 6, 37, 3, 17, 4, 68, 0, 22, 1, 76, 
    1, 43, 8, 35, 2, 47, 7, 13, 6,  8, 0, 49, 3, 45, 4, 14, 5, 14, 
    2, 99, 6, 29, 4, 37, 5, 66, 1, 63, 0, 74, 3, 83, 8, 77, 7, 87, 
    5, 44, 8, 99, 2, 11, 1, 76, 0, 45, 4, 73, 7, 10, 3, 85, 6, 54
  };
  const int q0431[] = {
    9, 9, // Number of jobs and machines
    7, 85, 3,  4, 0, 51, 8, 10, 4,  8, 6, 30, 2, 80, 5, 73, 1, 20, 
    3, 25, 0, 73, 6, 89, 1, 97, 2, 13, 7, 49, 4, 30, 8, 24, 5, 94, 
    4,  3, 3, 40, 7, 96, 5, 95, 1, 45, 8, 91, 6, 70, 2, 88, 0,  5, 
    5, 75, 0, 56, 4, 47, 8, 15, 7, 56, 1, 81, 3, 46, 6,  7, 2, 85, 
    1,  6, 4, 11, 0, 86, 6, 54, 3, 89, 8, 62, 7, 45, 5, 39, 2, 46, 
    4, 54, 3, 81, 7, 96, 8, 70, 5, 96, 2, 46, 6, 77, 1,  3, 0,  7, 
    5, 43, 1, 52, 2, 51, 6,  1, 7, 14, 4, 88, 8, 26, 0, 80, 3, 16, 
    1, 72, 8, 10, 3, 41, 6, 74, 2, 24, 7, 60, 0, 33, 4,  6, 5, 18, 
    3, 14, 4, 54, 8,  9, 7, 27, 5, 63, 0,  5, 1,  8, 6, 82, 2, 66
  };
  const int q0432[] = {
    9, 9, // Number of jobs and machines
    2, 56, 0, 65, 6, 61, 5, 46, 1,  1, 8, 36, 7, 25, 3, 72, 4, 95, 
    0, 37, 1, 81, 4, 90, 8, 18, 6, 56, 2, 97, 5, 57, 3,  6, 7, 55, 
    3, 72, 1, 83, 7, 15, 0, 22, 4, 61, 5, 38, 2, 39, 8, 69, 6, 35, 
    1, 69, 6, 14, 8, 77, 2,  9, 5, 65, 4, 50, 0, 48, 7, 71, 3, 31, 
    3, 31, 5, 26, 7,  1, 1, 94, 8, 28, 2, 76, 4, 59, 0, 61, 6, 73, 
    8, 98, 5, 39, 0, 48, 7, 79, 6, 42, 4, 63, 1, 78, 3, 68, 2, 94, 
    8, 37, 2, 16, 1, 47, 7, 70, 0, 28, 3,  2, 5, 49, 6, 61, 4, 11, 
    6, 78, 3, 80, 0, 87, 1, 75, 7, 63, 8, 52, 4, 73, 2, 39, 5, 30, 
    1, 36, 6, 16, 0, 92, 5, 85, 2, 40, 7, 10, 4, 57, 3, 12, 8, 48
  };
  const int q0433[] = {
    9, 9, // Number of jobs and machines
    3, 18, 1, 56, 2, 33, 7, 72, 8, 34, 4,  8, 5, 96, 0, 99, 6, 11, 
    7, 41, 5, 97, 2, 12, 4, 82, 1, 99, 0, 90, 8, 70, 3, 32, 6, 74, 
    7, 23, 6, 49, 2, 82, 3, 72, 4, 28, 1, 14, 0, 49, 5, 38, 8, 10, 
    0, 73, 2, 52, 8, 37, 4, 59, 5, 32, 1, 92, 6, 98, 3, 74, 7,  9, 
    8, 22, 1, 34, 2, 61, 0, 83, 7, 32, 4, 32, 6, 62, 5, 22, 3, 60, 
    0,  7, 6, 82, 1, 45, 5, 18, 8, 73, 3, 29, 7, 34, 2, 97, 4, 66, 
    6, 34, 3, 28, 7, 62, 5, 90, 2, 32, 4, 39, 0, 28, 1, 28, 8, 62, 
    4, 61, 0, 86, 5, 62, 6, 34, 1, 69, 3, 73, 7, 44, 2, 37, 8, 66, 
    0, 45, 6, 93, 8, 76, 5, 24, 2, 69, 3, 48, 4, 43, 7,  8, 1, 18
  };
  const int q0434[] = {
    9, 9, // Number of jobs and machines
    4, 39, 0, 23, 5, 98, 3,  6, 2, 60, 6, 76, 8, 65, 7, 72, 1, 55, 
    7, 56, 3, 17, 8, 92, 0, 94, 6, 23, 4, 85, 5, 64, 2, 40, 1, 43, 
    1,  7, 5, 59, 6, 20, 4, 21, 0, 12, 3, 78, 2, 52, 7, 78, 8, 22, 
    6, 48, 1, 58, 3, 18, 5, 21, 7, 53, 8, 78, 2, 13, 0, 55, 4, 57, 
    7, 20, 6, 71, 3, 32, 0, 16, 2, 64, 5, 43, 8, 26, 4, 99, 1, 49, 
    1, 71, 5, 10, 0, 17, 6, 94, 2, 74, 4, 64, 7, 70, 8, 73, 3, 26, 
    4, 38, 6,  6, 0, 33, 2, 26, 1, 96, 8, 65, 7, 53, 3, 64, 5, 17, 
    3, 42, 4, 87, 0, 16, 7, 99, 2, 66, 5, 68, 8, 82, 1, 14, 6, 40, 
    7, 45, 8, 89, 0, 33, 2, 33, 4, 62, 3, 65, 5, 35, 6, 29, 1, 94
  };
  const int q0435[] = {
    9, 9, // Number of jobs and machines
    1, 88, 4, 11, 0,  9, 5, 29, 7, 18, 8, 65, 6, 43, 3, 76, 2, 50, 
    5, 74, 8, 69, 4,  2, 1, 60, 3, 36, 0, 77, 6, 17, 7,  2, 2, 89, 
    7, 45, 6, 72, 1, 91, 4, 17, 3, 51, 8, 87, 0, 61, 5, 68, 2, 49, 
    5, 26, 3, 11, 6, 48, 7, 22, 1, 78, 8, 13, 2, 10, 4, 84, 0, 12, 
    4, 53, 6,  1, 1,  7, 5,  5, 0, 54, 2, 35, 8, 89, 7, 29, 3, 89, 
    2,  2, 0,  2, 6, 25, 5, 88, 1, 62, 8,  1, 7, 55, 3, 66, 4, 22, 
    8, 19, 2, 78, 0, 75, 5, 18, 1, 51, 7,  5, 3, 56, 4, 88, 6, 76, 
    5, 97, 2, 52, 4, 78, 8, 21, 3,  6, 1, 78, 6, 92, 7, 80, 0, 39, 
    7,  6, 0, 35, 6, 81, 1, 33, 2, 70, 3, 85, 4, 68, 8, 83, 5, 93
  };
  const int q0436[] = {
    9, 9, // Number of jobs and machines
    8, 85, 5, 27, 0, 84, 4, 31, 2, 79, 3, 72, 7, 75, 6, 75, 1, 62, 
    6, 67, 2, 36, 7, 27, 5, 27, 8, 41, 1, 51, 3, 22, 0, 16, 4, 42, 
    1, 26, 0, 72, 5, 54, 8, 37, 3, 39, 4, 63, 7, 91, 6, 34, 2, 22, 
    0, 30, 3, 34, 8, 88, 5, 20, 6, 56, 4, 53, 7, 40, 2, 43, 1, 62, 
    2, 94, 4, 44, 7, 16, 5, 42, 6, 17, 8, 44, 1, 44, 3, 10, 0,  1, 
    3, 90, 6,  5, 2,  7, 7, 98, 8,  1, 5, 73, 4, 35, 0, 94, 1, 10, 
    2, 31, 8, 95, 1, 91, 4, 17, 0, 91, 5, 39, 6, 15, 3, 17, 7, 38, 
    3, 37, 4, 53, 2, 90, 6, 47, 1, 63, 7, 86, 8, 68, 0, 41, 5, 58, 
    3, 49, 7, 84, 1, 59, 8, 77, 6, 44, 2, 35, 0,  3, 5, 71, 4, 60
  };
  const int q0437[] = {
    9, 9, // Number of jobs and machines
    7, 83, 3, 39, 6, 44, 0, 47, 4, 76, 5,  3, 8, 96, 2, 66, 1, 50, 
    1, 77, 5, 98, 2, 32, 6, 16, 3, 31, 7, 82, 4, 57, 0, 83, 8, 30, 
    0, 97, 4,  8, 3,  4, 7, 25, 8, 39, 2, 86, 6, 29, 5, 25, 1,  1, 
    3, 83, 8, 67, 7, 50, 2, 85, 0, 23, 1, 38, 4, 68, 6,  7, 5, 44, 
    4, 33, 2, 75, 8, 32, 1, 91, 3, 24, 5, 47, 0, 30, 6, 56, 7, 51, 
    8, 78, 5, 62, 6, 99, 2, 71, 1, 32, 3, 17, 7, 35, 0, 40, 4, 16, 
    8, 30, 2, 57, 5, 62, 3, 95, 6, 30, 1, 70, 0, 13, 7, 85, 4, 19, 
    6, 90, 2, 20, 5, 26, 3, 64, 0, 60, 1,  5, 7, 80, 4,  5, 8, 63, 
    4, 55, 3,  8, 6, 87, 1, 45, 2, 45, 5, 92, 0, 85, 8, 37, 7, 19
  };
  const int q0438[] = {
    9, 9, // Number of jobs and machines
    5, 47, 0,  4, 4, 83, 8, 95, 3, 50, 1,  9, 2, 79, 7, 64, 6, 13, 
    4, 60, 6,  3, 3, 16, 7,  9, 0, 86, 1, 64, 5, 58, 8, 45, 2, 34, 
    3,  6, 4, 64, 7, 28, 2, 59, 6, 75, 0, 68, 5, 18, 1, 74, 8, 71, 
    7, 96, 0, 34, 5, 14, 6, 47, 3, 74, 8, 57, 1,  1, 2, 84, 4, 23, 
    7, 19, 0, 22, 1, 81, 2, 80, 8,  4, 6, 53, 5, 59, 3, 96, 4, 34, 
    0, 55, 3, 88, 4, 66, 7,  3, 8, 20, 1, 46, 2, 11, 6, 13, 5,  9, 
    0, 61, 7, 61, 4,  6, 2, 39, 8, 93, 3, 15, 1, 27, 6, 81, 5, 11, 
    6, 88, 2, 62, 5, 26, 7, 90, 4, 55, 0, 53, 8, 41, 1, 29, 3, 44, 
    6, 34, 8, 74, 5,  6, 7, 29, 0, 35, 4, 14, 3, 18, 2, 11, 1, 45
  };
  const int q0439[] = {
    9, 9, // Number of jobs and machines
    3, 93, 1, 12, 5, 64, 6, 66, 2, 90, 7, 89, 0, 17, 4, 15, 8, 54, 
    7, 41, 1, 14, 2, 35, 6, 32, 4, 17, 5, 67, 0, 13, 3, 93, 8, 88, 
    8,  8, 3, 65, 1, 52, 2, 25, 4, 12, 6, 22, 5, 74, 7,  5, 0, 70, 
    7, 79, 2, 65, 5, 12, 3, 14, 0, 73, 6, 28, 4, 71, 8, 36, 1, 61, 
    3, 59, 6, 10, 0, 89, 1, 54, 4, 73, 8, 68, 7, 96, 2, 56, 5, 96, 
    5, 55, 4, 10, 8, 39, 3, 42, 0, 11, 1, 66, 7, 82, 2, 53, 6, 19, 
    5, 68, 4, 53, 2, 58, 1,  5, 0, 81, 7, 99, 8, 99, 3, 93, 6, 24, 
    8, 93, 3, 17, 7, 83, 0, 65, 2, 81, 5, 93, 4, 87, 1, 15, 6, 13, 
    2, 32, 3, 90, 8, 65, 1, 45, 4, 97, 7,  3, 5, 77, 6, 25, 0, 33
  };
  const int q0440[] = {
    9, 9, // Number of jobs and machines
    2, 19, 8,  2, 5, 29, 6, 65, 1, 26, 7, 87, 3, 31, 4, 35, 0, 14, 
    1,  7, 3, 25, 7, 28, 4, 12, 0, 64, 5, 23, 2, 84, 8, 73, 6, 42, 
    7, 66, 5, 34, 3, 27, 8, 62, 4,  2, 2, 74, 6, 27, 0, 38, 1, 67, 
    4, 19, 7, 66, 3, 57, 8,  6, 0, 26, 1, 78, 6, 43, 2, 33, 5, 59, 
    6,  2, 4, 24, 7, 87, 0, 71, 2, 54, 5, 13, 3, 27, 8, 36, 1, 53, 
    5, 30, 2, 16, 4, 97, 7, 60, 3,  3, 1, 71, 8,  6, 6, 71, 0, 48, 
    8, 60, 0, 77, 1, 76, 6, 68, 2, 84, 7, 58, 3, 37, 4, 39, 5, 94, 
    4, 73, 0, 34, 8, 42, 5,  8, 7, 56, 6, 12, 1, 14, 2, 10, 3, 49, 
    7, 63, 8, 90, 6, 95, 3, 70, 5, 47, 2, 97, 4, 75, 1, 91, 0, 75
  };
  const int q0441[] = {
    9, 9, // Number of jobs and machines
    6, 91, 2, 24, 4, 84, 5, 28, 1, 96, 7, 13, 0, 43, 8, 63, 3, 63, 
    2, 89, 8, 99, 1,  1, 5, 65, 0, 35, 4, 47, 6, 64, 3, 99, 7, 16, 
    7, 99, 8, 29, 4, 43, 1, 57, 6, 53, 2, 45, 3, 41, 0, 86, 5, 36, 
    7, 12, 6, 21, 4, 79, 2, 61, 1, 46, 8, 65, 0, 84, 3, 80, 5, 15, 
    0, 59, 7, 36, 4, 10, 6, 13, 8, 44, 5, 20, 1, 66, 3, 87, 2, 54, 
    7, 30, 6, 83, 4, 87, 1, 41, 5, 64, 3, 67, 8, 69, 0, 45, 2, 90, 
    5, 56, 1,  5, 7, 90, 0, 83, 2, 91, 3, 73, 6, 14, 8, 56, 4, 71, 
    4, 53, 6, 21, 5, 99, 7, 65, 8, 86, 3,  1, 0, 58, 1, 40, 2, 21, 
    5, 12, 0, 78, 2, 84, 7, 17, 1, 12, 6, 32, 8, 67, 4, 37, 3, 51
  };
  const int q0442[] = {
    9, 9, // Number of jobs and machines
    1, 91, 5, 96, 7, 80, 8, 60, 3,  6, 2, 11, 0, 69, 6, 68, 4, 84, 
    1, 84, 5, 52, 6, 14, 7, 98, 2, 39, 3, 33, 8, 96, 0, 54, 4, 29, 
    1, 30, 8, 43, 0, 18, 4, 38, 2, 66, 3, 13, 5, 25, 7, 87, 6, 10, 
    2, 22, 8, 11, 3,  4, 7, 18, 6, 62, 1, 73, 0, 53, 5, 12, 4, 13, 
    7, 81, 4, 25, 0, 70, 5, 46, 6, 46, 3,  4, 1, 93, 8,  8, 2, 93, 
    7, 41, 1, 57, 0, 15, 8, 31, 6, 57, 3, 13, 5, 89, 4, 58, 2, 94, 
    0,  7, 3,  8, 6, 76, 8,  2, 2, 79, 4, 89, 5, 74, 7, 32, 1,  6, 
    7,  3, 4, 88, 0, 54, 8, 89, 2, 33, 6, 82, 3, 16, 5, 12, 1, 31, 
    7, 76, 6, 21, 0, 81, 1, 47, 2, 49, 4, 19, 5, 79, 3, 46, 8, 85
  };
  const int q0443[] = {
    9, 9, // Number of jobs and machines
    2, 21, 5,  6, 7, 42, 3, 52, 8, 43, 0, 19, 6, 55, 1, 13, 4, 35, 
    1, 58, 2, 54, 6, 60, 5, 29, 0, 90, 7, 12, 4, 71, 8, 11, 3, 64, 
    5, 34, 0, 21, 4,  2, 8, 25, 6, 58, 3, 17, 7, 55, 2, 23, 1, 84, 
    5, 11, 0, 29, 7, 98, 8, 92, 2, 52, 4, 31, 6, 74, 3, 71, 1,  3, 
    2, 15, 5, 83, 8, 64, 3, 83, 6, 42, 7, 16, 1, 81, 4, 95, 0, 91, 
    0, 88, 6,  8, 2, 17, 4, 40, 1, 43, 5, 78, 7, 70, 3, 68, 8, 86, 
    3, 10, 4, 23, 0, 74, 2, 21, 7, 21, 6, 27, 5, 37, 8, 98, 1, 37, 
    4, 53, 2, 52, 7, 32, 8, 87, 3, 61, 0, 91, 6,  8, 1, 14, 5, 92, 
    6, 72, 8, 90, 3, 69, 5, 90, 0, 51, 2, 42, 4, 34, 7, 73, 1, 60
  };
  const int q0444[] = {
    9, 9, // Number of jobs and machines
    1, 44, 0, 83, 8, 69, 2, 81, 3,  2, 4, 43, 7, 85, 6, 32, 5, 52, 
    2, 53, 6, 33, 3, 97, 0, 25, 5,  5, 4, 23, 1, 16, 8, 75, 7, 58, 
    2,  5, 4, 20, 8, 49, 7, 95, 1, 66, 5, 49, 0, 95, 3, 39, 6,  3, 
    0, 49, 1, 55, 6, 84, 2, 99, 4, 44, 8, 12, 7, 24, 5, 13, 3, 70, 
    7, 26, 6, 31, 2, 17, 3, 15, 4, 17, 0, 83, 1,  3, 5, 25, 8, 98, 
    5, 79, 6, 34, 8, 93, 1, 69, 0, 91, 2, 92, 3,  6, 4, 79, 7, 45, 
    3, 23, 2, 42, 1,  7, 0, 56, 7, 64, 6, 79, 5, 56, 8,  1, 4, 55, 
    0, 65, 7, 30, 3, 58, 1, 46, 4, 61, 5, 63, 6, 98, 8, 86, 2, 58, 
    7, 62, 2, 53, 6, 89, 3, 28, 0, 72, 4, 17, 1, 76, 8, 50, 5, 47
  };
  const int q0445[] = {
    9, 9, // Number of jobs and machines
    1, 23, 2, 44, 8, 28, 4,  5, 7, 53, 6, 42, 0, 43, 3,  9, 5, 27, 
    2, 16, 0, 96, 3, 95, 4, 46, 1, 49, 7, 69, 8, 49, 6, 88, 5,  6, 
    6, 53, 8, 37, 3, 29, 1, 86, 5,  1, 0,  8, 4, 75, 2,  1, 7, 13, 
    8, 17, 1, 92, 5, 65, 2, 55, 7, 27, 4, 16, 6, 74, 0, 32, 3, 20, 
    6, 15, 5, 90, 7, 63, 4, 61, 1, 18, 2, 89, 8, 77, 0,  5, 3, 64, 
    3, 17, 7, 39, 8,  1, 1, 53, 2, 92, 0, 15, 5, 17, 6,  1, 4, 57, 
    3, 47, 7, 89, 6, 36, 5, 69, 0, 88, 1, 56, 4, 69, 2, 21, 8, 83, 
    6, 65, 7, 37, 8, 44, 1, 87, 4, 41, 3, 74, 5, 70, 0, 34, 2, 12, 
    1, 57, 7, 46, 5,  3, 2, 42, 0, 60, 6, 58, 4, 53, 3, 18, 8, 79
  };
  const int q0446[] = {
    9, 9, // Number of jobs and machines
    0, 35, 7, 88, 4, 23, 5, 70, 3, 21, 6, 22, 2, 55, 8, 10, 1, 13, 
    3, 21, 2,  3, 4, 93, 6, 89, 8, 73, 1, 60, 7, 37, 5, 23, 0, 88, 
    7, 72, 8, 50, 0, 59, 3, 89, 6,  5, 5, 74, 1, 87, 2, 31, 4, 78, 
    7, 29, 6, 16, 2, 68, 0, 13, 8, 15, 3, 82, 1, 67, 4, 29, 5, 27, 
    5, 73, 8, 92, 2, 78, 0, 32, 1, 88, 3, 13, 4, 93, 7, 49, 6, 52, 
    2,  9, 1, 85, 4, 62, 5, 17, 3, 97, 0, 94, 8, 51, 6, 37, 7, 45, 
    5, 37, 1, 88, 2, 17, 0, 33, 7, 32, 4, 47, 6, 15, 8, 69, 3, 55, 
    6, 50, 1, 58, 2, 30, 5,  9, 4, 93, 7, 99, 3, 24, 8, 22, 0, 64, 
    4, 60, 5, 72, 7, 34, 2, 85, 8,  3, 1, 38, 0, 82, 6,  4, 3, 87
  };
  const int q0447[] = {
    9, 9, // Number of jobs and machines
    1, 40, 7, 85, 0, 34, 4,  1, 6,  3, 5, 16, 8, 71, 2, 25, 3, 72, 
    2, 22, 1, 86, 8, 92, 7, 62, 0, 37, 3, 72, 4, 45, 6,  1, 5, 33, 
    7, 42, 3, 83, 0,  3, 2, 95, 1, 97, 4, 37, 8, 54, 5, 83, 6, 31, 
    0, 30, 5, 56, 7, 50, 1, 51, 4, 14, 3, 99, 6, 54, 2, 99, 8, 53, 
    2, 18, 1, 47, 3, 85, 7, 47, 4, 68, 6, 26, 8, 75, 0, 21, 5, 73, 
    5, 83, 0, 42, 8, 47, 7, 60, 3, 77, 4, 74, 1, 10, 6, 12, 2, 83, 
    3, 40, 5, 88, 2, 37, 0, 68, 4,  6, 7, 25, 1, 50, 6, 43, 8, 56, 
    6, 15, 2, 18, 1, 26, 0, 61, 7, 96, 3, 43, 8,  7, 5, 58, 4, 54, 
    8, 94, 0, 11, 5,  7, 4, 69, 6, 57, 7, 84, 2, 67, 3, 10, 1, 47
  };
  const int q0448[] = {
    9, 9, // Number of jobs and machines
    3, 14, 1, 18, 7, 23, 2, 57, 4, 72, 6, 15, 8, 58, 0,  3, 5, 85, 
    2, 97, 8, 87, 1, 33, 6, 23, 4, 61, 3, 92, 7, 77, 0, 65, 5, 37, 
    3, 41, 1, 71, 8, 20, 4, 37, 6, 26, 7, 33, 2, 19, 5, 82, 0, 79, 
    0, 86, 8, 79, 1, 51, 7,  7, 2, 60, 4, 68, 6, 58, 5, 50, 3,  8, 
    7, 72, 1, 39, 2, 87, 8, 24, 6, 85, 3, 95, 4, 96, 0, 20, 5, 94, 
    8, 19, 3, 40, 4, 35, 0, 80, 5, 65, 6, 34, 1, 40, 7, 83, 2, 59, 
    2, 72, 8, 61, 3, 98, 5, 88, 7,  2, 0, 63, 4, 28, 1, 60, 6, 42, 
    2,  6, 3, 42, 7, 63, 1, 88, 4, 18, 0, 92, 6, 71, 5, 46, 8, 13, 
    0, 24, 4, 10, 3, 45, 8, 94, 2, 88, 5, 52, 1,  1, 7, 49, 6, 65
  };
  const int q0449[] = {
    9, 9, // Number of jobs and machines
    0, 38, 3,  4, 7, 99, 8, 94, 4, 25, 6, 47, 1, 27, 5, 49, 2, 46, 
    0, 34, 5, 96, 1, 97, 8, 37, 7, 81, 2, 38, 3, 47, 4, 15, 6, 22, 
    7, 68, 0,  6, 1, 49, 3, 87, 5, 23, 4, 75, 8, 69, 2, 76, 6,  3, 
    6, 33, 2, 69, 3, 27, 8, 77, 1, 34, 7, 28, 0, 88, 4,  6, 5, 22, 
    6, 71, 5,  8, 3, 39, 0, 45, 8, 86, 4, 21, 7, 49, 1, 17, 2, 22, 
    0, 27, 3,  8, 8, 33, 2, 89, 1, 99, 7, 60, 4, 90, 6, 59, 5, 51, 
    0, 62, 2, 87, 1, 72, 3, 11, 7, 24, 6, 90, 8, 26, 4, 57, 5,  8, 
    6, 42, 3, 55, 5, 62, 7, 31, 2, 50, 4, 71, 0, 75, 8, 78, 1, 69, 
    5, 89, 2, 31, 6, 87, 8,  6, 1, 89, 3, 67, 4, 94, 7, 45, 0, 79
  };
  const int q0450[] = {
    9, 9, // Number of jobs and machines
    3, 75, 2, 94, 1, 78, 7, 60, 5, 49, 0, 60, 6,  8, 4, 13, 8, 69, 
    6, 51, 3, 39, 8, 40, 4, 62, 1, 24, 0, 53, 5, 20, 7, 60, 2, 43, 
    5, 24, 4, 13, 8, 16, 1, 75, 3, 48, 2, 25, 7, 90, 6, 33, 0, 39, 
    1, 54, 0, 46, 4, 43, 3,  4, 2, 26, 5, 73, 7, 57, 6, 38, 8, 50, 
    2, 41, 8, 44, 0, 81, 4, 35, 5, 61, 3,  4, 1, 83, 7, 88, 6, 41, 
    0, 33, 3, 69, 7, 71, 4, 92, 8, 67, 6, 78, 5, 33, 2, 85, 1, 23, 
    7, 15, 3, 97, 4, 49, 2, 58, 0, 44, 6, 30, 8, 34, 1, 25, 5, 31, 
    0, 74, 7, 78, 6,  9, 4, 78, 1, 66, 8, 58, 5,  3, 2, 70, 3, 68, 
    4,  2, 5, 81, 1, 32, 8, 59, 7, 77, 3, 20, 6, 61, 2, 76, 0, 61
  };
  const int q0451[] = {
    9, 9, // Number of jobs and machines
    0,  7, 8, 49, 5, 49, 7, 18, 1, 39, 2, 57, 6,  6, 3, 68, 4, 42, 
    6, 34, 5, 28, 1, 57, 8, 25, 4, 45, 7, 28, 2, 49, 3, 64, 0, 79, 
    5,  5, 0, 14, 2, 87, 4, 30, 3, 99, 6, 53, 1,  4, 8, 98, 7, 74, 
    2, 12, 5, 46, 4,  7, 0,  8, 6, 52, 3, 74, 7, 43, 8, 59, 1, 63, 
    5, 27, 4, 19, 8, 59, 7, 55, 1,  2, 2,  4, 3, 79, 6, 32, 0, 37, 
    2, 49, 6, 78, 7, 45, 0, 14, 1, 51, 4, 82, 8, 49, 3, 65, 5, 13, 
    4, 39, 3, 86, 1, 18, 5, 85, 2,  3, 7, 97, 6, 41, 8,  4, 0, 57, 
    6, 19, 8, 31, 7, 46, 2, 61, 3, 68, 0, 10, 5, 62, 1, 93, 4, 74, 
    6, 50, 1, 45, 4, 92, 3, 57, 5, 81, 0, 87, 7, 55, 2, 25, 8, 50
  };
  const int q0452[] = {
    9, 9, // Number of jobs and machines
    8, 17, 6, 37, 1, 54, 2, 62, 3, 91, 5, 51, 4, 30, 0, 75, 7, 32, 
    4, 62, 6, 18, 1, 69, 5, 76, 7, 40, 2, 87, 8, 51, 3, 95, 0, 81, 
    1,  5, 3, 86, 7, 87, 5,  2, 8, 43, 4, 80, 6, 96, 2, 24, 0, 90, 
    7,  9, 0, 74, 2, 46, 1, 48, 6, 58, 3, 10, 4, 12, 5, 33, 8, 86, 
    4, 76, 8,  1, 7, 59, 5, 58, 0, 54, 1,  8, 3, 38, 6, 43, 2, 21, 
    6,  6, 3, 99, 8, 49, 2, 91, 5, 56, 1,  3, 7, 64, 0, 58, 4, 60, 
    5,  7, 3, 43, 1, 14, 4, 30, 8, 75, 6, 67, 0,  3, 2, 82, 7, 95, 
    6,  3, 5, 96, 2, 19, 1, 63, 4, 63, 7, 15, 0, 43, 8,  4, 3, 78, 
    4, 86, 3, 34, 8, 16, 6, 57, 5,  9, 7, 84, 0, 23, 1, 30, 2, 53
  };
  const int q0453[] = {
    9, 9, // Number of jobs and machines
    8, 67, 2, 85, 5, 93, 6, 29, 4, 41, 3, 66, 1, 85, 7, 47, 0, 31, 
    0, 90, 1, 47, 2, 94, 7, 13, 3, 22, 6, 82, 8, 46, 4, 32, 5, 50, 
    3, 89, 5, 35, 2, 81, 0, 96, 4, 10, 7, 38, 1,  6, 8,  4, 6, 20, 
    5, 45, 7, 20, 0, 57, 2, 80, 4, 64, 3, 74, 1, 48, 6, 42, 8, 73, 
    3, 94, 2, 47, 6, 74, 4,  9, 8, 51, 7,  4, 5, 28, 0, 13, 1, 66, 
    5, 38, 3, 53, 2, 36, 1, 16, 4, 11, 8, 58, 0, 52, 7, 84, 6, 52, 
    6, 73, 3, 41, 0, 75, 2, 20, 4, 36, 5, 63, 8,  9, 7, 41, 1, 25, 
    3, 51, 4, 64, 8, 95, 5, 66, 2, 52, 6, 47, 0, 62, 7, 95, 1, 94, 
    7, 88, 3, 50, 4, 29, 1, 51, 8, 26, 0, 29, 2, 16, 5, 66, 6, 21
  };
  const int q0454[] = {
    9, 9, // Number of jobs and machines
    8, 56, 6,  1, 2, 44, 7, 37, 0, 77, 1, 99, 3, 68, 4, 97, 5, 76, 
    3, 52, 5, 87, 8, 30, 4, 64, 7, 31, 1, 28, 0,  5, 6, 15, 2, 82, 
    5, 56, 1, 31, 4, 69, 7, 22, 2, 76, 8, 57, 6, 84, 0, 78, 3, 92, 
    5,  8, 4, 97, 3, 91, 0, 71, 6, 31, 8, 33, 7, 62, 1, 41, 2, 32, 
    6, 66, 3, 67, 5, 67, 0, 37, 4, 24, 8, 60, 2, 69, 1, 14, 7, 23, 
    8, 58, 7, 96, 2, 35, 5, 76, 0, 88, 4,  2, 6, 55, 1,  9, 3, 65, 
    7, 78, 8, 94, 0,  5, 4, 15, 1,  1, 3,  6, 6, 39, 2, 94, 5, 24, 
    5, 56, 2, 53, 1, 78, 6, 44, 7, 38, 0, 40, 4, 67, 8, 28, 3, 96, 
    0, 76, 8, 21, 3, 12, 4, 76, 7, 86, 5,  7, 2, 22, 1, 27, 6, 27
  };
  const int q0455[] = {
    9, 9, // Number of jobs and machines
    7, 37, 1, 68, 4, 55, 0, 46, 3, 26, 2, 42, 8, 37, 6, 47, 5, 47, 
    4,  5, 1, 95, 3, 49, 7, 81, 8, 50, 5, 79, 6, 86, 2, 60, 0, 96, 
    6, 51, 5, 23, 3, 35, 0, 21, 7, 94, 2, 69, 8,  6, 1, 44, 4, 22, 
    7, 50, 6, 10, 0, 35, 8, 87, 5, 76, 3, 10, 2, 94, 4, 77, 1, 54, 
    0, 39, 1,  4, 7, 64, 2, 91, 6,  5, 8, 56, 3, 59, 5, 63, 4,  5, 
    5, 77, 2, 26, 7, 34, 0, 35, 8, 67, 4, 95, 3,  4, 6, 56, 1, 18, 
    6, 57, 0, 45, 2, 48, 5, 52, 1,  9, 7, 79, 3, 52, 4, 70, 8, 42, 
    0, 70, 8, 89, 5, 80, 1, 65, 2, 19, 3,  3, 4, 63, 7, 26, 6,  9, 
    5, 41, 2,  4, 8, 90, 6, 43, 3, 15, 1, 23, 4, 71, 7, 37, 0,  3
  };
  const int q0456[] = {
    9, 9, // Number of jobs and machines
    1,  6, 4, 73, 5, 33, 7, 85, 3, 35, 0, 26, 2, 72, 8, 74, 6, 26, 
    0, 12, 8, 59, 6, 50, 1, 96, 4, 38, 2, 94, 5, 14, 3, 36, 7, 29, 
    2, 69, 5,  7, 3,  1, 8, 27, 6, 21, 0, 97, 7, 92, 1, 55, 4, 67, 
    2, 91, 8, 11, 4, 74, 6,  5, 7,  5, 5, 39, 3, 48, 1, 67, 0, 82, 
    4, 49, 5,  9, 6, 70, 7, 23, 0, 34, 1, 55, 8, 94, 2, 95, 3, 12, 
    2, 67, 7, 70, 0, 46, 4, 53, 5, 59, 6, 85, 3, 40, 8, 81, 1, 40, 
    4, 37, 7, 75, 5, 89, 6, 97, 8,  6, 2, 97, 3, 25, 1, 49, 0, 52, 
    1, 70, 2, 61, 0, 96, 4,  5, 3,  1, 8, 48, 6, 79, 5, 22, 7,  8, 
    2, 58, 4, 75, 3,  9, 6, 35, 0, 93, 7, 70, 1, 78, 8, 33, 5, 66
  };
  const int q0457[] = {
    9, 9, // Number of jobs and machines
    6, 23, 3, 48, 0, 66, 5, 99, 4, 83, 7, 67, 2,  7, 1, 95, 8, 14, 
    1, 24, 8, 89, 4, 25, 6,  7, 7, 86, 0, 51, 2, 88, 3, 80, 5, 67, 
    2, 60, 5, 87, 4, 74, 7, 29, 6, 51, 1, 18, 8, 15, 0,  9, 3, 35, 
    5, 43, 1, 22, 3, 69, 7, 64, 2, 15, 0, 45, 4, 48, 6, 99, 8, 71, 
    7, 20, 8, 33, 4,  3, 6, 58, 2, 77, 0, 97, 3, 15, 1, 93, 5, 17, 
    4, 84, 8, 20, 3, 95, 0, 71, 5, 82, 2, 44, 1,  3, 7, 89, 6, 69, 
    7, 60, 3, 92, 5, 45, 1, 13, 0, 70, 8, 94, 2, 18, 4, 59, 6, 40, 
    4, 67, 5,  5, 2,  7, 6, 40, 0, 67, 7, 97, 1, 83, 8, 99, 3, 13, 
    6, 77, 8, 58, 0, 51, 4, 82, 5, 79, 2, 36, 3, 28, 7, 79, 1, 79
  };
  const int q0458[] = {
    9, 9, // Number of jobs and machines
    7, 89, 5, 98, 0, 60, 2, 75, 4, 92, 1, 97, 6, 38, 8, 51, 3, 36, 
    4, 91, 1,  8, 2, 86, 8, 46, 0, 38, 6, 25, 7, 47, 5, 30, 3, 60, 
    1, 34, 2, 41, 0, 22, 8, 29, 7, 32, 6, 17, 4, 77, 3, 35, 5, 61, 
    6, 72, 2, 12, 7, 68, 5, 11, 8, 78, 4, 64, 1, 39, 0, 85, 3, 71, 
    4,  8, 0, 70, 2, 45, 7,  2, 3, 49, 1, 65, 5, 23, 6, 48, 8, 91, 
    6, 31, 4, 37, 1, 53, 5, 85, 0, 66, 2, 54, 8, 84, 3, 76, 7, 99, 
    1,  9, 2, 62, 0, 22, 7, 66, 3, 17, 6, 15, 4, 94, 8, 55, 5, 76, 
    2, 52, 5,  9, 1, 38, 4, 27, 8, 91, 0, 54, 6, 35, 7, 26, 3, 19, 
    2, 43, 1, 94, 0, 84, 7, 97, 6, 74, 8, 76, 4, 49, 5,  2, 3, 52
  };
  const int q0459[] = {
    9, 9, // Number of jobs and machines
    8,  5, 6, 94, 1, 45, 3, 33, 2, 88, 0, 45, 5, 76, 4, 32, 7, 86, 
    5, 84, 8, 56, 7, 90, 2, 83, 6, 76, 1,  1, 0, 19, 3, 71, 4, 79, 
    2, 70, 6,  3, 5, 20, 8, 66, 4, 44, 3, 50, 7, 44, 0,  2, 1, 33, 
    2, 34, 1, 84, 3, 66, 7, 28, 4, 42, 8, 41, 0, 89, 6, 48, 5, 21, 
    6,  1, 8, 98, 4, 53, 5, 33, 3, 89, 0, 41, 1, 10, 2, 12, 7, 49, 
    0, 51, 4, 31, 6, 76, 5, 16, 1, 28, 7, 23, 8, 59, 3, 50, 2, 22, 
    4, 63, 8, 34, 5, 20, 2, 44, 3, 78, 7, 55, 6, 15, 0, 45, 1, 68, 
    7, 48, 4, 31, 6, 49, 8, 67, 2, 14, 5, 11, 0, 42, 3, 97, 1,  1, 
    6,  5, 8, 84, 1,  1, 3, 88, 0, 64, 7, 11, 4,  8, 5, 39, 2, 96
  };
  const int q0460[] = {
    9, 9, // Number of jobs and machines
    5, 69, 2, 82, 1, 22, 8, 71, 3, 57, 7, 45, 4, 77, 6,  5, 0, 58, 
    5, 63, 4, 90, 0, 73, 7, 19, 6, 79, 3, 41, 1, 15, 8, 11, 2, 74, 
    6, 49, 4, 19, 2, 98, 3,  7, 7, 32, 0, 25, 8, 79, 5, 43, 1, 92, 
    0, 53, 3, 87, 8, 19, 5, 57, 2, 72, 4, 72, 1, 26, 6, 68, 7, 88, 
    5, 40, 2, 33, 7, 97, 4, 24, 6, 49, 3, 73, 0, 50, 1, 67, 8, 15, 
    7, 22, 2, 51, 8, 14, 4,  8, 0, 41, 5, 51, 6, 68, 3, 79, 1, 81, 
    5, 98, 3, 36, 0, 28, 8, 70, 6, 82, 1, 11, 7, 20, 4, 90, 2, 73, 
    6, 35, 5, 92, 2,  5, 7, 16, 8, 73, 3, 90, 4, 41, 0, 33, 1, 39, 
    5, 80, 2, 82, 1, 98, 8, 62, 0, 96, 6, 88, 7, 29, 3, 87, 4, 69
  };
  const int q0461[] = {
    9, 9, // Number of jobs and machines
    4, 62, 8,  5, 1, 37, 7, 40, 5, 29, 0, 77, 6,  5, 2, 24, 3, 69, 
    2, 37, 5, 34, 6, 34, 3, 56, 7, 91, 0, 83, 8,  5, 4, 15, 1, 43, 
    6, 64, 8, 42, 4, 12, 5,  2, 1, 68, 2, 22, 3, 37, 7, 27, 0, 76, 
    3, 92, 6, 22, 4, 36, 5, 38, 0, 70, 7, 25, 8, 26, 2,  9, 1, 79, 
    0, 71, 5, 91, 3, 20, 4,  4, 1, 86, 6, 97, 2, 73, 7, 62, 8, 30, 
    5, 58, 0, 64, 7, 36, 4, 45, 3, 66, 6,  3, 2, 54, 1, 86, 8, 40, 
    2, 29, 8, 75, 6, 17, 7, 70, 3, 54, 0, 26, 4, 99, 5, 36, 1, 27, 
    7, 35, 6, 27, 5,  5, 4, 23, 2, 74, 1, 42, 0, 86, 8, 41, 3, 34, 
    6, 91, 1, 43, 7, 48, 5, 39, 3, 91, 8, 11, 2, 40, 0, 65, 4, 39
  };
  const int q0462[] = {
    9, 9, // Number of jobs and machines
    2, 78, 8, 55, 1, 28, 0, 57, 6, 72, 4, 82, 3, 10, 7, 24, 5, 89, 
    6, 89, 4, 15, 0, 28, 1, 94, 8, 60, 7, 68, 2, 49, 5, 60, 3, 68, 
    0, 78, 7, 32, 6, 85, 2, 27, 5, 38, 1, 48, 8, 85, 4,  6, 3, 16, 
    4, 82, 5,  7, 2, 85, 7, 57, 1, 10, 6, 68, 0,  2, 8, 28, 3, 69, 
    0, 81, 7, 85, 5, 97, 8, 68, 6, 94, 2, 97, 1, 52, 4, 74, 3, 58, 
    4, 80, 2, 95, 3, 80, 7, 78, 6,  2, 8, 86, 0, 67, 1, 64, 5, 57, 
    1, 43, 8, 92, 6, 94, 5, 20, 3, 80, 0,  9, 2, 16, 7, 15, 4, 86, 
    0,  9, 1, 25, 5, 90, 7, 47, 2, 54, 8, 34, 4, 76, 6, 24, 3, 44, 
    1,  9, 4,  1, 3, 42, 6, 57, 0, 81, 5, 38, 8, 76, 7, 17, 2, 25
  };
  const int q0463[] = {
    9, 9, // Number of jobs and machines
    1, 24, 7, 31, 0, 26, 6, 20, 5, 85, 4, 51, 3, 24, 2, 94, 8, 40, 
    3, 70, 6, 48, 1, 37, 8, 66, 7, 65, 5, 94, 0, 23, 2, 41, 4, 91, 
    4, 46, 3, 19, 0, 54, 2,  5, 7, 27, 6, 42, 1, 15, 5, 58, 8, 91, 
    5, 35, 6, 27, 1, 50, 3, 18, 0, 63, 4, 12, 8,  5, 2, 78, 7, 31, 
    8, 96, 2, 44, 7, 67, 1, 90, 4, 49, 6, 94, 5, 88, 3, 67, 0, 22, 
    3, 12, 5, 80, 2, 34, 0, 65, 1, 35, 6,  1, 7, 70, 8, 87, 4, 99, 
    2, 85, 4, 13, 3, 78, 7, 63, 8, 69, 6, 86, 1, 81, 0, 17, 5, 97, 
    6, 30, 0, 83, 1, 29, 3, 54, 7, 81, 8, 75, 2, 67, 5, 72, 4, 51, 
    6, 26, 4, 31, 1, 73, 7, 61, 2, 69, 5, 64, 0, 97, 3, 67, 8, 59
  };
  const int q0464[] = {
    9, 9, // Number of jobs and machines
    4, 15, 8, 76, 2, 20, 1, 70, 5, 62, 3, 84, 6, 48, 0, 31, 7, 65, 
    8, 37, 3,  9, 2, 88, 1, 26, 0, 67, 6, 80, 7, 34, 4, 43, 5, 74, 
    6, 32, 2, 88, 5, 60, 0, 41, 8, 60, 7, 50, 4,  1, 3, 72, 1,  7, 
    0, 11, 1, 25, 4, 55, 7, 19, 5, 31, 3, 97, 2, 99, 8, 94, 6, 30, 
    4, 70, 1, 45, 5, 84, 0,  4, 8, 92, 7, 80, 6, 85, 2, 13, 3, 65, 
    8, 44, 1, 20, 0, 56, 3, 73, 7, 43, 5, 56, 6, 22, 4, 76, 2, 31, 
    1, 60, 7, 87, 5, 56, 0, 74, 2, 83, 6, 51, 8, 32, 4, 86, 3, 19, 
    6, 37, 4, 10, 8, 47, 7,  9, 0, 18, 3, 52, 1, 96, 2, 81, 5,  6, 
    2, 68, 7, 86, 4, 98, 8, 51, 3, 34, 6, 56, 5, 59, 0, 14, 1, 82
  };
  const int q0465[] = {
    9, 9, // Number of jobs and machines
    1,  6, 4, 10, 5, 85, 8, 24, 3, 88, 6,  9, 0, 41, 7, 51, 2, 17, 
    3, 30, 2, 30, 4, 89, 1, 14, 5, 38, 7, 86, 8, 43, 0, 95, 6,  5, 
    1, 77, 6, 72, 8, 30, 7, 98, 2, 49, 5,  2, 3, 27, 4, 89, 0, 79, 
    6, 88, 5, 56, 0,  3, 1, 37, 8, 56, 3, 60, 2, 51, 4, 66, 7, 31, 
    3, 62, 8,  2, 0, 31, 4, 38, 5, 77, 6, 80, 1, 80, 2, 84, 7, 81, 
    5, 53, 7, 25, 0, 70, 2, 44, 4, 52, 1,  6, 3, 79, 8, 58, 6,  3, 
    7, 10, 5, 36, 2, 15, 0, 44, 6, 91, 8, 12, 3, 18, 1, 83, 4, 39, 
    2, 80, 5, 45, 4, 71, 0, 53, 8, 34, 1, 11, 6,  5, 7, 52, 3, 97, 
    8, 73, 2, 90, 1, 19, 0, 49, 6, 19, 5, 10, 3, 55, 7, 64, 4, 76
  };
  const int q0466[] = {
    9, 9, // Number of jobs and machines
    2, 78, 4, 89, 1, 39, 7, 74, 6, 37, 3, 19, 8, 76, 0, 44, 5, 94, 
    6, 27, 1, 81, 0, 31, 8, 90, 2, 75, 4,  9, 5, 64, 3,  5, 7, 41, 
    1, 44, 4, 34, 5, 73, 6,  4, 8, 62, 2, 41, 3, 99, 7, 37, 0, 46, 
    1, 43, 8, 72, 4, 82, 7, 16, 2, 29, 5, 74, 0, 35, 3, 13, 6,  4, 
    0, 76, 4, 11, 2, 83, 5, 94, 6,  1, 1, 36, 8, 44, 7, 41, 3, 47, 
    4, 90, 5, 14, 2, 90, 1, 75, 8, 42, 6, 29, 3, 17, 7, 24, 0, 89, 
    3, 79, 5, 39, 2, 64, 0, 25, 1,  2, 4, 48, 7,  7, 6, 12, 8, 87, 
    6, 37, 8, 20, 7, 82, 1, 46, 2, 56, 5, 14, 3, 41, 4, 85, 0, 39, 
    7, 94, 8, 84, 1, 58, 4, 23, 5, 94, 3,  8, 2, 28, 0, 21, 6, 37
  };
  const int q0467[] = {
    9, 9, // Number of jobs and machines
    7, 81, 5, 29, 4, 21, 8, 36, 0, 26, 2, 54, 6, 52, 3, 35, 1, 65, 
    0,  1, 6, 83, 5, 68, 1, 42, 4, 29, 2, 95, 3, 16, 7, 49, 8, 64, 
    0, 31, 6,  4, 7, 20, 1,  2, 2, 70, 5, 46, 8, 80, 4, 45, 3, 54, 
    8, 67, 2, 81, 0, 87, 1, 98, 3, 43, 5,  7, 6, 86, 7, 86, 4, 98, 
    0, 52, 2, 47, 7,  3, 8, 65, 4, 93, 5, 21, 6, 63, 3, 92, 1, 94, 
    7, 30, 5,  6, 6, 19, 0, 52, 8, 17, 4, 35, 3, 89, 1, 33, 2, 43, 
    7, 98, 2, 75, 0, 21, 4, 92, 1, 69, 5,  8, 8, 66, 3, 46, 6, 21, 
    8,  1, 4, 85, 3, 50, 7, 64, 1, 60, 0, 87, 5, 30, 2, 74, 6, 57, 
    2,  3, 3, 77, 0, 24, 6, 19, 4,  1, 1, 86, 7, 10, 8, 30, 5, 78
  };
  const int q0468[] = {
    9, 9, // Number of jobs and machines
    1, 51, 2, 40, 6, 98, 8, 39, 7, 74, 4, 61, 5, 68, 3, 13, 0, 42, 
    2, 70, 3, 47, 6, 56, 1, 85, 8, 69, 0,  5, 5, 78, 7, 64, 4, 39, 
    5, 17, 8, 46, 4, 36, 7, 76, 0, 18, 6, 77, 1, 97, 2, 49, 3, 93, 
    8, 27, 1,  6, 4, 83, 0, 43, 6, 86, 2, 90, 3, 62, 7, 78, 5, 60, 
    8, 76, 0, 27, 7, 78, 1, 78, 2, 52, 4, 73, 6, 85, 3,  5, 5, 82, 
    4,  3, 1, 43, 7, 86, 2, 83, 3,  7, 5,  9, 6, 18, 8, 44, 0, 19, 
    4, 65, 2, 73, 8, 37, 1,  4, 5, 21, 6, 59, 0,  2, 3, 87, 7, 89, 
    8, 88, 5, 65, 7,  8, 1, 28, 4, 50, 3, 93, 0, 18, 6, 36, 2,  1, 
    1, 38, 7,  6, 4, 78, 2, 36, 6, 81, 8, 25, 5, 28, 3, 88, 0, 87
  };
  const int q0469[] = {
    9, 9, // Number of jobs and machines
    8, 23, 4, 52, 6, 36, 5, 72, 3, 18, 2,  1, 0, 81, 7, 15, 1, 40, 
    4, 66, 7, 52, 3, 30, 0, 99, 8, 90, 2, 25, 6, 14, 5, 64, 1, 73, 
    5, 66, 2, 32, 4, 46, 7, 62, 1, 57, 8, 38, 6, 84, 3, 17, 0, 66, 
    2, 59, 5, 37, 4, 83, 3, 10, 7, 43, 0,  3, 8, 41, 1, 44, 6, 87, 
    0, 23, 1, 77, 6, 95, 5, 24, 2, 11, 4, 72, 7,  4, 8, 70, 3, 82, 
    3, 36, 7, 40, 5, 40, 2, 33, 4, 68, 6, 73, 0, 42, 8, 62, 1, 13, 
    2,  8, 3, 60, 1,  5, 5, 63, 7, 86, 0, 53, 6, 41, 8, 68, 4, 93, 
    1, 71, 0, 79, 6, 36, 8, 43, 5,  2, 7, 84, 3, 81, 2, 74, 4, 68, 
    0, 41, 4, 40, 7, 71, 2, 86, 6, 24, 8, 82, 1,  5, 3, 76, 5, 76
  };
  const int q0470[] = {
    9, 9, // Number of jobs and machines
    5, 48, 0, 91, 3, 93, 2,  6, 7, 12, 6, 79, 1,  8, 4, 39, 8, 31, 
    5, 95, 3, 29, 4, 95, 2, 30, 7, 82, 1, 76, 6, 81, 8,  4, 0, 16, 
    4, 68, 3, 37, 8, 24, 1, 48, 2, 41, 5, 38, 0, 10, 6,  9, 7, 75, 
    8,  6, 6, 34, 3, 99, 5, 64, 2, 86, 4, 62, 7, 95, 1, 52, 0, 63, 
    5, 54, 1, 91, 2, 76, 6, 62, 3, 83, 4, 80, 8, 64, 0, 11, 7, 86, 
    2, 97, 6, 76, 1, 53, 0,  4, 7, 83, 8,  5, 5, 40, 4, 85, 3,  6, 
    2,  5, 5, 12, 4, 22, 3, 52, 0, 96, 7, 59, 6, 27, 8, 34, 1, 56, 
    0, 21, 7, 28, 5, 28, 2, 68, 6, 97, 1, 48, 4, 71, 3, 40, 8, 59, 
    6, 40, 1, 62, 4, 42, 5, 90, 0, 11, 3, 10, 2, 72, 8, 72, 7, 80
  };
  const int q0471[] = {
    9, 9, // Number of jobs and machines
    8, 39, 3, 66, 5, 26, 2, 91, 1, 98, 0, 14, 7, 37, 4, 70, 6,  7, 
    3, 86, 8,  8, 7, 41, 6, 11, 2, 78, 1,  4, 4,  9, 5, 94, 0, 75, 
    0, 40, 1, 21, 6,  4, 5, 76, 2, 64, 8, 64, 3, 32, 7,  9, 4, 33, 
    0, 86, 7, 75, 1, 94, 8, 31, 2, 58, 5, 30, 4, 75, 3, 78, 6,  5, 
    1, 33, 2, 62, 4, 45, 6, 20, 8, 71, 3, 61, 5, 58, 0, 38, 7, 85, 
    7, 65, 4, 24, 8, 37, 5, 79, 3, 83, 6, 59, 2, 61, 0, 66, 1, 22, 
    6, 92, 0, 79, 8, 51, 4, 96, 5, 10, 7, 36, 3, 52, 2, 97, 1, 91, 
    4, 61, 1, 18, 7, 32, 0, 47, 3, 13, 6, 39, 5,  4, 2, 37, 8, 60, 
    3, 13, 5, 64, 7, 18, 4, 80, 8, 81, 0, 84, 2, 10, 1, 39, 6, 27
  };
  const int q0472[] = {
    9, 9, // Number of jobs and machines
    4, 70, 6, 25, 1, 88, 3, 68, 0, 39, 5, 20, 7, 87, 8, 99, 2, 91, 
    6, 96, 1, 78, 4, 17, 3,  5, 7, 44, 8, 31, 2,  7, 0, 10, 5, 41, 
    6, 58, 0, 78, 5, 17, 1, 28, 4, 60, 8, 31, 2, 14, 7, 27, 3,  6, 
    6, 93, 0, 99, 1, 74, 8, 87, 5, 76, 7, 39, 4, 75, 3, 43, 2,  1, 
    2, 36, 7, 95, 0, 36, 1, 18, 4, 42, 5, 15, 8, 86, 6,  4, 3, 27, 
    1, 10, 7, 77, 0, 47, 3, 20, 6, 67, 4,  8, 2, 17, 5, 69, 8, 93, 
    8, 49, 3, 97, 7, 39, 1, 15, 6, 49, 0, 80, 4, 57, 2, 68, 5, 56, 
    7, 13, 0, 98, 3, 93, 2, 72, 6, 36, 1, 84, 8, 72, 5, 81, 4, 53, 
    4, 25, 0,  2, 5, 15, 6, 51, 8, 36, 1, 55, 3, 23, 7, 62, 2, 95
  };
  const int q0473[] = {
    9, 9, // Number of jobs and machines
    2,  9, 8,  9, 5, 68, 0, 66, 4, 10, 6, 74, 3, 52, 7, 15, 1,  8, 
    4, 82, 3, 34, 0, 55, 1, 21, 7, 83, 2, 27, 5, 57, 8, 83, 6, 49, 
    1, 84, 7, 24, 3, 76, 0, 56, 8,  5, 6, 26, 5, 80, 2,  4, 4, 56, 
    1, 17, 2,  2, 3, 44, 0, 65, 4, 57, 6, 42, 8, 47, 5, 64, 7, 13, 
    2, 31, 6, 49, 7, 66, 3, 90, 5, 67, 8, 92, 4, 77, 0, 83, 1, 95, 
    4, 40, 7, 93, 5, 98, 1, 18, 8, 27, 0, 61, 6,  2, 3, 26, 2,  2, 
    3, 76, 0, 85, 8, 99, 5, 86, 4, 82, 1, 93, 6, 27, 7, 37, 2, 88, 
    6, 16, 3, 83, 2, 49, 8, 73, 5, 21, 7, 17, 1, 54, 4, 47, 0, 96, 
    2, 70, 7, 78, 6, 52, 3, 35, 5, 91, 4, 74, 0, 68, 1, 74, 8, 23
  };
  const int q0474[] = {
    9, 9, // Number of jobs and machines
    1, 96, 8, 48, 6, 16, 7, 14, 0, 50, 4, 96, 3, 14, 2, 12, 5,  2, 
    7, 56, 1,  8, 6, 44, 5, 99, 4, 28, 8, 77, 0, 70, 2, 59, 3, 68, 
    3, 72, 4, 15, 7, 18, 8, 28, 1, 24, 2, 74, 6, 55, 0, 45, 5,  6, 
    3, 14, 8,  1, 0, 25, 2, 58, 4, 25, 6, 67, 5, 23, 7, 48, 1, 97, 
    6, 13, 4, 45, 0, 12, 2, 75, 8, 58, 5, 69, 3, 59, 1, 94, 7, 31, 
    4, 20, 1, 36, 0, 98, 5, 44, 3, 28, 7, 16, 2, 53, 6, 25, 8, 12, 
    5, 31, 1, 22, 3, 54, 4, 99, 2, 65, 8,  3, 0, 22, 7, 25, 6, 48, 
    3,  5, 7, 74, 1, 98, 4, 27, 2, 72, 5, 92, 8, 80, 6, 92, 0, 86, 
    4, 88, 7, 13, 8, 48, 2, 41, 3, 48, 1, 50, 5, 24, 6, 33, 0, 26
  };
  const int q0475[] = {
    9, 9, // Number of jobs and machines
    1,  2, 8,  3, 2, 80, 3, 87, 6, 54, 0, 48, 4, 96, 5, 62, 7, 59, 
    8, 37, 4, 16, 2, 16, 3, 46, 6, 19, 0, 26, 5, 10, 1, 90, 7, 97, 
    6, 13, 4, 38, 0, 87, 8, 34, 7, 63, 5, 22, 1, 16, 2, 81, 3, 53, 
    7, 61, 0, 16, 2, 66, 6,  4, 8,  9, 1, 95, 3, 61, 4, 39, 5, 27, 
    8, 83, 4, 17, 2, 59, 7, 99, 0, 33, 6, 17, 5, 69, 3, 73, 1, 16, 
    5, 32, 2, 57, 4, 88, 8, 52, 0, 97, 6, 82, 1, 23, 3, 67, 7, 33, 
    2, 83, 0, 98, 5,  4, 1, 72, 8, 38, 6, 73, 4, 89, 3, 60, 7, 37, 
    7, 98, 6, 35, 1, 99, 8, 79, 4, 60, 0, 42, 5, 87, 3, 17, 2, 26, 
    2, 27, 3, 10, 1, 42, 8, 17, 6, 24, 0, 41, 7, 46, 5, 72, 4, 69
  };
  const int q0476[] = {
    9, 9, // Number of jobs and machines
    7, 83, 5, 23, 2, 98, 6, 72, 3, 38, 8, 21, 0, 83, 4,  9, 1, 28, 
    0, 24, 6, 91, 5, 51, 1, 62, 2, 94, 8,  3, 4, 21, 7, 90, 3, 39, 
    1, 75, 2, 17, 8, 63, 0, 76, 6, 13, 5, 73, 7, 24, 4, 57, 3, 70, 
    5, 22, 7, 92, 6, 14, 2, 18, 8, 23, 1, 41, 0, 96, 3, 31, 4, 26, 
    1, 33, 3, 60, 8, 34, 6, 91, 7, 29, 0, 45, 5, 47, 4, 85, 2, 19, 
    4, 29, 3, 28, 6, 37, 7, 87, 2, 13, 0, 98, 5, 48, 1, 88, 8, 18, 
    5,  7, 6, 95, 4, 82, 0, 15, 2, 81, 1, 48, 8, 74, 7, 37, 3, 68, 
    8, 66, 6, 14, 2, 31, 4, 28, 3, 28, 5, 90, 0, 96, 1, 12, 7, 87, 
    8, 60, 0,  8, 4, 90, 7, 53, 1, 62, 3, 79, 6, 93, 2, 60, 5, 66
  };
  const int q0477[] = {
    9, 9, // Number of jobs and machines
    1, 85, 6, 65, 0, 18, 3, 51, 2, 54, 5, 35, 4,  8, 8, 74, 7, 62, 
    1, 70, 5, 41, 2, 39, 3, 70, 4, 19, 7, 49, 8, 85, 0, 73, 6, 52, 
    0, 84, 1, 14, 2, 22, 7, 25, 5, 70, 4, 73, 3, 12, 8, 70, 6, 53, 
    3, 63, 6, 47, 8, 15, 0, 24, 4, 34, 1,  4, 7, 38, 5, 44, 2, 46, 
    0,  1, 2,  4, 1, 52, 8,  7, 5, 18, 3, 90, 4, 68, 7, 93, 6, 75, 
    7, 43, 1, 79, 8, 41, 5,  2, 4, 93, 6, 99, 0, 89, 3, 44, 2, 10, 
    8, 49, 2, 95, 5, 90, 1,  4, 4, 20, 6, 91, 0, 64, 3, 42, 7, 53, 
    5, 26, 4, 13, 0, 13, 2, 21, 3,  5, 1, 74, 6, 21, 7, 35, 8, 73, 
    8, 51, 7, 33, 0, 53, 1, 40, 2, 68, 3, 77, 6, 76, 5,  3, 4,  7
  };
  const int q0478[] = {
    9, 9, // Number of jobs and machines
    5, 92, 1, 53, 0, 15, 7, 17, 3, 55, 2, 86, 6,  3, 8, 33, 4, 65, 
    6, 12, 4, 92, 7,  7, 8, 89, 5, 48, 1, 71, 0, 43, 2, 68, 3, 47, 
    0, 58, 2, 97, 8, 26, 4, 57, 3, 69, 5, 91, 1, 55, 6, 91, 7, 56, 
    3, 17, 0, 45, 8, 21, 2,  2, 6, 30, 1,  6, 7, 31, 4, 33, 5, 66, 
    1, 88, 7, 46, 8, 34, 6, 74, 5,  8, 0, 34, 3, 98, 4, 83, 2, 97, 
    2, 18, 5, 63, 0, 42, 8, 64, 4, 83, 6, 19, 3, 99, 1, 55, 7, 29, 
    2, 25, 6, 40, 8, 10, 3, 48, 7, 75, 0, 72, 1, 12, 4, 67, 5,  5, 
    4, 74, 0, 47, 7, 65, 1, 79, 5,  7, 6, 40, 3, 65, 2, 87, 8, 23, 
    7, 24, 6, 35, 5, 63, 2, 26, 3, 52, 0, 83, 1, 61, 4, 38, 8, 96
  };
  const int q0479[] = {
    9, 9, // Number of jobs and machines
    1, 42, 8, 73, 2, 35, 6, 73, 0, 55, 5, 11, 7, 70, 4, 94, 3, 35, 
    0, 43, 5,  6, 3, 76, 8, 26, 4, 73, 7, 93, 1, 57, 2, 98, 6, 32, 
    1, 75, 0, 51, 6,  5, 3, 41, 7, 56, 8, 64, 5, 18, 2, 30, 4, 32, 
    2, 14, 7, 40, 1, 78, 0, 75, 4, 49, 8, 13, 3, 34, 5, 84, 6,  1, 
    2, 94, 8, 62, 7, 64, 6, 61, 3, 66, 5, 83, 4, 99, 1, 73, 0, 93, 
    3, 53, 1, 45, 2, 88, 5, 48, 8, 82, 4, 86, 0, 48, 6, 11, 7, 63, 
    3, 30, 5,  8, 4, 97, 2, 94, 6, 52, 0, 79, 8, 58, 7, 66, 1, 26, 
    6, 66, 4, 94, 8, 95, 5, 96, 0, 25, 2, 74, 3, 67, 1,  5, 7, 15, 
    6, 17, 1, 29, 5, 83, 0, 50, 8, 95, 3, 49, 7, 97, 4, 76, 2, 97
  };
  const int q0480[] = {
    9, 9, // Number of jobs and machines
    3, 89, 6, 16, 0, 37, 8, 92, 2, 65, 1, 61, 7, 54, 4, 71, 5, 52, 
    2,  3, 5, 49, 8, 45, 7, 98, 6, 39, 0, 78, 4, 54, 1, 22, 3, 54, 
    4, 66, 5, 68, 7,  4, 3, 35, 8, 79, 2, 17, 1,  6, 6,  7, 0, 27, 
    6, 99, 2, 34, 3, 79, 8, 66, 7, 95, 5, 54, 4, 88, 1, 26, 0, 64, 
    1,  5, 6, 79, 5, 74, 2, 52, 0, 77, 7, 49, 4, 36, 3,  4, 8,  6, 
    1, 52, 0,  1, 3, 97, 6, 68, 2, 37, 4, 54, 8,  3, 7,  8, 5, 65, 
    8, 73, 0,  3, 5, 35, 4, 92, 3, 32, 6, 15, 1, 67, 7, 57, 2, 48, 
    7, 92, 6, 94, 4, 82, 2, 19, 1, 95, 8, 75, 0, 47, 3, 96, 5, 71, 
    8, 94, 4, 29, 2, 79, 1, 84, 0, 95, 6, 89, 3, 71, 5, 50, 7, 94
  };
  const int q0481[] = {
    9, 9, // Number of jobs and machines
    4, 91, 1,  4, 3, 56, 6, 83, 5, 40, 7, 66, 2, 73, 8,  7, 0, 65, 
    3, 23, 7, 34, 8, 27, 2, 33, 6, 62, 0, 27, 5, 10, 1,  6, 4, 93, 
    7, 47, 0, 75, 2, 20, 4, 11, 1, 91, 3, 50, 8, 41, 6, 43, 5, 69, 
    5, 51, 4,  8, 0,  6, 6, 17, 1, 22, 7, 60, 8, 18, 2, 45, 3, 47, 
    1, 80, 6, 85, 2, 56, 7, 96, 0, 17, 3, 77, 5,  3, 4, 13, 8, 26, 
    8, 59, 0, 41, 1, 88, 7, 54, 5, 76, 2, 48, 6, 81, 3, 71, 4, 58, 
    3, 56, 4, 93, 1, 99, 7, 46, 5, 40, 8, 50, 0, 88, 6, 15, 2, 55, 
    7, 51, 1, 60, 8, 57, 6,  7, 3,  5, 0, 60, 2, 35, 5, 66, 4, 14, 
    2, 26, 0, 53, 1, 17, 7,  7, 8, 39, 3, 85, 6, 20, 5, 30, 4, 46
  };
  const int q0482[] = {
    9, 9, // Number of jobs and machines
    2, 52, 4, 77, 6, 73, 8, 53, 3,  4, 7, 49, 5, 39, 1, 17, 0, 16, 
    2, 30, 7, 67, 3, 10, 5, 75, 0, 59, 8,  3, 4, 95, 1, 49, 6, 83, 
    4,  8, 3,  7, 2, 27, 5, 44, 0, 15, 1, 77, 6, 26, 7, 90, 8, 82, 
    8, 85, 2, 26, 6, 94, 4, 20, 0, 32, 7, 79, 5, 88, 3,  2, 1, 38, 
    1, 89, 0, 38, 3, 40, 6, 89, 7, 57, 4, 97, 5, 69, 8, 43, 2, 59, 
    2, 36, 6,  5, 5, 69, 0, 30, 8, 75, 4, 89, 7, 29, 3, 87, 1, 83, 
    5, 47, 6, 24, 2, 26, 7, 84, 1,  9, 0, 14, 3, 45, 4, 70, 8, 54, 
    7, 72, 1, 82, 5, 57, 6, 40, 8,  3, 2, 35, 3, 39, 4, 70, 0, 43, 
    6, 77, 2, 81, 1, 29, 8, 34, 5, 33, 4, 38, 0, 56, 3, 93, 7, 51
  };
  const int q0483[] = {
    9, 9, // Number of jobs and machines
    1, 42, 0, 23, 8, 17, 3, 30, 2, 91, 5,  1, 7, 55, 4, 21, 6, 68, 
    1, 18, 3, 37, 0, 27, 2,  3, 7, 95, 6, 99, 5, 59, 4, 22, 8, 16, 
    5, 29, 4, 52, 7, 18, 1, 14, 3, 77, 6, 87, 8, 86, 2, 10, 0, 80, 
    4, 24, 8, 67, 1,  2, 3, 35, 0, 85, 7, 52, 5, 19, 6,  5, 2, 56, 
    6, 87, 1, 50, 4, 69, 8, 85, 0, 99, 5, 13, 7, 92, 3,  6, 2, 76, 
    1, 20, 8, 82, 5,  2, 0, 66, 6, 22, 2, 16, 4, 93, 7, 56, 3,  6, 
    8, 35, 7, 34, 0, 85, 4, 42, 2, 99, 3, 20, 6, 56, 5, 18, 1, 51, 
    1, 50, 3, 27, 6, 43, 8,  4, 5, 73, 4, 79, 2, 82, 0, 59, 7, 84, 
    5, 79, 0, 54, 4, 95, 8, 45, 7, 87, 6, 34, 1, 60, 3, 88, 2, 59
  };
  const int q0484[] = {
    9, 9, // Number of jobs and machines
    3, 81, 0,  8, 6, 35, 5, 16, 2, 52, 8,  3, 7, 63, 1, 37, 4,  7, 
    1, 33, 5, 69, 0, 95, 6, 34, 3, 96, 8, 24, 7, 56, 2, 59, 4, 17, 
    0, 48, 1, 26, 6, 75, 2, 13, 8,  8, 3, 90, 7, 96, 5, 54, 4, 82, 
    6,  4, 0, 52, 1, 87, 7, 25, 2, 18, 3,  8, 5, 99, 4,  3, 8, 50, 
    3, 47, 6, 64, 7, 81, 8, 41, 2, 75, 4, 32, 0, 50, 5, 69, 1, 61, 
    0, 71, 1, 56, 6, 35, 8, 74, 4, 44, 3, 89, 7, 95, 5, 61, 2, 27, 
    0, 10, 4, 65, 1, 48, 5, 88, 8, 91, 2, 48, 3, 71, 7, 40, 6, 27, 
    1, 95, 4, 36, 5, 46, 8, 89, 3, 88, 0, 58, 6, 87, 2, 35, 7, 39, 
    1,  7, 7, 55, 3, 41, 5,  2, 2, 39, 4, 27, 0, 55, 8, 81, 6,  2
  };
  const int q0485[] = {
    9, 9, // Number of jobs and machines
    1, 59, 8, 11, 6, 34, 3, 57, 4, 29, 0, 76, 7, 21, 2, 52, 5, 36, 
    3, 49, 2, 75, 4, 38, 8,  5, 0, 66, 7, 52, 1, 43, 6, 46, 5, 73, 
    8,  5, 3, 15, 2, 26, 4, 38, 7, 31, 5, 65, 0, 27, 6, 18, 1, 38, 
    5, 51, 7, 77, 1, 40, 4, 69, 0, 93, 8, 20, 6,  2, 3,  8, 2, 47, 
    3, 17, 2, 39, 6, 20, 8, 25, 0, 20, 7, 90, 1, 87, 4, 24, 5, 75, 
    5, 62, 8, 42, 6, 55, 2,  9, 0, 14, 4, 54, 7, 85, 1, 13, 3, 32, 
    6, 44, 0, 25, 8, 39, 5, 11, 4, 43, 1, 30, 2, 16, 3, 55, 7,  1, 
    6, 61, 5, 63, 2, 98, 0, 86, 1, 97, 3, 87, 7, 90, 8, 60, 4, 87, 
    1, 12, 3, 44, 7, 24, 4, 83, 8, 19, 5,  3, 6, 58, 0, 49, 2, 97
  };
  const int q0486[] = {
    9, 9, // Number of jobs and machines
    1, 31, 2,  3, 6, 14, 3, 64, 4,  4, 0, 84, 7, 83, 5, 51, 8, 79, 
    0,  3, 8, 11, 5, 45, 6, 70, 7, 25, 1, 38, 4, 75, 2, 97, 3, 99, 
    8,  2, 2, 50, 6, 20, 1, 68, 7, 86, 3, 38, 0, 95, 4, 71, 5, 51, 
    3, 59, 8, 49, 0, 44, 6, 22, 1, 71, 4, 11, 7, 41, 5, 44, 2, 71, 
    1, 52, 2, 29, 0, 49, 8, 79, 7,  7, 6, 45, 4, 31, 5,  6, 3, 32, 
    7, 85, 0, 44, 5, 34, 4, 43, 3, 91, 8, 83, 1,  1, 2, 37, 6, 80, 
    8,  9, 4, 39, 0, 64, 6, 76, 7, 78, 2, 16, 3,  3, 1, 30, 5, 84, 
    5, 25, 7, 89, 6, 82, 8,  9, 0, 33, 1, 15, 4, 77, 3, 41, 2, 12, 
    2, 44, 7, 23, 3, 63, 6, 36, 5, 45, 8, 14, 4, 91, 0, 27, 1, 55
  };
  const int q0487[] = {
    9, 9, // Number of jobs and machines
    8, 89, 4,  4, 7, 16, 0, 15, 1, 87, 5, 39, 2, 13, 6, 16, 3, 25, 
    1, 87, 6, 61, 7, 37, 5, 88, 0, 96, 8, 74, 4, 34, 2, 33, 3, 62, 
    0, 93, 6, 52, 3, 58, 7, 15, 5, 97, 4, 51, 1, 67, 2, 98, 8, 53, 
    7, 31, 6, 37, 3, 20, 2, 41, 0, 60, 5, 69, 4,  2, 8, 74, 1, 51, 
    2, 69, 8, 52, 5, 80, 4, 79, 0, 51, 6, 57, 1,  2, 3, 52, 7, 95, 
    2, 40, 5, 62, 6, 99, 1, 63, 8,  6, 0, 37, 7,  2, 3, 23, 4, 89, 
    6, 86, 1, 24, 8,  3, 7, 29, 2, 72, 5, 49, 3, 42, 0, 79, 4, 97, 
    1, 76, 4, 42, 6,  7, 3, 52, 8, 63, 5, 45, 7, 63, 2, 32, 0, 86, 
    6, 35, 3, 54, 2, 45, 8, 12, 1, 76, 4, 69, 5, 52, 7,  4, 0, 78
  };
  const int q0488[] = {
    9, 9, // Number of jobs and machines
    0, 23, 1,  2, 6, 73, 7, 69, 3,  6, 8, 25, 4, 66, 2, 16, 5, 92, 
    8, 76, 0, 77, 3, 34, 2, 99, 7, 10, 6, 80, 5, 31, 4, 78, 1, 18, 
    7,  4, 8, 80, 2, 63, 6, 84, 4, 83, 0, 66, 3, 68, 1, 96, 5, 20, 
    8, 85, 4, 50, 0, 65, 6, 19, 1,  4, 7,  4, 3, 24, 2, 12, 5, 97, 
    4, 10, 2, 54, 7, 39, 1,  9, 5, 30, 3, 34, 8, 85, 0, 97, 6, 56, 
    5, 44, 7, 59, 3, 89, 4, 12, 1, 77, 0, 86, 2, 23, 6, 65, 8, 22, 
    7, 42, 1, 76, 0, 60, 6, 61, 5, 37, 8, 29, 3,  5, 4, 22, 2, 59, 
    6, 43, 2, 12, 8,  4, 3, 79, 5, 33, 4, 77, 7, 57, 0, 15, 1, 36, 
    7, 83, 4, 85, 1, 35, 6, 81, 8, 75, 3, 30, 0, 35, 5, 14, 2, 63
  };
  const int q0489[] = {
    9, 9, // Number of jobs and machines
    3, 56, 2, 69, 4, 89, 8, 52, 6, 61, 5, 87, 1, 80, 0, 42, 7, 70, 
    0, 87, 2, 13, 6, 50, 5, 55, 3, 56, 8, 97, 4,  8, 1, 39, 7, 78, 
    0, 17, 3, 89, 8, 20, 6, 96, 5, 40, 4, 35, 2, 38, 1, 68, 7, 46, 
    6, 54, 7, 69, 1, 86, 3,  5, 5,  9, 0, 19, 8, 47, 4, 10, 2, 60, 
    3, 84, 2, 77, 8, 58, 5, 71, 0, 31, 7, 74, 6, 80, 1, 69, 4, 39, 
    0, 97, 3, 64, 4, 33, 6, 51, 7,  4, 2, 70, 5, 76, 8, 41, 1, 77, 
    3, 47, 1, 52, 2, 77, 0, 59, 6, 72, 4,  9, 5,  5, 8, 18, 7, 42, 
    0, 51, 3, 12, 7, 40, 8,  4, 1, 78, 2, 93, 4, 82, 5, 53, 6, 31, 
    4, 72, 6, 42, 5, 90, 0, 41, 8, 57, 7, 16, 1, 80, 2,  9, 3, 30
  };
  const int q0490[] = {
    9, 9, // Number of jobs and machines
    2, 50, 3, 97, 4, 20, 6, 19, 1, 90, 8, 97, 5, 36, 0, 32, 7, 84, 
    5, 79, 1, 60, 4, 81, 6, 13, 0,  6, 7, 55, 8, 70, 2, 23, 3, 70, 
    3, 78, 5, 83, 8,  2, 6, 50, 2, 38, 1, 19, 4, 91, 7, 13, 0, 50, 
    6, 65, 0, 15, 2, 81, 4, 93, 5, 54, 8,  9, 3, 82, 1, 10, 7, 26, 
    1,  9, 5, 30, 0,  8, 7, 18, 6,  4, 3, 12, 8, 49, 2, 54, 4, 53, 
    2, 98, 6, 89, 5, 38, 0, 90, 4, 10, 1, 69, 3, 78, 7, 64, 8, 90, 
    6, 34, 5, 41, 8, 49, 4, 48, 0, 19, 1,  5, 3, 39, 7, 74, 2, 25, 
    4, 36, 8, 45, 6, 27, 7, 13, 5, 76, 3, 90, 2, 84, 1, 62, 0,  9, 
    6, 74, 5, 11, 8, 39, 2, 71, 0, 71, 7, 23, 4, 45, 3, 37, 1, 52
  };
  const int q0491[] = {
    9, 9, // Number of jobs and machines
    0, 45, 8,  1, 1, 36, 5, 55, 4, 49, 3, 56, 7, 60, 2, 27, 6, 94, 
    5, 32, 1, 65, 4, 43, 8,  5, 3, 24, 0, 85, 7, 79, 2, 92, 6, 61, 
    0, 48, 8, 42, 6, 48, 7, 67, 1, 80, 2, 18, 3, 19, 4,  3, 5, 65, 
    7, 73, 5,  6, 8, 98, 1, 20, 4, 60, 3, 45, 2,  2, 6, 92, 0, 29, 
    0, 34, 2, 76, 6, 31, 3, 49, 7, 75, 1, 47, 5, 18, 8,  7, 4, 56, 
    3, 39, 8, 48, 2,  7, 6, 81, 7, 64, 5,  7, 0, 48, 4,  1, 1, 44, 
    6, 94, 2, 11, 4, 47, 7, 59, 1, 75, 3, 14, 5, 57, 0, 95, 8, 95, 
    5, 20, 1, 85, 6, 11, 4, 47, 0, 98, 2, 54, 3, 62, 8, 10, 7, 73, 
    8, 58, 4, 88, 1, 38, 3, 22, 6, 20, 7, 41, 5, 34, 0, 83, 2,  4
  };
  const int q0492[] = {
    9, 9, // Number of jobs and machines
    1, 70, 2, 49, 7, 52, 5, 63, 8, 58, 6, 63, 4, 97, 3, 38, 0, 19, 
    8, 53, 1, 96, 7, 47, 6,  2, 0, 28, 2, 76, 5, 31, 4, 26, 3, 13, 
    0, 24, 3, 67, 1, 89, 5, 90, 2, 14, 7, 61, 8, 28, 4, 83, 6, 67, 
    7, 21, 2, 72, 8,  2, 3, 82, 6, 42, 5, 96, 1, 94, 4, 10, 0, 87, 
    6,  9, 0, 84, 8, 84, 4, 55, 5, 21, 1, 43, 3, 12, 7, 13, 2, 53, 
    0, 58, 2, 81, 3, 23, 1, 61, 4, 56, 7, 74, 5,  5, 8, 59, 6, 65, 
    8, 53, 5,  4, 7,  3, 6, 37, 2, 69, 4,  7, 1,  1, 3, 95, 0, 20, 
    0, 61, 3, 97, 8, 26, 4, 81, 1, 48, 2, 10, 6, 85, 7, 17, 5, 69, 
    5,  6, 2, 88, 4, 73, 3, 23, 8, 67, 7, 78, 1, 79, 0, 55, 6, 57
  };
  const int q0493[] = {
    9, 9, // Number of jobs and machines
    1,  4, 4, 80, 6,  3, 3, 42, 2, 14, 7, 98, 0, 61, 8, 79, 5, 41, 
    2, 11, 0, 84, 1, 99, 7, 56, 5, 67, 8, 95, 3, 61, 6,  3, 4, 50, 
    4, 10, 7, 75, 6, 43, 3, 72, 2, 61, 1, 35, 0,  4, 5, 61, 8, 83, 
    7, 69, 8, 87, 2, 67, 1, 58, 4, 73, 0,  5, 5,  8, 3, 51, 6,  4, 
    7, 43, 5,  5, 8, 84, 3, 48, 0, 52, 4, 95, 1, 32, 6,  1, 2, 56, 
    0, 94, 3, 91, 1, 50, 4, 58, 5, 32, 6, 98, 7, 14, 8, 40, 2, 68, 
    8, 57, 1, 78, 3, 39, 6, 13, 5, 61, 4, 94, 2, 46, 0, 92, 7, 66, 
    3, 38, 5, 19, 4, 67, 0, 77, 7, 23, 1,  5, 8, 25, 6, 19, 2, 13, 
    6,  8, 0, 36, 1, 58, 8, 16, 3, 42, 2, 53, 4, 98, 7, 10, 5, 78
  };
  const int q0494[] = {
    9, 9, // Number of jobs and machines
    6, 53, 2,  5, 7,  3, 4, 75, 5,  5, 0, 72, 1, 75, 3, 93, 8, 29, 
    2, 25, 6, 61, 4, 44, 8, 85, 5, 79, 0, 86, 3, 92, 7, 69, 1, 58, 
    2, 36, 3, 58, 7, 62, 1, 60, 4, 97, 0, 57, 6, 49, 5, 78, 8,  2, 
    8, 71, 0, 44, 7, 89, 5, 26, 4, 23, 3, 69, 1, 56, 2, 79, 6, 73, 
    2, 11, 4, 47, 5, 10, 1, 89, 6, 73, 0, 15, 8, 20, 3, 71, 7, 35, 
    8, 30, 2, 68, 4, 23, 3, 38, 1, 73, 7, 39, 0, 48, 6, 62, 5, 84, 
    3, 48, 7,  2, 6, 58, 0, 96, 1, 82, 4, 42, 8, 22, 5, 41, 2, 29, 
    6,  9, 4, 74, 8, 77, 3, 47, 1, 64, 5, 77, 0, 66, 2, 65, 7,  3, 
    4, 57, 5, 55, 8, 96, 0, 92, 6, 71, 3, 94, 1, 57, 7, 11, 2, 88
  };
  const int q0495[] = {
    9, 9, // Number of jobs and machines
    4, 78, 0, 59, 3, 71, 5, 50, 2, 97, 7, 49, 8, 50, 1, 68, 6, 31, 
    4, 94, 8, 39, 2, 54, 5, 18, 1, 65, 3, 99, 0, 85, 6, 45, 7, 89, 
    5,  4, 1, 28, 6, 14, 8, 20, 7, 64, 2, 32, 3, 13, 0, 97, 4, 49, 
    7, 33, 4, 44, 6, 76, 0, 55, 2,  5, 1, 27, 3, 37, 8,  4, 5, 85, 
    6, 76, 1, 16, 7, 78, 5, 35, 4, 63, 0, 95, 3, 90, 2,  7, 8,  7, 
    0, 28, 4, 81, 2, 34, 8,  3, 6, 94, 1, 30, 3, 96, 5, 16, 7, 88, 
    8, 93, 3, 13, 1, 37, 6, 16, 0, 74, 5, 37, 7, 51, 2, 65, 4, 31, 
    8, 57, 6, 62, 5, 45, 4, 24, 3, 67, 0, 92, 7, 94, 1, 70, 2, 51, 
    8, 72, 1, 48, 3, 30, 6, 79, 4, 50, 5, 74, 2, 26, 0,  2, 7, 60
  };
  const int q0496[] = {
    9, 9, // Number of jobs and machines
    2, 46, 6, 81, 8, 11, 5, 46, 4, 36, 0, 17, 1, 70, 7, 16, 3, 29, 
    5, 90, 2, 60, 6, 76, 7, 37, 4, 33, 3, 24, 1, 50, 0, 45, 8, 18, 
    1, 66, 2, 66, 8, 60, 5, 20, 6, 54, 4,  2, 7, 23, 3, 16, 0, 40, 
    2, 27, 0, 24, 1, 10, 6, 44, 5, 53, 3, 47, 4, 98, 7, 29, 8, 60, 
    6, 26, 7, 21, 4, 59, 5, 62, 3, 74, 1, 12, 8, 10, 2, 19, 0, 27, 
    2, 29, 5, 41, 6,  1, 0, 42, 8, 93, 1, 59, 3, 42, 7, 80, 4, 71, 
    6, 77, 8, 47, 2, 75, 5, 80, 4, 56, 1, 93, 7,  4, 0,  1, 3, 43, 
    2, 74, 0,  8, 3, 82, 6, 96, 7, 21, 4, 46, 1, 68, 8, 79, 5, 39, 
    8, 10, 2, 58, 5, 33, 1, 35, 4, 68, 7, 45, 6, 92, 0, 10, 3, 97
  };
  const int q0497[] = {
    9, 9, // Number of jobs and machines
    3, 26, 5,  7, 2,  5, 6, 45, 4, 91, 8, 16, 0, 76, 7, 64, 1, 62, 
    6, 77, 3, 33, 1, 10, 4, 94, 2, 55, 5, 10, 7, 33, 0, 68, 8, 56, 
    8, 76, 6, 48, 0, 71, 2, 71, 1, 53, 3, 94, 7, 84, 4, 78, 5,  7, 
    6, 59, 1, 34, 8,  6, 2, 60, 7, 41, 5,  2, 0, 26, 3, 25, 4, 36, 
    5, 78, 8,  5, 4, 56, 6, 71, 2, 31, 7, 17, 1, 32, 0, 52, 3,  9, 
    1, 87, 7, 74, 5, 69, 8, 57, 3, 53, 0, 81, 2, 73, 6, 49, 4, 55, 
    1, 62, 8, 15, 5, 39, 3, 12, 2, 26, 0, 81, 6, 98, 7, 98, 4,  4, 
    3, 15, 5, 72, 7, 45, 6, 20, 4, 73, 8, 54, 0,  6, 2, 37, 1, 50, 
    5,  2, 0, 87, 6, 75, 1, 69, 2, 50, 7, 30, 4, 76, 3, 38, 8, 40
  };
  const int q0498[] = {
    9, 9, // Number of jobs and machines
    2, 57, 0, 95, 5, 30, 1, 85, 3, 72, 7, 50, 4, 88, 8, 82, 6,  4, 
    3, 21, 8, 76, 2, 25, 1, 40, 5, 10, 4,  1, 7, 65, 0, 26, 6, 68, 
    7, 47, 5, 15, 0, 61, 6, 36, 3, 15, 4, 73, 2, 31, 1, 35, 8,  1, 
    8, 15, 4, 39, 2, 78, 1, 43, 5, 25, 3, 26, 6, 76, 7, 85, 0, 46, 
    0, 83, 2, 28, 1, 69, 4, 85, 5, 65, 6, 52, 7,  3, 8, 99, 3, 96, 
    6, 71, 8, 33, 7, 98, 2, 69, 0, 21, 5, 73, 1,  9, 3, 83, 4, 93, 
    3, 51, 2, 13, 7, 83, 5,  5, 6,  6, 8, 14, 0, 71, 4,  7, 1, 73, 
    0, 42, 3, 32, 2, 99, 5, 53, 7, 54, 1,  2, 6, 51, 8, 33, 4, 12, 
    0, 40, 4, 30, 2, 91, 3, 44, 8, 93, 1, 54, 5, 29, 7,  1, 6, 85
  };
  const int q0499[] = {
    9, 9, // Number of jobs and machines
    1, 42, 8, 11, 7, 26, 5, 71, 3, 37, 6, 14, 2, 58, 0, 69, 4, 66, 
    4, 17, 8, 33, 0,  5, 1,  7, 3, 20, 5, 41, 7, 89, 6, 28, 2, 24, 
    6, 28, 8, 76, 5, 38, 4, 54, 7, 11, 2, 28, 0, 93, 1, 95, 3, 12, 
    3, 16, 6, 45, 7, 70, 4, 51, 2, 43, 8, 42, 5, 24, 0, 17, 1,  3, 
    5, 24, 6, 93, 7, 19, 2,  5, 8, 86, 3, 41, 0, 42, 4, 17, 1, 54, 
    8, 64, 0, 56, 2, 36, 5, 32, 1, 10, 7, 74, 6, 95, 4, 54, 3, 44, 
    4, 35, 5, 71, 6, 38, 0, 10, 7, 43, 8,  6, 1, 72, 3, 22, 2, 14, 
    7, 74, 5,  3, 8,  3, 0, 18, 4, 84, 3, 24, 6, 19, 2, 48, 1,  3, 
    6, 90, 4, 54, 8, 59, 1, 19, 0, 43, 3, 82, 2, 16, 7, 72, 5, 50
  };
  const int q0500[] = {
    9, 9, // Number of jobs and machines
    6, 71, 5, 42, 1, 58, 4, 21, 0, 28, 3, 32, 8, 15, 2, 94, 7, 13, 
    2, 15, 3, 15, 1, 84, 8, 10, 7,  9, 6, 63, 5, 21, 0, 35, 4, 59, 
    2, 50, 1, 88, 8, 90, 6, 89, 0, 37, 3, 10, 7, 70, 5, 49, 4,  1, 
    0, 96, 5, 68, 2, 11, 4, 24, 6, 62, 7, 56, 1, 81, 8,  7, 3, 47, 
    0, 11, 6, 87, 7, 69, 4, 34, 1, 88, 3, 58, 5,  9, 2, 71, 8, 40, 
    8, 99, 6, 19, 4, 67, 1, 20, 3, 81, 5, 36, 2, 57, 0, 33, 7, 50, 
    5, 80, 0, 88, 7, 27, 4, 16, 6, 97, 2, 55, 1, 72, 3, 63, 8, 52, 
    1, 46, 4, 27, 5, 76, 8, 52, 3,  4, 2, 25, 7, 16, 0, 67, 6, 92, 
    5, 23, 2,  4, 0, 82, 3, 69, 1, 58, 8, 30, 7, 70, 6, 38, 4, 24
  };
  const int q0501[] = {
    9, 9, // Number of jobs and machines
    6,  7, 3, 28, 7, 85, 2, 18, 4, 26, 8, 92, 5, 77, 1, 38, 0, 56, 
    2, 20, 0,  5, 7, 82, 3, 53, 4,  9, 5, 40, 6, 51, 1,  8, 8, 26, 
    3, 82, 5, 42, 4, 10, 6, 16, 7,  9, 8, 80, 1, 46, 2, 64, 0, 84, 
    2, 39, 6, 79, 4, 27, 8,  3, 5, 54, 1, 71, 7,  7, 0,  9, 3, 84, 
    4, 34, 8, 48, 5, 24, 6,  6, 7, 33, 3, 98, 0, 84, 1, 52, 2, 66, 
    6, 73, 2, 59, 4, 70, 7, 48, 8, 54, 0, 92, 3, 87, 1, 42, 5, 23, 
    0, 42, 5, 81, 6, 39, 1, 81, 2, 92, 8, 45, 3, 38, 4, 15, 7, 80, 
    4, 75, 1, 93, 8, 46, 6, 96, 7, 84, 3, 11, 5, 36, 2, 75, 0, 25, 
    3, 63, 0, 67, 1, 33, 7, 64, 4, 69, 6, 88, 2, 10, 5, 73, 8, 52
  };
  const int q0502[] = {
    9, 9, // Number of jobs and machines
    2, 33, 4, 97, 0, 65, 1, 23, 8, 63, 7, 73, 6, 35, 5,  9, 3,  4, 
    1, 88, 6, 99, 3, 16, 4, 85, 2, 56, 7, 87, 5, 89, 8, 59, 0, 39, 
    6, 44, 7, 11, 4, 83, 2, 67, 3, 43, 8, 64, 5, 97, 1, 30, 0, 87, 
    7, 74, 1, 68, 2, 71, 6, 11, 5,  6, 4, 51, 8, 64, 0, 85, 3, 49, 
    3, 33, 1, 71, 7, 18, 6,  6, 0, 96, 4, 83, 5, 39, 2, 39, 8, 60, 
    6, 82, 1, 73, 8, 81, 5, 77, 0, 82, 2, 76, 4, 93, 3, 81, 7, 26, 
    8, 72, 2, 42, 5, 24, 3, 28, 6, 97, 7, 28, 1, 49, 0, 35, 4, 92, 
    8,  3, 6, 79, 3, 30, 5, 45, 7, 78, 4, 23, 1, 40, 0, 83, 2, 90, 
    5,  3, 0, 58, 2, 78, 4, 11, 1, 32, 8, 41, 6, 43, 3, 98, 7, 88
  };
  const int q0503[] = {
    9, 9, // Number of jobs and machines
    1, 69, 4, 33, 2, 32, 6,  5, 0, 96, 8, 48, 7,  4, 3, 57, 5, 52, 
    2, 12, 7, 64, 6, 66, 1, 27, 5, 60, 4, 63, 8, 85, 3, 32, 0,  7, 
    8,  8, 0, 20, 7, 90, 3, 51, 1, 89, 5, 16, 6, 34, 4, 10, 2, 25, 
    4, 45, 0, 50, 5, 30, 7, 91, 1, 46, 8, 83, 3, 41, 2, 46, 6,  8, 
    7, 99, 2, 79, 5,  3, 4, 33, 6, 17, 0, 32, 3, 20, 1, 78, 8, 69, 
    8, 98, 2, 19, 7, 10, 6, 41, 5, 27, 1, 27, 4, 47, 0, 25, 3, 72, 
    7, 51, 0, 17, 4, 44, 6, 59, 3, 90, 2, 68, 1,  7, 8, 52, 5, 99, 
    7, 12, 0, 31, 1, 35, 3, 28, 6, 95, 8, 81, 4, 91, 5, 32, 2, 64, 
    4,  7, 6, 31, 0, 46, 8, 86, 1, 39, 5, 16, 2, 63, 7, 65, 3, 19
  };
  const int q0504[] = {
    9, 9, // Number of jobs and machines
    7, 37, 4, 89, 5, 20, 0, 87, 8, 61, 3, 10, 6, 45, 2, 88, 1, 25, 
    3, 98, 0,  8, 8, 71, 4,  5, 6, 56, 5, 21, 7, 90, 2, 63, 1, 15, 
    8, 80, 6, 47, 5, 83, 3, 15, 4, 40, 7, 67, 1,  7, 2, 33, 0, 69, 
    4, 62, 5, 65, 6, 45, 7, 39, 3, 40, 8, 49, 2, 80, 0, 84, 1, 99, 
    1, 75, 6, 56, 0, 92, 4, 10, 5, 47, 3, 74, 7, 36, 8,  9, 2, 11, 
    1, 48, 7, 48, 4, 89, 5, 13, 2,  9, 0, 28, 8, 67, 3, 26, 6, 84, 
    4, 88, 6, 57, 0, 18, 2, 22, 5, 39, 7, 96, 3, 25, 1, 83, 8, 99, 
    2, 76, 5, 70, 7, 50, 0, 19, 1, 35, 8, 48, 4, 42, 3,  8, 6, 48, 
    2, 75, 6, 96, 0, 84, 8, 20, 1, 78, 3,  4, 4, 85, 7, 33, 5, 33
  };
  const int q0505[] = {
    9, 9, // Number of jobs and machines
    3, 67, 1, 45, 4, 96, 7, 86, 6, 10, 2,  5, 8, 94, 0, 54, 5, 69, 
    5, 18, 6, 74, 2, 13, 4, 41, 7, 99, 1, 48, 0, 73, 8, 40, 3, 74, 
    7, 55, 0, 77, 1, 47, 8, 33, 2, 83, 6, 86, 3, 40, 4,  8, 5,  6, 
    5, 11, 0, 95, 6, 13, 2, 38, 4, 87, 1, 32, 7, 29, 3, 62, 8,  8, 
    2,  2, 5,  6, 6, 20, 3, 21, 4, 87, 1,  9, 0, 13, 7, 28, 8, 14, 
    2, 47, 0, 90, 7, 39, 6,  1, 8, 52, 4, 52, 5, 65, 1, 29, 3, 71, 
    7,  6, 6, 63, 4, 96, 5, 10, 0, 37, 2, 65, 8, 23, 1, 48, 3, 21, 
    0,  2, 3, 56, 4, 35, 2, 80, 1, 21, 5, 73, 8, 64, 6, 39, 7, 37, 
    4, 64, 3, 59, 1,  2, 0, 11, 6, 85, 7, 34, 2, 52, 5, 38, 8, 89
  };
  const int q0506[] = {
    9, 9, // Number of jobs and machines
    5, 12, 4, 29, 8, 52, 6, 53, 7, 20, 3, 88, 0, 53, 2,  5, 1, 60, 
    6, 22, 1, 52, 8, 25, 7, 70, 4, 20, 3, 87, 5, 92, 0, 38, 2, 95, 
    5, 90, 8, 94, 4, 43, 2, 75, 1, 58, 6, 89, 3, 87, 7, 80, 0,  7, 
    1, 82, 5, 98, 6, 48, 8, 27, 0,  7, 4, 68, 3, 65, 2, 97, 7, 44, 
    7, 29, 3, 64, 2, 14, 8, 36, 1, 35, 4, 57, 5, 66, 0, 35, 6,  4, 
    4, 28, 1, 49, 2, 50, 0, 95, 5, 77, 6,  1, 8, 48, 7, 76, 3,  8, 
    6, 47, 8, 26, 1, 56, 5, 10, 7, 65, 4,  9, 0, 38, 2, 65, 3, 17, 
    4, 42, 5,  4, 0, 19, 8, 47, 1, 83, 3, 69, 7, 61, 6, 74, 2, 22, 
    2, 30, 7, 65, 8, 50, 1, 39, 3, 70, 6, 85, 0, 24, 4, 44, 5, 74
  };
  const int q0507[] = {
    9, 9, // Number of jobs and machines
    0, 75, 6, 18, 4, 49, 5, 76, 3,  2, 7, 84, 1, 98, 2, 62, 8, 78, 
    3, 71, 8, 83, 4, 61, 7, 45, 2, 35, 0, 16, 6, 69, 5, 23, 1, 58, 
    2, 51, 3, 74, 7,  9, 6, 74, 0, 94, 1, 15, 4, 47, 8, 92, 5, 95, 
    4, 65, 1, 85, 5, 10, 2, 43, 6,  5, 3, 80, 7, 65, 8, 12, 0, 18, 
    0, 27, 5, 19, 6, 10, 8, 57, 2, 25, 7, 68, 4, 77, 1, 92, 3, 45, 
    1,  8, 5, 29, 2, 93, 7, 84, 4, 20, 3, 72, 6, 56, 8, 31, 0, 84, 
    0, 39, 7, 81, 2,  7, 8, 63, 3, 39, 1, 74, 5, 87, 4, 78, 6, 73, 
    3, 95, 2, 23, 0, 30, 7, 90, 6, 95, 1, 35, 4, 60, 8, 24, 5, 12, 
    1, 72, 0, 76, 5, 87, 4, 98, 8, 98, 6, 72, 7, 79, 3, 96, 2, 23
  };
  const int q0508[] = {
    9, 9, // Number of jobs and machines
    8, 95, 2, 82, 0, 48, 5, 80, 4, 78, 6, 47, 7, 24, 3, 52, 1, 51, 
    5, 86, 8, 70, 7, 49, 4, 18, 2, 62, 0, 84, 3,  5, 6, 83, 1, 52, 
    5, 64, 8, 33, 7, 44, 0, 14, 4, 25, 2, 53, 6, 65, 3, 71, 1, 49, 
    4, 58, 5, 12, 8, 29, 6, 71, 1, 52, 2, 27, 3, 97, 0,  5, 7, 81, 
    0, 31, 8, 47, 7, 12, 5, 52, 1, 29, 6, 65, 4, 44, 3,  2, 2, 68, 
    3, 74, 2, 70, 1, 84, 5, 67, 4, 34, 7,  3, 0, 63, 6,  5, 8, 64, 
    2, 34, 0, 53, 1, 32, 7, 10, 4, 53, 5, 14, 3,  9, 6, 82, 8, 46, 
    4, 20, 7, 77, 0, 20, 3, 57, 8, 60, 2, 64, 6, 33, 1,  8, 5, 48, 
    8, 97, 1,  7, 4, 49, 7, 29, 5, 43, 3, 67, 2,  3, 6, 94, 0, 12
  };
  const int q0509[] = {
    9, 9, // Number of jobs and machines
    8, 76, 0, 76, 6,  3, 1, 96, 3, 99, 5, 52, 7, 57, 2, 51, 4,  1, 
    6, 21, 5, 94, 0, 50, 8, 84, 4, 68, 2,  9, 7, 74, 1, 22, 3, 97, 
    7, 25, 2, 88, 3, 37, 6, 26, 5, 20, 8, 54, 4, 91, 1, 37, 0, 87, 
    3, 82, 6, 47, 5, 73, 2, 59, 4, 89, 0, 80, 1, 26, 7, 55, 8, 17, 
    7, 32, 5, 54, 4, 63, 6, 53, 8, 12, 3,  9, 2, 88, 0, 77, 1, 48, 
    8, 64, 5,  7, 6, 99, 7, 48, 2, 64, 1, 64, 3, 93, 4, 52, 0, 43, 
    7,  7, 4, 88, 8, 49, 2, 95, 3, 58, 6, 78, 1, 46, 5, 68, 0, 39, 
    1, 79, 8, 41, 4, 82, 0, 22, 6, 76, 3, 19, 5,  1, 7,  9, 2, 30, 
    6, 53, 8, 92, 4, 78, 5, 79, 2, 88, 1, 89, 7, 26, 0, 88, 3, 76
  };
  const int q0510[] = {
    9, 9, // Number of jobs and machines
    3, 38, 7, 68, 4, 29, 6, 51, 8, 76, 5, 25, 2, 71, 1, 90, 0, 85, 
    6, 39, 0, 77, 7, 86, 3, 25, 1, 86, 8, 14, 4, 43, 2, 80, 5, 33, 
    2, 82, 5,  7, 4, 94, 6, 40, 3, 82, 7, 74, 8, 51, 0, 57, 1, 88, 
    6, 55, 5, 59, 4, 71, 7,  2, 0,  5, 1,  2, 2, 43, 3, 28, 8, 35, 
    3, 42, 6, 82, 2, 14, 0, 33, 4, 90, 5, 83, 1, 51, 7, 48, 8, 10, 
    5, 57, 6, 62, 0, 11, 8, 45, 1, 14, 7, 14, 3,  4, 4, 84, 2, 96, 
    3, 74, 8,  7, 4,  9, 1, 85, 2,  3, 6,  4, 5, 50, 7, 57, 0, 82, 
    1, 10, 0, 13, 3,  1, 2, 66, 4, 60, 6, 45, 7, 96, 8, 60, 5, 14, 
    6, 68, 0, 34, 4, 11, 1, 46, 3, 72, 5, 60, 7,  4, 2, 84, 8, 78
  };
  const int q0511[] = {
    9, 9, // Number of jobs and machines
    3,  9, 0, 74, 5, 55, 7, 75, 6, 97, 4, 59, 8, 30, 2, 70, 1, 88, 
    3, 61, 7, 24, 6, 12, 8,  2, 1, 38, 2, 63, 4, 21, 5, 31, 0, 11, 
    8, 21, 0, 94, 6, 89, 3, 15, 2, 83, 4, 37, 7, 52, 1, 72, 5, 47, 
    2, 79, 5, 33, 7, 18, 4, 61, 0, 26, 8, 82, 1, 24, 6,  3, 3, 36, 
    8, 14, 0, 53, 4, 26, 2,  4, 7, 64, 1, 16, 3, 50, 5, 22, 6, 89, 
    6, 30, 0, 16, 3, 72, 1,  7, 4, 14, 5, 15, 2, 52, 8, 58, 7, 67, 
    4, 68, 2, 64, 0, 98, 8, 61, 1,  3, 7, 63, 6, 54, 5, 68, 3, 86, 
    2, 46, 5, 57, 3, 79, 6, 21, 7, 65, 8, 85, 0, 27, 4, 41, 1, 78, 
    8, 38, 0, 17, 2, 56, 1, 46, 7, 53, 6, 40, 3, 84, 4, 74, 5, 66
  };
  const int q0512[] = {
    9, 9, // Number of jobs and machines
    2, 47, 0, 78, 5, 31, 3, 66, 4, 82, 8, 43, 7, 73, 1, 25, 6, 26, 
    0, 21, 5, 76, 4, 88, 3,  4, 2, 17, 1, 48, 8, 18, 6, 71, 7, 16, 
    2, 33, 4, 31, 1, 54, 5, 52, 0, 40, 3, 59, 6, 76, 7, 22, 8, 71, 
    5, 27, 7, 60, 1, 12, 0, 69, 8, 79, 6,  4, 3, 49, 4, 62, 2, 57, 
    6, 45, 5, 38, 3, 86, 4, 72, 1, 88, 0, 20, 7, 19, 8, 21, 2, 64, 
    1, 60, 2, 72, 8,  8, 0, 81, 3, 24, 6, 60, 7, 78, 4, 63, 5, 24, 
    2, 53, 1, 71, 0, 72, 4, 66, 8, 66, 7, 17, 3, 37, 6, 83, 5, 95, 
    5, 99, 1,  1, 2, 38, 3, 60, 0, 47, 8, 81, 4, 89, 6, 33, 7, 93, 
    2, 53, 4, 39, 5, 49, 8, 84, 6, 62, 1, 27, 0, 82, 3, 68, 7, 52
  };
  const int q0513[] = {
    9, 9, // Number of jobs and machines
    5, 31, 6, 63, 3, 39, 0, 67, 7, 13, 2, 83, 1, 18, 8, 54, 4, 84, 
    6, 65, 5, 77, 2, 25, 0, 88, 8, 42, 3, 95, 7, 11, 1, 36, 4, 46, 
    2, 62, 5, 10, 4, 60, 8, 91, 3, 63, 6, 17, 0, 92, 1,  4, 7, 79, 
    8, 94, 3, 21, 6, 92, 1, 61, 5, 98, 7,  8, 2,  9, 0, 38, 4, 56, 
    4,  6, 3,  6, 1,  5, 6, 49, 8, 89, 5, 29, 7, 53, 2, 37, 0,  7, 
    1, 35, 3, 62, 6, 94, 8, 76, 5, 76, 7, 15, 2, 80, 0, 48, 4, 34, 
    1,  8, 6, 70, 2, 57, 5, 67, 4, 21, 3, 54, 7,  2, 8, 30, 0, 30, 
    8, 50, 1, 94, 7, 16, 0, 77, 5, 41, 6, 33, 2, 11, 3,  6, 4, 78, 
    7, 37, 2, 95, 0,  6, 8, 86, 3, 62, 6, 36, 1, 52, 4, 41, 5, 98
  };
  const int q0514[] = {
    9, 9, // Number of jobs and machines
    8, 92, 4, 18, 7, 60, 6,  2, 2, 61, 0, 17, 1, 60, 3, 70, 5, 85, 
    5, 68, 1, 41, 8, 20, 4, 43, 3, 69, 7, 33, 2, 98, 0, 53, 6, 91, 
    5, 21, 7, 92, 2, 42, 1, 32, 3,  7, 0,  5, 4, 78, 6,  1, 8, 32, 
    0, 17, 7, 85, 5, 86, 2,  9, 6, 97, 8, 40, 3, 54, 4, 29, 1, 60, 
    5, 89, 4, 90, 7, 40, 3, 76, 6, 53, 8, 60, 0, 25, 1, 51, 2, 68, 
    6, 82, 3, 72, 8, 44, 5, 12, 0, 95, 2, 91, 4, 92, 7, 68, 1, 57, 
    0, 28, 8, 88, 1, 65, 3, 34, 2, 19, 6, 92, 5,  1, 4, 58, 7, 73, 
    7,  3, 8, 50, 1, 24, 4,  1, 5, 22, 0, 96, 3, 43, 6, 76, 2, 42, 
    7, 25, 6, 37, 2, 30, 5, 73, 0, 53, 8, 44, 1, 16, 4, 80, 3, 58
  };
  const int q0515[] = {
    9, 9, // Number of jobs and machines
    1, 68, 0, 60, 2,  1, 5, 14, 8, 34, 3, 91, 4, 40, 7, 13, 6, 85, 
    5, 34, 6,  1, 2, 47, 8, 51, 7, 30, 3, 76, 1, 75, 4, 21, 0, 95, 
    4, 75, 1,  7, 8, 83, 0, 93, 3, 61, 6,  5, 7, 23, 2, 46, 5, 71, 
    0, 76, 3, 72, 5, 21, 1, 25, 2, 83, 7, 44, 8, 43, 6, 28, 4, 53, 
    8, 89, 4, 50, 7, 88, 2, 48, 6, 31, 3, 12, 0, 82, 5, 85, 1, 44, 
    3, 71, 0, 83, 8,  9, 1, 26, 2, 47, 4, 99, 6, 79, 5, 87, 7, 19, 
    5, 35, 0, 47, 4, 95, 6, 38, 7,  8, 1, 35, 2, 29, 3, 75, 8,  4, 
    4, 86, 8, 25, 2, 24, 7, 54, 0, 54, 5, 98, 1, 14, 3, 98, 6, 32, 
    6, 21, 3, 60, 1, 73, 8, 95, 0, 80, 4, 15, 5, 75, 2, 14, 7, 79
  };
  const int q0516[] = {
    9, 9, // Number of jobs and machines
    2, 72, 4, 41, 1, 10, 0, 23, 5, 32, 6, 44, 3,  4, 7, 32, 8, 95, 
    3, 36, 5, 53, 0,  3, 8, 98, 7, 80, 4, 16, 2, 63, 1, 37, 6, 35, 
    4, 44, 5, 86, 2, 75, 3,  5, 6, 63, 1,  3, 7, 70, 0,  4, 8, 20, 
    7,  2, 6, 86, 1, 78, 5, 36, 3, 90, 4, 81, 8, 79, 0, 18, 2, 89, 
    5, 77, 6, 73, 7, 35, 8, 48, 2, 81, 4, 56, 3, 21, 0, 98, 1, 72, 
    1,  1, 3, 11, 7, 79, 6, 18, 2, 34, 0, 13, 5, 22, 8,  3, 4, 14, 
    4, 27, 3, 59, 6,  6, 2, 76, 8,  3, 5, 13, 0, 75, 7, 49, 1, 91, 
    1, 20, 0, 37, 7, 67, 2, 43, 3, 17, 6,  6, 8, 72, 5, 45, 4, 84, 
    8, 19, 7, 70, 4, 72, 3, 28, 5, 48, 6, 28, 1, 65, 0, 50, 2, 45
  };
  const int q0517[] = {
    9, 9, // Number of jobs and machines
    8, 76, 6, 72, 2, 97, 4, 96, 1, 31, 5, 21, 7, 93, 0, 12, 3, 75, 
    6, 22, 0, 61, 3, 30, 5, 50, 2, 95, 4, 66, 1, 37, 8, 63, 7, 41, 
    1, 46, 5, 38, 6, 13, 8, 40, 7,  5, 0, 55, 3, 31, 2, 69, 4, 41, 
    3,  5, 5, 32, 7, 78, 4, 46, 2, 73, 1, 12, 0, 86, 8, 19, 6, 96, 
    5, 39, 4, 33, 8, 80, 6, 30, 0, 20, 7, 10, 3,  5, 2, 34, 1, 88, 
    8, 78, 7, 91, 3, 18, 2, 34, 4, 55, 1, 54, 5, 91, 6, 56, 0,  9, 
    1, 53, 3, 76, 2,  3, 7, 48, 4, 40, 5, 72, 6, 87, 8, 36, 0, 57, 
    3, 81, 2,  8, 4, 39, 5, 25, 8, 64, 1, 52, 7, 83, 6, 19, 0, 29, 
    1, 92, 5, 13, 3, 80, 8,  7, 7, 47, 6, 51, 4, 19, 0, 72, 2, 22
  };
  const int q0518[] = {
    9, 9, // Number of jobs and machines
    6, 86, 5, 40, 4, 66, 8, 58, 0, 34, 3, 60, 1, 51, 2, 47, 7, 60, 
    0, 78, 3, 68, 7, 37, 6, 55, 4, 54, 2, 89, 1, 87, 5, 71, 8, 70, 
    8, 26, 1, 12, 3, 93, 4, 46, 6, 47, 2, 22, 7, 21, 5, 64, 0, 61, 
    5, 71, 4, 92, 7, 69, 0,  8, 3, 48, 1, 68, 8, 80, 6, 49, 2, 80, 
    3, 11, 4, 27, 7, 49, 1, 66, 0, 71, 5, 75, 8, 23, 6, 65, 2, 51, 
    5, 23, 4, 66, 8, 29, 1, 31, 6, 79, 3,  6, 2, 29, 0, 39, 7, 91, 
    5, 57, 1, 11, 2, 45, 3, 26, 7, 31, 0, 56, 6, 64, 4, 35, 8,  8, 
    1, 12, 2, 81, 5, 70, 6, 95, 3, 99, 4, 61, 8, 87, 7, 43, 0,  6, 
    6, 45, 5, 57, 7,  5, 2, 74, 1, 29, 0, 34, 8, 95, 4, 79, 3, 72
  };
  const int q0519[] = {
    9, 9, // Number of jobs and machines
    0,  8, 4, 13, 7, 67, 5, 33, 1, 45, 8, 51, 3, 13, 6, 49, 2, 81, 
    3, 64, 0, 78, 1, 85, 7, 50, 2, 24, 4, 63, 5, 52, 8, 82, 6,  6, 
    1, 98, 5, 62, 8, 83, 2, 65, 0, 43, 4, 52, 3, 75, 7, 58, 6, 61, 
    8, 21, 0, 11, 6,  1, 2, 33, 3, 74, 5,  6, 1, 31, 7, 83, 4, 11, 
    8, 93, 5, 77, 4, 85, 2, 35, 7, 58, 1,  8, 6, 25, 3, 89, 0, 85, 
    7, 12, 1, 81, 8, 79, 6, 88, 4, 61, 0, 39, 2, 67, 5, 74, 3, 32, 
    2, 15, 1, 21, 5, 41, 4, 66, 0, 83, 7,  9, 3, 44, 6,  2, 8, 52, 
    4, 73, 7, 26, 3, 93, 1, 38, 5, 62, 2, 26, 6, 16, 0, 43, 8, 88, 
    3, 86, 2, 54, 7, 36, 1, 86, 6, 71, 0, 65, 8, 20, 4, 18, 5, 75
  };
  const int q0520[] = {
    9, 9, // Number of jobs and machines
    3, 94, 8, 75, 6, 31, 0, 30, 2, 81, 1, 62, 7, 34, 4, 40, 5, 96, 
    3, 10, 8, 89, 4, 99, 0, 62, 1, 76, 6, 50, 7, 90, 2, 46, 5, 82, 
    5, 44, 8,  9, 2, 32, 6, 31, 1, 38, 3, 16, 4,  8, 7, 42, 0, 76, 
    8, 78, 6, 77, 3, 73, 2, 37, 4,  6, 0,  1, 5, 45, 7, 20, 1, 74, 
    4, 38, 2, 94, 8, 53, 5, 14, 7, 38, 3, 17, 6, 42, 0, 22, 1, 16, 
    3, 57, 8, 14, 7, 71, 1, 84, 0, 23, 5,  1, 6, 73, 2,  1, 4, 84, 
    6, 40, 1, 66, 0, 50, 5, 66, 8, 82, 7, 89, 3, 23, 2, 47, 4, 17, 
    8, 51, 0, 96, 6, 48, 2, 48, 4, 28, 5, 39, 7, 79, 1, 70, 3, 20, 
    2, 22, 5,  1, 8, 24, 3, 14, 6, 76, 4, 43, 1, 19, 7, 22, 0, 15
  };
  const int q0521[] = {
    9, 9, // Number of jobs and machines
    2, 77, 4, 85, 5, 19, 3, 24, 6, 44, 8, 94, 7, 28, 0, 72, 1,  6, 
    7, 48, 5,  8, 8, 11, 4,  2, 2, 58, 3, 88, 0, 48, 6, 75, 1, 11, 
    6, 53, 5, 51, 2, 74, 7, 34, 0, 58, 1, 26, 4, 83, 3, 74, 8, 59, 
    0, 25, 7, 36, 2, 31, 1, 76, 3, 90, 5, 15, 4, 91, 8, 30, 6, 59, 
    3, 64, 5, 43, 6, 53, 4, 69, 1, 87, 8,  4, 0, 94, 2, 91, 7, 19, 
    2, 79, 4,  6, 0, 20, 6, 50, 8, 32, 5, 80, 1, 71, 3, 47, 7, 52, 
    2, 37, 6, 31, 0, 40, 8, 67, 4, 24, 7, 21, 1, 34, 3, 35, 5, 72, 
    2, 53, 8, 88, 3, 39, 4, 89, 5, 10, 0, 29, 7, 71, 6, 72, 1,  8, 
    5, 47, 4, 21, 6, 47, 0, 74, 7, 12, 3, 61, 1, 87, 2, 32, 8, 58
  };
  const int q0522[] = {
    9, 9, // Number of jobs and machines
    3, 65, 1, 47, 2, 28, 0, 16, 5, 77, 6, 43, 7, 62, 4, 79, 8, 43, 
    3,  3, 4, 19, 2, 54, 6, 89, 5, 26, 0, 94, 7, 48, 1, 79, 8, 31, 
    4, 58, 2, 76, 7, 75, 5, 58, 8,  4, 6,  4, 0,  9, 3, 81, 1, 37, 
    2, 87, 4, 71, 0, 40, 6, 69, 1,  1, 3,  7, 5, 39, 8, 34, 7, 43, 
    1, 13, 7, 25, 6, 88, 3,  5, 8, 67, 0, 82, 2, 75, 4,  8, 5, 14, 
    3, 68, 2, 32, 7, 48, 6, 12, 5, 20, 8, 86, 1, 12, 0, 73, 4, 88, 
    1, 80, 5, 22, 8, 13, 2, 43, 7, 64, 6, 40, 0, 74, 4, 20, 3, 68, 
    4, 40, 2, 51, 3, 94, 6, 47, 0, 83, 5, 48, 1, 69, 8, 64, 7, 12, 
    2, 77, 1, 44, 4, 83, 6, 80, 8, 54, 3, 29, 0, 35, 5, 42, 7, 23
  };
  const int q0523[] = {
    9, 9, // Number of jobs and machines
    1,  9, 8, 32, 6, 64, 5, 32, 4, 20, 0, 71, 2,  2, 7, 91, 3, 77, 
    0,  3, 3, 54, 7, 29, 4, 70, 6, 52, 1, 19, 8, 21, 2, 18, 5, 24, 
    3, 37, 6, 92, 0, 65, 4,  8, 8, 58, 7, 27, 1, 77, 2, 17, 5, 66, 
    6, 65, 1, 48, 4, 38, 0,  6, 5, 31, 7, 93, 3, 21, 8, 82, 2, 59, 
    5, 41, 1, 57, 8,  9, 7, 79, 2, 93, 3, 84, 0, 45, 6, 27, 4, 68, 
    8, 84, 4, 79, 7, 57, 2, 93, 1, 22, 5, 36, 6, 89, 0, 15, 3, 66, 
    2, 15, 7, 27, 6, 10, 4, 90, 0, 99, 1, 42, 8, 54, 5, 82, 3, 45, 
    8, 35, 7, 93, 2, 41, 5, 34, 6, 13, 3, 33, 4, 66, 0, 48, 1,  9, 
    5, 61, 0, 28, 4, 14, 1, 81, 3, 46, 6, 14, 7,  4, 8, 28, 2, 32
  };
  const int q0524[] = {
    9, 9, // Number of jobs and machines
    4, 35, 3,  9, 8, 30, 5, 92, 0, 49, 6, 91, 1, 48, 2, 10, 7, 65, 
    6, 42, 1, 78, 4, 77, 3, 92, 2, 64, 5, 47, 7, 62, 8, 90, 0, 47, 
    7, 88, 8, 19, 6, 77, 0, 20, 1, 85, 5, 43, 4, 87, 2, 77, 3, 40, 
    6, 65, 1, 37, 2, 25, 3, 58, 5, 43, 7, 81, 0, 41, 4,  2, 8,  5, 
    8, 12, 0, 27, 6, 14, 2, 86, 4, 57, 5, 69, 1, 72, 3, 16, 7, 13, 
    4,  4, 0, 58, 1, 48, 3,  7, 5, 67, 8, 70, 7, 48, 2, 65, 6, 97, 
    3, 70, 7, 44, 5, 67, 0, 38, 6, 44, 1,  7, 8, 63, 2, 59, 4, 47, 
    1, 55, 5, 82, 7, 81, 6, 97, 4, 86, 3, 69, 0, 24, 2, 48, 8, 25, 
    3, 61, 8, 73, 4, 84, 1, 98, 5, 57, 0, 28, 2, 56, 6, 55, 7, 54
  };
  const int q0525[] = {
    9, 9, // Number of jobs and machines
    0, 50, 4, 22, 5,  2, 7, 26, 3, 31, 1, 77, 6, 49, 2, 44, 8, 90, 
    2, 57, 7, 15, 4,  4, 8,  6, 3, 64, 6, 49, 1, 72, 0, 92, 5, 55, 
    4,  8, 7,  2, 6, 35, 2, 30, 5, 31, 8, 64, 0,  4, 3, 74, 1, 34, 
    1, 12, 7, 50, 2, 73, 5, 69, 3, 79, 4, 27, 0, 22, 6, 11, 8,  5, 
    1, 93, 6, 96, 3, 57, 5, 66, 8, 65, 4, 55, 0, 18, 2, 67, 7, 75, 
    2, 73, 1, 17, 3, 45, 6, 93, 5, 84, 7, 93, 8, 87, 4, 16, 0, 77, 
    4, 96, 2, 62, 8, 27, 0, 98, 1, 58, 6, 76, 5, 17, 3, 62, 7, 16, 
    6, 45, 3, 24, 5, 68, 1, 98, 8, 35, 4, 96, 7, 42, 0, 36, 2, 73, 
    1, 44, 6, 95, 4,  4, 7, 83, 0, 29, 5, 62, 3, 12, 2, 20, 8, 90
  };
  const int q0526[] = {
    9, 9, // Number of jobs and machines
    7, 50, 0, 85, 6, 50, 4,  2, 8, 64, 2, 32, 5, 44, 3, 64, 1, 67, 
    5,  9, 8,  5, 0, 56, 1,  9, 7, 19, 2, 14, 4, 26, 6, 38, 3, 37, 
    8, 98, 7, 98, 0, 25, 6, 97, 2, 57, 1, 65, 4, 39, 3, 38, 5, 76, 
    0, 12, 8, 51, 1, 57, 5, 49, 4, 45, 2, 85, 7,  6, 6, 23, 3, 87, 
    0, 33, 1, 17, 3, 52, 7, 34, 8, 25, 5, 97, 4, 49, 6, 57, 2, 83, 
    1, 73, 8, 25, 2, 24, 3, 56, 7, 14, 4, 30, 6, 32, 5, 81, 0, 81, 
    5, 83, 3, 84, 7, 39, 2, 99, 6, 10, 0, 55, 8, 82, 1, 69, 4, 41, 
    0, 60, 7, 58, 1, 80, 3, 38, 2, 63, 6, 92, 8, 41, 5, 31, 4, 38, 
    1, 88, 5, 57, 4, 32, 8, 22, 7,  2, 3, 51, 6, 32, 2, 40, 0, 80
  };
  const int q0527[] = {
    9, 9, // Number of jobs and machines
    8, 75, 1, 53, 7, 69, 4, 56, 0,  9, 3, 18, 6, 54, 2,  6, 5, 96, 
    6, 51, 2, 61, 0, 45, 5, 31, 4, 38, 3,  7, 8, 21, 7, 87, 1, 19, 
    8, 41, 4, 25, 7, 52, 1, 45, 3, 35, 2, 30, 5, 98, 0, 72, 6, 32, 
    0, 98, 8,  8, 6, 87, 4, 39, 5, 42, 3,  9, 2, 39, 7, 74, 1, 93, 
    8, 29, 4, 48, 5,  6, 0, 78, 1, 10, 2, 26, 7,  4, 3, 34, 6, 99, 
    7, 13, 1, 30, 4, 16, 3, 17, 8, 54, 5, 53, 6, 28, 0, 33, 2, 98, 
    4, 67, 5, 31, 1, 80, 7, 47, 0, 60, 3, 80, 2, 59, 6, 85, 8, 12, 
    5, 71, 3, 86, 6, 97, 2, 32, 7, 20, 4, 87, 8, 17, 0, 51, 1, 91, 
    1, 12, 5, 12, 2, 43, 0, 84, 3, 61, 6, 90, 7, 96, 4,  9, 8, 14
  };
  const int q0528[] = {
    9, 9, // Number of jobs and machines
    3, 98, 7, 99, 1,  8, 0, 86, 2, 58, 8, 42, 5, 82, 4, 24, 6, 89, 
    8, 33, 3, 85, 5, 23, 7, 96, 6, 51, 0, 84, 2, 24, 1, 31, 4, 94, 
    3, 28, 0, 46, 6, 81, 1, 13, 7, 24, 2, 58, 8, 48, 4, 61, 5, 64, 
    6, 13, 0,  2, 5, 26, 2, 80, 4, 48, 3, 27, 1,  8, 7, 88, 8, 50, 
    7, 20, 8,  4, 4, 39, 2, 23, 0, 56, 3, 18, 6, 82, 5, 59, 1,  8, 
    5, 41, 2, 21, 6, 10, 7, 19, 3, 35, 0, 59, 4, 52, 1, 29, 8, 70, 
    6,  8, 2, 91, 5, 49, 0, 47, 8, 45, 7, 83, 3, 25, 1, 37, 4, 99, 
    8, 12, 4, 12, 6, 96, 2, 89, 1, 46, 5, 89, 7, 50, 3, 31, 0, 61, 
    8, 56, 1, 25, 6, 90, 4, 78, 3, 96, 0, 73, 5, 57, 7, 25, 2, 19
  };
  const int q0529[] = {
    9, 9, // Number of jobs and machines
    2, 86, 0, 57, 3, 63, 7, 54, 1, 56, 5,  8, 4, 32, 8, 65, 6, 82, 
    8, 49, 2, 40, 7,  4, 3, 60, 1, 38, 6,  6, 0, 82, 4, 43, 5, 51, 
    5, 58, 1, 90, 0,  9, 3, 39, 2, 13, 7, 38, 8, 20, 4, 75, 6, 91, 
    8, 71, 2, 43, 1, 65, 4,  6, 6, 28, 5,  1, 3, 97, 7, 40, 0, 19, 
    3, 30, 2, 51, 7, 89, 1, 60, 4, 37, 8, 39, 6, 89, 5, 40, 0, 18, 
    1, 64, 8, 73, 7, 59, 0, 84, 3,  7, 6, 79, 2, 76, 4,  4, 5, 18, 
    5, 44, 6, 44, 2, 57, 8, 85, 3, 54, 0,  7, 7, 81, 4, 29, 1, 29, 
    8, 10, 0, 14, 4, 98, 7, 13, 1, 50, 2,  6, 3, 16, 6, 87, 5, 65, 
    1,  7, 8, 96, 5, 31, 2, 98, 0, 44, 7, 46, 6, 56, 4, 34, 3, 98
  };
  const int q0530[] = {
    9, 9, // Number of jobs and machines
    3, 88, 7, 56, 5, 17, 8, 91, 6, 97, 2, 93, 1, 36, 4, 58, 0, 34, 
    4, 90, 6, 64, 3, 37, 0, 42, 7, 33, 5, 90, 2,  6, 8,  3, 1, 53, 
    6, 40, 5, 56, 1, 60, 8, 74, 4, 12, 3, 62, 0,  5, 7, 15, 2,  4, 
    1, 37, 4, 37, 8, 58, 6, 75, 3, 57, 7, 60, 2, 34, 5, 32, 0, 72, 
    8, 52, 2, 41, 1, 22, 5, 81, 6, 60, 3, 27, 4, 82, 0,  1, 7, 21, 
    1, 99, 0, 37, 3, 95, 5, 16, 6, 85, 8, 93, 4, 47, 2, 60, 7, 21, 
    4, 70, 1, 38, 5, 99, 0, 66, 8, 40, 2,  4, 6, 97, 3, 18, 7, 23, 
    4, 20, 7, 39, 0, 43, 2, 96, 5, 90, 8, 71, 1, 43, 6, 80, 3, 60, 
    0, 69, 3, 23, 2, 68, 7, 66, 4, 50, 5, 70, 8,  3, 6, 13, 1, 13
  };
  const int q0531[] = {
    9, 9, // Number of jobs and machines
    6, 60, 5, 21, 7, 93, 4, 38, 1, 58, 8,  6, 0, 20, 2, 53, 3, 22, 
    4, 32, 6, 64, 8, 33, 1, 34, 5, 43, 0, 67, 7, 55, 3, 18, 2, 94, 
    4, 14, 3, 12, 7, 99, 1, 63, 6, 91, 0, 99, 5, 27, 2, 39, 8, 98, 
    2, 49, 5, 59, 4, 46, 0, 43, 3, 54, 1, 51, 8, 45, 7, 76, 6, 52, 
    4, 15, 6, 69, 2, 65, 0, 98, 8, 41, 5, 79, 3, 32, 7, 38, 1, 83, 
    6, 44, 0,  6, 7,  6, 2, 15, 3, 72, 1, 79, 5, 21, 4, 62, 8,  7, 
    7, 49, 1, 98, 0, 89, 4,  5, 3, 75, 6, 16, 5,  5, 2, 65, 8, 97, 
    8,  4, 3, 87, 1, 74, 6, 88, 0,  9, 4, 20, 5, 60, 2, 31, 7, 71, 
    0, 84, 1,  6, 3, 18, 4, 81, 8, 25, 2, 49, 5, 84, 6, 72, 7, 36
  };
  const int q0532[] = {
    9, 9, // Number of jobs and machines
    3, 52, 1,  3, 8,  8, 4, 16, 7, 97, 5, 91, 0, 26, 6, 42, 2, 72, 
    1, 60, 5, 52, 8, 15, 0,  3, 4, 10, 2, 16, 7, 13, 3, 24, 6, 98, 
    1, 47, 8, 25, 5, 57, 6, 85, 4, 25, 0, 54, 2, 15, 7, 24, 3, 77, 
    1, 73, 5, 67, 8, 80, 2, 69, 4,  5, 6, 92, 7,  5, 3,  8, 0, 66, 
    6,  6, 7, 53, 5, 87, 8, 88, 3, 11, 1,  5, 0, 25, 4,  5, 2, 61, 
    5,  8, 8,  9, 7, 84, 1, 15, 3, 15, 4, 65, 6, 83, 2,  6, 0, 81, 
    1, 55, 3, 28, 6, 98, 8, 82, 4, 69, 7, 70, 5, 23, 2,  7, 0, 47, 
    7,  3, 0, 63, 1, 42, 3, 32, 4, 90, 2, 35, 8, 88, 5, 72, 6, 11, 
    6, 20, 7, 86, 8, 51, 4, 85, 1, 38, 3, 95, 5, 53, 2, 71, 0, 46
  };
  const int q0533[] = {
    9, 9, // Number of jobs and machines
    0, 83, 4, 31, 8, 62, 3, 35, 7,  3, 5, 79, 6, 49, 1, 96, 2, 82, 
    3, 55, 0, 26, 4, 22, 6, 86, 2, 33, 5, 93, 1, 62, 8, 66, 7, 92, 
    0, 84, 5, 34, 6, 31, 4, 23, 2, 58, 1, 73, 8, 26, 3, 96, 7, 65, 
    7, 90, 5, 91, 1, 40, 3, 69, 4, 79, 2, 37, 6, 40, 0, 15, 8, 67, 
    6, 69, 8, 74, 3, 35, 7, 65, 4, 67, 5, 91, 0, 43, 2, 90, 1,  4, 
    6, 42, 8, 42, 2, 55, 3, 76, 7, 19, 4, 82, 5, 11, 0,  4, 1, 49, 
    6, 79, 0, 51, 2, 14, 3, 77, 8, 27, 4, 25, 5, 77, 7, 10, 1, 69, 
    3, 45, 5, 37, 6, 12, 1, 25, 8, 27, 4, 48, 2, 12, 0, 65, 7, 69, 
    1, 92, 8,  9, 2,  9, 4, 39, 6, 77, 7, 17, 3, 47, 5, 40, 0, 30
  };
  const int q0534[] = {
    9, 9, // Number of jobs and machines
    6, 90, 0, 20, 7, 99, 5, 28, 2, 22, 3, 68, 1, 82, 4, 96, 8, 76, 
    2, 42, 7, 86, 6, 17, 1,  4, 0, 41, 8, 60, 5, 79, 4, 54, 3,  6, 
    0, 37, 7, 93, 2, 74, 3, 43, 8, 40, 5, 35, 6, 46, 1, 28, 4, 52, 
    3, 90, 4, 41, 8, 83, 5, 39, 1, 81, 6, 20, 7, 37, 0, 60, 2, 54, 
    7, 57, 6, 25, 3, 26, 2, 54, 8, 54, 0, 94, 1, 14, 4,  4, 5, 49, 
    3, 82, 6, 50, 4, 62, 0, 88, 1, 42, 8, 33, 5, 88, 7, 71, 2, 68, 
    6,  1, 1, 60, 5, 86, 2, 18, 4, 68, 3, 62, 8, 59, 0, 24, 7, 53, 
    5, 81, 3, 89, 1, 59, 7, 62, 6, 68, 8, 96, 2, 93, 4, 22, 0, 98, 
    2, 34, 7, 91, 8, 10, 0, 56, 3, 90, 5, 56, 1, 28, 6, 32, 4, 35
  };
  const int q0535[] = {
    9, 9, // Number of jobs and machines
    3, 68, 8, 31, 7,  3, 6, 76, 2, 65, 0, 37, 1, 84, 5, 37, 4, 45, 
    2, 79, 4, 29, 0, 90, 8, 13, 6, 57, 7, 92, 3,  6, 1, 91, 5, 60, 
    1, 49, 3, 16, 2,  8, 6, 43, 5, 46, 7, 27, 8, 35, 0, 26, 4, 63, 
    4, 16, 3, 42, 0, 45, 5, 20, 8,  8, 1, 23, 7,  8, 6, 58, 2, 57, 
    8, 54, 7, 89, 1,  3, 5, 11, 0, 67, 4, 37, 6, 95, 3, 85, 2,  1, 
    5, 89, 2,  2, 7, 51, 0, 46, 6, 71, 1, 61, 8, 47, 3, 28, 4, 45, 
    5,  5, 0, 87, 4, 42, 2, 54, 1, 22, 7, 71, 3, 94, 6, 21, 8, 12, 
    8, 50, 6,  5, 3, 53, 7, 53, 2, 21, 4, 75, 0, 94, 1, 67, 5, 30, 
    2, 52, 3, 19, 4,  3, 5, 34, 8, 52, 7, 48, 0, 42, 1, 45, 6,  8
  };
  const int q0536[] = {
    9, 9, // Number of jobs and machines
    0, 93, 3, 49, 2, 47, 6, 44, 5, 14, 1, 40, 7, 33, 4, 41, 8,  3, 
    2, 96, 4, 49, 7, 65, 3, 82, 6, 95, 1, 19, 8, 73, 5,  6, 0, 63, 
    4, 23, 5, 71, 1, 56, 0, 22, 7, 51, 8, 35, 3, 30, 2, 86, 6, 77, 
    8, 40, 2, 29, 0, 57, 3, 49, 5, 67, 1, 75, 7, 73, 6, 65, 4, 24, 
    7, 43, 1, 63, 5, 49, 3, 99, 6, 70, 0, 10, 4, 17, 8, 57, 2, 52, 
    5, 37, 7, 15, 8, 94, 1, 31, 3, 23, 2, 19, 4,  9, 6, 57, 0,  8, 
    3, 97, 8, 63, 5, 90, 4, 75, 1, 16, 0, 53, 6, 68, 2, 22, 7, 19, 
    5, 66, 2, 47, 7, 64, 1, 82, 4, 71, 8,  4, 0, 41, 3, 31, 6,  5, 
    2, 72, 0, 92, 3,  2, 5, 31, 1, 96, 6, 96, 8, 70, 7, 76, 4, 81
  };
  const int q0537[] = {
    9, 9, // Number of jobs and machines
    2,  5, 7, 28, 3, 27, 0, 28, 4, 80, 6,  7, 5, 49, 8, 33, 1, 27, 
    2, 25, 0, 42, 5, 19, 7,  9, 3, 70, 8, 74, 1,  3, 6, 68, 4, 29, 
    4, 28, 6, 98, 8, 66, 0, 24, 1, 76, 7, 95, 2, 80, 5, 87, 3, 10, 
    6, 22, 8, 23, 4, 60, 2, 32, 5, 62, 1, 84, 0, 87, 3, 85, 7, 22, 
    1, 35, 3, 30, 0, 80, 8, 90, 4, 16, 2, 30, 5, 36, 7, 12, 6,  9, 
    7, 69, 8, 40, 3, 69, 1, 61, 6, 20, 5, 60, 0, 47, 2, 99, 4, 88, 
    2, 55, 5, 30, 3, 83, 6, 65, 0, 82, 4, 21, 1,  7, 8, 86, 7, 73, 
    5, 10, 0, 97, 3, 81, 2, 81, 7, 58, 6, 22, 1, 40, 8, 30, 4, 44, 
    2, 26, 6, 48, 0, 49, 5,  9, 1, 64, 7, 22, 8, 39, 4, 73, 3, 27
  };
  const int q0538[] = {
    9, 9, // Number of jobs and machines
    1, 64, 5, 76, 6, 99, 2, 71, 3, 71, 4, 76, 7, 74, 0, 97, 8, 83, 
    7, 26, 1, 38, 6,  8, 8, 10, 5, 21, 3, 18, 2, 51, 0, 96, 4, 43, 
    7, 82, 8,  1, 2, 55, 6,  8, 5, 21, 1, 47, 0, 75, 4, 54, 3, 90, 
    3, 82, 8, 73, 2, 99, 0, 25, 6, 49, 1, 92, 7, 50, 5,  1, 4, 63, 
    7, 12, 2, 78, 3, 46, 4, 70, 1, 56, 5, 56, 6, 66, 0, 54, 8, 89, 
    8,  3, 3, 91, 0, 54, 2, 41, 5, 78, 7, 42, 4, 16, 1, 58, 6, 82, 
    7, 70, 5,  4, 2, 21, 8,  4, 0, 70, 1, 55, 6,  8, 4,  4, 3, 68, 
    5, 75, 3, 55, 6, 30, 4, 50, 0, 17, 8, 40, 7, 77, 1, 45, 2, 69, 
    2, 15, 8, 72, 6, 51, 3, 59, 7, 83, 1,  6, 5, 17, 4, 85, 0, 32
  };
  const int q0539[] = {
    9, 9, // Number of jobs and machines
    2, 70, 4, 25, 0, 28, 6, 97, 8, 43, 3, 41, 1, 88, 5, 18, 7, 27, 
    2, 61, 7, 26, 8, 69, 1, 83, 0, 78, 3, 84, 4, 22, 5, 79, 6, 78, 
    5, 61, 7, 77, 1, 47, 4, 49, 6, 75, 8, 49, 0, 35, 3, 42, 2, 80, 
    5, 63, 7, 43, 6, 80, 3, 37, 8, 97, 4, 79, 2, 80, 1, 81, 0, 45, 
    8, 30, 6, 39, 5, 93, 1, 88, 2, 15, 0, 39, 7, 80, 3, 75, 4, 96, 
    0, 27, 4, 57, 1, 11, 2, 66, 3, 13, 5, 54, 6, 71, 8, 64, 7, 68, 
    4, 70, 0, 23, 2, 19, 3, 96, 7,  5, 6, 28, 8, 83, 1, 16, 5, 52, 
    3, 12, 8,  6, 4, 84, 6,  8, 2, 89, 7, 46, 5, 11, 0, 80, 1, 18, 
    3, 78, 6, 59, 7, 33, 8, 32, 5, 34, 4, 11, 2,  1, 1, 45, 0, 70
  };
  const int q0540[] = {
    9, 9, // Number of jobs and machines
    2, 99, 4, 82, 1, 77, 5, 63, 8, 81, 0, 88, 6, 99, 3,  5, 7, 11, 
    6, 51, 8, 96, 7, 13, 1, 98, 0, 58, 5, 16, 3, 36, 4, 14, 2, 20, 
    8, 72, 5, 99, 6, 49, 1, 80, 2, 40, 4, 90, 7, 52, 0, 42, 3, 19, 
    4, 84, 0, 58, 8, 58, 1, 53, 3, 53, 6, 10, 7, 36, 5, 92, 2, 98, 
    3, 16, 4, 73, 7, 82, 5, 64, 1, 61, 6, 45, 2, 21, 8, 96, 0,  8, 
    5, 14, 2, 20, 6, 33, 8, 75, 7, 32, 3, 44, 4, 51, 0, 59, 1, 86, 
    5, 57, 4, 35, 0, 97, 6, 29, 7, 88, 1, 57, 8, 20, 3, 75, 2, 66, 
    0, 61, 8, 44, 4,  6, 5, 77, 7, 88, 6, 85, 2, 61, 3, 64, 1, 96, 
    7, 55, 4, 24, 1, 40, 5, 72, 2, 70, 3, 39, 8, 72, 0, 40, 6, 71
  };
  const int q0541[] = {
    9, 9, // Number of jobs and machines
    2,  4, 5, 36, 7, 85, 3, 21, 0, 60, 8, 32, 1,  8, 4, 19, 6, 90, 
    1, 17, 3, 43, 4, 45, 6, 54, 2, 53, 0, 97, 5, 81, 8, 67, 7, 63, 
    2, 67, 4, 81, 8, 97, 3, 51, 7, 25, 6,  5, 0, 73, 5,  1, 1, 22, 
    6, 99, 8, 97, 1, 17, 0,  5, 7, 87, 5, 48, 2, 64, 4, 33, 3, 57, 
    4, 78, 1, 37, 7, 45, 6,  5, 2, 66, 8, 64, 0, 46, 5, 82, 3, 99, 
    0, 74, 2, 92, 5, 91, 7, 29, 1, 54, 4, 93, 8, 38, 3, 89, 6,  2, 
    2, 55, 4, 84, 3, 66, 5, 10, 7, 91, 0, 63, 6, 67, 8, 46, 1, 71, 
    7, 88, 8, 98, 3, 71, 5, 49, 1, 80, 0, 26, 6, 25, 2, 54, 4, 86, 
    4, 58, 7, 46, 1, 74, 2, 93, 8, 39, 0, 10, 6, 22, 5, 90, 3, 24
  };
  const int q0542[] = {
    9, 9, // Number of jobs and machines
    8, 60, 2, 32, 5, 26, 3, 28, 7, 17, 0, 88, 6, 35, 4, 17, 1, 47, 
    0, 79, 6, 73, 7, 47, 4, 26, 3, 80, 8, 83, 1, 35, 2, 12, 5, 99, 
    3, 95, 8, 86, 6, 44, 7, 99, 2, 89, 0, 35, 4, 55, 1, 58, 5, 48, 
    7, 85, 5, 63, 1, 72, 0, 81, 2, 79, 4, 90, 3, 48, 8, 74, 6, 78, 
    4, 25, 3, 81, 0, 85, 7, 25, 1, 54, 2, 85, 6,  6, 8, 73, 5, 15, 
    3, 30, 4, 91, 6, 65, 5, 72, 1, 52, 0, 25, 7, 66, 8, 48, 2, 87, 
    5, 55, 6, 42, 2, 13, 8, 43, 0, 61, 4, 36, 1, 93, 7, 46, 3, 36, 
    5, 10, 8,  5, 6, 36, 1, 40, 0, 92, 7, 69, 4, 76, 2, 21, 3, 51, 
    7, 50, 6, 19, 4,  6, 3, 39, 1, 15, 8, 58, 2,  2, 0, 98, 5, 60
  };
  const int q0543[] = {
    9, 9, // Number of jobs and machines
    0, 97, 2, 59, 6, 77, 4, 30, 1, 98, 7, 52, 8, 91, 5, 33, 3, 49, 
    4, 42, 1, 88, 5, 47, 0, 61, 2, 83, 3,  4, 8, 36, 7, 47, 6, 77, 
    5, 85, 2, 58, 4, 84, 6, 84, 3, 90, 8,  9, 7, 79, 1, 98, 0, 51, 
    1,  5, 2, 83, 7, 26, 0, 44, 4, 45, 3, 28, 5, 69, 8, 73, 6, 37, 
    3, 61, 6,  5, 7, 99, 0, 15, 8, 27, 1, 38, 2, 38, 4, 43, 5, 51, 
    8, 80, 2, 62, 3, 43, 1, 19, 5, 77, 0, 45, 6, 69, 4,  7, 7, 78, 
    6,  8, 5, 81, 1, 21, 0, 98, 3,  8, 7,  1, 2, 96, 4, 55, 8, 18, 
    6, 56, 0, 42, 4, 92, 3,  6, 1, 12, 8, 79, 7, 17, 2, 49, 5, 16, 
    7, 68, 8, 67, 6, 99, 3, 84, 0, 88, 4, 20, 2, 33, 5, 58, 1, 72
  };
  const int q0544[] = {
    9, 9, // Number of jobs and machines
    1, 66, 3, 89, 4, 14, 8, 28, 6, 75, 2, 58, 5, 30, 0, 24, 7, 69, 
    0, 33, 6, 67, 1, 67, 3, 95, 8, 14, 2, 44, 7, 14, 4, 57, 5, 48, 
    2, 35, 4,  9, 5, 30, 0, 29, 3, 87, 6, 31, 8, 63, 1, 14, 7, 48, 
    2, 74, 0, 12, 4, 83, 8, 76, 5, 43, 1, 38, 7, 97, 6, 83, 3,  4, 
    8, 16, 3, 72, 7, 79, 6, 79, 5, 99, 0, 56, 2, 59, 1, 53, 4, 98, 
    4, 23, 5, 11, 6,  4, 0, 87, 2, 19, 8, 68, 7,  6, 1, 60, 3, 26, 
    4, 49, 6, 99, 0, 31, 7, 22, 5, 48, 1, 44, 8,  3, 3, 63, 2,  4, 
    5, 72, 3, 15, 1, 91, 4, 45, 2, 43, 0, 34, 6, 45, 8, 65, 7, 17, 
    2, 57, 8, 68, 0, 26, 1, 76, 5,  9, 6, 84, 7, 65, 3, 68, 4, 38
  };
  const int q0545[] = {
    9, 9, // Number of jobs and machines
    0, 54, 1, 58, 3,  6, 5, 53, 6,  4, 2, 49, 8, 21, 7,  9, 4, 56, 
    4, 97, 8, 72, 2,  5, 3, 62, 0, 27, 7, 28, 1, 96, 5, 40, 6, 22, 
    8, 38, 4, 52, 6, 95, 2, 36, 1, 27, 0, 52, 5, 46, 3,  5, 7,  6, 
    3, 30, 6, 37, 8, 94, 5, 89, 2, 14, 0, 73, 7, 77, 4, 87, 1, 79, 
    7,  8, 6,  9, 5,  9, 0, 59, 1, 85, 2, 80, 4,  6, 8, 78, 3, 19, 
    6, 22, 8, 79, 3, 55, 5, 31, 0, 44, 1,  1, 7, 91, 2, 76, 4, 87, 
    2, 45, 0, 47, 3, 49, 1, 90, 7, 88, 5, 60, 4, 88, 6,  6, 8, 48, 
    2, 49, 7, 14, 4, 84, 5, 17, 1, 23, 8, 45, 6, 14, 3, 82, 0, 71, 
    5, 31, 6,  4, 7, 59, 0, 44, 8, 51, 3, 18, 4, 37, 1, 39, 2, 62
  };
  const int q0546[] = {
    9, 9, // Number of jobs and machines
    0, 48, 5, 18, 8, 11, 4, 68, 1, 74, 3, 31, 7, 88, 2, 36, 6, 24, 
    5, 13, 0, 49, 2, 29, 3, 77, 1, 88, 6, 99, 4,  7, 8, 74, 7, 61, 
    5, 81, 1, 13, 0, 36, 3, 17, 6, 93, 7, 98, 4, 53, 8, 65, 2, 80, 
    1, 36, 0, 38, 5, 80, 4, 39, 7, 62, 3, 15, 6, 17, 8, 36, 2, 81, 
    5, 70, 7, 84, 4, 91, 0,  4, 1,  3, 8, 38, 3, 48, 2, 50, 6, 24, 
    2, 34, 5, 44, 4, 82, 3, 44, 1, 21, 6, 83, 7, 91, 0, 46, 8, 83, 
    0, 41, 7, 23, 6, 19, 5, 18, 8, 81, 4, 24, 1, 21, 3, 74, 2, 95, 
    2, 24, 6, 30, 8, 82, 0,  5, 3, 50, 1, 39, 5, 18, 4, 74, 7, 13, 
    6, 85, 0, 65, 7, 26, 4, 92, 8, 37, 5, 26, 1, 77, 2,  2, 3, 63
  };
  const int q0547[] = {
    9, 9, // Number of jobs and machines
    6, 42, 3, 85, 5, 73, 8,  9, 1,  2, 4, 63, 7, 69, 0, 32, 2, 12, 
    6, 93, 8, 32, 0, 79, 7, 47, 3, 26, 1, 67, 4, 79, 5, 90, 2, 64, 
    8, 47, 3, 79, 1, 68, 2, 44, 7, 76, 5, 60, 6, 89, 0, 18, 4, 47, 
    1, 59, 5, 21, 3, 32, 8, 43, 6,  6, 4, 34, 2, 76, 7, 19, 0, 43, 
    4, 39, 5, 92, 6,  1, 8, 74, 0, 52, 3, 86, 1, 58, 2, 97, 7, 34, 
    6, 56, 7, 59, 3, 35, 5, 91, 8, 82, 2, 21, 4, 27, 0, 82, 1, 44, 
    7, 86, 5, 54, 1, 43, 6,  8, 2, 50, 0, 44, 4,  9, 8, 86, 3, 98, 
    6,  4, 4,  5, 3, 79, 5,  6, 8, 13, 7, 25, 0, 73, 2, 13, 1, 24, 
    2, 39, 1, 52, 5, 74, 7, 19, 3, 20, 6, 23, 8, 11, 4, 77, 0, 61
  };
  const int q0548[] = {
    9, 9, // Number of jobs and machines
    4, 32, 6, 62, 2, 87, 7, 35, 1, 55, 8, 62, 0, 33, 3, 38, 5, 93, 
    0, 31, 4,  5, 2, 14, 5, 59, 6, 35, 7, 74, 3, 10, 1, 26, 8, 55, 
    5,  8, 1, 48, 3, 40, 6,  6, 8,  2, 0, 14, 2, 68, 7, 11, 4,  9, 
    4, 73, 2, 47, 6, 99, 3, 99, 1, 93, 8, 12, 5,  2, 7, 73, 0, 50, 
    8, 61, 1, 93, 7, 58, 0, 93, 2,  6, 6, 89, 3,  1, 5, 12, 4, 47, 
    2, 73, 0, 65, 8, 91, 1, 97, 6, 23, 4, 13, 7, 97, 3,  7, 5, 87, 
    5, 87, 2, 96, 1,  8, 4, 60, 7, 97, 6, 19, 3, 90, 0, 63, 8,  3, 
    8, 11, 4, 18, 6, 11, 7, 19, 2, 35, 3, 63, 5, 44, 1, 70, 0, 44, 
    3, 51, 0, 34, 6, 29, 2, 37, 7, 93, 4, 39, 1, 15, 5, 58, 8, 68
  };
  const int q0549[] = {
    9, 9, // Number of jobs and machines
    7, 44, 1, 95, 2, 40, 3, 97, 8, 37, 4, 97, 5, 18, 6, 28, 0, 11, 
    1, 43, 7, 25, 3, 11, 5, 60, 6, 95, 4, 68, 2, 18, 8, 98, 0, 71, 
    5, 86, 1, 63, 4, 25, 6, 52, 3, 45, 7, 59, 2, 97, 8, 94, 0, 72, 
    5, 43, 6, 56, 2, 33, 4, 19, 0, 19, 7, 69, 8, 91, 1, 19, 3, 92, 
    3, 64, 7, 28, 5, 24, 8, 14, 4, 43, 6, 38, 2, 72, 1, 33, 0, 36, 
    4, 55, 6, 78, 3, 74, 5, 64, 2, 41, 0, 47, 8, 87, 1, 41, 7, 40, 
    8, 60, 1, 32, 5, 94, 0, 74, 2, 72, 6,  4, 4, 47, 7, 66, 3, 25, 
    2, 99, 6,  7, 3, 55, 0, 10, 5, 71, 4, 14, 1, 54, 7, 36, 8, 85, 
    4, 20, 7, 10, 3, 34, 1,  6, 6, 90, 5, 33, 8, 31, 2, 94, 0, 26
  };
  const int q0550[] = {
    9, 9, // Number of jobs and machines
    3, 28, 4, 90, 6, 70, 7, 93, 5, 12, 1, 87, 0, 47, 8, 97, 2, 21, 
    1,  7, 4, 97, 7, 14, 3, 91, 5, 60, 2, 87, 6, 26, 0, 63, 8, 76, 
    0, 55, 6, 38, 7, 15, 1, 92, 8, 75, 4, 47, 2, 29, 3, 45, 5, 64, 
    3, 34, 5, 27, 8, 24, 7, 68, 6, 95, 4, 96, 2, 83, 0, 54, 1, 35, 
    6,  8, 0, 83, 4, 18, 2, 39, 5, 86, 7, 82, 3, 44, 1, 44, 8, 23, 
    6, 24, 2, 89, 5, 20, 4, 61, 0, 93, 7, 87, 8, 83, 3, 24, 1, 71, 
    2, 70, 0, 90, 1, 74, 3, 27, 4, 57, 5, 71, 7, 93, 8,  6, 6, 64, 
    3, 13, 1, 58, 5, 67, 6, 79, 0, 30, 2, 49, 4, 36, 8, 99, 7, 57, 
    5, 77, 1, 73, 4, 12, 2, 94, 7, 48, 3, 12, 0, 86, 8, 19, 6, 61
  };
  const int q0551[] = {
    9, 9, // Number of jobs and machines
    7, 27, 8, 76, 1,  6, 2, 18, 0, 75, 6, 73, 5, 79, 3, 13, 4,  8, 
    8, 95, 3, 72, 7, 31, 0, 62, 2, 10, 6, 21, 1,  1, 5, 42, 4, 12, 
    6, 15, 3, 71, 2, 38, 8,  4, 4, 66, 1, 39, 7, 17, 0, 31, 5, 42, 
    5, 92, 8, 65, 2,  7, 6, 35, 3, 11, 7, 41, 4, 79, 1, 36, 0, 41, 
    7, 46, 8, 40, 5, 91, 0, 22, 2, 27, 4, 94, 3, 39, 6, 54, 1, 73, 
    1, 81, 0, 33, 4, 42, 5, 63, 6, 48, 2, 55, 7, 41, 3, 72, 8, 50, 
    6,  3, 7,  8, 3, 77, 1, 25, 0, 33, 2,  7, 5,  7, 4, 37, 8, 74, 
    0, 61, 1, 49, 5, 42, 7, 85, 6, 69, 8, 84, 3, 20, 4, 18, 2, 58, 
    3, 50, 4, 93, 6, 81, 7, 58, 0, 11, 8, 53, 5, 96, 1, 82, 2, 31
  };
  const int q0552[] = {
    9, 9, // Number of jobs and machines
    7, 70, 5, 63, 8, 56, 0,  3, 6, 95, 4, 83, 1, 67, 3, 65, 2, 67, 
    0, 94, 3, 11, 1, 97, 4, 29, 2, 58, 7, 22, 6, 57, 5, 83, 8, 82, 
    8, 55, 4, 67, 1, 77, 6, 63, 5, 56, 7, 10, 0,  9, 2, 22, 3, 66, 
    7, 83, 8, 62, 5, 33, 1, 94, 4, 34, 6, 60, 0, 29, 2, 65, 3, 25, 
    1, 62, 7, 36, 0, 86, 2, 62, 4,  3, 5, 17, 6, 43, 3, 96, 8, 77, 
    4, 99, 8, 66, 0, 45, 1, 91, 5, 95, 6,  5, 7, 50, 3, 42, 2, 61, 
    3, 92, 4, 57, 5, 71, 1,  9, 8, 76, 6, 19, 7, 73, 0,  3, 2,  4, 
    2, 35, 1, 23, 5, 50, 7, 94, 0, 69, 6, 48, 3, 61, 4, 73, 8, 36, 
    6, 33, 2, 78, 5, 61, 0, 32, 7, 59, 3, 65, 1, 16, 4, 54, 8, 18
  };
  const int q0553[] = {
    9, 9, // Number of jobs and machines
    4, 29, 8, 25, 2, 43, 1,  5, 0, 69, 7, 14, 6, 22, 3, 90, 5, 78, 
    1, 38, 2, 54, 8, 70, 3, 20, 5, 15, 6, 99, 4, 34, 0,  3, 7, 93, 
    8, 68, 6, 59, 7, 77, 0, 60, 5, 14, 2, 75, 4, 59, 1, 48, 3, 37, 
    5, 78, 8,  1, 0, 24, 3, 91, 7,  5, 4, 78, 2, 58, 6, 15, 1, 34, 
    4, 75, 2,  3, 3, 99, 7, 70, 8, 45, 0,  5, 5,  4, 6, 27, 1, 94, 
    8, 13, 7, 16, 4, 36, 2,  7, 1, 39, 0, 33, 3, 24, 5, 56, 6, 27, 
    7, 11, 6, 23, 0, 58, 2, 39, 1, 99, 5, 62, 3, 38, 4,  1, 8, 97, 
    8, 56, 7, 23, 3, 37, 5, 30, 6, 37, 0, 42, 4, 46, 1, 17, 2, 69, 
    1, 51, 3, 57, 7, 33, 0, 76, 4, 73, 5, 45, 6, 60, 8, 94, 2,  2
  };
  const int q0554[] = {
    9, 9, // Number of jobs and machines
    5, 34, 2,  8, 8, 30, 4, 80, 7, 65, 1, 57, 6, 66, 3, 20, 0, 89, 
    2, 61, 1, 67, 4, 55, 3, 67, 7, 16, 8, 68, 0,  8, 5, 26, 6, 26, 
    7, 30, 6, 33, 2, 95, 3,  3, 1, 86, 4, 15, 0,  9, 5, 83, 8, 26, 
    0, 53, 6, 17, 7, 77, 3, 55, 1, 10, 2, 33, 8, 69, 4, 95, 5, 45, 
    6, 74, 5, 30, 1,  4, 2, 17, 3, 92, 7, 57, 4,  2, 0, 98, 8, 67, 
    8, 53, 7, 54, 4, 38, 6,  6, 0,  8, 3, 49, 2, 49, 1, 85, 5, 60, 
    6,  3, 4, 96, 0, 28, 2,  6, 8, 43, 7, 74, 5, 79, 3, 20, 1, 77, 
    3, 36, 7, 29, 0, 74, 5, 77, 8, 99, 4, 86, 1, 30, 6, 27, 2, 13, 
    8,  7, 3, 40, 5, 51, 7, 92, 4, 19, 6, 77, 2, 29, 1, 19, 0,  2
  };
  const int q0555[] = {
    9, 9, // Number of jobs and machines
    4, 48, 7, 70, 0, 73, 3, 61, 5, 28, 1, 11, 6,  9, 8, 38, 2, 72, 
    3, 13, 6, 53, 4, 45, 8, 40, 2, 99, 7, 88, 1, 77, 5, 97, 0,  2, 
    0,  9, 4, 18, 1, 89, 7, 66, 3, 23, 8, 42, 6, 38, 5, 58, 2, 66, 
    0, 48, 2, 73, 3, 36, 1, 60, 7, 70, 5, 61, 4, 74, 8,  1, 6, 46, 
    6, 79, 0, 45, 5, 30, 1, 21, 7, 92, 3, 50, 2, 39, 4, 22, 8, 29, 
    7, 65, 0, 97, 8, 34, 6, 55, 4, 31, 5, 19, 2, 94, 1, 86, 3, 63, 
    8, 35, 6, 82, 1,  8, 4, 73, 7, 45, 2, 84, 3, 57, 5, 57, 0, 16, 
    4, 77, 3, 50, 1, 59, 2, 86, 0, 21, 5, 13, 7, 38, 6, 56, 8, 12, 
    7,  3, 5, 37, 4, 87, 0, 66, 1, 95, 3, 24, 6, 98, 2,  9, 8, 24
  };
  const int q0556[] = {
    9, 9, // Number of jobs and machines
    6, 34, 8, 98, 4, 24, 1, 31, 7, 58, 5, 43, 3, 73, 2, 13, 0, 25, 
    2, 59, 5, 38, 6, 76, 1,  1, 8, 53, 4, 91, 3, 14, 7, 55, 0, 32, 
    4, 30, 2, 50, 7, 14, 5, 66, 0, 20, 6, 73, 8, 12, 1, 46, 3, 61, 
    2, 17, 3, 73, 4, 36, 8, 14, 6,  4, 0, 30, 5, 59, 7, 75, 1, 59, 
    5, 12, 7,  6, 6, 74, 2, 56, 1, 60, 0, 89, 3, 15, 8, 34, 4, 58, 
    5, 72, 6, 40, 3, 23, 1,  3, 2, 65, 4, 59, 7, 31, 0, 89, 8, 43, 
    8, 76, 2, 27, 7, 32, 1, 14, 6, 86, 0,  1, 3, 68, 5, 73, 4, 66, 
    0, 98, 1, 46, 7, 19, 4,  1, 6, 60, 8, 51, 5, 18, 3, 64, 2, 31, 
    2,  8, 1, 11, 3, 68, 7, 42, 5, 41, 0, 22, 6, 47, 4, 73, 8, 87
  };
  const int q0557[] = {
    9, 9, // Number of jobs and machines
    8, 94, 7, 58, 5,  4, 4, 31, 1, 61, 3, 54, 2, 71, 0, 43, 6, 10, 
    3, 48, 7, 14, 5, 62, 1, 96, 2, 15, 0, 44, 8, 99, 6, 15, 4, 16, 
    0, 96, 8, 74, 1, 37, 3, 28, 6, 63, 2, 49, 5, 53, 4, 31, 7,  3, 
    8, 15, 6, 58, 3, 27, 0, 75, 4,  6, 2, 40, 7, 73, 5, 16, 1, 66, 
    0, 50, 4, 80, 1, 89, 7, 70, 8, 27, 6, 18, 5, 96, 3, 66, 2, 62, 
    1, 92, 3, 34, 0, 70, 8, 52, 4, 39, 2, 79, 7, 10, 6, 14, 5, 13, 
    1, 84, 7, 93, 3, 39, 2, 90, 0, 46, 5, 52, 4,  8, 6, 83, 8, 27, 
    2, 47, 1, 68, 3, 93, 8, 29, 5, 26, 0, 22, 7, 24, 6, 61, 4, 26, 
    5, 55, 4, 99, 3, 14, 2, 43, 1, 90, 8, 52, 6, 89, 7, 27, 0, 32
  };
  const int q0558[] = {
    9, 9, // Number of jobs and machines
    7, 10, 3, 91, 0, 85, 6, 41, 2, 36, 1, 96, 5, 40, 4, 48, 8, 36, 
    3, 10, 2, 76, 4, 63, 6, 15, 1, 46, 5, 47, 8, 56, 7,  1, 0, 59, 
    4, 45, 5, 41, 8, 25, 6, 63, 7, 21, 1, 22, 2, 92, 0,  2, 3, 82, 
    8, 17, 1, 48, 5, 92, 2, 70, 0, 18, 6, 59, 3, 42, 4, 74, 7, 59, 
    0, 63, 8, 53, 5,  3, 3, 50, 4, 97, 1, 83, 7, 30, 6, 57, 2, 97, 
    1, 40, 2,  4, 3, 41, 6, 13, 4, 93, 7, 64, 0,  4, 8, 49, 5, 86, 
    0,  9, 4, 43, 6, 70, 1, 69, 7, 16, 8, 72, 3,  3, 5, 60, 2, 63, 
    5, 11, 1, 30, 4, 32, 7, 87, 3,  6, 8, 74, 6, 50, 2, 51, 0, 49, 
    3,  4, 6, 26, 4, 48, 0, 97, 5, 22, 1, 97, 2, 64, 7, 55, 8, 41
  };
  const int q0559[] = {
    9, 9, // Number of jobs and machines
    7, 61, 2, 87, 3, 27, 5, 51, 4, 89, 8, 85, 6, 81, 0, 80, 1, 22, 
    4, 10, 0, 19, 8, 11, 6, 51, 3, 30, 7, 65, 5, 60, 2, 55, 1, 76, 
    4, 68, 2, 65, 5, 65, 3, 22, 1, 31, 8, 52, 6, 86, 0, 35, 7, 56, 
    8, 24, 0, 17, 7, 43, 5, 21, 4, 37, 2, 29, 6, 71, 3, 87, 1, 97, 
    0, 30, 6, 10, 7,  4, 3, 60, 2, 41, 4, 36, 8, 44, 5, 23, 1, 54, 
    0, 46, 6, 70, 7,  3, 3, 74, 2, 63, 8, 96, 1, 49, 5, 83, 4, 21, 
    0, 54, 1, 38, 8, 21, 2, 90, 5, 69, 6, 98, 4, 85, 3,  4, 7, 66, 
    1, 25, 3,  6, 6, 60, 5, 52, 0, 96, 7, 55, 8,  5, 4,  2, 2, 22, 
    8,  5, 1, 42, 0, 26, 5, 20, 2, 29, 3,  2, 6, 93, 4, 63, 7, 78
  };
  const int q0560[] = {
    9, 9, // Number of jobs and machines
    7, 62, 6, 68, 3, 16, 2, 14, 8, 70, 0, 12, 1, 53, 4, 29, 5, 54, 
    2, 73, 0, 32, 8, 34, 5, 15, 1, 54, 7, 70, 6, 61, 4, 94, 3, 75, 
    1, 28, 2, 85, 4, 48, 5, 90, 8, 94, 3,  9, 0, 57, 7, 99, 6, 38, 
    4, 16, 0, 45, 3, 75, 8, 86, 5, 37, 7, 37, 6, 51, 2, 78, 1, 82, 
    2, 43, 7, 60, 0, 91, 4, 67, 8, 87, 6, 58, 1, 62, 5, 25, 3, 57, 
    8, 54, 7, 10, 0, 93, 3, 75, 1, 84, 2, 40, 6, 34, 4, 90, 5, 45, 
    5, 74, 4, 74, 0, 65, 8, 76, 6, 51, 7, 16, 2, 15, 1, 86, 3, 46, 
    6, 13, 8, 84, 4, 95, 3, 24, 2, 41, 0, 80, 5, 61, 1, 76, 7,  1, 
    3, 76, 0, 97, 5, 95, 8, 57, 7, 31, 1, 57, 2, 82, 6, 92, 4,  1
  };
  const int q0561[] = {
    9, 9, // Number of jobs and machines
    1,  3, 3, 37, 6, 24, 5, 60, 0, 15, 2, 31, 4, 97, 8, 26, 7,  1, 
    7, 80, 3, 44, 4, 62, 1, 79, 8, 59, 6,  5, 2, 75, 0,  3, 5, 37, 
    4, 56, 8, 59, 0, 43, 1, 47, 2, 15, 5, 16, 6, 67, 3, 21, 7, 53, 
    8, 37, 2, 75, 3, 47, 1, 58, 7, 90, 4, 33, 5, 90, 0, 13, 6, 35, 
    6, 57, 0, 25, 1, 38, 7, 18, 8, 85, 3, 90, 2, 39, 5, 68, 4, 82, 
    2, 30, 8, 39, 0, 55, 4, 35, 3, 48, 1, 48, 5, 32, 7, 18, 6, 26, 
    4,  6, 1, 28, 7, 10, 0, 63, 2, 16, 8,  4, 3,  6, 5, 90, 6, 49, 
    8, 13, 7, 93, 4, 63, 0, 81, 1, 48, 3, 22, 6, 69, 2, 71, 5,  9, 
    0, 30, 4, 44, 7, 97, 8, 63, 5, 18, 6,  2, 3, 32, 2,  6, 1, 52
  };
  const int q0562[] = {
    9, 9, // Number of jobs and machines
    6, 31, 8, 43, 7, 77, 2, 96, 4, 66, 0, 82, 3, 83, 1, 28, 5, 28, 
    3, 12, 8, 61, 4, 60, 2, 15, 7, 37, 5, 73, 1, 91, 0, 29, 6, 71, 
    6,  1, 3, 17, 7,  8, 4, 95, 8, 64, 2, 24, 0, 55, 1, 19, 5, 94, 
    2, 74, 5, 52, 3, 20, 7, 73, 0, 69, 4, 22, 1, 77, 6, 48, 8, 20, 
    6, 65, 3, 91, 4, 68, 2, 12, 1,  4, 7, 96, 8, 30, 5, 37, 0, 57, 
    2, 58, 7, 63, 0, 84, 4, 98, 3, 51, 8, 29, 5,  3, 1, 55, 6, 48, 
    4, 95, 3, 66, 7, 91, 6, 87, 5, 48, 2, 37, 1, 95, 8, 23, 0, 40, 
    8, 39, 4, 65, 7, 96, 6, 94, 5, 74, 2,  4, 3, 16, 1, 61, 0, 91, 
    2, 11, 7, 88, 6, 67, 0, 41, 8, 52, 5, 99, 3, 51, 4, 33, 1, 56
  };
  const int q0563[] = {
    9, 9, // Number of jobs and machines
    7, 19, 3, 18, 0, 60, 5, 84, 8, 88, 2, 40, 1, 46, 4, 59, 6, 82, 
    6, 55, 0, 30, 1, 15, 5, 70, 2, 80, 7, 27, 4, 32, 8, 48, 3, 89, 
    6, 77, 8,  1, 7, 93, 0,  5, 2, 42, 3, 13, 1, 80, 4, 23, 5,  8, 
    4, 35, 5, 76, 8, 48, 1, 27, 6, 10, 3, 68, 7, 86, 0, 35, 2, 67, 
    2, 42, 4, 12, 5, 15, 1,  8, 8, 36, 0, 70, 6, 24, 3, 62, 7,  5, 
    4, 11, 1, 81, 3, 78, 7, 95, 0, 36, 8, 69, 6, 65, 5, 56, 2, 75, 
    2, 75, 0, 66, 3, 43, 7, 33, 5, 77, 6, 44, 4, 82, 8, 37, 1, 51, 
    0, 69, 4, 14, 2, 58, 6, 77, 3, 77, 8, 34, 5, 55, 1, 20, 7, 13, 
    1, 46, 0, 73, 8, 81, 6, 62, 2, 94, 4, 98, 5, 92, 3, 92, 7, 28
  };
  const int q0564[] = {
    9, 9, // Number of jobs and machines
    4, 45, 3,  9, 8, 39, 2, 57, 5, 97, 0, 20, 7, 40, 1, 28, 6,  2, 
    0, 16, 8, 52, 7, 27, 4, 49, 1, 39, 2, 46, 3, 50, 6, 56, 5, 13, 
    3,  7, 0, 84, 1, 70, 7,  7, 5, 29, 8, 49, 2, 30, 6,  6, 4, 24, 
    7, 21, 6, 35, 5, 72, 0, 90, 3, 20, 4, 30, 1,  6, 2, 26, 8, 59, 
    5, 30, 2, 75, 1, 93, 3,  1, 7, 39, 4, 54, 0, 75, 8, 35, 6, 64, 
    1, 38, 7, 80, 5, 12, 3, 96, 0, 59, 2, 72, 8, 73, 4, 66, 6, 46, 
    7, 75, 3, 86, 8, 37, 4, 37, 6,  6, 0, 22, 2, 86, 1,  2, 5,  5, 
    6, 41, 3, 56, 0, 62, 2, 97, 4, 54, 1, 77, 5,  3, 8, 67, 7, 93, 
    6, 56, 0, 56, 8, 48, 1, 91, 3, 88, 4, 44, 7, 76, 5, 98, 2,  8
  };
  const int q0565[] = {
    9, 9, // Number of jobs and machines
    7, 44, 3, 47, 8, 21, 2, 36, 1, 76, 6, 39, 4, 57, 0, 25, 5, 24, 
    7, 22, 8, 37, 1, 47, 3, 28, 6, 70, 4, 35, 0, 17, 5, 92, 2, 66, 
    0, 33, 4, 14, 1, 13, 3, 61, 6, 91, 8, 34, 7, 44, 5, 36, 2,  3, 
    1, 23, 3, 70, 4, 10, 7, 75, 5, 86, 6, 45, 0, 60, 8, 82, 2, 66, 
    3, 35, 5, 31, 8, 66, 7, 29, 0,  5, 4,  9, 6, 71, 1, 48, 2, 88, 
    7, 63, 8, 70, 1, 43, 4, 50, 2, 72, 5, 31, 0, 20, 3, 40, 6,  8, 
    4,  7, 7,  4, 1, 19, 5, 94, 3, 82, 6, 12, 8,  7, 0, 45, 2, 73, 
    4, 72, 0, 63, 6, 90, 7, 22, 1, 55, 8, 86, 2, 71, 5, 28, 3,  7, 
    4, 45, 5, 60, 8, 11, 2, 60, 1, 96, 0,  9, 6, 48, 7, 68, 3, 84
  };
  const int q0566[] = {
    9, 9, // Number of jobs and machines
    8,  4, 2, 36, 3, 64, 1, 85, 5, 61, 4, 10, 6, 17, 7, 85, 0, 56, 
    3, 74, 4,  4, 6, 12, 1, 58, 2,  4, 7, 66, 8, 98, 5, 93, 0, 42, 
    1, 47, 7, 13, 5, 66, 4, 45, 6, 69, 2, 32, 0, 37, 3,  4, 8, 79, 
    2, 87, 4, 43, 6, 98, 5, 52, 1, 37, 7,  7, 0, 30, 8, 80, 3, 46, 
    3, 17, 1,  8, 7, 51, 8, 88, 2, 72, 0, 27, 4,  9, 6,  7, 5, 94, 
    6, 42, 3,  9, 5, 98, 2, 42, 1, 80, 7, 75, 8, 94, 4, 44, 0, 67, 
    1, 71, 7, 86, 5, 65, 0, 15, 4, 74, 6, 64, 8, 44, 2, 11, 3, 53, 
    0, 46, 1, 42, 6, 83, 5,  1, 2, 41, 4, 96, 7, 67, 3, 48, 8, 45, 
    8, 50, 7, 41, 2,  3, 0, 72, 3, 83, 5, 73, 6, 46, 1, 99, 4, 26
  };
  const int q0567[] = {
    9, 9, // Number of jobs and machines
    0, 47, 6, 67, 4, 75, 2, 54, 8, 95, 5, 22, 7, 79, 3, 71, 1, 46, 
    1, 66, 6,  8, 3, 51, 4, 96, 7, 76, 0, 63, 5, 91, 8, 23, 2, 49, 
    8, 52, 2, 36, 0, 13, 7, 56, 5,  2, 1, 19, 3, 99, 6, 34, 4, 71, 
    4, 78, 8, 85, 7, 23, 2, 98, 3, 72, 6, 52, 1, 39, 0,  7, 5, 31, 
    3, 53, 5, 35, 7, 11, 4, 96, 8, 74, 2, 34, 1, 85, 6, 95, 0, 33, 
    1, 60, 2, 69, 3, 63, 0, 79, 5, 11, 7,  2, 6, 33, 8, 82, 4,  5, 
    2, 23, 5, 25, 6, 69, 4, 45, 8, 19, 1, 42, 3, 26, 0, 26, 7, 32, 
    8,  1, 5, 38, 3, 97, 2, 87, 1, 40, 4, 41, 0, 69, 6, 35, 7, 28, 
    1, 38, 2, 86, 8, 16, 7, 66, 4, 10, 0, 92, 3, 54, 5, 68, 6, 65
  };
  const int q0568[] = {
    9, 9, // Number of jobs and machines
    7, 19, 3, 50, 2, 30, 4, 16, 6, 91, 5, 80, 1, 16, 0, 29, 8, 38, 
    1, 32, 7, 46, 4, 25, 5, 32, 0, 42, 8, 65, 6,  4, 3, 79, 2, 10, 
    0, 36, 3,  5, 6, 21, 2, 63, 8, 39, 1, 39, 4, 35, 5,  6, 7, 95, 
    8, 80, 0, 97, 4, 21, 5, 45, 1, 19, 2, 81, 6, 91, 7,  6, 3, 97, 
    8, 35, 4, 84, 5, 86, 2, 54, 0, 66, 3, 25, 1, 27, 7,  8, 6, 37, 
    4, 94, 7,  3, 8, 35, 5, 45, 0, 87, 6, 45, 1, 11, 3, 37, 2, 20, 
    8, 63, 1, 55, 5, 20, 4, 53, 7, 11, 6, 43, 3, 83, 0, 25, 2,  6, 
    0,  4, 7, 30, 3, 50, 8, 66, 4,  5, 2, 62, 5, 46, 1, 36, 6, 88, 
    2, 67, 5, 27, 0, 73, 4, 46, 7, 27, 6, 51, 1, 12, 3, 48, 8, 32
  };
  const int q0569[] = {
    9, 9, // Number of jobs and machines
    4, 79, 6, 74, 8, 91, 7, 24, 5, 34, 0,  3, 2, 11, 3, 37, 1, 33, 
    6, 69, 0,  3, 3, 87, 2, 67, 8, 59, 5, 35, 7, 80, 1, 12, 4, 77, 
    6, 24, 1, 63, 5, 33, 3, 62, 0, 13, 7, 72, 2, 34, 4, 52, 8, 71, 
    3, 91, 1, 70, 5, 36, 6, 65, 8, 33, 2, 40, 4, 36, 7, 41, 0,  9, 
    8, 38, 3, 17, 4, 42, 0, 94, 2, 19, 5, 72, 7,  7, 1, 77, 6, 95, 
    3, 66, 2, 63, 5, 59, 8,  3, 6, 99, 4, 88, 7,  7, 0, 45, 1, 53, 
    7, 63, 3, 61, 8, 20, 0,  5, 1,  2, 4,  8, 5, 89, 2, 65, 6, 64, 
    3, 42, 5, 33, 4, 29, 2, 57, 8, 84, 1, 28, 7, 18, 0, 50, 6, 16, 
    0, 98, 4, 31, 2, 19, 3, 72, 8, 68, 7, 46, 6,  2, 5, 30, 1, 93
  };
  const int q0570[] = {
    9, 9, // Number of jobs and machines
    4,  1, 2, 57, 6, 60, 1, 24, 5, 80, 7, 65, 0, 13, 3, 25, 8,  5, 
    7, 56, 8, 54, 6, 37, 2,  7, 0, 21, 4, 88, 1, 88, 3, 90, 5, 47, 
    5, 64, 3, 90, 4, 68, 6, 20, 0, 93, 2, 47, 7, 41, 1, 51, 8, 60, 
    3, 46, 8, 36, 1, 85, 7, 29, 6, 43, 5, 53, 0, 60, 4, 76, 2, 94, 
    4, 55, 2, 63, 6, 52, 3, 52, 1, 48, 8, 60, 7,  5, 0, 74, 5, 73, 
    3, 84, 6, 63, 1, 62, 7, 21, 0, 52, 4, 52, 2, 72, 8,  1, 5, 87, 
    0, 89, 7, 69, 5, 25, 2, 30, 6, 45, 8, 76, 3, 15, 1, 80, 4, 52, 
    3, 98, 8, 63, 5, 28, 6, 58, 1, 26, 2, 87, 7, 94, 4, 78, 0, 38, 
    8, 38, 0, 11, 1, 28, 6, 88, 7, 94, 4, 61, 3, 87, 2, 67, 5, 95
  };
  const int q0571[] = {
    9, 9, // Number of jobs and machines
    6, 76, 7, 65, 5, 71, 8, 36, 1, 94, 4, 88, 3,  7, 0, 36, 2, 81, 
    7, 69, 2, 86, 0, 78, 4,  8, 3, 61, 8, 58, 5, 65, 1,  3, 6, 34, 
    0, 38, 7, 95, 2, 22, 3, 33, 6, 38, 5, 68, 4,  7, 8, 39, 1, 84, 
    4, 73, 1, 93, 6, 62, 5, 90, 3,  7, 8, 12, 2, 99, 0, 45, 7, 49, 
    2, 69, 6, 51, 0, 39, 4, 72, 3, 48, 8, 74, 7, 52, 1, 51, 5, 32, 
    5, 33, 2, 32, 3,  3, 4, 91, 8, 84, 6, 36, 0, 77, 1, 35, 7, 87, 
    6, 98, 1, 22, 8, 83, 0, 25, 3, 67, 5, 77, 4, 88, 7, 96, 2, 26, 
    1, 85, 2, 22, 6, 94, 0, 22, 3, 68, 8, 60, 7, 36, 4, 37, 5, 10, 
    2, 99, 6, 69, 4, 28, 5, 47, 8, 17, 0, 11, 1, 40, 7, 84, 3, 90
  };
  const int q0572[] = {
    9, 9, // Number of jobs and machines
    8, 20, 3,  2, 7, 94, 0, 31, 2, 14, 6, 35, 1, 51, 4, 49, 5, 72, 
    2, 59, 0, 34, 4, 70, 7, 95, 5, 94, 1, 91, 3, 76, 8, 99, 6, 78, 
    5, 12, 3, 12, 2, 88, 7, 66, 0, 85, 8, 16, 1, 62, 4, 74, 6, 50, 
    6, 67, 0, 35, 2, 77, 4,  1, 1, 15, 5, 79, 7, 81, 8, 44, 3, 42, 
    3,  2, 4, 32, 6, 22, 7, 75, 1, 33, 0, 44, 2, 86, 8, 73, 5, 74, 
    7, 28, 2, 79, 6,  1, 0, 90, 5, 62, 3, 40, 1, 20, 8, 77, 4, 35, 
    5, 75, 3, 90, 2, 38, 0, 82, 6, 91, 7, 46, 1, 59, 4, 71, 8, 13, 
    3, 50, 8, 91, 7, 20, 1, 54, 0, 75, 4, 55, 2, 73, 5, 35, 6, 13, 
    1, 20, 7, 90, 6, 67, 8, 77, 2, 56, 0, 72, 4, 93, 3, 72, 5, 65
  };
  const int q0573[] = {
    9, 9, // Number of jobs and machines
    7, 74, 2, 99, 4, 57, 1, 94, 0,  9, 6, 48, 5, 86, 8, 82, 3, 12, 
    0, 13, 5, 26, 7, 20, 4, 37, 6, 10, 8, 50, 2, 57, 3, 59, 1, 51, 
    0, 16, 7, 25, 6, 16, 2, 14, 4, 16, 3, 80, 1, 53, 5, 32, 8, 35, 
    7, 30, 6, 20, 5, 56, 8, 90, 4, 84, 1, 61, 0, 25, 2, 12, 3, 15, 
    2,  4, 4, 40, 7, 61, 3, 53, 5, 88, 6, 56, 8, 67, 1, 27, 0, 82, 
    4,  3, 1, 71, 6, 79, 5, 28, 0, 48, 2, 86, 3, 17, 7, 35, 8, 22, 
    2, 74, 5, 47, 6, 39, 3, 71, 7, 20, 0, 46, 4, 85, 1, 18, 8, 75, 
    5, 71, 2, 45, 4, 68, 0,  6, 8, 66, 7, 50, 3,  5, 6, 55, 1, 88, 
    8, 70, 4, 62, 0,  7, 6, 50, 2,  7, 3, 42, 1, 16, 5, 38, 7, 82
  };
  const int q0574[] = {
    9, 9, // Number of jobs and machines
    2, 44, 8, 24, 6, 15, 4, 83, 3, 75, 1, 56, 0, 25, 5, 48, 7, 75, 
    2, 29, 5, 25, 4, 41, 0, 29, 6, 21, 7,  3, 8, 53, 3,  5, 1, 39, 
    7, 95, 6, 45, 3, 59, 8, 77, 2, 13, 1, 59, 0, 45, 4, 18, 5, 82, 
    5, 34, 0, 71, 3, 85, 2, 51, 1, 46, 7,  3, 6, 87, 4, 25, 8, 34, 
    2, 44, 4, 74, 5, 64, 1, 81, 6, 99, 8, 87, 3, 97, 7, 98, 0, 77, 
    4, 41, 5, 11, 1, 96, 2, 11, 3, 57, 8, 82, 7, 24, 0, 48, 6, 37, 
    4, 65, 2, 51, 7, 91, 8,  2, 0,  5, 6, 35, 5, 17, 1, 91, 3, 22, 
    6, 88, 5, 50, 4, 48, 1, 77, 2, 40, 0, 95, 3, 37, 7, 15, 8, 58, 
    0, 24, 5, 70, 8, 19, 6, 85, 2, 65, 7, 60, 3,  7, 4, 89, 1, 92
  };
  const int q0575[] = {
    9, 9, // Number of jobs and machines
    8, 24, 4,  1, 6, 95, 3, 54, 5, 51, 7, 59, 1, 30, 2, 46, 0, 40, 
    4, 18, 1, 60, 2,  2, 5, 11, 7, 94, 3, 25, 6,  6, 8, 52, 0, 64, 
    4, 47, 5, 60, 0, 30, 2,  7, 7, 89, 8, 89, 1, 51, 3, 92, 6, 17, 
    4,  1, 3, 66, 2, 38, 1, 73, 0, 15, 5,  3, 6, 20, 7, 59, 8, 37, 
    3, 57, 7, 37, 6, 95, 5, 11, 8, 42, 2, 26, 0, 94, 1, 86, 4, 74, 
    4, 16, 3, 46, 0, 47, 2, 85, 7, 18, 1, 99, 5, 48, 8, 63, 6, 48, 
    8, 94, 6, 18, 7, 87, 3, 19, 2, 45, 4, 42, 0, 15, 1, 91, 5, 19, 
    2, 23, 5, 12, 1,  2, 4, 11, 7, 51, 3, 77, 8, 94, 6, 98, 0, 17, 
    1, 15, 3, 49, 8, 29, 2, 90, 6, 18, 4, 29, 5, 26, 7, 60, 0, 29
  };
  const int q0576[] = {
    9, 9, // Number of jobs and machines
    1, 58, 0, 96, 7, 37, 5, 74, 2, 90, 6,  2, 3, 45, 4, 36, 8,  5, 
    0, 34, 7, 11, 6, 74, 4, 62, 3, 73, 8, 81, 2, 47, 1, 29, 5, 17, 
    8, 56, 0, 43, 5, 74, 3, 99, 1,  1, 2,  5, 6, 76, 7, 27, 4,  2, 
    8, 99, 5, 31, 7, 48, 0, 52, 2, 89, 6, 27, 1, 19, 3, 35, 4, 64, 
    7, 79, 6, 30, 3, 51, 1, 67, 2, 42, 4, 63, 5, 78, 8, 29, 0, 30, 
    6, 24, 2, 10, 0, 68, 7, 75, 3, 54, 1, 96, 8, 23, 4, 17, 5, 74, 
    1, 26, 2, 54, 4, 37, 0, 95, 3, 41, 7, 79, 8, 68, 5, 87, 6, 61, 
    6,  2, 8, 24, 2, 11, 5, 32, 4, 51, 3, 25, 7, 61, 1, 33, 0, 18, 
    0, 62, 1, 67, 3, 86, 7, 22, 4, 98, 5,  9, 2, 51, 8, 58, 6, 56
  };
  const int q0577[] = {
    9, 9, // Number of jobs and machines
    8, 33, 0, 39, 6, 70, 3, 54, 1, 65, 5, 11, 4, 21, 2, 75, 7, 71, 
    8, 79, 1, 24, 2, 87, 7, 63, 4, 60, 3, 49, 0, 22, 6, 15, 5, 62, 
    7,  3, 6, 73, 5, 73, 2, 91, 1, 84, 4, 25, 8, 43, 3, 79, 0, 66, 
    5, 98, 0, 98, 3, 18, 4, 60, 6, 93, 8, 50, 7, 89, 1, 60, 2, 45, 
    2, 61, 1, 55, 5, 83, 3, 98, 4, 30, 7, 55, 0, 90, 8, 78, 6, 25, 
    5, 15, 7, 58, 0, 42, 2, 20, 1, 22, 8, 97, 6, 46, 4, 88, 3, 97, 
    8, 32, 2, 48, 0, 24, 6, 26, 3, 88, 7, 42, 5, 70, 4, 50, 1, 87, 
    8, 79, 6, 21, 1,  5, 0, 83, 4,  6, 3, 67, 7, 18, 5,  4, 2, 39, 
    4, 62, 7, 76, 1, 93, 8, 33, 6, 40, 2, 78, 3, 79, 0, 17, 5, 94
  };
  const int q0578[] = {
    9, 9, // Number of jobs and machines
    3, 64, 2, 62, 1, 35, 5, 22, 0, 76, 7, 67, 8, 77, 6, 66, 4, 45, 
    0, 34, 3, 69, 2, 14, 8,  3, 7, 86, 5, 73, 1, 14, 6, 75, 4, 32, 
    7, 82, 4, 30, 6, 56, 3, 21, 1, 60, 8,  5, 0, 41, 5, 84, 2, 12, 
    6, 55, 8, 87, 3, 58, 1, 53, 7, 59, 4, 69, 0, 93, 2, 16, 5, 54, 
    5, 41, 1, 57, 4, 27, 2, 79, 6,  5, 0,  8, 3, 18, 7, 14, 8, 20, 
    0, 25, 5, 46, 7, 71, 2, 37, 6, 25, 1, 65, 4, 85, 8, 65, 3, 90, 
    5,  1, 0, 75, 4, 94, 6, 44, 1, 61, 2, 31, 3, 75, 7, 65, 8, 53, 
    2, 29, 1, 67, 7, 89, 5, 65, 6, 44, 0, 11, 4, 55, 8, 68, 3, 75, 
    7,  1, 4, 56, 2, 20, 8, 70, 1, 70, 5, 13, 0, 36, 6, 54, 3, 88
  };
  const int q0579[] = {
    9, 9, // Number of jobs and machines
    2, 18, 7, 84, 0, 18, 8, 98, 1, 87, 3, 39, 5, 95, 6, 18, 4, 51, 
    5,  3, 7, 30, 1, 33, 8,  1, 4, 68, 0, 65, 3, 35, 6, 91, 2, 80, 
    0,  6, 1, 71, 4, 20, 7, 10, 5,  2, 3, 55, 8, 68, 6, 54, 2, 49, 
    2, 16, 4, 91, 3, 41, 1, 80, 5, 24, 6, 10, 7, 36, 0, 36, 8, 97, 
    6, 98, 8, 77, 7, 78, 3, 54, 1, 35, 4, 19, 2, 60, 0, 41, 5, 54, 
    7, 55, 3, 12, 8, 88, 4, 14, 0, 24, 5, 96, 6,  4, 2, 39, 1, 51, 
    5, 15, 6, 79, 3, 58, 2, 63, 1, 44, 0, 40, 8, 14, 7, 90, 4,  4, 
    5, 44, 1, 37, 4, 40, 7, 13, 8, 48, 2, 84, 0, 56, 3, 19, 6, 36, 
    5, 89, 4, 68, 6, 54, 1, 13, 7, 45, 3, 22, 0, 66, 8, 25, 2, 34
  };
  const int q0580[] = {
    9, 9, // Number of jobs and machines
    2, 34, 3, 93, 8, 54, 4, 36, 7, 81, 1,  8, 6, 58, 5, 31, 0, 25, 
    4, 39, 2, 90, 6, 10, 7, 23, 0, 35, 1, 96, 8, 71, 3, 79, 5,  3, 
    0,  7, 4, 33, 5, 40, 3, 15, 2, 80, 6, 42, 8, 79, 1, 49, 7, 83, 
    1, 86, 5, 49, 6, 49, 0, 56, 7, 62, 2, 76, 8, 91, 4,  4, 3, 70, 
    1, 70, 6, 86, 7, 41, 3, 87, 0, 89, 8,  2, 5, 62, 2, 78, 4, 90, 
    7, 94, 2, 37, 4, 75, 8, 70, 1, 71, 0, 73, 5, 30, 6, 98, 3, 54, 
    2, 44, 1, 80, 5, 73, 7, 44, 4, 55, 8, 53, 3, 12, 6,  5, 0, 95, 
    4, 30, 5, 21, 8, 19, 0, 24, 3,  3, 1, 87, 6, 25, 2, 20, 7, 26, 
    1, 93, 4, 70, 7,  4, 6, 17, 3, 34, 8, 28, 2, 73, 0, 52, 5, 95
  };
  const int q0581[] = {
    9, 9, // Number of jobs and machines
    2, 49, 1, 22, 3, 25, 4, 17, 5, 64, 8, 93, 6, 46, 0, 90, 7, 40, 
    1, 78, 0, 59, 5, 62, 4, 11, 6, 98, 2, 16, 3, 94, 7, 59, 8,  8, 
    6, 83, 0, 84, 7, 32, 1, 15, 8, 23, 5, 29, 2,  3, 3,  5, 4, 39, 
    2, 67, 3,  1, 0, 22, 7, 34, 8, 39, 6, 87, 1, 88, 5, 80, 4, 81, 
    8,  6, 0, 85, 7, 95, 4,  1, 6, 67, 1, 93, 5,  7, 2, 15, 3, 33, 
    1, 68, 3,  2, 5, 67, 2, 11, 4, 17, 6, 94, 8, 36, 7, 30, 0, 15, 
    3, 22, 8, 12, 7, 58, 4, 21, 0, 64, 5,  6, 1, 80, 6, 35, 2, 27, 
    3, 38, 5, 84, 8, 40, 7, 85, 4,  6, 1, 85, 0, 93, 6, 45, 2, 27, 
    2, 87, 0, 28, 5, 70, 1, 76, 6, 71, 4, 30, 3, 92, 8, 12, 7, 30
  };
  const int q0582[] = {
    9, 9, // Number of jobs and machines
    4, 21, 6, 73, 3, 89, 2, 33, 5, 98, 8, 95, 7,  5, 1, 95, 0, 29, 
    1, 76, 3, 57, 2, 90, 8, 63, 5,  7, 0, 26, 6, 72, 4, 52, 7, 80, 
    8,  1, 1, 63, 2,  9, 4, 68, 6,  8, 7, 58, 0, 34, 3, 33, 5, 75, 
    1, 77, 7, 13, 5,  2, 8,  1, 3, 83, 0, 69, 2, 73, 6, 64, 4, 29, 
    2, 18, 1, 98, 4, 12, 6, 20, 7, 45, 8, 24, 5, 72, 0, 88, 3, 93, 
    7, 59, 6, 25, 2, 74, 3, 11, 5, 95, 4, 67, 1, 79, 0, 53, 8, 37, 
    4, 69, 2, 57, 1, 97, 0, 50, 7, 56, 3, 40, 5, 39, 6, 91, 8, 25, 
    3, 83, 0, 34, 6, 45, 2, 17, 4, 57, 1, 72, 7,  3, 8,  3, 5, 82, 
    3, 39, 5, 91, 2, 59, 8, 82, 1, 62, 7,  8, 6, 22, 0, 75, 4, 95
  };
  const int q0583[] = {
    9, 9, // Number of jobs and machines
    4, 89, 2, 75, 6, 74, 5, 56, 8,  2, 1, 57, 0, 96, 7, 82, 3, 41, 
    2, 11, 7,  8, 4, 30, 1, 30, 8, 55, 0, 43, 3, 61, 5, 97, 6, 88, 
    6, 41, 1, 88, 8, 77, 5, 27, 3, 31, 0, 32, 4, 15, 2, 65, 7,  1, 
    1, 33, 4, 52, 7, 15, 8, 98, 6, 81, 5,  3, 0, 61, 2, 44, 3, 71, 
    4, 43, 1, 90, 3, 19, 7, 63, 8, 92, 0, 40, 6, 48, 2, 89, 5, 11, 
    0, 45, 5, 87, 3, 78, 2, 86, 4, 59, 6, 41, 7, 49, 8, 25, 1, 11, 
    6, 25, 4, 73, 5, 95, 2,  8, 3, 59, 0, 42, 8,  9, 1, 56, 7, 68, 
    5, 56, 6, 15, 8, 28, 7,  7, 4,  9, 0, 29, 2, 45, 3, 35, 1, 21, 
    8, 45, 5, 90, 4, 12, 3, 13, 2, 21, 1, 59, 0, 75, 7, 71, 6, 65
  };
  const int q0584[] = {
    9, 9, // Number of jobs and machines
    0, 20, 2, 43, 3, 70, 7, 74, 1, 99, 4,  5, 8, 49, 6,  4, 5, 80, 
    3, 64, 0, 23, 1, 39, 6, 74, 8, 92, 5, 10, 4, 35, 2,  4, 7, 76, 
    5, 53, 0, 24, 3, 25, 1, 54, 4, 10, 7, 92, 2, 61, 8, 78, 6, 24, 
    8, 51, 2, 17, 0, 67, 1,  1, 3, 23, 5, 21, 7, 44, 4,  5, 6, 28, 
    8, 19, 4, 79, 5,  2, 2, 28, 7,  7, 6, 33, 1,  5, 0, 95, 3, 58, 
    7, 75, 4, 26, 0, 71, 5, 30, 2, 77, 1, 31, 8, 13, 3, 52, 6,  3, 
    6, 26, 0, 33, 3, 49, 2, 78, 8, 15, 1, 17, 4, 41, 7, 61, 5, 18, 
    5, 94, 8, 59, 0, 15, 4, 46, 3, 40, 6, 71, 2, 96, 7, 78, 1, 13, 
    1, 40, 6, 69, 7, 21, 2, 42, 5, 51, 0, 30, 8, 82, 3, 10, 4, 65
  };
  const int q0585[] = {
    9, 9, // Number of jobs and machines
    4, 17, 2, 43, 5, 60, 1, 23, 7, 36, 6,  1, 3, 97, 8, 58, 0, 25, 
    5, 76, 4, 92, 6,  6, 8, 77, 7, 43, 3, 92, 2, 68, 1,  4, 0, 78, 
    3, 27, 8,  6, 4, 94, 6,  9, 0, 96, 1, 82, 2, 38, 7, 93, 5, 78, 
    2, 81, 8, 13, 0, 51, 3, 33, 1, 94, 7, 44, 6, 29, 5, 56, 4, 57, 
    2, 66, 5, 41, 7, 64, 4, 37, 0, 40, 1, 98, 6, 20, 8, 11, 3,  7, 
    6, 92, 8, 42, 0, 72, 7, 92, 2, 33, 5, 44, 4, 25, 1, 66, 3, 36, 
    2, 64, 8, 15, 3, 55, 4, 22, 6, 73, 1, 14, 0, 73, 7, 64, 5, 98, 
    6, 62, 1, 96, 8, 97, 4, 67, 0, 22, 3, 93, 5, 63, 7, 76, 2, 46, 
    1, 82, 0, 81, 3, 76, 5, 34, 6, 54, 2, 12, 7, 16, 4, 19, 8, 81
  };
  const int q0586[] = {
    9, 9, // Number of jobs and machines
    3, 15, 5, 80, 1, 94, 8, 14, 6, 72, 2,  7, 4, 49, 0, 64, 7,  1, 
    1, 30, 6,  9, 2, 60, 8, 15, 5, 43, 3, 58, 4, 40, 7, 26, 0, 36, 
    7,  2, 5, 80, 3, 99, 0, 14, 8, 47, 6, 43, 1, 78, 4, 47, 2,  5, 
    5, 80, 0, 76, 2,  2, 1, 90, 4, 78, 8, 61, 3, 13, 6, 25, 7, 98, 
    3, 24, 8, 76, 2, 76, 4, 39, 6, 16, 7, 88, 5, 57, 0, 14, 1,  2, 
    6, 53, 4, 57, 3,  7, 8, 83, 7, 85, 2, 76, 5,  9, 1,  5, 0, 16, 
    6, 59, 0, 90, 4,  6, 8, 81, 5, 91, 1, 77, 2, 26, 3, 40, 7, 56, 
    3, 71, 8, 33, 7, 63, 5, 36, 2, 31, 1, 15, 6, 48, 4, 14, 0, 75, 
    0, 34, 6, 92, 8, 35, 2, 97, 3, 55, 5, 93, 7, 82, 4, 92, 1,  7
  };
  const int q0587[] = {
    9, 9, // Number of jobs and machines
    6, 72, 3, 59, 2,  9, 0, 48, 7, 49, 8, 49, 5, 53, 1, 13, 4, 45, 
    6, 45, 0, 58, 8, 16, 1, 15, 4, 63, 3, 69, 5, 59, 7, 38, 2, 86, 
    1, 25, 2, 74, 6, 19, 8, 85, 3, 19, 5, 28, 7, 33, 4, 79, 0, 18, 
    1,  5, 6, 66, 5, 92, 7, 79, 8, 40, 0, 63, 2, 88, 4, 38, 3, 81, 
    7,  7, 2, 56, 5, 41, 0, 96, 8, 17, 6, 52, 3, 40, 1, 58, 4,  8, 
    5, 35, 3,  4, 6, 31, 8, 47, 1, 26, 0, 40, 2, 48, 7, 56, 4, 46, 
    5, 39, 4, 89, 3, 35, 1, 31, 0, 27, 6, 37, 8, 96, 7, 13, 2, 89, 
    0, 26, 5, 28, 1, 60, 8, 17, 4, 34, 6, 94, 2, 10, 3, 56, 7,  5, 
    2, 89, 7, 43, 4,  8, 3, 69, 8, 38, 1, 94, 0, 10, 5,  6, 6, 89
  };
  const int q0588[] = {
    9, 9, // Number of jobs and machines
    0, 13, 6, 98, 1, 65, 5, 30, 7, 68, 2, 81, 3, 82, 4, 14, 8, 85, 
    5, 87, 3, 78, 1, 96, 6, 32, 0, 20, 8, 18, 2,  6, 7,  5, 4, 68, 
    1, 42, 8, 69, 5, 70, 7, 56, 3, 13, 2, 59, 6, 81, 0, 39, 4, 98, 
    3, 23, 7, 65, 0, 57, 2, 38, 4,  3, 8, 68, 1, 79, 5, 89, 6, 47, 
    8, 27, 4, 94, 5, 25, 3, 99, 7, 35, 2, 18, 1, 83, 6, 77, 0, 82, 
    1, 85, 3, 94, 4, 88, 5, 14, 6, 55, 0, 94, 7, 48, 8,  2, 2, 40, 
    6, 51, 2, 95, 7, 93, 0, 92, 8, 36, 3, 28, 5, 96, 1, 25, 4, 54, 
    6, 32, 8, 49, 5,  9, 2, 50, 4, 78, 3, 26, 0, 53, 1, 88, 7, 66, 
    8, 77, 0, 89, 5, 69, 1, 18, 4, 23, 2, 85, 7,  6, 3, 73, 6, 31
  };
  const int q0589[] = {
    9, 9, // Number of jobs and machines
    6, 11, 7, 57, 0,  3, 2, 70, 1, 70, 8, 73, 5, 23, 4, 37, 3, 19, 
    2, 68, 1, 15, 7, 74, 8, 66, 3, 66, 5, 56, 0, 76, 6, 57, 4, 68, 
    1, 48, 4, 75, 2, 27, 3, 18, 5, 29, 8, 31, 0,  6, 6, 20, 7, 82, 
    4, 89, 7, 87, 5, 79, 1, 45, 2, 65, 0, 49, 6, 76, 3, 55, 8, 91, 
    2, 80, 8, 25, 1, 40, 0, 46, 7, 52, 6, 50, 4, 99, 3, 17, 5, 85, 
    5, 71, 0, 22, 1, 24, 8, 99, 6, 31, 4,  1, 2,  6, 7, 77, 3, 48, 
    2, 27, 3, 11, 5, 37, 7, 15, 4, 20, 0, 42, 1, 52, 6, 59, 8, 63, 
    5, 63, 8,  2, 6, 39, 1, 53, 4, 65, 2, 24, 3, 75, 0,  4, 7, 82, 
    3, 52, 2, 87, 8, 64, 0, 12, 1, 65, 4, 66, 5, 82, 6, 53, 7, 32
  };
  const int q0590[] = {
    9, 9, // Number of jobs and machines
    2, 92, 6, 52, 3, 80, 5, 77, 1, 82, 7, 92, 0, 74, 4, 90, 8, 22, 
    5, 23, 7, 35, 0, 32, 6, 77, 3, 38, 8, 43, 1, 40, 2, 40, 4, 79, 
    0, 71, 3, 81, 4, 52, 8, 61, 6, 39, 1, 15, 7, 74, 5, 50, 2, 76, 
    4, 22, 2, 55, 1,  3, 5, 43, 0, 61, 7,  6, 3,  9, 8, 91, 6, 52, 
    1, 45, 6, 12, 4,  8, 2, 14, 8,  8, 5, 49, 7,  7, 0, 10, 3, 39, 
    1, 99, 0, 15, 5, 82, 4, 79, 6, 42, 8, 19, 7, 97, 2, 31, 3, 82, 
    3, 33, 4, 14, 8, 70, 5, 69, 6, 96, 7, 67, 2, 67, 1, 61, 0,  7, 
    8, 49, 6, 31, 4,  1, 7, 39, 1, 20, 3, 72, 2, 90, 0, 51, 5, 35, 
    4, 95, 2, 71, 0, 48, 3,  7, 7, 93, 5, 65, 6, 49, 8, 84, 1, 79
  };
  const int q0591[] = {
    9, 9, // Number of jobs and machines
    3, 31, 7, 43, 8, 37, 6, 27, 0, 46, 1, 25, 4, 84, 2, 10, 5,  8, 
    4, 12, 2, 41, 7, 63, 5, 97, 0, 82, 1, 69, 3, 82, 6, 57, 8,  6, 
    7, 55, 5, 26, 6, 67, 2, 15, 8, 53, 4, 90, 1, 71, 3, 61, 0,  8, 
    5, 33, 6, 12, 7, 16, 2, 48, 3, 92, 4, 76, 0, 62, 1, 68, 8, 47, 
    3, 30, 0, 12, 1, 87, 4, 43, 8, 50, 5, 44, 2, 81, 7, 29, 6,  3, 
    4, 22, 5, 71, 6, 54, 8, 92, 2, 54, 0, 48, 7, 76, 1, 50, 3, 27, 
    3, 99, 2, 89, 4, 82, 8,  7, 5, 76, 7, 75, 1, 51, 6, 63, 0, 34, 
    0, 23, 3, 17, 2, 12, 5, 55, 1, 41, 4, 13, 8, 80, 6,  2, 7, 80, 
    3, 88, 7, 33, 0, 54, 1, 36, 4, 60, 5, 18, 2, 70, 8,  9, 6, 77
  };
  const int q0592[] = {
    9, 9, // Number of jobs and machines
    7, 29, 4, 55, 1, 44, 0, 21, 3, 72, 2, 20, 6, 39, 8, 47, 5, 89, 
    2, 64, 7, 85, 3, 65, 8, 81, 4, 14, 6, 12, 0, 82, 1, 95, 5, 79, 
    1, 54, 3, 19, 0,  9, 4,  9, 8, 41, 5, 97, 2, 12, 6, 35, 7, 32, 
    0, 38, 8, 30, 3, 76, 4, 99, 7, 20, 2, 59, 1,  3, 5, 15, 6, 24, 
    2,  7, 8, 84, 0, 55, 4, 45, 1, 52, 3, 48, 7, 83, 5, 95, 6, 50, 
    8,  8, 2, 84, 7, 19, 4, 76, 1, 98, 6,  4, 5, 19, 0, 37, 3, 74, 
    5, 61, 2, 17, 8, 47, 6, 78, 3, 76, 4,  8, 0, 38, 1, 41, 7,  1, 
    4, 95, 6, 54, 3, 26, 0, 83, 5, 36, 1, 49, 8, 41, 2,  7, 7, 57, 
    6,  7, 8, 31, 3, 38, 0,  5, 7, 38, 4, 48, 5, 28, 1, 37, 2, 28
  };
  const int q0593[] = {
    9, 9, // Number of jobs and machines
    6,  9, 7, 75, 1, 28, 0, 54, 2, 95, 5, 64, 3, 41, 4, 81, 8, 76, 
    1, 18, 7,  8, 5, 42, 8, 95, 3, 93, 0, 66, 6,  1, 4, 22, 2, 14, 
    6, 83, 3, 62, 7, 72, 4, 80, 0, 85, 2, 81, 1, 64, 8, 13, 5, 53, 
    6, 65, 0, 93, 3,  9, 8, 20, 4, 64, 2, 14, 7, 66, 5, 77, 1, 78, 
    0,  2, 5, 90, 2, 14, 8, 10, 4, 42, 3, 98, 6, 76, 1, 51, 7, 57, 
    3, 78, 4, 17, 1, 49, 6, 76, 8, 16, 5,  8, 0, 26, 2,  6, 7, 53, 
    6, 22, 8, 14, 1,  6, 5, 31, 7, 65, 0, 22, 2, 82, 4,  9, 3, 85, 
    0, 53, 6, 13, 2, 68, 7, 16, 3, 58, 8, 22, 4, 16, 5, 61, 1, 92, 
    0, 88, 5, 73, 8, 83, 1, 16, 3, 93, 7, 26, 2, 68, 6, 38, 4, 90
  };
  const int q0594[] = {
    9, 9, // Number of jobs and machines
    7, 80, 1, 85, 4, 56, 2, 93, 0, 57, 6, 78, 8,  3, 5, 93, 3, 27, 
    7, 68, 6, 31, 2, 42, 1, 56, 4, 40, 0, 50, 5,  7, 8, 80, 3,  3, 
    3, 82, 7, 85, 5, 66, 4, 70, 6, 58, 1, 54, 2, 70, 0, 35, 8, 47, 
    5,  2, 3, 50, 2, 28, 6, 33, 0, 59, 8, 72, 1, 45, 4, 73, 7, 85, 
    5, 71, 1, 26, 4, 83, 0, 22, 7, 61, 2, 29, 8, 65, 3, 58, 6, 82, 
    3, 61, 4, 19, 8, 46, 2, 30, 6, 25, 7, 26, 5, 22, 0, 68, 1, 26, 
    8, 15, 4, 42, 3, 36, 7, 39, 6, 74, 1, 32, 0, 85, 5, 11, 2, 88, 
    3,  8, 0, 10, 2, 19, 1, 99, 8, 72, 7, 18, 5, 61, 4, 18, 6, 40, 
    2, 60, 1, 23, 3,  5, 6, 51, 0, 65, 8, 85, 4, 18, 7, 34, 5, 42
  };
  const int q0595[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 13, 7, 20, 6, 85, 8, 67, 5, 63, 0, 24, 1, 19, 3, 17, 
    6, 42, 1, 86, 0,  7, 8, 61, 7, 12, 5, 15, 2, 93, 4, 79, 3, 43, 
    1, 43, 3, 78, 6, 60, 5, 53, 4, 33, 0, 90, 7, 46, 8, 97, 2,  9, 
    8, 54, 7,  3, 5, 87, 0, 17, 6, 30, 4, 64, 2, 64, 3, 10, 1, 26, 
    3, 29, 7, 57, 4, 74, 5, 42, 2, 89, 0, 50, 8, 76, 1, 48, 6, 40, 
    1, 27, 3, 65, 4, 73, 0, 93, 5, 69, 8, 55, 2, 14, 6, 62, 7,  7, 
    2, 58, 8, 56, 0, 81, 7, 68, 1, 49, 3, 50, 5, 31, 6, 57, 4, 30, 
    5, 19, 7, 27, 1, 78, 6, 73, 0, 77, 4, 52, 8, 86, 3, 34, 2, 42, 
    0, 18, 3, 66, 2, 86, 4,  7, 7, 85, 1, 30, 5,  1, 8, 23, 6, 12
  };
  const int q0596[] = {
    9, 9, // Number of jobs and machines
    7, 39, 3, 43, 2, 80, 0, 44, 1, 36, 8, 26, 4, 86, 6, 65, 5, 69, 
    2, 74, 3, 81, 0, 11, 7, 27, 6,  6, 1, 97, 4, 43, 5, 50, 8, 26, 
    4, 67, 7, 56, 6, 95, 8, 40, 2, 94, 5, 26, 0, 85, 1, 43, 3, 40, 
    4, 56, 3,  1, 0, 67, 2, 74, 5, 19, 8, 66, 7, 43, 6, 21, 1, 44, 
    8, 20, 2, 54, 1, 41, 3, 61, 4, 18, 6, 49, 0, 38, 7, 39, 5, 35, 
    2, 42, 1, 25, 3, 62, 6, 91, 7, 47, 8, 49, 0, 66, 5, 38, 4, 57, 
    0,  6, 4, 25, 5, 13, 1, 32, 6, 97, 3,  1, 2, 14, 7,  2, 8, 95, 
    0, 27, 1, 51, 7, 68, 5, 23, 8,  9, 2, 26, 6, 51, 3, 40, 4, 15, 
    5, 78, 1, 54, 8, 74, 2, 80, 3,  5, 4, 58, 6, 21, 0, 92, 7, 24
  };
  const int q0597[] = {
    9, 9, // Number of jobs and machines
    5,  7, 3, 91, 0, 55, 2, 41, 1, 53, 6, 79, 4, 22, 7, 26, 8, 75, 
    5, 85, 6, 52, 1, 62, 2, 17, 0,  9, 3, 83, 8, 61, 4, 53, 7, 86, 
    1, 99, 3, 91, 0, 91, 8, 92, 2,  2, 7, 86, 5, 34, 6, 89, 4, 47, 
    7, 28, 8, 73, 4, 26, 3, 12, 5, 88, 1, 10, 2,  7, 6, 95, 0, 84, 
    6,  4, 7, 99, 0, 97, 8, 24, 4, 25, 2, 74, 3, 23, 1, 40, 5, 10, 
    2, 73, 8, 81, 1, 78, 6, 96, 4, 92, 5, 67, 7, 46, 3, 38, 0, 52, 
    6, 47, 8, 99, 3, 39, 1, 97, 2, 12, 0, 42, 4, 31, 5, 18, 7, 71, 
    0, 21, 2, 79, 7, 79, 6, 24, 1, 83, 4, 74, 5, 65, 3, 63, 8, 96, 
    2, 93, 1, 71, 0, 28, 5, 20, 7, 22, 6, 13, 8, 41, 3, 70, 4,  4
  };
  const int q0598[] = {
    9, 9, // Number of jobs and machines
    0, 76, 8, 10, 7, 57, 4,  6, 5, 75, 3, 83, 2, 76, 6, 16, 1, 45, 
    7, 33, 8, 56, 1, 83, 2,  3, 5, 41, 0, 38, 3, 49, 6, 57, 4, 59, 
    3, 94, 0, 26, 8, 65, 1, 22, 4, 63, 6, 55, 5, 78, 7, 25, 2, 92, 
    8, 93, 5, 39, 4, 83, 2, 45, 1, 83, 6, 37, 3, 53, 0,  1, 7, 42, 
    5, 12, 6, 50, 3, 93, 8, 20, 4, 75, 1,  8, 0, 90, 7, 28, 2, 74, 
    4, 63, 8, 64, 1, 33, 0, 24, 3, 87, 2, 38, 5, 45, 7, 39, 6,  3, 
    4, 53, 5, 11, 1, 63, 3, 43, 7, 93, 2, 36, 6, 71, 0, 28, 8, 34, 
    8, 65, 1, 76, 6, 63, 2, 73, 4, 95, 7, 93, 0, 39, 3, 74, 5, 99, 
    8, 88, 1, 58, 0, 87, 6, 58, 5, 95, 3, 46, 7, 55, 2, 20, 4, 51
  };
  const int q0599[] = {
    9, 9, // Number of jobs and machines
    4, 68, 3, 28, 5, 65, 8, 67, 6, 67, 2, 78, 7, 94, 1, 73, 0, 67, 
    1, 10, 6, 75, 8, 60, 0, 26, 4, 99, 5, 57, 3, 75, 7, 51, 2, 66, 
    1, 28, 3, 34, 8, 90, 4, 29, 2, 33, 7, 35, 0, 48, 6, 97, 5, 27, 
    4, 14, 0, 61, 2, 21, 1,  9, 6, 49, 8,  5, 7, 20, 5, 19, 3, 10, 
    0, 18, 4,  3, 8, 11, 6, 71, 5, 37, 7, 83, 1, 67, 3, 15, 2, 15, 
    0, 33, 6, 97, 8, 67, 3, 83, 7,  5, 4, 20, 5, 96, 2, 36, 1,  4, 
    0, 59, 7, 69, 5, 11, 1,  4, 3, 53, 8, 10, 4, 21, 2, 87, 6, 95, 
    7, 18, 6, 74, 1, 92, 3,  2, 2, 38, 8, 56, 4, 81, 5, 18, 0, 92, 
    4, 77, 5, 39, 8, 48, 2, 97, 7, 51, 0, 32, 3, 14, 1, 76, 6,  1
  };
  const int q0600[] = {
    9, 9, // Number of jobs and machines
    4, 18, 0, 28, 3, 80, 8, 35, 2, 84, 1, 73, 5, 19, 7, 22, 6, 51, 
    1, 51, 3, 32, 4, 13, 2, 39, 5, 29, 6, 39, 7, 75, 8, 50, 0, 38, 
    2, 46, 5, 12, 0, 79, 6, 35, 7, 54, 4, 88, 8, 16, 1, 59, 3, 36, 
    5, 96, 0, 84, 7, 99, 6, 47, 3, 27, 1, 71, 2, 49, 4,  8, 8, 29, 
    0, 95, 2, 20, 1,  5, 3, 34, 4, 70, 7, 90, 8, 14, 6, 96, 5, 74, 
    0, 41, 3,  5, 8, 62, 2, 28, 6, 16, 5, 93, 4, 25, 1, 96, 7, 94, 
    4, 72, 0, 31, 3, 79, 5, 50, 2, 24, 1, 32, 8, 47, 7, 91, 6, 64, 
    2, 15, 5, 40, 8, 40, 1, 72, 6, 63, 4, 62, 0, 71, 3, 59, 7, 27, 
    6, 92, 1, 27, 7, 95, 8, 55, 5, 78, 2, 78, 4, 60, 0,  8, 3, 22
  };
  const int q0601[] = {
    9, 9, // Number of jobs and machines
    8, 59, 0, 14, 5, 57, 1, 83, 7, 66, 6, 10, 2, 45, 4, 55, 3, 27, 
    7, 42, 3, 30, 2, 52, 1, 96, 5, 68, 6, 97, 0,  9, 4, 49, 8, 29, 
    4, 95, 7, 51, 5, 79, 8, 91, 6, 50, 0, 27, 2,  3, 1,  3, 3, 80, 
    5, 39, 3, 81, 4, 74, 8,  8, 0, 79, 6, 91, 7, 56, 2, 49, 1, 22, 
    7, 94, 6,  8, 4, 95, 2, 35, 0, 43, 3, 71, 1, 20, 8, 85, 5, 30, 
    6, 93, 5, 21, 4, 14, 2,  6, 1, 25, 0, 27, 3, 16, 8, 71, 7, 80, 
    4, 26, 7, 78, 8, 50, 2, 66, 3, 41, 0, 60, 1, 71, 6, 71, 5,  1, 
    0, 52, 5, 94, 3, 36, 8, 10, 1, 98, 6,  5, 4, 45, 7, 51, 2, 11, 
    2,  7, 3, 46, 5, 76, 0, 33, 8,  4, 7, 20, 6, 85, 4, 91, 1,  4
  };
  const int q0602[] = {
    9, 9, // Number of jobs and machines
    5, 54, 0,  4, 8, 40, 6, 12, 7, 92, 3, 99, 1, 22, 4, 62, 2, 82, 
    3, 67, 4, 57, 0, 87, 8, 99, 1, 71, 2, 17, 7, 57, 6, 56, 5, 31, 
    8, 31, 4, 58, 0, 22, 5, 28, 1, 72, 2, 16, 7,  5, 6, 65, 3, 30, 
    4, 71, 5, 31, 1, 36, 6, 82, 2, 58, 3, 46, 0, 21, 7, 18, 8, 23, 
    5, 46, 8, 20, 0, 85, 6, 79, 3, 52, 7, 30, 1, 90, 2, 48, 4, 88, 
    6, 21, 4, 96, 5, 18, 8, 72, 1, 16, 7, 91, 0, 18, 2, 64, 3, 24, 
    0, 15, 8, 18, 5,  2, 3, 38, 7, 13, 1, 98, 2, 10, 4, 89, 6, 19, 
    6, 63, 2, 86, 1, 99, 5, 78, 8, 59, 7, 63, 4, 44, 3, 44, 0, 80, 
    3, 77, 1, 10, 0, 70, 7, 68, 2, 94, 4, 82, 6, 84, 8,  8, 5,  6
  };
  const int q0603[] = {
    9, 9, // Number of jobs and machines
    4, 90, 7, 11, 2, 30, 6, 50, 5,  4, 3,  2, 1, 16, 0, 26, 8, 51, 
    1, 24, 8, 37, 6, 54, 2, 34, 4, 63, 3, 15, 7, 70, 0, 74, 5, 77, 
    4,  3, 8, 79, 2, 67, 6, 12, 7, 25, 5, 73, 0,  5, 3,  8, 1, 66, 
    7, 39, 8, 72, 0, 24, 4, 94, 3, 86, 6, 89, 5, 93, 1, 50, 2, 79, 
    4,  1, 1, 18, 3, 97, 0,  9, 5, 74, 8, 21, 7, 77, 6, 63, 2, 61, 
    8, 67, 2, 13, 1, 40, 3, 91, 5, 99, 7, 55, 0, 63, 4, 82, 6, 25, 
    7, 58, 2, 17, 4, 58, 5, 57, 0, 14, 3, 55, 1, 74, 6, 71, 8, 80, 
    3, 45, 8, 68, 5, 16, 0, 32, 2, 57, 1, 33, 6, 90, 7, 19, 4, 11, 
    6, 49, 2, 76, 0, 90, 4, 38, 8, 13, 3,  4, 1, 59, 7, 47, 5, 69
  };
  const int q0604[] = {
    9, 9, // Number of jobs and machines
    6, 64, 2,  3, 3,  3, 7, 95, 1,  8, 0, 97, 5, 34, 8, 85, 4, 47, 
    3,  2, 4, 67, 6, 66, 8, 35, 5, 97, 2, 83, 1, 20, 7,  6, 0, 53, 
    8, 15, 7, 66, 3, 70, 2, 60, 4, 50, 5, 45, 6, 99, 0, 80, 1, 80, 
    8, 99, 5, 21, 4, 18, 1,  3, 0, 32, 3,  8, 2, 46, 6, 29, 7, 80, 
    1, 62, 4, 77, 8, 89, 3, 82, 6,  4, 5, 39, 7, 96, 2,  1, 0, 91, 
    5, 81, 8, 34, 3, 14, 2, 43, 7, 21, 6, 78, 4, 83, 0,  6, 1, 90, 
    0, 36, 3, 61, 8, 20, 1, 44, 4, 14, 5, 39, 6, 70, 2, 92, 7, 11, 
    1,  8, 6, 60, 2, 82, 0,  3, 8, 63, 4, 73, 7, 64, 3,  3, 5, 32, 
    1, 38, 7, 68, 8,  1, 5, 60, 2, 60, 6, 63, 4, 51, 3,  9, 0, 35
  };
  const int q0605[] = {
    9, 9, // Number of jobs and machines
    2, 36, 7,  2, 1, 40, 0,  6, 5, 85, 6, 24, 3, 71, 4, 18, 8, 18, 
    0, 22, 5, 29, 7, 15, 6, 38, 4, 92, 3, 33, 2, 64, 8, 81, 1, 74, 
    7, 50, 5, 66, 2, 79, 8, 53, 6, 17, 0, 11, 1, 29, 4, 66, 3, 26, 
    2, 22, 8, 58, 7, 85, 5, 78, 1, 22, 6, 49, 0, 37, 3,  3, 4, 37, 
    0, 50, 2, 64, 3, 91, 8, 30, 6, 33, 5, 20, 1, 51, 7, 54, 4, 39, 
    2, 92, 8, 62, 6, 30, 0, 30, 1, 82, 3, 71, 5, 22, 4, 49, 7, 86, 
    0, 21, 8, 59, 7, 35, 4, 73, 3, 29, 6, 96, 1, 32, 5, 22, 2,  6, 
    4, 18, 5, 50, 6, 67, 1, 45, 2, 33, 7, 14, 8, 33, 3, 62, 0, 91, 
    4, 89, 0,  5, 3, 51, 6, 40, 8, 58, 7,  4, 1, 97, 5, 51, 2, 28
  };
  const int q0606[] = {
    9, 9, // Number of jobs and machines
    3,  2, 2, 26, 6, 44, 1, 18, 0, 35, 8, 22, 5, 93, 4, 73, 7, 83, 
    8, 95, 6, 62, 3, 58, 5, 65, 0, 18, 1, 31, 7, 47, 4, 99, 2, 11, 
    6, 85, 8, 41, 3, 96, 7, 65, 4, 62, 2, 15, 0, 40, 5, 55, 1, 44, 
    7, 97, 3, 74, 2, 65, 8, 56, 6, 59, 1, 39, 4, 53, 0, 70, 5, 49, 
    6, 70, 4, 10, 0,  9, 7, 19, 5, 21, 8, 49, 2, 64, 1, 99, 3, 40, 
    8, 52, 7, 71, 1, 80, 4, 16, 6, 37, 0, 41, 5, 86, 2,  1, 3, 52, 
    5, 80, 7, 69, 8, 38, 2,  3, 3, 20, 6, 83, 0, 13, 1, 54, 4, 49, 
    0, 91, 6,  3, 5, 82, 4, 21, 7, 71, 2, 25, 1, 28, 3, 61, 8, 45, 
    2,  2, 6, 44, 1, 90, 4, 94, 7,  1, 5, 40, 3, 62, 8,  9, 0, 38
  };
  const int q0607[] = {
    9, 9, // Number of jobs and machines
    4, 77, 3, 85, 1, 19, 0, 83, 6, 83, 2, 43, 8, 28, 5, 88, 7, 62, 
    4, 65, 5, 88, 2, 45, 7, 20, 3, 33, 0, 11, 6, 67, 1, 52, 8, 52, 
    4, 32, 2, 25, 8, 82, 0, 95, 1, 75, 3,  8, 7, 48, 5, 89, 6, 77, 
    1, 10, 8, 13, 4, 68, 5, 61, 0, 71, 3, 73, 2, 26, 6, 39, 7, 35, 
    4, 94, 5, 51, 3, 21, 8, 17, 7, 13, 2, 17, 0, 58, 6, 62, 1, 42, 
    4, 63, 3, 87, 2,  2, 7, 30, 5, 86, 8, 63, 0, 38, 1, 90, 6, 71, 
    4, 77, 7, 92, 5, 65, 6, 74, 0, 51, 8, 88, 1, 15, 2, 14, 3, 72, 
    3, 44, 6, 36, 4,  8, 2, 38, 0, 23, 5, 34, 8, 71, 7,  9, 1, 27, 
    1, 37, 7, 57, 8, 52, 3, 79, 2, 48, 6, 64, 4, 91, 0, 87, 5, 47
  };
  const int q0608[] = {
    9, 9, // Number of jobs and machines
    8, 31, 6, 24, 3,  9, 2, 11, 1, 93, 0, 33, 7, 42, 4, 27, 5, 76, 
    7, 64, 1, 74, 4, 75, 5, 24, 2, 33, 8, 93, 6, 49, 3, 64, 0, 59, 
    0, 47, 3, 30, 7, 81, 1, 38, 8, 47, 2, 68, 6, 10, 4, 61, 5, 65, 
    7, 66, 6, 49, 4, 16, 2, 62, 3, 67, 0, 75, 5, 41, 1, 69, 8, 40, 
    6, 36, 5,  5, 3, 89, 1, 78, 2, 66, 7, 85, 4, 95, 8, 39, 0, 46, 
    7, 30, 1, 17, 6, 68, 8, 56, 5, 83, 4, 37, 0, 19, 2, 62, 3, 97, 
    8, 16, 2,  3, 6,  3, 4, 98, 3,  7, 1, 79, 7, 86, 5, 91, 0, 15, 
    0, 60, 7, 49, 8, 32, 1, 19, 3, 39, 2, 78, 4,  4, 5, 55, 6, 17, 
    6, 19, 2, 30, 3, 92, 5, 34, 1, 60, 0, 59, 7, 16, 8, 81, 4, 75
  };
  const int q0609[] = {
    9, 9, // Number of jobs and machines
    6, 99, 1, 13, 0, 98, 5, 25, 2, 75, 3, 38, 7, 25, 4, 97, 8, 62, 
    3, 30, 6, 20, 4, 74, 0, 10, 2, 20, 7, 67, 8, 74, 5, 11, 1, 44, 
    5, 16, 3, 60, 0, 71, 4, 72, 7, 85, 8, 48, 2, 61, 1, 41, 6, 79, 
    4, 23, 1, 37, 5, 30, 0, 59, 6, 49, 8, 18, 2, 61, 7, 22, 3, 64, 
    0,  7, 3, 43, 2, 49, 4, 31, 5, 87, 1, 31, 7, 16, 6, 65, 8, 97, 
    2, 53, 6, 13, 7, 23, 1, 99, 4, 24, 8, 64, 3, 74, 5, 78, 0, 86, 
    0, 38, 1, 95, 6, 37, 5, 99, 4, 92, 7, 54, 8, 55, 2, 33, 3, 15, 
    2, 60, 3,  1, 6,  2, 0, 48, 1, 67, 8, 50, 4,  9, 7, 75, 5, 26, 
    7, 58, 8, 10, 0, 29, 4, 81, 5, 15, 2, 26, 1, 11, 6, 23, 3, 40
  };
  const int q0610[] = {
    9, 9, // Number of jobs and machines
    2, 41, 0, 47, 6, 24, 1, 91, 4,  2, 8, 42, 3, 46, 5, 34, 7, 26, 
    6,  8, 8, 66, 2, 48, 0, 95, 7, 73, 5, 23, 1, 93, 3,  2, 4, 60, 
    2, 41, 6, 69, 3, 93, 5, 19, 4, 88, 7, 98, 1, 90, 0, 49, 8,  7, 
    8, 96, 0, 83, 6, 12, 3, 97, 4, 18, 1, 87, 2, 36, 7, 55, 5, 24, 
    1, 22, 7, 62, 0, 90, 2, 59, 3, 27, 6, 46, 5, 16, 8, 41, 4, 66, 
    4, 32, 8, 80, 3, 88, 7, 44, 6, 36, 1,  8, 5, 37, 0, 97, 2, 57, 
    6, 25, 1, 62, 5, 99, 4, 72, 7, 29, 2, 87, 3, 36, 0, 62, 8, 88, 
    6, 27, 3, 83, 4, 46, 2, 71, 8, 95, 0, 44, 1, 85, 5, 46, 7, 54, 
    5, 54, 8, 43, 1, 43, 6, 41, 2, 60, 4, 30, 7, 44, 0, 71, 3, 19
  };
  const int q0611[] = {
    9, 9, // Number of jobs and machines
    8, 93, 4, 97, 7, 96, 5, 57, 6, 94, 0, 48, 1,  6, 2, 44, 3, 39, 
    3, 84, 2, 50, 0, 15, 5, 26, 6, 97, 7, 14, 8, 69, 4, 61, 1,  7, 
    3, 57, 0, 20, 8, 93, 4, 43, 5,  6, 7, 58, 2, 30, 1, 33, 6, 18, 
    8, 11, 6, 68, 1, 95, 7, 42, 0, 68, 3, 52, 5, 51, 2, 88, 4, 64, 
    1, 98, 3, 70, 4, 65, 6, 21, 5, 40, 2,  5, 0, 16, 7, 51, 8, 87, 
    5, 45, 8, 40, 7, 28, 4, 24, 6, 27, 1, 20, 3, 60, 2, 73, 0, 78, 
    3, 50, 7, 11, 0, 30, 4, 85, 2, 26, 6,  2, 1, 47, 5, 24, 8, 77, 
    1, 35, 5, 78, 6, 61, 0, 56, 8, 86, 2, 95, 3,  3, 4, 23, 7, 30, 
    8,  2, 4, 40, 3, 15, 2, 59, 7, 46, 0, 80, 5, 93, 6, 71, 1, 55
  };
  const int q0612[] = {
    9, 9, // Number of jobs and machines
    0, 42, 6, 60, 5, 34, 8, 72, 1, 37, 4, 34, 3, 53, 7, 40, 2, 76, 
    4, 19, 1, 33, 7, 92, 8, 81, 6, 29, 2, 44, 5, 62, 0, 24, 3, 54, 
    2, 10, 4, 98, 7,  9, 8, 26, 1, 90, 5, 88, 3, 34, 6,  3, 0, 92, 
    1, 20, 7, 76, 4, 21, 5, 19, 2, 40, 3, 98, 6, 45, 8, 24, 0, 38, 
    4, 74, 7,  9, 2, 73, 6, 73, 8, 37, 5, 96, 0, 50, 3, 64, 1, 74, 
    2, 86, 5,  4, 1, 69, 0, 15, 8, 29, 3, 37, 7, 39, 4, 35, 6, 44, 
    7, 91, 1, 67, 4, 46, 0, 72, 8, 36, 2,  4, 5, 77, 6, 87, 3, 48, 
    8, 97, 0, 88, 1, 59, 4, 15, 5, 88, 2, 59, 6, 94, 3, 98, 7, 78, 
    0, 57, 2, 29, 1, 62, 3, 62, 5, 52, 7, 92, 6, 12, 8, 57, 4, 21
  };
  const int q0613[] = {
    9, 9, // Number of jobs and machines
    5, 78, 0, 33, 7, 50, 8, 38, 6, 38, 3,  6, 4, 52, 1, 91, 2,  2, 
    6, 82, 0, 83, 4, 34, 1, 80, 2, 47, 7, 33, 5, 27, 3, 73, 8, 61, 
    2, 15, 8, 14, 6, 34, 1, 61, 7, 76, 5,  4, 3, 82, 0, 12, 4, 87, 
    5, 87, 0, 63, 8, 13, 1, 71, 6, 98, 3, 94, 7, 49, 4, 50, 2, 23, 
    0, 29, 3, 53, 2, 91, 7, 65, 4, 31, 1, 67, 6, 26, 8, 63, 5, 36, 
    4, 13, 8,  4, 6, 48, 7, 99, 1, 58, 0, 54, 5, 54, 2, 38, 3,  4, 
    5, 33, 2, 54, 0, 35, 6, 48, 7, 16, 1, 37, 4, 44, 8, 49, 3, 96, 
    8, 67, 6, 62, 0, 76, 4, 70, 7, 12, 2, 23, 3, 60, 1, 68, 5, 53, 
    3, 49, 7, 12, 5, 11, 0, 45, 4, 79, 1, 24, 2, 46, 8, 41, 6, 56
  };
  const int q0614[] = {
    9, 9, // Number of jobs and machines
    0, 21, 5, 21, 7, 66, 6, 12, 1, 45, 2, 41, 4, 80, 3, 63, 8, 12, 
    8, 78, 2, 83, 3, 51, 5, 83, 6, 31, 4, 23, 1, 71, 7, 86, 0, 64, 
    0, 47, 6, 33, 7, 55, 2, 41, 1,  5, 3, 73, 8, 49, 5, 52, 4, 93, 
    1, 51, 5, 67, 0, 88, 6, 72, 8, 84, 2, 60, 4, 39, 3, 76, 7, 82, 
    1, 87, 6, 68, 0, 41, 5, 48, 4, 33, 2, 42, 8, 61, 7, 60, 3, 64, 
    8, 38, 6,  6, 3, 57, 0, 18, 1, 49, 4, 84, 7, 37, 2, 18, 5,  4, 
    1, 82, 3, 51, 0, 22, 4, 32, 2, 91, 8, 82, 6, 45, 7, 48, 5, 61, 
    8, 86, 2, 96, 4, 57, 5, 47, 1, 80, 0, 86, 6, 16, 7, 59, 3, 82, 
    7, 91, 5, 20, 6, 42, 4,  7, 0, 88, 3, 46, 1, 93, 8, 76, 2, 38
  };
  const int q0615[] = {
    9, 9, // Number of jobs and machines
    6,  9, 0, 79, 2, 34, 8, 95, 3, 13, 1, 59, 7, 16, 4, 89, 5, 89, 
    0, 35, 4, 86, 6, 58, 7, 74, 3, 88, 1, 12, 8, 71, 5, 27, 2, 37, 
    8, 35, 7, 46, 1, 69, 3, 36, 6, 46, 5, 65, 4, 52, 2,  4, 0, 29, 
    2, 67, 0, 94, 8, 85, 4, 41, 1, 96, 3, 21, 7, 69, 6, 26, 5,  5, 
    7, 61, 8, 11, 4, 34, 3, 14, 0, 62, 2,  3, 5, 72, 1,  2, 6, 64, 
    7, 71, 2, 99, 3, 58, 0, 57, 6, 92, 4, 12, 5, 48, 1, 90, 8, 83, 
    0, 36, 8, 61, 1, 37, 4, 31, 2, 70, 6, 44, 5, 43, 7, 60, 3,  9, 
    0, 16, 8, 85, 4, 52, 5, 34, 3, 94, 2, 34, 7, 81, 1, 50, 6, 10, 
    5, 14, 1, 33, 3, 38, 4, 15, 8, 57, 0, 68, 7, 55, 6, 85, 2, 27
  };
  const int q0616[] = {
    9, 9, // Number of jobs and machines
    5, 39, 6,  6, 8,  7, 0, 96, 4, 69, 1, 85, 7, 97, 2, 49, 3, 51, 
    4,  1, 7, 25, 6, 81, 3, 95, 5, 56, 1, 14, 8, 99, 2, 33, 0, 47, 
    4, 65, 6, 75, 7, 99, 1, 31, 5, 43, 8, 48, 3, 55, 0, 15, 2, 93, 
    4, 82, 8, 90, 1,  7, 2,  5, 0,  6, 5, 62, 3, 86, 6, 91, 7, 16, 
    4, 88, 7, 61, 1, 79, 0, 98, 5, 88, 6, 31, 8, 32, 3, 13, 2, 30, 
    3, 93, 6, 67, 8,  6, 7, 66, 0, 13, 4,  8, 2, 70, 5, 86, 1, 32, 
    3, 76, 1, 71, 6, 50, 4, 17, 7, 82, 2, 93, 8, 24, 0, 42, 5, 98, 
    2, 57, 7, 19, 6, 22, 0, 46, 3,  8, 1, 56, 5, 42, 4, 87, 8, 68, 
    1, 89, 6, 48, 5, 37, 8, 84, 4, 54, 0, 49, 2,  5, 7, 56, 3, 24
  };
  const int q0617[] = {
    9, 9, // Number of jobs and machines
    3, 23, 7, 69, 4, 85, 5, 28, 6,  5, 8, 87, 1, 76, 2, 37, 0,  9, 
    2, 30, 5, 15, 3, 73, 1, 27, 7, 22, 8, 60, 4, 19, 6, 26, 0,  8, 
    7, 26, 2, 77, 4, 43, 3, 35, 6, 26, 5, 15, 0, 17, 8, 87, 1, 88, 
    7, 80, 6, 62, 2, 25, 1, 87, 4,  7, 5, 97, 3, 73, 0, 38, 8, 89, 
    1, 62, 6, 88, 2, 48, 8, 21, 0, 85, 5, 54, 7, 81, 3,  9, 4, 90, 
    5, 88, 0, 26, 2, 49, 3, 23, 1, 88, 6, 44, 8, 28, 7, 31, 4, 22, 
    6, 63, 7, 51, 0, 39, 1, 92, 4, 63, 5, 77, 2, 93, 8, 68, 3, 59, 
    5, 59, 0, 79, 8, 53, 6, 23, 3, 53, 7, 64, 1, 96, 2,  6, 4, 79, 
    6, 82, 2,  7, 4, 63, 7, 98, 3, 22, 5, 54, 8, 71, 1, 70, 0, 47
  };
  const int q0618[] = {
    9, 9, // Number of jobs and machines
    5, 15, 3, 23, 8, 19, 2, 33, 4, 69, 0, 76, 1, 15, 6, 61, 7,  1, 
    6, 83, 7, 84, 8, 30, 5, 30, 1, 21, 4, 70, 0, 64, 3, 16, 2, 54, 
    1, 19, 0, 92, 7, 19, 4, 35, 2, 37, 3, 59, 8, 84, 5, 35, 6, 84, 
    6, 91, 2, 58, 4, 46, 1, 13, 3, 48, 7, 23, 0, 29, 8, 61, 5, 48, 
    8, 98, 6, 43, 5, 42, 1, 41, 4, 42, 0, 80, 7, 87, 3, 41, 2, 79, 
    7, 75, 8, 99, 6, 20, 0,  1, 2, 79, 5, 12, 3,  4, 1, 28, 4, 85, 
    1, 68, 4, 37, 5, 11, 6,  5, 7, 53, 0,  8, 2, 51, 8, 35, 3, 81, 
    0, 39, 4, 60, 6, 67, 8, 19, 3, 10, 2, 76, 5, 47, 1, 89, 7, 94, 
    6, 79, 5, 28, 2,  4, 0, 13, 7, 79, 1, 13, 8, 66, 3, 65, 4, 84
  };
  const int q0619[] = {
    9, 9, // Number of jobs and machines
    5, 16, 7, 88, 2, 83, 6, 88, 0, 22, 8, 84, 3, 52, 4, 46, 1, 59, 
    3, 18, 7, 44, 4, 12, 6, 86, 1, 38, 5, 39, 0, 71, 8, 26, 2,  4, 
    6, 52, 2, 69, 3, 51, 8, 21, 4, 58, 0, 14, 1, 44, 7,  2, 5, 15, 
    0, 49, 3,  1, 2, 95, 1, 55, 6, 76, 7, 54, 5, 84, 4, 10, 8, 44, 
    0, 70, 3, 36, 2, 92, 4, 28, 1,  6, 6, 43, 8,  1, 7,  8, 5, 97, 
    1, 10, 8, 23, 5, 41, 3, 31, 4, 89, 0, 45, 6, 24, 2, 93, 7, 26, 
    8, 26, 7, 84, 6, 92, 5, 54, 1, 80, 2, 37, 4, 71, 0,  6, 3, 80, 
    8, 66, 1,  2, 5, 44, 4, 39, 0,  4, 7, 15, 6, 82, 3, 40, 2, 76, 
    2, 16, 8, 56, 6, 58, 3, 46, 7, 37, 5, 61, 4, 57, 0, 55, 1, 80
  };
  const int q0620[] = {
    9, 9, // Number of jobs and machines
    7, 14, 0, 21, 1, 93, 2, 82, 3, 60, 4, 71, 6, 71, 8, 86, 5, 43, 
    6, 24, 7, 32, 5, 66, 8, 18, 1, 24, 2, 56, 4,  2, 0, 68, 3, 52, 
    2, 89, 8, 56, 5, 65, 7, 61, 4, 58, 3, 65, 0, 20, 6, 21, 1, 59, 
    4,  4, 5, 15, 6, 78, 1, 99, 8,  9, 7, 32, 2,  8, 3, 20, 0, 95, 
    6, 90, 1, 14, 5, 98, 3, 97, 7, 60, 4, 91, 2, 39, 0, 62, 8,  7, 
    5,  3, 1, 11, 2, 25, 6, 77, 8, 94, 0, 82, 7, 98, 4, 34, 3, 22, 
    5, 77, 2, 70, 4, 33, 7, 37, 3, 29, 1, 54, 6,  8, 8, 75, 0, 85, 
    4, 96, 5, 20, 3, 68, 2, 59, 6, 93, 0, 98, 1, 86, 8, 25, 7, 38, 
    5, 85, 2, 27, 0,  1, 4, 20, 8, 67, 3, 65, 6, 33, 1,  4, 7, 36
  };
  const int q0621[] = {
    9, 9, // Number of jobs and machines
    5, 56, 0, 70, 3,  7, 4, 37, 7, 12, 6, 59, 1, 58, 2, 86, 8, 27, 
    8, 45, 0, 43, 4, 85, 6, 15, 3,  2, 7, 39, 5, 38, 2, 41, 1, 19, 
    6, 73, 0, 21, 1,  3, 2, 85, 4, 29, 8,  4, 3, 88, 5,  7, 7, 79, 
    2, 54, 4, 64, 8, 69, 1, 71, 7, 22, 5, 12, 6, 50, 0, 87, 3, 24, 
    0, 19, 4, 64, 2, 64, 7, 15, 1,  4, 8, 58, 6, 36, 3, 48, 5, 57, 
    5, 57, 3, 27, 1, 69, 4, 65, 7, 76, 2, 96, 0, 92, 8, 24, 6, 24, 
    0, 93, 7, 83, 3, 20, 6, 54, 5, 83, 4, 56, 2, 56, 8, 21, 1,  9, 
    7, 56, 8, 36, 5, 76, 6, 73, 4, 15, 2, 70, 0, 69, 3, 70, 1, 39, 
    4, 25, 3, 53, 6,  2, 1, 51, 7, 70, 2,  4, 0, 28, 5, 27, 8, 29
  };
  const int q0622[] = {
    9, 9, // Number of jobs and machines
    8, 89, 3, 12, 2, 93, 6, 34, 5,  1, 1, 16, 7, 99, 4, 36, 0, 48, 
    0, 39, 2, 37, 7, 38, 8, 46, 6, 34, 3, 65, 4, 24, 1, 98, 5, 93, 
    5, 96, 0, 88, 4,  6, 2, 14, 6, 88, 3, 13, 1, 34, 7, 40, 8, 10, 
    1, 54, 7, 49, 8, 80, 2, 59, 5, 84, 3, 62, 0, 86, 4, 73, 6, 95, 
    0, 77, 5, 26, 2, 90, 3, 43, 7, 43, 6, 31, 8,  3, 1, 68, 4, 14, 
    6, 32, 2, 17, 7, 36, 1, 31, 8, 47, 5, 56, 3, 24, 0, 43, 4, 49, 
    2, 17, 3, 22, 5, 28, 4, 37, 6, 64, 7, 12, 1,  7, 8, 50, 0,  5, 
    8, 20, 5, 70, 4, 23, 2, 80, 7, 74, 0, 14, 6, 41, 1, 21, 3, 36, 
    0, 77, 1, 83, 4, 19, 5, 53, 8, 85, 2, 15, 7, 76, 6, 25, 3,  7
  };
  const int q0623[] = {
    9, 9, // Number of jobs and machines
    4, 48, 5, 59, 8, 58, 6, 98, 2, 93, 3, 45, 0, 84, 7, 29, 1, 65, 
    6,  6, 2, 20, 0, 33, 1, 38, 5, 69, 3, 62, 7, 26, 4, 78, 8, 72, 
    3, 24, 2, 64, 0, 95, 7, 28, 5, 72, 8, 99, 4, 30, 6, 99, 1, 72, 
    2, 63, 4, 15, 5, 93, 1, 26, 8, 37, 7, 64, 0, 29, 6, 81, 3, 98, 
    7, 41, 4, 66, 3, 88, 8, 26, 5,  6, 2, 89, 6, 24, 0, 82, 1, 58, 
    2, 53, 5, 92, 4,  3, 3, 39, 6, 84, 1, 90, 0, 37, 7, 90, 8, 18, 
    2, 82, 5, 27, 6, 73, 0, 25, 4, 24, 1, 27, 3, 77, 8, 30, 7, 58, 
    4, 59, 5, 84, 0, 20, 7, 95, 1,  8, 8, 51, 6, 78, 2, 94, 3, 76, 
    8, 88, 1, 77, 6, 23, 7, 92, 3, 99, 5, 39, 2, 87, 0, 78, 4, 94
  };
  const int q0624[] = {
    9, 9, // Number of jobs and machines
    4, 91, 7, 65, 1,  6, 3, 82, 0, 77, 5, 20, 6, 48, 8, 62, 2, 23, 
    6, 48, 3, 21, 5, 27, 7, 74, 1, 37, 8, 85, 0, 53, 2, 94, 4, 48, 
    3, 14, 7, 96, 4,  2, 2, 99, 6, 77, 0, 69, 5, 20, 1, 41, 8, 13, 
    4, 48, 2, 90, 6, 91, 1, 55, 7, 54, 3, 33, 5, 98, 8, 54, 0, 58, 
    1, 50, 4, 22, 8, 29, 2, 94, 3, 15, 0, 45, 7, 68, 5, 19, 6, 30, 
    3,  4, 0, 39, 5, 83, 7, 50, 1, 76, 2, 18, 4, 76, 6, 50, 8, 23, 
    4,  6, 2,  8, 3, 59, 7, 58, 5, 68, 8, 44, 6, 78, 0, 50, 1, 96, 
    8, 53, 4, 43, 2, 50, 1, 11, 0, 73, 7, 36, 3, 62, 5, 42, 6, 14, 
    2, 91, 3, 47, 5,  8, 7, 71, 4, 80, 8, 10, 1, 95, 6, 37, 0, 23
  };
  const int q0625[] = {
    9, 9, // Number of jobs and machines
    0,  9, 4, 56, 1, 71, 7, 99, 8, 62, 6, 32, 2, 99, 5, 99, 3, 82, 
    7, 23, 8, 86, 1, 70, 0, 54, 2, 19, 3, 11, 4, 89, 6, 80, 5, 57, 
    2, 42, 0, 90, 4, 29, 7, 95, 3, 99, 5, 47, 8, 69, 6, 13, 1, 84, 
    4, 19, 2, 40, 5, 89, 7, 92, 6, 44, 8, 77, 0, 76, 1, 77, 3,  4, 
    8, 41, 1,  2, 0, 17, 3, 79, 2, 14, 7, 17, 5, 75, 4, 60, 6, 94, 
    8, 96, 5, 90, 7, 21, 2, 85, 3, 96, 6, 43, 0, 57, 1, 18, 4, 36, 
    6, 71, 8, 37, 1, 39, 7, 89, 3,  3, 0, 22, 4, 74, 5, 70, 2, 28, 
    4, 47, 2, 49, 6, 14, 1, 60, 8, 77, 3, 73, 7, 35, 0, 11, 5, 59, 
    4, 39, 2, 63, 6, 72, 1, 59, 5, 78, 7, 58, 3, 57, 0, 34, 8, 42
  };
  const int q0626[] = {
    9, 9, // Number of jobs and machines
    4, 27, 7, 16, 2, 36, 5, 48, 1, 71, 8, 90, 3, 59, 6, 24, 0, 55, 
    6, 42, 2, 72, 8, 41, 7, 83, 3, 94, 4, 97, 0, 95, 5, 88, 1, 80, 
    2, 12, 8, 43, 1, 35, 6, 70, 7, 23, 5, 84, 3, 10, 0, 27, 4, 43, 
    8, 95, 1, 78, 2, 44, 7, 82, 6, 11, 3, 65, 0,  4, 5, 31, 4, 62, 
    8, 71, 0, 61, 3, 60, 4, 95, 5,  6, 7, 66, 6, 55, 1,  9, 2,  4, 
    3, 13, 4, 35, 6, 82, 1, 14, 0, 95, 8, 19, 5, 62, 7, 18, 2, 54, 
    0, 72, 5, 98, 2, 92, 8, 22, 7, 48, 6, 65, 4, 15, 1,  8, 3, 14, 
    2,  6, 5, 68, 7, 40, 8, 92, 3, 52, 6, 78, 0, 95, 1, 22, 4, 82, 
    2, 96, 8, 50, 4, 47, 3, 74, 5, 21, 7, 37, 6, 40, 1, 74, 0, 53
  };
  const int q0627[] = {
    9, 9, // Number of jobs and machines
    1, 83, 0, 86, 3, 85, 2, 72, 8, 83, 6, 11, 5, 38, 7, 79, 4, 56, 
    2, 30, 7, 32, 4, 33, 8, 31, 5, 52, 3,  2, 0,  9, 1, 35, 6,  5, 
    6, 37, 1, 88, 7,  4, 5, 92, 2, 16, 4, 55, 0, 95, 8, 71, 3, 74, 
    7, 74, 1, 58, 3, 76, 4,  2, 8, 16, 5, 16, 0, 11, 2, 68, 6, 29, 
    2, 56, 0, 61, 7, 83, 6, 89, 3, 59, 8, 98, 1, 21, 4, 76, 5, 64, 
    1, 67, 8, 81, 2, 58, 3, 69, 6, 68, 5,  8, 7, 69, 0, 86, 4, 34, 
    3, 30, 0, 41, 5, 39, 1, 66, 7, 48, 4, 91, 2,  8, 6, 50, 8, 72, 
    5, 16, 6, 15, 7, 22, 4, 13, 1, 33, 0, 82, 2, 64, 3, 48, 8, 52, 
    4, 57, 2, 38, 3, 82, 1,  8, 7, 59, 5, 66, 6, 67, 0, 75, 8,  7
  };
  const int q0628[] = {
    9, 9, // Number of jobs and machines
    4, 12, 2, 40, 0, 31, 5,  7, 7, 26, 8, 70, 1, 87, 3, 85, 6, 29, 
    3, 93, 8,  8, 0, 77, 5, 92, 2, 67, 4, 52, 1, 16, 7, 62, 6, 41, 
    0, 79, 2, 42, 4, 11, 7, 89, 8, 61, 6, 44, 3, 58, 1, 98, 5, 64, 
    7, 47, 5, 55, 3, 70, 2, 93, 0,  6, 8, 77, 1, 89, 4, 64, 6, 73, 
    3, 27, 7, 55, 4, 31, 8, 45, 5,  1, 6, 77, 0, 65, 2, 67, 1, 88, 
    4, 48, 3, 18, 1,  6, 2, 17, 8, 53, 0, 19, 7, 20, 5,  9, 6, 11, 
    5, 45, 1, 47, 4, 55, 8, 86, 2, 74, 0, 60, 3, 29, 7, 58, 6,  7, 
    5,  8, 4, 25, 0, 16, 7, 92, 3, 74, 1,  9, 6, 64, 2, 57, 8, 17, 
    1, 62, 4, 21, 7, 25, 3, 25, 0, 63, 6, 44, 2, 53, 8, 41, 5, 66
  };
  const int q0629[] = {
    9, 9, // Number of jobs and machines
    8, 52, 5, 76, 3,  5, 4, 20, 0, 88, 2, 77, 7, 35, 1,  1, 6, 10, 
    2, 16, 7,  3, 1, 42, 0, 85, 5, 59, 8, 79, 3, 24, 4, 11, 6, 89, 
    6, 62, 8, 63, 3,  2, 5, 16, 7, 48, 4, 79, 0, 33, 2, 62, 1, 70, 
    3, 63, 7, 85, 5, 93, 0, 39, 6, 24, 4, 86, 8, 92, 1, 26, 2, 39, 
    5, 98, 1, 31, 8, 79, 0,  6, 2, 31, 7,  9, 4, 59, 6, 84, 3, 33, 
    3, 98, 4, 86, 0, 75, 2, 25, 8, 91, 6, 58, 1, 91, 5, 14, 7, 78, 
    2, 49, 3, 11, 0, 19, 5, 77, 7, 22, 8, 80, 1,  7, 6, 67, 4, 90, 
    0, 68, 2, 74, 3, 77, 7, 37, 6, 56, 4, 40, 1, 80, 5, 28, 8, 60, 
    5, 22, 4, 37, 1, 22, 6, 55, 2,  9, 7, 38, 3,  5, 0, 91, 8,  1
  };
  const int q0630[] = {
    9, 9, // Number of jobs and machines
    7, 50, 8, 89, 0, 28, 6, 83, 4, 84, 3, 48, 5, 88, 1, 19, 2, 43, 
    0, 41, 1, 49, 2, 51, 7, 97, 3, 13, 4, 95, 5, 59, 6, 64, 8, 49, 
    7, 43, 4, 10, 1, 59, 6, 85, 8, 56, 5, 69, 3, 47, 0, 15, 2, 72, 
    0, 92, 5, 83, 6, 18, 8, 64, 7, 82, 2, 13, 3, 24, 1, 58, 4, 64, 
    6, 30, 0, 36, 2, 98, 4, 97, 7, 76, 3, 24, 5, 94, 1, 14, 8,  6, 
    0, 19, 8, 21, 1, 51, 2, 52, 6, 17, 4, 31, 5, 33, 7, 27, 3, 28, 
    3, 25, 8, 21, 4, 20, 6, 42, 0,  4, 5, 18, 2, 90, 1, 58, 7, 46, 
    0, 58, 7, 85, 2, 39, 5, 24, 6, 11, 8, 63, 1, 80, 4, 18, 3, 73, 
    4, 80, 0, 36, 1, 55, 6, 45, 2, 29, 7, 92, 3,  2, 5, 58, 8, 75
  };
  const int q0631[] = {
    9, 9, // Number of jobs and machines
    6, 46, 1, 91, 7, 39, 2, 99, 0, 46, 3, 36, 5,  4, 4, 39, 8, 87, 
    6, 62, 8, 39, 7, 65, 0, 44, 2, 13, 5, 85, 4, 40, 1, 96, 3, 48, 
    7, 13, 6, 99, 5, 12, 3, 72, 1, 54, 0,  2, 2, 81, 8, 73, 4, 70, 
    3, 71, 5, 46, 2, 17, 8, 32, 0, 73, 1, 25, 6, 30, 7, 42, 4, 64, 
    2, 78, 3, 16, 7, 76, 6, 29, 5, 79, 4, 78, 1, 74, 8, 94, 0, 46, 
    4, 82, 0, 54, 3,  1, 7, 10, 2, 88, 8, 12, 5, 41, 1, 68, 6, 35, 
    8,  4, 0, 68, 2, 17, 1, 21, 6, 97, 7, 66, 3, 49, 5, 80, 4, 68, 
    6, 87, 7, 90, 3, 23, 4, 21, 2, 54, 0, 84, 5, 85, 8, 41, 1, 57, 
    5, 63, 8, 85, 2, 27, 4, 84, 6, 11, 0, 70, 1,  5, 3, 16, 7, 62
  };
  const int q0632[] = {
    9, 9, // Number of jobs and machines
    1, 37, 2, 17, 8, 68, 6,  2, 4, 34, 7, 37, 0, 94, 3, 25, 5, 18, 
    7, 21, 3, 44, 6, 30, 0,  3, 5, 22, 4, 86, 2, 36, 1, 24, 8, 33, 
    0, 48, 8, 31, 4, 76, 5, 78, 1, 60, 7, 66, 3, 88, 6, 82, 2, 37, 
    7, 86, 2, 85, 8, 41, 3, 23, 0, 41, 5, 40, 4, 99, 1, 70, 6, 83, 
    5, 70, 0, 21, 2, 23, 3, 93, 1, 99, 7, 50, 4, 61, 8, 72, 6, 95, 
    4, 93, 8, 55, 5, 25, 3, 62, 2, 48, 0, 86, 7, 72, 1, 38, 6, 94, 
    1, 52, 5, 23, 8, 86, 7, 98, 0, 18, 6, 29, 4, 14, 2, 67, 3, 45, 
    6, 92, 2, 66, 5, 31, 1, 29, 3, 20, 4, 47, 8,  7, 7, 64, 0, 44, 
    6, 32, 8, 33, 0, 97, 3, 99, 4, 43, 2, 83, 7,  8, 1, 18, 5, 21
  };
  const int q0633[] = {
    9, 9, // Number of jobs and machines
    2, 57, 8, 16, 0, 10, 7, 34, 3, 25, 4, 35, 5, 53, 6, 42, 1, 69, 
    1, 61, 2, 23, 7, 26, 5, 42, 6, 41, 3, 71, 8, 79, 4, 61, 0, 30, 
    6, 99, 7, 25, 2, 38, 5, 15, 0, 79, 4, 68, 1, 78, 8, 49, 3, 89, 
    1, 73, 4, 64, 8, 18, 3, 38, 2, 51, 7, 71, 6,  1, 0, 26, 5, 53, 
    4,  5, 6, 98, 7, 46, 3, 28, 0, 82, 2, 17, 8, 99, 5, 49, 1, 41, 
    6, 15, 5, 19, 8, 37, 3, 48, 1,  6, 0, 87, 7, 10, 2, 35, 4, 43, 
    4, 39, 0, 13, 3, 20, 7, 13, 5, 70, 6, 96, 2, 96, 1, 43, 8, 40, 
    4, 95, 5, 64, 0, 40, 1,  4, 2, 42, 6, 38, 8, 97, 3, 72, 7, 94, 
    3, 88, 0,  2, 2, 30, 8, 31, 4,  5, 5, 62, 6, 19, 7, 17, 1, 39
  };
  const int q0634[] = {
    9, 9, // Number of jobs and machines
    1, 69, 6, 58, 5, 74, 2, 51, 0, 56, 7, 94, 8, 73, 3, 81, 4, 63, 
    3, 16, 5, 68, 1, 60, 6, 16, 2, 15, 8, 51, 0, 48, 7, 54, 4, 94, 
    5, 99, 6, 46, 7,  4, 0, 80, 8, 24, 1,  3, 4, 44, 3, 96, 2, 76, 
    0, 45, 4, 39, 7, 23, 2, 91, 8,  9, 5,  1, 6, 18, 1, 75, 3, 87, 
    2, 13, 8, 41, 3, 28, 1, 14, 6, 55, 7, 79, 4, 58, 0, 80, 5, 19, 
    4, 43, 2, 73, 3, 90, 6, 21, 0, 81, 8,  8, 1,  1, 5,  1, 7,  7, 
    4, 48, 5, 97, 6, 60, 2, 70, 7, 38, 3, 65, 0, 92, 8, 76, 1, 83, 
    1, 16, 5, 57, 2, 24, 0, 82, 6,  3, 8, 63, 7, 26, 4, 36, 3,  2, 
    2, 59, 7, 40, 3, 39, 8, 79, 4, 22, 5, 92, 6, 34, 1,  1, 0, 89
  };
  const int q0635[] = {
    9, 9, // Number of jobs and machines
    8, 23, 7, 64, 1,  2, 3, 29, 5, 36, 0, 84, 2, 26, 4, 38, 6, 45, 
    8, 40, 4, 20, 0, 67, 2, 18, 5, 49, 1, 85, 6, 52, 7, 78, 3, 16, 
    0, 39, 7, 33, 4, 22, 5, 21, 1, 77, 8, 12, 6, 58, 3, 47, 2, 34, 
    4, 27, 6, 66, 3, 69, 8, 28, 1, 45, 0,  4, 2, 59, 7, 88, 5, 62, 
    8, 76, 1, 88, 3, 86, 7,  5, 5, 86, 6, 34, 2, 50, 4, 13, 0, 71, 
    4, 75, 0, 31, 8, 50, 2, 20, 6, 29, 7, 54, 1, 21, 5, 78, 3, 73, 
    1, 54, 3, 80, 6, 85, 7, 24, 0, 41, 2, 31, 4, 78, 8, 55, 5, 40, 
    0, 23, 3, 53, 1, 94, 8, 10, 2, 13, 7, 60, 4, 56, 5, 48, 6, 30, 
    0, 98, 3,  8, 8, 41, 6, 74, 2, 70, 7,  1, 1, 58, 4, 77, 5, 45
  };
  const int q0636[] = {
    9, 9, // Number of jobs and machines
    7, 66, 6, 60, 1, 10, 3, 23, 8, 76, 0, 95, 4, 52, 5, 88, 2, 83, 
    2, 95, 6, 73, 4,  3, 3, 58, 5, 83, 7, 86, 8, 83, 1, 60, 0, 38, 
    3,  5, 8, 96, 0,  9, 7,  4, 4, 93, 1, 92, 6, 29, 2, 47, 5, 69, 
    3, 83, 0, 49, 8, 47, 6, 65, 4, 72, 7, 28, 5, 10, 1, 30, 2, 49, 
    5, 64, 6, 36, 7, 19, 2, 27, 0, 62, 1, 52, 8, 40, 4, 13, 3, 98, 
    7, 85, 3, 34, 2, 28, 5, 48, 4, 53, 6, 25, 0, 59, 8, 54, 1, 61, 
    2, 40, 7, 81, 8, 70, 6, 33, 1, 11, 5, 15, 4, 97, 3, 70, 0,  6, 
    2, 29, 5, 26, 4, 11, 8, 74, 1, 11, 6, 61, 0, 55, 7, 65, 3, 43, 
    3, 39, 0, 50, 6, 50, 2, 48, 1, 99, 7, 29, 5, 85, 4,  2, 8, 49
  };
  const int q0637[] = {
    9, 9, // Number of jobs and machines
    7, 69, 4, 39, 5, 30, 6, 12, 2, 61, 0, 19, 8, 82, 3, 42, 1, 29, 
    0, 82, 4, 89, 8, 70, 1, 75, 2, 74, 6, 97, 5, 63, 3, 47, 7,  9, 
    7, 35, 2, 91, 4, 53, 6,  9, 5, 41, 1, 95, 0,  2, 8, 36, 3, 34, 
    4, 35, 0,  5, 6, 71, 3, 89, 7,  3, 1, 80, 8, 36, 2, 82, 5, 99, 
    8, 63, 6, 18, 0, 59, 1, 95, 3, 40, 4, 75, 2, 76, 7, 93, 5, 41, 
    5, 48, 7, 29, 0, 65, 2, 36, 3, 52, 8, 28, 4, 31, 6, 10, 1, 41, 
    8, 18, 4, 35, 6, 15, 7, 95, 2, 20, 3, 33, 1, 20, 5,  4, 0, 36, 
    5, 75, 4,  1, 3,  7, 7, 56, 1, 40, 6, 71, 2,  9, 8, 67, 0, 53, 
    0, 78, 1, 35, 2, 95, 7, 31, 6, 95, 8, 90, 5, 67, 3,  4, 4, 26
  };
  const int q0638[] = {
    9, 9, // Number of jobs and machines
    0, 45, 3, 68, 7, 10, 5, 57, 8, 94, 2, 59, 4, 52, 6, 41, 1, 21, 
    2, 71, 6, 26, 3, 31, 4, 27, 7, 93, 1, 70, 8, 58, 5, 22, 0, 85, 
    2, 56, 3, 20, 5, 21, 4, 84, 7, 13, 8, 93, 6, 22, 1, 33, 0,  4, 
    6, 18, 2, 96, 7, 61, 8, 19, 0, 14, 4, 17, 3, 85, 5, 79, 1, 53, 
    8, 66, 3, 65, 1,  3, 2, 15, 4, 73, 0, 75, 6, 48, 7, 44, 5, 11, 
    7, 81, 3, 89, 8, 62, 5, 46, 0, 99, 6, 50, 4, 87, 2, 29, 1,  2, 
    0, 25, 8, 38, 2, 71, 3, 58, 4, 13, 5, 55, 7, 27, 1,  7, 6, 98, 
    7,  7, 6, 87, 1, 54, 0, 44, 3, 22, 4, 14, 8, 80, 5, 12, 2, 89, 
    6, 90, 1, 43, 0, 53, 5, 82, 8, 46, 4, 83, 3, 21, 2, 68, 7, 75
  };
  const int q0639[] = {
    9, 9, // Number of jobs and machines
    6, 27, 5, 33, 0, 76, 4, 31, 2, 38, 8, 92, 1, 10, 7, 22, 3, 31, 
    2, 56, 0, 62, 3,  9, 7, 69, 8, 84, 5, 54, 6, 50, 1, 31, 4, 24, 
    6, 31, 7, 94, 3, 57, 0, 44, 1, 87, 4, 22, 5, 77, 8, 72, 2, 46, 
    6,  6, 4, 57, 2, 22, 3,  9, 1, 72, 7, 78, 5, 32, 8, 15, 0, 21, 
    5, 10, 6, 69, 0, 59, 8, 28, 4, 39, 1, 17, 7,  3, 2, 33, 3, 31, 
    1, 94, 7, 89, 0, 52, 3, 42, 8, 17, 5, 42, 6,  9, 2, 63, 4, 81, 
    5, 80, 4, 67, 8, 10, 7, 95, 0, 76, 6, 29, 2,  4, 3, 81, 1, 84, 
    0, 14, 1, 17, 5, 63, 2, 88, 4, 17, 6, 65, 3, 87, 7, 85, 8, 76, 
    8, 12, 4, 65, 3, 68, 5, 65, 7, 28, 6, 31, 1,  9, 2, 29, 0, 76
  };
  const int q0640[] = {
    9, 9, // Number of jobs and machines
    0, 51, 7, 25, 8, 58, 3, 12, 1, 35, 2, 90, 5, 65, 4, 69, 6, 34, 
    5, 65, 7, 43, 6, 14, 8, 79, 3, 69, 0, 95, 2, 69, 4, 83, 1, 30, 
    5, 84, 2,  1, 3, 42, 0, 73, 7, 71, 4, 64, 6, 44, 8, 71, 1, 46, 
    6, 44, 5, 27, 3, 85, 0, 35, 4, 94, 8,  3, 2, 29, 1, 88, 7, 78, 
    0, 82, 8, 90, 1,  9, 3, 45, 7, 70, 6, 58, 2, 59, 5, 76, 4, 35, 
    3, 61, 0, 35, 4, 83, 6, 18, 7, 80, 1,  8, 8, 78, 5, 79, 2, 36, 
    3, 20, 7, 34, 4, 67, 1, 88, 2, 67, 5, 71, 6, 60, 8, 87, 0, 66, 
    1, 63, 2, 46, 5, 94, 6, 79, 7, 84, 3, 37, 4, 46, 8, 34, 0, 70, 
    5, 21, 4, 42, 6, 65, 2, 34, 1, 68, 8, 70, 7, 44, 3, 77, 0, 18
  };
  const int q0641[] = {
    9, 9, // Number of jobs and machines
    8,  4, 1,  3, 7, 83, 5, 12, 0, 73, 3, 62, 2, 11, 4, 66, 6, 20, 
    1, 73, 2, 45, 7, 82, 0, 59, 8, 10, 4, 33, 5, 72, 6, 91, 3, 28, 
    5, 90, 0, 15, 1, 39, 2, 80, 3, 99, 4, 73, 8, 72, 6, 91, 7, 48, 
    8, 67, 3, 55, 7, 28, 2, 83, 5, 63, 0, 16, 6, 68, 1, 87, 4, 83, 
    6, 61, 1, 53, 3, 93, 4, 24, 8, 14, 7, 78, 2,  9, 5, 85, 0, 47, 
    7, 85, 1, 30, 2,  5, 6,  2, 3, 83, 5, 33, 4, 86, 8, 14, 0, 58, 
    0, 83, 1, 37, 5, 49, 8,  2, 4,  9, 2, 74, 6, 57, 7,  4, 3, 69, 
    2, 41, 3, 24, 8, 55, 5, 67, 6, 56, 7, 50, 4, 93, 1, 68, 0, 59, 
    1, 71, 6, 79, 5, 38, 0, 25, 4,  7, 2,  1, 7, 34, 3, 14, 8,  2
  };
  const int q0642[] = {
    9, 9, // Number of jobs and machines
    0, 60, 1, 27, 8,  3, 7, 21, 4, 43, 3, 83, 2, 53, 6, 70, 5, 52, 
    4, 57, 0, 93, 3, 14, 8, 97, 7, 53, 6, 38, 1, 13, 5, 36, 2, 76, 
    2, 56, 4, 90, 5, 18, 0, 92, 6, 17, 3, 60, 8, 11, 1, 98, 7,  2, 
    3, 50, 8, 85, 6, 55, 0, 76, 5, 88, 2, 51, 7, 82, 1, 13, 4, 43, 
    4, 63, 0, 65, 7, 92, 3, 90, 2, 40, 5, 91, 8,  4, 1, 77, 6, 59, 
    2, 37, 1, 69, 3, 12, 4, 69, 5, 52, 8, 20, 0,  8, 7,  7, 6, 73, 
    7, 65, 3, 89, 8, 27, 2, 97, 5, 46, 6, 13, 4, 15, 0, 89, 1, 57, 
    4, 11, 2, 40, 3,  8, 5, 25, 1, 96, 6,  5, 7, 58, 0, 47, 8, 61, 
    3, 93, 6, 98, 0, 53, 1, 57, 5, 81, 7, 32, 4,  9, 8, 57, 2,  4
  };
  const int q0643[] = {
    9, 9, // Number of jobs and machines
    4, 77, 1, 32, 7, 11, 8, 65, 3, 40, 5,  8, 2, 26, 6, 46, 0, 80, 
    1,  9, 7, 91, 6, 71, 5, 49, 3, 12, 0, 35, 4, 55, 2,  5, 8, 24, 
    3, 42, 1, 96, 6, 41, 8, 81, 0, 98, 5, 15, 7, 63, 4, 37, 2, 37, 
    2, 72, 8, 44, 7,  7, 6, 11, 5, 53, 1, 54, 3, 89, 0, 11, 4, 65, 
    1, 25, 2, 36, 8,  8, 3, 39, 6, 59, 0, 44, 4, 91, 5, 30, 7, 97, 
    2, 82, 5, 61, 3,  3, 6, 59, 8, 23, 1, 89, 7, 76, 0, 51, 4,  6, 
    4, 70, 5, 32, 1, 80, 2, 70, 6, 64, 3,  3, 7,  8, 8, 79, 0, 65, 
    4, 68, 3, 82, 7, 75, 8, 14, 0, 58, 1, 78, 2, 76, 6, 12, 5, 99, 
    3,  9, 7, 32, 5, 66, 0, 11, 6, 54, 8, 89, 4, 54, 1, 66, 2, 24
  };
  const int q0644[] = {
    9, 9, // Number of jobs and machines
    3,  5, 0, 46, 2, 51, 1, 39, 7, 39, 5, 47, 8, 12, 6, 39, 4, 54, 
    3, 83, 7, 37, 2, 36, 4,  9, 0, 36, 6, 15, 5, 70, 8, 59, 1, 83, 
    8, 78, 5, 11, 7, 44, 0, 97, 1, 55, 4,  1, 3, 37, 6, 39, 2, 74, 
    1, 98, 2, 58, 4, 10, 3, 86, 6, 78, 5, 40, 8, 57, 0, 47, 7, 53, 
    6, 23, 8, 74, 3,  1, 5,  2, 2, 53, 1, 19, 4, 63, 0, 57, 7, 99, 
    3, 40, 6, 23, 4, 44, 2, 20, 5, 33, 7,  5, 0, 89, 1, 64, 8, 86, 
    2, 85, 4, 41, 5, 56, 0, 66, 3, 30, 8, 96, 6, 76, 7, 52, 1, 28, 
    5, 93, 6, 62, 8, 38, 0, 95, 3, 69, 1,  4, 2, 65, 4, 28, 7, 61, 
    7, 79, 6, 99, 0, 97, 8, 65, 3,  3, 2, 11, 1, 34, 5, 46, 4, 57
  };
  const int q0645[] = {
    9, 9, // Number of jobs and machines
    2, 34, 5, 71, 3, 48, 1, 82, 7, 23, 8, 41, 4, 55, 0, 64, 6, 33, 
    0, 52, 2, 39, 4, 85, 8, 34, 5, 69, 7, 43, 6, 30, 3, 49, 1,  6, 
    2, 82, 6, 49, 7, 46, 0, 79, 3, 37, 1, 45, 8, 90, 4, 47, 5, 57, 
    0, 26, 5, 33, 4, 92, 6, 81, 8,  6, 1, 72, 3, 18, 2, 16, 7, 92, 
    2, 50, 8, 39, 6, 13, 5, 43, 0, 99, 4, 53, 1, 83, 7,  2, 3, 56, 
    2, 26, 0, 91, 3, 53, 7, 88, 5, 60, 4,  2, 8, 96, 6, 76, 1, 67, 
    3, 99, 4, 99, 6,  2, 1,  2, 8, 91, 2, 70, 7, 61, 5, 17, 0, 84, 
    0, 83, 4, 12, 8, 94, 1, 53, 6, 19, 7, 57, 2, 59, 5, 70, 3, 52, 
    2, 29, 4,  2, 3, 83, 1, 29, 7, 58, 0, 73, 6, 82, 8, 90, 5, 94
  };
  const int q0646[] = {
    9, 9, // Number of jobs and machines
    2, 80, 1, 34, 4, 73, 7, 94, 3, 11, 5, 79, 8, 71, 6, 41, 0, 24, 
    5, 16, 8, 11, 6, 24, 4, 23, 7, 17, 3,  3, 1, 12, 2, 43, 0, 56, 
    8, 37, 1, 27, 7, 26, 5, 31, 0, 32, 2, 28, 6, 26, 4, 60, 3, 43, 
    0, 96, 1, 82, 3, 14, 2, 38, 7, 71, 8, 13, 5, 83, 4, 44, 6, 96, 
    5, 66, 1,  5, 3, 35, 4,  8, 8, 16, 7, 22, 0, 85, 6, 40, 2, 98, 
    2,  6, 7, 89, 5, 15, 0, 99, 1, 22, 4, 35, 8, 56, 6, 14, 3, 10, 
    1, 28, 7, 86, 6, 69, 2, 97, 4, 17, 3, 78, 0, 14, 8, 31, 5, 35, 
    8, 42, 2,  5, 7, 93, 4, 26, 3, 10, 6, 65, 5, 63, 1, 63, 0, 21, 
    6, 55, 5, 47, 2, 87, 1, 52, 8,  5, 0, 34, 7, 67, 3,  2, 4, 36
  };
  const int q0647[] = {
    9, 9, // Number of jobs and machines
    7, 17, 0, 47, 1, 53, 3,  7, 8, 96, 2, 92, 6, 43, 5, 63, 4, 67, 
    4, 79, 3, 80, 2,  5, 8, 39, 5, 83, 0, 36, 6,  5, 1, 90, 7,  4, 
    7, 24, 6, 66, 0, 33, 1, 25, 5, 11, 8, 45, 2, 71, 4, 88, 3, 28, 
    3,  7, 1, 57, 0, 75, 5, 25, 4, 62, 2, 99, 7, 59, 6,  6, 8, 82, 
    0, 61, 5, 28, 4, 81, 1, 38, 8, 81, 6, 86, 3, 39, 2, 86, 7,  6, 
    6, 97, 2, 47, 5, 34, 4,  7, 1, 55, 8, 36, 3, 16, 0, 70, 7, 16, 
    4, 53, 3, 53, 7, 60, 6,  9, 0, 27, 1, 40, 5, 45, 8, 44, 2, 69, 
    0, 54, 5, 97, 3, 96, 8, 30, 2, 63, 7, 97, 4, 53, 1, 65, 6, 86, 
    0, 46, 7, 34, 2, 53, 6, 70, 5, 32, 1, 83, 8, 45, 4, 88, 3, 81
  };
  const int q0648[] = {
    9, 9, // Number of jobs and machines
    2, 40, 8, 76, 3, 69, 6, 93, 1, 77, 4, 93, 0, 45, 5,  4, 7, 39, 
    0, 91, 3, 31, 4, 32, 6, 30, 2, 94, 7, 68, 5, 56, 8,  8, 1, 13, 
    3, 19, 2, 96, 0, 59, 6, 30, 8, 10, 1, 89, 5, 35, 7, 24, 4, 13, 
    4, 77, 2, 62, 1, 18, 0, 29, 8, 81, 7, 57, 6, 70, 3,  1, 5, 32, 
    0, 89, 6, 84, 8, 72, 5, 88, 4, 35, 7, 14, 2, 65, 3, 53, 1, 33, 
    7, 64, 4, 56, 3, 51, 0, 87, 8, 70, 1, 23, 6, 26, 5, 13, 2, 63, 
    7, 96, 0, 19, 5, 47, 2,  7, 3, 75, 6, 35, 8, 57, 1, 95, 4, 69, 
    0, 90, 1, 66, 5, 89, 6, 80, 8, 10, 3, 94, 7, 89, 4, 28, 2, 43, 
    3, 14, 2, 86, 6, 13, 8, 13, 7, 23, 5, 17, 4, 26, 1, 54, 0, 63
  };
  const int q0649[] = {
    9, 9, // Number of jobs and machines
    1, 27, 5, 81, 3, 60, 8, 61, 6, 94, 4, 19, 2, 55, 0, 57, 7, 37, 
    1, 62, 6, 39, 5, 63, 2, 92, 8,  3, 0, 21, 4, 96, 3, 49, 7, 45, 
    1,  7, 4, 40, 5, 40, 6,  7, 2, 31, 3, 82, 7, 36, 0, 95, 8, 68, 
    7, 84, 5, 10, 8, 56, 0, 70, 2, 95, 1, 47, 3, 27, 6, 30, 4, 51, 
    5,  2, 3, 62, 1, 31, 2,  7, 0, 46, 4, 59, 8, 78, 6, 51, 7, 46, 
    8, 84, 7, 66, 5, 48, 3, 87, 6, 68, 0,  5, 2, 51, 1, 63, 4, 77, 
    6, 18, 8, 69, 2, 22, 7, 16, 1, 87, 0, 40, 4, 39, 5,  6, 3, 28, 
    4, 58, 7, 43, 6, 66, 0, 87, 3, 10, 5, 56, 1, 44, 2, 22, 8,  5, 
    7, 92, 5, 80, 1, 57, 2, 24, 8, 43, 0,  2, 6, 15, 3, 80, 4, 29
  };
  const int q0650[] = {
    9, 9, // Number of jobs and machines
    7, 85, 1, 29, 2, 10, 5, 29, 0, 73, 8, 37, 3, 68, 4, 94, 6, 44, 
    4, 69, 0, 78, 8, 71, 7, 61, 5, 17, 2, 62, 6, 95, 3, 29, 1, 10, 
    6,  9, 4, 10, 8, 12, 0, 93, 1, 37, 2, 53, 3, 95, 7, 70, 5, 27, 
    8, 44, 4, 66, 3, 85, 6, 32, 7, 13, 0, 44, 5, 42, 1, 48, 2, 26, 
    1, 36, 6, 35, 3, 12, 0, 97, 8, 99, 2, 93, 5, 11, 7, 96, 4, 76, 
    0, 28, 4, 78, 3, 77, 2, 18, 6, 77, 7, 61, 1, 33, 8, 56, 5, 14, 
    5, 71, 7, 31, 8, 28, 1, 72, 6, 77, 3, 12, 4, 76, 0, 31, 2, 37, 
    3, 29, 8, 17, 2, 29, 7, 38, 5, 42, 0, 21, 1, 30, 4, 77, 6, 99, 
    6, 44, 4, 67, 2, 72, 3, 93, 7, 66, 1, 68, 0, 73, 5,  2, 8, 13
  };
  const int q0651[] = {
    9, 9, // Number of jobs and machines
    4,  9, 8, 69, 1, 90, 0, 84, 3, 96, 6, 55, 5,  7, 2, 16, 7, 97, 
    8, 32, 5, 97, 6, 83, 7,  2, 2, 46, 0, 56, 1,  1, 3, 34, 4, 11, 
    4, 21, 6, 55, 3, 21, 0, 10, 7, 79, 5, 98, 1, 26, 2, 19, 8, 94, 
    1, 21, 2,  8, 0, 29, 8, 64, 4, 34, 3,  3, 6, 71, 7, 33, 5, 34, 
    8,  1, 1, 12, 2, 74, 5, 86, 3, 74, 7, 60, 4, 12, 0, 79, 6, 67, 
    1, 87, 3, 78, 7, 82, 2,  7, 8, 74, 5,  3, 6, 93, 0, 49, 4, 90, 
    8, 73, 4,  3, 2, 46, 6, 60, 3, 97, 1, 82, 7, 34, 0, 99, 5, 39, 
    5, 55, 6, 25, 3, 30, 7, 64, 8, 72, 4, 79, 1, 63, 0, 26, 2, 32, 
    6,  8, 3, 72, 5, 74, 8, 25, 4,  7, 1, 71, 2, 57, 7, 80, 0, 35
  };
  const int q0652[] = {
    9, 9, // Number of jobs and machines
    8,  2, 6,  5, 3, 23, 2,  9, 1, 13, 0, 85, 7, 45, 5, 84, 4, 34, 
    4, 21, 3, 49, 0, 15, 8, 62, 1, 41, 7, 41, 6, 37, 2, 62, 5, 81, 
    8, 10, 6, 70, 7,  6, 1, 37, 0, 26, 5, 18, 3, 11, 4, 84, 2, 17, 
    1,  4, 5,  4, 3, 53, 6, 57, 0, 45, 8, 27, 4, 40, 2, 69, 7, 92, 
    0, 78, 2, 26, 8, 90, 4, 27, 3, 37, 7, 44, 5, 23, 1, 52, 6, 62, 
    1,  7, 8, 76, 2, 19, 3, 35, 0, 99, 5, 38, 6, 52, 7, 13, 4, 75, 
    0, 26, 5, 58, 4, 97, 1, 37, 8, 41, 3, 87, 2, 61, 6, 76, 7, 82, 
    6, 74, 0, 51, 8, 82, 5, 57, 3, 47, 4, 86, 2, 95, 7,  5, 1, 62, 
    1, 45, 6, 14, 0,  8, 5, 24, 7, 19, 4, 36, 3, 67, 2, 63, 8, 85
  };
  const int q0653[] = {
    9, 9, // Number of jobs and machines
    1,  1, 2, 32, 7, 72, 3, 90, 6, 16, 4, 48, 0, 95, 5, 33, 8, 47, 
    5, 91, 4,  5, 0,  1, 8, 78, 6, 57, 7, 42, 1, 84, 3, 12, 2, 51, 
    3, 58, 1, 99, 7, 63, 6, 75, 0, 78, 5,  6, 4, 83, 8, 54, 2,  3, 
    6, 11, 7, 66, 2, 51, 0, 47, 3, 75, 4, 36, 5, 31, 8, 78, 1, 83, 
    7, 19, 3, 20, 2, 75, 1, 12, 8, 16, 4,  1, 6, 13, 5,  1, 0, 42, 
    1, 31, 8, 73, 4, 77, 5, 85, 7, 66, 3, 81, 2, 13, 6, 85, 0, 56, 
    3, 79, 8, 58, 4, 60, 6, 51, 2, 83, 1, 23, 5, 51, 0, 10, 7, 13, 
    1, 31, 4, 67, 5, 78, 2, 38, 3, 97, 6, 75, 8,  1, 7, 71, 0, 42, 
    3, 42, 1, 86, 7,  6, 5, 56, 2, 20, 6, 14, 8, 33, 4, 12, 0, 32
  };
  const int q0654[] = {
    9, 9, // Number of jobs and machines
    8, 10, 5, 92, 1, 17, 3, 77, 0, 61, 4, 37, 2, 35, 7, 49, 6, 85, 
    0, 13, 7, 49, 2, 67, 6, 19, 3, 96, 4,  8, 8, 24, 5, 75, 1, 41, 
    8, 24, 3,  2, 2, 47, 0, 61, 1, 60, 4, 40, 7, 54, 5, 69, 6, 12, 
    2,  5, 7, 14, 1, 57, 5, 69, 4, 30, 8, 81, 6, 96, 3,  7, 0, 72, 
    1, 37, 2, 99, 5, 75, 4, 73, 3, 45, 7, 15, 6, 11, 0, 25, 8, 90, 
    5, 32, 0, 37, 1, 40, 2, 57, 3, 93, 7, 79, 6, 79, 8, 53, 4, 73, 
    5, 42, 1, 18, 7, 17, 8, 28, 6, 69, 2, 22, 0, 17, 4, 33, 3, 68, 
    5, 44, 8, 54, 0, 61, 3, 96, 6, 89, 4, 39, 1, 71, 2, 22, 7, 49, 
    2, 31, 6, 52, 4, 43, 7, 64, 8, 89, 3,  1, 5, 16, 1, 13, 0, 37
  };
  const int q0655[] = {
    9, 9, // Number of jobs and machines
    4, 90, 1, 46, 8, 28, 5, 65, 7, 58, 6, 34, 0, 72, 3, 65, 2, 73, 
    4, 88, 3,  6, 6, 68, 7, 96, 2, 31, 1, 41, 8, 66, 0, 67, 5, 48, 
    1, 97, 0, 13, 6, 89, 5, 48, 4, 76, 8, 64, 7, 37, 3, 11, 2, 37, 
    1, 33, 8, 74, 2, 25, 4, 73, 7, 85, 6, 74, 3, 76, 0, 12, 5, 43, 
    1, 76, 8, 74, 5, 13, 7, 68, 2, 25, 6, 39, 3, 77, 0,  8, 4, 67, 
    7, 53, 4, 75, 0, 93, 6, 17, 3, 44, 5, 61, 1, 29, 8, 55, 2, 61, 
    1, 61, 8, 51, 5, 52, 7,  3, 2, 66, 3, 99, 0, 29, 4,  3, 6, 69, 
    0, 77, 7, 35, 2, 62, 4, 58, 8, 98, 3, 24, 5, 31, 6,  1, 1, 81, 
    1, 47, 8, 94, 4, 24, 6, 29, 2, 73, 3,  6, 5, 75, 7, 24, 0, 23
  };
  const int q0656[] = {
    9, 9, // Number of jobs and machines
    0, 71, 3, 54, 7,  9, 8,  7, 2, 31, 5, 99, 6, 97, 1, 94, 4, 39, 
    4, 36, 0, 13, 8, 46, 2, 98, 3, 27, 5, 26, 7, 83, 6, 85, 1, 66, 
    4, 91, 1, 54, 5, 84, 3, 87, 0, 45, 6, 86, 2, 18, 7, 52, 8,  7, 
    1, 22, 7, 74, 2, 64, 4, 67, 8, 95, 6, 90, 3, 11, 0,  9, 5, 48, 
    3, 51, 4, 66, 2, 38, 8, 82, 7, 66, 1, 70, 0, 93, 6, 75, 5, 69, 
    1, 56, 2, 52, 4, 28, 5, 46, 3, 24, 7, 41, 8, 47, 0, 49, 6, 83, 
    4, 56, 6, 39, 8, 72, 0, 16, 3, 77, 2, 24, 1, 97, 7, 16, 5,  3, 
    7, 24, 1,  4, 0, 43, 5,  1, 3, 92, 2, 34, 8, 69, 6, 40, 4,  3, 
    7, 92, 0, 64, 1, 60, 2, 80, 3, 14, 4, 81, 5, 99, 8, 71, 6, 33
  };
  const int q0657[] = {
    9, 9, // Number of jobs and machines
    0, 78, 2, 50, 5, 15, 8, 59, 6, 11, 1, 57, 3, 41, 7, 75, 4, 55, 
    5, 92, 1,  7, 2, 75, 6, 11, 7, 73, 8, 54, 3, 26, 4, 13, 0, 63, 
    0, 17, 3, 31, 5, 40, 6, 54, 4, 99, 8, 35, 2, 17, 7, 48, 1, 26, 
    2, 97, 8,  6, 0, 23, 7, 67, 3,  3, 1, 50, 5, 60, 4, 98, 6, 80, 
    6, 99, 2, 28, 8, 17, 7, 76, 0, 12, 4, 64, 1, 58, 3, 10, 5, 88, 
    2, 97, 5,  1, 8,  2, 0, 89, 4, 29, 1, 64, 7, 41, 6, 44, 3, 79, 
    8, 82, 6, 30, 2, 65, 5,  1, 3, 73, 1, 46, 7, 93, 0, 17, 4, 25, 
    8, 87, 2, 82, 7, 97, 3,  8, 5, 49, 6,  8, 0, 86, 1, 74, 4, 91, 
    4, 57, 1, 50, 3, 19, 8, 41, 7, 44, 2, 16, 6, 44, 0, 11, 5, 59
  };
  const int q0658[] = {
    9, 9, // Number of jobs and machines
    4, 72, 0, 59, 3, 10, 1, 64, 7, 87, 2, 88, 8, 37, 5, 10, 6, 21, 
    8, 77, 4, 90, 0, 30, 1, 91, 7, 23, 3, 45, 2, 57, 6, 45, 5, 76, 
    4, 12, 2,  1, 1, 15, 0, 21, 6, 52, 8, 10, 7, 23, 5, 15, 3, 49, 
    1, 69, 8, 82, 2, 69, 6, 50, 7,  6, 5,  7, 0, 62, 3, 62, 4, 79, 
    1, 40, 7, 76, 6, 67, 3, 49, 2, 35, 8, 87, 4, 30, 5, 11, 0, 29, 
    2, 99, 7,  1, 0, 97, 5, 30, 6, 82, 4, 56, 3, 47, 8, 62, 1, 62, 
    1, 70, 3, 41, 5, 22, 0,  4, 2, 63, 8, 41, 6, 58, 7, 97, 4, 74, 
    7, 72, 6, 93, 4, 14, 3, 83, 1,  8, 0, 41, 5, 64, 8, 64, 2, 84, 
    1, 83, 2, 87, 3, 52, 4, 39, 7, 75, 6, 39, 5, 89, 8, 84, 0, 26
  };
  const int q0659[] = {
    9, 9, // Number of jobs and machines
    3, 88, 4,  9, 0, 69, 8, 40, 2, 11, 5, 44, 7, 20, 6, 28, 1, 25, 
    1,  5, 6, 34, 2, 29, 3, 71, 7, 60, 4, 33, 5, 56, 8, 62, 0, 16, 
    6, 25, 7, 49, 2, 37, 0, 72, 1,  4, 5, 42, 4, 15, 8, 58, 3, 84, 
    3, 23, 0, 10, 5, 94, 1, 13, 6, 37, 2, 81, 4, 90, 7, 11, 8, 26, 
    2, 27, 5, 64, 8, 96, 7, 85, 6, 79, 0, 55, 1, 86, 4, 43, 3, 66, 
    3, 99, 2, 96, 5, 82, 6, 74, 8, 41, 4,  7, 0,  9, 7, 48, 1, 25, 
    5, 16, 7, 83, 1, 85, 3, 34, 6, 75, 2, 18, 0, 70, 4, 55, 8, 95, 
    6, 27, 5, 94, 3, 20, 7, 73, 1, 99, 0, 61, 8, 81, 4, 24, 2, 33, 
    1, 86, 8, 33, 5, 92, 4, 46, 7, 95, 0, 11, 2, 92, 3, 24, 6,  1
  };
  const int q0660[] = {
    9, 9, // Number of jobs and machines
    5, 35, 7, 36, 4, 47, 2, 55, 6, 78, 8,  8, 3, 46, 0, 18, 1, 20, 
    1, 71, 7, 92, 4, 92, 8, 48, 0, 94, 5, 74, 3, 29, 2, 76, 6, 55, 
    7, 64, 8, 97, 3, 41, 5, 95, 1, 61, 6, 65, 4, 38, 2, 11, 0, 16, 
    5, 53, 2, 55, 0, 64, 8, 85, 4, 61, 1, 65, 3, 20, 6, 53, 7, 53, 
    7, 51, 4, 89, 3, 74, 8, 19, 6, 50, 2, 46, 1, 73, 5, 76, 0, 86, 
    7, 94, 1, 70, 3, 21, 2, 32, 4, 48, 0,  2, 8, 63, 6, 68, 5, 89, 
    3, 21, 2, 22, 8, 64, 6, 26, 0, 96, 7, 36, 4, 27, 5, 60, 1, 81, 
    8, 99, 0, 53, 2, 94, 4, 11, 1, 36, 7, 87, 3, 62, 5, 53, 6, 12, 
    8, 64, 6, 99, 7, 54, 4, 27, 2, 69, 0, 21, 1, 21, 5, 13, 3, 68
  };
  const int q0661[] = {
    9, 9, // Number of jobs and machines
    3, 49, 5, 27, 4,  6, 6,  7, 0, 67, 8,  6, 2, 71, 1, 32, 7,  4, 
    1, 65, 5, 13, 6, 71, 8, 52, 2, 71, 3, 98, 7, 35, 0, 84, 4, 45, 
    4, 26, 8, 55, 3, 81, 2, 44, 0, 22, 7, 58, 1, 60, 6, 66, 5, 11, 
    7, 39, 4, 81, 0, 28, 2, 45, 6,  6, 8, 32, 5, 17, 1, 89, 3, 26, 
    8, 63, 5, 15, 2, 53, 1, 59, 0,  8, 7, 54, 3, 66, 4, 19, 6, 27, 
    1, 74, 4, 22, 8, 91, 3, 58, 7,  5, 2, 44, 6, 75, 5, 39, 0, 25, 
    5, 84, 7, 80, 2, 14, 0, 69, 6, 55, 1, 32, 3, 26, 4, 29, 8,  2, 
    6,  3, 5, 82, 0, 74, 4, 27, 1, 20, 7, 81, 2, 32, 8, 23, 3,  4, 
    0, 24, 6, 18, 8, 12, 3, 94, 1,  2, 2, 66, 7, 62, 5, 40, 4, 50
  };
  const int q0662[] = {
    9, 9, // Number of jobs and machines
    8, 50, 1, 24, 4, 68, 5,  7, 7,  8, 6, 80, 0, 19, 3, 62, 2, 75, 
    3, 86, 2, 31, 1, 78, 4, 85, 0, 30, 5,  1, 7, 49, 6, 67, 8, 60, 
    0, 57, 8, 46, 4, 85, 7, 71, 1, 87, 6, 45, 5,  3, 3, 70, 2, 67, 
    4, 96, 2, 53, 5, 87, 7, 12, 0, 80, 1,  7, 6, 82, 3,  8, 8, 82, 
    1, 40, 3, 24, 4, 47, 0, 85, 2, 38, 8, 54, 6, 73, 5, 56, 7, 98, 
    7, 86, 1, 65, 2, 95, 8, 96, 0, 30, 3, 40, 6, 31, 5, 61, 4, 87, 
    6,  9, 3, 57, 8, 31, 0, 23, 2, 29, 5, 64, 4, 19, 7, 85, 1, 22, 
    6, 81, 3, 21, 2, 15, 1, 55, 4, 73, 0, 75, 7, 67, 5,  4, 8, 42, 
    2, 38, 4, 68, 8, 12, 7, 74, 0, 29, 1,  5, 3, 93, 5, 72, 6, 26
  };
  const int q0663[] = {
    9, 9, // Number of jobs and machines
    5, 30, 8, 50, 6, 93, 7, 64, 3, 62, 2, 67, 1, 48, 4, 52, 0, 13, 
    7, 92, 0, 45, 3, 31, 6, 63, 1, 42, 5, 41, 4, 83, 8, 64, 2, 14, 
    7, 22, 8, 43, 3, 94, 2, 92, 1, 88, 4, 33, 6, 10, 5, 30, 0, 32, 
    1,  4, 8, 74, 2,  8, 6, 64, 3, 45, 4, 45, 7, 28, 5, 23, 0, 75, 
    4, 35, 0, 62, 3, 55, 6, 69, 7, 78, 1,  6, 8, 40, 2, 95, 5, 24, 
    4, 20, 6, 41, 3, 50, 2, 47, 5,  9, 0, 88, 1, 10, 8, 25, 7, 43, 
    0, 61, 2, 42, 6,  4, 5, 82, 7, 87, 8, 78, 4, 87, 3, 81, 1, 36, 
    3,  9, 0, 98, 2, 50, 4, 66, 7,  9, 5, 78, 6, 18, 1, 56, 8, 82, 
    2, 46, 6, 31, 1, 35, 3, 18, 7, 86, 5,  9, 0, 40, 4, 73, 8, 48
  };
  const int q0664[] = {
    9, 9, // Number of jobs and machines
    8, 61, 2, 76, 6, 50, 4, 93, 0, 39, 1, 15, 7, 89, 3, 43, 5, 42, 
    2, 80, 7, 94, 0, 84, 1, 23, 8, 42, 3, 53, 5, 40, 6, 53, 4, 98, 
    7, 85, 5, 95, 4,  9, 8, 22, 6, 90, 2, 87, 0, 38, 3, 27, 1, 87, 
    8, 88, 7, 59, 1, 81, 6,  7, 0, 71, 5, 54, 3, 21, 4, 51, 2, 93, 
    7, 99, 4, 13, 3, 87, 1, 15, 6, 19, 0, 35, 8, 61, 2, 95, 5, 28, 
    2, 51, 3, 39, 4, 12, 5, 92, 1, 58, 6, 61, 0, 73, 7, 39, 8, 26, 
    6, 49, 1, 78, 3, 81, 7, 32, 4, 14, 8, 58, 5,  6, 2, 64, 0, 74, 
    8, 23, 3, 91, 6, 64, 7, 28, 5, 26, 4, 27, 2, 62, 1,  1, 0, 49, 
    4, 94, 0, 42, 3, 34, 6, 71, 5, 33, 1, 98, 8, 98, 2, 58, 7, 74
  };
  const int q0665[] = {
    9, 9, // Number of jobs and machines
    4, 90, 0, 32, 7, 18, 8, 10, 3, 60, 5, 47, 2, 87, 6, 21, 1, 88, 
    7, 99, 3, 93, 0, 12, 2, 90, 5, 56, 4, 16, 6, 44, 8, 90, 1, 78, 
    1, 18, 0, 15, 3, 44, 5, 80, 4, 66, 7, 88, 6, 41, 8, 75, 2, 21, 
    0, 65, 5, 42, 2, 57, 1, 20, 8, 72, 7, 28, 4, 89, 3, 17, 6, 24, 
    3, 64, 7, 76, 5, 68, 4, 43, 8, 69, 1, 77, 6, 76, 2, 31, 0,  6, 
    4, 10, 0, 68, 8, 19, 3, 56, 7, 20, 2, 56, 5, 17, 1, 56, 6, 10, 
    3, 18, 6, 46, 2, 88, 1, 40, 4, 73, 7, 76, 8, 78, 0, 87, 5, 58, 
    5, 94, 6, 70, 0, 39, 4, 30, 1, 79, 8, 13, 7, 16, 2, 97, 3,  4, 
    2,  5, 6, 42, 8, 71, 1, 26, 5, 77, 0, 35, 4, 78, 3, 29, 7, 19
  };
  const int q0666[] = {
    9, 9, // Number of jobs and machines
    6, 76, 4, 32, 1, 37, 7, 34, 0, 37, 8, 28, 2, 54, 3, 83, 5, 71, 
    1, 47, 8, 78, 7, 78, 2, 14, 4, 46, 5, 71, 0, 13, 3, 31, 6, 54, 
    8, 13, 6, 75, 2, 66, 7, 54, 3, 40, 0, 58, 1, 56, 4, 12, 5, 77, 
    0, 62, 5,  1, 8, 60, 2, 78, 4, 58, 7, 54, 6, 51, 1, 44, 3, 41, 
    1,  3, 3, 77, 2, 65, 6, 87, 5, 78, 8, 72, 7, 57, 4, 30, 0, 83, 
    0, 18, 1, 38, 7, 83, 5, 96, 8, 83, 4, 39, 2, 47, 3, 33, 6, 70, 
    4, 68, 3, 66, 7, 90, 6, 13, 0, 98, 1, 56, 2, 13, 8, 33, 5, 38, 
    0, 72, 3, 28, 7, 41, 2, 41, 5, 47, 8, 15, 4, 37, 6, 63, 1, 51, 
    2,  9, 7, 17, 4, 42, 0, 81, 8, 68, 5, 25, 3, 57, 1, 38, 6, 71
  };
  const int q0667[] = {
    9, 9, // Number of jobs and machines
    4, 85, 5, 74, 3, 64, 1, 33, 6, 99, 2, 75, 0, 81, 8, 61, 7, 37, 
    2, 99, 6, 29, 8, 59, 3, 32, 7, 98, 4, 40, 5, 42, 1, 65, 0, 49, 
    0, 41, 2,  2, 3, 37, 4, 98, 8,  8, 6, 90, 1, 94, 5, 58, 7, 31, 
    6, 82, 2,  3, 4, 86, 5, 36, 0, 87, 7, 23, 3, 73, 8, 94, 1, 50, 
    5, 67, 6, 85, 1, 31, 2, 58, 8, 72, 4, 94, 7, 94, 0, 62, 3, 79, 
    4,  7, 3, 68, 7, 29, 1, 46, 6, 99, 2,  2, 0, 37, 8, 37, 5, 60, 
    7, 54, 8, 87, 3, 67, 5, 28, 0,  9, 1, 20, 6, 47, 2, 98, 4, 38, 
    7, 92, 6, 69, 0, 38, 2,  2, 8, 82, 5, 59, 1, 16, 3, 66, 4, 42, 
    2, 25, 5, 84, 3, 78, 7, 28, 4, 59, 6, 23, 0, 10, 8,  8, 1, 97
  };
  const int q0668[] = {
    9, 9, // Number of jobs and machines
    5, 56, 2, 30, 6, 63, 1, 45, 0, 68, 3, 32, 4, 20, 8, 46, 7, 89, 
    2, 34, 7, 71, 6, 30, 4, 58, 5, 97, 0, 67, 1, 22, 3, 20, 8, 87, 
    8, 28, 3, 32, 0, 99, 2, 68, 1, 71, 4, 51, 6, 14, 5, 85, 7, 81, 
    8, 96, 0, 31, 5,  3, 2, 56, 3,  2, 4, 34, 7, 89, 6, 71, 1, 68, 
    5, 24, 1, 10, 8, 76, 3, 18, 7, 33, 0, 18, 4, 90, 2, 70, 6,  3, 
    3, 91, 6, 40, 7, 10, 2, 50, 8, 18, 0, 39, 1, 61, 5, 60, 4, 60, 
    7, 72, 0, 31, 3, 57, 2, 46, 1, 78, 6, 24, 5, 98, 8, 87, 4, 12, 
    6, 55, 4, 19, 7, 78, 1, 11, 8, 51, 2, 32, 0, 18, 5, 70, 3, 57, 
    4,  8, 1, 50, 6, 25, 8, 33, 2, 44, 0, 45, 5, 17, 3, 61, 7, 97
  };
  const int q0669[] = {
    9, 9, // Number of jobs and machines
    4, 83, 7, 14, 2, 65, 1, 45, 3,  7, 0, 62, 8, 71, 6,  1, 5,  9, 
    3, 80, 6, 89, 1, 13, 8, 70, 4,  5, 2, 46, 5, 39, 0, 58, 7, 72, 
    8, 56, 2, 57, 3, 42, 0, 36, 5, 62, 1, 99, 4, 42, 7, 39, 6,  6, 
    7, 14, 2, 49, 8, 84, 3, 39, 0, 34, 5, 99, 1, 20, 6, 64, 4, 79, 
    6, 68, 8, 81, 1, 70, 5, 73, 0, 79, 3, 11, 2, 98, 7, 83, 4,  9, 
    5,  4, 7, 35, 1, 98, 0, 95, 8, 71, 4, 99, 3, 71, 2, 50, 6, 83, 
    4, 90, 0, 24, 6, 22, 8, 28, 2, 65, 5, 38, 7, 72, 3, 27, 1, 51, 
    6, 84, 5, 49, 3, 53, 0, 46, 2, 10, 1, 41, 8, 53, 4, 40, 7, 52, 
    5, 71, 2, 30, 1, 41, 4, 89, 0, 96, 3, 11, 8, 97, 7, 11, 6, 36
  };
  const int q0670[] = {
    9, 9, // Number of jobs and machines
    5, 79, 6, 79, 1, 43, 3, 10, 2, 26, 4, 87, 7, 99, 0, 33, 8, 15, 
    3, 71, 6, 64, 0, 35, 1,  3, 2, 29, 8, 25, 7, 30, 4, 38, 5, 71, 
    1, 87, 6, 52, 3, 54, 0, 60, 7, 75, 8, 76, 5, 43, 4, 80, 2, 35, 
    4, 12, 1, 36, 7, 67, 2, 70, 0, 12, 6, 87, 8,  9, 3, 69, 5, 50, 
    6, 33, 7, 38, 4, 75, 0, 96, 3, 97, 8, 94, 1, 88, 5, 94, 2, 26, 
    4, 75, 5, 82, 3, 19, 6, 75, 7, 50, 2, 77, 8, 98, 1, 31, 0, 77, 
    6, 25, 3, 44, 4, 35, 0, 62, 7,  6, 5, 56, 1, 39, 2,  8, 8, 73, 
    7, 74, 3, 99, 4, 67, 8,  9, 1, 13, 2, 98, 6, 71, 0, 25, 5, 45, 
    3, 78, 6, 27, 1, 22, 5, 98, 4, 17, 8, 21, 7, 64, 0, 16, 2, 65
  };
  const int q0671[] = {
    9, 9, // Number of jobs and machines
    6, 78, 7, 13, 2, 21, 1, 10, 5, 10, 3, 71, 0, 14, 8, 69, 4, 27, 
    7, 16, 2, 75, 5, 77, 8, 63, 6, 60, 1,  9, 4, 42, 0, 51, 3, 35, 
    8, 13, 3, 41, 4, 11, 0, 10, 2, 98, 5, 20, 1, 84, 6, 68, 7, 55, 
    2, 59, 0, 79, 8, 81, 1, 16, 6, 92, 5, 18, 4, 79, 7, 80, 3, 54, 
    0,  9, 4, 47, 3, 22, 6, 27, 7, 54, 8, 41, 2, 26, 5,  7, 1, 54, 
    6, 62, 2, 82, 8, 81, 1, 27, 4, 62, 5, 17, 0, 20, 7, 78, 3, 91, 
    1, 53, 2, 59, 5, 61, 6, 11, 0,  7, 8,  9, 4, 95, 7, 95, 3, 34, 
    2, 18, 8, 66, 1, 57, 3, 87, 7, 58, 0,  7, 4, 88, 5, 86, 6, 55, 
    4, 80, 8, 93, 3, 68, 2, 50, 0, 91, 1, 42, 5, 79, 7, 72, 6, 34
  };
  const int q0672[] = {
    9, 9, // Number of jobs and machines
    5, 43, 2, 33, 0, 76, 3, 84, 4, 75, 7, 96, 6, 52, 8, 98, 1, 18, 
    5,  9, 1, 75, 4,  4, 2, 26, 3, 91, 7, 59, 0, 30, 8, 88, 6, 29, 
    3, 49, 8, 61, 4, 71, 0,  1, 7, 11, 6, 17, 1, 80, 5, 11, 2, 25, 
    3, 13, 5, 33, 7, 71, 8, 29, 1, 19, 6, 89, 0, 63, 2, 79, 4, 88, 
    7, 87, 0, 54, 8, 96, 2, 19, 3, 23, 6, 24, 1,  7, 5, 65, 4, 46, 
    7, 25, 1, 99, 8, 28, 0,  6, 5, 31, 6,  2, 4, 84, 2, 74, 3,  4, 
    3, 72, 1, 39, 2, 83, 0, 23, 4, 76, 7, 11, 8, 84, 5, 60, 6, 89, 
    2, 58, 6, 20, 4, 57, 1, 89, 3, 80, 5, 34, 8,  7, 0, 34, 7, 33, 
    5, 68, 7, 91, 1, 86, 6, 46, 0, 53, 8, 31, 4, 83, 2, 56, 3,  7
  };
  const int q0673[] = {
    9, 9, // Number of jobs and machines
    7, 36, 6, 65, 5, 48, 0, 79, 4, 91, 8, 91, 2, 45, 3, 43, 1, 99, 
    4,  6, 7, 10, 1, 23, 6, 16, 8, 67, 3, 37, 0, 20, 5, 69, 2, 81, 
    3, 93, 5, 34, 7, 95, 4,  4, 1, 83, 0, 73, 6, 58, 8, 61, 2, 36, 
    3, 46, 4, 95, 8, 83, 2, 75, 6, 67, 5, 61, 1,  3, 0, 88, 7, 48, 
    0, 71, 5, 28, 1, 27, 7, 25, 4, 63, 8,  5, 3, 49, 2, 91, 6, 97, 
    3, 99, 1, 38, 0, 92, 7, 89, 4, 40, 6,  1, 8, 11, 2, 59, 5, 69, 
    2, 28, 4, 11, 5, 41, 1, 72, 8, 76, 7,  9, 3, 62, 6, 94, 0, 53, 
    2, 56, 7, 36, 5, 95, 0, 83, 6,  5, 4, 41, 1, 16, 3, 46, 8, 90, 
    2,  1, 0,  6, 6, 73, 5, 36, 4, 84, 1, 41, 7, 54, 3, 85, 8,  8
  };
  const int q0674[] = {
    9, 9, // Number of jobs and machines
    1, 47, 5, 62, 0, 63, 2, 33, 4, 66, 6, 58, 3, 33, 7, 61, 8, 87, 
    4, 97, 7, 67, 5, 80, 2, 75, 3, 80, 8, 66, 6, 25, 0, 11, 1, 14, 
    4, 57, 7, 59, 2, 73, 6, 23, 8, 26, 3, 64, 0, 74, 5, 36, 1,  4, 
    1, 56, 2, 74, 6, 32, 3,  9, 8, 62, 5, 61, 7, 37, 0, 94, 4, 15, 
    6,  8, 0, 97, 8, 23, 4, 54, 3,  8, 5,  3, 1, 86, 7, 78, 2, 29, 
    8, 82, 5, 84, 6, 69, 4, 24, 3, 55, 0, 59, 1, 58, 2, 32, 7, 10, 
    8, 58, 3, 52, 4, 83, 2, 44, 6, 69, 5, 73, 7, 52, 1,  9, 0, 70, 
    3, 18, 2, 54, 1, 52, 5, 67, 0, 39, 7, 67, 4, 58, 8, 98, 6, 52, 
    1,  8, 0, 17, 6, 44, 8, 57, 3, 47, 5, 89, 7, 24, 2, 15, 4, 77
  };
  const int q0675[] = {
    9, 9, // Number of jobs and machines
    6, 29, 5, 25, 1, 82, 4, 41, 3,  5, 8, 49, 7, 61, 2, 20, 0, 75, 
    4, 48, 8, 44, 3, 96, 6, 60, 0,  4, 2, 86, 7, 31, 1, 20, 5, 50, 
    4, 15, 8,  7, 2, 37, 3, 10, 6, 36, 1, 96, 5, 75, 0, 87, 7,  9, 
    7, 65, 8, 82, 1, 44, 4, 36, 3, 86, 0,  7, 6, 56, 2, 75, 5, 90, 
    3, 47, 7, 21, 0, 96, 8, 70, 1, 52, 2, 55, 5, 44, 4, 64, 6, 66, 
    1, 61, 7, 75, 2, 74, 0, 71, 8, 63, 5, 50, 4, 47, 6, 52, 3, 40, 
    5,  8, 0, 38, 7, 97, 2, 49, 8, 77, 3, 52, 6, 99, 4, 34, 1, 42, 
    0, 35, 1, 79, 8, 88, 3, 85, 7, 25, 2, 90, 5, 23, 6, 69, 4, 66, 
    4, 72, 7, 47, 5,  4, 0, 82, 3, 97, 6, 77, 1,  5, 2, 50, 8, 40
  };
  const int q0676[] = {
    9, 9, // Number of jobs and machines
    6, 47, 2, 28, 4, 79, 0, 24, 5, 95, 3,  6, 1, 74, 8, 37, 7, 94, 
    5, 44, 2, 73, 3, 17, 4, 49, 6, 97, 8, 74, 1, 16, 0, 96, 7,  3, 
    6,  4, 2, 96, 5, 34, 3, 75, 8, 28, 0, 56, 7, 21, 1, 60, 4, 75, 
    8,  9, 0, 70, 4,  9, 2, 62, 1, 95, 5, 94, 3, 93, 7, 59, 6, 77, 
    4, 64, 5, 88, 7, 50, 6, 12, 3, 92, 0,  1, 8,  5, 2, 27, 1, 75, 
    3, 57, 0, 61, 2, 10, 8, 88, 4, 54, 7, 41, 5, 37, 1,  8, 6, 96, 
    6,  4, 5, 72, 4, 42, 3, 77, 8, 96, 1, 58, 7,  2, 0, 63, 2, 44, 
    7,  3, 0, 43, 8, 30, 3, 21, 5, 22, 1, 39, 2,  6, 6, 72, 4, 34, 
    1, 43, 2, 83, 8,  8, 5, 95, 7, 56, 0, 62, 4, 94, 3, 68, 6, 54
  };
  const int q0677[] = {
    9, 9, // Number of jobs and machines
    6, 76, 1,  2, 2, 24, 7, 52, 0, 75, 5, 86, 3,  6, 4, 41, 8, 72, 
    3, 63, 6, 40, 5, 62, 7, 67, 8, 89, 1, 50, 4, 47, 2, 18, 0, 51, 
    6, 17, 3, 64, 4, 64, 1, 91, 8, 70, 0, 82, 5, 48, 2, 61, 7, 56, 
    2, 20, 7, 79, 5, 16, 6, 41, 1, 65, 4, 10, 3, 64, 0, 15, 8, 87, 
    6,  9, 8, 77, 1, 28, 5, 58, 4, 56, 7,  5, 0, 64, 3, 59, 2, 74, 
    8, 93, 2, 40, 0, 79, 5,  7, 3, 30, 1, 41, 6, 90, 7,  4, 4, 26, 
    4, 21, 7, 38, 6, 74, 3, 20, 0, 32, 8, 13, 1, 22, 2, 75, 5, 84, 
    3, 99, 1, 12, 8, 34, 5, 76, 6, 43, 2, 14, 4, 38, 7, 44, 0, 12, 
    3, 63, 0, 22, 4, 49, 6, 56, 8, 12, 7, 12, 2, 24, 5, 71, 1, 29
  };
  const int q0678[] = {
    9, 9, // Number of jobs and machines
    3, 94, 2, 25, 6, 18, 5, 36, 4, 23, 1, 36, 0, 10, 8, 10, 7, 60, 
    0, 29, 1, 83, 7, 89, 4, 45, 6, 11, 5, 94, 3, 81, 2, 75, 8, 67, 
    8, 57, 1, 73, 5, 14, 4, 69, 0,  5, 6, 63, 3, 48, 2, 18, 7, 63, 
    7, 66, 6, 90, 1, 65, 4, 95, 2, 48, 8, 64, 0, 55, 5, 53, 3, 10, 
    3,  9, 7, 29, 6, 26, 0, 85, 4, 89, 5,  8, 2, 56, 1, 51, 8, 67, 
    8, 37, 5, 89, 0, 70, 6, 78, 1, 44, 4, 47, 7, 95, 3, 52, 2, 61, 
    5,  6, 6, 57, 1, 85, 3, 33, 4,  2, 0, 56, 7,  4, 2, 80, 8, 76, 
    1, 23, 2,  5, 5, 79, 8, 23, 7, 25, 6, 78, 3, 72, 0, 48, 4, 22, 
    6, 12, 7, 67, 1, 32, 0, 23, 5, 52, 4, 94, 8, 39, 2, 10, 3, 63
  };
  const int q0679[] = {
    9, 9, // Number of jobs and machines
    4,  2, 3, 58, 6, 66, 7, 56, 8, 31, 0, 10, 1, 18, 2, 78, 5, 75, 
    1, 12, 8, 67, 4, 89, 2, 73, 3, 25, 7, 56, 5,  1, 0, 22, 6, 16, 
    6, 72, 4,  3, 3, 40, 5, 23, 1,  6, 7, 54, 0, 74, 8,  5, 2, 66, 
    4, 90, 1, 15, 7, 55, 5, 97, 2, 34, 6, 24, 3, 11, 0, 73, 8, 60, 
    5, 52, 2, 25, 7, 89, 4, 84, 0, 69, 3, 85, 8,  8, 6, 53, 1,  8, 
    7, 66, 1, 21, 3, 87, 2, 14, 4, 70, 8, 80, 0, 57, 5, 53, 6, 36, 
    6, 36, 5, 17, 1,  8, 7, 84, 2, 52, 3, 22, 8, 23, 0, 21, 4, 83, 
    1, 36, 2, 67, 6, 66, 0, 71, 3, 46, 5, 60, 8, 24, 4, 64, 7, 58, 
    8, 96, 5, 97, 2, 34, 4,  2, 3, 62, 6, 79, 1, 80, 0, 14, 7, 67
  };
  const int q0680[] = {
    9, 9, // Number of jobs and machines
    2, 70, 8, 31, 6, 73, 5, 69, 7, 56, 1, 91, 3, 46, 4,  6, 0,  8, 
    2, 99, 5, 42, 0, 35, 4, 66, 8, 51, 1, 33, 6, 85, 3, 41, 7, 11, 
    3, 42, 1, 91, 6, 22, 7,  5, 0, 38, 2, 10, 5, 37, 4, 89, 8,  1, 
    0, 79, 2, 46, 3, 71, 8, 23, 4, 68, 1, 36, 7, 72, 6, 56, 5, 52, 
    2, 56, 8, 97, 6, 64, 0, 73, 7, 98, 1, 11, 5, 65, 4, 45, 3, 42, 
    3, 95, 6, 54, 8, 30, 7, 80, 4, 39, 1, 59, 0, 67, 5, 10, 2, 30, 
    1, 77, 6, 88, 2, 82, 0,  8, 8, 77, 5, 17, 4, 89, 7, 26, 3, 64, 
    8, 57, 4, 86, 1, 72, 3, 53, 6, 87, 2, 75, 7, 38, 0, 33, 5, 98, 
    2, 92, 4, 25, 3, 70, 7, 53, 1, 68, 8, 10, 0, 25, 6, 77, 5, 52
  };
  const int q0681[] = {
    9, 9, // Number of jobs and machines
    3, 21, 2, 94, 5, 23, 7,  7, 1, 14, 0, 46, 4, 62, 8, 97, 6, 69, 
    4,  7, 3,  1, 8, 62, 2, 96, 6,  3, 5, 82, 7, 64, 0,  5, 1, 76, 
    3, 23, 2, 31, 1, 41, 0, 19, 5, 30, 4, 56, 6, 79, 8, 87, 7, 46, 
    2, 59, 3, 47, 4,  5, 0, 32, 7, 37, 8, 77, 6, 30, 1, 65, 5, 39, 
    0, 70, 4, 85, 2, 84, 8, 14, 7, 77, 5, 45, 1, 38, 6, 68, 3, 95, 
    3, 46, 8, 89, 4, 53, 7, 80, 1, 72, 5, 81, 2, 75, 6, 99, 0, 45, 
    2, 48, 6, 91, 0, 59, 3, 74, 4, 49, 5, 77, 1, 50, 8, 43, 7, 65, 
    0, 26, 4, 83, 3, 30, 6, 70, 7, 81, 1, 26, 5, 31, 8, 75, 2, 52, 
    4, 62, 1, 11, 6, 45, 5, 47, 8, 62, 0, 23, 3, 71, 2, 70, 7, 40
  };
  const int q0682[] = {
    9, 9, // Number of jobs and machines
    4, 13, 5, 64, 0, 45, 2, 75, 7, 10, 6, 27, 8, 24, 3, 29, 1, 52, 
    3, 75, 4, 70, 0, 16, 1, 26, 6,  2, 2, 70, 5, 15, 8, 40, 7, 55, 
    6, 36, 4, 21, 3,  5, 7, 66, 2, 10, 5, 15, 8,  2, 0, 77, 1, 27, 
    8, 54, 3, 34, 1, 60, 7, 70, 4, 56, 6,  8, 2, 73, 0, 37, 5, 88, 
    7, 33, 4, 87, 0, 34, 6, 11, 5, 61, 3,  3, 2,  6, 8, 70, 1, 92, 
    5, 57, 0, 41, 2, 84, 8, 58, 4, 90, 1, 30, 6, 68, 7,  6, 3, 87, 
    0, 53, 6, 77, 5, 11, 4, 49, 8, 77, 7,  3, 2, 60, 1, 27, 3,  7, 
    3,  9, 4, 15, 6, 88, 7,  9, 1, 63, 5, 27, 2, 26, 0,  5, 8, 25, 
    4, 12, 2, 29, 1, 46, 8, 91, 6, 77, 5, 63, 7, 33, 0, 39, 3, 58
  };
  const int q0683[] = {
    9, 9, // Number of jobs and machines
    7, 97, 4, 79, 5, 47, 6, 12, 0, 37, 2, 71, 3, 94, 1, 63, 8, 18, 
    7, 76, 5, 89, 0, 28, 6,  6, 2, 60, 3, 81, 4, 97, 1, 21, 8, 98, 
    8, 17, 0, 76, 6, 63, 3, 41, 5, 93, 2, 77, 7, 23, 4, 91, 1, 65, 
    3, 21, 6, 97, 5,  8, 4,  3, 1, 96, 7, 86, 2, 71, 0, 96, 8, 74, 
    2,  4, 8, 39, 0, 46, 6, 98, 5, 31, 7, 16, 4, 87, 1, 37, 3, 22, 
    3, 95, 2, 65, 1, 34, 7, 84, 5, 73, 8, 50, 6, 57, 0, 27, 4, 16, 
    7,  9, 1, 85, 0, 40, 4, 98, 2, 48, 8, 98, 5,  6, 3, 99, 6, 86, 
    7, 30, 3, 88, 8, 99, 5, 45, 0, 28, 4, 15, 2, 40, 1, 17, 6, 55, 
    6, 58, 2, 99, 1, 33, 7, 70, 8, 51, 3, 59, 0, 31, 4, 84, 5, 32
  };
  const int q0684[] = {
    9, 9, // Number of jobs and machines
    7, 97, 6,  8, 5, 43, 4, 10, 8, 90, 3, 48, 1, 90, 2, 48, 0, 58, 
    2, 75, 4, 64, 8, 41, 3, 59, 5, 51, 6, 61, 1, 85, 7, 33, 0, 66, 
    2,  3, 8, 29, 4, 31, 6, 51, 3, 84, 5, 99, 7, 63, 1, 62, 0, 28, 
    5, 51, 2, 22, 3, 43, 7, 23, 4, 69, 0, 26, 1,  2, 8, 86, 6, 24, 
    2, 70, 6, 87, 8,  8, 3, 54, 0, 78, 1, 84, 5,  8, 7, 26, 4, 35, 
    4, 69, 8, 84, 5, 58, 2, 67, 3, 33, 7, 88, 6, 87, 1, 35, 0, 86, 
    4, 39, 1, 87, 2, 74, 0, 23, 7, 79, 6, 59, 8, 66, 5, 70, 3, 43, 
    5, 26, 7, 53, 2, 10, 4,  9, 8, 25, 6, 87, 3, 28, 0, 48, 1, 98, 
    1, 92, 8, 92, 2, 42, 5, 16, 3, 93, 7, 73, 6, 39, 4, 31, 0, 19
  };
  const int q0685[] = {
    9, 9, // Number of jobs and machines
    5,  7, 1,  4, 4, 33, 7,  9, 6, 49, 8, 35, 3,  7, 0, 87, 2, 81, 
    0, 90, 5, 42, 6, 99, 1, 87, 2, 55, 4, 43, 8, 68, 7, 69, 3, 72, 
    5, 94, 0, 48, 2, 97, 4, 70, 3, 83, 7, 88, 6, 76, 8, 76, 1, 22, 
    8, 16, 2, 99, 3, 39, 6, 96, 7, 37, 4, 21, 0,  8, 1, 34, 5, 46, 
    5, 46, 3, 87, 1, 91, 0, 22, 8, 19, 6, 44, 2, 33, 4, 87, 7, 70, 
    8, 42, 4, 99, 6,  2, 7, 92, 3, 10, 1, 53, 5,  1, 0,  2, 2, 80, 
    5, 21, 6, 83, 0, 84, 4,  9, 3, 88, 1, 24, 2, 84, 7, 49, 8, 63, 
    1, 22, 7, 76, 5, 61, 2, 76, 6, 31, 0, 18, 3, 42, 8, 74, 4, 72, 
    5,  2, 4, 65, 3,  5, 6, 43, 2, 59, 8, 56, 7, 63, 0, 14, 1, 68
  };
  const int q0686[] = {
    9, 9, // Number of jobs and machines
    2, 67, 0, 33, 1, 78, 5, 92, 6, 13, 8, 48, 7, 69, 3, 97, 4, 32, 
    5, 84, 6, 68, 3,  6, 0, 26, 4, 43, 1, 29, 7, 84, 2, 44, 8, 14, 
    7, 40, 5, 58, 0, 50, 1, 19, 6,  8, 3, 15, 8, 49, 4, 93, 2, 61, 
    4, 20, 7, 25, 2, 93, 5, 67, 0, 62, 6, 68, 8, 30, 3,  5, 1, 51, 
    2, 21, 0, 93, 3, 99, 7, 74, 8, 94, 5, 84, 6, 30, 1,  7, 4, 39, 
    2, 10, 1,  1, 4, 94, 7, 60, 6, 39, 0, 47, 3, 28, 8, 82, 5, 25, 
    1, 61, 5, 32, 2, 89, 3, 15, 0, 39, 8, 97, 6, 66, 4, 45, 7, 73, 
    1,  8, 3, 74, 8, 33, 2, 65, 6,  5, 0, 47, 5, 15, 4, 66, 7, 29, 
    4, 61, 7, 33, 5, 38, 2, 84, 0, 39, 1, 59, 3, 44, 8, 39, 6, 96
  };
  const int q0687[] = {
    9, 9, // Number of jobs and machines
    7, 60, 0, 90, 1, 73, 3, 74, 2, 63, 5, 23, 8, 70, 4, 82, 6, 75, 
    2, 30, 3, 83, 0, 10, 6, 39, 4, 86, 1, 51, 7, 30, 8, 26, 5, 76, 
    8, 62, 5, 38, 6, 16, 2, 22, 4, 10, 1, 66, 7, 11, 3, 63, 0, 61, 
    5, 60, 2, 52, 0,  3, 1, 64, 6, 96, 8, 90, 4, 10, 3, 90, 7,  6, 
    5, 59, 8, 73, 4, 18, 2, 57, 0, 43, 1, 39, 6, 79, 7, 49, 3,  3, 
    2,  9, 3, 46, 8, 55, 5, 63, 0, 39, 6, 67, 4, 19, 7, 57, 1, 21, 
    7, 81, 0, 85, 8, 67, 4, 12, 6, 98, 2, 60, 1, 47, 5, 79, 3, 75, 
    3, 86, 1, 91, 5, 90, 8,  6, 2, 13, 6, 93, 0, 33, 4, 34, 7, 28, 
    4, 53, 7, 83, 6, 61, 5, 14, 8, 47, 0, 61, 2,  9, 3, 32, 1, 23
  };
  const int q0688[] = {
    9, 9, // Number of jobs and machines
    6, 28, 7, 24, 2, 83, 5, 48, 1, 13, 4,  9, 3, 73, 0, 74, 8, 96, 
    8, 48, 4, 57, 7, 41, 5, 48, 2, 79, 6, 59, 3,  9, 0, 83, 1,  2, 
    6, 91, 7, 72, 8, 93, 2, 86, 4, 42, 0, 70, 5, 46, 1, 15, 3, 94, 
    0, 80, 3, 81, 6, 85, 5, 33, 4, 77, 2, 61, 1, 34, 8, 48, 7, 69, 
    0, 38, 7,  5, 8, 12, 3, 85, 2, 44, 4, 55, 5, 99, 6, 32, 1, 23, 
    6, 46, 2, 13, 3, 50, 8, 29, 5, 58, 7, 99, 1, 76, 4, 58, 0, 90, 
    5, 96, 3, 31, 4, 44, 1, 33, 0, 39, 7, 39, 6, 50, 2, 16, 8, 94, 
    2, 74, 7, 53, 1, 49, 0, 76, 4, 56, 5, 12, 8, 52, 3, 89, 6, 69, 
    5, 37, 3, 92, 4, 43, 7, 21, 0, 83, 8, 35, 2, 81, 1, 89, 6, 96
  };
  const int q0689[] = {
    9, 9, // Number of jobs and machines
    3, 78, 2, 80, 7, 23, 4, 53, 5, 76, 0, 39, 8,  9, 6, 70, 1, 70, 
    8, 40, 0, 78, 2, 15, 1, 82, 5, 60, 7, 78, 6,  1, 4, 13, 3, 54, 
    8, 98, 5, 71, 4, 79, 0, 49, 7, 88, 1, 20, 6, 31, 2, 80, 3, 14, 
    1, 61, 0, 27, 3, 13, 4, 98, 6, 45, 7, 59, 2, 15, 5, 30, 8, 18, 
    7, 34, 0, 84, 6, 19, 4, 54, 2,  3, 8,  3, 5, 23, 1, 36, 3, 39, 
    0, 41, 5, 19, 3, 26, 2, 25, 8, 98, 7, 38, 1,  8, 4, 50, 6, 32, 
    1, 73, 4,  8, 8, 24, 6, 64, 5, 46, 3, 57, 0, 80, 2, 99, 7, 14, 
    4, 82, 8, 81, 2, 75, 0, 58, 6, 18, 5,  4, 1, 34, 7, 59, 3, 98, 
    4, 67, 3, 92, 1, 69, 7, 49, 0, 64, 2, 65, 5, 41, 6, 52, 8, 44
  };
  const int q0690[] = {
    9, 9, // Number of jobs and machines
    8,  8, 6, 33, 1, 84, 4, 67, 2, 81, 5, 17, 0, 40, 3,  3, 7, 41, 
    3, 42, 1, 51, 7, 12, 8,  9, 4, 21, 0, 86, 2, 57, 6, 58, 5, 27, 
    6, 82, 8, 89, 5, 12, 7, 27, 4,  1, 1, 43, 2, 37, 3, 34, 0, 49, 
    1, 91, 3,  9, 5, 14, 6, 39, 8, 17, 0, 52, 7, 67, 4, 69, 2, 78, 
    5, 56, 0, 41, 4, 32, 3, 52, 1, 78, 7,  9, 6, 15, 2, 18, 8, 29, 
    2, 21, 8, 12, 7, 82, 1, 73, 6,  4, 4, 61, 0, 21, 3,  7, 5, 85, 
    1, 59, 8, 21, 4, 73, 6, 83, 0, 32, 5, 15, 7, 93, 2, 26, 3, 54, 
    0, 42, 5, 74, 4, 87, 7, 49, 6, 61, 8, 85, 3,  9, 1, 59, 2, 58, 
    0, 80, 5, 32, 6, 54, 2, 64, 1, 51, 3, 59, 8, 73, 7, 19, 4, 84
  };
  const int q0691[] = {
    9, 9, // Number of jobs and machines
    2, 63, 8, 10, 7, 41, 3, 14, 5, 94, 6, 92, 4, 11, 0, 11, 1, 84, 
    6, 63, 1, 11, 5, 11, 2, 85, 4, 83, 0, 94, 8, 54, 3, 67, 7, 51, 
    3,  1, 4, 97, 5, 15, 8,  2, 0, 34, 2,  3, 6, 85, 7, 73, 1, 85, 
    3, 73, 1, 54, 2, 55, 0, 23, 5, 50, 7, 98, 4, 31, 8, 65, 6, 27, 
    7, 53, 1,  5, 8,  1, 5, 57, 6, 33, 2, 38, 4, 14, 0, 34, 3, 90, 
    2, 57, 0, 39, 1, 15, 8, 98, 7, 30, 6, 73, 3, 77, 4, 39, 5, 60, 
    4, 77, 6, 25, 2, 32, 5, 70, 3, 63, 8,  8, 0, 91, 7, 81, 1,  7, 
    3, 84, 5, 68, 6, 50, 7, 25, 1, 67, 2,  1, 0, 73, 8, 88, 4, 58, 
    6, 11, 1, 49, 5, 94, 3, 37, 4, 53, 0, 88, 8, 77, 7, 70, 2, 85
  };
  const int q0692[] = {
    9, 9, // Number of jobs and machines
    5, 14, 3, 38, 7, 18, 8, 11, 6, 55, 1, 19, 4, 42, 0, 93, 2,  1, 
    5, 19, 7,  1, 1, 83, 0, 63, 4, 31, 3, 89, 2,  9, 6, 30, 8, 59, 
    8, 93, 5, 92, 4, 54, 2, 26, 3, 88, 1,  4, 7, 99, 6, 40, 0, 63, 
    2, 48, 3, 40, 1, 10, 0, 92, 5, 72, 7, 32, 6, 39, 4, 70, 8, 74, 
    6, 54, 8, 94, 0, 35, 3, 81, 2, 18, 5, 98, 7,  9, 4, 15, 1, 72, 
    4, 58, 0, 71, 5,  3, 3, 96, 7, 77, 8, 87, 6, 67, 1,  9, 2, 11, 
    2,  8, 6, 39, 3, 34, 0, 27, 7, 91, 4,  5, 5, 86, 1, 14, 8, 13, 
    1, 22, 8, 14, 3, 49, 5, 87, 6, 34, 2, 95, 4, 41, 7, 48, 0, 68, 
    0, 12, 6, 32, 5, 18, 7, 59, 3, 49, 4, 14, 1, 96, 2, 48, 8, 78
  };
  const int q0693[] = {
    9, 9, // Number of jobs and machines
    8, 24, 4, 15, 0, 40, 2, 24, 7, 67, 6, 48, 5, 20, 3, 55, 1, 94, 
    1, 83, 0, 76, 2, 22, 8,  9, 6,  2, 3, 43, 7, 41, 4,  8, 5, 50, 
    4, 36, 5, 75, 7, 27, 8, 40, 3, 13, 0, 51, 1, 85, 6, 76, 2, 55, 
    1, 62, 0, 18, 2, 86, 8, 70, 4, 78, 7, 29, 5, 90, 3, 32, 6, 73, 
    2, 73, 1, 75, 0, 87, 3,  9, 7, 29, 4, 88, 6, 43, 8, 66, 5, 23, 
    1, 44, 0, 36, 8, 28, 4, 89, 7, 58, 3, 78, 6, 88, 5, 19, 2, 10, 
    4, 74, 1, 17, 6, 10, 3, 11, 2, 53, 5, 14, 0, 61, 8,  1, 7, 94, 
    0, 63, 6, 76, 3, 24, 4, 89, 7, 88, 8, 74, 2,  6, 1, 19, 5, 26, 
    4, 67, 5, 68, 1, 32, 2, 96, 3, 81, 6,  4, 8, 46, 7, 89, 0, 47
  };
  const int q0694[] = {
    9, 9, // Number of jobs and machines
    3, 61, 2, 16, 4, 34, 6, 61, 0, 23, 5, 45, 1, 76, 7, 94, 8, 25, 
    8,  7, 7, 92, 5, 21, 4,  3, 6, 59, 3, 24, 1, 57, 0, 99, 2, 53, 
    6, 47, 3, 70, 5,  3, 1, 92, 2, 41, 7, 72, 0,  7, 4, 27, 8, 65, 
    4, 96, 1, 16, 2, 50, 6, 15, 5, 49, 8,  2, 0, 12, 7, 43, 3, 13, 
    3, 84, 8, 88, 6, 54, 2, 45, 4, 25, 5, 64, 0, 12, 7, 95, 1, 34, 
    2, 88, 0, 51, 3, 60, 4, 25, 7, 15, 8, 51, 5, 30, 6, 62, 1, 51, 
    7, 43, 5,  9, 4, 44, 2, 74, 1, 79, 6, 68, 8, 74, 0, 64, 3, 57, 
    3, 83, 1, 45, 7, 91, 4, 21, 5, 46, 0, 57, 2, 12, 8, 41, 6, 85, 
    7, 50, 6,  1, 3, 98, 0, 15, 4,  9, 1, 31, 8, 13, 5, 68, 2, 89
  };
  const int q0695[] = {
    9, 9, // Number of jobs and machines
    6, 22, 1, 65, 3, 31, 5, 39, 8, 46, 7, 15, 4, 14, 2, 59, 0, 72, 
    5, 60, 8, 70, 6, 18, 0, 52, 1, 75, 2, 85, 3,  2, 7, 55, 4,  1, 
    5, 13, 1, 33, 7, 84, 3, 39, 6, 91, 8, 41, 4, 91, 2, 55, 0, 37, 
    0,  7, 3, 89, 5, 60, 4, 59, 7, 61, 1, 53, 8, 62, 2, 93, 6,  1, 
    5, 22, 1, 15, 2, 66, 7, 30, 4, 24, 6,  4, 3, 55, 8, 64, 0, 78, 
    0, 49, 6, 92, 8, 71, 2, 64, 5, 19, 4, 59, 7, 97, 3, 39, 1, 51, 
    6, 92, 7, 15, 4, 81, 0, 87, 2, 41, 3, 95, 1, 40, 5, 77, 8, 82, 
    6, 34, 4, 93, 2, 17, 7, 83, 1, 26, 3, 42, 8, 57, 0, 27, 5, 79, 
    5, 12, 0, 93, 6, 52, 2, 76, 1, 64, 8,  6, 3, 64, 4, 47, 7, 35
  };
  const int q0696[] = {
    9, 9, // Number of jobs and machines
    4,  8, 5, 39, 0, 72, 6,  9, 7, 82, 8,  8, 1, 32, 3, 95, 2, 81, 
    8, 76, 1, 46, 2, 17, 4, 46, 6, 46, 3, 11, 0, 47, 5, 60, 7, 47, 
    4, 47, 1, 62, 7, 29, 5, 54, 8, 10, 3,  7, 6, 51, 2, 69, 0,  6, 
    6, 48, 7,  9, 1, 61, 8, 35, 0, 75, 5, 72, 4, 58, 2, 76, 3, 68, 
    7, 12, 5, 22, 1, 95, 2, 73, 3, 78, 6, 63, 8, 86, 4, 91, 0, 30, 
    5,  5, 8, 91, 2, 49, 1, 96, 6, 37, 4,  9, 0, 76, 3, 34, 7, 41, 
    4, 85, 7, 80, 8, 42, 0, 62, 2, 26, 6, 66, 5, 16, 1, 54, 3, 73, 
    3, 15, 0, 37, 2, 25, 1, 27, 6, 90, 5,  4, 4, 82, 7, 33, 8, 98, 
    2, 56, 0,  3, 4,  6, 7, 22, 6, 92, 8, 24, 1, 63, 5,  5, 3, 40
  };
  const int q0697[] = {
    9, 9, // Number of jobs and machines
    3,  9, 0, 55, 8, 86, 2, 73, 5, 58, 4, 73, 6, 17, 1,  8, 7, 68, 
    5,  4, 3, 25, 2, 28, 1, 45, 8, 86, 6, 88, 4, 91, 7, 89, 0, 55, 
    7, 87, 4, 24, 6, 57, 8, 25, 1, 86, 3, 39, 5, 63, 2, 79, 0, 69, 
    1, 32, 0, 26, 8, 55, 2, 12, 6, 34, 4, 31, 5, 35, 3, 93, 7, 53, 
    2, 25, 4, 83, 3, 29, 0, 84, 1, 65, 6, 60, 8, 62, 5, 94, 7, 12, 
    7, 21, 5, 11, 2, 24, 8, 93, 1, 76, 4, 11, 6,  6, 0, 72, 3, 42, 
    1, 29, 4, 56, 5, 23, 0, 56, 3, 42, 8,  8, 7, 60, 2, 95, 6,  2, 
    7, 56, 3, 50, 1, 74, 6, 26, 5, 18, 4, 24, 2, 99, 8, 73, 0, 68, 
    2, 39, 4,  9, 5, 59, 0, 16, 3, 39, 6, 91, 8, 54, 7, 59, 1, 29
  };
  const int q0698[] = {
    9, 9, // Number of jobs and machines
    2, 43, 7, 36, 0, 29, 4, 72, 3, 56, 6, 83, 8, 24, 1, 33, 5, 74, 
    0, 14, 2, 68, 5,  1, 7, 17, 1, 17, 8,  7, 6, 37, 4, 37, 3,  5, 
    6,  5, 4, 33, 1, 14, 5,  9, 2, 86, 0, 99, 7, 38, 3,  9, 8, 21, 
    8, 31, 2, 55, 4, 15, 7, 50, 1, 11, 3, 10, 6, 68, 0, 61, 5, 91, 
    2, 95, 4, 34, 6, 77, 0, 13, 3, 45, 1, 92, 5, 47, 8, 81, 7,  8, 
    3, 34, 2, 73, 8, 55, 4, 84, 1, 68, 0, 97, 5, 76, 6, 61, 7, 80, 
    7, 80, 1, 53, 5,  8, 4, 15, 6, 23, 2, 30, 0, 44, 3, 96, 8, 85, 
    2, 46, 8, 16, 1, 39, 3, 87, 7, 96, 6, 26, 4, 11, 0,  3, 5, 63, 
    4, 44, 1, 15, 6, 26, 8, 73, 3, 67, 0, 85, 5, 21, 2, 15, 7, 79
  };
  const int q0699[] = {
    9, 9, // Number of jobs and machines
    5, 82, 8, 94, 6, 75, 0, 70, 1, 15, 7, 82, 4,  3, 3, 26, 2, 97, 
    5, 92, 0, 40, 8, 99, 2, 97, 1, 13, 7, 80, 4, 85, 6, 74, 3, 29, 
    2, 43, 5, 47, 0, 11, 7, 16, 4, 85, 8, 95, 3,  6, 6, 67, 1, 48, 
    4, 52, 1, 29, 2, 39, 3, 62, 0, 23, 8, 98, 6, 41, 7, 10, 5, 61, 
    5, 19, 6, 78, 1, 23, 7, 36, 4, 73, 2, 71, 0, 22, 8, 93, 3, 66, 
    3, 18, 1,  3, 7, 78, 4, 46, 2, 18, 0, 97, 6, 90, 8, 82, 5, 69, 
    3, 71, 1, 46, 4, 37, 8, 83, 2, 94, 0, 81, 5,  1, 7, 42, 6, 98, 
    2, 90, 3, 30, 6, 89, 0, 71, 4, 20, 1, 99, 7, 87, 8, 25, 5, 57, 
    7, 18, 1, 71, 4, 86, 6, 71, 0, 88, 8,  5, 3, 45, 5, 49, 2,  8
  };
  const int q0700[] = {
    9, 9, // Number of jobs and machines
    0, 98, 1, 93, 2, 94, 3, 32, 6, 54, 7, 24, 4,  3, 8, 46, 5, 52, 
    3,  8, 6, 49, 1, 91, 2, 10, 5, 19, 0, 72, 7, 16, 8, 54, 4, 59, 
    2, 90, 4, 68, 6, 16, 0, 89, 5, 76, 8, 71, 1, 23, 7, 75, 3, 53, 
    2, 97, 3, 27, 6, 11, 8, 77, 5,  3, 0, 75, 4,  5, 7, 52, 1, 15, 
    0, 32, 5, 59, 4, 32, 1, 46, 2, 77, 3, 79, 7, 17, 6, 63, 8, 20, 
    4, 72, 6, 57, 3,  8, 0, 17, 8, 51, 1, 70, 2, 18, 5, 57, 7, 40, 
    7, 78, 1, 49, 3, 30, 0, 11, 2, 45, 4,  4, 5, 27, 6, 28, 8, 10, 
    6,  4, 4,  3, 8, 99, 5, 20, 7, 80, 3, 73, 0, 99, 1, 42, 2, 34, 
    6,  2, 1, 91, 7, 69, 3, 55, 0, 58, 8, 54, 4, 57, 5, 21, 2, 20
  };
  const int q0701[] = {
    9, 9, // Number of jobs and machines
    8, 40, 4, 29, 0,  7, 5, 92, 3,  5, 2, 70, 7, 88, 6, 80, 1, 47, 
    3, 65, 4, 13, 1, 21, 2, 23, 8, 25, 5, 42, 6, 56, 7, 10, 0, 23, 
    1, 39, 7, 55, 8, 40, 3, 24, 5, 96, 0, 48, 6, 20, 2, 41, 4, 98, 
    8,  2, 0, 31, 7, 87, 1, 47, 2, 32, 3, 57, 6, 34, 4, 20, 5, 60, 
    7,  6, 6, 98, 0, 52, 1, 18, 2, 66, 3, 86, 5, 75, 4, 85, 8, 63, 
    1, 37, 5, 95, 4, 69, 7, 68, 8, 93, 2, 99, 6, 62, 3, 79, 0, 57, 
    5, 83, 3, 12, 6, 75, 4, 55, 0, 53, 1, 57, 8, 73, 7, 93, 2, 13, 
    3, 38, 0, 61, 5, 17, 4, 27, 2, 43, 8, 64, 6, 59, 7, 96, 1,  2, 
    0, 67, 4, 70, 1, 47, 6, 84, 7, 34, 3, 44, 8, 50, 2, 38, 5, 56
  };
  const int q0702[] = {
    9, 9, // Number of jobs and machines
    3, 30, 6, 91, 8, 51, 5, 92, 2, 83, 1, 11, 4, 86, 7, 59, 0, 38, 
    3, 88, 0, 35, 8, 99, 4, 30, 7, 23, 5, 14, 1, 65, 2, 21, 6,  5, 
    8, 91, 1,  6, 7, 75, 4, 65, 0, 40, 3, 17, 6, 87, 2, 69, 5, 74, 
    5, 63, 1, 74, 4, 74, 8, 43, 3, 41, 0, 15, 6, 29, 7,  6, 2, 68, 
    2, 40, 5, 21, 1, 76, 3, 84, 4, 75, 8, 50, 7, 22, 0, 67, 6, 18, 
    6, 41, 2, 40, 0, 87, 8, 56, 1,  8, 7, 40, 4, 61, 3, 69, 5,  4, 
    3, 50, 0,  6, 6, 81, 2, 30, 5, 10, 8, 64, 4, 95, 1, 99, 7, 97, 
    7, 87, 6, 70, 4, 81, 0,  4, 5, 35, 8, 45, 3, 55, 2, 37, 1, 33, 
    0, 21, 4, 93, 8,  3, 3, 76, 6, 86, 2, 73, 1, 84, 5, 36, 7, 35
  };
  const int q0703[] = {
    9, 9, // Number of jobs and machines
    1, 59, 6, 27, 0, 28, 8, 14, 4, 39, 3, 23, 7, 70, 2, 19, 5,  6, 
    4,  6, 7, 52, 5, 59, 3, 35, 1, 84, 6, 68, 8, 73, 0, 44, 2, 58, 
    0, 55, 8, 62, 4, 92, 3, 39, 2, 44, 5, 74, 7, 55, 1, 17, 6, 44, 
    3,  9, 2, 87, 6, 91, 4, 12, 8, 92, 7, 19, 1, 27, 5, 17, 0, 71, 
    1, 39, 7, 18, 6, 53, 8, 55, 0, 83, 2, 20, 4, 71, 5, 76, 3, 52, 
    6, 31, 5, 72, 1, 73, 4, 45, 2, 70, 7, 82, 3, 35, 8, 98, 0, 57, 
    6, 13, 4, 49, 3, 20, 0, 59, 2, 83, 7, 22, 5, 83, 8, 40, 1, 65, 
    1, 17, 4, 53, 2, 36, 3, 79, 7, 95, 8, 39, 5, 84, 0, 12, 6, 54, 
    4, 95, 1, 85, 0,  7, 8, 21, 2, 26, 6, 22, 7, 17, 3, 97, 5, 49
  };
  const int q0704[] = {
    9, 9, // Number of jobs and machines
    1,  9, 5, 49, 6, 41, 0, 47, 8, 80, 7,  1, 2, 38, 3, 93, 4, 95, 
    7, 42, 4, 19, 5,  2, 6, 56, 1, 30, 3, 40, 0, 51, 8, 14, 2, 17, 
    4, 55, 1, 37, 8, 57, 6, 88, 2, 23, 3, 81, 5, 95, 7, 84, 0, 67, 
    5, 77, 2, 66, 1, 13, 0, 30, 6, 50, 4, 39, 3, 48, 8,  3, 7, 30, 
    2, 80, 0, 92, 7, 56, 6, 43, 1, 82, 5, 88, 8, 86, 4, 61, 3, 23, 
    6, 36, 1, 65, 8, 33, 7, 71, 3, 20, 4, 53, 2, 85, 5, 50, 0, 88, 
    0, 65, 4, 12, 5, 10, 3, 84, 8, 93, 1,  7, 6,  1, 7, 41, 2, 49, 
    6, 39, 7, 25, 8, 32, 4, 96, 0, 85, 3, 67, 2, 50, 5, 43, 1, 58, 
    0, 86, 4,  9, 8, 37, 5,  5, 1, 68, 7, 92, 3, 51, 6, 68, 2, 16
  };
  const int q0705[] = {
    9, 9, // Number of jobs and machines
    4, 70, 5, 66, 8, 63, 2, 53, 7, 72, 6,  6, 3, 62, 0, 47, 1,  1, 
    0, 76, 6, 22, 7, 93, 1, 84, 5, 83, 4, 20, 8, 95, 3,  3, 2, 50, 
    6, 31, 4, 12, 5,  4, 2, 11, 8, 70, 1,  3, 3, 64, 7,  6, 0, 91, 
    7, 38, 3, 56, 1, 48, 6, 49, 2, 39, 8, 28, 5, 32, 0, 40, 4, 33, 
    8, 28, 4, 89, 3, 77, 2, 93, 1, 90, 5, 50, 0, 56, 7,  5, 6, 22, 
    5, 33, 2, 90, 1,  3, 6, 13, 3, 14, 7, 17, 8, 87, 0,  2, 4, 82, 
    1, 97, 0, 97, 2, 61, 5, 85, 7, 93, 6,  4, 3, 15, 4, 30, 8, 92, 
    3, 50, 8, 76, 4, 32, 7, 59, 1, 79, 5, 81, 6, 17, 2, 72, 0, 96, 
    3, 29, 5, 37, 2, 26, 8, 53, 1, 95, 0, 57, 6, 37, 4, 59, 7, 49
  };
  const int q0706[] = {
    9, 9, // Number of jobs and machines
    7, 17, 2, 48, 1, 37, 6, 67, 5, 95, 8,  3, 3, 22, 0, 19, 4, 63, 
    7, 79, 4, 50, 0, 42, 5, 91, 6, 33, 1,  2, 3,  2, 8, 60, 2, 25, 
    7, 20, 5,  6, 1, 32, 8, 25, 3, 41, 6, 60, 4, 79, 0, 97, 2,  5, 
    2, 16, 6, 64, 1, 29, 0, 34, 5, 95, 8, 94, 4,  5, 7, 54, 3, 11, 
    0, 26, 2, 13, 1, 63, 4, 83, 5, 85, 6, 98, 8, 73, 7, 70, 3, 46, 
    5, 84, 7, 21, 6, 49, 4, 42, 3, 77, 8, 31, 1,  1, 2, 64, 0, 96, 
    6, 71, 1,  8, 5, 43, 0,  3, 4, 35, 7, 57, 3, 32, 8, 81, 2, 35, 
    8, 54, 0, 91, 6, 92, 7, 45, 5, 69, 1, 14, 3, 23, 4, 12, 2, 23, 
    8, 84, 7, 58, 2, 26, 5, 81, 1, 72, 6, 49, 4,  4, 0, 23, 3,  8
  };
  const int q0707[] = {
    9, 9, // Number of jobs and machines
    6, 37, 4,  9, 5, 68, 0, 32, 1, 87, 3, 75, 8, 20, 7, 60, 2, 90, 
    6, 48, 2, 19, 0, 50, 5, 50, 4, 49, 8, 66, 1, 84, 3, 11, 7, 86, 
    1,  2, 2, 12, 7, 90, 3, 50, 6, 78, 8, 52, 5, 46, 0, 10, 4, 12, 
    7, 24, 6,  4, 1, 36, 2, 82, 3, 98, 4, 41, 8, 88, 0, 12, 5, 82, 
    0, 29, 6, 39, 8, 96, 4, 78, 3, 16, 5,  7, 2, 34, 1, 96, 7, 62, 
    6, 24, 2, 64, 7, 93, 4, 31, 0,  5, 8, 13, 1, 57, 3, 66, 5, 36, 
    0, 12, 5, 17, 3, 24, 2, 49, 4,  6, 8,  7, 6, 33, 7, 77, 1, 63, 
    7, 77, 5, 49, 8, 17, 3, 36, 4, 81, 1, 71, 6,  3, 2, 53, 0, 69, 
    1, 63, 5, 41, 2, 34, 3, 88, 4, 36, 7, 95, 0, 37, 8, 99, 6, 80
  };
  const int q0708[] = {
    9, 9, // Number of jobs and machines
    2,  3, 5, 90, 0, 88, 7, 71, 1,  6, 4, 91, 8, 63, 6, 20, 3, 87, 
    7, 55, 2, 64, 4, 78, 1, 26, 5, 53, 0, 52, 6, 72, 8,  3, 3, 45, 
    7,  5, 5, 70, 0,  8, 4, 63, 8,  5, 3, 66, 1, 32, 2, 45, 6, 40, 
    3, 37, 6, 85, 0, 77, 7, 44, 2, 83, 4, 96, 1, 71, 5, 65, 8, 44, 
    7, 50, 6, 42, 3, 41, 1, 90, 5, 51, 2, 73, 8, 31, 0, 57, 4, 89, 
    8, 48, 4, 44, 3, 93, 7, 32, 6, 36, 2, 39, 0, 87, 1, 75, 5, 11, 
    6, 87, 5, 32, 2, 78, 3, 87, 4, 31, 0, 95, 7, 23, 8,  8, 1, 74, 
    2, 86, 8, 40, 1, 75, 7, 16, 6, 11, 4,  6, 3, 45, 0, 97, 5, 12, 
    2, 94, 4, 73, 0, 77, 3, 89, 7, 74, 5, 42, 8, 83, 1, 18, 6, 75
  };
  const int q0709[] = {
    9, 9, // Number of jobs and machines
    1, 68, 7, 99, 2, 32, 6, 39, 8, 73, 5, 62, 0, 60, 4, 51, 3, 32, 
    2, 32, 5, 53, 3, 97, 8,  2, 0, 30, 6, 50, 4, 79, 1,  8, 7, 59, 
    8,  4, 7, 52, 3, 83, 4, 51, 0, 66, 5, 33, 1, 23, 6, 72, 2, 75, 
    3, 78, 7, 97, 5, 15, 8, 90, 2, 76, 4, 34, 6, 45, 0, 86, 1,  3, 
    6, 90, 5, 59, 8, 95, 7, 34, 3, 24, 4, 42, 1, 48, 2, 74, 0, 86, 
    5, 98, 3, 92, 1, 21, 0,  8, 7, 81, 8, 86, 2, 76, 4, 14, 6,  6, 
    8, 24, 2, 88, 0, 88, 5,  1, 7, 91, 4, 24, 3, 31, 6, 52, 1, 97, 
    5, 22, 7,  9, 2, 31, 4, 50, 1, 90, 8, 37, 0, 89, 3, 27, 6, 52, 
    0, 47, 1, 21, 7, 48, 3, 45, 5, 99, 2,  3, 6,  5, 4,  7, 8, 36
  };
  const int q0710[] = {
    9, 9, // Number of jobs and machines
    1, 11, 5, 33, 3, 73, 6,  5, 2, 64, 4,  6, 7, 45, 0, 38, 8, 12, 
    4, 84, 7, 28, 3, 98, 0, 84, 5, 46, 2, 93, 6, 87, 1, 48, 8, 35, 
    4, 57, 5, 78, 1, 51, 3, 68, 0, 86, 7,  4, 2, 78, 6, 81, 8, 73, 
    3, 72, 0, 58, 2, 69, 1, 69, 8, 94, 4, 54, 7,  5, 5, 45, 6, 34, 
    1, 68, 2, 27, 7, 98, 0,  7, 8, 57, 5, 73, 4, 22, 6, 44, 3, 52, 
    3, 82, 7, 57, 5, 40, 1, 36, 2, 63, 8, 59, 6,  4, 0, 31, 4,  4, 
    5, 42, 3, 37, 8, 18, 1, 40, 4, 54, 7, 22, 2, 16, 0, 41, 6, 75, 
    6, 95, 4, 90, 2, 60, 3, 10, 7, 36, 8, 57, 0, 73, 5,  9, 1, 64, 
    4, 67, 7, 80, 5, 69, 6, 37, 8, 23, 2, 92, 1, 15, 3, 65, 0, 23
  };
  const int q0711[] = {
    9, 9, // Number of jobs and machines
    2, 31, 3, 50, 8, 25, 5, 20, 4, 44, 0, 26, 7, 19, 1, 49, 6, 69, 
    1, 61, 4, 81, 6, 58, 7, 50, 2, 35, 3, 24, 0, 54, 5, 43, 8, 71, 
    6,  6, 2, 63, 5, 82, 0, 35, 8,  5, 3, 87, 4, 31, 7, 71, 1, 86, 
    6, 97, 8,  6, 7, 54, 5, 35, 4, 84, 0, 27, 1,  1, 2, 93, 3, 19, 
    6, 23, 1,  6, 7, 42, 3,  6, 2, 18, 4, 43, 8, 60, 5, 96, 0, 89, 
    7, 90, 5, 89, 2,  7, 1, 94, 3, 18, 0, 13, 8, 69, 6, 60, 4, 98, 
    3, 45, 8,  8, 7, 22, 5, 78, 4,  8, 6, 14, 1, 96, 2, 92, 0, 42, 
    0, 12, 8, 92, 1, 94, 6, 94, 5, 36, 3, 76, 4, 17, 7, 42, 2, 85, 
    0, 19, 3, 96, 6, 23, 7, 82, 1, 38, 8, 68, 5, 14, 2, 63, 4, 57
  };
  const int q0712[] = {
    9, 9, // Number of jobs and machines
    4, 65, 8, 80, 0, 46, 3, 58, 7, 31, 5, 86, 6, 66, 2, 20, 1, 23, 
    1, 55, 7, 96, 8, 94, 5, 70, 4, 48, 0, 64, 2, 71, 6, 29, 3, 28, 
    8, 43, 6, 60, 5, 16, 7, 53, 3, 52, 4, 35, 1, 41, 0,  9, 2, 60, 
    0, 32, 3, 84, 5, 18, 7, 43, 2, 55, 6, 66, 4, 56, 1, 50, 8, 49, 
    6, 70, 1, 35, 7,  4, 3, 67, 2, 44, 4, 43, 5, 30, 0, 81, 8, 68, 
    1, 49, 7, 20, 0, 23, 6, 95, 2, 62, 5, 71, 8, 99, 4, 69, 3, 35, 
    0, 31, 2, 20, 5, 66, 6, 57, 1, 43, 4, 68, 3, 60, 8, 55, 7, 21, 
    5, 34, 7, 12, 2, 83, 3, 96, 6, 59, 8, 50, 4, 52, 0, 26, 1, 83, 
    8, 45, 6, 82, 0, 51, 2,  6, 7, 38, 5,  7, 3, 36, 1, 94, 4, 25
  };
  const int q0713[] = {
    9, 9, // Number of jobs and machines
    0, 12, 4, 18, 5, 69, 1, 66, 6, 15, 8, 63, 3, 71, 2, 75, 7, 15, 
    0, 53, 8, 75, 1, 49, 6, 28, 3, 82, 4, 42, 5, 15, 2, 55, 7, 93, 
    8, 50, 4, 44, 1, 46, 7, 91, 5, 43, 0,  8, 2, 40, 3, 92, 6, 10, 
    4, 65, 1, 82, 7, 41, 5, 90, 8, 28, 3, 60, 2,  8, 6, 28, 0,  9, 
    8, 57, 2, 99, 7, 72, 6, 42, 0, 45, 5, 64, 4, 39, 1, 58, 3, 28, 
    0, 96, 7,  7, 3, 12, 4, 54, 8, 39, 2, 10, 1, 86, 5, 52, 6, 63, 
    2, 45, 7, 46, 0, 38, 5, 27, 8, 25, 4,  1, 6, 50, 3, 68, 1, 58, 
    4, 12, 8, 53, 7, 64, 2, 64, 5,  2, 1, 39, 3, 82, 6, 48, 0, 30, 
    4, 87, 3, 90, 8, 53, 0, 29, 5, 29, 6, 61, 1, 70, 7, 53, 2, 78
  };
  const int q0714[] = {
    9, 9, // Number of jobs and machines
    1, 87, 6, 70, 5, 86, 2, 10, 8, 77, 0, 67, 3, 79, 4, 20, 7, 49, 
    7, 77, 0, 31, 4, 91, 3, 79, 6, 71, 1, 91, 8, 79, 2, 73, 5, 16, 
    0, 16, 6, 31, 3,  8, 5, 29, 1, 94, 7, 70, 4, 18, 8,  2, 2, 83, 
    5, 37, 7, 76, 0, 22, 3, 94, 1,  4, 6, 91, 8, 81, 4, 93, 2, 49, 
    2, 28, 1, 68, 3, 57, 6, 87, 8, 68, 5, 57, 7, 57, 0, 82, 4, 49, 
    6, 98, 2, 32, 5, 98, 7, 35, 3, 12, 1, 39, 8, 78, 4, 78, 0, 58, 
    8,  2, 4, 65, 6, 24, 7, 30, 3, 31, 2, 52, 1, 40, 0, 94, 5, 42, 
    6, 68, 3, 70, 0, 77, 1,  5, 4, 58, 8, 38, 2, 91, 5, 90, 7, 40, 
    6, 86, 3, 73, 5, 15, 1, 72, 7,  4, 8, 89, 0, 93, 4, 15, 2, 72
  };
  const int q0715[] = {
    9, 9, // Number of jobs and machines
    8, 64, 7, 20, 4, 96, 2, 24, 6, 80, 5, 41, 0, 44, 1, 21, 3, 64, 
    3, 28, 8, 17, 1,  5, 0, 89, 6, 74, 4, 63, 7, 40, 5, 92, 2, 42, 
    6, 45, 3, 75, 7, 50, 4,  2, 0, 23, 1, 87, 5, 91, 8, 60, 2, 70, 
    2, 58, 1, 22, 5, 67, 4, 29, 7, 80, 8,  5, 0, 78, 6,  7, 3, 91, 
    0, 27, 2, 11, 3,  2, 4, 99, 8, 27, 7, 98, 6, 12, 1, 56, 5, 11, 
    6, 64, 7, 14, 3, 23, 8, 65, 4, 71, 1, 79, 0, 83, 2, 98, 5, 57, 
    3, 38, 8, 66, 2, 38, 7, 64, 1, 86, 5, 57, 0, 49, 4, 11, 6, 74, 
    6, 57, 7,  4, 5,  8, 0, 37, 4, 29, 8, 87, 2, 27, 1, 44, 3, 42, 
    4, 52, 8, 33, 1, 25, 7, 64, 0, 23, 5, 13, 2, 47, 3, 15, 6,  8
  };
  const int q0716[] = {
    9, 9, // Number of jobs and machines
    2, 94, 5, 65, 0, 29, 4, 43, 8, 71, 7, 69, 3, 65, 1, 29, 6, 28, 
    8,  9, 2, 14, 3, 58, 0, 46, 5, 28, 1, 59, 4, 90, 7,  3, 6, 88, 
    2, 13, 8, 75, 0, 55, 5, 50, 1, 66, 7, 22, 3, 20, 4, 68, 6, 97, 
    1, 79, 5, 12, 6, 85, 0, 17, 3, 63, 8, 87, 7, 20, 2, 29, 4, 75, 
    7, 21, 1, 11, 6, 82, 5, 16, 0, 64, 4, 19, 2, 39, 8, 96, 3, 11, 
    5, 71, 8, 13, 1,  8, 4, 39, 2, 92, 7, 98, 0, 67, 6, 26, 3, 24, 
    5, 44, 7, 88, 1, 50, 8, 95, 2, 20, 6,  3, 4, 34, 0, 88, 3, 54, 
    2, 66, 5, 88, 1, 28, 6, 76, 7, 87, 3, 83, 4, 44, 8, 83, 0, 34, 
    0, 29, 5, 17, 4,  5, 3, 80, 2, 19, 8, 34, 7, 60, 1, 35, 6, 73
  };
  const int q0717[] = {
    9, 9, // Number of jobs and machines
    4, 88, 2, 80, 3, 13, 7, 52, 5,  9, 6,  7, 0, 73, 8, 21, 1, 17, 
    6, 53, 0, 68, 1, 35, 7, 79, 4, 49, 2, 21, 5, 27, 3,  1, 8, 83, 
    0, 93, 5, 19, 1, 89, 8, 29, 7, 53, 3, 27, 4, 46, 6, 81, 2, 99, 
    8, 85, 0, 83, 6, 93, 1, 10, 3, 95, 5, 70, 4, 88, 2, 30, 7, 18, 
    1, 28, 4, 10, 0, 39, 2, 53, 8, 31, 7, 74, 3,  3, 5, 87, 6, 98, 
    0, 86, 7, 56, 3, 38, 8, 48, 6, 23, 4, 67, 5, 33, 1, 83, 2, 82, 
    7, 13, 1, 71, 6, 70, 8,  2, 0, 86, 2, 57, 5, 65, 4,  2, 3, 35, 
    1, 44, 3, 25, 6, 54, 7, 56, 0, 39, 2, 80, 4, 14, 5, 74, 8, 46, 
    2,  9, 8, 98, 1, 96, 3, 78, 4, 91, 7,  2, 6, 77, 0, 58, 5, 57
  };
  const int q0718[] = {
    9, 9, // Number of jobs and machines
    7, 50, 4, 40, 6, 42, 1, 48, 5, 91, 3,  7, 8, 16, 0,  3, 2, 89, 
    1, 24, 4, 87, 0, 78, 6, 79, 2, 25, 5, 76, 8, 48, 3, 95, 7, 92, 
    6, 64, 4, 57, 0, 19, 8, 21, 5, 91, 7, 16, 1, 34, 3, 13, 2, 50, 
    4, 65, 2, 84, 6, 34, 8, 46, 1,  5, 5, 96, 0, 12, 3, 99, 7, 89, 
    2, 51, 8, 91, 7, 66, 5, 38, 6, 88, 4, 77, 1, 65, 0, 46, 3, 17, 
    1, 89, 4,  9, 0, 95, 6, 34, 7, 74, 5, 71, 8, 80, 3, 59, 2, 65, 
    4, 93, 2, 69, 1, 28, 7, 50, 5, 94, 3, 56, 6,  7, 8, 78, 0, 55, 
    1, 20, 4, 10, 3, 78, 5, 40, 7, 73, 8, 23, 6, 92, 0, 22, 2, 81, 
    5, 74, 0, 20, 3, 67, 1, 84, 8, 39, 4,  9, 2, 45, 6, 35, 7, 24
  };
  const int q0719[] = {
    9, 9, // Number of jobs and machines
    0, 14, 8, 49, 3, 94, 2, 78, 1, 37, 7, 30, 5, 55, 4, 42, 6,  9, 
    3, 61, 8,  9, 6, 41, 7, 87, 2, 82, 4, 57, 1, 54, 0, 58, 5, 15, 
    4, 65, 0, 54, 7, 43, 2, 81, 1, 51, 8, 95, 5, 82, 3, 49, 6, 44, 
    6, 92, 7, 19, 4, 15, 5, 38, 8,  4, 1, 34, 0,  2, 2, 54, 3, 48, 
    7, 67, 1, 10, 8, 59, 0, 77, 3, 78, 4, 54, 2, 40, 5, 21, 6, 75, 
    4, 44, 2, 29, 1, 86, 5, 52, 3,  2, 0,  2, 8,  1, 6,  9, 7, 95, 
    4, 53, 7, 43, 3, 13, 1, 72, 5, 44, 0, 38, 8, 40, 2, 50, 6,  5, 
    4,  3, 8, 20, 3, 93, 6, 65, 5, 35, 2, 27, 7, 78, 0, 38, 1, 46, 
    5, 95, 0, 26, 1, 13, 8, 54, 7, 50, 6, 33, 2, 76, 3,  9, 4, 70
  };
  const int q0720[] = {
    9, 9, // Number of jobs and machines
    7, 37, 3, 67, 2, 87, 5, 21, 0, 63, 4, 37, 6,  1, 8, 17, 1, 49, 
    0, 90, 4, 47, 8, 98, 6, 17, 3, 36, 7, 22, 2, 20, 1, 25, 5,  4, 
    1, 83, 2, 41, 6, 62, 8, 15, 4, 51, 0, 37, 5, 16, 3, 54, 7, 63, 
    1, 49, 5, 22, 4, 21, 7, 56, 0, 79, 8, 52, 3, 19, 2, 68, 6, 12, 
    5, 19, 0, 42, 6, 24, 1, 77, 3,  6, 4, 70, 2, 90, 7, 47, 8, 91, 
    2, 88, 6, 71, 5, 54, 3, 75, 0, 96, 8, 37, 4,  3, 7, 64, 1,  1, 
    0, 93, 1, 83, 5, 43, 3, 51, 4, 66, 2, 53, 8, 94, 7, 83, 6, 34, 
    0, 15, 2, 45, 6, 19, 1, 97, 7, 95, 8, 27, 3, 76, 4, 91, 5, 74, 
    5, 80, 3, 96, 0, 66, 8, 44, 6, 97, 7, 75, 2, 15, 4, 18, 1, 56
  };
  const int q0721[] = {
    9, 9, // Number of jobs and machines
    7,  5, 2, 51, 0, 95, 6, 87, 4, 19, 3, 36, 1, 58, 5, 12, 8, 44, 
    8, 49, 7, 34, 5, 18, 0, 26, 6, 65, 1,  8, 2, 81, 3, 52, 4, 50, 
    8, 86, 6, 26, 3, 68, 1, 70, 2, 66, 4, 78, 7, 24, 5, 59, 0, 12, 
    3, 13, 4, 39, 8, 12, 2, 21, 0,  5, 7, 17, 1, 15, 6, 11, 5, 97, 
    4, 64, 0, 45, 1, 39, 6, 63, 3, 94, 5, 99, 7, 53, 8, 34, 2, 51, 
    3,  9, 5, 18, 6, 89, 7,  5, 0, 96, 2, 86, 8, 66, 1, 94, 4, 80, 
    7, 62, 4, 72, 1, 57, 0, 66, 6, 62, 8, 72, 3, 90, 2,  7, 5, 69, 
    2, 87, 6, 80, 4, 31, 1, 72, 3, 60, 8,  4, 5, 75, 7,  3, 0, 16, 
    8, 76, 1, 53, 5, 43, 3, 58, 7, 83, 6, 92, 2, 99, 4, 10, 0, 39
  };
  const int q0722[] = {
    9, 9, // Number of jobs and machines
    4, 63, 7, 94, 6, 17, 5, 37, 2,  8, 0, 52, 3,  1, 8, 16, 1, 22, 
    2, 40, 3, 12, 5, 11, 7, 46, 6, 93, 4, 80, 1, 88, 8, 87, 0, 46, 
    6, 52, 5, 35, 8, 23, 2, 22, 3,  7, 4, 66, 7, 71, 1, 96, 0, 41, 
    7, 26, 0, 19, 8, 66, 6, 39, 2, 73, 4, 84, 1, 38, 3, 58, 5, 69, 
    7, 27, 1, 53, 3, 88, 4, 73, 2, 12, 0, 73, 5, 84, 8, 61, 6, 15, 
    3, 92, 8, 79, 5, 95, 4, 25, 7, 40, 2, 45, 1,  6, 6, 64, 0, 21, 
    4, 12, 3, 58, 8, 93, 1, 71, 7, 69, 6,  9, 5, 78, 0, 57, 2, 41, 
    8, 11, 3, 16, 0, 39, 6, 39, 4, 50, 1,  8, 7, 86, 2,  3, 5, 71, 
    5,  9, 8, 76, 6, 92, 1, 36, 7, 87, 4, 93, 3, 56, 2, 59, 0, 95
  };
  const int q0723[] = {
    9, 9, // Number of jobs and machines
    7, 15, 5, 32, 6,  6, 0, 78, 8, 80, 1, 23, 4, 18, 3, 18, 2, 81, 
    8, 77, 4, 73, 0, 10, 6, 23, 1, 94, 3, 60, 7, 95, 5, 13, 2,  7, 
    1, 47, 0,  9, 5, 17, 4, 42, 3, 86, 6, 99, 7, 82, 8, 75, 2, 72, 
    6, 73, 5, 84, 2, 67, 1, 16, 3, 73, 0, 14, 4, 12, 8, 23, 7, 65, 
    1, 44, 3, 53, 6, 30, 7, 38, 2, 69, 5, 38, 4, 70, 8, 20, 0, 33, 
    0, 11, 5, 50, 3, 83, 6, 34, 8, 44, 2, 71, 1, 22, 4, 32, 7, 63, 
    5, 80, 8, 27, 7, 87, 2,  5, 6, 47, 3,  2, 4, 36, 0, 46, 1, 58, 
    3, 23, 6,  7, 7, 87, 5, 80, 2, 34, 4, 28, 8,  8, 1, 69, 0,  2, 
    5, 32, 4, 35, 1, 23, 6, 45, 0, 40, 2, 14, 7, 33, 8, 47, 3, 87
  };
  const int q0724[] = {
    9, 9, // Number of jobs and machines
    2, 23, 5,  4, 4, 34, 6, 65, 8, 73, 0,  1, 1, 38, 3, 41, 7, 80, 
    7,  7, 5, 20, 1, 25, 6, 59, 4, 92, 8, 87, 0,  6, 2, 29, 3, 90, 
    7, 71, 5, 74, 1, 89, 4, 51, 3, 20, 6, 63, 0, 38, 2, 48, 8, 70, 
    1, 25, 8, 77, 3, 45, 6, 66, 7, 25, 5, 28, 2, 80, 4, 63, 0, 89, 
    6, 52, 5, 83, 1, 43, 8, 97, 2, 32, 0, 18, 4, 79, 7, 27, 3, 16, 
    3, 32, 2, 97, 6,  9, 4, 89, 8,  8, 5, 40, 1, 88, 7, 83, 0, 76, 
    4, 52, 5, 21, 3, 11, 1, 22, 0, 66, 7, 56, 6, 36, 2, 31, 8, 83, 
    1, 43, 8, 98, 4, 33, 0, 61, 7, 94, 3, 98, 6, 47, 2, 41, 5, 39, 
    2, 99, 8, 17, 0, 58, 4, 79, 6, 55, 3, 87, 5, 45, 1, 61, 7, 79
  };
  const int q0725[] = {
    9, 9, // Number of jobs and machines
    3, 37, 6, 40, 7, 13, 5, 36, 0, 59, 4, 12, 1, 22, 8, 18, 2, 56, 
    4, 32, 5, 28, 6, 64, 3, 30, 7, 81, 8, 89, 0, 79, 1, 79, 2, 62, 
    0, 28, 3,  8, 4, 79, 6, 96, 2, 92, 7, 83, 1, 91, 5, 65, 8, 68, 
    4, 40, 7, 52, 8, 76, 5,  1, 3, 96, 1, 46, 2, 44, 6, 37, 0, 87, 
    8,  4, 3,  5, 1, 56, 4, 94, 7, 36, 2, 61, 6, 54, 0, 22, 5, 88, 
    5, 14, 7, 81, 3, 21, 4, 24, 0, 70, 2, 62, 6, 12, 1, 58, 8,  2, 
    4,  2, 0, 17, 2, 93, 7, 64, 8, 92, 6, 16, 1, 78, 3, 34, 5, 71, 
    7,  5, 8, 15, 1, 49, 4, 14, 3, 67, 5, 59, 6, 34, 2, 85, 0, 70, 
    8, 58, 7, 69, 4, 13, 5, 39, 6, 86, 0, 74, 3,  3, 1, 99, 2, 86
  };
  const int q0726[] = {
    9, 9, // Number of jobs and machines
    1, 60, 0, 90, 5, 56, 3, 42, 7, 25, 6, 83, 2, 60, 8, 71, 4, 98, 
    0, 32, 4, 28, 3,  7, 1, 95, 7, 35, 5, 42, 8, 96, 6, 24, 2, 49, 
    6, 25, 2, 87, 8, 61, 4,  3, 1,  7, 0, 42, 3, 99, 7, 24, 5,  5, 
    7,  4, 0, 65, 6, 73, 8, 49, 2, 45, 1, 84, 3, 95, 4, 19, 5, 50, 
    2, 25, 5, 99, 8, 76, 7, 13, 6, 74, 0, 28, 1, 80, 4,  2, 3, 15, 
    4,  4, 7, 43, 6, 51, 0, 31, 5, 95, 2, 18, 3, 58, 1, 47, 8, 49, 
    7, 94, 8, 21, 5, 22, 4,  6, 0, 55, 6, 70, 1, 27, 3, 81, 2, 69, 
    6,  2, 1, 51, 3, 92, 5,  4, 4, 42, 8, 79, 2, 24, 0, 58, 7, 47, 
    4, 11, 0, 66, 6, 64, 8, 27, 7, 54, 3,  9, 1, 54, 5, 65, 2, 70
  };
  const int q0727[] = {
    9, 9, // Number of jobs and machines
    5, 43, 6, 56, 1, 17, 0, 68, 7, 60, 4, 80, 2, 51, 3, 85, 8, 18, 
    1, 89, 5, 95, 8, 12, 6, 78, 2, 99, 7, 91, 4, 75, 3,  4, 0, 41, 
    0, 71, 3, 26, 7, 64, 5, 39, 4, 19, 1, 30, 8,  7, 6, 64, 2, 38, 
    1, 95, 0, 36, 8, 86, 2, 54, 5, 89, 6, 53, 7, 62, 3, 55, 4, 68, 
    3, 71, 1, 13, 0, 10, 8, 63, 6, 78, 2, 34, 7, 93, 5, 85, 4, 66, 
    8, 72, 4, 51, 3, 11, 6, 13, 2, 80, 7,  9, 0, 11, 5, 76, 1, 26, 
    8, 56, 2, 68, 0, 54, 1, 42, 6, 63, 5, 19, 7,  6, 3, 24, 4, 93, 
    1, 23, 7, 25, 8, 69, 2, 19, 4, 32, 5, 46, 6, 89, 3, 97, 0, 49, 
    8, 99, 0, 95, 1, 16, 5, 41, 3, 47, 4,  5, 7, 61, 2, 78, 6,  4
  };
  const int q0728[] = {
    9, 9, // Number of jobs and machines
    4, 50, 2, 65, 7, 93, 5, 58, 1, 89, 3, 98, 8, 25, 0,  6, 6, 23, 
    8, 28, 2, 90, 4, 96, 1, 25, 0, 58, 3, 53, 5,  6, 6, 67, 7, 84, 
    5, 73, 7, 86, 8, 62, 4, 30, 3, 97, 2,  1, 1, 78, 0,  2, 6,  4, 
    0,  8, 2, 69, 8, 20, 4, 48, 7, 28, 5, 18, 3, 50, 1, 38, 6,  1, 
    3, 39, 5, 92, 4, 84, 7, 40, 8, 68, 2, 40, 6, 75, 1, 81, 0, 82, 
    3, 45, 8, 52, 0, 84, 6, 61, 7, 75, 1, 14, 4, 30, 5, 54, 2, 10, 
    4, 96, 7, 30, 5, 15, 8,  2, 6, 91, 0, 35, 1, 60, 2, 93, 3, 22, 
    7, 92, 8, 45, 4, 92, 1, 81, 2, 25, 0, 63, 5, 33, 3, 32, 6, 32, 
    1, 24, 5,  5, 4, 13, 8, 73, 7, 76, 3,  3, 0, 81, 6, 33, 2, 22
  };
  const int q0729[] = {
    9, 9, // Number of jobs and machines
    0, 94, 8, 74, 6, 90, 7, 76, 5, 46, 1, 91, 2, 72, 4, 15, 3, 63, 
    8, 17, 7, 28, 1,  3, 4, 37, 0, 80, 5, 63, 2, 49, 6, 21, 3, 62, 
    5, 21, 4, 18, 2, 99, 3, 53, 0, 14, 1, 77, 7, 61, 8, 11, 6, 97, 
    0, 34, 6, 46, 2, 80, 1,  8, 5, 61, 3, 62, 4, 76, 7, 75, 8, 48, 
    4, 98, 6,  6, 2, 49, 1, 64, 3, 52, 0,  2, 5, 33, 7, 93, 8, 10, 
    8, 12, 2,  2, 6, 58, 5, 49, 3, 63, 1, 37, 0, 13, 7, 79, 4, 82, 
    5, 38, 2, 92, 8, 40, 3, 87, 0,  8, 1, 14, 4, 35, 7, 94, 6, 87, 
    7, 85, 4, 19, 6,  5, 5,  6, 8, 55, 3,  4, 2, 57, 1, 20, 0, 23, 
    7, 56, 2, 60, 3,  5, 0, 10, 6, 36, 1, 32, 5, 17, 4, 25, 8, 49
  };
  const int q0730[] = {
    9, 9, // Number of jobs and machines
    1, 75, 8, 52, 5, 10, 2, 97, 0, 28, 7, 67, 4, 44, 3, 36, 6, 36, 
    0, 73, 8, 27, 6, 92, 4, 77, 1, 49, 5, 83, 3, 36, 7, 27, 2, 40, 
    0, 34, 6, 89, 3, 80, 8, 17, 4, 82, 5, 15, 2, 96, 7, 41, 1, 46, 
    1, 89, 2, 36, 0, 94, 4, 62, 6, 31, 8, 17, 3, 44, 7, 98, 5, 48, 
    0, 24, 2, 84, 5, 11, 3, 68, 4, 69, 6, 24, 7, 72, 1, 72, 8, 63, 
    7, 87, 8, 97, 4, 83, 2, 97, 6, 27, 3, 88, 5, 71, 0,  4, 1, 87, 
    1, 74, 7, 48, 8, 57, 5, 16, 4, 31, 2, 52, 0, 92, 3, 50, 6, 11, 
    7, 66, 3, 94, 2, 95, 8, 99, 1, 86, 6, 28, 4, 92, 0, 61, 5, 67, 
    2,  6, 6, 57, 0, 26, 3, 72, 7, 50, 4, 87, 8, 12, 1, 97, 5,  6
  };
  const int q0731[] = {
    9, 9, // Number of jobs and machines
    1, 74, 5, 33, 2,  2, 4, 47, 0,  8, 6, 21, 7, 56, 8, 28, 3, 19, 
    0, 69, 7, 88, 3, 88, 1, 23, 6, 29, 5, 99, 8,  2, 4, 56, 2, 79, 
    3, 10, 6, 59, 7, 62, 8, 44, 2,  7, 4, 56, 0, 42, 1, 56, 5, 46, 
    5, 59, 7, 16, 1, 97, 6, 66, 8, 12, 3, 59, 4, 76, 0, 86, 2, 46, 
    8, 41, 1, 40, 4, 58, 6, 46, 0, 73, 2, 79, 5, 97, 7, 29, 3, 54, 
    7, 67, 5, 20, 6, 71, 2, 67, 3, 58, 8, 94, 1, 70, 0, 64, 4, 83, 
    1, 59, 2, 15, 3, 47, 0, 73, 6, 94, 8,  3, 5, 79, 4, 53, 7, 46, 
    3,  3, 6, 37, 5, 43, 1, 32, 7, 61, 8, 20, 2, 46, 0,  7, 4, 21, 
    5, 33, 1, 17, 7, 76, 6, 86, 2, 16, 8, 65, 0, 40, 4, 29, 3, 26
  };
  const int q0732[] = {
    9, 9, // Number of jobs and machines
    5, 79, 6, 63, 4, 36, 2, 46, 8, 94, 0, 33, 7, 35, 1, 23, 3, 14, 
    4,  5, 8, 45, 0, 98, 3, 57, 2, 76, 6, 27, 7, 11, 1, 11, 5, 93, 
    6, 13, 7, 16, 4, 86, 1, 93, 2, 32, 8, 86, 5, 80, 3, 45, 0, 47, 
    8, 73, 3, 98, 6, 41, 1, 78, 5, 23, 7, 65, 0, 19, 2, 47, 4,  1, 
    7, 90, 1, 55, 4, 61, 6, 67, 5, 32, 3, 83, 8, 55, 0, 97, 2, 73, 
    5, 99, 8, 48, 1, 37, 4, 87, 6, 53, 7, 91, 0, 24, 3, 93, 2, 26, 
    4, 44, 8, 28, 1, 41, 0, 53, 5, 60, 7, 54, 2, 52, 3, 30, 6, 99, 
    0, 37, 7, 49, 6, 47, 5, 42, 3, 33, 1, 15, 4, 71, 8, 35, 2, 27, 
    1, 51, 6,  6, 4, 81, 3, 45, 0, 81, 7,  9, 8, 25, 2, 10, 5, 89
  };
  const int q0733[] = {
    9, 9, // Number of jobs and machines
    7, 46, 4,  9, 8, 39, 1, 26, 5, 18, 6, 67, 2, 26, 0,  8, 3, 20, 
    2, 37, 3, 62, 7, 14, 6, 77, 8, 27, 0, 12, 1,  1, 4, 39, 5, 74, 
    5, 52, 4, 74, 1, 51, 8, 20, 2, 49, 0, 56, 3, 56, 7, 59, 6, 34, 
    1, 28, 5, 54, 7, 52, 2, 24, 6, 21, 4, 73, 8, 97, 0, 21, 3, 90, 
    7, 12, 5, 74, 0, 71, 8, 84, 4, 77, 1, 18, 2, 66, 6, 91, 3, 58, 
    3, 53, 8,  9, 7, 79, 5, 39, 0, 87, 6, 27, 4, 95, 2, 82, 1, 81, 
    4, 54, 1, 58, 2, 54, 0, 79, 7, 73, 3, 84, 8, 50, 6, 86, 5, 54, 
    5, 27, 1, 47, 3, 60, 2, 91, 8, 83, 6, 78, 4, 70, 0, 41, 7, 59, 
    4, 82, 8,  2, 1, 74, 0, 88, 7, 34, 3, 10, 6, 50, 5, 88, 2, 37
  };
  const int q0734[] = {
    9, 9, // Number of jobs and machines
    7, 57, 6,  1, 1, 11, 3, 80, 8, 15, 4, 92, 5, 95, 0,  4, 2, 12, 
    3, 96, 4, 95, 6, 52, 5, 90, 0, 96, 2, 14, 1, 90, 7, 74, 8,  2, 
    4,  7, 0,  9, 1, 57, 5, 96, 3, 71, 6, 14, 8, 67, 7, 45, 2, 91, 
    6, 23, 8, 37, 3, 22, 5, 83, 4, 60, 7, 66, 0, 70, 2, 81, 1, 18, 
    0, 72, 1, 64, 3, 19, 5, 57, 6, 59, 2, 12, 4, 99, 8, 49, 7, 88, 
    1,  4, 4, 23, 2,  9, 7, 57, 6, 59, 5, 11, 0, 18, 8, 50, 3, 66, 
    8, 23, 3, 97, 7, 62, 5, 50, 2, 70, 4, 15, 1, 94, 6, 18, 0,  5, 
    5,  6, 6, 46, 4, 43, 0, 12, 3,  3, 2, 66, 8, 79, 7, 24, 1, 59, 
    7, 16, 1, 85, 6, 66, 5, 18, 8, 33, 0, 86, 3, 86, 4, 83, 2, 32
  };
  const int q0735[] = {
    9, 9, // Number of jobs and machines
    6, 66, 1, 83, 0, 78, 8, 29, 7, 61, 3, 88, 4, 83, 5, 69, 2,  2, 
    2, 55, 3,  2, 6,  7, 5, 58, 1, 60, 8, 92, 0, 44, 7, 42, 4, 52, 
    7,  4, 8, 76, 2, 80, 6, 73, 3, 52, 0, 44, 4, 54, 1, 39, 5, 52, 
    3, 40, 2, 24, 0, 48, 6, 38, 5, 87, 1, 32, 7,  8, 8,  8, 4, 93, 
    5, 97, 4, 91, 3, 28, 7, 72, 8, 29, 6, 72, 2, 75, 1, 57, 0, 77, 
    0, 40, 3, 23, 4, 71, 2, 64, 8, 66, 6, 53, 5, 71, 1,  3, 7, 39, 
    5, 98, 1, 51, 7, 46, 0, 30, 3, 92, 6, 72, 4, 15, 8, 45, 2, 20, 
    8, 77, 4, 99, 0, 12, 1, 26, 2, 24, 5, 21, 7, 11, 3, 21, 6, 53, 
    1, 98, 4, 51, 8, 46, 2, 56, 5,  7, 3, 85, 7, 27, 6, 84, 0, 85
  };
  const int q0736[] = {
    9, 9, // Number of jobs and machines
    8, 37, 6, 53, 5, 70, 7, 27, 0, 90, 1,  7, 2, 59, 4, 67, 3, 63, 
    2, 63, 6, 81, 3, 68, 0, 88, 5, 55, 8, 63, 7, 58, 4, 23, 1, 22, 
    4, 81, 2, 92, 8, 25, 3,  5, 1, 92, 7,  1, 5, 87, 6, 35, 0, 77, 
    6, 33, 7, 63, 5, 98, 8, 26, 3, 40, 0, 15, 2, 99, 1, 67, 4, 10, 
    1, 11, 4, 93, 7, 37, 0, 27, 2, 67, 6,  7, 8, 28, 5, 50, 3, 37, 
    6, 79, 7, 25, 2, 44, 3, 85, 8, 11, 1, 55, 4, 28, 0, 58, 5, 15, 
    5, 77, 2, 11, 4, 83, 8, 55, 3,  8, 6, 14, 0, 40, 7,  3, 1, 18, 
    1,  8, 3, 89, 8, 71, 7, 25, 0, 42, 6, 99, 4, 34, 5, 49, 2, 74, 
    8, 31, 4, 16, 3, 78, 1, 82, 2,  8, 5, 36, 7, 27, 6, 83, 0, 57
  };
  const int q0737[] = {
    9, 9, // Number of jobs and machines
    3, 24, 1, 25, 7, 34, 8, 11, 0, 21, 2, 17, 4, 72, 5, 99, 6, 11, 
    7, 50, 1, 31, 0, 95, 3, 64, 6, 74, 2, 34, 4, 28, 5, 44, 8, 44, 
    2, 68, 8, 57, 5,  5, 4, 82, 6, 74, 3, 17, 1,  1, 7, 96, 0, 86, 
    1, 67, 3, 10, 5, 19, 6, 50, 8, 34, 0, 67, 7, 63, 2, 55, 4, 57, 
    1, 32, 0, 77, 2, 14, 5,  1, 7, 16, 8, 17, 4, 81, 6, 18, 3, 80, 
    0, 34, 4, 72, 2, 15, 1,  3, 3, 44, 8, 44, 5, 68, 7, 42, 6, 55, 
    7, 95, 0, 78, 6, 62, 5, 35, 8, 75, 4, 92, 2,  4, 1,  1, 3, 84, 
    1, 90, 2, 51, 3, 47, 5, 63, 4, 29, 0, 83, 6, 73, 7, 56, 8, 83, 
    3,  9, 7, 11, 0, 92, 4, 38, 5, 67, 8, 97, 1, 12, 2, 71, 6, 47
  };
  const int q0738[] = {
    9, 9, // Number of jobs and machines
    7, 85, 0, 70, 1, 68, 2, 33, 3,  9, 8, 98, 6, 70, 4, 54, 5, 11, 
    2, 73, 8, 86, 1, 71, 3, 37, 6, 74, 4, 87, 5, 94, 7, 49, 0, 38, 
    2,  7, 8, 67, 3,  1, 1, 37, 0, 78, 4, 58, 6, 22, 7, 36, 5, 40, 
    4, 48, 3, 84, 2, 23, 1, 67, 5, 32, 8, 95, 6, 55, 7, 31, 0, 23, 
    7, 91, 1, 41, 4,  8, 8, 93, 5, 19, 2, 79, 3, 52, 0, 43, 6, 98, 
    1, 78, 7, 66, 5, 12, 6, 24, 3, 25, 0, 14, 2, 63, 8, 67, 4,  3, 
    8, 90, 3, 29, 5, 79, 7, 98, 6,  9, 0, 43, 4, 35, 2,  7, 1, 62, 
    7, 18, 4, 37, 1, 46, 2, 94, 6, 10, 3, 15, 0, 98, 8,  6, 5, 88, 
    2, 80, 8, 93, 6, 40, 3, 63, 4, 84, 5,  1, 0, 47, 7,  3, 1, 50
  };
  const int q0739[] = {
    9, 9, // Number of jobs and machines
    5, 84, 3, 93, 0, 15, 6, 20, 2, 26, 4, 42, 7,  8, 8, 43, 1, 32, 
    5, 74, 0, 45, 4, 33, 2, 49, 6, 76, 1,  2, 7, 25, 3, 37, 8, 64, 
    6,  6, 2, 93, 3,  1, 8, 52, 5, 72, 4, 14, 1, 42, 7, 76, 0, 96, 
    5, 33, 3, 38, 8, 12, 2, 66, 6, 59, 0, 83, 7, 28, 1, 10, 4, 22, 
    4, 62, 5, 61, 6, 15, 8, 13, 2, 49, 7, 28, 0, 70, 3, 62, 1, 12, 
    8, 38, 1, 91, 6, 18, 3, 65, 2, 92, 4, 27, 7, 52, 5, 94, 0, 64, 
    2,  8, 0, 43, 5, 50, 8,  7, 6, 72, 3, 47, 7, 92, 4, 74, 1, 79, 
    1, 90, 8, 34, 4, 38, 2, 25, 7,  8, 3, 39, 6,  7, 0, 60, 5, 56, 
    6, 57, 2,  7, 4, 75, 1, 78, 7, 97, 0, 48, 8, 55, 3, 76, 5, 65
  };
  const int q0740[] = {
    9, 9, // Number of jobs and machines
    0, 59, 2, 48, 4, 26, 5, 96, 8, 52, 6, 21, 3, 19, 1, 54, 7, 91, 
    7, 32, 1, 16, 2, 43, 0, 76, 8, 45, 3, 10, 6, 32, 4,  9, 5, 16, 
    6, 46, 0, 52, 2,  4, 5, 53, 7, 13, 1, 85, 8, 57, 3, 60, 4, 83, 
    7, 32, 6, 33, 1, 16, 4, 21, 8, 34, 3, 49, 2, 10, 5, 67, 0, 14, 
    3, 73, 4,  8, 7, 28, 0, 54, 5,  1, 8, 38, 2, 89, 1, 81, 6, 57, 
    6, 63, 4,  7, 3, 78, 1, 62, 8, 19, 5, 72, 0, 23, 7, 72, 2, 24, 
    6, 67, 5, 37, 0, 92, 8, 55, 1,  2, 2, 38, 4, 65, 7,  3, 3, 93, 
    2, 11, 3, 65, 4, 20, 6,  5, 7, 46, 0,  5, 5, 14, 8, 71, 1, 51, 
    8, 75, 4, 75, 5, 80, 7, 71, 1, 72, 3,  8, 2, 97, 6, 25, 0, 37
  };
  const int q0741[] = {
    9, 9, // Number of jobs and machines
    5, 45, 2, 77, 4, 93, 0, 89, 8, 86, 3, 85, 1,  2, 6, 74, 7, 59, 
    3, 21, 6, 96, 1, 42, 4, 46, 5, 71, 7, 25, 2, 97, 8, 17, 0, 67, 
    4, 82, 0, 15, 8, 66, 7,  1, 5, 83, 1, 15, 6, 79, 2, 98, 3, 70, 
    0, 94, 8, 59, 4, 56, 6, 92, 7,  2, 1, 15, 3, 26, 2, 92, 5, 35, 
    2, 93, 3, 74, 6, 40, 8,  6, 0, 99, 4, 73, 7, 17, 5, 55, 1,  4, 
    3, 17, 7, 21, 6,  9, 1,  4, 4, 32, 2, 27, 8, 70, 5, 83, 0, 74, 
    4,  2, 7, 26, 6, 89, 3, 69, 2, 12, 5, 67, 8, 10, 0, 36, 1,  1, 
    7, 86, 3, 81, 0, 84, 4, 10, 2, 63, 6, 53, 8, 16, 5, 20, 1, 83, 
    5, 64, 0,  2, 7, 95, 2, 90, 8, 56, 4, 87, 1, 25, 6, 59, 3, 73
  };
  const int q0742[] = {
    9, 9, // Number of jobs and machines
    2, 51, 0, 18, 5, 54, 3, 54, 4, 65, 6, 92, 1, 22, 8, 85, 7, 88, 
    0, 86, 4, 70, 3, 28, 7,  3, 5,  4, 2, 57, 8, 56, 6, 67, 1, 24, 
    5, 70, 8,  2, 4, 26, 0, 73, 1, 70, 6,  9, 2, 59, 7, 14, 3, 32, 
    7,  4, 2, 78, 8, 60, 4, 80, 3, 31, 0, 96, 5, 11, 1, 48, 6, 93, 
    4, 84, 3,  3, 7, 75, 0, 25, 6, 85, 5, 94, 2, 17, 8, 47, 1, 25, 
    3, 11, 1, 29, 4, 11, 6, 89, 0, 88, 5,  9, 8, 82, 7, 49, 2, 90, 
    5,  4, 8, 63, 3, 83, 0, 12, 7, 41, 1, 51, 6, 66, 2, 91, 4, 47, 
    5, 24, 7, 95, 1, 46, 6, 35, 8, 36, 2, 37, 4, 95, 0, 17, 3, 97, 
    3, 59, 7, 92, 6, 42, 5,  1, 2, 35, 0, 96, 4,  2, 8,  4, 1, 96
  };
  const int q0743[] = {
    9, 9, // Number of jobs and machines
    6, 21, 0, 49, 1, 12, 5, 23, 3, 58, 8, 28, 2, 14, 7, 38, 4, 82, 
    7, 27, 3, 28, 4,  8, 6,  1, 0, 38, 1, 28, 2, 39, 5, 31, 8, 30, 
    2, 35, 8, 24, 5, 49, 0, 84, 6, 25, 1, 38, 3, 55, 7, 11, 4, 69, 
    2, 22, 7, 69, 5, 48, 3, 22, 6, 27, 0,  6, 1,  7, 8, 16, 4, 22, 
    6, 41, 1, 17, 2,  1, 3, 82, 0, 47, 5, 50, 7,  7, 8, 33, 4, 76, 
    8, 81, 7,  7, 4, 49, 3, 13, 6, 14, 2, 79, 1, 93, 5,  8, 0, 84, 
    1, 86, 0, 21, 3, 93, 7, 40, 8, 43, 5, 51, 6, 54, 2, 51, 4, 84, 
    3, 73, 8, 13, 6, 72, 0, 88, 1, 13, 4, 45, 2, 23, 5,  1, 7, 74, 
    6,  8, 3, 19, 1,  1, 5, 19, 4,  9, 8, 89, 7, 33, 2, 33, 0, 56
  };
  const int q0744[] = {
    9, 9, // Number of jobs and machines
    5, 41, 3, 29, 0, 13, 1, 96, 8, 11, 4, 24, 6, 85, 2, 61, 7, 10, 
    3, 92, 8, 76, 6, 65, 2, 78, 4, 16, 0, 66, 7, 80, 1, 39, 5, 99, 
    4, 76, 1, 60, 6, 67, 5, 63, 0, 69, 3, 14, 8, 57, 7, 94, 2, 47, 
    7, 17, 2, 48, 5,  3, 6,  4, 0, 48, 4, 52, 8, 43, 3, 19, 1, 93, 
    3,  6, 1, 85, 7, 94, 4, 50, 2, 39, 0, 59, 8, 68, 5, 71, 6, 70, 
    3, 28, 4,  1, 1, 49, 2, 74, 5, 93, 8, 26, 0,  8, 7, 64, 6, 29, 
    8, 93, 4, 11, 7, 37, 6, 95, 3, 30, 0, 11, 5, 51, 2, 28, 1, 45, 
    2, 56, 0, 59, 7, 71, 8, 75, 3, 56, 1,  9, 5, 41, 4, 39, 6, 96, 
    5, 92, 1, 26, 8, 70, 4, 23, 6, 13, 7, 11, 0, 87, 2, 38, 3,  9
  };
  const int q0745[] = {
    9, 9, // Number of jobs and machines
    1, 45, 7,  3, 4,  6, 0, 74, 6, 35, 3, 17, 5, 46, 2,  1, 8, 72, 
    0, 34, 6, 41, 7, 98, 2, 78, 1, 76, 4, 48, 5, 78, 8, 19, 3, 95, 
    5, 47, 0, 10, 8, 21, 2, 59, 3, 52, 6, 53, 1, 71, 4,  8, 7, 97, 
    3, 16, 1, 25, 5, 98, 8, 23, 2, 49, 0, 90, 4, 81, 7, 48, 6, 90, 
    4, 94, 8, 22, 2, 24, 1, 13, 5, 91, 3, 45, 6, 40, 7, 46, 0, 72, 
    6, 60, 1,  6, 3, 38, 5, 54, 2, 71, 0, 65, 8, 35, 7, 40, 4,  8, 
    7, 51, 0, 27, 2, 55, 5, 49, 1, 62, 6, 82, 4, 36, 8, 41, 3, 11, 
    5, 14, 3, 19, 2, 94, 1, 79, 0, 73, 6, 91, 7, 46, 4, 73, 8, 92, 
    6, 23, 4, 29, 8, 72, 3, 58, 5, 39, 2, 82, 0,  5, 7, 61, 1, 95
  };
  const int q0746[] = {
    9, 9, // Number of jobs and machines
    5, 44, 1, 79, 0, 66, 7, 51, 4, 84, 8, 17, 6, 27, 3, 87, 2, 73, 
    3, 71, 8, 75, 4, 13, 2, 36, 1, 62, 5, 79, 0, 12, 7, 46, 6, 22, 
    4, 33, 1, 12, 0,  3, 6, 48, 7, 94, 3, 61, 8, 30, 5, 69, 2, 83, 
    4, 96, 6, 29, 1, 88, 2, 99, 0, 55, 5, 86, 7, 38, 3, 40, 8, 26, 
    4, 46, 8, 55, 0,  9, 5, 32, 6, 12, 1,  1, 2,  8, 7, 67, 3, 40, 
    6, 59, 0, 79, 2, 16, 4, 46, 5, 99, 7, 57, 8, 40, 3, 56, 1, 20, 
    5, 92, 2, 36, 4, 21, 8, 57, 1, 24, 7,  8, 6, 86, 3, 59, 0, 85, 
    1, 90, 7, 63, 2, 23, 3, 31, 5, 74, 4, 39, 8, 48, 6, 87, 0, 44, 
    1, 78, 5, 29, 6, 38, 2, 80, 3, 36, 7, 84, 0, 40, 4, 71, 8,  3
  };
  const int q0747[] = {
    9, 9, // Number of jobs and machines
    5, 41, 6, 60, 1, 69, 8, 90, 4, 89, 7, 31, 0, 80, 3, 25, 2, 24, 
    3,  7, 1, 94, 8, 19, 0, 71, 6, 11, 7, 42, 2, 77, 5, 48, 4, 76, 
    6, 44, 1, 90, 8, 87, 2, 97, 3, 85, 7, 19, 5, 89, 0, 44, 4, 91, 
    3,  8, 6, 22, 7, 21, 4, 55, 0, 72, 2, 78, 8, 47, 5, 76, 1, 11, 
    0, 23, 7, 66, 4, 85, 6, 81, 3, 21, 8, 39, 1,  6, 2, 90, 5, 97, 
    7, 23, 0, 66, 1, 54, 6,  8, 3, 26, 8, 22, 4, 78, 5, 26, 2, 12, 
    2, 10, 8, 90, 7, 52, 3, 37, 4, 16, 1, 37, 0, 18, 5, 59, 6, 78, 
    0, 51, 5, 31, 6, 63, 8, 56, 1, 99, 3, 59, 7, 78, 2, 22, 4, 97, 
    4, 58, 7, 51, 6, 81, 0, 45, 8, 62, 3, 51, 2,  6, 1, 89, 5,  3
  };
  const int q0748[] = {
    9, 9, // Number of jobs and machines
    8,  1, 3, 71, 0,  2, 6, 36, 5, 73, 4, 97, 1, 94, 7, 15, 2, 31, 
    5, 47, 4, 98, 0, 83, 1,  7, 3, 27, 6, 38, 8, 52, 2, 80, 7,  5, 
    6, 98, 1, 15, 4, 95, 3, 57, 2, 33, 0, 65, 8, 62, 7, 97, 5, 85, 
    0,  9, 3, 56, 6, 91, 2, 37, 1, 65, 5, 48, 7, 76, 8, 23, 4, 80, 
    7, 41, 2, 34, 1, 53, 8, 29, 4,  8, 0, 90, 3, 47, 5, 77, 6, 54, 
    8, 61, 7, 13, 1, 37, 4, 12, 3, 98, 0, 59, 5, 89, 2, 59, 6, 56, 
    0, 68, 3, 92, 1, 45, 4, 96, 2, 96, 5, 16, 8, 11, 7, 28, 6, 84, 
    2, 45, 5, 94, 7, 73, 0, 50, 1, 54, 8, 71, 3, 19, 4, 14, 6, 34, 
    7, 15, 4, 71, 8,  3, 3, 72, 2,  7, 1,  7, 6, 41, 5, 77, 0, 14
  };
  const int q0749[] = {
    9, 9, // Number of jobs and machines
    4, 24, 0, 28, 5,  2, 8, 45, 3, 67, 2, 43, 6, 14, 1, 86, 7, 15, 
    0, 63, 3, 11, 7, 22, 1, 75, 2, 39, 6, 50, 5,  3, 4, 74, 8, 64, 
    0, 81, 6, 21, 8, 97, 3, 34, 7, 56, 2, 50, 5,  4, 4, 59, 1, 82, 
    1, 44, 8, 63, 4, 38, 5, 68, 2, 40, 6, 45, 7, 72, 3, 36, 0, 83, 
    3, 67, 6, 36, 7, 57, 5, 59, 8, 85, 0, 35, 1, 25, 4, 58, 2, 87, 
    7, 47, 8, 77, 5, 64, 6, 88, 3, 52, 0, 12, 2, 29, 4, 29, 1, 45, 
    2, 71, 7,  2, 6, 67, 5, 21, 0, 48, 1, 18, 3, 33, 8, 88, 4, 89, 
    0,  5, 1, 34, 6, 28, 8,  2, 2, 75, 5, 48, 4, 84, 7, 61, 3, 83, 
    2, 90, 5, 11, 1, 55, 4, 61, 7,  3, 0, 57, 8, 78, 6, 71, 3,  3
  };
  const int q0750[] = {
    9, 9, // Number of jobs and machines
    4, 52, 3, 59, 1, 80, 5,  5, 7, 56, 0, 47, 8, 30, 6, 10, 2, 62, 
    5, 18, 7, 96, 3,  2, 6, 54, 1, 77, 4, 91, 2,  7, 8, 24, 0, 75, 
    2, 70, 1, 82, 0, 94, 5, 90, 7, 34, 3, 14, 6, 37, 8, 17, 4, 92, 
    8,  9, 2,  3, 5, 75, 6, 64, 3, 77, 0, 69, 7, 87, 1, 50, 4, 95, 
    0,  1, 7, 45, 4, 22, 1, 51, 6, 19, 8, 49, 2, 53, 5, 62, 3, 43, 
    6, 59, 2, 94, 8, 74, 5, 95, 0, 72, 7, 27, 3, 87, 1, 91, 4, 86, 
    8, 58, 7, 21, 5, 41, 6, 25, 4, 16, 2, 39, 3, 21, 0, 66, 1, 74, 
    3,  3, 2, 43, 1, 58, 8, 65, 6, 23, 5, 60, 7, 42, 4, 64, 0, 28, 
    3,  9, 4, 54, 7, 44, 5, 37, 8, 37, 2, 36, 1, 21, 0, 65, 6, 33
  };
  const int q0751[] = {
    9, 9, // Number of jobs and machines
    5,  6, 0, 67, 6, 65, 7, 66, 1, 42, 8, 85, 2, 11, 3, 57, 4, 94, 
    1,  1, 2, 54, 0, 33, 7, 46, 3, 42, 5, 94, 4,  5, 8, 49, 6, 98, 
    3, 26, 7,  9, 1, 44, 4, 34, 2, 61, 6, 52, 5, 56, 8, 75, 0, 56, 
    0, 37, 3, 39, 6, 46, 7, 72, 8, 90, 5, 95, 2, 84, 1,  2, 4,  8, 
    4, 14, 8, 26, 7, 60, 6, 67, 1, 23, 2, 69, 0, 10, 3, 95, 5, 27, 
    4, 70, 0, 27, 7,  5, 2, 89, 8, 90, 1, 38, 3, 38, 6, 36, 5, 57, 
    6, 53, 5, 33, 8,  4, 1, 59, 4,  5, 2, 64, 3, 45, 0,  7, 7, 26, 
    3, 93, 0, 84, 8,  1, 4, 80, 2,  6, 5, 78, 6, 61, 1, 57, 7,  6, 
    5,  9, 3, 77, 6, 75, 1, 57, 0, 18, 2, 45, 8, 23, 7, 47, 4, 99
  };
  const int q0752[] = {
    9, 9, // Number of jobs and machines
    4, 78, 1, 56, 6,  2, 8, 21, 5, 75, 0, 85, 3, 50, 2, 33, 7,  8, 
    1, 52, 3, 39, 0, 66, 2, 30, 8, 66, 5, 67, 6, 55, 4, 67, 7, 10, 
    4, 71, 7, 30, 8, 87, 0, 71, 6, 93, 3, 75, 1, 30, 5, 76, 2, 78, 
    4, 60, 6, 83, 3, 19, 8, 38, 1, 79, 0, 63, 5,  7, 7, 55, 2, 11, 
    5, 62, 3, 59, 0, 43, 1, 91, 4, 26, 8, 84, 6, 64, 2, 30, 7, 17, 
    1, 52, 6, 10, 4, 51, 2, 87, 7, 79, 5, 54, 8, 88, 0, 45, 3, 11, 
    0, 53, 4, 52, 6, 29, 5, 31, 1, 19, 2, 52, 8,  4, 3, 76, 7, 17, 
    1, 77, 2, 16, 7, 42, 8, 52, 6, 66, 3, 25, 4,  9, 5, 69, 0,  6, 
    3, 75, 2, 44, 7, 86, 0, 52, 4, 72, 8, 17, 5, 16, 6, 57, 1, 14
  };
  const int q0753[] = {
    9, 9, // Number of jobs and machines
    8, 54, 1,  1, 7, 61, 0, 57, 6,  3, 4, 79, 3, 80, 5, 27, 2, 18, 
    0, 59, 4, 72, 3, 48, 2, 50, 7, 94, 6, 39, 5, 11, 8, 70, 1, 95, 
    3, 63, 8,  4, 1,  2, 0, 46, 7, 34, 2, 43, 4, 11, 5, 75, 6, 60, 
    2, 50, 1, 20, 6, 67, 0, 92, 4, 23, 3, 24, 5, 80, 7, 15, 8, 67, 
    2, 40, 5, 37, 3, 86, 6, 36, 1, 95, 0, 83, 4, 29, 8, 94, 7, 79, 
    1, 30, 2, 56, 8, 65, 5,  5, 4, 78, 0, 62, 6, 52, 3, 10, 7, 41, 
    1, 81, 6, 56, 0, 93, 7, 44, 5, 58, 3, 97, 2, 47, 8, 24, 4, 18, 
    8,  2, 4, 22, 1, 61, 3, 52, 6, 71, 0,  9, 5, 71, 7, 39, 2, 72, 
    8, 28, 2, 35, 5, 46, 1, 63, 0, 38, 7, 27, 3, 64, 6, 88, 4, 67
  };
  const int q0754[] = {
    9, 9, // Number of jobs and machines
    5, 27, 8, 99, 0, 53, 1, 29, 3, 12, 4,  5, 6, 62, 7, 20, 2, 80, 
    2, 99, 5, 75, 4, 20, 6, 54, 7, 48, 1,  3, 3, 75, 0, 47, 8, 75, 
    8, 15, 7, 79, 2, 35, 1, 36, 6,  2, 5, 85, 3, 99, 0, 82, 4,  8, 
    0, 36, 6, 31, 5, 49, 7, 63, 1, 46, 8, 13, 3,  3, 4, 70, 2, 69, 
    3, 18, 6,  8, 5, 22, 8, 60, 4, 49, 7, 30, 2,  8, 1, 51, 0, 29, 
    2, 22, 0, 47, 8, 91, 7, 80, 5, 41, 4, 87, 6, 75, 3, 14, 1, 22, 
    3, 31, 1, 27, 8, 49, 5, 15, 7, 18, 0, 54, 4, 81, 6, 84, 2,  3, 
    3, 37, 0, 10, 8, 42, 1, 55, 7, 73, 5, 25, 6, 44, 2, 23, 4,  6, 
    5, 80, 8, 78, 4, 98, 0, 73, 6, 29, 7,  5, 1, 34, 2, 12, 3,  5
  };
  const int q0755[] = {
    9, 9, // Number of jobs and machines
    5, 30, 7, 62, 2, 54, 1, 77, 4, 16, 0, 29, 6, 11, 3, 94, 8,  6, 
    7, 51, 1, 72, 0, 16, 8, 43, 2, 18, 6, 30, 3, 30, 5, 70, 4, 95, 
    0, 84, 6, 13, 5, 84, 2, 52, 7,  8, 4, 27, 8, 28, 3, 95, 1, 88, 
    1, 48, 8, 10, 5, 35, 2, 27, 4, 30, 3, 51, 0, 52, 7, 91, 6, 47, 
    7, 24, 4, 79, 8, 80, 1, 16, 6, 58, 3, 10, 2, 52, 0, 93, 5, 86, 
    1,  9, 6, 95, 5, 58, 2, 50, 8, 69, 4, 37, 7, 25, 0, 66, 3, 44, 
    5, 34, 2,  1, 4, 98, 8, 77, 3, 16, 6, 34, 1,  1, 7, 59, 0, 21, 
    0, 86, 1, 59, 3, 84, 7, 29, 8, 37, 2, 37, 4, 17, 6, 63, 5, 97, 
    4,  1, 7, 49, 6,  8, 2, 38, 3, 63, 1, 55, 8, 31, 0, 68, 5, 43
  };
  const int q0756[] = {
    9, 9, // Number of jobs and machines
    5, 58, 7, 56, 1, 79, 3, 63, 8, 60, 2, 51, 0,  1, 4, 53, 6, 84, 
    7, 24, 5, 20, 3, 11, 6, 32, 2, 78, 0, 51, 1, 95, 4, 45, 8, 53, 
    8, 77, 2, 15, 6, 29, 1, 59, 7,  9, 5, 50, 0, 25, 3, 94, 4, 77, 
    3,  7, 7, 78, 1,  2, 5, 94, 0, 82, 4, 77, 8, 12, 2, 38, 6, 36, 
    5, 29, 6, 88, 1,  8, 7, 36, 8, 82, 3, 81, 0, 20, 4, 57, 2, 95, 
    1, 44, 7, 13, 0, 38, 4, 23, 5, 38, 8, 24, 2,  4, 6, 30, 3, 14, 
    3, 77, 6, 31, 8,  9, 7, 41, 4, 20, 5,  8, 1, 30, 2, 20, 0, 99, 
    3, 59, 8, 21, 4, 32, 1, 36, 0, 67, 6, 67, 5, 94, 2, 99, 7,  5, 
    0, 53, 7, 98, 3, 88, 1, 71, 8, 60, 6, 38, 4, 91, 5, 64, 2, 16
  };
  const int q0757[] = {
    9, 9, // Number of jobs and machines
    0, 11, 7, 25, 8, 33, 4, 87, 6,  8, 2, 69, 3, 60, 5, 30, 1, 80, 
    1, 78, 5, 37, 8, 75, 6, 20, 0, 89, 2, 32, 3, 62, 4, 65, 7, 67, 
    2, 76, 4, 34, 3,  6, 7, 24, 5, 25, 0, 55, 1, 42, 6, 82, 8, 35, 
    7, 90, 8, 51, 5, 53, 4, 59, 6, 24, 3, 32, 2, 89, 1, 15, 0, 38, 
    4, 48, 5, 42, 8,  4, 2, 91, 6, 97, 7, 85, 1, 45, 3, 93, 0, 61, 
    8, 10, 5, 78, 3, 86, 7, 66, 0, 20, 1, 88, 2,  7, 4, 27, 6, 62, 
    2, 93, 4, 59, 5, 83, 7, 99, 1, 63, 3, 73, 8, 19, 0, 86, 6, 15, 
    5, 69, 1, 42, 8, 27, 0, 13, 2, 47, 6, 10, 4, 87, 7, 65, 3, 55, 
    4, 48, 6, 70, 8, 14, 3, 56, 0, 25, 1,  5, 5, 88, 2, 73, 7, 33
  };
  const int q0758[] = {
    9, 9, // Number of jobs and machines
    5, 40, 3, 46, 4, 91, 1, 90, 6, 17, 2, 62, 7, 97, 0, 99, 8, 38, 
    4, 29, 3, 38, 5, 97, 2, 89, 1, 90, 6, 20, 0, 52, 8, 63, 7, 43, 
    5, 53, 2, 13, 1, 87, 6, 46, 8,  4, 0, 10, 7, 26, 3, 81, 4, 10, 
    0, 65, 1, 92, 7, 89, 8, 64, 5, 50, 4, 11, 2, 85, 6, 53, 3, 77, 
    1, 36, 2,  9, 4, 98, 7, 32, 5, 64, 0, 85, 3, 21, 6, 44, 8, 51, 
    8,  1, 7, 42, 2, 15, 5, 19, 6, 51, 4, 87, 1, 77, 0, 12, 3, 23, 
    1, 61, 6, 74, 3, 97, 5, 84, 7, 41, 0, 18, 8, 80, 2, 14, 4, 83, 
    7, 46, 2, 78, 3, 59, 5,  3, 6, 13, 8, 11, 4, 18, 0,  4, 1, 93, 
    6, 62, 2, 24, 3, 87, 1, 44, 7, 70, 4, 41, 8, 67, 5,  9, 0, 81
  };
  const int q0759[] = {
    9, 9, // Number of jobs and machines
    6, 35, 4, 32, 3, 36, 7, 67, 8, 54, 5, 53, 0, 98, 2, 44, 1, 27, 
    8,  1, 6, 77, 1, 87, 5, 59, 7, 96, 0, 54, 2, 30, 3, 52, 4, 29, 
    4, 82, 8, 38, 5, 22, 3,  7, 2, 58, 6, 98, 0, 83, 7,  3, 1, 36, 
    6, 14, 2, 87, 7, 11, 3,  5, 8, 35, 0, 11, 5, 34, 1,  3, 4, 55, 
    3, 56, 5, 71, 2, 30, 1, 71, 4,  1, 0, 97, 7, 30, 8, 49, 6, 72, 
    3, 66, 4, 99, 1, 39, 2, 73, 7,  3, 0, 87, 8, 43, 5, 62, 6, 82, 
    5, 46, 7, 59, 3, 54, 2, 26, 6, 31, 4, 77, 0, 44, 1, 88, 8, 22, 
    8, 28, 7, 78, 2, 69, 0, 83, 3, 93, 1,  1, 4,  5, 6, 91, 5, 90, 
    8, 39, 0, 75, 2, 72, 4, 15, 6, 63, 1, 54, 5, 97, 3, 59, 7, 26
  };
  const int q0760[] = {
    9, 9, // Number of jobs and machines
    7, 57, 5, 81, 2, 87, 4, 71, 1, 65, 6, 90, 8, 57, 0, 55, 3, 66, 
    5, 67, 2, 47, 1, 28, 4, 46, 0, 50, 8, 25, 7, 58, 6, 89, 3, 97, 
    3, 26, 0, 80, 1, 49, 5, 39, 4, 82, 8, 41, 6, 55, 2, 31, 7, 16, 
    5, 30, 0, 66, 8, 81, 2, 23, 3, 55, 1, 53, 6, 26, 7, 33, 4, 12, 
    5, 99, 0, 90, 3, 85, 6, 14, 4, 19, 2, 69, 7, 17, 8, 58, 1, 53, 
    4, 89, 3, 19, 0, 84, 2, 19, 1,  7, 6, 75, 5, 68, 8, 33, 7, 24, 
    0, 93, 7,  8, 4, 19, 1, 93, 8, 63, 6, 93, 5,  8, 2, 86, 3, 38, 
    7, 13, 0, 76, 4, 81, 1, 95, 3, 19, 2, 62, 5, 12, 8, 29, 6, 71, 
    7, 59, 4, 68, 2, 52, 3, 33, 8, 81, 6, 89, 1, 16, 0, 78, 5, 88
  };
  const int q0761[] = {
    9, 9, // Number of jobs and machines
    4, 69, 8, 60, 6, 86, 5, 87, 2, 93, 0, 50, 7, 98, 1, 12, 3, 61, 
    6, 45, 8, 80, 2, 21, 4, 30, 5, 17, 1,  3, 0, 37, 3, 59, 7, 93, 
    2, 69, 4, 38, 8, 12, 3, 40, 0, 74, 5, 97, 1, 98, 7, 61, 6, 12, 
    5, 12, 0, 11, 3, 69, 4, 81, 2, 43, 7, 22, 1, 88, 8, 13, 6, 15, 
    8, 37, 0, 58, 3, 86, 7, 90, 2, 24, 5, 69, 4, 32, 1, 82, 6, 54, 
    3, 85, 7, 89, 0, 19, 2, 68, 8, 53, 4, 56, 1, 89, 6, 80, 5, 53, 
    8, 11, 5, 10, 0,  8, 3, 83, 7, 52, 1, 52, 4, 41, 2, 61, 6, 42, 
    3, 17, 8, 19, 2, 10, 1, 78, 0, 81, 5, 19, 7,  5, 6, 24, 4, 99, 
    0, 55, 6,  5, 5, 80, 1, 93, 4, 32, 3, 23, 7,  7, 8, 53, 2, 64
  };
  const int q0762[] = {
    9, 9, // Number of jobs and machines
    3, 90, 7, 32, 6, 17, 2, 26, 8, 82, 5, 25, 0, 37, 4, 21, 1, 35, 
    1, 99, 3, 36, 2, 51, 8, 33, 5, 39, 7,  8, 0, 81, 4, 61, 6, 84, 
    5, 51, 0, 96, 1, 36, 7, 68, 2, 27, 3, 49, 8, 59, 4, 40, 6, 61, 
    7, 54, 5, 88, 0, 84, 8, 73, 3, 72, 4,  7, 1, 33, 2, 86, 6, 18, 
    7, 46, 2, 36, 6, 24, 8, 63, 4, 75, 1, 55, 0,  7, 5, 50, 3, 47, 
    7,  7, 0, 72, 4, 42, 6, 13, 8, 19, 3, 25, 1, 29, 5, 31, 2, 16, 
    4, 51, 6, 52, 8, 22, 0, 91, 3, 76, 5, 16, 1, 60, 2, 48, 7, 66, 
    5, 35, 4, 35, 3, 21, 7, 41, 1, 54, 6, 16, 8, 98, 2, 56, 0, 66, 
    8, 73, 6, 84, 2, 39, 0, 42, 3, 83, 7, 92, 1,  3, 4, 22, 5, 94
  };
  const int q0763[] = {
    9, 9, // Number of jobs and machines
    5, 46, 8, 19, 0,  4, 6, 98, 1, 22, 2, 35, 4, 56, 3, 36, 7, 71, 
    3, 75, 1, 11, 5, 80, 7, 60, 8, 11, 4, 27, 2, 82, 0, 95, 6, 23, 
    0, 39, 4, 35, 6, 30, 5, 73, 7, 22, 1, 23, 8, 20, 3, 82, 2, 78, 
    7, 94, 3, 22, 5, 20, 6, 10, 4, 95, 2, 16, 8, 21, 0, 66, 1, 82, 
    3, 77, 4, 41, 7, 47, 0, 61, 2, 91, 6, 54, 8,  3, 1, 99, 5, 80, 
    2, 54, 5, 65, 4, 65, 6, 64, 1, 69, 7, 93, 0, 76, 8, 83, 3,  5, 
    1, 85, 5, 21, 3, 96, 7, 34, 0, 46, 6, 90, 2, 18, 4, 16, 8, 68, 
    2,  4, 5, 67, 6, 99, 4, 63, 1, 45, 8, 98, 0, 35, 3, 18, 7, 24, 
    0, 16, 3, 32, 5, 20, 8, 54, 4, 92, 2, 52, 1, 44, 6, 25, 7,  9
  };
  const int q0764[] = {
    9, 9, // Number of jobs and machines
    4, 42, 5,  7, 7, 50, 1, 15, 6, 72, 3, 82, 8, 74, 0,  1, 2, 91, 
    7, 87, 3, 26, 0, 46, 4,  3, 6, 16, 2, 60, 1, 65, 5, 51, 8, 69, 
    5, 21, 8, 68, 3, 26, 1, 58, 6, 50, 0,  1, 7, 94, 2, 29, 4, 79, 
    6, 56, 2, 39, 7,  4, 3, 72, 1, 10, 4, 79, 8, 35, 5, 98, 0, 44, 
    0,  3, 2, 88, 1, 23, 5, 70, 7, 40, 3, 29, 8, 32, 4, 21, 6, 58, 
    6, 95, 1, 58, 2, 95, 7, 70, 4, 42, 5, 25, 0,  1, 3, 22, 8, 92, 
    4,  9, 0, 93, 7, 67, 8, 23, 6, 26, 5, 32, 1, 25, 2, 47, 3, 85, 
    1,  2, 8, 88, 6, 69, 2, 62, 5, 35, 4, 75, 0, 17, 3, 22, 7, 37, 
    1, 61, 4, 63, 0, 77, 2, 96, 3, 62, 5, 56, 6, 10, 7, 10, 8, 79
  };
  const int q0765[] = {
    9, 9, // Number of jobs and machines
    8, 13, 2, 94, 6, 18, 0, 25, 5, 68, 7, 83, 1, 33, 4, 41, 3, 45, 
    3, 71, 8, 18, 7, 74, 4,  3, 0, 32, 5, 49, 6, 44, 2, 83, 1,  4, 
    3, 84, 5, 77, 1, 67, 4, 63, 2, 99, 0, 87, 6, 94, 7, 13, 8, 80, 
    7, 32, 0, 95, 8, 54, 4, 11, 3, 24, 2, 69, 6, 75, 1, 73, 5, 97, 
    4, 18, 2,  1, 7, 43, 3, 60, 1, 99, 0,  7, 5, 48, 6, 80, 8, 37, 
    6, 32, 7, 60, 4, 54, 2, 35, 1, 62, 5, 58, 0, 76, 3, 95, 8, 23, 
    3, 97, 2,  1, 6, 29, 1, 17, 8, 60, 7, 20, 0, 49, 4, 79, 5, 86, 
    3, 57, 6, 92, 2, 75, 4, 50, 5, 76, 7, 97, 1, 65, 0,  6, 8,  9, 
    8, 22, 5, 30, 7, 30, 2, 35, 0, 55, 4, 35, 6, 72, 1, 41, 3, 18
  };
  const int q0766[] = {
    9, 9, // Number of jobs and machines
    4, 35, 5, 80, 7, 23, 0, 94, 1, 67, 3, 11, 2, 96, 8, 70, 6, 19, 
    6, 18, 1, 24, 7, 97, 8, 81, 2, 94, 4, 84, 0, 11, 3, 80, 5, 89, 
    6, 30, 7, 33, 1, 80, 3, 45, 0, 98, 4,  2, 5, 18, 8, 65, 2, 31, 
    4, 99, 8, 73, 7, 83, 6, 88, 2, 22, 0, 11, 1, 52, 5,  3, 3, 50, 
    6, 35, 1, 21, 4, 61, 0, 97, 8, 87, 2, 95, 3, 65, 7, 12, 5, 85, 
    5, 44, 0,  8, 4, 29, 8, 94, 6, 36, 3, 79, 7, 15, 2, 58, 1,  3, 
    5, 77, 3, 95, 2, 17, 6, 27, 4, 82, 8,  9, 7, 64, 0, 83, 1, 16, 
    4, 34, 7, 77, 0,  2, 6, 11, 5, 65, 1,  5, 8, 62, 2,  1, 3, 27, 
    3, 89, 1, 15, 5, 96, 2, 82, 4, 86, 6, 12, 8, 43, 7, 89, 0, 52
  };
  const int q0767[] = {
    9, 9, // Number of jobs and machines
    7,  4, 2, 52, 0, 76, 6, 58, 3,  1, 5, 51, 1, 87, 8, 10, 4, 99, 
    8, 30, 3, 56, 7, 71, 1, 92, 2, 15, 0, 33, 5, 81, 6, 26, 4, 66, 
    1, 25, 4, 28, 2, 86, 3, 98, 7, 62, 6, 81, 0, 18, 8, 60, 5, 61, 
    0, 14, 5, 22, 7, 66, 1, 18, 4, 21, 2, 24, 6, 85, 3, 69, 8, 82, 
    3, 32, 5, 96, 4, 52, 6, 42, 1, 99, 7, 15, 2, 53, 0, 43, 8, 36, 
    3, 23, 2, 49, 4, 78, 5, 84, 7, 49, 8, 61, 1, 34, 0, 59, 6, 53, 
    4, 13, 7, 30, 1, 13, 3, 97, 5, 47, 8, 21, 2, 23, 6, 45, 0, 35, 
    1, 22, 7, 35, 0, 37, 8, 33, 5, 66, 6, 96, 3, 32, 2, 26, 4, 90, 
    0, 19, 5, 99, 6, 41, 3, 60, 1, 36, 4,  8, 7,  5, 2, 74, 8, 42
  };
  const int q0768[] = {
    9, 9, // Number of jobs and machines
    2, 83, 3, 93, 6, 45, 7, 48, 5, 53, 8, 63, 4, 82, 0,  5, 1, 37, 
    4, 17, 7, 98, 1, 63, 3, 41, 8, 44, 5, 51, 0,  3, 6, 98, 2, 45, 
    2, 62, 0, 94, 8, 86, 6, 45, 5, 11, 7, 94, 3, 55, 1, 62, 4, 50, 
    1, 21, 2, 66, 0, 66, 5, 72, 7,  2, 3, 72, 6, 20, 4, 34, 8,  9, 
    1, 40, 0, 83, 6, 87, 7, 71, 5, 62, 2, 37, 3, 90, 4, 47, 8, 26, 
    1, 41, 0, 54, 3, 65, 5, 51, 8, 63, 7, 75, 4, 35, 2, 38, 6, 46, 
    2, 53, 0, 66, 1, 41, 8, 91, 7, 62, 5, 16, 4, 39, 6, 40, 3, 72, 
    2, 77, 0,  6, 1, 63, 3, 81, 6, 38, 7,  6, 4, 93, 8, 88, 5, 13, 
    5, 76, 3, 77, 7, 32, 8,  1, 1, 37, 6, 59, 2,  9, 4,  4, 0, 36
  };
  const int q0769[] = {
    9, 9, // Number of jobs and machines
    8, 29, 2, 34, 5, 12, 6,  6, 0, 56, 3,  4, 7, 23, 1, 60, 4,  5, 
    0, 14, 3, 77, 5,  4, 4, 73, 6, 75, 2, 28, 8, 49, 1,  9, 7, 43, 
    2, 41, 6, 31, 8, 64, 0, 67, 5, 49, 7, 98, 3, 43, 4, 88, 1, 97, 
    0, 24, 5, 55, 2, 52, 4, 47, 7, 97, 1, 31, 3, 42, 6, 79, 8, 23, 
    5, 70, 2,  1, 7, 17, 6, 28, 0, 55, 3, 87, 4, 64, 1,  9, 8, 90, 
    3, 36, 6, 67, 0, 60, 5, 23, 1, 22, 8, 96, 7, 95, 2,  5, 4, 50, 
    1, 46, 0, 52, 4, 63, 5, 79, 2, 72, 7, 63, 6, 47, 8, 32, 3, 55, 
    4, 44, 1,  7, 3, 43, 7, 76, 5, 60, 0, 71, 8, 56, 2, 43, 6, 59, 
    2, 21, 4, 85, 6, 33, 3, 86, 5,  4, 8, 55, 7,  3, 1, 59, 0, 68
  };
  const int q0770[] = {
    9, 9, // Number of jobs and machines
    2, 36, 8, 10, 3, 18, 6, 64, 7, 51, 4, 55, 0, 75, 5, 15, 1, 81, 
    7, 14, 1, 81, 3, 71, 6, 13, 0, 92, 2, 61, 8, 55, 5, 17, 4, 35, 
    0, 98, 8, 39, 6, 23, 3,  1, 7,  8, 5, 39, 4, 75, 1, 79, 2, 19, 
    4, 36, 3, 46, 0, 47, 1, 93, 7, 88, 8, 70, 6,  1, 5, 18, 2, 68, 
    5, 51, 6, 19, 0, 24, 4, 30, 7, 35, 1, 11, 2, 78, 3,  9, 8, 17, 
    3, 88, 8,  7, 5, 61, 2, 10, 6, 66, 7, 28, 4,  4, 1, 44, 0, 31, 
    6, 14, 2, 92, 4, 37, 0, 85, 8, 61, 5, 53, 3, 92, 1, 42, 7, 27, 
    2, 76, 3, 36, 8, 87, 0, 55, 7, 88, 1,  2, 5, 38, 4, 78, 6, 99, 
    5, 12, 8, 83, 1, 39, 4, 93, 3,  9, 6,  5, 7, 99, 2, 51, 0,  5
  };
  const int q0771[] = {
    9, 9, // Number of jobs and machines
    0, 76, 6, 26, 2, 74, 5, 31, 3, 88, 4, 55, 1, 89, 8, 53, 7, 76, 
    3, 70, 8, 33, 1,  3, 7, 41, 2, 62, 4, 58, 5, 35, 6, 26, 0, 34, 
    7, 86, 4, 28, 8, 71, 5, 29, 2, 47, 3, 77, 0, 37, 1, 11, 6, 29, 
    4, 90, 7, 81, 1, 30, 6,  7, 5, 82, 0, 95, 2, 37, 3, 58, 8, 63, 
    2, 20, 8, 39, 5, 58, 1, 38, 3, 51, 4, 81, 7, 12, 6, 32, 0, 62, 
    5, 81, 4, 34, 8, 40, 6, 79, 7, 62, 3, 82, 0, 40, 1, 88, 2, 89, 
    0, 52, 3,  2, 1, 80, 2, 19, 6, 20, 4, 53, 7, 33, 8, 69, 5,  9, 
    6, 30, 1, 52, 3, 82, 4, 10, 2, 25, 7, 71, 0, 43, 8, 37, 5, 71, 
    0, 55, 5, 13, 7, 43, 4, 25, 1, 70, 6, 79, 8,  4, 3, 42, 2, 51
  };
  const int q0772[] = {
    9, 9, // Number of jobs and machines
    5, 45, 3, 26, 2, 73, 1, 86, 6,  2, 0, 59, 8, 93, 4, 77, 7, 59, 
    0, 23, 7, 94, 6, 60, 5, 25, 1, 51, 8,  7, 2, 93, 4,  7, 3, 67, 
    6, 56, 5, 83, 0, 74, 2, 31, 8, 28, 3, 99, 7, 67, 1, 14, 4, 55, 
    2, 91, 1, 56, 3, 87, 6,  2, 4, 60, 0, 49, 7, 57, 5,  9, 8, 10, 
    2, 98, 3, 45, 4, 12, 1, 83, 0, 68, 8, 51, 5, 70, 7,  3, 6, 62, 
    0, 91, 7, 31, 8, 17, 4, 93, 5, 69, 2, 70, 6, 41, 1, 34, 3,  1, 
    5, 69, 3, 81, 0, 38, 8, 21, 7, 72, 2, 61, 4,  8, 6, 14, 1, 46, 
    1, 12, 3, 61, 4, 86, 7,  3, 5, 48, 6, 58, 2, 42, 8, 94, 0, 78, 
    6,  9, 1, 37, 7,  9, 8, 32, 5, 88, 3, 82, 4, 50, 0, 19, 2, 48
  };
  const int q0773[] = {
    9, 9, // Number of jobs and machines
    6, 22, 0, 17, 8, 91, 1, 28, 2, 56, 7, 45, 5, 69, 4, 45, 3, 89, 
    7, 24, 0, 29, 5, 32, 3, 59, 8, 72, 2, 84, 4, 62, 6, 84, 1, 90, 
    4, 27, 0, 74, 6, 88, 2, 33, 3, 42, 8, 84, 7, 35, 5, 79, 1, 94, 
    3, 39, 6, 50, 1, 73, 8, 46, 4, 88, 2, 69, 0, 49, 5, 25, 7, 99, 
    7, 15, 0, 45, 2, 62, 6, 58, 4, 70, 5, 14, 3, 29, 1, 56, 8, 76, 
    2, 80, 8, 25, 5, 81, 3, 54, 6, 56, 4, 85, 1, 88, 7, 82, 0, 40, 
    0, 67, 8, 22, 5, 25, 6, 86, 2, 11, 7, 58, 3, 13, 1, 96, 4,  8, 
    1,  2, 5, 89, 4, 88, 6, 60, 8, 96, 7, 16, 3, 22, 2, 17, 0, 30, 
    6, 22, 4, 42, 2, 54, 8,  8, 5, 52, 3, 75, 7, 29, 1, 24, 0, 30
  };
  const int q0774[] = {
    9, 9, // Number of jobs and machines
    2, 65, 5, 34, 7, 59, 4,  9, 0,  6, 8, 92, 3, 58, 6, 25, 1, 26, 
    6, 45, 2, 54, 5, 85, 3, 35, 8, 53, 4, 62, 7, 72, 1, 93, 0, 81, 
    8, 46, 1, 47, 7, 56, 6, 71, 3, 66, 2,  7, 0,  4, 5, 63, 4, 26, 
    6, 19, 3, 36, 4, 70, 2, 44, 5, 78, 7, 14, 8, 17, 1, 14, 0, 65, 
    5,  9, 0, 54, 8, 64, 3, 88, 6, 53, 7, 69, 4, 63, 1,  2, 2, 51, 
    6, 84, 8, 54, 2, 30, 7, 64, 1, 78, 0, 14, 3, 52, 5, 55, 4, 95, 
    8,  3, 1, 70, 6, 59, 0, 81, 3, 98, 5, 34, 7, 46, 4, 41, 2, 68, 
    5, 89, 8, 11, 7, 20, 2, 97, 6, 14, 4, 13, 0, 46, 1, 39, 3, 93, 
    0, 78, 6, 10, 1, 68, 7, 50, 5, 76, 8, 36, 3, 35, 4, 67, 2,  1
  };
  const int q0775[] = {
    9, 9, // Number of jobs and machines
    3, 46, 5, 26, 8, 50, 4, 93, 6, 27, 7, 75, 0, 77, 2, 49, 1, 34, 
    1, 30, 5, 91, 3, 92, 2, 24, 8, 72, 4, 64, 7, 74, 6,  5, 0, 53, 
    4, 58, 1, 82, 5, 62, 7, 35, 0, 12, 3, 64, 2, 91, 8, 79, 6, 15, 
    4, 70, 6,  8, 5, 92, 0, 79, 2, 72, 8,  2, 1, 77, 3, 24, 7,  7, 
    2, 80, 4, 79, 5, 70, 1, 42, 3, 18, 7, 45, 0, 33, 6, 18, 8, 34, 
    4, 19, 0, 61, 2, 53, 8,  7, 5, 86, 7, 98, 3, 60, 6, 81, 1, 10, 
    1, 61, 2, 42, 7,  4, 8, 91, 0, 35, 3, 67, 6, 94, 4, 36, 5, 74, 
    4, 18, 6, 98, 7, 36, 2, 35, 3, 67, 1, 96, 0,  9, 8, 11, 5, 72, 
    1, 43, 8,  9, 4, 49, 3, 23, 5, 60, 7, 39, 2, 51, 0, 99, 6, 26
  };
  const int q0776[] = {
    9, 9, // Number of jobs and machines
    4, 51, 2, 39, 1, 30, 6, 61, 7, 42, 3,  7, 8, 49, 0, 39, 5, 91, 
    2, 33, 3,  2, 8, 32, 4, 17, 0, 17, 5, 59, 1, 39, 6, 23, 7, 61, 
    5, 61, 1, 85, 2, 16, 6, 15, 3, 18, 4, 90, 0, 82, 7, 91, 8,  1, 
    6, 11, 7, 54, 5, 51, 2, 26, 3, 73, 8, 69, 4,  7, 0, 92, 1, 24, 
    5, 65, 2, 53, 0, 22, 6,  2, 4, 90, 3, 53, 1, 35, 8, 14, 7,  4, 
    0, 81, 2, 19, 7, 76, 5, 47, 3, 70, 8, 83, 4, 98, 6, 20, 1, 97, 
    1, 97, 4,  7, 6, 78, 0, 83, 7, 48, 3, 78, 8,  6, 2, 93, 5, 92, 
    5, 77, 2, 79, 6, 74, 8, 92, 1, 34, 4, 84, 3,  1, 0, 12, 7, 24, 
    1, 74, 4, 39, 7, 98, 2,  8, 3, 90, 5, 78, 0, 20, 6, 76, 8, 59
  };
  const int q0777[] = {
    9, 9, // Number of jobs and machines
    8, 12, 2, 69, 1, 30, 7,  1, 6, 15, 0, 34, 3, 16, 5, 90, 4, 18, 
    4, 98, 3, 39, 1, 47, 6, 83, 0, 72, 2, 77, 7, 37, 5, 73, 8, 70, 
    7, 85, 2, 34, 8, 42, 0, 14, 3, 19, 4, 45, 5, 30, 6, 23, 1, 11, 
    2, 62, 8, 94, 6, 37, 3, 92, 5, 85, 0, 49, 4, 87, 1, 49, 7, 30, 
    3, 44, 1,  3, 6, 71, 0, 17, 2, 78, 5, 81, 7, 21, 8, 60, 4, 51, 
    6, 68, 0, 42, 2,  4, 1, 69, 7, 98, 4, 71, 5, 16, 8, 89, 3, 53, 
    3,  5, 5, 31, 8, 69, 6, 15, 2,  8, 0, 91, 7, 74, 4, 80, 1, 31, 
    6, 56, 7, 77, 0, 82, 1, 93, 3, 55, 5, 64, 4, 81, 8, 23, 2, 32, 
    6, 73, 2, 46, 3, 81, 4, 64, 7, 59, 8,  4, 5, 70, 1, 37, 0, 53
  };
  const int q0778[] = {
    9, 9, // Number of jobs and machines
    7, 62, 3, 48, 1, 81, 5, 22, 8, 25, 2, 46, 6, 93, 0, 37, 4, 76, 
    6, 75, 4, 31, 8, 63, 7, 30, 3, 26, 0, 73, 2, 70, 5, 83, 1, 77, 
    2, 16, 4, 89, 0, 87, 6,  1, 7, 88, 3, 40, 5, 68, 1, 97, 8, 82, 
    3,  4, 2, 59, 4, 51, 8, 77, 1, 88, 6, 35, 5, 22, 7, 92, 0, 79, 
    0, 59, 5, 42, 6, 18, 3, 23, 2, 13, 8,  1, 7, 24, 4,  9, 1, 32, 
    1, 97, 8,  4, 5, 54, 2, 70, 3, 57, 4, 78, 0, 18, 7,  4, 6, 30, 
    7, 49, 8, 19, 2, 22, 3, 23, 5, 12, 6, 30, 1, 55, 0, 85, 4, 65, 
    6, 16, 1, 61, 4, 17, 3, 29, 8, 42, 0, 68, 7, 85, 2, 30, 5, 81, 
    3, 71, 4, 41, 0, 93, 7, 99, 1, 84, 2,  1, 6, 42, 8, 22, 5, 60
  };
  const int q0779[] = {
    9, 9, // Number of jobs and machines
    7, 13, 1, 43, 8,  5, 4, 22, 3, 46, 5, 47, 2, 79, 6, 76, 0, 85, 
    1,  3, 0, 59, 6, 36, 8, 15, 2, 34, 7, 24, 5, 35, 3, 35, 4, 52, 
    3, 36, 0, 22, 1, 25, 5, 41, 7,  8, 4, 21, 8, 88, 6, 58, 2, 17, 
    1, 69, 7, 26, 3, 70, 2, 75, 4, 95, 5, 29, 0, 77, 8, 85, 6, 94, 
    6, 83, 1,  6, 4, 82, 0, 64, 3, 45, 7, 81, 8, 76, 2, 72, 5, 84, 
    4, 44, 1, 75, 7, 83, 3, 55, 2, 42, 6, 50, 8, 80, 0, 85, 5, 28, 
    5, 62, 2, 86, 7, 30, 6, 39, 4, 41, 0, 51, 1, 76, 3, 87, 8, 60, 
    4,  8, 1, 64, 3, 43, 6,  4, 8, 21, 5, 36, 2, 30, 0, 91, 7, 65, 
    1, 70, 5, 74, 0, 90, 7,  5, 4, 30, 3, 63, 8, 27, 6, 43, 2, 28
  };
  const int q0780[] = {
    9, 9, // Number of jobs and machines
    8, 13, 5, 76, 2, 70, 4, 31, 6, 33, 1, 52, 3, 86, 7, 11, 0, 45, 
    8,  1, 7, 17, 0, 43, 2, 88, 1, 87, 3, 63, 5, 71, 6, 95, 4, 69, 
    2, 73, 0, 29, 4, 22, 3, 56, 6, 17, 5, 77, 8, 96, 1, 34, 7, 82, 
    1, 62, 2, 37, 4, 80, 3, 59, 7,  7, 0, 87, 5, 21, 8,  2, 6,  8, 
    6, 16, 8, 25, 4, 57, 7, 39, 5, 45, 1, 87, 3, 84, 0, 68, 2, 98, 
    3, 97, 2, 85, 5, 11, 1, 10, 7, 75, 8,  4, 0, 62, 4, 62, 6, 29, 
    5,  7, 2, 72, 0, 92, 1, 16, 4, 30, 3, 25, 7, 86, 8, 23, 6, 17, 
    0, 34, 1, 85, 5, 97, 2, 64, 4, 30, 8,  9, 7, 76, 6, 48, 3, 92, 
    7, 45, 1, 52, 6, 95, 5, 16, 0, 10, 4, 71, 3, 56, 8, 33, 2, 37
  };
  const int q0781[] = {
    9, 9, // Number of jobs and machines
    2, 49, 3, 61, 6, 48, 8,  6, 7, 90, 1, 64, 4, 92, 5, 98, 0, 27, 
    7, 11, 1, 57, 2, 91, 8, 94, 3, 26, 0, 77, 4, 24, 5, 12, 6, 69, 
    2, 19, 6, 78, 4, 82, 5, 45, 8, 50, 0, 81, 1, 61, 7, 76, 3, 89, 
    4, 54, 3, 20, 2, 56, 0, 11, 8, 34, 6, 39, 7, 55, 5, 87, 1, 23, 
    4, 25, 5, 24, 7, 67, 6, 71, 8, 97, 0, 36, 1, 95, 2,  8, 3, 24, 
    0, 41, 6,  8, 5, 55, 2, 98, 4, 28, 7,  3, 1, 36, 8, 99, 3, 67, 
    0, 60, 6, 44, 2, 93, 7, 42, 8, 88, 3, 78, 4, 50, 5, 81, 1,  8, 
    7,  7, 2, 73, 0, 71, 4, 91, 3, 45, 6, 46, 1, 68, 8, 82, 5, 35, 
    4, 95, 7, 64, 2, 75, 3, 93, 6,  4, 1,  2, 8, 62, 0, 72, 5, 68
  };
  const int q0782[] = {
    9, 9, // Number of jobs and machines
    7, 66, 4, 24, 8, 12, 5, 76, 1, 51, 6, 23, 0, 52, 2, 64, 3, 63, 
    3,  8, 7, 92, 6, 33, 2, 70, 1, 81, 4, 56, 8, 38, 5, 45, 0, 99, 
    6, 87, 1, 16, 0, 98, 3, 41, 7, 95, 2, 84, 4, 90, 5, 22, 8, 15, 
    2, 67, 1, 45, 0, 11, 5, 10, 6, 81, 4, 48, 7, 20, 8, 26, 3, 57, 
    6, 59, 0, 43, 7, 98, 2, 23, 8, 30, 5, 29, 4, 89, 1, 70, 3, 75, 
    8, 17, 7, 59, 1, 63, 0, 26, 2, 44, 5, 40, 3, 96, 6, 63, 4, 82, 
    2, 81, 3, 20, 4, 56, 6, 36, 7, 20, 1, 27, 5, 99, 0, 53, 8, 12, 
    2,  8, 6, 83, 0, 73, 3, 43, 7, 13, 8, 44, 5, 15, 4, 81, 1, 19, 
    5, 97, 6, 31, 2, 87, 1, 30, 7, 39, 8, 20, 4, 65, 0, 56, 3, 93
  };
  const int q0783[] = {
    9, 9, // Number of jobs and machines
    6, 39, 4, 79, 1, 34, 8, 86, 2, 69, 5, 26, 0, 57, 7, 25, 3, 23, 
    0, 57, 4, 81, 1, 61, 6, 42, 8, 22, 5,  2, 3, 91, 2, 30, 7, 79, 
    5, 60, 1, 33, 7, 31, 8, 47, 3, 15, 6, 52, 4, 80, 0, 12, 2, 61, 
    0, 83, 5, 82, 2, 15, 1, 62, 6, 39, 8, 80, 3, 97, 7, 95, 4, 87, 
    8, 41, 0, 54, 6, 72, 3,  5, 5, 69, 1, 71, 2,  1, 7, 11, 4, 73, 
    0, 35, 5, 60, 2, 31, 6, 73, 1, 86, 8, 35, 7, 81, 3, 80, 4, 58, 
    7, 25, 3, 90, 4, 82, 1,  6, 2, 92, 6, 91, 5, 33, 8, 11, 0, 65, 
    7, 29, 1,  4, 6, 63, 4, 17, 0, 44, 2, 17, 8, 84, 3, 21, 5, 31, 
    6, 49, 2, 79, 3, 29, 4,  1, 8, 72, 5, 50, 1, 86, 7, 21, 0, 27
  };
  const int q0784[] = {
    9, 9, // Number of jobs and machines
    4, 93, 2, 19, 8,  7, 0, 58, 6, 60, 1, 48, 7, 32, 3, 37, 5, 48, 
    3, 76, 6, 84, 5, 85, 2, 93, 4, 99, 1, 27, 7, 73, 0, 31, 8, 66, 
    2, 78, 3, 33, 0, 15, 1, 14, 4, 42, 8, 89, 5, 20, 6, 75, 7, 49, 
    5, 12, 1, 27, 4, 97, 7, 78, 6, 56, 0, 95, 2, 53, 8, 82, 3, 72, 
    3, 31, 7, 79, 4, 40, 0, 38, 8, 94, 6, 21, 2, 75, 1, 66, 5, 32, 
    4,  8, 2, 61, 6, 93, 5, 38, 1, 80, 7, 49, 8, 91, 3, 70, 0, 19, 
    5, 23, 8,  5, 7, 10, 2, 98, 3, 37, 1, 30, 6, 36, 4, 41, 0, 81, 
    0, 96, 5, 88, 8, 88, 1, 47, 3,  5, 6, 23, 4, 66, 7, 23, 2, 45, 
    6, 62, 2, 52, 4, 31, 0, 17, 3, 11, 5, 21, 7, 78, 1, 88, 8, 43
  };
  const int q0785[] = {
    9, 9, // Number of jobs and machines
    8, 44, 7,  1, 1, 72, 4, 89, 3, 54, 2,  7, 6, 80, 0, 67, 5, 50, 
    5, 47, 7, 97, 2, 69, 6, 20, 4, 43, 8, 35, 0, 18, 1, 12, 3, 22, 
    3, 49, 6, 21, 0, 29, 1, 84, 7, 51, 4, 24, 5, 41, 8, 23, 2,  3, 
    6, 32, 2, 72, 5, 25, 0,  1, 3, 53, 8, 81, 7, 48, 4, 42, 1, 37, 
    8, 79, 7, 57, 3,  9, 6,  5, 1, 88, 5, 15, 4, 15, 2, 14, 0, 35, 
    1, 43, 8, 14, 3, 19, 6, 94, 5, 14, 4, 30, 0, 45, 7, 58, 2, 50, 
    7,  8, 8, 37, 0, 60, 2, 38, 5, 50, 1,  8, 4,  7, 6, 81, 3, 19, 
    5, 27, 8, 71, 3, 69, 2, 47, 0, 92, 1, 22, 7, 12, 6, 99, 4, 83, 
    1, 17, 2, 52, 6,  7, 3, 56, 8, 29, 5, 37, 7, 25, 4, 69, 0, 15
  };
  const int q0786[] = {
    9, 9, // Number of jobs and machines
    4, 28, 6, 90, 0,  1, 7, 19, 5, 92, 3, 35, 2, 10, 8, 77, 1,  4, 
    7, 76, 0, 84, 8, 33, 4,  6, 1,  1, 5, 46, 2, 89, 3, 95, 6, 78, 
    0, 38, 5, 46, 4, 60, 6, 32, 8, 42, 1, 99, 2, 96, 7, 72, 3, 45, 
    0, 32, 8, 25, 1, 59, 2, 63, 3, 58, 4, 96, 6, 42, 5, 78, 7, 34, 
    3,  1, 1, 25, 4, 15, 0, 60, 6,  1, 8, 67, 2, 29, 7, 38, 5, 40, 
    6, 90, 7, 16, 2,  8, 8,  6, 1, 70, 3, 84, 4, 15, 5, 53, 0, 69, 
    4,  1, 1, 25, 7, 93, 6, 79, 8,  2, 0, 37, 2, 19, 5, 15, 3, 82, 
    3, 12, 0,  1, 8, 20, 7, 30, 1, 52, 4, 28, 5, 66, 2, 10, 6, 13, 
    3,  3, 4, 19, 2, 11, 8,  3, 6, 98, 7, 92, 1, 90, 0, 68, 5,  8
  };
  const int q0787[] = {
    9, 9, // Number of jobs and machines
    6, 60, 7, 72, 0, 67, 2, 46, 1, 75, 8, 79, 3, 54, 5, 35, 4, 84, 
    2, 14, 1, 13, 6,  8, 8,  3, 3, 68, 0, 34, 7, 61, 5, 20, 4, 48, 
    2, 74, 8, 40, 1, 93, 5,  7, 6, 48, 3, 46, 7,  8, 4,  7, 0, 40, 
    4, 33, 3, 25, 8, 86, 0, 47, 6, 44, 2, 78, 7, 34, 5, 75, 1, 24, 
    3,  1, 7, 21, 0, 88, 4, 59, 1, 87, 5, 50, 2, 82, 6, 99, 8, 46, 
    1, 36, 8, 62, 7, 84, 5, 31, 0, 88, 6,  9, 2, 20, 3, 38, 4, 58, 
    4, 36, 7, 54, 3, 34, 2, 21, 5, 11, 6, 30, 1,  5, 0,  4, 8, 44, 
    8, 14, 7, 49, 5,  5, 2, 49, 3, 54, 0, 96, 1, 76, 4,  9, 6, 81, 
    8, 64, 5, 97, 6, 77, 7, 91, 3,  8, 0, 37, 4,  8, 2, 21, 1, 33
  };
  const int q0788[] = {
    9, 9, // Number of jobs and machines
    5, 42, 4, 30, 2, 81, 0, 25, 1, 84, 6, 68, 8, 30, 7, 27, 3, 52, 
    1, 41, 6, 26, 4, 30, 7, 40, 5, 13, 0, 82, 8, 24, 2,  6, 3, 12, 
    1, 30, 0, 13, 4,  3, 6, 45, 2, 58, 8, 62, 7, 50, 5, 10, 3, 12, 
    2, 94, 0,  4, 7, 54, 4, 55, 6, 98, 1, 13, 8, 61, 3, 47, 5, 11, 
    3,  7, 8, 83, 7, 62, 0, 95, 4, 12, 2, 37, 6, 94, 5, 46, 1, 23, 
    0, 50, 5, 78, 6, 69, 7, 95, 8, 92, 1, 41, 4,  2, 2, 84, 3, 93, 
    1, 19, 6, 28, 3, 49, 4, 73, 0, 68, 5,  1, 7, 10, 2, 99, 8, 58, 
    1, 86, 6, 14, 5, 97, 0, 52, 7, 26, 3, 60, 8,  1, 2, 71, 4,  6, 
    0, 37, 7, 35, 2, 70, 5, 39, 6, 16, 8, 32, 3, 20, 1, 68, 4, 83
  };
  const int q0789[] = {
    9, 9, // Number of jobs and machines
    2, 72, 6, 36, 5,  6, 3,  2, 0, 35, 8, 31, 1, 47, 4, 82, 7, 96, 
    8, 25, 0, 18, 6, 10, 1, 44, 3, 49, 5, 37, 4, 64, 7, 58, 2, 11, 
    8, 36, 2, 39, 1, 68, 7, 56, 0, 30, 6, 90, 5,  9, 4, 54, 3, 71, 
    4, 92, 6,  9, 5, 21, 8, 21, 2, 44, 1, 16, 0, 59, 3, 37, 7, 16, 
    6, 16, 7, 79, 3, 55, 0, 42, 2, 43, 1, 44, 5, 13, 4, 18, 8, 64, 
    4, 84, 2, 61, 0, 93, 7,  1, 3,  6, 1,  9, 5, 90, 6, 67, 8, 84, 
    7, 86, 2, 74, 0, 55, 4, 89, 3, 37, 1, 63, 8, 45, 6, 59, 5, 58, 
    6,  4, 1, 62, 2, 35, 3, 94, 8, 18, 7, 42, 4, 70, 0, 69, 5, 65, 
    4, 52, 5, 79, 7, 55, 0, 62, 1,  3, 2, 66, 6, 69, 8, 84, 3, 36
  };
  const int q0790[] = {
    9, 9, // Number of jobs and machines
    4,  7, 5, 21, 3, 49, 1, 91, 0, 91, 6,  7, 8, 72, 2, 60, 7, 26, 
    3, 65, 2, 95, 4, 43, 6, 62, 8,  5, 7, 14, 5, 33, 1, 94, 0,  8, 
    4, 11, 6, 88, 0, 37, 1, 25, 3, 69, 5, 67, 8, 81, 2, 28, 7, 89, 
    0, 29, 6, 37, 4, 86, 7,  1, 2, 99, 3, 56, 1, 89, 5,  9, 8, 58, 
    4, 57, 5,  1, 3, 25, 1, 44, 8, 51, 2, 17, 7, 29, 0, 49, 6, 20, 
    8, 13, 1, 87, 0, 46, 4, 32, 2, 87, 5, 22, 3, 97, 6, 98, 7, 85, 
    7, 99, 1, 64, 5, 28, 4,  3, 8, 96, 3, 45, 2, 90, 6, 43, 0, 34, 
    0, 61, 4, 96, 6, 13, 1, 36, 2, 36, 8, 26, 3, 46, 5, 77, 7,  3, 
    5, 74, 1, 53, 4, 10, 2, 39, 6, 80, 7, 15, 3, 40, 8, 18, 0, 93
  };
  const int q0791[] = {
    9, 9, // Number of jobs and machines
    5, 43, 3, 83, 0, 88, 8,  7, 2, 88, 6, 58, 1, 99, 7, 27, 4, 83, 
    2, 11, 4, 13, 5, 50, 3, 21, 7, 71, 1, 89, 0, 16, 8, 66, 6, 15, 
    3, 96, 8, 60, 7, 96, 1, 29, 2, 95, 4, 62, 5, 86, 0, 79, 6, 10, 
    8, 90, 1, 41, 7, 11, 0, 76, 4, 91, 5, 23, 6, 56, 3, 17, 2, 45, 
    0, 19, 8,  4, 6, 51, 2,  9, 5, 45, 3, 29, 7, 51, 4, 39, 1, 30, 
    7, 56, 0, 58, 3, 18, 2, 55, 1, 50, 6, 16, 5, 97, 4, 19, 8, 82, 
    7, 79, 8, 36, 4, 53, 6, 76, 0,  1, 3, 91, 5, 64, 2,  3, 1, 38, 
    7, 14, 6, 32, 3, 30, 8, 51, 1, 61, 2, 41, 4, 21, 5, 85, 0, 44, 
    7, 88, 2, 60, 4, 16, 1, 48, 0, 74, 6, 58, 8,  2, 5, 38, 3,  4
  };
  const int q0792[] = {
    9, 9, // Number of jobs and machines
    5, 20, 1, 61, 4, 14, 2, 49, 8, 76, 3, 95, 6, 24, 0, 36, 7, 54, 
    6, 11, 0, 70, 1, 69, 2, 65, 7, 20, 4, 32, 8, 19, 3, 50, 5, 63, 
    4, 50, 3, 56, 0, 39, 6, 46, 2,  8, 8, 99, 7, 34, 1, 20, 5, 42, 
    8, 40, 3, 64, 7, 60, 1, 82, 5, 55, 2,  9, 4, 81, 0, 43, 6, 60, 
    5, 33, 7, 54, 1, 96, 2, 59, 3, 64, 8,  2, 0, 76, 4, 62, 6, 47, 
    7, 71, 2, 20, 3, 19, 5, 37, 0, 77, 4, 22, 8, 20, 6, 24, 1, 47, 
    7, 33, 3, 25, 0, 83, 2, 29, 4, 66, 6, 38, 8, 83, 1, 41, 5, 36, 
    2, 79, 4, 29, 3, 76, 1,  8, 5, 62, 6, 66, 7, 14, 8,  7, 0, 46, 
    5, 15, 7, 26, 1, 19, 6, 93, 4, 51, 8, 73, 3, 54, 2, 26, 0, 20
  };
  const int q0793[] = {
    9, 9, // Number of jobs and machines
    3, 53, 6, 21, 2, 25, 7, 25, 8, 19, 4, 29, 5, 45, 0, 87, 1, 74, 
    2, 95, 8, 99, 0, 55, 5, 20, 1, 87, 6, 44, 3, 58, 7, 40, 4, 44, 
    6, 32, 3, 64, 4, 14, 1, 72, 7, 99, 8, 94, 5, 67, 0, 44, 2, 73, 
    3, 19, 6, 89, 8, 59, 4, 63, 2, 77, 7, 69, 5, 77, 1, 58, 0,  5, 
    7,  8, 6, 39, 1, 89, 0, 53, 3, 16, 2, 52, 5, 16, 8, 98, 4, 54, 
    5, 60, 1, 25, 2, 17, 7, 15, 6, 23, 8, 45, 0,  8, 4, 65, 3, 57, 
    4, 29, 7, 29, 1, 89, 3, 46, 5,  5, 2, 23, 0, 81, 6,  9, 8, 81, 
    8, 13, 7, 61, 0, 57, 2, 61, 6, 24, 1, 68, 4, 43, 5, 25, 3, 25, 
    7, 50, 0, 52, 4, 13, 2, 95, 5, 24, 1, 46, 6, 59, 3, 68, 8, 41
  };
  const int q0794[] = {
    9, 9, // Number of jobs and machines
    5, 17, 6, 61, 4, 16, 8, 54, 1, 47, 7, 78, 3, 66, 0, 57, 2, 14, 
    8, 38, 4, 50, 2, 19, 5, 86, 6, 71, 1, 30, 0, 24, 3, 38, 7, 29, 
    3, 45, 0, 93, 8, 46, 1, 97, 5,  6, 6, 12, 4, 85, 7, 77, 2, 45, 
    5, 21, 2, 24, 6,  5, 1, 44, 4, 44, 7, 86, 0, 80, 3, 84, 8, 45, 
    7, 37, 0, 74, 4, 35, 3, 31, 8, 47, 5, 59, 6, 38, 1, 97, 2, 48, 
    5, 27, 1, 25, 8, 71, 6, 47, 4, 16, 2, 47, 7, 80, 3, 74, 0, 53, 
    5, 10, 6, 41, 2,  4, 0, 85, 1, 61, 8, 14, 7, 94, 3, 70, 4, 58, 
    4, 80, 8,  9, 3, 73, 6,  7, 7, 78, 5, 74, 2,  1, 0, 44, 1, 24, 
    3,  2, 8, 11, 5, 85, 4, 65, 7, 34, 2, 58, 1, 56, 6, 24, 0, 34
  };
  const int q0795[] = {
    9, 9, // Number of jobs and machines
    2, 82, 7, 80, 0, 79, 3, 91, 4, 50, 1, 90, 8, 51, 5, 47, 6, 13, 
    0, 85, 5, 51, 8, 21, 3, 77, 4, 39, 6, 27, 1, 94, 7, 25, 2, 96, 
    3, 81, 7, 85, 1, 63, 5, 99, 6, 30, 8, 41, 4, 90, 2, 40, 0, 80, 
    2, 52, 6, 68, 0, 36, 4, 43, 3, 53, 1, 54, 7, 18, 5, 87, 8, 87, 
    0,  1, 8, 38, 7,  3, 2, 73, 6, 58, 4, 35, 5, 64, 3, 43, 1, 17, 
    8, 67, 5, 35, 7, 71, 3, 26, 6, 42, 0, 57, 4, 27, 1, 99, 2, 79, 
    0, 62, 6, 86, 4, 59, 3,  6, 2, 54, 7, 39, 8, 77, 5, 95, 1, 91, 
    7, 38, 8, 20, 5,  3, 6, 87, 3, 59, 1, 97, 4, 72, 0, 54, 2, 70, 
    5, 28, 8, 43, 7, 27, 6, 70, 4,  8, 3, 75, 0, 13, 2, 17, 1, 13
  };
  const int q0796[] = {
    9, 9, // Number of jobs and machines
    5, 16, 8,  8, 4, 21, 1, 91, 7, 59, 3, 47, 0, 41, 6, 97, 2, 39, 
    6, 69, 2, 22, 4, 58, 7, 46, 1, 50, 5, 16, 0, 84, 3, 66, 8, 92, 
    1, 15, 8, 73, 3, 72, 0, 27, 7, 31, 2, 88, 6, 95, 4, 56, 5, 91, 
    1, 65, 3, 70, 8, 88, 4, 72, 0, 25, 7, 65, 6, 77, 2,  3, 5, 80, 
    1, 52, 5, 86, 8, 80, 0,  7, 4, 66, 2, 41, 3, 54, 6, 42, 7, 12, 
    6, 86, 3, 50, 7, 11, 5, 47, 0,  7, 4, 99, 8, 47, 2, 66, 1, 73, 
    7, 44, 6, 78, 1, 55, 8,  8, 0, 30, 4, 12, 2, 40, 3, 31, 5, 31, 
    5, 28, 7, 17, 4, 78, 8, 74, 1, 12, 2, 99, 3, 24, 0,  1, 6, 33, 
    0, 14, 3, 57, 4, 73, 8, 75, 6, 45, 7, 89, 5, 99, 2, 84, 1, 16
  };
  const int q0797[] = {
    9, 9, // Number of jobs and machines
    1, 97, 6, 98, 3, 41, 4,  2, 5, 69, 0, 35, 2, 75, 8, 44, 7, 39, 
    0, 78, 8, 52, 4, 26, 2, 38, 1, 12, 5, 52, 3, 98, 7, 65, 6, 36, 
    1, 37, 8, 94, 3, 62, 0, 69, 6, 15, 5, 55, 2, 39, 7, 28, 4, 52, 
    8, 98, 1, 37, 5, 15, 3, 57, 7, 35, 6, 63, 2, 73, 0, 32, 4, 39, 
    4, 56, 0, 91, 5, 76, 2, 23, 1, 42, 3, 60, 6, 21, 8, 77, 7, 74, 
    7, 31, 5, 77, 8, 24, 0, 41, 4, 32, 3, 31, 6, 53, 1, 88, 2, 19, 
    1, 65, 7, 36, 5, 45, 2, 21, 4,  4, 8, 79, 6, 91, 0, 13, 3,  4, 
    8, 29, 7, 57, 5, 16, 2, 52, 4, 31, 3, 29, 1, 49, 0, 23, 6, 12, 
    8, 86, 6, 29, 0, 54, 4, 98, 1,  2, 3, 22, 7, 12, 2, 14, 5, 83
  };
  const int q0798[] = {
    9, 9, // Number of jobs and machines
    8, 60, 0,  1, 6, 83, 7, 61, 3, 83, 2, 61, 1, 56, 5, 75, 4, 68, 
    6, 16, 0, 48, 7, 12, 4, 87, 3, 22, 1, 72, 2, 90, 5, 23, 8, 22, 
    2, 31, 5, 20, 6, 25, 7, 45, 3, 73, 8, 92, 1, 53, 0, 33, 4, 88, 
    0, 62, 8, 99, 6, 91, 2, 71, 7, 34, 3, 68, 4, 37, 1, 38, 5, 78, 
    5, 86, 8, 70, 3, 51, 2, 97, 0, 48, 1, 28, 7, 74, 6, 24, 4, 66, 
    7, 18, 8, 99, 6,  1, 1, 68, 5, 98, 3, 94, 4, 97, 2, 30, 0, 18, 
    1, 28, 7, 80, 2, 77, 6, 40, 3, 91, 0, 29, 8, 48, 5, 66, 4, 24, 
    7, 59, 4, 22, 8, 95, 3,  7, 0, 85, 5, 27, 1, 23, 2, 85, 6, 37, 
    5, 66, 8, 92, 2, 28, 3, 91, 7, 62, 0, 46, 6, 61, 1, 52, 4, 17
  };
  const int q0799[] = {
    9, 9, // Number of jobs and machines
    1, 38, 6, 96, 3, 96, 0, 97, 8, 51, 5, 98, 7, 19, 2, 75, 4, 40, 
    3, 98, 6, 97, 2, 91, 5,  1, 0, 50, 4, 16, 8, 10, 7, 41, 1,  8, 
    3,  6, 2, 78, 5, 76, 6, 41, 8, 90, 4, 91, 7,  5, 1, 63, 0, 10, 
    2, 68, 0, 85, 4, 44, 1, 28, 7,  8, 8, 20, 6, 87, 5, 83, 3,  7, 
    2, 88, 7, 25, 1, 39, 5, 33, 6, 56, 3, 49, 0,  4, 8, 89, 4, 29, 
    2,  4, 3,  7, 4, 42, 1, 63, 8, 20, 5, 53, 7, 62, 6, 91, 0, 37, 
    3, 31, 4, 30, 5, 14, 2,  4, 0, 48, 7, 37, 8, 28, 6, 57, 1, 17, 
    5, 51, 3,  7, 8, 89, 1, 82, 2, 41, 7,  5, 0, 73, 4, 88, 6, 15, 
    4,  2, 3, 68, 8, 25, 7, 24, 5,  7, 0, 32, 2, 14, 1, 72, 6,  6
  };
  const int q0800[] = {
    9, 9, // Number of jobs and machines
    3, 79, 2, 92, 6, 56, 7, 14, 5, 88, 0, 25, 1, 76, 4, 92, 8, 32, 
    1, 32, 3, 58, 8, 68, 5, 29, 2, 36, 7, 91, 6, 28, 4, 53, 0, 70, 
    5, 94, 6, 14, 1, 64, 7, 39, 0, 54, 8, 73, 4,  3, 2, 83, 3, 56, 
    6, 83, 4, 97, 3, 16, 7, 99, 2, 61, 8, 82, 5, 94, 1, 53, 0, 46, 
    8, 29, 2, 25, 6, 68, 0, 12, 5, 40, 3, 85, 7, 22, 1, 84, 4, 93, 
    1, 61, 0, 90, 7, 16, 3, 14, 6, 36, 5, 15, 4, 91, 2, 74, 8, 67, 
    1, 78, 2, 25, 7, 89, 0, 95, 5, 90, 8, 99, 4, 94, 3, 72, 6,  8, 
    0,  7, 6, 19, 8, 30, 7, 33, 5,  8, 2, 99, 1, 62, 4,  5, 3, 90, 
    6, 60, 7, 73, 2, 67, 4, 61, 3, 70, 5, 58, 8, 30, 0, 85, 1, 39
  };
  const int q0801[] = {
    9, 9, // Number of jobs and machines
    7, 82, 6,  2, 2, 56, 3,  7, 0, 31, 8, 60, 5, 22, 4,  3, 1, 44, 
    8, 46, 6,  7, 5, 61, 0, 63, 2, 99, 1,  1, 3, 24, 7, 32, 4, 47, 
    2, 44, 3, 69, 1, 80, 6, 35, 4, 44, 5, 50, 7, 92, 0, 58, 8, 80, 
    7, 42, 0, 29, 3, 87, 8, 67, 1, 47, 6, 37, 5, 92, 4, 82, 2, 42, 
    4,  3, 7, 52, 5, 12, 1, 16, 3, 41, 2, 74, 0, 45, 6, 39, 8, 72, 
    6, 63, 4, 19, 0, 79, 5, 38, 8, 41, 1, 37, 3, 66, 7, 20, 2, 30, 
    4,  5, 1, 92, 7, 56, 5, 66, 0, 39, 8, 85, 3, 92, 6, 12, 2, 85, 
    1, 92, 4, 23, 7, 75, 2, 95, 8, 91, 5, 76, 0, 42, 3, 86, 6, 43, 
    2, 18, 1, 95, 6, 79, 7, 54, 5, 58, 3,  9, 4, 24, 0, 80, 8, 41
  };
  const int q0802[] = {
    9, 9, // Number of jobs and machines
    7, 36, 5, 17, 6, 56, 0,  5, 8, 63, 4, 63, 1, 47, 2, 58, 3, 31, 
    7, 12, 1, 32, 3, 22, 0, 27, 8, 88, 6, 58, 2, 30, 4, 73, 5, 32, 
    7, 15, 6, 14, 1, 50, 2, 80, 5, 93, 3, 64, 4, 64, 0, 83, 8, 21, 
    7, 47, 1,  8, 8, 51, 0, 83, 4, 26, 3, 97, 5, 17, 2, 73, 6, 65, 
    1, 60, 7,  5, 0,  2, 5, 21, 2, 63, 3, 36, 8, 47, 4, 76, 6, 20, 
    1, 11, 2, 87, 7, 22, 0, 42, 6,  2, 3, 66, 4, 90, 5, 76, 8, 46, 
    6, 24, 0, 56, 8, 89, 2, 62, 7, 45, 4, 41, 1, 41, 3, 17, 5, 93, 
    4, 87, 0, 68, 2, 29, 8, 26, 6, 11, 7,  4, 3, 47, 1, 97, 5, 22, 
    3,  4, 0, 57, 8, 94, 1, 10, 6, 58, 2, 31, 5, 27, 4, 42, 7,  3
  };
  const int q0803[] = {
    9, 9, // Number of jobs and machines
    8, 84, 5,  5, 7, 93, 6, 71, 1, 61, 2, 38, 0, 20, 3, 58, 4, 23, 
    8, 93, 4, 18, 3, 89, 0, 52, 6, 94, 1, 63, 5, 82, 7, 20, 2, 10, 
    5, 11, 6,  1, 7, 95, 3, 51, 8, 25, 0, 93, 1, 79, 4, 95, 2, 81, 
    0, 62, 7, 43, 6, 55, 5,  6, 3, 94, 4, 49, 8, 65, 2, 53, 1, 89, 
    6, 13, 0, 99, 4, 70, 2, 22, 1, 57, 3, 76, 5,  8, 8, 73, 7, 39, 
    3, 50, 1, 95, 2, 30, 6, 99, 0, 12, 4, 40, 7, 30, 5, 45, 8, 27, 
    3, 47, 6, 13, 7, 55, 1, 52, 4, 27, 8, 12, 2, 10, 0, 38, 5, 45, 
    1, 61, 7, 94, 6,  3, 0, 52, 8, 64, 5, 65, 3, 23, 2, 48, 4, 13, 
    6, 22, 4, 54, 0, 56, 7, 78, 5, 85, 2, 51, 1, 98, 3, 64, 8, 77
  };
  const int q0804[] = {
    9, 9, // Number of jobs and machines
    7, 58, 0, 54, 6, 10, 4, 36, 1, 92, 2,  7, 3,  5, 5, 87, 8, 34, 
    5, 77, 6, 34, 1, 81, 2, 61, 8, 67, 3, 25, 4, 59, 0,  6, 7, 75, 
    3, 88, 5, 86, 7, 24, 2, 12, 6, 45, 0, 80, 4, 86, 1,  1, 8, 37, 
    3, 34, 7, 63, 2, 40, 4, 37, 0, 93, 1, 35, 8,  2, 6, 50, 5, 55, 
    5, 30, 3, 65, 4, 45, 0,  6, 8, 64, 2, 99, 1, 34, 6,  8, 7, 18, 
    1, 14, 2, 95, 6, 92, 3,  5, 7, 28, 8, 75, 4, 14, 5, 33, 0, 26, 
    0,  1, 8, 71, 5, 96, 1, 42, 4, 94, 6, 58, 2, 88, 3,  5, 7, 82, 
    7, 69, 2,  7, 1, 17, 5, 39, 8, 12, 4, 82, 3, 46, 6, 12, 0, 83, 
    0, 60, 2, 50, 8, 92, 5, 65, 6, 48, 3,  8, 4, 44, 1, 83, 7, 35
  };
  const int q0805[] = {
    9, 9, // Number of jobs and machines
    3, 77, 6, 27, 1, 99, 5, 81, 4, 57, 8, 32, 7,  5, 0, 92, 2, 32, 
    4, 98, 7, 76, 2, 87, 6, 89, 0, 31, 1, 62, 5, 11, 3, 81, 8, 51, 
    8, 67, 4, 89, 2, 51, 5, 42, 0, 81, 6, 92, 1, 93, 3,  8, 7, 25, 
    1,  3, 3, 76, 2, 32, 5, 46, 6, 48, 0,  2, 8, 45, 7, 68, 4, 83, 
    0, 72, 6, 99, 2, 95, 8, 98, 1, 79, 7,  7, 3, 50, 5, 87, 4, 29, 
    6, 35, 7, 25, 5, 34, 8, 61, 1, 27, 3, 56, 0, 97, 4, 48, 2, 34, 
    8,  3, 6, 95, 7, 45, 3, 91, 1, 51, 5, 19, 2, 34, 4, 84, 0, 89, 
    2,  3, 3, 64, 4, 12, 8, 70, 5, 27, 6,  8, 7, 68, 1, 93, 0, 44, 
    1, 66, 2, 14, 0, 43, 7, 52, 5, 14, 3, 66, 8, 71, 6, 50, 4, 45
  };
  const int q0806[] = {
    9, 9, // Number of jobs and machines
    1, 38, 7, 16, 3, 10, 0, 82, 8, 28, 6, 42, 4, 20, 5, 59, 2, 80, 
    3, 19, 0, 56, 7, 93, 8, 29, 6, 37, 4, 66, 1, 79, 2,  2, 5,  7, 
    6, 35, 7, 94, 8, 73, 0, 76, 4, 38, 1, 59, 2, 52, 3, 18, 5, 39, 
    2,  4, 5, 50, 0, 27, 7, 90, 4, 59, 6, 10, 1,  7, 3, 63, 8, 28, 
    1, 64, 3, 43, 4, 19, 0,  1, 5, 68, 6,  8, 2, 31, 8, 60, 7, 15, 
    6, 76, 4, 73, 1, 56, 0, 59, 7, 20, 2,  6, 3, 56, 5, 22, 8, 58, 
    2, 43, 6, 59, 0,  4, 3, 29, 4, 19, 5, 35, 7, 66, 1, 98, 8,  7, 
    2, 86, 1, 45, 4, 24, 5, 63, 8, 93, 0, 50, 3, 19, 6, 56, 7, 63, 
    6, 49, 4, 83, 8, 95, 3, 15, 5, 57, 1, 61, 7, 21, 2, 61, 0, 61
  };
  const int q0807[] = {
    9, 9, // Number of jobs and machines
    3, 64, 6, 52, 7, 93, 1, 98, 0, 53, 5, 44, 8, 26, 4, 59, 2, 42, 
    2, 85, 8, 29, 0, 60, 4,  1, 5, 76, 7, 57, 6, 51, 1, 66, 3, 87, 
    6, 69, 4, 24, 3, 67, 8, 46, 1,  2, 2, 42, 7, 86, 5, 17, 0, 76, 
    7, 41, 4, 16, 3, 66, 1, 97, 8, 26, 0, 89, 2, 36, 6, 49, 5, 49, 
    3, 31, 5, 60, 6, 73, 2, 81, 1, 12, 0, 13, 4, 15, 8, 81, 7, 26, 
    3, 15, 4,  7, 7, 28, 8, 68, 6, 35, 5, 45, 2, 64, 1, 48, 0, 38, 
    7, 61, 1, 41, 6, 61, 4, 36, 0, 66, 8, 74, 3, 50, 5, 83, 2, 98, 
    2,  7, 4, 69, 6, 14, 5, 41, 1, 23, 7, 31, 3, 82, 8, 95, 0, 41, 
    4,  9, 2, 36, 0, 75, 5, 63, 1, 23, 7, 46, 6, 86, 8, 13, 3, 22
  };
  const int q0808[] = {
    9, 9, // Number of jobs and machines
    2, 43, 1, 84, 4, 65, 6, 21, 5, 56, 8, 53, 7, 47, 3,  3, 0, 62, 
    6, 31, 5, 78, 4, 74, 1, 87, 8, 19, 0, 55, 7,  7, 3, 19, 2, 59, 
    2, 29, 4,  7, 5, 64, 0, 84, 3, 50, 6, 75, 7, 59, 8, 58, 1, 73, 
    6, 20, 3, 97, 2, 24, 4, 90, 7, 10, 5, 63, 0, 71, 1, 73, 8, 60, 
    0, 83, 8, 83, 5,  8, 3, 16, 2,  8, 6, 67, 4, 64, 7, 92, 1, 50, 
    3, 94, 0, 75, 2, 16, 5, 21, 6, 52, 8, 95, 7, 97, 4, 42, 1, 95, 
    3, 74, 1, 70, 4, 66, 0, 32, 6, 92, 7, 92, 5,  4, 2, 13, 8, 81, 
    0, 52, 2, 75, 4, 57, 6, 77, 3, 75, 1, 82, 8, 84, 5, 91, 7,  9, 
    1, 91, 4,  3, 2, 15, 7, 45, 6, 57, 3, 62, 8, 75, 5, 65, 0, 13
  };
  const int q0809[] = {
    9, 9, // Number of jobs and machines
    8, 17, 6, 72, 5, 30, 2, 17, 3, 11, 1, 12, 4, 93, 0, 25, 7, 34, 
    1, 22, 4, 70, 3, 53, 8, 41, 2, 72, 6, 41, 5, 10, 0, 92, 7, 54, 
    8, 65, 4, 83, 7, 71, 2, 66, 0, 85, 3, 59, 5, 17, 1, 60, 6, 30, 
    6, 84, 0, 68, 2, 68, 5, 23, 7, 62, 4, 83, 1, 74, 8, 10, 3, 10, 
    3, 40, 8, 17, 2, 79, 1, 98, 7, 22, 0, 40, 5, 89, 6, 45, 4, 19, 
    2, 63, 3, 49, 8, 37, 5, 15, 1, 11, 0, 79, 4, 14, 7, 31, 6,  4, 
    7, 83, 3, 91, 8, 55, 5, 85, 4, 12, 0,  2, 2, 35, 6, 87, 1, 92, 
    0, 39, 5, 22, 7, 82, 6, 26, 3, 59, 2, 22, 4, 53, 1, 50, 8, 52, 
    6, 35, 1, 37, 5, 71, 8, 64, 7, 78, 4, 31, 3, 33, 0, 29, 2, 43
  };
  const int q0810[] = {
    9, 9, // Number of jobs and machines
    1,  8, 5, 95, 2, 51, 3, 97, 0, 68, 7, 47, 4,  6, 8, 51, 6, 82, 
    4, 38, 7, 86, 3, 77, 2, 64, 6, 50, 8, 82, 0, 80, 5,  5, 1, 64, 
    7, 50, 4, 58, 8, 89, 5, 82, 2, 17, 6, 52, 3, 79, 1,  5, 0,  2, 
    1, 29, 2,  3, 5, 30, 4, 75, 6, 54, 7, 31, 8, 39, 3, 14, 0, 25, 
    4, 44, 6, 40, 0,  7, 5, 32, 7, 49, 8, 36, 2, 57, 3, 75, 1, 38, 
    3,  2, 2,  2, 6, 36, 4, 78, 7, 96, 1, 56, 5, 88, 8, 90, 0, 94, 
    8, 29, 2, 93, 1, 39, 5, 55, 0, 82, 4, 70, 7, 89, 6,  2, 3, 17, 
    8, 66, 1,  1, 7, 77, 6,  6, 5, 19, 0, 11, 3, 94, 4, 53, 2, 47, 
    3, 19, 5, 42, 4, 85, 2, 29, 1, 21, 8, 94, 6, 63, 7, 92, 0, 24
  };
  const int q0811[] = {
    9, 9, // Number of jobs and machines
    7, 90, 0, 22, 4, 81, 2, 33, 8, 90, 1, 57, 6, 47, 5, 96, 3, 13, 
    8, 57, 6, 84, 7, 52, 3, 32, 1, 57, 5, 58, 4, 53, 0, 89, 2, 54, 
    7, 51, 4, 42, 0, 56, 1, 75, 6, 92, 8, 82, 3,  9, 5, 48, 2, 17, 
    1, 31, 2, 14, 8, 15, 0, 84, 3, 63, 4, 59, 6, 80, 7, 64, 5, 99, 
    8, 16, 4, 26, 1, 76, 2, 75, 6, 43, 7, 96, 0,  2, 5, 38, 3, 61, 
    8, 44, 2,  8, 1, 89, 7, 97, 5, 16, 3, 48, 4,  8, 0, 84, 6, 37, 
    4, 89, 2, 20, 3, 19, 6, 98, 8, 14, 0,  1, 1,  7, 7, 25, 5, 24, 
    8, 27, 1, 25, 3, 27, 0, 42, 4,  7, 2,  1, 5, 88, 7, 63, 6, 73, 
    7, 34, 8, 70, 6, 20, 1, 80, 5, 37, 2, 88, 0, 89, 4, 40, 3,  1
  };
  const int q0812[] = {
    9, 9, // Number of jobs and machines
    0, 47, 8, 64, 2, 55, 3, 30, 4, 80, 7, 97, 6, 36, 5, 28, 1, 80, 
    1, 34, 6, 11, 5, 68, 3, 42, 8, 52, 0, 12, 2, 12, 7, 93, 4, 19, 
    2, 48, 7, 53, 6, 88, 5, 71, 8, 43, 4, 18, 1, 75, 3, 57, 0, 63, 
    4, 17, 8, 35, 7, 10, 1, 16, 5, 34, 0, 77, 3, 55, 6, 40, 2, 72, 
    2, 28, 0, 50, 4, 36, 5, 63, 7, 97, 6, 92, 3, 26, 1, 95, 8, 70, 
    2, 61, 6, 50, 1, 54, 4, 96, 0, 26, 5,  6, 7, 77, 3, 69, 8, 32, 
    3, 34, 8, 60, 7, 62, 2, 16, 0, 39, 4, 23, 6, 32, 1, 80, 5, 63, 
    2, 33, 4, 79, 8, 70, 5, 86, 0, 71, 7,  6, 1, 70, 3, 39, 6, 60, 
    1, 11, 6, 88, 4, 37, 7, 50, 2, 42, 3, 63, 8, 31, 0, 42, 5, 72
  };
  const int q0813[] = {
    9, 9, // Number of jobs and machines
    2, 89, 4, 18, 5, 76, 0,  9, 6, 75, 3, 19, 8, 71, 1, 29, 7, 87, 
    2, 26, 7, 22, 6,  2, 0, 61, 4, 71, 3, 20, 8, 31, 1, 81, 5, 27, 
    1, 60, 6, 77, 5, 55, 8, 53, 4, 15, 0, 37, 2, 99, 3, 37, 7, 59, 
    8, 56, 0,  8, 2, 21, 4,  6, 7,  7, 6, 44, 3, 68, 1, 71, 5, 97, 
    7, 49, 1, 21, 8, 95, 2, 78, 6, 40, 3, 20, 5,  5, 0, 87, 4, 39, 
    3, 35, 4, 79, 6, 19, 7, 69, 5, 74, 2, 86, 0, 92, 1,  4, 8, 96, 
    4, 97, 0, 61, 8, 93, 2, 79, 7, 98, 3, 96, 5, 95, 1, 54, 6, 56, 
    3, 45, 0, 81, 1, 73, 6,  9, 5, 66, 7, 66, 8,  6, 4, 86, 2, 50, 
    2, 99, 4, 75, 7, 38, 5, 92, 8, 56, 0,  4, 6, 86, 1, 78, 3, 23
  };
  const int q0814[] = {
    9, 9, // Number of jobs and machines
    2, 39, 4, 95, 6, 82, 8, 50, 1,  8, 0, 52, 5, 44, 3, 70, 7, 61, 
    5, 71, 0, 57, 3, 97, 2, 66, 1, 91, 4, 46, 8, 21, 7, 11, 6, 12, 
    1, 35, 8,  6, 3, 95, 6, 30, 2, 88, 7, 65, 5, 18, 0, 15, 4, 62, 
    0, 55, 2, 11, 3, 18, 8, 48, 6, 98, 4, 20, 1, 47, 5, 48, 7,  3, 
    7, 24, 3, 34, 4, 45, 5, 44, 2, 32, 8, 84, 1, 45, 6, 48, 0,  7, 
    6, 79, 1, 77, 8, 49, 3, 58, 0, 86, 7, 80, 2, 35, 5, 94, 4,  5, 
    8, 26, 0, 21, 5, 13, 7,  3, 3, 24, 4, 74, 6, 81, 2, 82, 1, 50, 
    6, 92, 7,  2, 5, 33, 1, 23, 3, 83, 8, 57, 0, 46, 2, 70, 4,  8, 
    1, 55, 0, 59, 8, 31, 7, 74, 2, 93, 4, 89, 6, 19, 5, 53, 3, 63
  };
  const int q0815[] = {
    9, 9, // Number of jobs and machines
    0, 72, 7, 29, 6, 13, 5, 87, 3, 31, 8, 94, 1, 51, 4, 17, 2, 75, 
    3,  4, 2, 58, 5, 78, 6, 58, 0, 26, 8, 95, 7, 53, 1, 36, 4,  5, 
    4, 27, 2, 76, 0, 13, 3, 19, 5, 49, 1,  8, 7, 79, 8, 31, 6, 72, 
    8, 11, 7, 86, 6,  1, 4, 96, 1, 26, 3, 88, 0, 60, 2, 54, 5, 94, 
    4, 99, 2, 35, 6, 34, 5, 72, 1, 97, 3, 95, 7, 80, 8, 87, 0, 34, 
    3, 11, 1, 38, 4, 41, 2, 12, 5, 93, 8, 18, 0, 38, 7, 89, 6, 51, 
    4, 78, 3, 55, 6, 41, 8, 72, 2, 71, 7, 96, 1, 80, 0, 24, 5, 33, 
    7, 56, 4, 24, 0, 10, 8, 88, 3, 17, 2, 48, 5, 15, 1,  6, 6, 84, 
    6, 46, 8, 36, 5, 60, 2, 55, 1, 33, 0, 27, 4, 47, 7, 93, 3, 83
  };
  const int q0816[] = {
    9, 9, // Number of jobs and machines
    6, 91, 4, 99, 7, 98, 2, 56, 0, 72, 8, 73, 5, 73, 3, 48, 1, 80, 
    6, 83, 4, 65, 1, 36, 0, 61, 8, 18, 2, 88, 5,  2, 7, 88, 3, 31, 
    3,  6, 7, 92, 0, 86, 2, 65, 5, 32, 6, 81, 1, 53, 4, 15, 8, 75, 
    5, 93, 3, 34, 8, 86, 7, 74, 4, 77, 2, 15, 0, 90, 1, 52, 6, 76, 
    0, 24, 2, 12, 7, 43, 8, 77, 6, 31, 1, 40, 3, 16, 4, 93, 5, 31, 
    7, 80, 2, 14, 6, 46, 1, 50, 3, 11, 8, 56, 0, 55, 4, 72, 5, 19, 
    3, 82, 2, 25, 8, 14, 6, 51, 1, 91, 4, 21, 7, 69, 0, 76, 5, 57, 
    7, 21, 1, 17, 3, 21, 6, 31, 5, 49, 8,  4, 2, 60, 4, 81, 0, 92, 
    0, 26, 7, 44, 1, 29, 2, 69, 5, 28, 3,  1, 4, 24, 8, 39, 6, 68
  };
  const int q0817[] = {
    9, 9, // Number of jobs and machines
    2, 49, 0, 31, 8, 29, 5, 18, 3, 57, 7, 78, 4, 14, 6, 85, 1,  2, 
    5,  2, 1, 37, 3, 12, 0, 46, 8, 93, 7,  5, 2, 43, 6, 91, 4, 82, 
    1, 53, 3, 98, 8, 92, 4, 64, 6,  1, 2, 67, 5, 38, 7,  4, 0,  7, 
    3, 76, 7,  4, 4, 26, 2, 85, 0, 25, 8, 17, 6, 54, 5, 54, 1, 19, 
    0, 96, 1, 25, 4, 51, 5, 21, 6, 13, 7, 49, 8, 79, 3, 39, 2, 23, 
    6, 37, 3, 76, 1, 29, 5, 44, 8, 88, 2, 42, 0, 59, 4, 93, 7, 90, 
    7, 62, 0, 23, 2, 44, 1, 41, 3,  9, 4, 25, 8,  2, 5, 87, 6, 11, 
    2, 18, 7, 74, 0, 57, 6, 12, 8, 15, 1,  6, 4, 16, 5, 91, 3, 48, 
    4, 51, 7, 25, 6, 77, 1, 91, 3, 94, 2,  8, 5, 74, 8, 48, 0, 87
  };
  const int q0818[] = {
    9, 9, // Number of jobs and machines
    2, 56, 8, 97, 1, 47, 6, 31, 5, 60, 0, 57, 7, 51, 3, 68, 4, 50, 
    5, 99, 4, 51, 7, 43, 2, 96, 1,  7, 6,  6, 0,  6, 8,  9, 3, 84, 
    1, 41, 2, 65, 8, 12, 5, 10, 6, 49, 3, 17, 0, 74, 7,  7, 4, 23, 
    8, 70, 4, 76, 5, 45, 0, 30, 1, 24, 3, 91, 2, 77, 6, 76, 7, 95, 
    2, 18, 4, 32, 0, 34, 5, 17, 3, 40, 1, 19, 8, 93, 6, 62, 7,  1, 
    3, 57, 8, 89, 2, 28, 4, 85, 1, 70, 5, 83, 7, 56, 6, 77, 0, 40, 
    5, 94, 6,  3, 2, 85, 3, 29, 8, 35, 7, 70, 0, 16, 4, 37, 1, 21, 
    0, 39, 6,  4, 8, 24, 3, 55, 2, 72, 1, 42, 4, 49, 5, 44, 7, 89, 
    5, 39, 1, 94, 7, 26, 8, 74, 6, 11, 4, 95, 0, 46, 3, 43, 2, 92
  };
  const int q0819[] = {
    9, 9, // Number of jobs and machines
    0, 91, 5,  5, 2, 99, 4, 33, 1,  2, 8, 64, 6, 92, 3, 53, 7, 43, 
    1, 52, 6,  2, 7, 94, 2, 73, 4, 36, 3, 13, 5, 77, 0, 71, 8, 55, 
    2, 66, 3, 33, 5, 73, 1, 37, 0, 70, 6, 11, 4, 82, 7, 57, 8, 33, 
    0, 70, 3, 42, 5, 98, 1,  5, 4, 53, 8, 46, 6, 17, 7, 82, 2, 49, 
    7, 64, 3, 94, 8, 48, 6, 22, 4, 26, 5, 12, 0,  1, 1, 19, 2, 98, 
    6, 39, 4, 38, 0, 89, 8, 58, 5,  6, 3,  5, 7,  5, 2, 67, 1, 42, 
    5, 62, 8, 48, 6, 80, 2,  1, 7, 24, 3, 72, 1, 92, 4, 51, 0, 98, 
    4,  5, 3, 79, 5, 18, 1, 79, 7, 13, 8, 90, 2, 83, 6, 68, 0, 75, 
    2, 60, 7, 28, 4, 44, 5, 73, 1, 60, 6, 25, 3, 22, 8, 61, 0, 53
  };
  const int q0820[] = {
    9, 9, // Number of jobs and machines
    5, 44, 1, 73, 2, 73, 0, 24, 7, 64, 8, 60, 4, 26, 6, 16, 3, 68, 
    1,  8, 2, 33, 0, 57, 3, 34, 7, 38, 4,  4, 8, 54, 5, 96, 6, 41, 
    2, 44, 8, 22, 3, 94, 7, 41, 5, 92, 0, 82, 4, 57, 6, 67, 1, 35, 
    1, 27, 2, 35, 0, 98, 4,  1, 8, 16, 7, 53, 6, 66, 3, 54, 5, 72, 
    4, 10, 2, 70, 1,  1, 3, 10, 7, 88, 0, 43, 5, 60, 8, 21, 6, 95, 
    3, 39, 2, 12, 4, 79, 5, 46, 8, 64, 1, 38, 7, 55, 0, 86, 6, 60, 
    8, 34, 5, 89, 3, 51, 6, 37, 7, 14, 1, 44, 4, 14, 0, 20, 2, 47, 
    3, 37, 1, 49, 2, 10, 7, 55, 6, 98, 8, 45, 0, 92, 5, 72, 4, 61, 
    8, 71, 0, 47, 7, 62, 4, 55, 3, 50, 2,  2, 1,  3, 5, 20, 6, 29
  };
  const int q0821[] = {
    9, 9, // Number of jobs and machines
    0,  1, 6, 47, 2, 70, 8, 28, 5, 29, 7, 85, 4, 65, 3, 53, 1, 56, 
    2, 50, 6, 99, 5, 96, 7, 56, 4, 19, 1, 83, 0, 97, 8, 32, 3, 47, 
    7, 51, 0,  7, 2, 17, 6, 68, 8,  7, 5, 24, 1, 77, 3, 67, 4, 60, 
    2, 91, 5,  7, 6, 33, 3, 68, 7, 93, 8, 57, 1, 59, 0, 58, 4, 21, 
    4,  7, 5, 70, 1, 65, 6, 81, 8, 79, 3, 90, 7, 83, 2, 97, 0, 54, 
    5, 98, 2, 22, 6, 82, 0, 46, 1, 90, 3,  9, 7, 11, 8, 59, 4, 72, 
    2, 73, 6, 48, 3, 14, 4,  1, 8, 21, 5, 73, 1, 80, 0, 83, 7, 53, 
    0, 85, 1, 62, 4, 84, 7, 41, 5, 64, 3, 11, 2, 40, 8, 61, 6, 40, 
    2, 42, 3, 64, 5, 31, 8, 82, 4, 77, 1, 16, 6, 22, 0, 85, 7, 31
  };
  const int q0822[] = {
    9, 9, // Number of jobs and machines
    1,  5, 3, 32, 2, 66, 5,  7, 4,  7, 7, 51, 0, 16, 6, 27, 8, 79, 
    2,  9, 0, 34, 8, 65, 5, 77, 7, 36, 6, 70, 4, 83, 3, 41, 1, 74, 
    3, 90, 6, 53, 8, 72, 4, 77, 0, 56, 7, 79, 1, 75, 5, 14, 2, 84, 
    0, 36, 2, 92, 3, 20, 1, 95, 4, 66, 5, 80, 7, 44, 8, 47, 6, 37, 
    1, 11, 4, 37, 5, 48, 0, 64, 7, 35, 8, 21, 6, 39, 2,  2, 3, 72, 
    2, 32, 5,  8, 6, 37, 3, 55, 7, 32, 0, 79, 8, 47, 1, 98, 4, 58, 
    7, 91, 4, 57, 3, 74, 2, 68, 6, 26, 1, 56, 0, 37, 5, 79, 8, 28, 
    6, 45, 2, 48, 4, 43, 3, 72, 8,  5, 5, 16, 1, 84, 7, 83, 0, 53, 
    4, 75, 2, 89, 8, 21, 3, 59, 5, 57, 1, 51, 0, 24, 7, 72, 6, 47
  };
  const int q0823[] = {
    9, 9, // Number of jobs and machines
    5, 17, 6, 72, 1, 21, 0, 51, 8, 54, 4, 50, 7,  5, 3, 89, 2,  4, 
    0, 32, 8, 99, 1, 54, 6, 68, 4, 16, 5, 25, 7, 80, 3, 92, 2, 34, 
    6,  1, 8, 96, 2, 89, 5, 98, 3, 34, 1, 46, 7, 69, 0, 54, 4, 72, 
    5, 90, 4, 13, 0, 54, 2, 47, 8, 16, 6, 79, 7, 38, 1, 51, 3, 24, 
    2, 42, 0,  2, 6, 41, 4, 72, 1, 41, 8, 96, 3, 79, 7, 19, 5, 53, 
    0, 41, 1, 89, 4, 37, 6, 68, 5, 51, 7, 81, 2, 46, 8, 71, 3, 94, 
    5, 70, 2, 79, 3, 61, 6, 36, 0, 86, 4, 30, 7, 59, 1, 20, 8, 47, 
    6, 90, 0, 34, 7, 36, 5, 64, 2, 91, 8, 26, 3, 25, 1, 34, 4, 42, 
    2, 42, 4, 65, 0, 73, 7, 51, 8, 31, 1, 43, 3, 55, 6, 68, 5, 55
  };
  const int q0824[] = {
    9, 9, // Number of jobs and machines
    1, 44, 3, 11, 8, 62, 2, 60, 6, 33, 7, 96, 0, 27, 4, 85, 5, 28, 
    5, 91, 3, 75, 1, 96, 4, 45, 8, 98, 0, 19, 6, 37, 2, 48, 7, 52, 
    3, 81, 5, 57, 2, 35, 6, 21, 8, 16, 1, 54, 0, 40, 4, 51, 7, 67, 
    8, 31, 1, 34, 5, 40, 4, 73, 0, 71, 2, 66, 3, 14, 7, 28, 6, 80, 
    2, 41, 0, 59, 3, 10, 6,  4, 4, 91, 7, 29, 8, 85, 5, 81, 1, 89, 
    5, 54, 8, 35, 1, 99, 2, 45, 0, 96, 3, 51, 4, 79, 6, 96, 7, 94, 
    7,  9, 8, 11, 3, 85, 5, 72, 4, 60, 6, 45, 2, 73, 0, 73, 1, 64, 
    4, 78, 3, 96, 2, 56, 5, 27, 6, 72, 1, 50, 8, 86, 0, 53, 7, 53, 
    2, 44, 8, 22, 3,  5, 5, 42, 0,  9, 6, 37, 4, 94, 1, 89, 7, 49
  };
  const int q0825[] = {
    9, 9, // Number of jobs and machines
    2, 76, 6, 77, 4, 47, 3, 34, 0, 55, 5, 76, 8,  2, 7, 26, 1, 81, 
    3, 91, 1, 89, 8, 62, 2, 97, 7, 17, 5, 78, 0,  2, 4, 57, 6,  3, 
    7, 22, 3, 83, 8, 68, 5, 14, 0, 66, 1,  7, 6,  7, 4, 89, 2, 47, 
    0, 64, 4, 43, 1, 60, 8, 81, 7, 77, 5, 10, 6, 37, 2, 47, 3, 66, 
    2, 38, 6, 63, 5, 60, 7, 44, 1, 54, 4, 83, 8, 59, 0, 39, 3, 74, 
    1, 33, 6, 12, 8, 38, 7, 88, 4, 79, 5, 79, 3, 31, 0, 72, 2, 20, 
    4, 78, 0, 74, 3, 83, 8, 56, 6, 56, 5,  3, 1, 94, 7, 47, 2, 49, 
    5,  4, 1, 42, 0, 92, 8, 74, 6, 45, 4, 38, 3, 16, 2, 97, 7, 57, 
    3, 91, 7, 27, 1,  5, 0, 63, 2,  3, 6, 42, 5,  9, 8, 71, 4, 89
  };
  const int q0826[] = {
    9, 9, // Number of jobs and machines
    2, 39, 4, 50, 8, 42, 3, 58, 7, 82, 0, 88, 6, 20, 1, 32, 5, 42, 
    0,  1, 5, 88, 2, 73, 6, 61, 3, 79, 1, 36, 8, 66, 4, 16, 7, 41, 
    8, 24, 7, 43, 2, 12, 3, 80, 5, 16, 1, 60, 6, 48, 0, 67, 4, 92, 
    7, 21, 2, 95, 4, 27, 1, 89, 6, 71, 0, 78, 8, 90, 5, 65, 3, 40, 
    8, 84, 1, 95, 5, 56, 4, 93, 2, 79, 0, 79, 6, 89, 7, 64, 3, 82, 
    0, 25, 4, 80, 8,  2, 3, 58, 5, 38, 1, 52, 7, 85, 2, 18, 6, 56, 
    7, 39, 0, 66, 4, 25, 3, 97, 5, 27, 1, 67, 2, 31, 6, 53, 8, 35, 
    5, 79, 3, 18, 4, 31, 6, 24, 7, 89, 2, 75, 8, 81, 1, 84, 0,  1, 
    7, 80, 8, 94, 1, 75, 5, 94, 3, 37, 6, 92, 0, 85, 4, 50, 2, 82
  };
  const int q0827[] = {
    9, 9, // Number of jobs and machines
    3, 38, 0, 76, 8, 86, 5, 54, 4, 81, 2, 81, 6, 56, 7, 23, 1, 60, 
    5,  1, 6, 45, 4, 29, 3, 81, 1, 26, 0, 44, 2, 26, 7, 74, 8, 79, 
    7, 85, 5, 10, 2, 20, 6, 30, 8, 52, 4, 15, 0, 63, 3, 12, 1, 18, 
    1, 15, 8, 93, 2, 95, 3, 60, 7, 89, 0, 46, 5,  3, 4, 52, 6, 80, 
    6, 23, 8,  5, 5,  6, 7, 36, 0, 13, 2, 40, 3,  6, 4, 42, 1, 84, 
    4, 58, 2, 40, 3, 23, 5, 17, 1, 71, 6, 39, 0, 24, 7, 90, 8, 51, 
    3, 49, 5, 69, 7, 30, 0, 39, 8, 80, 6, 63, 2, 41, 4, 56, 1, 32, 
    1, 97, 5, 22, 3, 42, 2, 31, 8, 88, 4, 71, 7, 47, 6, 47, 0, 15, 
    3,  8, 7, 40, 2, 19, 1, 19, 8, 34, 4, 38, 5, 27, 6, 18, 0, 56
  };
  const int q0828[] = {
    9, 9, // Number of jobs and machines
    8, 75, 6, 96, 7, 85, 2,  6, 4,  5, 5, 47, 1, 82, 0, 52, 3, 40, 
    6,  6, 2, 25, 7, 68, 0,  3, 3, 10, 8, 98, 5, 74, 1,  8, 4, 86, 
    5, 17, 4,  1, 6, 90, 2, 85, 0, 43, 8, 44, 3, 80, 7, 21, 1, 53, 
    2, 78, 5, 34, 1, 40, 8, 40, 7,  5, 0, 95, 6,  9, 3, 57, 4, 42, 
    2, 10, 1, 29, 3, 30, 7, 34, 8, 32, 4, 75, 6, 49, 5, 52, 0, 25, 
    7, 50, 4, 37, 0, 69, 8, 76, 6, 18, 1, 79, 5, 39, 3, 41, 2, 69, 
    1, 91, 8, 38, 5, 29, 4, 24, 6, 40, 3, 26, 2, 59, 0,  1, 7, 20, 
    0, 33, 6, 63, 5, 32, 2,  4, 4, 65, 3, 18, 8, 36, 1, 31, 7, 92, 
    5, 56, 6, 18, 7, 89, 2, 86, 0, 19, 1, 61, 3, 27, 4,  7, 8, 66
  };
  const int q0829[] = {
    9, 9, // Number of jobs and machines
    4, 63, 7,  5, 3, 26, 8, 42, 5, 30, 0, 15, 1,  7, 2, 47, 6, 18, 
    0, 49, 5, 31, 1, 86, 4, 93, 7,  1, 2, 18, 8, 61, 6, 82, 3, 16, 
    8, 23, 5, 34, 7, 28, 6, 49, 2, 50, 4, 31, 3, 94, 0, 79, 1, 14, 
    2, 70, 3,  5, 4, 62, 0, 52, 5, 80, 6,  4, 1, 44, 7, 21, 8, 38, 
    7, 27, 8, 31, 3, 69, 4, 69, 1, 54, 5,  8, 6, 85, 0, 31, 2, 33, 
    0, 14, 1, 45, 3, 35, 5, 11, 4, 30, 7, 29, 8, 76, 2, 93, 6, 70, 
    3, 85, 1, 62, 7, 70, 8, 33, 2, 34, 0, 68, 4, 28, 5, 12, 6, 85, 
    1, 91, 0, 16, 5, 92, 2, 62, 6, 13, 3, 79, 7, 42, 4, 35, 8, 24, 
    8, 18, 1, 91, 0,  2, 5,  1, 2, 12, 3, 14, 4, 79, 7,  9, 6, 93
  };
  const int q0830[] = {
    9, 9, // Number of jobs and machines
    7, 28, 1, 65, 3, 15, 4, 12, 2, 25, 0, 73, 6, 16, 8, 83, 5, 68, 
    0, 81, 8, 96, 7,  4, 3, 31, 5, 48, 6,  5, 4, 85, 2, 96, 1, 45, 
    0, 46, 1, 54, 2, 75, 4, 61, 6, 94, 5, 28, 7, 97, 3, 60, 8, 38, 
    6, 70, 0, 87, 5, 41, 7, 55, 4, 18, 8, 21, 2,  2, 1, 50, 3, 22, 
    1, 71, 8, 87, 4, 98, 6, 41, 5, 13, 7, 20, 0, 19, 2, 43, 3, 39, 
    4, 32, 1, 31, 8, 30, 5, 27, 2, 31, 6, 34, 7,  6, 0, 55, 3, 57, 
    0, 71, 5, 88, 3, 47, 4, 22, 2, 74, 7, 66, 6, 60, 8, 26, 1,  8, 
    0, 47, 2, 13, 5, 71, 6, 81, 1, 29, 4, 54, 3,  9, 7, 25, 8, 84, 
    4, 56, 6, 66, 5, 57, 2, 53, 3, 92, 8, 74, 1, 51, 7, 21, 0, 82
  };
  const int q0831[] = {
    9, 9, // Number of jobs and machines
    6, 62, 5, 82, 0,  5, 1, 64, 2, 89, 4, 80, 7, 27, 3, 53, 8, 60, 
    2, 43, 4, 26, 6, 19, 8, 23, 3, 50, 0, 44, 1, 47, 5, 48, 7, 44, 
    6, 61, 4, 97, 2, 33, 8, 55, 3, 19, 1, 86, 0, 71, 5, 81, 7, 40, 
    4, 93, 3, 66, 1, 47, 7, 29, 6,  5, 8, 95, 2, 31, 5, 40, 0, 21, 
    0, 15, 7, 74, 5, 41, 6,  6, 2, 37, 4, 21, 3, 16, 1, 46, 8, 37, 
    7, 81, 4, 92, 3, 77, 2, 16, 5, 13, 6, 70, 8, 71, 0, 28, 1, 99, 
    5,  9, 6, 71, 3, 67, 2,  2, 7,  7, 1, 62, 8, 97, 0,  6, 4, 88, 
    3,  1, 4, 60, 1, 29, 2, 71, 0, 77, 8, 28, 6, 94, 5, 67, 7,  9, 
    2, 89, 5, 56, 7, 20, 4, 55, 6, 12, 1, 51, 0,  4, 8, 46, 3, 11
  };
  const int q0832[] = {
    9, 9, // Number of jobs and machines
    3, 37, 0, 32, 2, 91, 1, 77, 5, 76, 6, 98, 4, 21, 8, 95, 7, 21, 
    1, 55, 8, 85, 3, 74, 7, 65, 5, 50, 2, 78, 0, 38, 4,  6, 6, 64, 
    2,  4, 7, 63, 5, 54, 8, 85, 0, 64, 1, 74, 6, 41, 3, 31, 4, 69, 
    5, 52, 2, 98, 7, 60, 6, 18, 8, 11, 3, 15, 0,  6, 1, 62, 4, 51, 
    4, 46, 2, 31, 8, 70, 7, 50, 1, 36, 6, 45, 5, 46, 3, 83, 0, 94, 
    1, 51, 5, 47, 6, 30, 2, 96, 0, 16, 3, 13, 7, 45, 4, 38, 8, 12, 
    4, 40, 1, 78, 3, 21, 8, 81, 0, 49, 6, 92, 2, 43, 7, 35, 5,  4, 
    1, 54, 0, 44, 2, 76, 5, 50, 7, 86, 3, 38, 8,  6, 6, 83, 4, 94, 
    8,  7, 0, 16, 6, 63, 3, 56, 2, 65, 5, 76, 4, 16, 1, 71, 7, 10
  };
  const int q0833[] = {
    9, 9, // Number of jobs and machines
    4, 21, 2, 92, 6, 30, 5, 61, 1, 16, 7, 95, 3, 84, 8, 68, 0, 74, 
    8, 40, 3, 60, 1, 30, 2, 93, 5, 94, 7, 91, 4, 21, 0, 24, 6, 95, 
    8, 63, 7, 24, 0, 74, 3, 14, 4, 19, 2, 86, 6, 23, 5, 49, 1, 73, 
    2, 92, 6, 62, 3, 46, 7, 92, 4, 61, 1, 30, 8, 54, 5, 94, 0,  2, 
    2, 34, 4, 35, 3, 56, 1, 89, 8, 85, 7, 72, 6, 44, 0, 76, 5, 29, 
    6, 30, 0, 21, 5, 84, 4, 50, 7, 41, 2, 87, 1, 34, 3, 70, 8, 79, 
    0, 36, 8, 29, 2, 22, 4, 88, 1, 58, 5, 96, 7, 66, 3, 84, 6, 78, 
    3, 85, 4, 48, 8, 89, 2, 10, 1, 80, 0,  7, 7, 39, 5, 65, 6, 74, 
    3, 61, 8, 91, 4, 60, 7, 51, 5, 52, 0, 45, 6, 13, 2, 22, 1, 45
  };
  const int q0834[] = {
    9, 9, // Number of jobs and machines
    4, 29, 0,  2, 6, 27, 7, 20, 2, 28, 5, 58, 8, 74, 1, 50, 3, 21, 
    1, 46, 7, 81, 3, 95, 2, 48, 5, 17, 8, 10, 6, 83, 4, 89, 0, 54, 
    6, 93, 2, 54, 5, 61, 4, 25, 8,  2, 7, 14, 1, 27, 3, 24, 0,  6, 
    0, 78, 4, 61, 5, 55, 6, 87, 3, 13, 1, 13, 7,  9, 2, 81, 8, 70, 
    8,  1, 1, 96, 0, 20, 6, 18, 3,  3, 5, 31, 2, 91, 7, 96, 4, 29, 
    0, 94, 2, 52, 4, 97, 1, 72, 7, 45, 5, 75, 8, 30, 3, 65, 6, 70, 
    8, 93, 6, 47, 0, 74, 7, 49, 5, 87, 2, 79, 1, 70, 3, 79, 4,  8, 
    2, 94, 8, 39, 5, 47, 6, 26, 0, 37, 3, 77, 4, 49, 1, 88, 7, 17, 
    3, 79, 7, 23, 6,  2, 2, 17, 4, 96, 0, 30, 8,  8, 1, 91, 5, 79
  };
  const int q0835[] = {
    9, 9, // Number of jobs and machines
    2, 41, 1, 19, 4, 96, 0, 42, 8, 19, 3,  4, 6, 23, 5, 71, 7, 55, 
    5, 71, 3, 58, 7, 77, 6, 71, 0, 73, 8, 77, 4, 45, 2, 61, 1, 88, 
    7, 92, 4, 59, 1,  8, 0, 85, 3, 66, 6, 20, 2, 32, 5, 96, 8, 57, 
    3, 26, 2, 31, 5, 25, 7, 10, 4,  5, 6, 44, 8, 30, 0, 10, 1, 69, 
    1, 89, 6, 56, 5, 97, 8, 93, 3, 56, 7, 71, 2, 35, 4, 62, 0, 60, 
    5, 11, 0, 99, 2, 72, 4, 54, 1, 79, 6, 24, 8, 88, 7, 37, 3, 18, 
    3, 68, 4, 37, 5, 14, 8, 43, 6,  8, 0, 60, 7, 33, 1, 47, 2, 78, 
    0, 97, 2, 42, 7, 74, 4, 87, 6, 91, 8, 55, 5, 78, 3, 91, 1, 32, 
    2, 12, 0, 61, 7, 66, 3,  4, 8, 76, 6, 93, 1, 37, 4, 97, 5, 12
  };
  const int q0836[] = {
    9, 9, // Number of jobs and machines
    4, 47, 1,  4, 3, 19, 6, 65, 7, 81, 8, 90, 2, 93, 0,  4, 5, 10, 
    6, 84, 0, 45, 7, 90, 5, 60, 2, 93, 1, 56, 3, 82, 4, 84, 8, 22, 
    8, 94, 2, 42, 0,  4, 1, 65, 6, 43, 7, 79, 3, 87, 4, 57, 5, 94, 
    8, 63, 1, 68, 0, 68, 2, 83, 7, 70, 4, 42, 5, 26, 6, 23, 3, 87, 
    8, 30, 3, 83, 5, 27, 4, 96, 6, 51, 1, 66, 2, 30, 0, 31, 7, 35, 
    7, 24, 8, 87, 0, 44, 4, 39, 2, 40, 3, 59, 5, 60, 6, 63, 1, 40, 
    6, 99, 8, 86, 2, 15, 7, 10, 5, 20, 0, 60, 3, 32, 4, 84, 1, 22, 
    4, 19, 3,  5, 1, 30, 8, 67, 7, 18, 6,  4, 0,  1, 2, 70, 5, 69, 
    6, 20, 4, 79, 1, 58, 0, 56, 7, 85, 3, 75, 5, 84, 8, 23, 2, 69
  };
  const int q0837[] = {
    9, 9, // Number of jobs and machines
    7, 79, 1, 86, 8, 68, 0, 68, 5, 87, 4, 10, 2, 64, 6, 18, 3, 78, 
    4, 93, 6, 66, 5, 73, 2, 90, 1,  7, 3, 94, 8, 59, 0, 18, 7, 53, 
    0, 48, 8, 94, 6, 87, 2, 29, 7, 84, 3, 86, 4,  8, 5, 19, 1, 91, 
    4, 62, 2, 97, 5,  6, 3, 36, 1, 93, 7, 83, 0,  1, 6, 31, 8, 55, 
    3, 28, 8,  4, 5, 24, 2, 23, 7, 31, 0, 35, 4, 37, 6, 63, 1,  3, 
    5, 93, 4, 75, 0, 70, 7, 21, 3,  2, 8, 11, 2, 47, 6, 84, 1, 70, 
    4, 51, 3,  5, 8, 12, 1, 32, 0, 51, 2, 94, 6, 90, 5, 40, 7, 98, 
    3,  8, 8, 70, 0, 59, 6, 95, 7,  3, 4, 33, 5, 77, 1, 67, 2, 68, 
    5, 42, 7, 22, 4, 25, 3, 45, 8, 87, 0, 21, 6, 98, 1, 65, 2, 46
  };
  const int q0838[] = {
    9, 9, // Number of jobs and machines
    6, 93, 3, 92, 7, 36, 2, 90, 0, 19, 4, 92, 5, 84, 1, 40, 8, 13, 
    5, 63, 3, 89, 7, 61, 1, 30, 4, 55, 2, 51, 6, 53, 0, 39, 8, 51, 
    6, 99, 7, 78, 2, 53, 3, 94, 4, 31, 1, 73, 0, 42, 5, 52, 8, 26, 
    5, 58, 2, 16, 7, 60, 8, 96, 4, 90, 6, 15, 0, 25, 3, 35, 1, 82, 
    4, 63, 0, 87, 2, 70, 8, 71, 1, 24, 5, 89, 7, 80, 3, 87, 6, 85, 
    5, 56, 8, 84, 4, 66, 1, 64, 0, 32, 2, 63, 6, 38, 7, 39, 3, 29, 
    2, 63, 0,  5, 5, 46, 6,  3, 4, 59, 8, 35, 7, 72, 3, 64, 1, 62, 
    1, 44, 6, 58, 7, 68, 5, 62, 8, 27, 4,  1, 3, 82, 0, 14, 2, 50, 
    4, 76, 0, 76, 8, 39, 1, 66, 5, 37, 6, 53, 3, 33, 2, 10, 7, 99
  };
  const int q0839[] = {
    9, 9, // Number of jobs and machines
    7, 92, 4, 32, 6, 17, 5, 97, 8, 69, 0, 99, 1, 63, 2, 44, 3, 73, 
    2, 36, 8, 80, 4, 53, 1, 97, 3, 38, 0, 83, 5,  5, 6, 30, 7, 61, 
    5, 45, 1, 37, 2, 21, 8, 72, 6, 63, 3,  6, 0, 73, 7, 96, 4, 41, 
    4, 50, 0, 76, 2, 28, 1, 31, 7, 35, 5, 22, 6, 85, 3, 39, 8, 65, 
    7, 94, 5,  2, 8,  5, 6, 39, 4, 85, 0, 30, 3, 68, 2, 17, 1, 94, 
    3, 61, 1, 53, 8, 97, 7, 99, 2, 71, 5, 84, 0, 19, 4, 13, 6, 48, 
    6, 66, 8, 32, 4, 13, 3, 55, 0, 89, 5, 74, 7, 82, 2, 44, 1, 97, 
    0, 33, 2, 33, 1, 27, 8, 57, 3, 25, 5, 54, 4, 95, 7, 41, 6, 38, 
    2, 71, 0, 69, 1, 84, 7, 80, 6, 31, 8, 93, 3, 81, 4, 43, 5, 80
  };
  const int q0840[] = {
    9, 9, // Number of jobs and machines
    1, 18, 3, 68, 5, 96, 2, 56, 7, 96, 0, 83, 8, 66, 6, 80, 4, 31, 
    4, 60, 6, 21, 1, 45, 0, 12, 3,  5, 2, 18, 5, 73, 7, 52, 8, 10, 
    2, 78, 5, 18, 4, 48, 6, 62, 1, 66, 3, 91, 0, 96, 7, 79, 8, 45, 
    1, 24, 5, 59, 6, 92, 4, 93, 2, 69, 7, 84, 3, 38, 0, 52, 8, 64, 
    2, 94, 1, 68, 5, 96, 8, 40, 7, 73, 6, 55, 0, 44, 3, 93, 4, 76, 
    4, 76, 3,  5, 7, 17, 5, 69, 2, 40, 8, 46, 0, 63, 6, 57, 1, 58, 
    2, 71, 6, 47, 0, 37, 1, 97, 4,  1, 8, 14, 5, 89, 3, 92, 7, 65, 
    6, 12, 3, 44, 7, 15, 4, 93, 2, 19, 0, 52, 1, 76, 8, 97, 5, 54, 
    5, 19, 1, 26, 8, 21, 0, 87, 6, 39, 2, 37, 7, 40, 3, 31, 4, 31
  };
  const int q0841[] = {
    9, 9, // Number of jobs and machines
    3, 49, 2, 85, 6,  8, 0, 68, 7, 30, 4, 18, 8, 57, 5, 13, 1, 58, 
    3, 54, 0, 90, 4, 65, 5, 39, 6, 22, 8, 87, 2, 85, 7, 65, 1, 84, 
    7,  9, 5,  8, 6, 22, 0, 37, 2, 20, 4, 64, 3, 61, 1, 75, 8, 69, 
    7, 87, 3, 62, 1, 95, 5, 91, 8, 40, 6, 73, 2,  2, 0, 52, 4, 98, 
    6, 95, 8, 11, 1, 20, 5, 45, 4, 75, 3, 39, 0, 60, 7,  1, 2, 94, 
    4, 38, 2, 83, 1, 58, 6, 43, 5, 33, 8, 71, 3, 92, 0, 55, 7, 21, 
    1, 45, 4, 83, 3, 75, 2, 54, 6, 60, 8, 53, 7, 36, 0, 75, 5, 56, 
    3, 61, 7, 49, 5, 82, 6, 27, 8, 35, 0, 63, 2, 23, 1, 66, 4, 53, 
    2, 16, 4, 30, 0, 69, 8, 43, 3, 14, 1, 44, 6, 89, 7, 87, 5, 66
  };
  const int q0842[] = {
    9, 9, // Number of jobs and machines
    7, 36, 4,  8, 5,  5, 8, 47, 0, 27, 3, 78, 2, 76, 6,  7, 1, 45, 
    4, 95, 5,  2, 6, 23, 2, 34, 1, 91, 3, 99, 8, 42, 0, 64, 7,  5, 
    3, 82, 1, 27, 4, 56, 2, 29, 6, 55, 5, 77, 0,  4, 7, 41, 8, 43, 
    5, 34, 8, 18, 6,  7, 4, 53, 7, 41, 0, 84, 3, 41, 1, 27, 2, 13, 
    3, 34, 8,  6, 7, 23, 1, 29, 2, 66, 0, 38, 4, 61, 5, 67, 6, 51, 
    4, 61, 5, 62, 8, 66, 1, 25, 6, 75, 2, 52, 0, 49, 7, 88, 3, 69, 
    0, 66, 4, 87, 2, 42, 5, 43, 3, 55, 6, 47, 8, 50, 7, 19, 1, 77, 
    2, 13, 0, 20, 8, 60, 1, 90, 6, 29, 5, 94, 7, 93, 3, 30, 4, 54, 
    3, 33, 6, 30, 1, 31, 5, 69, 2, 71, 0, 54, 7, 54, 8, 99, 4, 55
  };
  const int q0843[] = {
    9, 9, // Number of jobs and machines
    2, 14, 1, 42, 6, 54, 8, 73, 3, 40, 7,  9, 0, 98, 5, 94, 4, 65, 
    7,  1, 6, 92, 8,  2, 2, 22, 3, 59, 1, 65, 5, 34, 0,  6, 4, 39, 
    8, 16, 2, 70, 0, 21, 3, 27, 6, 24, 4, 68, 7, 13, 5, 39, 1, 83, 
    7,  2, 6,  9, 3, 76, 0, 61, 8, 78, 4, 97, 2, 56, 5, 53, 1, 65, 
    5, 93, 4, 97, 3, 52, 0, 99, 7, 21, 2, 99, 6, 48, 8, 27, 1, 54, 
    3, 47, 8, 31, 2, 69, 7, 83, 1, 68, 0, 81, 6, 54, 5, 51, 4, 85, 
    2, 51, 0, 65, 7, 42, 4, 10, 8, 87, 3, 57, 5, 56, 6, 16, 1, 92, 
    4, 38, 0, 29, 8, 71, 5, 44, 2, 92, 1, 16, 3, 23, 6, 93, 7, 20, 
    4, 25, 5, 23, 3, 63, 7, 28, 0, 26, 6, 99, 1, 89, 2, 52, 8, 15
  };
  const int q0844[] = {
    9, 9, // Number of jobs and machines
    4, 50, 1, 70, 2,  9, 8, 72, 3, 70, 7, 54, 5, 57, 6, 35, 0, 79, 
    6, 70, 3, 28, 7,  6, 1, 26, 8, 18, 5, 72, 2,  2, 4, 21, 0, 91, 
    7, 38, 8, 79, 4, 89, 1, 31, 0,  7, 3, 91, 5, 96, 6, 98, 2, 25, 
    7, 96, 0, 61, 1, 25, 3, 70, 5, 53, 4, 99, 6, 60, 8, 50, 2, 22, 
    6, 35, 1,  9, 2, 14, 4, 50, 7, 42, 8, 70, 5, 23, 3, 49, 0, 78, 
    7, 75, 1, 24, 0, 30, 8,  2, 2, 99, 6, 77, 4, 87, 5, 60, 3, 68, 
    7, 49, 3, 71, 8,  7, 6, 72, 2, 12, 0, 16, 4, 50, 1, 56, 5, 83, 
    3, 24, 2, 47, 0,  5, 4, 74, 1, 28, 7, 88, 6, 80, 5, 18, 8, 89, 
    4, 69, 5, 19, 0, 27, 2, 93, 8, 21, 7, 79, 1, 77, 6, 16, 3, 57
  };
  const int q0845[] = {
    9, 9, // Number of jobs and machines
    4, 34, 1, 95, 0, 75, 5, 48, 2, 16, 6,  9, 7, 89, 8, 78, 3, 83, 
    3, 10, 0, 42, 1, 25, 7, 38, 6, 97, 5, 60, 8, 59, 4, 14, 2, 35, 
    7, 64, 5, 81, 0, 20, 4, 78, 1, 43, 3, 27, 6, 98, 8, 93, 2, 45, 
    2, 74, 6, 87, 3, 15, 8, 62, 4, 88, 7, 94, 0, 95, 5, 11, 1, 67, 
    5, 40, 8, 11, 3, 62, 2,  3, 7, 18, 4, 25, 0,  9, 6, 97, 1, 96, 
    4, 48, 8, 43, 7, 11, 5, 10, 2, 85, 0, 32, 6, 76, 3, 73, 1, 90, 
    5, 24, 8, 59, 3, 11, 1, 91, 0, 83, 4, 89, 7, 71, 2,  6, 6, 11, 
    4, 47, 7, 22, 3, 15, 1, 51, 5, 10, 0, 10, 8, 45, 6, 84, 2, 60, 
    0, 69, 5, 95, 1, 19, 8,  9, 4, 85, 6, 90, 2, 99, 3, 70, 7, 80
  };
  const int q0846[] = {
    9, 9, // Number of jobs and machines
    1, 74, 3, 65, 7, 17, 5, 53, 4, 51, 8, 31, 0,  9, 2, 10, 6, 19, 
    8, 78, 6, 46, 0, 70, 3, 38, 2, 89, 5, 78, 7, 39, 1, 71, 4, 63, 
    5, 49, 8, 74, 1, 94, 6, 68, 3, 92, 0,  3, 4, 82, 7, 91, 2, 39, 
    7, 25, 5,  3, 1, 96, 8, 94, 4,  7, 0,  3, 6, 15, 2, 97, 3, 56, 
    0, 19, 1, 11, 5,  9, 4, 36, 8, 88, 6, 94, 2, 18, 3, 89, 7, 53, 
    8, 56, 1, 25, 4, 51, 7, 26, 5, 83, 2, 32, 0, 25, 3, 31, 6, 36, 
    3, 63, 1, 67, 7,  2, 5, 16, 6, 79, 2, 68, 8, 42, 0, 40, 4, 86, 
    7,  2, 4, 89, 2, 99, 0, 36, 6, 65, 8, 31, 3, 96, 1, 41, 5, 46, 
    8, 98, 1, 86, 3, 77, 6, 80, 5, 27, 0, 59, 7, 63, 2, 99, 4, 56
  };
  const int q0847[] = {
    9, 9, // Number of jobs and machines
    0, 94, 2, 42, 5, 14, 7,  9, 8, 71, 1, 22, 4, 71, 3, 59, 6, 88, 
    2,  4, 8, 96, 4, 92, 3,  9, 1, 12, 5,  9, 0, 36, 7, 76, 6, 52, 
    0, 43, 8, 71, 5, 10, 7, 65, 4, 31, 6, 60, 2, 43, 3, 92, 1, 38, 
    3, 48, 4, 54, 6, 47, 5, 38, 7, 82, 1, 22, 0, 27, 8, 47, 2, 32, 
    7, 85, 4, 69, 5, 63, 3, 72, 0, 76, 2, 95, 8, 91, 1,  7, 6, 96, 
    7, 99, 8, 15, 0, 12, 6, 28, 1, 44, 2,  9, 3,  6, 5, 57, 4, 56, 
    8, 39, 4, 31, 3, 72, 1, 62, 5, 20, 7, 73, 2, 82, 0, 89, 6, 96, 
    2, 22, 0,  9, 5, 38, 3, 87, 7, 36, 1,  9, 4, 83, 8, 55, 6, 55, 
    5, 29, 3, 11, 4, 18, 7,  7, 2, 28, 6, 59, 8, 60, 1, 99, 0,  3
  };
  const int q0848[] = {
    9, 9, // Number of jobs and machines
    6, 69, 5, 23, 7, 90, 0, 16, 8, 98, 2, 75, 4, 65, 1, 51, 3, 83, 
    0, 12, 8, 98, 5, 20, 4, 70, 3, 99, 1, 85, 2, 12, 6, 64, 7, 63, 
    3, 83, 8, 64, 6, 74, 0, 73, 2,  9, 4, 57, 5, 48, 7, 88, 1, 37, 
    6, 64, 8, 74, 4, 90, 2, 21, 0, 62, 3, 46, 7, 57, 5, 14, 1, 54, 
    1, 55, 7, 20, 2, 22, 0, 46, 5, 53, 6, 38, 8, 35, 4, 17, 3, 19, 
    2,  3, 7, 33, 6, 13, 0, 49, 8, 88, 4, 68, 1, 36, 5, 25, 3, 17, 
    4, 50, 7, 88, 3, 42, 1, 89, 2, 85, 0,  5, 6,  3, 5, 34, 8, 20, 
    2, 19, 8, 94, 4, 86, 7,  2, 6, 83, 0, 32, 1, 42, 5, 46, 3, 98, 
    6, 79, 0, 57, 3, 97, 1, 19, 7, 38, 8, 60, 4, 72, 5, 68, 2, 98
  };
  const int q0849[] = {
    9, 9, // Number of jobs and machines
    8, 49, 5, 69, 6, 85, 4, 70, 0, 50, 1, 65, 2, 94, 7, 45, 3, 88, 
    7, 38, 8, 98, 6, 11, 3,  3, 1, 97, 4, 45, 2, 32, 0, 93, 5, 78, 
    4, 47, 0,  5, 7, 30, 6, 64, 5, 51, 8, 46, 1, 46, 3, 12, 2, 94, 
    3, 17, 2, 39, 5,  7, 0, 32, 1, 97, 7, 92, 4, 48, 8, 81, 6, 56, 
    4, 21, 7, 12, 3, 98, 5, 17, 2, 38, 6, 30, 8, 35, 1, 98, 0, 30, 
    7, 15, 6, 49, 5,  2, 0, 26, 1, 14, 3, 76, 4, 28, 8, 70, 2, 23, 
    6, 75, 5, 61, 4, 96, 7,  1, 1, 80, 8, 67, 0, 80, 3, 69, 2, 10, 
    1, 17, 8,  8, 6, 71, 5, 26, 3, 43, 2, 21, 4,  6, 0, 39, 7, 37, 
    2, 22, 3, 36, 8, 81, 4, 91, 7, 49, 5, 62, 0, 83, 1, 47, 6, 21
  };
  const int q0850[] = {
    9, 9, // Number of jobs and machines
    4, 16, 0, 72, 3, 83, 5, 63, 1, 25, 7, 38, 6, 83, 2, 33, 8,  6, 
    4, 71, 6,  9, 7, 62, 8, 54, 5,  5, 0, 57, 2, 51, 1,  8, 3, 32, 
    7, 12, 8, 60, 5, 21, 1, 50, 6, 80, 2, 56, 0, 54, 3, 39, 4, 38, 
    8, 59, 7, 24, 1, 97, 0, 28, 4, 48, 6, 29, 3, 53, 2, 37, 5, 19, 
    0, 68, 5, 89, 7, 91, 8, 39, 4, 37, 3, 71, 2, 30, 6, 65, 1, 14, 
    7, 47, 4, 89, 8, 10, 0, 33, 2, 31, 1, 73, 5, 45, 6, 44, 3, 86, 
    4, 97, 7, 78, 6,  9, 1, 13, 3, 84, 2, 39, 5, 89, 0, 13, 8, 77, 
    6, 96, 3, 40, 2, 41, 7, 72, 8, 46, 5, 86, 4, 95, 0, 54, 1,  7, 
    3, 10, 4, 13, 1, 44, 2, 37, 5, 36, 8, 63, 7, 17, 0, 58, 6, 80
  };
  const int q0851[] = {
    9, 9, // Number of jobs and machines
    7,  9, 5, 70, 8, 42, 3, 54, 6, 96, 2, 22, 0, 73, 1, 57, 4, 71, 
    8, 91, 0, 38, 6, 89, 4, 30, 3, 10, 7, 77, 5, 29, 1, 98, 2, 31, 
    5,  3, 8, 85, 2, 54, 4, 85, 6, 27, 0, 61, 1, 97, 3, 81, 7, 64, 
    2, 78, 5,  1, 6, 71, 7, 37, 3, 88, 0, 22, 1, 97, 4, 73, 8, 53, 
    1, 29, 4, 58, 3, 76, 6, 90, 5, 20, 8, 18, 7, 26, 0, 92, 2, 52, 
    2, 23, 0, 47, 6, 67, 5, 38, 7, 16, 8, 82, 3, 72, 4, 81, 1, 85, 
    8, 51, 1, 98, 5, 57, 0, 41, 4, 36, 6, 87, 2, 44, 3, 15, 7, 92, 
    4, 52, 6, 48, 2, 63, 3,  5, 7, 89, 5, 74, 0, 14, 8, 62, 1, 75, 
    8, 35, 6, 91, 1,  2, 3,  1, 4, 22, 5, 69, 2,  1, 0, 52, 7, 64
  };
  const int q0852[] = {
    9, 9, // Number of jobs and machines
    7, 90, 6, 19, 0, 19, 3, 31, 5, 43, 8, 87, 1, 14, 2, 48, 4, 26, 
    1, 28, 6, 51, 0, 23, 2, 86, 5, 80, 4,  1, 8, 40, 7, 82, 3, 16, 
    0, 33, 6, 43, 1, 34, 8,  5, 4, 95, 3, 50, 5, 98, 2,  9, 7, 25, 
    8, 61, 0, 72, 5, 61, 4, 80, 3, 86, 7, 63, 2, 92, 1, 42, 6, 71, 
    0, 11, 1, 87, 5, 38, 4,  5, 7, 79, 8, 31, 2, 42, 3, 16, 6, 25, 
    2,  4, 8, 66, 7, 32, 6, 83, 4, 54, 0,  2, 3, 40, 5, 10, 1, 67, 
    4, 66, 7, 98, 5, 92, 6, 27, 3, 80, 1, 33, 8, 91, 0, 40, 2, 19, 
    3, 32, 4, 66, 0, 98, 5, 70, 7, 47, 2, 61, 6,  1, 1, 90, 8, 86, 
    3, 70, 6, 83, 1, 51, 4, 14, 0,  1, 7, 36, 8, 99, 5, 84, 2, 38
  };
  const int q0853[] = {
    9, 9, // Number of jobs and machines
    0, 30, 8,  3, 5, 28, 3, 31, 2, 91, 6, 61, 7, 83, 4, 73, 1, 53, 
    3,  2, 1, 50, 5,  7, 8, 71, 0, 14, 6, 59, 4, 82, 7, 30, 2, 59, 
    3,  5, 7, 70, 0, 94, 5, 60, 2, 47, 1, 84, 4, 86, 8, 41, 6, 46, 
    8, 11, 3, 31, 6,  2, 4, 23, 2,  6, 0, 24, 7, 85, 5, 13, 1,  4, 
    6, 57, 7, 87, 1, 75, 5, 59, 4, 94, 0,  2, 8,  6, 3, 44, 2,  7, 
    8, 71, 4, 71, 5, 75, 1, 25, 3, 69, 0, 39, 2, 25, 6, 44, 7, 53, 
    5, 50, 0, 36, 2, 64, 1, 78, 8, 32, 3, 11, 6, 75, 7, 47, 4, 44, 
    7, 17, 2, 18, 1, 40, 6, 52, 4, 33, 3, 93, 0, 35, 5, 27, 8, 80, 
    6, 85, 0, 97, 3, 45, 8, 24, 7,  5, 2,  7, 1, 38, 5, 26, 4, 45
  };
  const int q0854[] = {
    9, 9, // Number of jobs and machines
    5, 56, 3, 58, 1, 22, 0, 23, 8, 13, 6, 86, 2,  2, 4, 57, 7, 45, 
    6, 16, 5,  8, 4, 53, 2, 76, 0, 30, 3,  6, 7, 95, 1, 43, 8, 13, 
    6, 15, 1, 89, 8, 12, 3, 34, 5, 23, 0, 14, 7, 22, 2, 64, 4, 29, 
    6, 94, 4, 73, 7, 16, 0, 72, 2, 45, 8, 44, 1, 41, 3, 10, 5, 72, 
    8, 40, 5, 16, 4, 81, 7, 34, 1, 70, 0,  2, 3, 64, 2, 63, 6, 66, 
    3, 61, 7, 74, 4, 63, 8, 29, 6, 27, 1, 40, 5, 64, 0, 57, 2, 88, 
    4, 52, 8, 13, 1, 74, 6, 79, 3, 63, 2, 76, 5,  6, 7, 85, 0, 13, 
    5, 73, 2, 49, 4, 63, 7, 32, 1, 40, 0, 28, 3, 22, 8, 95, 6, 50, 
    0,  5, 1, 60, 5,  6, 4, 74, 3, 22, 2,  2, 8, 80, 6, 61, 7, 58
  };
  const int q0855[] = {
    9, 9, // Number of jobs and machines
    6, 82, 3, 44, 0, 68, 2,  3, 5, 90, 7, 11, 1, 39, 4, 55, 8, 11, 
    7, 91, 8, 83, 4, 56, 6, 44, 5,  9, 0, 41, 1, 79, 2, 69, 3, 22, 
    6,  5, 5, 39, 7, 68, 8, 64, 3, 57, 1,  1, 0, 92, 4, 52, 2, 45, 
    5, 25, 8, 28, 6, 58, 0, 44, 1, 66, 3, 98, 7, 97, 2, 22, 4, 45, 
    1, 11, 4, 90, 7, 96, 0,  4, 2,  7, 6, 80, 8, 27, 5, 82, 3, 17, 
    2, 70, 1,  1, 5, 78, 0, 27, 3, 25, 8, 58, 7, 25, 6,  4, 4, 84, 
    4, 70, 3, 66, 1,  9, 2, 54, 6, 34, 0, 38, 5, 77, 8, 62, 7, 91, 
    2, 66, 6,  5, 7, 43, 4, 51, 0, 13, 8, 76, 3, 62, 5, 37, 1, 39, 
    1, 76, 7, 28, 3, 10, 8, 73, 6, 49, 2, 28, 5, 59, 4, 75, 0, 17
  };
  const int q0856[] = {
    9, 9, // Number of jobs and machines
    1, 42, 0,  2, 5, 95, 6, 96, 4, 92, 7, 72, 2, 62, 8, 59, 3, 21, 
    1, 46, 4, 93, 5, 20, 6, 77, 8, 74, 3, 27, 2, 18, 7, 15, 0, 92, 
    8, 95, 2, 88, 5, 76, 4, 45, 3, 73, 7, 22, 1, 10, 0, 73, 6, 90, 
    4, 95, 0, 16, 1, 19, 3, 72, 2, 71, 7, 17, 5,  6, 8,  4, 6, 98, 
    1, 47, 4, 89, 5, 71, 2, 31, 8, 23, 0, 56, 7, 63, 3, 61, 6,  7, 
    3, 83, 5, 95, 8, 75, 4, 63, 2, 42, 0, 65, 1,  6, 6,  7, 7, 94, 
    6, 52, 0, 74, 2, 47, 5,  3, 7, 79, 8, 43, 4, 77, 1, 55, 3, 31, 
    5, 60, 2, 66, 6, 37, 0, 61, 7, 68, 1, 78, 3, 30, 8, 42, 4, 64, 
    5, 66, 3, 64, 8, 51, 1, 11, 7, 65, 6, 88, 0, 57, 2, 27, 4, 56
  };
  const int q0857[] = {
    9, 9, // Number of jobs and machines
    6, 25, 7, 75, 4, 78, 1, 25, 0, 26, 5, 41, 2, 57, 3, 71, 8, 26, 
    4, 69, 6, 67, 0,  5, 7, 62, 5, 55, 8, 58, 1, 98, 3, 31, 2, 21, 
    1, 63, 8, 40, 5, 11, 6, 19, 3, 86, 2, 15, 4, 93, 7, 75, 0, 42, 
    7, 96, 1, 97, 8, 28, 5, 31, 6, 36, 0, 66, 4, 32, 3, 88, 2, 45, 
    4,  4, 5, 46, 7, 78, 2, 17, 3, 26, 8, 25, 0, 74, 6, 93, 1, 17, 
    4, 98, 8, 59, 7, 35, 1, 57, 6, 89, 0, 75, 3, 71, 2, 44, 5, 41, 
    3,  1, 2, 50, 5, 44, 6, 38, 4, 60, 0, 36, 7, 56, 8, 41, 1, 13, 
    1, 19, 4, 85, 2, 52, 3, 92, 5, 73, 0, 88, 7, 30, 6, 81, 8, 17, 
    4, 37, 3, 65, 8, 94, 6, 89, 5, 53, 2, 63, 0, 10, 1,  8, 7, 23
  };
  const int q0858[] = {
    9, 9, // Number of jobs and machines
    5, 10, 3, 14, 8, 71, 1, 51, 0, 29, 2, 11, 7, 85, 6, 92, 4, 73, 
    0, 65, 2,  5, 4, 12, 3, 14, 6, 76, 7, 55, 8, 87, 1,  4, 5, 86, 
    6, 34, 7,  7, 4, 52, 2, 32, 1, 34, 8, 13, 0, 91, 3, 79, 5, 50, 
    5,  9, 8, 51, 6, 21, 4, 84, 2, 32, 7, 31, 3, 97, 0, 79, 1,  3, 
    3, 64, 2, 47, 0, 80, 7, 81, 5, 78, 8, 98, 1, 99, 6, 59, 4, 82, 
    4, 37, 3, 80, 1, 53, 0, 96, 5, 61, 2, 24, 8, 17, 6, 83, 7, 83, 
    3, 33, 2, 79, 0, 43, 4, 44, 8, 65, 5, 77, 1, 30, 6, 11, 7, 74, 
    7, 99, 8, 70, 2,  1, 3, 33, 0,  5, 6, 52, 4, 41, 5,  3, 1, 22, 
    2, 85, 4, 99, 7, 60, 6, 12, 5,  7, 1, 41, 8, 31, 0, 51, 3, 37
  };
  const int q0859[] = {
    9, 9, // Number of jobs and machines
    2, 90, 4, 47, 7, 59, 3, 43, 1, 90, 6, 59, 5, 85, 0, 86, 8, 10, 
    6, 22, 2, 67, 3, 37, 7,  9, 8, 39, 1,  6, 4, 47, 0,  4, 5, 57, 
    2, 90, 4, 99, 3, 28, 7, 24, 0, 54, 8, 31, 6, 93, 5, 99, 1, 16, 
    6, 24, 2, 50, 0, 17, 7, 82, 8, 25, 4, 69, 3, 42, 1, 75, 5, 81, 
    0, 37, 1, 81, 8, 29, 4, 76, 7, 10, 2,  9, 6, 28, 5, 18, 3, 81, 
    2, 53, 0, 45, 3, 34, 7, 97, 6,  1, 1, 71, 8, 96, 5, 89, 4, 41, 
    0,  1, 2, 39, 5, 81, 7, 43, 4, 40, 1, 39, 3, 29, 8, 67, 6, 25, 
    2, 80, 6, 95, 7, 45, 3, 19, 1, 73, 8, 19, 0, 49, 4, 92, 5, 86, 
    7, 31, 0, 58, 4, 87, 2, 60, 8, 36, 3, 22, 5, 60, 6, 84, 1, 38
  };
  const int q0860[] = {
    9, 9, // Number of jobs and machines
    6, 43, 0, 10, 2, 60, 8, 69, 7, 37, 5, 74, 4, 56, 3, 83, 1, 21, 
    3, 40, 2,  6, 5, 16, 0, 87, 6, 40, 7, 23, 4, 66, 1, 17, 8, 94, 
    4, 84, 1, 67, 8, 77, 3, 86, 5, 94, 7, 79, 6, 38, 2, 51, 0, 70, 
    0, 19, 6, 88, 5, 59, 2, 75, 1, 60, 4, 65, 3,  2, 7, 75, 8, 33, 
    2, 12, 3,  1, 6, 51, 0, 82, 1,  1, 7, 47, 8, 35, 5, 61, 4, 15, 
    2, 58, 4, 43, 1, 63, 3, 39, 7, 79, 6, 46, 0, 17, 8,  6, 5, 44, 
    7, 82, 5, 41, 2, 53, 4, 99, 8, 66, 0, 70, 6,  8, 1, 17, 3, 49, 
    1, 17, 5,  4, 8,  7, 4, 75, 7, 46, 6,  5, 2,  9, 3,  1, 0, 89, 
    6, 86, 8, 44, 2, 50, 0, 66, 7, 97, 4, 91, 3, 16, 1, 64, 5, 63
  };
  const int q0861[] = {
    9, 9, // Number of jobs and machines
    4, 82, 8, 88, 1, 57, 3, 45, 7, 46, 2, 83, 0, 48, 6, 70, 5, 53, 
    2, 81, 0, 58, 4, 86, 7, 37, 5,  1, 8,  1, 1, 62, 3, 62, 6, 79, 
    5, 67, 8,  9, 4, 97, 1, 74, 3, 64, 6, 34, 2, 26, 7, 68, 0, 12, 
    6, 80, 3, 59, 4, 33, 1, 42, 7, 45, 0, 55, 8, 95, 5, 50, 2,  4, 
    2, 57, 5, 10, 3, 48, 8, 54, 1, 76, 4, 25, 7, 46, 0, 31, 6, 72, 
    3, 40, 0, 81, 6, 74, 8, 93, 4, 64, 5, 72, 1, 12, 7, 17, 2, 72, 
    4, 61, 0,  9, 7, 20, 6, 65, 8, 97, 2, 23, 1, 42, 5, 12, 3, 48, 
    2, 12, 6, 88, 4, 20, 5, 56, 8, 82, 0, 76, 1, 24, 3, 36, 7, 17, 
    1, 77, 4, 56, 5, 45, 8, 99, 2, 81, 6, 88, 7, 25, 3, 94, 0, 45
  };
  const int q0862[] = {
    9, 9, // Number of jobs and machines
    5, 34, 3, 12, 4,  5, 2, 16, 6, 72, 0, 40, 7, 22, 1, 63, 8, 99, 
    7, 11, 0, 38, 5, 92, 4, 21, 2, 41, 6,  5, 1, 19, 3, 13, 8, 51, 
    8, 25, 1, 28, 0, 55, 7, 58, 3, 71, 5, 66, 4, 34, 2, 65, 6, 38, 
    3, 13, 7, 39, 6, 91, 2,  9, 0, 15, 5, 17, 8, 17, 4, 25, 1, 43, 
    2, 44, 3, 76, 6, 57, 7, 48, 4, 14, 1, 20, 0, 92, 8, 20, 5, 77, 
    7, 68, 1, 81, 0, 46, 5, 99, 8, 54, 4, 80, 3, 51, 6, 78, 2, 22, 
    7, 31, 8, 24, 6, 28, 4, 11, 5, 42, 0, 47, 3, 14, 2, 66, 1, 90, 
    3, 71, 0, 61, 1,  6, 7, 15, 8,  3, 4, 44, 2, 44, 6, 56, 5, 58, 
    4, 86, 1, 18, 8,  3, 3,  4, 0, 97, 6, 31, 7, 47, 2, 22, 5, 60
  };
  const int q0863[] = {
    9, 9, // Number of jobs and machines
    4, 46, 1, 39, 7, 33, 5, 86, 0, 71, 2, 20, 3, 77, 8, 21, 6, 50, 
    1,  6, 2, 38, 5, 34, 4,  5, 8, 67, 3,  4, 7, 81, 6, 99, 0, 76, 
    1, 98, 4, 17, 5, 72, 8, 10, 0, 60, 3, 83, 6, 36, 7, 52, 2, 84, 
    5, 30, 0,  1, 1, 39, 6, 98, 8, 15, 7, 97, 4, 58, 2, 99, 3,  3, 
    5, 36, 2, 81, 0, 95, 4, 91, 6, 55, 8,  4, 1, 83, 3, 67, 7, 94, 
    7,  7, 1, 41, 6, 18, 0, 66, 5, 51, 8, 60, 4, 88, 2, 58, 3, 42, 
    0, 34, 8, 66, 3, 55, 5,  5, 2, 74, 6, 11, 4, 59, 7, 81, 1, 94, 
    4, 22, 7, 74, 6, 73, 0, 22, 8, 25, 1, 63, 2, 79, 5, 83, 3, 29, 
    0, 85, 2, 72, 1, 62, 4,  2, 3, 58, 8, 93, 6, 91, 5, 64, 7, 19
  };
  const int q0864[] = {
    9, 9, // Number of jobs and machines
    7, 98, 3, 38, 4, 29, 8, 80, 5, 52, 6, 63, 2, 33, 1, 60, 0, 68, 
    6, 91, 8, 63, 3, 74, 7, 26, 4,  9, 1, 51, 5, 15, 2, 40, 0, 81, 
    6, 78, 7, 54, 0, 61, 1, 26, 5, 53, 4,  8, 8, 17, 2, 77, 3, 25, 
    5, 32, 8, 69, 2, 72, 4, 43, 6,  8, 1, 11, 7, 32, 3, 32, 0, 54, 
    3, 85, 7, 45, 4, 94, 6, 56, 8, 95, 1, 67, 5, 90, 2, 48, 0, 66, 
    0, 23, 1,  2, 8, 49, 4, 10, 7, 34, 3, 47, 2, 35, 5, 85, 6, 54, 
    3, 99, 8, 60, 7, 66, 1, 44, 6, 90, 0, 33, 2, 26, 5, 27, 4, 37, 
    6, 52, 3, 34, 0, 21, 2, 69, 7, 59, 1, 31, 5,  7, 8, 20, 4, 25, 
    5, 29, 2, 85, 0, 11, 4, 65, 1, 11, 7, 35, 3, 60, 6, 43, 8, 66
  };
  const int q0865[] = {
    9, 9, // Number of jobs and machines
    7, 91, 2, 48, 8,  1, 5, 36, 6,  2, 0, 84, 1, 63, 4, 29, 3, 91, 
    6, 58, 7, 97, 4, 37, 0, 30, 3, 40, 1, 27, 5, 19, 8, 73, 2, 23, 
    4, 81, 3, 35, 6, 17, 2, 28, 5, 98, 7, 78, 8, 14, 0, 59, 1, 49, 
    6, 96, 7, 65, 2, 14, 4, 24, 5, 59, 8, 14, 0, 74, 3, 11, 1, 31, 
    7, 72, 0, 43, 6, 11, 5, 66, 2, 50, 1, 96, 3, 88, 8,  7, 4,  7, 
    1, 70, 0, 23, 5, 84, 8, 27, 2, 81, 6, 71, 7, 39, 3,  3, 4,  2, 
    3, 75, 8, 90, 4, 75, 0, 27, 6, 92, 2,  9, 7, 22, 1,  1, 5, 56, 
    4,  8, 2, 32, 8,  5, 6, 63, 5, 87, 0,  1, 3, 41, 7, 85, 1, 66, 
    2, 62, 8, 40, 0, 20, 3, 85, 6, 93, 5,  2, 1, 67, 7, 58, 4, 23
  };
  const int q0866[] = {
    9, 9, // Number of jobs and machines
    0, 30, 2,  4, 4, 30, 3, 94, 7, 30, 8, 56, 1, 36, 6, 65, 5, 66, 
    5, 26, 7, 57, 3, 13, 1, 89, 6, 58, 0, 76, 8, 63, 2, 47, 4, 47, 
    7, 51, 3, 30, 2, 69, 4, 72, 5, 77, 1, 85, 6, 56, 0, 88, 8,  9, 
    3, 67, 5, 63, 4, 74, 0, 69, 6, 61, 1, 63, 7, 57, 2, 58, 8,  3, 
    6, 20, 0, 85, 3, 79, 7, 78, 2,  7, 4, 32, 1, 52, 8, 28, 5, 60, 
    8, 26, 2, 59, 6, 29, 3, 85, 4, 97, 1, 93, 7, 63, 0, 64, 5, 69, 
    8, 10, 0, 65, 6, 28, 7, 65, 4, 72, 2, 97, 1, 83, 3, 80, 5, 26, 
    2, 98, 1, 81, 0, 26, 8, 39, 3, 70, 5, 69, 7, 48, 4, 94, 6, 15, 
    8, 66, 7, 15, 6, 74, 2, 80, 0, 42, 3, 44, 5, 27, 4, 78, 1, 59
  };
  const int q0867[] = {
    9, 9, // Number of jobs and machines
    2, 89, 4, 34, 0, 93, 6, 49, 5, 61, 3, 45, 8, 17, 1, 71, 7, 30, 
    8, 43, 6, 54, 0, 40, 5, 23, 7, 49, 1, 78, 2, 71, 3, 56, 4, 56, 
    4, 91, 6, 31, 0,  1, 5, 24, 1, 20, 2, 70, 7, 41, 8, 32, 3, 92, 
    0, 66, 6, 42, 4, 95, 7, 16, 1, 54, 3, 28, 2, 78, 8, 15, 5, 39, 
    5, 55, 7, 21, 8, 51, 3, 75, 0, 83, 1, 41, 4, 43, 6, 91, 2, 13, 
    2, 82, 1, 55, 5, 53, 8, 38, 0,  2, 7, 46, 4, 22, 6, 56, 3, 16, 
    3,  7, 8, 62, 4, 59, 2, 58, 6, 86, 7, 24, 5, 97, 0, 78, 1, 90, 
    5, 54, 4, 53, 0, 63, 6, 87, 7,  1, 2, 88, 8, 65, 3, 88, 1, 78, 
    4, 49, 3,  6, 5, 85, 8, 47, 2, 83, 0, 69, 1, 75, 6, 58, 7, 74
  };
  const int q0868[] = {
    9, 9, // Number of jobs and machines
    5, 36, 0, 91, 3, 75, 8,  2, 4, 72, 1,  9, 2, 16, 6,  2, 7, 46, 
    3, 95, 8, 19, 6, 26, 5, 47, 2, 16, 4, 57, 0,  8, 7, 11, 1, 17, 
    5, 10, 4, 89, 2, 70, 3, 40, 7, 93, 0, 91, 8,  2, 6, 14, 1, 10, 
    1, 46, 3,  8, 5, 13, 0, 94, 6, 69, 2, 61, 8, 19, 4, 50, 7, 43, 
    7, 99, 0, 39, 3, 90, 2, 19, 8, 30, 1, 63, 5, 35, 4, 97, 6,  2, 
    4, 93, 0, 48, 2, 70, 1, 89, 7, 47, 3, 88, 6, 54, 5, 53, 8,  9, 
    4, 82, 8, 74, 3, 37, 7, 88, 1, 83, 5, 41, 2, 52, 6,  6, 0, 71, 
    3, 17, 6, 78, 7,  7, 5, 33, 1, 95, 0, 97, 4, 50, 8, 10, 2, 89, 
    7,  1, 5, 15, 3, 33, 8, 57, 1, 43, 0, 40, 6, 88, 2, 39, 4, 47
  };
  const int q0869[] = {
    9, 9, // Number of jobs and machines
    6, 45, 1, 10, 8, 25, 5, 26, 7, 42, 0, 65, 4, 36, 2, 69, 3, 55, 
    4,  3, 5, 56, 1, 81, 8, 31, 7, 13, 6, 29, 3,  7, 2, 32, 0, 38, 
    6, 30, 4, 40, 5, 31, 3, 18, 8,  4, 0, 29, 2, 47, 1, 23, 7, 37, 
    4, 90, 5, 98, 7, 64, 0, 42, 6,  5, 3, 14, 2, 18, 1, 44, 8,  9, 
    6, 18, 2, 22, 1, 42, 4, 30, 7, 34, 0, 72, 8,  5, 5, 80, 3, 22, 
    1, 35, 2, 61, 3, 33, 0, 79, 4, 76, 8, 51, 5, 72, 7, 27, 6, 31, 
    0, 40, 3, 55, 8, 46, 4, 51, 5, 41, 7, 38, 6, 57, 2, 83, 1, 93, 
    3, 53, 7, 63, 6, 32, 8, 16, 4, 11, 0, 36, 1, 65, 2, 18, 5, 61, 
    7, 60, 2,  4, 1, 90, 5, 39, 3,  9, 6, 84, 8, 31, 0, 84, 4, 32
  };
  const int q0870[] = {
    9, 9, // Number of jobs and machines
    8, 44, 0,  1, 3, 66, 2, 96, 6, 74, 1, 66, 4, 91, 7, 60, 5, 39, 
    3, 75, 6, 40, 7, 34, 8, 91, 0, 97, 2,  5, 4, 49, 1, 96, 5, 37, 
    6, 43, 8, 85, 1, 71, 2, 14, 5, 20, 7, 45, 0, 49, 4, 31, 3, 20, 
    6, 97, 7, 13, 0, 66, 1, 89, 3, 68, 8, 14, 4, 97, 2, 80, 5, 20, 
    5, 14, 7, 73, 2,  2, 0, 22, 3, 98, 4, 79, 6, 68, 1,  6, 8, 50, 
    3, 80, 4, 19, 5, 98, 1,  6, 2, 81, 7, 55, 6, 96, 0, 44, 8, 59, 
    0,  8, 6, 75, 5, 30, 8, 61, 7, 63, 3, 82, 2, 99, 4, 58, 1, 63, 
    0, 30, 2, 65, 1,  9, 8, 77, 7, 20, 3, 12, 6,  8, 4, 66, 5, 52, 
    4, 15, 7, 76, 8, 53, 0, 28, 3,  2, 2, 61, 1,  6, 6, 94, 5, 14
  };
  const int q0871[] = {
    9, 9, // Number of jobs and machines
    1, 37, 2, 35, 5, 32, 4, 13, 6, 14, 7, 72, 0, 91, 3, 61, 8, 57, 
    1, 32, 4, 89, 6, 53, 3,  7, 7, 77, 8, 54, 0, 46, 2, 92, 5, 92, 
    8, 69, 5, 32, 3,  8, 6, 89, 0, 44, 7, 26, 2, 49, 4, 20, 1, 78, 
    7,  3, 1, 60, 6, 11, 4, 68, 5, 67, 2, 78, 8, 16, 0, 37, 3, 98, 
    8, 97, 7, 48, 6,  3, 2, 31, 0, 85, 1, 38, 4, 70, 5, 33, 3, 60, 
    1, 78, 8, 10, 2, 98, 4, 56, 7, 36, 0, 51, 3, 64, 5, 48, 6, 53, 
    1, 27, 8, 94, 7, 74, 3, 27, 5, 66, 4, 98, 0, 65, 2, 53, 6, 56, 
    6, 43, 7,  7, 3, 20, 4, 76, 2, 61, 5,  2, 1, 92, 8, 45, 0, 36, 
    2, 12, 1,  8, 6,  7, 0, 16, 4, 50, 5,  6, 8, 96, 7, 58, 3, 43
  };
  const int q0872[] = {
    9, 9, // Number of jobs and machines
    8, 84, 0, 97, 6, 77, 4, 39, 7, 49, 3, 13, 1, 99, 5, 71, 2, 67, 
    4, 42, 2, 59, 6,  1, 5, 18, 1, 30, 8, 80, 3, 67, 0,  7, 7, 57, 
    6, 47, 5, 69, 8, 71, 3,  4, 4, 58, 2, 32, 1, 58, 7, 11, 0, 38, 
    7, 40, 5, 38, 8, 35, 4, 24, 2, 83, 3, 33, 1, 30, 6, 15, 0, 13, 
    1, 10, 6, 37, 4, 74, 7, 86, 0, 68, 8, 25, 3, 22, 5, 51, 2, 86, 
    4, 15, 5, 43, 0, 60, 2, 98, 1, 11, 6, 43, 3, 67, 7, 59, 8, 90, 
    4, 63, 7, 64, 2, 49, 8, 44, 6, 28, 3, 26, 0, 41, 1, 21, 5, 21, 
    5, 19, 7, 79, 3, 91, 8, 19, 6, 12, 0, 13, 2, 15, 4, 63, 1, 90, 
    1, 16, 3, 22, 0, 91, 6, 41, 7, 26, 2, 11, 8, 37, 4, 57, 5, 19
  };
  const int q0873[] = {
    9, 9, // Number of jobs and machines
    3, 38, 6, 20, 7, 18, 5, 96, 4, 92, 8,  5, 1, 41, 0, 55, 2, 27, 
    7, 29, 1, 54, 3, 74, 8, 47, 2, 65, 5, 54, 4, 28, 0, 37, 6, 68, 
    4, 73, 8, 94, 1, 99, 2, 34, 5, 97, 6, 88, 0, 76, 7, 51, 3, 17, 
    7, 31, 0, 11, 8, 58, 2,  6, 1, 69, 5, 79, 3,  6, 4, 44, 6, 90, 
    6, 60, 2, 39, 5, 91, 1, 38, 4, 73, 8, 77, 0, 27, 7,  9, 3, 58, 
    5, 23, 3,  8, 6, 75, 2, 72, 0, 92, 1, 94, 8, 63, 7, 62, 4, 70, 
    8, 43, 1, 67, 0, 58, 2,  7, 7, 13, 3, 34, 5, 20, 4, 77, 6, 22, 
    0, 79, 7, 95, 5, 64, 1, 99, 6, 61, 2, 42, 3, 73, 8, 45, 4, 55, 
    7, 59, 4, 49, 6, 41, 8, 88, 2, 88, 5, 14, 3, 37, 0, 72, 1, 62
  };
  const int q0874[] = {
    9, 9, // Number of jobs and machines
    4, 36, 1, 16, 2, 51, 5, 90, 7, 54, 3, 96, 6, 32, 8,  2, 0, 84, 
    8,  1, 7, 28, 4, 80, 1, 70, 6, 52, 0, 61, 5, 34, 2, 99, 3, 38, 
    3,  7, 5, 97, 1, 51, 4, 68, 6, 50, 0, 91, 7, 52, 2, 39, 8, 32, 
    1, 74, 0, 50, 3, 76, 4, 79, 8, 15, 7, 52, 5, 84, 6, 73, 2, 49, 
    4, 66, 5,  2, 8, 90, 7, 18, 2, 63, 0, 42, 3, 33, 6, 40, 1, 58, 
    0,  4, 8,  6, 3, 21, 1, 28, 7, 74, 5, 55, 2, 83, 4, 16, 6, 90, 
    2, 51, 8, 94, 6, 34, 3, 70, 0, 83, 4, 66, 5, 77, 1, 32, 7, 55, 
    3, 60, 1, 33, 6,  5, 5, 97, 7, 47, 8, 90, 4, 32, 2, 84, 0, 10, 
    7, 35, 0, 53, 2, 62, 3, 22, 4,  8, 5, 74, 6, 63, 1,  4, 8,  9
  };
  const int q0875[] = {
    9, 9, // Number of jobs and machines
    5, 43, 4, 13, 8, 82, 1, 81, 2,  5, 6, 66, 7, 70, 3, 74, 0, 72, 
    5, 69, 6, 53, 8, 32, 1, 30, 0, 61, 3, 35, 2, 49, 7, 72, 4, 74, 
    1, 63, 8, 66, 2, 76, 3, 95, 0, 56, 6, 91, 7, 83, 4, 64, 5, 47, 
    2, 59, 3, 48, 7, 15, 6, 49, 1, 95, 4, 68, 0, 92, 8, 85, 5, 66, 
    2, 45, 8, 10, 0, 39, 1,  9, 5, 39, 7, 31, 4, 58, 6, 46, 3, 69, 
    2, 70, 5, 47, 7, 38, 0, 95, 8, 35, 3, 89, 1, 30, 6, 67, 4, 13, 
    2,  2, 3, 76, 8, 90, 4, 73, 6, 60, 7, 97, 1, 90, 5, 38, 0, 63, 
    0, 32, 2, 39, 6, 48, 3, 94, 7, 62, 5, 30, 1,  5, 4, 73, 8,  1, 
    2, 34, 1, 86, 5, 72, 8, 67, 4, 45, 6, 96, 0, 17, 7, 62, 3, 50
  };
  const int q0876[] = {
    9, 9, // Number of jobs and machines
    6, 36, 1, 13, 5, 40, 2, 82, 4, 23, 0, 45, 8, 58, 3, 15, 7, 86, 
    0, 30, 7, 60, 8,  9, 5, 29, 2, 30, 1, 83, 3, 98, 6, 42, 4,  6, 
    3,  1, 1, 29, 8, 61, 5, 72, 6, 59, 4, 97, 2, 40, 0, 59, 7, 53, 
    6, 93, 2, 42, 0, 97, 1, 24, 8, 72, 3, 83, 7, 80, 4, 42, 5,  5, 
    5, 77, 2, 15, 7, 90, 4, 73, 0,  6, 3, 95, 1, 74, 6, 99, 8, 88, 
    7, 58, 6, 47, 8, 73, 4,  8, 3, 35, 0, 73, 1, 82, 2, 65, 5, 74, 
    4, 94, 5, 27, 1, 50, 7, 14, 0, 79, 3, 65, 2, 86, 8, 35, 6, 21, 
    1, 29, 2, 67, 6, 53, 8, 56, 4, 25, 0, 86, 7, 16, 5, 41, 3, 78, 
    1, 22, 4,  8, 7, 82, 8, 59, 5, 41, 0, 68, 6, 71, 2, 52, 3, 43
  };
  const int q0877[] = {
    9, 9, // Number of jobs and machines
    8, 39, 4, 96, 6, 80, 0,  1, 5, 43, 2,  1, 1,  3, 7, 51, 3, 86, 
    6, 62, 5, 46, 0, 74, 8, 18, 7, 17, 2, 25, 1, 50, 4, 74, 3, 76, 
    2, 53, 8, 80, 3, 93, 5, 80, 6, 85, 1, 43, 0, 53, 7, 47, 4, 44, 
    8, 50, 5, 58, 0, 14, 6, 80, 2, 53, 1, 90, 3, 51, 7, 42, 4, 95, 
    5, 49, 1, 79, 3, 19, 4, 14, 2, 16, 6, 70, 7, 26, 8, 88, 0,  2, 
    3, 99, 2, 79, 7, 21, 6, 87, 5, 34, 1, 78, 4, 70, 0, 94, 8, 51, 
    0, 75, 8, 46, 1, 73, 5,  3, 7, 43, 2, 92, 6, 39, 4, 19, 3, 65, 
    1, 20, 2, 74, 4, 92, 3, 33, 8, 35, 7, 14, 0, 81, 5, 17, 6, 90, 
    7,  6, 8, 92, 0, 29, 5, 88, 2, 72, 3,  7, 6, 89, 1, 65, 4, 52
  };
  const int q0878[] = {
    9, 9, // Number of jobs and machines
    2, 46, 7, 75, 1, 95, 6, 48, 0, 71, 8, 52, 3,  8, 4, 44, 5,  8, 
    0, 11, 5, 90, 6, 20, 7, 10, 8, 95, 2, 72, 3, 87, 1, 25, 4, 59, 
    5, 78, 4, 46, 0, 95, 2, 26, 1, 59, 8, 48, 6, 15, 3, 48, 7, 88, 
    7, 76, 4, 82, 5, 59, 8, 70, 6, 77, 1, 76, 3, 78, 0, 10, 2, 54, 
    7, 61, 0, 71, 2, 30, 3, 60, 4, 13, 1, 82, 6, 87, 5, 81, 8, 55, 
    8, 87, 6, 30, 5, 63, 7, 33, 4, 10, 3, 85, 2, 82, 0, 82, 1,  6, 
    7, 81, 4, 62, 5, 56, 6, 21, 8, 67, 3, 12, 2, 61, 0, 34, 1, 55, 
    1, 24, 0,  8, 4, 83, 7, 44, 3, 56, 2, 42, 8,  3, 6, 23, 5, 90, 
    0, 82, 3, 58, 1, 47, 5, 98, 8, 90, 6, 53, 2, 93, 4, 40, 7, 90
  };
  const int q0879[] = {
    9, 9, // Number of jobs and machines
    3, 38, 4, 99, 7, 35, 5, 46, 2, 73, 0, 70, 6, 14, 8, 95, 1, 22, 
    6, 15, 2,  4, 8, 38, 1, 40, 7, 45, 5, 60, 3, 83, 0, 19, 4, 52, 
    7, 18, 6, 52, 2, 37, 1, 67, 4, 98, 3, 89, 8, 77, 5, 48, 0, 61, 
    5, 45, 1, 55, 3, 25, 2, 24, 0, 58, 8, 62, 4, 44, 7, 91, 6, 37, 
    4, 82, 1, 55, 2, 40, 7, 10, 6, 41, 8, 23, 5, 48, 3, 97, 0, 74, 
    3, 96, 0, 62, 1, 35, 6, 49, 2, 87, 4, 20, 8, 23, 7, 31, 5, 85, 
    2, 82, 1, 11, 0, 12, 7, 62, 8,  4, 6, 43, 5, 19, 4,  7, 3,  4, 
    6, 54, 4, 36, 5, 81, 8, 70, 3, 91, 1, 84, 2, 40, 7, 29, 0, 51, 
    8,  1, 5, 43, 3, 41, 7, 27, 4, 39, 0,  6, 6, 32, 2, 63, 1, 42
  };
  const int q0880[] = {
    9, 9, // Number of jobs and machines
    4, 39, 3, 87, 0, 97, 8, 62, 2, 72, 5,  8, 7, 89, 1, 67, 6, 70, 
    2, 13, 0, 54, 5, 13, 4, 16, 7, 19, 3, 74, 1, 55, 6, 80, 8, 74, 
    4, 93, 1, 31, 5, 92, 6, 18, 2, 80, 8, 30, 7, 76, 0,  3, 3, 84, 
    3, 11, 1, 95, 7, 93, 8, 44, 6, 65, 4, 35, 2, 42, 0, 11, 5, 75, 
    5,  6, 6,  8, 2, 50, 8, 90, 4, 53, 3, 83, 0, 32, 7, 24, 1, 27, 
    1, 80, 3, 52, 6, 27, 4, 64, 0, 79, 5, 78, 7,  4, 8, 10, 2,  9, 
    3, 89, 8, 92, 2, 95, 6, 68, 7, 54, 0, 72, 5, 14, 1, 99, 4, 56, 
    1, 55, 5, 43, 4, 74, 2, 44, 3, 53, 7, 41, 6, 69, 8, 56, 0, 54, 
    3, 61, 1, 11, 6, 50, 0, 31, 5, 22, 4, 50, 7, 72, 2, 68, 8, 30
  };
  const int q0881[] = {
    9, 9, // Number of jobs and machines
    6, 13, 0, 58, 3, 15, 8, 51, 7, 84, 2, 88, 1, 48, 5, 32, 4, 17, 
    7, 19, 5, 61, 2, 63, 1, 91, 4,  8, 0, 14, 8, 49, 6, 77, 3,  5, 
    1, 58, 2, 56, 7, 41, 6, 76, 0, 93, 5, 57, 3, 60, 8, 79, 4, 68, 
    3, 10, 5, 70, 2, 69, 6, 85, 4, 79, 7, 97, 8, 33, 0, 36, 1, 19, 
    8, 23, 5, 62, 4, 17, 2, 83, 3, 73, 0, 86, 6, 53, 7, 29, 1, 51, 
    1, 33, 8, 25, 3, 43, 4, 55, 0, 59, 6, 15, 2, 91, 5, 79, 7, 73, 
    3, 86, 1, 92, 4, 86, 6, 45, 7, 94, 2, 25, 5, 23, 0, 43, 8, 57, 
    0, 73, 8, 65, 6, 92, 5, 21, 1, 32, 7, 31, 4, 22, 3, 26, 2, 20, 
    5, 73, 1, 64, 8, 72, 6, 64, 4, 67, 3, 60, 0, 38, 7, 18, 2, 75
  };
  const int q0882[] = {
    9, 9, // Number of jobs and machines
    4, 75, 3, 16, 1, 53, 2, 12, 7, 48, 6, 15, 0, 67, 8, 84, 5, 42, 
    8, 21, 5, 68, 0, 49, 1, 81, 2, 75, 4, 73, 6, 57, 7, 68, 3,  2, 
    8, 49, 0,  4, 2, 33, 4, 51, 1, 85, 7, 47, 3, 96, 6, 11, 5, 95, 
    5, 73, 3, 73, 6, 48, 1, 79, 4, 39, 0, 16, 8, 12, 7, 31, 2, 31, 
    7, 21, 5, 29, 3, 98, 2, 28, 6, 11, 1, 10, 0, 81, 4, 43, 8, 31, 
    6, 45, 0, 73, 1, 87, 8, 89, 4, 16, 3, 81, 5, 87, 2, 13, 7, 19, 
    0, 28, 5, 74, 2, 69, 1, 28, 3, 13, 4, 85, 7, 76, 8, 74, 6, 84, 
    5,  2, 1, 23, 2, 24, 3, 26, 7,  6, 0, 47, 8, 24, 6, 57, 4, 34, 
    4, 94, 6, 11, 5, 68, 2, 17, 1, 68, 3, 71, 0, 45, 7, 41, 8, 46
  };
  const int q0883[] = {
    9, 9, // Number of jobs and machines
    5, 81, 7,  5, 0, 24, 2, 38, 1, 93, 3, 15, 6, 92, 8, 11, 4, 19, 
    7, 99, 2, 59, 1, 83, 0, 42, 6, 27, 3, 69, 5, 90, 8, 37, 4, 48, 
    4, 30, 6, 73, 7, 15, 3,  1, 0, 99, 1,  5, 5,  2, 8, 38, 2, 87, 
    4, 78, 0, 65, 2, 59, 6, 76, 3, 18, 7, 63, 8, 70, 5, 69, 1, 53, 
    6, 65, 0, 48, 1,  5, 7, 34, 8,  3, 3, 71, 4, 35, 5, 26, 2,  2, 
    2, 68, 4, 45, 1, 44, 0, 68, 5, 40, 7, 82, 6, 17, 8, 29, 3, 18, 
    8, 81, 5, 15, 7, 72, 1, 38, 3,  3, 2, 44, 0, 27, 4, 56, 6, 47, 
    8, 89, 2, 49, 4, 74, 6, 88, 7,  8, 0, 48, 3, 81, 1, 94, 5, 24, 
    2, 56, 6, 69, 8, 70, 3, 93, 7, 37, 5, 56, 0, 71, 4, 45, 1, 95
  };
  const int q0884[] = {
    9, 9, // Number of jobs and machines
    0,  9, 8, 18, 5,  8, 7, 79, 3, 13, 6, 23, 4, 34, 2, 13, 1, 55, 
    1, 35, 7, 13, 3,  9, 4,  6, 8, 44, 6, 82, 0, 23, 2, 76, 5, 24, 
    3, 96, 6, 40, 5, 81, 2, 63, 7, 66, 0, 34, 8, 32, 1, 75, 4, 30, 
    5, 60, 8, 17, 1, 93, 4, 60, 0, 16, 2, 71, 7, 24, 6, 69, 3, 32, 
    4, 53, 6, 14, 8, 33, 5, 91, 1, 22, 0, 22, 2, 93, 3, 85, 7, 12, 
    3, 67, 7, 32, 0, 19, 1, 36, 6, 57, 4, 51, 2, 91, 8, 57, 5, 85, 
    4, 21, 0, 32, 5,  2, 8, 17, 3, 21, 2, 89, 1, 38, 7, 35, 6, 96, 
    4, 33, 6, 89, 5, 22, 1, 40, 7, 83, 8,  2, 0, 49, 2, 40, 3, 70, 
    3,  8, 8, 74, 1, 27, 5, 63, 0, 95, 7, 62, 4,  2, 6, 69, 2, 60
  };
  const int q0885[] = {
    9, 9, // Number of jobs and machines
    7, 20, 2, 40, 8, 52, 6, 56, 5, 32, 3, 27, 0, 49, 4, 54, 1, 87, 
    1, 30, 0, 91, 2, 10, 3, 35, 6, 90, 8, 33, 7, 16, 5, 23, 4, 59, 
    8, 65, 5, 47, 0, 21, 1, 22, 7, 85, 6, 14, 2, 32, 3, 52, 4,  3, 
    6, 33, 3, 26, 8, 45, 1, 23, 7, 77, 4, 74, 5, 17, 2, 22, 0, 52, 
    8, 32, 3, 78, 5, 42, 2, 49, 7, 82, 1, 20, 4, 94, 6,  4, 0, 91, 
    0, 96, 5, 35, 7, 82, 4, 67, 8, 44, 3, 23, 6, 46, 1, 11, 2, 50, 
    1, 97, 0, 70, 8, 62, 5, 84, 4, 83, 3, 46, 7, 14, 2, 61, 6, 55, 
    8, 46, 7, 12, 6, 72, 4, 25, 0, 72, 2, 23, 1, 21, 5, 60, 3, 33, 
    2, 41, 5, 83, 4, 33, 3, 56, 0, 31, 8, 25, 6, 34, 7, 89, 1,  9
  };
  const int q0886[] = {
    9, 9, // Number of jobs and machines
    3, 95, 6, 75, 0, 72, 2, 26, 7, 86, 8, 23, 1, 18, 5, 47, 4, 47, 
    0, 12, 5,  2, 4, 28, 2, 99, 8, 28, 3, 60, 1, 44, 6, 10, 7, 45, 
    6, 26, 1, 48, 5, 37, 7, 41, 3, 93, 8, 44, 4, 97, 2, 73, 0,  8, 
    3,  2, 0, 76, 5, 86, 1, 24, 7, 90, 4, 58, 8, 53, 6, 59, 2,  8, 
    0, 54, 5,  1, 8, 10, 4, 19, 6, 34, 3,  5, 1, 57, 2,  4, 7, 84, 
    3, 90, 7,  6, 1, 11, 5, 17, 4,  6, 2, 94, 8, 26, 0, 51, 6,  8, 
    2, 40, 6, 45, 7, 82, 8, 47, 3, 49, 1,  9, 5, 21, 4, 39, 0, 99, 
    1, 65, 3, 60, 2,  6, 0, 30, 4, 56, 8, 54, 6, 58, 7, 44, 5, 49, 
    6, 36, 0, 62, 3, 40, 2, 23, 1, 10, 7, 77, 5, 95, 8, 13, 4, 34
  };
  const int q0887[] = {
    9, 9, // Number of jobs and machines
    4, 72, 0, 13, 6, 58, 5, 84, 8, 11, 2, 30, 1, 56, 7, 49, 3, 58, 
    2, 78, 8, 91, 5, 92, 3, 83, 1, 84, 0,  4, 6, 87, 7, 52, 4, 73, 
    2, 73, 5, 36, 8, 50, 3, 83, 6, 98, 1,  9, 7, 90, 4, 22, 0, 91, 
    7, 75, 4, 12, 6, 21, 1,  3, 0, 99, 8, 85, 5, 48, 2, 11, 3, 20, 
    6, 48, 3, 12, 2, 98, 8, 16, 0, 40, 7,  2, 5, 80, 1, 33, 4,  5, 
    8, 70, 1, 74, 5, 22, 4, 32, 3, 12, 6, 92, 0, 34, 2, 18, 7, 37, 
    7, 95, 0,  2, 6, 53, 8, 50, 2, 31, 3, 15, 1, 82, 5, 59, 4, 78, 
    6, 63, 1, 70, 5, 82, 7, 60, 8,  8, 0, 64, 2,  9, 3, 45, 4, 85, 
    3,  8, 7, 15, 8, 26, 2, 28, 0, 35, 4, 32, 1, 68, 6, 35, 5, 70
  };
  const int q0888[] = {
    9, 9, // Number of jobs and machines
    2, 13, 4, 30, 8, 44, 6, 86, 3, 43, 1, 42, 7, 95, 5, 10, 0, 29, 
    1, 21, 0, 26, 4, 78, 8, 36, 3, 64, 2,  6, 7, 16, 6, 41, 5, 15, 
    2, 75, 0,  4, 6, 94, 1, 78, 5, 95, 7, 46, 4, 52, 8, 54, 3, 86, 
    7, 96, 1, 58, 8, 84, 0, 13, 3, 28, 6, 98, 2, 48, 4, 77, 5, 32, 
    5, 12, 8, 66, 0,  7, 7, 16, 6, 40, 3, 89, 4,  2, 2, 78, 1, 91, 
    5, 53, 7, 77, 4,  4, 2, 66, 0, 41, 3, 49, 8, 50, 6, 81, 1, 97, 
    1, 13, 8, 64, 5, 43, 7, 55, 6,  2, 4, 67, 3, 31, 0, 50, 2, 33, 
    7,  9, 6, 35, 2, 52, 8, 21, 1, 88, 4, 77, 5, 33, 3,  2, 0, 77, 
    5, 54, 2,  7, 7, 56, 3, 83, 1, 66, 4, 15, 6,  3, 8, 56, 0, 21
  };
  const int q0889[] = {
    9, 9, // Number of jobs and machines
    1, 23, 0, 18, 5, 41, 2,  6, 8, 72, 7, 63, 3, 10, 6, 47, 4, 61, 
    8, 32, 4, 64, 2, 64, 7, 43, 0, 81, 3, 64, 1,  1, 5, 14, 6, 47, 
    3, 25, 8, 21, 2, 92, 0, 99, 1, 75, 5, 70, 4, 63, 6, 71, 7, 11, 
    6, 26, 3, 36, 5, 40, 8, 12, 2, 54, 0, 26, 7, 12, 4, 17, 1, 16, 
    0, 82, 7,  4, 3,  9, 1, 12, 8, 27, 4, 39, 2, 53, 6, 27, 5, 11, 
    3, 90, 7, 31, 0, 10, 8, 60, 6, 88, 4, 87, 1, 73, 5, 59, 2, 23, 
    0, 35, 1, 20, 5, 90, 4, 42, 8, 21, 3, 42, 6, 77, 2, 17, 7, 50, 
    5, 10, 2, 62, 8, 52, 7, 68, 1,  3, 0, 42, 3,  7, 6, 52, 4,  6, 
    2, 33, 3, 92, 5, 53, 6, 25, 1, 33, 0, 78, 7, 67, 4, 82, 8, 56
  };
  const int q0890[] = {
    9, 9, // Number of jobs and machines
    4, 15, 8, 64, 1, 92, 5, 45, 0, 45, 6, 72, 2, 48, 3,  2, 7, 13, 
    8, 76, 3, 33, 7, 34, 0, 29, 1, 53, 5, 52, 2, 49, 4, 65, 6, 66, 
    1, 68, 0, 11, 4, 24, 8, 55, 3, 44, 7, 13, 5, 21, 6,  8, 2, 12, 
    1, 82, 3, 18, 4, 35, 2, 95, 7,  4, 8, 38, 6,  6, 0, 31, 5, 51, 
    7, 31, 3, 88, 8, 99, 2, 21, 1, 68, 6, 25, 4, 45, 5, 17, 0, 46, 
    2, 15, 1, 62, 6, 76, 8, 64, 4, 83, 0, 90, 7, 39, 3, 21, 5, 40, 
    6, 76, 5,  9, 7, 61, 8, 45, 1, 40, 3, 37, 0, 57, 4, 46, 2, 36, 
    4, 67, 0, 42, 8, 23, 3, 68, 7, 29, 1, 81, 2, 19, 6, 54, 5, 58, 
    5,  1, 0, 80, 4,  6, 2, 92, 8, 12, 1,  6, 6, 65, 7, 39, 3,  8
  };
  const int q0891[] = {
    9, 9, // Number of jobs and machines
    5, 29, 7, 92, 6, 40, 8, 19, 3, 85, 1, 95, 2, 30, 4, 58, 0, 15, 
    0,  5, 5, 54, 1, 61, 4, 23, 7, 27, 2, 35, 3,  1, 6, 14, 8, 80, 
    6, 33, 4, 44, 0, 33, 3, 35, 7, 27, 5, 73, 8, 72, 2, 71, 1, 32, 
    7, 26, 0, 65, 2, 48, 8, 10, 1, 64, 3, 40, 4, 11, 6, 29, 5, 51, 
    8, 63, 3, 46, 4,  4, 5, 45, 7, 67, 6,  3, 2, 93, 1, 48, 0, 76, 
    8, 22, 5, 90, 2, 26, 0, 72, 1,  7, 6, 68, 7, 57, 4, 94, 3, 80, 
    1, 78, 6, 82, 2, 90, 0, 94, 7, 89, 5, 47, 3, 90, 4, 71, 8, 47, 
    2, 66, 4, 84, 3, 35, 6,  8, 1, 60, 7, 73, 8, 90, 5, 23, 0, 12, 
    7, 75, 8, 96, 5, 61, 3, 91, 1, 81, 0, 90, 2, 54, 6, 59, 4, 32
  };
  const int q0892[] = {
    9, 9, // Number of jobs and machines
    3, 17, 8, 87, 1, 65, 7, 44, 2, 14, 5, 63, 6, 92, 0, 95, 4,  7, 
    7, 61, 1, 49, 4, 47, 8, 93, 3, 10, 5, 34, 0, 83, 2, 34, 6, 57, 
    5, 71, 1, 99, 6, 34, 8,  6, 2, 15, 4, 56, 3, 81, 0, 21, 7, 76, 
    0, 39, 3, 24, 2, 13, 5, 35, 8, 58, 7, 16, 6, 53, 4, 59, 1,  8, 
    7, 71, 6, 83, 3, 53, 4, 43, 2, 18, 0, 44, 8, 42, 5, 65, 1, 47, 
    5,  5, 4, 30, 8, 78, 2, 25, 6, 46, 7,  1, 1, 62, 3, 17, 0,  7, 
    3, 69, 0, 98, 8, 29, 5, 69, 7, 53, 2, 23, 1, 30, 6, 90, 4, 67, 
    0, 62, 4, 51, 1, 25, 3, 16, 6, 65, 7, 94, 2, 12, 5, 40, 8, 27, 
    8, 47, 5, 54, 6, 34, 0, 58, 3, 13, 2, 92, 1, 28, 4, 83, 7, 89
  };
  const int q0893[] = {
    9, 9, // Number of jobs and machines
    2, 17, 7, 50, 0,  4, 4, 26, 8, 52, 1,  6, 3, 20, 5, 16, 6, 34, 
    8, 86, 7, 51, 1, 57, 6, 65, 5, 92, 3, 40, 4, 18, 0, 70, 2, 50, 
    5, 54, 1, 79, 8, 70, 4, 16, 2, 16, 7, 26, 0, 55, 6, 50, 3, 96, 
    5, 61, 7, 90, 4,  6, 2,  6, 0, 19, 6, 58, 3, 12, 8, 46, 1, 46, 
    8, 34, 2, 99, 5, 11, 0, 34, 4, 13, 3, 95, 7, 46, 6, 29, 1, 11, 
    1, 79, 4, 78, 8, 66, 5, 77, 7, 57, 2, 93, 0, 60, 6, 83, 3,  1, 
    6, 93, 3,  9, 5, 70, 8, 82, 2, 93, 1, 55, 0, 83, 4, 17, 7, 16, 
    0, 72, 7, 94, 8, 66, 6, 77, 5,  7, 2, 66, 3, 23, 1, 14, 4, 38, 
    7, 27, 0, 28, 4, 69, 3, 24, 6, 98, 2, 29, 1, 93, 5,  2, 8, 27
  };
  const int q0894[] = {
    9, 9, // Number of jobs and machines
    1, 57, 3, 30, 7, 60, 4, 26, 8, 17, 2, 17, 6, 84, 0, 30, 5, 30, 
    6, 97, 4, 60, 3, 59, 1, 65, 2, 79, 8, 77, 7, 62, 0, 10, 5, 86, 
    1, 74, 4, 90, 8,  2, 0, 66, 7, 96, 3, 16, 2, 10, 5,  5, 6, 15, 
    4, 83, 5, 11, 7,  9, 1, 26, 0, 69, 8, 85, 2, 55, 3, 63, 6,  2, 
    1, 16, 0, 59, 7, 35, 2, 21, 4, 18, 5, 47, 6, 92, 3, 53, 8, 86, 
    7, 92, 0, 26, 1, 42, 2, 53, 3, 47, 4, 99, 5, 60, 6, 96, 8, 63, 
    2, 24, 6, 83, 0, 60, 4, 49, 1, 75, 8,  4, 7, 74, 3, 85, 5, 71, 
    3,  4, 8, 91, 2, 31, 1, 62, 0, 76, 5, 34, 4,  9, 6, 84, 7, 49, 
    0, 31, 5, 90, 7, 30, 2, 23, 8, 98, 4, 32, 1, 31, 3, 30, 6, 62
  };
  const int q0895[] = {
    9, 9, // Number of jobs and machines
    2, 66, 5, 85, 0,  7, 1, 29, 4, 63, 7, 80, 3, 78, 6, 25, 8, 41, 
    4, 42, 1, 29, 3, 47, 5, 43, 8, 17, 0, 62, 6, 29, 2,  3, 7, 23, 
    5, 53, 7, 42, 6, 52, 0, 36, 8,  7, 2, 80, 1, 24, 3, 19, 4, 63, 
    6, 23, 3, 48, 7, 93, 5, 33, 1, 99, 4, 68, 0, 90, 8, 42, 2, 77, 
    0, 84, 2, 90, 3, 11, 1,  1, 4, 31, 6, 50, 8, 98, 7, 44, 5,  5, 
    0, 35, 7,  3, 3, 67, 8, 56, 5, 66, 6, 18, 1, 82, 2, 94, 4, 58, 
    4, 61, 7,  2, 3,  7, 2, 39, 1, 44, 0, 72, 5, 43, 6,  3, 8, 21, 
    4,  2, 3, 96, 0, 43, 2, 54, 5, 94, 6,  8, 7, 63, 1, 35, 8, 88, 
    3, 28, 6, 45, 1, 26, 0, 74, 4,  6, 2, 56, 5, 97, 7, 55, 8, 25
  };
  const int q0896[] = {
    9, 9, // Number of jobs and machines
    2,  5, 0, 65, 5, 15, 3, 50, 7, 13, 8, 80, 4, 59, 6, 25, 1, 57, 
    4, 59, 2, 44, 1, 56, 5, 63, 6, 70, 3, 18, 8, 49, 0, 63, 7, 82, 
    2, 80, 6, 38, 0, 24, 4, 19, 5, 57, 3, 35, 7,  1, 8, 98, 1, 90, 
    6, 46, 4, 35, 8,  4, 5, 73, 3, 65, 7, 54, 0, 48, 2, 82, 1, 59, 
    5,  2, 6, 96, 0, 75, 7, 32, 3, 46, 1, 96, 8, 43, 4, 45, 2, 58, 
    3, 40, 5,  9, 7, 28, 4, 11, 1,  3, 2,  4, 0, 74, 8,  2, 6, 64, 
    0, 28, 1, 93, 2,  2, 4, 42, 8,  1, 6, 92, 3, 59, 7, 12, 5, 35, 
    3, 61, 7, 35, 5,  5, 6, 96, 2, 84, 1, 46, 4, 82, 8, 18, 0, 35, 
    8, 51, 2, 66, 4, 33, 1, 72, 0, 29, 7, 25, 5, 20, 6, 76, 3, 56
  };
  const int q0897[] = {
    9, 9, // Number of jobs and machines
    6, 42, 2, 97, 8, 29, 4, 98, 5,  5, 7, 99, 3, 88, 1, 87, 0, 88, 
    7, 21, 6, 18, 2, 94, 3, 26, 0, 32, 4, 59, 5, 90, 8, 20, 1, 91, 
    2,  5, 4, 35, 5,  4, 1,  7, 0, 68, 8, 72, 7, 77, 3, 36, 6, 41, 
    5, 49, 1, 82, 4, 90, 3, 17, 2, 77, 7, 47, 0,  2, 8, 65, 6, 14, 
    1, 95, 8, 39, 7, 98, 2, 31, 0, 34, 3, 69, 6, 33, 5, 88, 4, 58, 
    0, 93, 6, 61, 4, 81, 3, 58, 8, 97, 1, 80, 7, 74, 2, 10, 5, 54, 
    5, 90, 1, 14, 4, 49, 0, 70, 7, 56, 8, 61, 2, 37, 6, 71, 3, 53, 
    6, 73, 3, 62, 0, 36, 4,  3, 2, 79, 1, 78, 5, 20, 8,  5, 7, 78, 
    7, 24, 4, 34, 6, 11, 8, 99, 5, 64, 1, 24, 3, 61, 0,  1, 2, 38
  };
  const int q0898[] = {
    9, 9, // Number of jobs and machines
    2, 32, 5, 26, 4, 29, 3, 72, 6, 84, 8, 92, 7, 97, 0, 37, 1, 36, 
    0, 99, 5, 61, 6, 55, 2,  4, 4, 29, 1, 40, 3, 53, 7, 37, 8, 97, 
    0, 92, 3, 53, 5, 56, 8, 27, 2, 80, 6, 91, 1, 35, 4,  9, 7, 49, 
    2, 58, 7, 28, 4,  8, 6, 40, 3, 41, 8, 23, 0, 14, 5, 93, 1, 97, 
    0, 16, 4,  4, 6, 36, 3, 95, 5, 41, 2, 38, 7, 88, 8, 45, 1, 89, 
    1, 11, 6, 42, 3, 22, 8,  4, 0, 31, 4,  3, 5, 35, 2, 41, 7, 38, 
    2, 89, 6, 75, 8, 27, 4, 92, 1, 65, 0, 29, 5, 93, 7, 11, 3, 65, 
    1, 30, 5,  2, 7, 89, 0, 72, 8, 20, 2, 18, 3, 44, 4,  8, 6, 63, 
    4,  3, 5, 24, 2, 83, 8, 33, 7, 62, 3, 52, 0, 28, 6,  6, 1, 91
  };
  const int q0899[] = {
    9, 9, // Number of jobs and machines
    6, 39, 3, 62, 7, 30, 2, 48, 1, 88, 4, 12, 8, 44, 5, 75, 0, 28, 
    3, 90, 6, 33, 8, 63, 0, 80, 1, 55, 4, 45, 7, 24, 2, 19, 5, 97, 
    6, 12, 3, 61, 0, 49, 8, 84, 2, 41, 1,  9, 4, 50, 5, 81, 7, 31, 
    1, 40, 6, 80, 5, 51, 7, 31, 8, 44, 2,  3, 3, 85, 4, 37, 0, 11, 
    5, 50, 6, 48, 0,  3, 2, 49, 7, 86, 8, 40, 3, 12, 4, 85, 1, 63, 
    7, 21, 5, 79, 6, 58, 4, 63, 3, 43, 8,  4, 0,  7, 1, 53, 2, 41, 
    5, 38, 0, 94, 1, 29, 2, 42, 3, 27, 8, 57, 4, 37, 6,  5, 7, 66, 
    3, 12, 5, 93, 0, 83, 2, 67, 4, 54, 8, 20, 7, 72, 1, 37, 6, 79, 
    6, 22, 5, 41, 1, 10, 8, 10, 4, 75, 3,  1, 0, 65, 7, 76, 2, 33
  };
  const int q0900[] = {
    9, 9, // Number of jobs and machines
    6, 11, 3, 32, 4, 66, 1, 50, 8, 24, 5, 27, 2, 24, 0, 33, 7, 53, 
    0, 14, 6, 90, 8, 12, 7,  9, 5, 56, 4, 42, 2, 14, 1, 17, 3, 70, 
    5, 71, 8,  4, 2, 74, 4, 69, 0, 39, 6, 68, 7, 96, 3, 41, 1, 88, 
    4, 47, 0, 36, 6, 61, 5, 52, 8, 77, 2, 89, 1, 11, 3, 16, 7,  5, 
    7, 17, 5, 26, 2,  9, 0, 22, 6, 15, 3, 71, 8, 99, 4, 47, 1, 93, 
    6, 28, 7, 75, 8, 77, 5, 50, 2, 52, 4, 35, 3, 93, 1, 11, 0,  3, 
    7, 58, 4, 72, 2, 16, 0, 85, 1, 90, 6, 90, 8, 91, 3, 22, 5, 98, 
    1, 50, 3, 70, 6, 49, 0, 44, 7, 59, 5, 66, 4, 65, 2, 50, 8, 13, 
    1, 64, 0, 40, 8, 86, 4, 14, 2, 60, 6, 61, 5, 83, 3, 57, 7, 79
  };
  const int q0901[] = {
    9, 9, // Number of jobs and machines
    7, 54, 5, 61, 0, 64, 1, 83, 6, 44, 3, 81, 4, 80, 2, 57, 8, 98, 
    5, 41, 2, 61, 7, 35, 6,  4, 1, 50, 4, 61, 0, 57, 3, 76, 8,  7, 
    8, 32, 7, 93, 4, 80, 1, 11, 0, 34, 3, 79, 6, 13, 5, 79, 2, 76, 
    0, 97, 4, 65, 8, 91, 1, 23, 6, 18, 7, 56, 5, 93, 3, 30, 2, 44, 
    0, 12, 7,  1, 6, 38, 3, 65, 8, 76, 5, 47, 2, 53, 1, 41, 4, 24, 
    3, 84, 5, 70, 4,  1, 1,  5, 7, 69, 0, 45, 2, 57, 6, 75, 8, 47, 
    2, 24, 0, 75, 8, 75, 3, 71, 1, 47, 4, 40, 6, 98, 7, 10, 5, 81, 
    7, 44, 5, 17, 4, 16, 2, 62, 1, 58, 6, 63, 0, 45, 3, 57, 8, 28, 
    2, 54, 6, 90, 0, 56, 1, 15, 7, 54, 5, 90, 4, 75, 8, 22, 3, 97
  };
  const int q0902[] = {
    9, 9, // Number of jobs and machines
    7, 58, 6, 32, 0, 52, 8, 86, 4, 70, 5, 89, 3, 29, 2, 62, 1, 91, 
    7, 70, 2,  6, 1, 60, 5, 63, 0, 54, 3, 17, 8, 16, 6, 18, 4, 17, 
    7, 23, 2, 15, 1, 34, 0,  9, 5, 70, 4, 36, 3,  1, 8, 27, 6, 33, 
    4, 43, 5, 26, 0, 45, 7, 68, 1, 55, 8, 65, 3, 31, 6, 43, 2, 30, 
    5, 61, 6, 47, 8, 24, 4, 11, 1, 15, 3, 12, 7, 23, 2, 15, 0, 92, 
    4,  1, 0, 18, 2, 41, 8, 99, 3, 27, 6, 91, 1, 99, 5, 75, 7, 92, 
    2, 11, 1, 99, 0, 37, 8, 56, 5,  5, 3, 61, 4, 26, 7, 63, 6, 63, 
    2, 21, 3,  6, 7, 76, 0, 45, 6, 62, 5, 39, 8, 90, 4, 37, 1, 57, 
    0, 16, 4, 59, 6, 96, 3, 39, 7, 40, 1, 52, 2, 60, 8, 85, 5, 18
  };
  const int q0903[] = {
    9, 9, // Number of jobs and machines
    3, 79, 0, 16, 7,  3, 1, 62, 4, 45, 8, 93, 2,  9, 5, 20, 6, 13, 
    5, 26, 1, 51, 3, 22, 8, 64, 0, 30, 6, 18, 2, 60, 7, 13, 4,  4, 
    1, 44, 7, 89, 5, 26, 0, 30, 4,  4, 2,  1, 8, 27, 6, 60, 3, 45, 
    2, 79, 5, 17, 7, 70, 6, 26, 0, 26, 1, 68, 4, 58, 3,  5, 8, 71, 
    3,  7, 4, 65, 0, 43, 2, 82, 6, 97, 5, 61, 7, 93, 8, 12, 1, 92, 
    5, 70, 8, 65, 1, 44, 0,  8, 4, 72, 7, 34, 2, 43, 6, 78, 3, 37, 
    0, 47, 6, 36, 4, 61, 7, 41, 5, 73, 8, 72, 2,  6, 1, 96, 3, 75, 
    2, 36, 1, 69, 7, 71, 4, 41, 6,  6, 5, 84, 8, 56, 3, 37, 0,  9, 
    3, 20, 5, 24, 4, 69, 8,  7, 2, 78, 1, 34, 6, 84, 0, 56, 7, 28
  };
  const int q0904[] = {
    9, 9, // Number of jobs and machines
    6,  5, 4, 68, 7, 25, 8,  4, 5, 62, 3, 95, 0,  7, 1, 87, 2, 31, 
    1, 73, 4, 96, 2, 10, 5, 80, 6, 93, 0, 99, 8, 90, 7, 46, 3, 75, 
    7, 25, 2, 94, 8,  2, 3, 28, 0,  2, 6, 10, 1, 43, 4, 84, 5,  6, 
    3,  6, 6, 69, 0, 66, 5, 59, 1, 34, 2,  4, 7, 96, 8, 80, 4, 83, 
    7, 11, 3, 70, 5,  2, 2,  1, 0, 10, 4, 38, 6, 35, 8, 58, 1, 20, 
    7, 94, 8, 40, 3,  1, 4,  5, 2, 51, 0, 30, 1, 95, 5, 20, 6, 63, 
    7, 31, 6, 42, 3, 88, 5, 81, 2,  9, 1, 91, 8, 62, 0, 56, 4, 24, 
    8, 59, 0, 86, 5, 32, 3,  5, 2, 78, 6, 71, 1, 97, 4, 59, 7, 12, 
    3, 17, 5, 96, 6, 89, 7, 47, 1, 55, 8,  9, 2, 59, 4, 96, 0,  2
  };
  const int q0905[] = {
    9, 9, // Number of jobs and machines
    0, 95, 8, 97, 5, 60, 2, 83, 3, 33, 1, 64, 7, 26, 6, 72, 4, 67, 
    8, 79, 7, 50, 4, 51, 3, 59, 2, 41, 5, 93, 6, 47, 1, 97, 0, 73, 
    7, 84, 8, 84, 4, 16, 3, 14, 0, 56, 5, 29, 6, 43, 1, 27, 2, 13, 
    3, 27, 7, 72, 5, 58, 2, 22, 1, 72, 0, 65, 4, 33, 8,  5, 6, 76, 
    3, 25, 2, 20, 0, 25, 7, 14, 4, 85, 6, 89, 5, 56, 1, 49, 8, 74, 
    2, 30, 8, 95, 4, 72, 6, 52, 5, 89, 0, 51, 1, 14, 7, 29, 3, 11, 
    2, 92, 0, 17, 8, 84, 6, 12, 5, 90, 1, 16, 4, 44, 7, 44, 3, 54, 
    0, 33, 3, 21, 5,  7, 4, 29, 1, 44, 6, 79, 7, 27, 2,  1, 8, 41, 
    8, 16, 4, 94, 3, 24, 7, 78, 1, 12, 6, 92, 5, 37, 0, 90, 2,  4
  };
  const int q0906[] = {
    9, 9, // Number of jobs and machines
    8, 29, 7, 93, 1, 71, 5, 68, 4, 79, 0, 64, 2,  8, 6, 46, 3, 16, 
    5, 51, 6, 52, 2, 29, 8, 69, 7, 80, 3, 53, 0, 83, 1, 16, 4, 87, 
    3,  5, 2, 30, 1, 28, 8, 21, 0, 70, 5, 70, 6,  1, 4, 88, 7, 23, 
    1, 61, 5, 96, 7, 87, 4, 81, 0, 29, 3, 87, 2, 29, 6, 25, 8, 64, 
    3, 84, 4, 95, 1, 25, 2, 70, 5, 13, 8, 37, 0, 12, 6, 12, 7, 69, 
    7, 77, 5, 57, 4, 95, 8, 64, 2, 78, 6,  7, 0, 19, 1, 42, 3, 61, 
    6, 25, 2,  7, 3, 17, 0, 47, 4, 53, 5, 68, 1, 41, 7, 81, 8, 79, 
    5, 75, 4, 96, 0, 41, 8, 52, 3, 45, 2, 50, 1, 32, 7,  7, 6, 56, 
    1, 16, 2, 80, 8, 83, 7, 31, 3, 49, 4,  4, 0, 35, 5, 24, 6, 67
  };
  const int q0907[] = {
    9, 9, // Number of jobs and machines
    5,  5, 3, 59, 2, 72, 7, 77, 8, 31, 0, 37, 1, 28, 4, 53, 6,  2, 
    8, 56, 6, 49, 3, 60, 5, 38, 4, 67, 2, 90, 1, 23, 7, 87, 0, 30, 
    1, 10, 7, 98, 4, 45, 3, 38, 0, 90, 8, 87, 5, 16, 2, 10, 6, 91, 
    1,  5, 6, 73, 5, 40, 8, 20, 4, 18, 2, 29, 7, 71, 0, 95, 3, 62, 
    2, 57, 7,  1, 5, 35, 4, 59, 8, 23, 3, 39, 6, 49, 0, 63, 1, 38, 
    5, 18, 6, 81, 2, 90, 0, 32, 8, 30, 1, 63, 3, 95, 7, 12, 4, 58, 
    0,  1, 6, 29, 2,  7, 8, 54, 3,  8, 7, 12, 1, 26, 5, 63, 4,  3, 
    1, 22, 0, 28, 3, 93, 8, 91, 6, 88, 5, 55, 2, 41, 4, 25, 7, 56, 
    4, 57, 1, 25, 0, 46, 7, 40, 6, 70, 8, 63, 2, 65, 5, 40, 3, 83
  };
  const int q0908[] = {
    9, 9, // Number of jobs and machines
    2,  8, 3,  6, 4, 22, 8, 14, 5, 52, 0,  4, 1, 34, 7, 34, 6, 38, 
    1, 92, 4, 11, 0,  2, 2, 69, 8, 52, 5, 46, 7, 63, 3, 32, 6, 75, 
    8, 19, 5, 57, 6, 21, 2, 34, 7, 20, 3, 45, 0, 34, 1, 59, 4,  5, 
    1, 97, 7,  9, 0, 73, 8, 70, 3, 35, 6, 22, 4, 27, 5, 85, 2, 86, 
    8, 52, 6, 27, 7, 51, 3, 74, 0, 89, 5, 80, 2, 26, 4, 43, 1, 72, 
    8, 50, 7, 52, 0, 32, 3, 92, 6, 50, 4, 97, 1, 37, 2, 18, 5,  1, 
    1, 18, 0, 99, 5, 59, 7, 45, 3, 31, 6, 89, 2, 36, 4, 43, 8, 75, 
    6, 54, 5, 95, 1, 75, 0, 46, 7, 57, 8, 85, 4, 56, 2, 74, 3, 67, 
    3,  8, 5, 11, 6, 15, 8, 89, 7, 78, 1, 88, 4, 16, 2, 30, 0, 21
  };
  const int q0909[] = {
    9, 9, // Number of jobs and machines
    2, 59, 0, 19, 1, 37, 3, 58, 8, 24, 7, 19, 4, 52, 5, 51, 6, 99, 
    3, 43, 2, 92, 1,  6, 7, 56, 4, 81, 0, 88, 8, 90, 5, 51, 6, 96, 
    1,  9, 6,  4, 7, 24, 2, 57, 4, 93, 0, 86, 5, 19, 3, 42, 8, 32, 
    0, 90, 5, 73, 3, 47, 2, 99, 4, 33, 6, 43, 7,  2, 1, 12, 8, 14, 
    2, 55, 1, 14, 3, 88, 8,  5, 4, 66, 0, 55, 5, 83, 7, 72, 6, 47, 
    2, 20, 7, 53, 6, 19, 5, 47, 8, 58, 1, 76, 0, 12, 4, 66, 3, 23, 
    3, 99, 8, 34, 2, 77, 1, 42, 4, 99, 7, 35, 6, 54, 0, 22, 5, 21, 
    7, 86, 0, 71, 2, 80, 5, 16, 3, 56, 6, 50, 8,  5, 4, 94, 1, 96, 
    1, 59, 7, 59, 8, 39, 6, 73, 3, 42, 0, 87, 4, 79, 5, 63, 2, 29
  };
  const int q0910[] = {
    9, 9, // Number of jobs and machines
    3, 95, 5, 12, 0, 82, 4, 41, 7, 45, 8, 77, 2, 50, 6, 64, 1, 67, 
    3, 36, 6, 10, 7, 10, 0, 74, 4, 90, 2, 89, 1, 19, 8, 87, 5, 68, 
    1, 54, 4, 23, 0, 16, 7, 32, 6, 20, 8, 11, 3, 77, 5, 39, 2, 34, 
    6, 13, 8, 87, 0, 60, 5, 90, 7, 93, 4,  7, 1, 39, 2, 91, 3, 36, 
    6, 22, 8, 18, 4, 14, 7, 26, 1, 88, 2, 64, 5, 23, 0,  3, 3, 30, 
    4, 33, 0, 38, 2, 91, 1, 35, 3, 54, 6, 63, 5, 25, 7, 99, 8,  3, 
    7, 91, 4, 77, 1, 83, 8, 53, 5, 82, 6, 48, 2, 80, 0,  7, 3, 63, 
    2, 83, 4, 24, 8, 65, 7, 87, 5, 18, 3, 41, 6, 55, 0, 31, 1, 49, 
    2, 65, 3, 75, 7, 21, 6, 11, 4, 16, 8, 18, 5, 77, 0, 11, 1, 39
  };
  const int q0911[] = {
    9, 9, // Number of jobs and machines
    2, 32, 3, 67, 4, 27, 5, 12, 0, 59, 8, 97, 6, 42, 7, 27, 1, 46, 
    7, 42, 8, 50, 2, 32, 6, 28, 1, 91, 5, 21, 3, 41, 0, 84, 4, 64, 
    3, 59, 5, 57, 4, 82, 6, 89, 0, 68, 1, 56, 8, 73, 7,  4, 2, 84, 
    2, 48, 6, 29, 0, 85, 4, 59, 1, 23, 8, 62, 7, 45, 3, 16, 5, 34, 
    3, 33, 7, 11, 6,  5, 0,  2, 1, 57, 2, 24, 8, 39, 5, 70, 4, 90, 
    2, 77, 7, 65, 0, 85, 8, 26, 5, 93, 3, 99, 4, 39, 1, 34, 6, 90, 
    0, 23, 7, 20, 3, 10, 4, 36, 6, 97, 1, 29, 2, 83, 8, 19, 5, 60, 
    8, 56, 7, 97, 3, 15, 4, 36, 1, 23, 5, 69, 6, 48, 2, 85, 0, 60, 
    0, 82, 8, 48, 7, 87, 6, 52, 1, 57, 4, 31, 5, 95, 2, 12, 3, 49
  };
  const int q0912[] = {
    9, 9, // Number of jobs and machines
    2, 10, 8, 81, 6, 98, 3, 50, 0, 95, 1, 52, 7, 63, 4, 29, 5,  8, 
    2, 47, 0, 81, 3,  4, 7, 48, 5, 14, 1, 90, 8, 54, 4, 78, 6, 82, 
    7, 51, 6, 62, 1, 99, 8, 57, 2, 11, 3, 13, 5, 19, 0, 37, 4, 73, 
    7, 54, 4, 58, 6, 19, 0, 27, 8, 28, 3, 32, 5, 60, 2, 47, 1, 55, 
    0, 80, 2, 55, 5, 35, 3, 54, 1, 41, 6, 99, 8, 14, 7, 28, 4, 60, 
    4, 21, 7, 26, 0, 73, 3, 52, 5, 33, 2, 16, 6, 73, 1,  7, 8, 99, 
    5, 67, 7, 86, 3, 66, 8, 57, 4, 83, 6, 39, 1, 92, 2, 81, 0, 65, 
    7, 11, 1, 84, 2, 77, 8, 52, 5, 87, 4, 88, 6, 31, 3, 22, 0, 92, 
    0,  8, 2, 18, 5, 40, 3, 72, 4, 49, 1, 59, 6, 74, 8, 66, 7, 85
  };
  const int q0913[] = {
    9, 9, // Number of jobs and machines
    2, 71, 5,  1, 4, 72, 6, 97, 1, 48, 0,  3, 7, 51, 3, 62, 8, 90, 
    6, 47, 3, 25, 7, 34, 0, 44, 2, 96, 8, 82, 1, 28, 4, 70, 5, 77, 
    2, 22, 3, 14, 5, 78, 7, 47, 0, 44, 4, 36, 1, 54, 8, 29, 6, 91, 
    1, 62, 7, 68, 6, 73, 2, 63, 8, 12, 0, 35, 3, 50, 4, 31, 5, 25, 
    3, 95, 6, 12, 4, 87, 7, 77, 2, 59, 1, 60, 5, 43, 0, 41, 8, 41, 
    4,  5, 1, 96, 0, 51, 3, 53, 8, 52, 5, 64, 7, 85, 6, 50, 2, 50, 
    1, 21, 2, 26, 7, 20, 8, 53, 6, 88, 5, 53, 4, 66, 0, 84, 3,  4, 
    3, 77, 1, 51, 4,  3, 8, 88, 2,  9, 7, 87, 0, 36, 6,  2, 5, 87, 
    3, 33, 4, 10, 1, 71, 0, 50, 7, 84, 5, 24, 2, 30, 8, 65, 6, 98
  };
  const int q0914[] = {
    9, 9, // Number of jobs and machines
    8, 47, 0, 28, 6, 58, 2, 37, 5, 53, 3, 25, 4, 41, 7, 21, 1, 85, 
    4, 51, 7,  1, 6,  4, 3, 50, 8, 55, 1, 14, 0, 32, 2, 38, 5, 93, 
    5, 39, 8,  2, 1, 68, 7, 50, 4, 99, 0, 10, 6, 77, 3, 88, 2, 18, 
    2, 29, 5, 16, 3, 31, 6, 20, 7, 73, 4, 52, 0, 92, 8, 79, 1, 56, 
    8, 53, 3,  1, 4, 43, 7, 94, 2, 11, 0, 13, 6, 94, 1, 87, 5, 26, 
    4, 81, 7, 39, 2,  6, 3, 27, 6,  7, 0, 36, 1, 70, 5, 12, 8, 77, 
    5, 85, 0, 48, 8, 52, 7, 62, 2, 92, 6, 22, 4, 62, 1,  1, 3, 17, 
    7, 52, 4, 68, 3, 85, 0, 93, 6, 89, 5,  2, 1, 71, 2, 55, 8, 76, 
    0, 50, 6, 61, 1, 57, 7, 68, 2, 76, 5, 71, 8, 21, 3, 98, 4, 65
  };
  const int q0915[] = {
    9, 9, // Number of jobs and machines
    5, 96, 0, 29, 2, 24, 7, 72, 4, 79, 8, 57, 1, 36, 3, 42, 6, 10, 
    5, 10, 6, 88, 2, 42, 4, 18, 3, 43, 8, 27, 0, 39, 1,  4, 7, 88, 
    4, 95, 2, 98, 5, 19, 1, 58, 7, 88, 0, 13, 8,  8, 6, 23, 3, 59, 
    6, 64, 7, 50, 5, 83, 2,  1, 0, 20, 4, 50, 3,  5, 1, 83, 8,  9, 
    2, 32, 1, 59, 5,  2, 8, 77, 3, 15, 7, 27, 4, 14, 0, 40, 6, 31, 
    4, 13, 6,  9, 3, 53, 2, 56, 0, 49, 5, 90, 1, 84, 7, 25, 8, 64, 
    0, 89, 5,  6, 2, 35, 4, 38, 6, 18, 3, 93, 1, 87, 7, 16, 8,  2, 
    6, 32, 7, 46, 0, 60, 8,  8, 3, 25, 4, 78, 5, 74, 1, 34, 2, 76, 
    4, 83, 8, 68, 1, 64, 0, 81, 5, 85, 7, 44, 2, 55, 6, 70, 3, 53
  };
  const int q0916[] = {
    9, 9, // Number of jobs and machines
    1, 45, 7, 82, 2, 70, 3, 74, 4, 39, 8,  6, 6, 10, 0, 16, 5, 33, 
    4, 65, 6, 31, 5, 63, 8, 80, 2,  3, 7, 15, 0, 71, 3, 41, 1, 50, 
    0, 68, 7, 18, 1, 42, 3,  5, 5, 51, 4, 49, 2, 89, 8, 36, 6, 92, 
    2, 35, 0, 97, 6, 10, 4, 62, 1, 66, 7, 77, 8, 93, 3, 75, 5, 92, 
    1, 10, 7, 83, 3, 30, 0,  4, 8, 85, 5, 36, 6, 18, 4,  1, 2, 97, 
    3, 76, 8, 37, 6, 69, 5, 62, 1, 66, 2, 91, 7, 26, 4, 87, 0, 22, 
    4, 42, 8, 53, 7,  6, 0,  7, 3, 89, 6, 70, 1, 73, 5, 61, 2, 39, 
    8, 82, 4, 77, 2, 95, 7, 56, 3, 15, 0, 21, 6, 10, 5,  6, 1, 56, 
    5,  5, 6, 49, 4, 94, 7, 32, 0, 75, 1, 91, 2, 60, 3, 92, 8, 58
  };
  const int q0917[] = {
    9, 9, // Number of jobs and machines
    2, 56, 8, 96, 4, 56, 7, 95, 3, 77, 5, 77, 1, 29, 6, 84, 0, 97, 
    5, 59, 6, 72, 2, 80, 7, 43, 1,  8, 4, 76, 3, 22, 0, 24, 8, 72, 
    1, 44, 5, 66, 8, 21, 6, 80, 2, 20, 0, 68, 7, 43, 4, 67, 3, 51, 
    4, 71, 2, 80, 0, 56, 3, 32, 1, 88, 5, 85, 7, 34, 6, 16, 8,  4, 
    1, 79, 5, 16, 4, 49, 2, 48, 6, 61, 8, 28, 3, 30, 0, 99, 7,  1, 
    6, 48, 0, 89, 7, 92, 1, 49, 3, 63, 2, 54, 5, 17, 8, 69, 4, 94, 
    8, 67, 7, 54, 6, 36, 4, 62, 5, 72, 0, 28, 3, 75, 1, 50, 2, 87, 
    5, 98, 1, 12, 7, 98, 4, 64, 6, 59, 2,  8, 0, 68, 3, 69, 8, 63, 
    3, 37, 1, 31, 4,  6, 6, 99, 5, 36, 8, 57, 7, 10, 0, 25, 2, 33
  };
  const int q0918[] = {
    9, 9, // Number of jobs and machines
    3, 22, 4, 41, 5, 33, 8, 27, 6, 13, 0, 53, 7, 87, 1, 24, 2, 17, 
    2, 51, 4,  4, 8, 27, 0, 19, 3, 13, 6, 82, 7, 24, 5,  9, 1, 61, 
    3, 33, 8,  8, 0, 47, 1, 24, 4, 53, 2, 73, 5, 16, 7, 13, 6, 81, 
    6, 34, 0, 18, 2, 91, 7, 38, 8, 49, 5, 52, 3,  2, 4, 91, 1, 35, 
    8, 93, 5, 14, 2,  4, 1, 29, 4, 98, 7, 61, 0, 90, 6, 54, 3, 13, 
    4, 39, 8, 86, 5, 63, 6, 49, 3, 29, 7, 54, 0, 59, 1, 76, 2, 18, 
    5, 58, 7, 97, 3, 24, 0, 37, 1,  1, 8, 84, 2, 49, 4, 29, 6, 60, 
    6,  5, 3, 45, 0,  6, 4, 29, 1, 90, 5, 68, 7, 12, 8, 67, 2, 25, 
    3, 50, 7, 86, 6, 88, 2, 84, 1, 16, 4, 80, 0, 22, 5, 54, 8, 61
  };
  const int q0919[] = {
    9, 9, // Number of jobs and machines
    0, 19, 6,  7, 1, 38, 4, 13, 8, 66, 3, 19, 2, 30, 7, 64, 5, 75, 
    2, 10, 6, 43, 4, 86, 3, 38, 7, 12, 1, 59, 8, 53, 5, 37, 0, 85, 
    1, 31, 3, 32, 8, 96, 2, 57, 5, 65, 4, 84, 7,  7, 0, 14, 6, 83, 
    6,  3, 4, 66, 2, 90, 3, 98, 8, 58, 1, 21, 5, 99, 0, 79, 7, 78, 
    8, 74, 7, 14, 0, 92, 2, 83, 3, 40, 5, 83, 4, 28, 1, 88, 6, 86, 
    2, 88, 8, 15, 5, 35, 6, 81, 3, 99, 1, 14, 7, 79, 0, 72, 4, 31, 
    7, 35, 5, 40, 8,  5, 2, 31, 1, 15, 6, 10, 0, 17, 3, 41, 4,  5, 
    0, 42, 6,  9, 5, 64, 4, 77, 8, 44, 2, 60, 1, 35, 3, 47, 7, 87, 
    5, 38, 2, 98, 8, 95, 4, 64, 6, 54, 3, 65, 0, 32, 1, 68, 7, 32
  };
  const int q0920[] = {
    9, 9, // Number of jobs and machines
    2,  3, 3, 28, 0, 88, 8, 94, 5, 25, 1, 38, 4, 44, 7, 59, 6, 13, 
    0, 58, 6, 83, 7, 95, 5, 10, 1, 68, 2,  3, 3, 66, 4, 37, 8,  8, 
    5, 35, 6, 18, 0, 71, 4, 80, 1,  2, 7, 87, 3, 87, 2, 82, 8, 98, 
    3, 84, 4, 36, 7, 44, 0, 32, 8, 17, 2,  9, 5, 47, 6, 95, 1, 30, 
    5, 85, 3, 22, 0, 91, 2, 62, 8, 27, 1, 87, 7, 55, 4, 23, 6, 48, 
    4, 44, 8,  4, 0, 57, 1, 18, 2, 90, 7, 10, 3, 15, 6, 63, 5, 99, 
    1, 63, 5, 10, 3, 62, 7, 42, 2, 63, 0, 37, 4, 40, 6, 50, 8, 95, 
    6,  5, 2, 86, 4, 78, 1, 50, 5, 42, 3,  3, 0, 16, 7, 64, 8, 93, 
    3, 70, 1, 90, 8,  4, 2, 56, 0, 99, 4, 81, 5, 61, 7, 73, 6, 46
  };
  const int q0921[] = {
    9, 9, // Number of jobs and machines
    8, 73, 2, 99, 1, 98, 6, 61, 5, 56, 0, 67, 3, 62, 7, 56, 4, 98, 
    2, 40, 3, 39, 7, 72, 4, 20, 6, 64, 5, 24, 8,  6, 0, 37, 1, 46, 
    1, 25, 4, 81, 8, 63, 0, 37, 2, 48, 6, 26, 3, 10, 7, 41, 5, 72, 
    2, 91, 3, 76, 4,  2, 1, 89, 8, 78, 0, 57, 6, 71, 5, 59, 7, 84, 
    6, 89, 8, 19, 2,  6, 4, 24, 3, 29, 5, 32, 1, 46, 7, 98, 0, 88, 
    3, 80, 2, 50, 5, 46, 7,  3, 4, 55, 8, 87, 6, 37, 0, 49, 1, 68, 
    0, 25, 6, 53, 5, 19, 2, 71, 4, 96, 3, 59, 1, 56, 8, 86, 7, 85, 
    8, 22, 2, 35, 0,  6, 4,  8, 6, 43, 3, 72, 5, 46, 1, 68, 7, 35, 
    7, 35, 4, 74, 3, 82, 5, 20, 2, 51, 0, 22, 8, 74, 6, 20, 1, 81
  };
  const int q0922[] = {
    9, 9, // Number of jobs and machines
    5,  3, 8, 14, 3, 62, 1, 23, 4, 98, 7, 18, 6, 41, 0, 21, 2, 11, 
    4, 32, 7, 95, 1, 17, 5, 13, 0, 51, 2, 76, 8, 51, 6, 87, 3, 95, 
    3, 12, 2, 33, 1, 48, 4, 12, 7,  8, 6, 98, 8, 87, 5, 23, 0, 53, 
    0, 11, 6, 37, 2, 98, 5,  4, 7, 52, 4, 72, 3, 49, 1, 45, 8, 27, 
    4, 49, 8, 98, 3, 25, 7, 80, 0, 42, 2, 76, 1, 69, 5, 63, 6, 73, 
    3, 93, 0,  9, 5, 16, 6, 12, 7, 11, 4,  9, 2, 23, 1, 20, 8, 50, 
    3,  9, 7, 27, 8, 64, 2, 90, 1, 99, 5,  9, 6, 42, 0,  1, 4, 22, 
    8, 76, 4, 65, 2, 12, 1, 35, 6, 76, 0, 29, 5, 98, 3, 61, 7, 92, 
    3, 14, 0, 45, 2, 27, 7, 34, 5, 93, 6, 85, 1, 99, 4, 93, 8, 79
  };
  const int q0923[] = {
    9, 9, // Number of jobs and machines
    2, 70, 0, 38, 8, 14, 7, 77, 6, 61, 5, 17, 1, 36, 3, 83, 4, 85, 
    2, 35, 0, 10, 7, 69, 8, 39, 6, 18, 4, 30, 5, 10, 3, 15, 1, 90, 
    1, 64, 4, 66, 6, 35, 0, 35, 7, 56, 2, 66, 3, 41, 5, 47, 8,  3, 
    5, 48, 4, 18, 2, 50, 1, 36, 8, 54, 0, 82, 7, 25, 3, 26, 6, 24, 
    0, 36, 2, 81, 7,  3, 8, 57, 3, 14, 4, 73, 5, 41, 6, 64, 1, 99, 
    6, 99, 3, 54, 0, 95, 1, 43, 7, 51, 2, 44, 5, 38, 8, 90, 4, 90, 
    0,  5, 1, 83, 7, 74, 8, 94, 5, 76, 2, 39, 6, 73, 4,  9, 3, 82, 
    6, 86, 8, 39, 1,  9, 7, 60, 5, 80, 0, 11, 2, 92, 3, 19, 4, 99, 
    4, 33, 2, 29, 8, 32, 1,  3, 5, 42, 3, 73, 7, 43, 6, 72, 0, 54
  };
  const int q0924[] = {
    9, 9, // Number of jobs and machines
    3,  3, 0, 83, 6, 52, 7, 46, 2, 36, 5, 42, 1, 38, 4, 97, 8, 57, 
    8, 30, 0,  8, 6, 79, 4, 51, 1, 68, 3, 11, 2, 71, 7, 21, 5, 30, 
    6, 32, 4, 25, 2, 48, 3, 66, 8,  1, 0, 70, 5,  8, 1,  8, 7, 67, 
    1, 44, 0, 32, 7, 27, 3, 41, 5, 40, 4,  3, 8, 15, 6,  4, 2,  7, 
    6, 95, 5, 32, 1, 88, 4,  5, 8, 18, 7, 43, 2,  8, 0, 37, 3, 52, 
    5, 30, 8,  4, 3, 45, 1, 57, 0, 69, 2, 46, 7, 86, 4, 63, 6, 90, 
    1, 94, 7, 92, 0, 97, 4, 56, 5, 31, 6,  4, 3, 72, 2, 69, 8, 35, 
    3, 91, 0, 94, 4, 11, 6, 43, 5,  3, 8, 55, 1, 91, 2, 49, 7,  1, 
    5, 45, 3, 88, 1, 45, 2, 72, 4, 81, 7, 88, 0, 29, 6, 96, 8, 83
  };
  const int q0925[] = {
    9, 9, // Number of jobs and machines
    7,  7, 5, 59, 0, 69, 2, 13, 3, 97, 1, 78, 4, 64, 6, 86, 8, 78, 
    7, 94, 3, 12, 4, 81, 6, 25, 1, 57, 5, 31, 8, 44, 0, 83, 2, 24, 
    5, 12, 1, 21, 0, 45, 4, 44, 8, 80, 6, 87, 3, 52, 7, 82, 2, 78, 
    0,  1, 3, 31, 7, 58, 8, 45, 2, 15, 4, 52, 6, 34, 1, 68, 5,  9, 
    0, 41, 4, 47, 8, 23, 3, 82, 5, 77, 2, 35, 7, 63, 1, 92, 6, 99, 
    0, 42, 2, 58, 8,  3, 3, 36, 7, 20, 1, 42, 5, 42, 4, 90, 6,  5, 
    2, 62, 1, 91, 0, 94, 8, 68, 6, 10, 7, 94, 3, 15, 4, 14, 5, 72, 
    7, 84, 1, 91, 8, 84, 3, 42, 6, 54, 0,  4, 2, 22, 5, 44, 4, 15, 
    6, 33, 8, 67, 7, 72, 0, 63, 3, 80, 4, 55, 5, 77, 2, 57, 1,  4
  };
  const int q0926[] = {
    9, 9, // Number of jobs and machines
    5, 57, 8, 21, 1, 11, 7, 81, 3, 47, 6, 36, 4, 50, 0, 83, 2, 63, 
    1, 42, 7, 47, 8, 15, 6, 13, 3, 49, 4, 36, 5, 49, 0,  6, 2, 25, 
    8, 54, 2, 26, 5, 47, 1,  2, 4, 95, 7, 53, 6, 74, 0, 50, 3, 82, 
    1, 17, 3, 32, 5, 97, 0, 40, 6, 33, 7, 27, 8, 70, 4,  9, 2, 74, 
    6, 87, 5,  4, 1, 39, 7, 85, 2, 57, 3, 62, 8, 28, 4, 82, 0, 92, 
    8, 84, 1, 21, 2, 93, 4, 42, 7, 63, 0, 60, 5, 13, 6, 44, 3, 58, 
    1, 27, 5, 54, 7, 15, 3, 55, 4, 46, 8, 49, 2, 38, 6, 75, 0, 72, 
    5, 90, 6, 80, 7, 60, 4, 91, 3, 72, 8,  9, 1, 41, 0, 94, 2, 82, 
    3,  2, 2, 53, 0, 12, 8, 77, 4, 83, 5, 63, 1, 83, 7, 18, 6, 59
  };
  const int q0927[] = {
    9, 9, // Number of jobs and machines
    2, 88, 8, 24, 1,  6, 6, 93, 5, 41, 4, 65, 3, 27, 0, 33, 7, 79, 
    3, 95, 5, 58, 6, 10, 0,  1, 8, 76, 7, 40, 2, 53, 1,  2, 4, 92, 
    7, 13, 2, 12, 5, 21, 4, 44, 0, 64, 3, 96, 1, 85, 8, 10, 6, 40, 
    1, 12, 5, 41, 2, 74, 8, 17, 0, 60, 6,  6, 4,  4, 7, 59, 3, 54, 
    6, 57, 7, 92, 2, 40, 3, 31, 1, 49, 4, 79, 5, 97, 0, 87, 8, 61, 
    2, 35, 5, 42, 4, 37, 3, 36, 6,  8, 0, 60, 7, 29, 8,  2, 1, 50, 
    2, 83, 6, 23, 3, 60, 4, 18, 5, 89, 7, 65, 8, 62, 0,  1, 1, 33, 
    7, 36, 0, 88, 8, 58, 5, 45, 1, 83, 4, 71, 6, 15, 2,  1, 3, 58, 
    1, 72, 2,  7, 0, 64, 3, 19, 4, 80, 5, 82, 7, 99, 8, 18, 6, 49
  };
  const int q0928[] = {
    9, 9, // Number of jobs and machines
    3, 73, 2, 81, 8, 75, 6, 56, 1, 87, 7, 46, 5, 30, 4, 74, 0, 77, 
    6, 84, 5,  8, 4, 89, 0, 70, 3, 20, 7, 88, 8, 89, 1, 52, 2, 73, 
    3, 76, 0, 18, 2, 45, 8, 95, 6, 71, 4, 81, 7, 28, 1, 76, 5, 85, 
    8, 18, 2,  1, 1, 90, 4, 37, 7, 11, 3, 40, 6,  1, 0, 47, 5, 30, 
    4, 51, 6, 60, 0, 29, 8, 26, 5, 71, 3, 99, 2, 35, 1, 28, 7, 75, 
    3, 36, 1, 15, 6, 61, 2, 57, 0, 86, 8, 23, 4, 63, 7, 27, 5, 33, 
    1, 40, 0, 27, 2, 28, 3, 87, 8, 30, 7,  2, 5, 71, 6, 75, 4, 14, 
    1, 58, 7, 92, 3, 35, 6, 42, 4, 83, 8, 28, 0, 50, 2,  3, 5, 94, 
    8, 44, 0, 91, 4, 92, 6, 42, 7, 46, 1, 27, 2,  9, 3, 59, 5, 74
  };
  const int q0929[] = {
    9, 9, // Number of jobs and machines
    0, 31, 8, 82, 7,  3, 6,  8, 3, 83, 2, 95, 5, 97, 1, 72, 4, 47, 
    1, 41, 2, 24, 5, 99, 6, 85, 8, 14, 3, 44, 0, 48, 4, 98, 7, 81, 
    3, 98, 5, 12, 8,  2, 2, 74, 6, 53, 7, 22, 4, 88, 0, 35, 1, 80, 
    4, 72, 3, 23, 0, 56, 2,  6, 8, 94, 6, 23, 7, 48, 1, 87, 5, 62, 
    2, 98, 4, 46, 6, 87, 7, 16, 0, 31, 1, 62, 5, 43, 8, 79, 3, 73, 
    0, 40, 4, 14, 7, 51, 2, 81, 8, 62, 5, 94, 6, 14, 3, 23, 1, 20, 
    7, 92, 3, 17, 0, 56, 8, 72, 4, 14, 2, 82, 6, 59, 5, 15, 1, 64, 
    4, 83, 8, 15, 6, 87, 1, 17, 7, 25, 5, 73, 0, 33, 3, 83, 2, 56, 
    4, 76, 0, 50, 1, 86, 3, 26, 2, 65, 7, 27, 8, 14, 6, 38, 5, 44
  };
  const int q0930[] = {
    9, 9, // Number of jobs and machines
    3, 30, 2, 37, 4, 67, 0, 41, 7, 24, 1, 92, 8,  5, 5, 29, 6, 68, 
    2, 63, 3, 23, 7, 40, 4, 64, 8, 60, 0, 89, 6, 79, 1, 48, 5, 16, 
    8, 21, 5, 71, 6, 98, 4, 54, 7, 52, 3, 72, 0, 45, 2, 41, 1, 22, 
    5, 77, 4, 46, 0, 30, 6, 86, 8, 61, 7, 31, 2, 99, 1, 22, 3, 41, 
    0, 96, 1, 50, 7, 51, 6, 52, 3, 81, 8, 19, 5, 42, 4, 54, 2, 89, 
    6, 45, 5, 66, 7,  9, 4, 51, 8, 82, 3, 26, 0, 59, 1,  5, 2, 53, 
    6, 86, 5, 19, 1, 17, 0, 37, 4, 55, 2, 10, 7, 63, 3, 86, 8, 44, 
    4, 88, 6, 79, 2,  7, 0, 77, 8, 15, 5, 69, 1, 67, 3, 11, 7, 48, 
    4, 41, 8, 35, 6, 32, 7, 92, 0, 71, 1, 91, 5, 62, 3, 44, 2,  6
  };
  const int q0931[] = {
    9, 9, // Number of jobs and machines
    5, 59, 6, 11, 7, 30, 4, 34, 8, 87, 1, 59, 2, 96, 0, 67, 3, 64, 
    7, 76, 8, 50, 3, 24, 0, 39, 2, 61, 1, 53, 5,  3, 6, 40, 4, 46, 
    2, 48, 6, 58, 7, 26, 4, 26, 5, 62, 1, 96, 3, 94, 8,  9, 0, 45, 
    6,  8, 0, 55, 4, 96, 2,  7, 5,  7, 8, 98, 1, 19, 7, 96, 3, 25, 
    5, 89, 0, 58, 1, 40, 7, 42, 4, 54, 8, 61, 6, 84, 3, 63, 2, 27, 
    6, 87, 7, 16, 4, 83, 2, 36, 0, 28, 8, 99, 3, 67, 1, 98, 5, 11, 
    0, 38, 4, 92, 2, 54, 8,  3, 3, 84, 5, 38, 1, 10, 6, 99, 7, 20, 
    6, 44, 8, 31, 7, 19, 2, 79, 3, 46, 1, 12, 4,  3, 5, 11, 0, 63, 
    8, 79, 3, 83, 6, 12, 7, 51, 4, 77, 2, 29, 1, 18, 5, 55, 0, 28
  };
  const int q0932[] = {
    9, 9, // Number of jobs and machines
    1, 96, 6, 44, 4, 80, 2, 19, 5,  6, 7, 97, 0, 27, 8, 14, 3, 33, 
    1, 29, 6, 60, 0, 11, 2, 60, 4, 49, 5, 85, 3, 19, 7, 80, 8,  1, 
    2, 69, 1, 15, 3, 92, 8,  3, 6, 13, 4, 48, 7, 67, 5, 81, 0, 63, 
    1, 35, 6, 44, 4, 54, 7, 84, 3, 44, 8, 30, 2, 54, 5, 82, 0, 89, 
    5, 32, 6, 12, 1, 52, 4, 98, 3, 15, 8, 31, 7, 66, 2, 63, 0, 80, 
    4, 90, 3, 40, 8, 23, 5, 44, 2,  8, 1, 95, 6, 26, 0, 76, 7, 11, 
    4, 49, 2, 35, 6, 59, 3,  4, 5, 60, 8, 27, 0, 32, 7, 87, 1, 63, 
    4, 82, 1, 21, 6, 51, 8, 25, 5, 56, 0,  1, 7, 26, 2, 48, 3,  4, 
    3, 44, 7, 85, 8, 25, 1, 44, 5, 90, 6, 58, 2, 99, 0, 77, 4, 26
  };
  const int q0933[] = {
    9, 9, // Number of jobs and machines
    7, 33, 6, 78, 1, 54, 0, 58, 3, 70, 8, 19, 5, 12, 2, 49, 4, 13, 
    7, 38, 3, 50, 1, 91, 2, 12, 6,  6, 0, 31, 8, 71, 4, 20, 5, 31, 
    3, 37, 1, 36, 7, 62, 8, 61, 5, 42, 0, 75, 4, 55, 2, 61, 6, 87, 
    2, 89, 8,  3, 1, 85, 0, 27, 4, 73, 5, 38, 7, 96, 3, 84, 6, 33, 
    0, 35, 5, 88, 6, 82, 4, 56, 1, 91, 3, 26, 7, 96, 2, 18, 8, 16, 
    3, 34, 4, 68, 6, 15, 2, 79, 7, 69, 0, 85, 1,  6, 8, 93, 5, 88, 
    5, 12, 0, 12, 7, 10, 6, 93, 8, 33, 3, 65, 4, 77, 2, 78, 1, 18, 
    7, 88, 4, 38, 3, 25, 0, 87, 2, 78, 6, 70, 5, 12, 1, 46, 8,  6, 
    7, 66, 8, 53, 2, 66, 4, 11, 0, 83, 3, 60, 1, 87, 6, 80, 5, 91
  };
  const int q0934[] = {
    9, 9, // Number of jobs and machines
    6, 59, 5, 32, 3, 91, 4, 57, 2, 41, 7, 82, 0, 98, 1, 78, 8,  6, 
    2, 21, 1, 96, 4, 66, 7,  4, 6, 10, 3, 56, 0, 47, 5, 63, 8, 13, 
    4, 20, 7, 61, 5, 68, 6, 49, 3, 14, 1, 38, 0, 93, 8, 97, 2, 89, 
    6, 32, 3, 81, 7, 16, 5, 73, 0, 37, 4, 63, 1, 37, 8, 99, 2, 66, 
    6, 67, 7, 82, 8, 41, 4, 74, 1, 30, 5, 84, 2, 60, 3, 70, 0, 40, 
    2, 31, 7, 88, 8, 75, 4,  6, 5, 10, 3, 26, 6, 14, 1, 15, 0,  3, 
    5, 64, 1, 42, 2, 60, 4, 84, 0, 22, 6, 50, 8, 78, 3, 49, 7, 18, 
    6, 82, 5, 78, 2, 54, 7, 61, 3, 90, 0, 25, 4, 80, 8, 95, 1,  1, 
    8, 99, 7, 20, 2, 67, 1, 44, 0, 40, 3,  4, 4, 34, 5, 91, 6, 44
  };
  const int q0935[] = {
    9, 9, // Number of jobs and machines
    1, 62, 7, 45, 4, 84, 3, 20, 5, 72, 0, 66, 6,  5, 2, 37, 8, 17, 
    7, 55, 6, 74, 2, 43, 3, 35, 0, 31, 5, 49, 4, 98, 8, 33, 1, 35, 
    0, 36, 8, 22, 3, 70, 4, 39, 6, 83, 5, 33, 1, 12, 7, 77, 2, 95, 
    3, 74, 7, 60, 8,  2, 6, 33, 2, 28, 4, 53, 1, 71, 0, 50, 5, 62, 
    4, 26, 0, 88, 7,  3, 1, 74, 2, 61, 6, 21, 3, 74, 8, 64, 5, 69, 
    7, 34, 3,  7, 4, 35, 6, 26, 2, 37, 0, 68, 1, 38, 5, 88, 8, 60, 
    4, 63, 0, 18, 3, 30, 2, 36, 8, 78, 7, 61, 1, 24, 6, 75, 5, 41, 
    5, 58, 3,  7, 2,  3, 6, 99, 7, 12, 8, 13, 4, 71, 1, 23, 0,  7, 
    6, 68, 7, 46, 0, 44, 5, 52, 3, 11, 1, 71, 2, 31, 8, 97, 4, 27
  };
  const int q0936[] = {
    9, 9, // Number of jobs and machines
    4, 33, 2, 83, 7, 33, 1, 81, 3, 68, 6, 74, 0, 48, 8, 78, 5, 65, 
    6, 31, 4, 50, 5, 46, 0, 46, 7, 53, 3, 92, 1, 54, 8, 57, 2, 30, 
    3, 46, 5, 71, 2, 20, 0, 31, 6, 19, 4, 86, 8, 48, 7, 87, 1,  5, 
    2, 16, 4, 29, 0, 78, 7, 53, 6, 97, 8, 45, 3,  6, 1, 87, 5,  4, 
    4, 47, 5, 42, 2, 63, 8, 65, 1, 27, 7, 95, 6, 16, 3, 75, 0, 82, 
    7, 14, 3, 63, 8, 67, 6,  3, 4, 85, 5, 58, 2, 32, 1, 52, 0, 53, 
    5, 26, 8,  7, 0, 86, 1, 59, 7, 67, 6, 62, 2, 30, 3, 29, 4, 55, 
    0, 39, 6, 54, 4, 49, 5, 16, 1, 50, 3, 38, 2, 28, 7, 32, 8, 31, 
    0, 50, 8, 77, 6, 31, 4, 16, 7, 50, 2, 90, 1, 63, 5, 69, 3, 82
  };
  const int q0937[] = {
    9, 9, // Number of jobs and machines
    0, 77, 5, 90, 2, 35, 3, 87, 1, 37, 7, 45, 6, 20, 4, 98, 8, 90, 
    2, 73, 7, 77, 3, 46, 0, 83, 1, 72, 4, 79, 5, 69, 6, 56, 8, 67, 
    7, 85, 3, 17, 4, 83, 6, 75, 8, 24, 2, 46, 0, 95, 5, 46, 1, 92, 
    4, 96, 2, 28, 0, 90, 1, 98, 5, 95, 7, 76, 6, 30, 3, 89, 8, 94, 
    0,  5, 7, 44, 3, 62, 5, 88, 8, 96, 1, 78, 4, 28, 2,  3, 6, 90, 
    4,  9, 8, 34, 5, 20, 6, 65, 0, 62, 7, 38, 2, 84, 3, 83, 1, 23, 
    4, 55, 0, 74, 5, 40, 8, 89, 7, 18, 6, 16, 3, 52, 2,  9, 1, 70, 
    7, 29, 4, 47, 6, 38, 0, 60, 3,  4, 2, 73, 5, 23, 8, 90, 1,  5, 
    6, 10, 2, 74, 7, 73, 4, 27, 0, 69, 5, 55, 1,  6, 8, 78, 3,  5
  };
  const int q0938[] = {
    9, 9, // Number of jobs and machines
    6,  7, 2, 60, 0, 99, 4,  9, 5, 55, 7, 42, 1,  8, 3, 89, 8,  9, 
    7, 61, 2, 42, 5, 75, 4, 60, 6, 62, 1, 38, 3, 90, 0, 81, 8, 19, 
    5,  6, 8, 61, 3, 30, 6, 75, 2, 77, 1, 41, 4, 43, 7, 73, 0, 86, 
    5, 50, 0, 36, 1, 44, 3, 56, 2, 41, 6, 97, 7, 74, 8, 16, 4, 40, 
    1, 15, 5, 69, 0, 11, 7, 94, 3, 43, 4, 61, 6, 84, 8, 39, 2, 26, 
    3, 45, 6, 64, 7, 57, 0, 53, 8, 79, 4, 62, 1, 87, 2, 65, 5, 21, 
    1, 99, 6, 44, 8, 42, 0, 85, 7, 34, 2, 85, 5, 37, 3,  3, 4, 44, 
    2, 52, 1, 33, 7, 35, 5, 92, 0,  5, 3, 35, 6, 24, 8, 30, 4, 56, 
    0, 79, 4, 44, 2, 85, 1, 42, 8, 83, 7, 81, 5, 59, 3, 51, 6, 83
  };
  const int q0939[] = {
    9, 9, // Number of jobs and machines
    4, 23, 3, 81, 7, 42, 6, 97, 5, 70, 2, 40, 0, 96, 1, 19, 8,  1, 
    7, 28, 6, 34, 0, 70, 2, 60, 1, 67, 8, 60, 3, 82, 5, 10, 4, 88, 
    4, 37, 3, 35, 1, 25, 6, 86, 2, 31, 0, 83, 5,  4, 7, 78, 8, 78, 
    7, 37, 6, 99, 5,  1, 2, 34, 3, 18, 0, 52, 8, 48, 1, 77, 4, 82, 
    6, 81, 5, 91, 0, 82, 3, 11, 1, 65, 2, 69, 8, 73, 4, 35, 7, 38, 
    5, 42, 6, 28, 8,  4, 7, 17, 4, 99, 2, 81, 0, 12, 3,  7, 1, 34, 
    7, 75, 8, 89, 4, 36, 2, 79, 6, 11, 1, 48, 0, 74, 5, 62, 3, 80, 
    0, 66, 3, 93, 2, 15, 6, 63, 1, 81, 5, 79, 7, 10, 4, 21, 8, 28, 
    4, 96, 3,  6, 8, 12, 2, 54, 1, 61, 7, 77, 6, 47, 5,  4, 0, 76
  };
  const int q0940[] = {
    9, 9, // Number of jobs and machines
    1, 28, 5, 10, 2, 29, 6, 13, 3, 32, 7, 68, 4, 73, 8, 95, 0, 83, 
    3, 13, 8, 54, 6, 89, 2, 11, 1, 13, 5, 90, 7, 53, 0, 44, 4, 16, 
    8, 55, 7, 82, 6, 95, 5, 55, 4, 97, 2, 96, 3, 78, 0, 80, 1, 80, 
    1, 62, 8, 40, 2, 45, 7, 82, 3, 34, 4, 29, 6, 45, 0, 73, 5, 31, 
    0, 17, 8,  3, 5, 21, 4, 20, 7, 63, 2, 73, 6, 33, 1,  1, 3, 68, 
    0, 22, 8, 15, 5, 43, 2, 26, 4, 23, 6, 54, 7, 34, 1, 58, 3, 27, 
    2, 81, 1, 96, 0,  4, 7, 50, 8, 56, 4,  4, 3, 27, 6,  9, 5, 43, 
    0, 28, 7, 83, 3, 13, 1, 33, 2,  7, 6, 86, 5, 92, 8, 79, 4, 75, 
    3, 46, 2, 95, 6, 80, 5, 56, 1, 51, 4, 27, 0, 97, 8, 34, 7, 98
  };
  const int q0941[] = {
    9, 9, // Number of jobs and machines
    8, 65, 4, 91, 1, 58, 6, 78, 3, 32, 0, 76, 2, 48, 5, 49, 7, 46, 
    2, 54, 6, 33, 5, 71, 0,  4, 7, 54, 4,  9, 3, 41, 1, 42, 8, 74, 
    5, 88, 2, 62, 8, 26, 6, 78, 4,  8, 1, 62, 3,  4, 7, 31, 0, 65, 
    7, 18, 0, 44, 8, 89, 1, 15, 2, 91, 5, 12, 6,  3, 3, 14, 4, 45, 
    4, 54, 7, 42, 0, 28, 2, 87, 1, 12, 3, 38, 5, 73, 8, 64, 6, 13, 
    5, 58, 3, 19, 7, 63, 8, 81, 6,  9, 2, 33, 1, 93, 4, 88, 0, 53, 
    7, 47, 8, 57, 6, 44, 4, 50, 1, 27, 2, 56, 5, 38, 3, 63, 0, 14, 
    5, 23, 0, 75, 4,  5, 8, 56, 3, 72, 1, 65, 6, 30, 7, 97, 2, 25, 
    2, 76, 7, 85, 0, 64, 5, 25, 1, 27, 3, 68, 8, 26, 4, 90, 6, 81
  };
  const int q0942[] = {
    9, 9, // Number of jobs and machines
    5, 49, 0, 54, 2, 34, 4, 36, 1, 14, 7, 48, 8, 35, 6, 64, 3, 16, 
    8,  7, 2,  8, 3, 67, 7, 93, 1, 60, 5, 12, 4, 48, 6, 88, 0, 81, 
    7, 24, 5,  8, 8, 91, 4, 44, 3, 55, 6, 95, 1, 66, 2, 67, 0, 43, 
    7, 25, 1, 30, 6, 45, 8, 51, 3, 71, 5, 64, 0, 60, 4, 11, 2, 28, 
    6, 43, 2, 10, 8, 31, 1, 92, 0, 78, 5,  5, 7, 27, 4, 48, 3, 76, 
    3, 78, 1, 53, 4, 27, 7,  7, 0, 27, 8,  3, 6, 17, 5,  1, 2, 58, 
    6, 34, 5, 44, 4, 77, 1, 45, 3, 56, 2, 89, 7, 59, 8, 45, 0,  7, 
    0, 18, 2, 87, 3, 97, 4, 97, 1, 39, 7, 83, 5, 36, 8, 99, 6, 61, 
    8, 86, 2, 19, 4, 22, 6, 46, 7, 68, 3,  1, 1, 31, 0, 24, 5, 66
  };
  const int q0943[] = {
    9, 9, // Number of jobs and machines
    2, 87, 8, 83, 7, 53, 4, 33, 1, 67, 5, 55, 0, 67, 3, 59, 6, 46, 
    3, 77, 8, 68, 6, 83, 7, 89, 0, 97, 1, 31, 2,  6, 4, 36, 5,  3, 
    7, 33, 0, 71, 5, 98, 1,  3, 3, 27, 4, 48, 2, 55, 8, 41, 6, 37, 
    4, 38, 8, 32, 0, 52, 5, 32, 3, 49, 6, 66, 2, 96, 1, 52, 7, 90, 
    1, 20, 6, 79, 2, 15, 8,  9, 3, 11, 7, 64, 5, 89, 4, 40, 0, 83, 
    5,  6, 4, 23, 3, 10, 2, 65, 7,  5, 1,  5, 0, 48, 6,  6, 8, 52, 
    1, 35, 3, 84, 6, 17, 5, 61, 4, 36, 0, 10, 2, 88, 7, 13, 8, 48, 
    8, 40, 3, 75, 1, 11, 6, 43, 5, 66, 2, 15, 0, 69, 4,  1, 7, 83, 
    1, 59, 0,  6, 2, 65, 8, 78, 4, 55, 6, 86, 3, 97, 5, 54, 7, 79
  };
  const int q0944[] = {
    9, 9, // Number of jobs and machines
    4, 90, 8, 63, 7, 50, 1, 91, 6, 53, 2, 24, 0, 43, 5,  3, 3, 70, 
    4,  8, 8, 84, 7, 76, 2, 65, 0, 35, 5, 71, 1, 52, 6, 69, 3, 25, 
    8, 55, 1, 57, 4, 86, 2, 48, 0, 60, 6, 98, 5, 81, 7, 30, 3, 34, 
    6, 50, 8, 76, 5, 73, 3, 65, 1, 81, 7, 26, 2, 39, 4, 42, 0, 81, 
    3, 18, 8, 50, 5, 30, 7, 81, 1, 68, 4, 84, 2,  7, 6, 28, 0, 44, 
    3, 16, 7, 13, 4,  8, 0, 69, 8, 84, 6, 66, 5, 46, 1,  2, 2, 73, 
    3, 86, 5, 87, 1, 29, 2, 65, 6, 41, 7,  9, 8, 26, 4, 38, 0, 28, 
    4, 43, 6, 58, 2, 83, 3, 18, 0, 23, 7, 89, 5, 11, 8, 57, 1, 67, 
    6, 83, 4, 41, 0, 35, 1, 66, 3, 19, 5, 48, 2, 80, 7, 56, 8, 96
  };
  const int q0945[] = {
    9, 9, // Number of jobs and machines
    6, 32, 8, 28, 5, 56, 7, 84, 0, 64, 2, 65, 3, 80, 1, 77, 4, 35, 
    8, 20, 3, 93, 6, 19, 2, 11, 1, 97, 0, 47, 7,  2, 5, 20, 4, 75, 
    1, 54, 2, 85, 8,  9, 4, 84, 7, 39, 3, 94, 0, 80, 6, 42, 5, 88, 
    1, 59, 4, 13, 5,  5, 7, 49, 6, 28, 2, 50, 8, 79, 0, 79, 3, 48, 
    2, 43, 0, 12, 1, 71, 4, 55, 6,  9, 7, 60, 3, 78, 5, 64, 8, 18, 
    4, 88, 0, 70, 8, 32, 2, 33, 3, 68, 5, 33, 1, 73, 6, 42, 7, 35, 
    8, 71, 1,  7, 4,  4, 7, 65, 2, 88, 5, 67, 3, 25, 0, 46, 6, 74, 
    5, 41, 2, 85, 7,  4, 4, 87, 1, 33, 8, 84, 3, 75, 6, 78, 0, 46, 
    0, 68, 5, 55, 6,  2, 4, 50, 8, 95, 2, 70, 7, 99, 1,  7, 3, 83
  };
  const int q0946[] = {
    9, 9, // Number of jobs and machines
    2, 48, 4, 38, 5,  8, 3, 34, 7, 10, 0, 21, 8, 44, 6,  7, 1, 60, 
    8, 52, 3, 60, 6, 36, 7, 35, 4, 59, 0, 60, 2, 64, 1, 23, 5, 69, 
    6, 24, 8, 14, 3, 23, 1, 70, 2, 22, 5, 73, 0, 47, 7, 33, 4, 59, 
    5, 25, 1, 48, 8, 49, 2, 49, 3, 92, 4, 89, 6, 11, 7, 80, 0, 51, 
    0, 93, 5, 66, 1, 93, 4, 70, 8, 24, 7,  3, 3, 66, 2, 10, 6,  5, 
    7, 32, 4, 12, 2, 94, 0, 45, 6, 65, 8, 68, 5, 34, 3,  4, 1, 54, 
    1, 58, 7, 78, 3,  7, 4, 90, 5, 56, 8, 45, 6, 47, 0, 56, 2,  9, 
    6, 85, 4, 77, 7, 60, 8, 87, 2, 64, 3, 96, 0,  4, 1, 92, 5, 60, 
    7, 29, 2, 63, 3, 88, 4,  9, 5, 43, 8, 84, 6, 93, 0, 55, 1, 50
  };
  const int q0947[] = {
    9, 9, // Number of jobs and machines
    8, 11, 2, 18, 6, 65, 0, 33, 3,  2, 5, 14, 7, 53, 1,  6, 4, 71, 
    7, 28, 5, 55, 4, 24, 8, 57, 6, 27, 0, 84, 3, 25, 1, 36, 2,  9, 
    1,  8, 7, 24, 0,  9, 2, 53, 5, 30, 6, 92, 3, 12, 8, 17, 4, 78, 
    3, 17, 8, 56, 7, 92, 0, 42, 2, 45, 5, 84, 6, 75, 4, 34, 1, 65, 
    2, 39, 5, 91, 3, 10, 6, 87, 7,  5, 0, 92, 8, 27, 4, 83, 1, 75, 
    3,  1, 8, 71, 6, 10, 1,  5, 2, 19, 7, 10, 4, 59, 0, 72, 5, 88, 
    7, 37, 2, 47, 0, 70, 4, 23, 6, 18, 1, 68, 5, 97, 8, 91, 3, 43, 
    1, 96, 5, 58, 6, 29, 0, 90, 7, 53, 8, 29, 4, 41, 2, 59, 3, 61, 
    4, 92, 7, 40, 3, 84, 5,  1, 6, 97, 1, 39, 2, 92, 8, 14, 0, 33
  };
  const int q0948[] = {
    9, 9, // Number of jobs and machines
    7, 37, 5, 23, 6, 89, 2, 45, 3, 68, 0, 82, 1, 87, 8, 44, 4,  6, 
    5, 50, 6, 29, 7, 46, 8, 61, 0, 24, 1, 87, 3, 37, 2, 17, 4, 36, 
    6, 65, 2, 45, 0, 52, 8,  9, 1, 94, 3, 56, 4, 64, 7, 31, 5, 96, 
    1, 62, 3, 69, 6, 96, 7, 31, 8, 67, 2,  8, 5, 74, 0, 99, 4, 16, 
    0, 82, 8, 21, 1, 42, 6, 56, 5, 46, 7, 32, 2, 29, 3, 60, 4, 69, 
    3, 39, 1, 30, 0, 49, 4,  5, 5, 23, 7,  7, 6, 45, 2, 23, 8, 88, 
    0, 32, 3,  1, 5, 30, 1, 11, 2, 68, 7, 26, 6, 13, 4, 89, 8, 84, 
    3,  2, 2,  5, 7, 58, 6, 60, 5, 86, 1, 38, 0, 56, 4, 50, 8, 58, 
    6, 29, 2, 84, 5, 91, 7, 35, 8, 45, 4, 88, 0, 36, 1, 66, 3,  2
  };
  const int q0949[] = {
    9, 9, // Number of jobs and machines
    6, 90, 4, 73, 7, 12, 5, 38, 1, 84, 2,  9, 3,  5, 8, 41, 0, 82, 
    2, 44, 8, 12, 5,  1, 7, 98, 0, 11, 6,  3, 3, 17, 1, 37, 4, 47, 
    6,  7, 3, 31, 2, 78, 5, 70, 0, 86, 7, 18, 1, 85, 8, 16, 4, 20, 
    2, 20, 3, 50, 1,  8, 0, 36, 4, 10, 7, 80, 5,  7, 8, 62, 6, 63, 
    6, 14, 8, 80, 2, 25, 1, 23, 5, 64, 0,  6, 3, 49, 7, 12, 4, 58, 
    6, 27, 7, 95, 1,  1, 3, 29, 5, 84, 4, 43, 0,  1, 2, 67, 8, 78, 
    0, 66, 4, 80, 2, 23, 6, 10, 1, 98, 3, 73, 7, 73, 5, 65, 8, 48, 
    6, 40, 0, 94, 7, 88, 3,  8, 8, 71, 5,  2, 4, 10, 1, 33, 2, 90, 
    0, 18, 2, 21, 1, 84, 3, 79, 4, 81, 5, 18, 8, 89, 6, 75, 7, 31
  };
  const int q0950[] = {
    9, 9, // Number of jobs and machines
    7, 95, 4, 55, 1, 63, 3,  9, 0, 17, 5, 62, 8, 45, 6, 20, 2, 84, 
    0, 63, 4, 60, 8, 15, 5, 79, 6, 82, 3,  2, 1, 16, 2, 90, 7, 39, 
    1, 35, 5, 86, 8, 77, 3, 78, 2, 56, 7, 99, 0, 24, 6, 15, 4, 11, 
    6, 27, 5, 29, 7, 16, 8, 76, 4, 96, 1, 74, 2, 18, 0, 72, 3, 19, 
    1, 45, 8, 35, 5,  7, 7, 18, 0, 31, 2, 46, 4, 80, 3, 25, 6, 56, 
    0, 93, 8, 16, 2, 63, 1, 60, 5, 71, 7, 97, 3, 59, 4, 96, 6, 40, 
    0, 60, 8,  8, 4, 94, 2,  2, 6, 95, 5, 26, 1, 59, 3, 51, 7, 55, 
    8, 10, 4,  2, 3, 72, 5, 50, 6, 88, 2, 66, 7, 55, 1, 83, 0,  3, 
    8, 30, 7, 64, 4, 39, 1, 75, 2, 75, 3, 48, 6, 70, 5, 42, 0,  1
  };
  const int q0951[] = {
    9, 9, // Number of jobs and machines
    5, 38, 7, 33, 1, 94, 0, 60, 3, 33, 2, 76, 4, 16, 6, 60, 8, 92, 
    4, 22, 6, 70, 1, 32, 5, 78, 3, 53, 7, 96, 0,  8, 8, 29, 2, 35, 
    8, 57, 7, 73, 0, 98, 4, 56, 5, 74, 2, 66, 3,  3, 1, 69, 6, 10, 
    2, 87, 7, 51, 5, 16, 8, 65, 0, 40, 1, 89, 4, 74, 6, 97, 3, 98, 
    5, 52, 1, 66, 7, 26, 3, 24, 2,  6, 0, 58, 4, 64, 8, 84, 6, 60, 
    3, 32, 4, 87, 0,  9, 2, 56, 1, 78, 7, 46, 5, 77, 6, 17, 8,  8, 
    5, 46, 4, 28, 6, 69, 7, 56, 2, 22, 1, 90, 3, 92, 8, 56, 0,  3, 
    5, 97, 4, 66, 8, 89, 0, 23, 7, 96, 3, 44, 1, 86, 2, 47, 6,  2, 
    3, 65, 7, 27, 6, 45, 1, 13, 0, 14, 8, 37, 5, 35, 2, 20, 4, 87
  };
  const int q0952[] = {
    9, 9, // Number of jobs and machines
    3, 51, 8, 22, 0, 83, 5,  6, 6, 34, 2,  5, 4, 36, 1, 28, 7, 46, 
    4,  7, 1, 97, 7, 25, 2,  4, 5, 88, 6, 89, 8, 17, 3, 67, 0, 10, 
    7, 21, 3, 65, 1,  1, 4, 46, 0, 72, 5, 41, 2, 84, 8, 18, 6, 66, 
    5, 23, 0, 71, 4, 34, 3, 23, 7, 54, 8, 32, 6, 44, 2, 61, 1, 65, 
    3,  5, 0, 71, 6, 97, 8, 26, 1, 30, 5, 19, 2, 68, 4, 52, 7, 62, 
    6, 63, 7, 93, 2, 39, 1, 53, 3, 58, 8, 39, 4, 43, 0, 31, 5, 21, 
    2, 66, 7, 46, 0, 41, 1, 27, 5, 24, 6, 92, 4, 90, 3, 97, 8, 50, 
    3, 52, 6,  7, 2, 90, 7, 84, 0, 26, 4, 67, 1, 79, 5, 40, 8, 92, 
    5, 19, 1, 30, 2, 70, 4, 91, 7, 96, 3, 97, 0,  5, 6,  2, 8, 23
  };
  const int q0953[] = {
    9, 9, // Number of jobs and machines
    2, 72, 6, 43, 4, 31, 7, 42, 5, 45, 8, 47, 1, 57, 3, 83, 0,  3, 
    0, 24, 8, 69, 6, 79, 7, 10, 1, 37, 3, 11, 5,  3, 4, 39, 2, 99, 
    0, 95, 7, 95, 6, 62, 3, 71, 4, 22, 8, 43, 5, 80, 2, 89, 1, 69, 
    5, 99, 1, 84, 8,  8, 4, 62, 7, 59, 2, 42, 0, 29, 3, 32, 6, 99, 
    4, 49, 3, 76, 6, 22, 1, 86, 7, 61, 2, 10, 0, 15, 5, 15, 8, 11, 
    0, 60, 4, 82, 6, 63, 8, 68, 5, 40, 2, 27, 1, 35, 7, 94, 3, 74, 
    5, 30, 7, 74, 1, 99, 8, 40, 6, 62, 3, 39, 0,  7, 2, 52, 4, 62, 
    6, 25, 8, 97, 0, 92, 4, 42, 5, 73, 3, 96, 1, 66, 7, 61, 2, 34, 
    5, 29, 4,  9, 6, 17, 1, 59, 7, 66, 0, 63, 3, 63, 8, 66, 2, 25
  };
  const int q0954[] = {
    9, 9, // Number of jobs and machines
    3, 65, 8, 34, 2, 44, 0, 85, 1, 12, 5, 11, 4, 96, 6, 40, 7, 69, 
    5, 58, 7, 32, 4,  1, 2, 11, 1, 82, 0, 90, 8, 86, 3, 61, 6, 54, 
    0, 28, 2, 90, 6, 18, 5, 66, 1, 37, 4, 80, 7, 72, 8, 74, 3, 98, 
    2, 15, 7, 44, 6, 43, 3, 72, 4, 91, 1, 10, 0, 38, 5, 77, 8, 44, 
    8, 25, 0,  4, 3, 85, 1, 54, 7, 72, 4, 16, 5, 44, 2, 29, 6,  9, 
    0, 30, 6, 25, 3, 77, 7, 59, 8, 66, 1, 11, 4, 21, 5,  5, 2, 46, 
    5, 37, 1, 80, 8, 52, 0,  5, 7, 32, 6, 38, 3, 80, 4, 90, 2, 15, 
    4, 71, 0, 62, 8, 87, 3, 18, 7, 81, 6, 98, 5, 97, 2,  8, 1, 31, 
    7, 13, 6, 77, 1,  2, 3, 27, 2, 55, 0, 24, 4, 26, 8, 57, 5, 69
  };
  const int q0955[] = {
    9, 9, // Number of jobs and machines
    6, 16, 0, 96, 8, 30, 3,  5, 2,  1, 5, 76, 7, 65, 4,  9, 1, 76, 
    5, 40, 6, 82, 4, 16, 7,  7, 1, 51, 3, 88, 2, 59, 0, 76, 8, 40, 
    5,  1, 8, 30, 6, 76, 1, 81, 4, 97, 7, 44, 0, 81, 3,  7, 2, 75, 
    1, 38, 8, 82, 2, 96, 3, 47, 6, 40, 0, 15, 7, 99, 5, 96, 4, 65, 
    4, 30, 3, 74, 5, 25, 1, 62, 8, 92, 2, 75, 0, 17, 7, 71, 6, 86, 
    6, 57, 1, 67, 2, 72, 8, 33, 7, 81, 5, 95, 3,  7, 0, 14, 4, 21, 
    5, 19, 3, 56, 7, 28, 1, 39, 8, 63, 4, 48, 2,  6, 0, 26, 6,  7, 
    0, 51, 2, 36, 6, 17, 5, 66, 7, 96, 4, 13, 1, 33, 3, 93, 8, 43, 
    3, 15, 1, 39, 0, 67, 2, 52, 4, 49, 6,  3, 5,  8, 7, 22, 8, 46
  };
  const int q0956[] = {
    9, 9, // Number of jobs and machines
    3, 78, 8,  8, 2, 55, 6, 52, 0, 28, 5,  4, 4, 34, 7, 14, 1, 62, 
    2, 47, 5,  2, 0, 69, 7, 91, 8,  3, 3, 56, 1, 16, 6, 36, 4, 66, 
    0, 33, 8,  2, 7, 26, 3, 71, 4, 90, 1, 36, 5, 14, 6, 88, 2, 53, 
    5, 33, 8, 34, 4, 11, 7, 77, 6, 56, 3, 11, 0, 29, 1, 78, 2, 93, 
    5, 92, 6, 72, 2, 68, 3, 70, 4, 79, 8, 69, 1, 59, 0, 60, 7, 33, 
    3, 86, 7, 95, 2,  5, 6, 50, 5, 20, 0, 22, 1, 56, 8, 87, 4, 94, 
    5, 14, 3, 79, 7, 80, 2, 40, 0, 39, 6, 95, 4, 12, 1, 60, 8, 12, 
    3, 15, 7, 94, 2, 68, 4, 59, 0, 46, 5,  8, 8, 17, 1, 71, 6, 86, 
    7, 16, 2, 63, 5, 16, 1, 73, 4, 70, 8, 42, 0, 24, 3, 70, 6, 30
  };
  const int q0957[] = {
    9, 9, // Number of jobs and machines
    8, 74, 3, 94, 0, 58, 5, 61, 7, 14, 2, 26, 4, 43, 1, 62, 6, 54, 
    7,  3, 4, 29, 6, 12, 8, 17, 2, 69, 5, 47, 0, 65, 1, 28, 3, 83, 
    3, 70, 2, 95, 1, 28, 7, 22, 0, 12, 5,  2, 8, 98, 6, 99, 4, 21, 
    2, 84, 4, 89, 6,  2, 3, 50, 1, 16, 8, 54, 5, 40, 0,  4, 7, 65, 
    7, 39, 2, 86, 0, 63, 3,  4, 1, 37, 5, 34, 4, 83, 6, 58, 8, 10, 
    0, 36, 3, 88, 4, 48, 7, 55, 6,  2, 5,  7, 8, 35, 2, 32, 1, 42, 
    3, 16, 7, 61, 6, 92, 1, 30, 4, 93, 5, 34, 0, 82, 2, 73, 8, 37, 
    0, 74, 4, 42, 6, 59, 8, 28, 5, 26, 1, 73, 7, 80, 2, 18, 3,  7, 
    2, 86, 5,  7, 6, 33, 3, 24, 7, 41, 1, 49, 0,  2, 4,  9, 8, 11
  };
  const int q0958[] = {
    9, 9, // Number of jobs and machines
    8,  8, 5,  6, 0, 78, 1, 83, 7, 39, 3, 56, 2, 30, 4, 44, 6, 20, 
    6, 54, 8, 91, 2, 66, 3, 53, 1, 77, 0, 40, 5, 54, 4, 63, 7, 45, 
    6, 81, 4, 16, 1, 27, 5, 48, 7, 36, 0, 18, 2,  7, 8, 99, 3, 70, 
    2, 81, 5, 64, 8, 39, 4, 73, 3, 14, 7, 79, 1, 71, 0, 34, 6,  8, 
    7,  8, 4, 10, 8,  1, 2, 64, 6, 57, 5, 84, 0, 41, 3, 38, 1, 24, 
    3, 37, 2, 85, 8, 84, 7, 84, 1, 25, 6, 94, 4, 67, 5, 87, 0, 12, 
    8, 74, 1, 60, 7, 28, 4, 18, 3, 86, 0, 40, 6, 70, 5, 96, 2, 62, 
    2, 71, 6,  1, 1, 97, 7, 71, 0, 84, 4, 56, 8, 11, 3, 92, 5, 34, 
    4, 46, 5, 67, 7, 91, 3, 87, 2, 47, 8, 65, 6, 80, 1, 20, 0, 81
  };
  const int q0959[] = {
    9, 9, // Number of jobs and machines
    0, 29, 7, 26, 3, 68, 8, 24, 4, 67, 6, 92, 5, 30, 1, 30, 2, 97, 
    3, 53, 2, 83, 6, 19, 4, 55, 0, 97, 1, 54, 7, 33, 8, 54, 5, 70, 
    7, 89, 1, 87, 3, 77, 0, 46, 5, 74, 8, 45, 6, 19, 2, 25, 4, 12, 
    4, 36, 0, 91, 5, 56, 7, 41, 2, 60, 1, 52, 3, 26, 6, 46, 8, 63, 
    3,  2, 1, 87, 2, 29, 8, 75, 7, 55, 5, 29, 0, 69, 6, 25, 4, 99, 
    4, 64, 2, 74, 5, 79, 0, 56, 1, 82, 7, 34, 3, 92, 6,  2, 8, 62, 
    0, 86, 3, 51, 5, 93, 7, 11, 6, 51, 2, 84, 1,  7, 4, 57, 8, 35, 
    6, 10, 5, 49, 8, 88, 4, 68, 3, 98, 7, 85, 1, 97, 0, 38, 2, 19, 
    8, 44, 1, 33, 3, 57, 2, 64, 7, 93, 4, 35, 5, 53, 0,  9, 6, 38
  };
  const int q0960[] = {
    9, 9, // Number of jobs and machines
    6,  1, 7, 38, 4, 51, 8, 18, 0, 73, 1, 32, 3, 49, 5, 64, 2, 65, 
    8, 39, 2, 64, 5, 16, 0, 92, 3, 73, 4, 31, 6, 84, 1,  7, 7, 73, 
    4, 63, 8, 17, 2, 46, 7, 35, 6, 95, 1, 44, 3, 11, 0, 38, 5, 46, 
    6,  6, 0, 37, 1, 40, 7,  6, 2, 55, 5, 50, 8, 96, 3,  8, 4, 78, 
    2, 19, 0, 72, 4, 95, 8, 42, 1, 12, 5, 14, 3, 65, 7, 44, 6, 23, 
    3, 33, 1, 73, 7, 97, 4,  3, 8, 83, 0, 15, 6, 89, 2, 22, 5, 59, 
    4, 76, 3, 84, 1, 20, 2, 56, 6, 78, 7, 27, 5,  2, 8, 58, 0, 60, 
    6, 26, 0, 57, 8, 41, 1, 72, 3, 33, 2, 32, 7, 86, 5, 94, 4, 12, 
    2, 13, 1, 70, 3, 56, 5, 21, 0, 20, 8,  8, 6, 49, 4, 25, 7, 80
  };
  const int q0961[] = {
    9, 9, // Number of jobs and machines
    3, 49, 7, 76, 2, 35, 5, 89, 0, 29, 6, 99, 1, 83, 8, 65, 4, 68, 
    4, 33, 6, 81, 8, 31, 7,  5, 5, 47, 1, 60, 3, 14, 0, 53, 2, 47, 
    0, 64, 3, 85, 4, 95, 8, 65, 2, 69, 7, 74, 1, 65, 6, 91, 5, 84, 
    0, 17, 3, 60, 6, 67, 5, 47, 8, 14, 1, 24, 4,  2, 7, 97, 2, 32, 
    4, 92, 5, 92, 2,  7, 8, 72, 3, 79, 0, 98, 6, 69, 1,  6, 7, 75, 
    0, 31, 4, 44, 2,  1, 3,  1, 8, 55, 1, 68, 5, 45, 6, 64, 7, 81, 
    7, 86, 1, 50, 6,  7, 8, 20, 5, 18, 0, 59, 2, 86, 3, 21, 4, 78, 
    5, 40, 6, 71, 2, 82, 4, 27, 1, 66, 0, 23, 8, 49, 3, 48, 7,  5, 
    0, 69, 1, 62, 7, 23, 6, 55, 3,  2, 4, 56, 5, 82, 8, 26, 2, 36
  };
  const int q0962[] = {
    9, 9, // Number of jobs and machines
    0, 78, 5, 85, 4,  8, 7, 26, 8, 40, 1, 62, 6, 80, 3, 77, 2, 54, 
    3, 17, 6, 81, 5, 25, 7, 47, 1, 20, 0, 76, 4, 27, 8, 86, 2, 59, 
    1, 32, 3, 87, 4, 56, 5, 10, 2, 37, 6, 52, 0, 71, 7, 67, 8, 37, 
    3, 13, 8, 75, 6, 15, 5,  6, 0,  2, 1, 33, 7, 75, 2, 95, 4, 31, 
    2, 63, 3,  5, 6, 43, 1, 40, 5, 29, 8,  3, 0,  2, 4, 16, 7, 96, 
    5, 16, 2, 84, 4, 45, 3, 14, 0,  9, 8, 86, 7, 31, 6, 94, 1, 53, 
    8, 16, 7, 11, 1, 26, 3, 22, 2, 78, 0, 15, 6, 95, 4, 66, 5, 53, 
    7, 79, 6, 93, 4, 60, 5, 47, 3, 15, 0, 69, 2, 17, 8, 14, 1, 38, 
    8, 33, 3, 68, 4, 51, 6, 33, 0, 30, 2, 85, 5, 95, 7, 83, 1, 39
  };
  const int q0963[] = {
    9, 9, // Number of jobs and machines
    4, 27, 1, 88, 3, 18, 6, 36, 2, 92, 7, 35, 0, 10, 5, 73, 8,  5, 
    5, 57, 6, 93, 8, 36, 3, 42, 4, 92, 0, 45, 7, 29, 1, 78, 2, 21, 
    4, 78, 0, 68, 6, 69, 7, 76, 2, 24, 5, 19, 1,  7, 3, 26, 8, 88, 
    1, 56, 8,  7, 6,  5, 4, 72, 5, 87, 0, 81, 3,  3, 7, 40, 2, 29, 
    4, 67, 8, 49, 3, 96, 5, 76, 1, 19, 2, 83, 7, 85, 0, 89, 6, 19, 
    6, 33, 7, 27, 8, 42, 2, 27, 4, 77, 5, 66, 1, 24, 0, 95, 3, 87, 
    6, 71, 5, 18, 1, 69, 4, 34, 3, 39, 7, 28, 8, 61, 2, 98, 0, 51, 
    5, 62, 7, 29, 4, 49, 0, 26, 6, 11, 2, 86, 8,  3, 3, 81, 1, 52, 
    0, 90, 5, 38, 8, 79, 7, 65, 2, 41, 6, 39, 3, 38, 1, 89, 4, 13
  };
  const int q0964[] = {
    9, 9, // Number of jobs and machines
    8,  8, 7, 13, 4, 13, 0, 12, 6, 13, 1, 24, 3, 59, 2, 99, 5, 32, 
    5, 11, 3, 60, 1, 35, 4, 87, 6, 99, 7,  7, 8,  8, 2, 52, 0, 49, 
    2, 21, 0, 69, 8, 33, 7, 79, 4, 11, 1, 31, 5, 94, 6,  8, 3, 63, 
    5, 86, 7, 24, 2, 73, 0, 71, 6, 56, 1, 72, 8, 62, 4, 99, 3, 26, 
    5, 21, 1, 46, 2, 32, 4, 30, 8, 35, 0, 73, 3, 37, 6,  7, 7, 67, 
    3, 53, 2, 73, 5, 85, 7, 20, 6,  8, 8, 87, 4, 96, 1, 81, 0, 54, 
    0,  7, 4, 68, 8, 65, 3, 79, 7, 56, 5, 94, 1,  7, 6,  1, 2, 76, 
    8, 31, 1, 26, 7, 54, 0, 10, 2, 60, 4, 38, 6, 56, 3, 98, 5,  4, 
    6, 72, 2,  5, 5, 32, 7, 65, 8, 88, 3, 48, 0, 26, 1, 11, 4, 59
  };
  const int q0965[] = {
    9, 9, // Number of jobs and machines
    5, 86, 7, 97, 1, 78, 0,  6, 8, 98, 3, 28, 6, 48, 2, 84, 4, 65, 
    1, 90, 4,  3, 7,  1, 0, 69, 2,  7, 6, 65, 3, 25, 8, 25, 5, 30, 
    2, 65, 8, 15, 5,  3, 1, 52, 4, 85, 6, 98, 3, 93, 0, 52, 7, 27, 
    0,  5, 3, 57, 8, 14, 5, 60, 1, 36, 7, 56, 6, 62, 2,  9, 4, 18, 
    1, 62, 2, 90, 3, 61, 6, 20, 5, 11, 4, 87, 7,  3, 0, 43, 8, 57, 
    2, 35, 0, 46, 1, 47, 6, 34, 5, 98, 3, 85, 4, 54, 7, 94, 8, 25, 
    6, 59, 0, 78, 4, 75, 2, 71, 1, 49, 5, 19, 7, 25, 8, 13, 3, 29, 
    4, 91, 3, 14, 5, 86, 8,  8, 0, 91, 2,  1, 1, 96, 6, 12, 7, 33, 
    3, 67, 1, 37, 8, 29, 0, 99, 4, 99, 7,  5, 6, 39, 5, 75, 2, 70
  };
  const int q0966[] = {
    9, 9, // Number of jobs and machines
    2, 47, 6, 66, 3,  5, 5, 55, 0, 77, 4, 48, 1, 42, 7, 87, 8, 69, 
    6, 84, 2, 85, 5, 71, 7, 99, 4, 68, 3, 77, 1, 69, 8, 46, 0, 90, 
    2, 85, 8, 29, 3, 10, 6, 37, 4, 45, 7, 16, 5, 40, 0, 66, 1, 54, 
    8, 89, 3, 11, 1, 53, 0, 65, 6, 69, 2, 63, 4, 73, 5, 52, 7, 91, 
    3, 16, 8, 67, 6, 39, 1, 65, 4, 53, 0, 40, 2, 37, 7, 77, 5, 40, 
    0, 34, 5, 19, 3, 37, 7, 11, 8, 65, 4,  1, 6, 88, 1, 54, 2, 85, 
    1, 81, 3, 97, 2, 31, 6, 75, 4, 71, 8, 23, 7,  3, 5, 63, 0, 30, 
    7, 99, 3, 18, 1, 88, 4, 58, 0, 92, 5,  5, 8, 33, 2, 27, 6, 47, 
    7, 27, 2, 17, 3,  2, 0, 41, 8, 23, 5, 26, 6, 68, 1, 43, 4, 39
  };
  const int q0967[] = {
    9, 9, // Number of jobs and machines
    0, 39, 1, 82, 4, 43, 3, 41, 2, 33, 8, 30, 5, 23, 6,  9, 7, 28, 
    6, 72, 2, 35, 3, 24, 0, 12, 7, 51, 5, 22, 8, 48, 1, 76, 4, 28, 
    5, 67, 3, 60, 7, 24, 1, 22, 2, 97, 4, 17, 6,  1, 0, 73, 8, 91, 
    5, 69, 6,  6, 0, 34, 7, 59, 2, 71, 3, 57, 4, 96, 1, 72, 8, 32, 
    5, 81, 7, 89, 3, 10, 4, 96, 1, 88, 6, 90, 0, 13, 8, 86, 2, 90, 
    0, 19, 1, 66, 5, 66, 7, 79, 6, 20, 4, 56, 2, 67, 3, 53, 8,  2, 
    4,  5, 6, 74, 8, 65, 3, 15, 0, 59, 2,  4, 5, 79, 1, 21, 7, 21, 
    6, 94, 1,  5, 4, 10, 3, 74, 5,  1, 8, 21, 7, 72, 2, 58, 0, 75, 
    1,  4, 4, 79, 7, 92, 2, 40, 6, 53, 3, 73, 8, 95, 0, 88, 5, 66
  };
  const int q0968[] = {
    9, 9, // Number of jobs and machines
    4,  9, 2, 43, 1, 68, 0, 64, 6, 22, 5, 50, 7, 47, 8, 69, 3, 77, 
    3, 45, 1,  5, 8, 43, 0, 27, 2, 73, 5, 30, 7, 16, 4, 74, 6, 16, 
    1, 40, 0, 61, 7, 91, 4, 15, 3, 27, 8, 69, 6, 11, 2, 84, 5, 53, 
    7, 64, 5, 45, 1, 48, 3, 40, 4, 15, 0, 60, 8, 38, 6, 71, 2, 28, 
    5, 88, 2, 15, 7, 89, 0, 45, 4, 58, 6, 21, 3, 21, 1, 94, 8, 21, 
    4, 30, 6, 90, 0, 89, 8, 17, 5, 20, 1, 56, 2, 48, 3, 92, 7, 56, 
    8, 54, 4, 53, 0, 34, 3, 60, 6, 16, 7, 59, 1, 65, 5, 32, 2, 88, 
    5, 33, 6, 10, 0, 36, 1, 72, 7, 16, 8, 85, 2, 47, 3, 43, 4, 59, 
    7, 60, 2, 33, 8, 35, 3, 10, 5, 58, 4, 50, 1, 90, 0, 96, 6, 22
  };
  const int q0969[] = {
    9, 9, // Number of jobs and machines
    8, 62, 4, 84, 3, 89, 2, 89, 7, 98, 6, 46, 0, 21, 5, 37, 1, 70, 
    2, 45, 6, 79, 1,  4, 0,  2, 7, 77, 5, 16, 3, 78, 4, 53, 8, 46, 
    2, 94, 7, 15, 4,  9, 0, 46, 5, 65, 3, 53, 8, 71, 1,  1, 6, 57, 
    5, 19, 1,  9, 0, 34, 4, 51, 8, 16, 7, 68, 6, 26, 3, 99, 2, 56, 
    7, 50, 0, 27, 2,  7, 4, 61, 6,  7, 1, 23, 8, 14, 5, 28, 3, 74, 
    8, 73, 5, 65, 2, 61, 6, 80, 3, 86, 7, 46, 4, 95, 0, 85, 1, 75, 
    3, 84, 6, 56, 2, 74, 0, 45, 8, 82, 1, 53, 4, 20, 7, 96, 5, 38, 
    4, 87, 0, 32, 1, 10, 2, 19, 3, 25, 7, 82, 6, 72, 5, 27, 8, 34, 
    7, 56, 2, 89, 5, 56, 6,  5, 1, 35, 8, 52, 4, 90, 0, 17, 3, 78
  };
  const int q0970[] = {
    9, 9, // Number of jobs and machines
    4, 88, 1, 17, 2, 68, 7, 36, 8, 53, 3, 77, 5, 47, 6, 96, 0, 84, 
    3, 59, 8, 92, 0, 31, 2, 62, 6, 10, 4, 25, 5, 40, 7, 34, 1, 67, 
    7, 89, 8, 46, 5,  8, 2, 52, 0, 25, 3, 56, 6, 65, 4, 48, 1, 48, 
    0, 18, 8, 33, 3, 97, 6, 64, 1, 16, 4, 30, 5, 56, 7, 78, 2, 28, 
    4, 12, 3,  6, 5,  9, 1, 53, 8, 69, 6, 11, 0, 51, 2, 53, 7, 69, 
    3, 32, 5, 76, 7, 79, 2, 43, 0, 90, 8, 27, 6, 81, 1, 76, 4,  8, 
    2, 82, 7, 63, 4, 18, 0, 30, 5, 51, 8, 42, 6, 96, 1, 81, 3, 38, 
    4, 32, 7,  4, 6, 93, 0, 24, 3, 97, 5,  4, 8, 57, 1, 22, 2, 46, 
    4, 32, 1, 43, 7, 56, 8,  4, 3, 32, 6, 69, 5, 94, 2, 37, 0,  7
  };
  const int q0971[] = {
    9, 9, // Number of jobs and machines
    5, 54, 7, 61, 3, 27, 0,  2, 2, 33, 1, 62, 8, 67, 6, 94, 4, 23, 
    5, 81, 8, 32, 6, 81, 2, 23, 3, 53, 4, 24, 7,  5, 0,  5, 1, 50, 
    7, 19, 3,  3, 4, 23, 6, 24, 2, 67, 8,  2, 5, 27, 1, 70, 0, 74, 
    3, 97, 8, 92, 1, 24, 7, 67, 0, 56, 4, 46, 2, 21, 6, 86, 5, 88, 
    7, 12, 1, 34, 2, 12, 8, 70, 0, 75, 4, 88, 5, 43, 6, 16, 3, 84, 
    3,  9, 4, 56, 7, 19, 0, 83, 2, 78, 8, 36, 6, 76, 1, 50, 5, 56, 
    0, 33, 7, 67, 5,  2, 2, 48, 8, 59, 4, 51, 6, 31, 1, 39, 3, 93, 
    8, 69, 7, 75, 1, 20, 0, 43, 5, 27, 4, 21, 2, 99, 3, 43, 6, 18, 
    5, 64, 1, 91, 2, 77, 4,  5, 0, 89, 3, 83, 6, 65, 7, 86, 8, 66
  };
  const int q0972[] = {
    9, 9, // Number of jobs and machines
    2, 33, 0, 45, 3, 31, 1, 45, 4, 36, 7, 82, 6, 43, 5, 89, 8, 10, 
    0, 86, 1, 83, 2, 49, 7, 87, 6, 49, 3, 48, 4, 30, 5, 69, 8, 57, 
    1, 99, 2, 98, 3, 98, 8, 73, 5, 91, 7, 92, 0, 84, 4, 30, 6, 47, 
    4, 93, 7, 45, 5, 52, 1, 72, 6, 77, 0, 87, 3,  1, 2, 79, 8, 15, 
    1, 61, 3, 11, 8,  3, 4, 85, 7, 79, 2,  6, 5, 63, 0, 71, 6, 93, 
    2, 16, 4, 12, 7, 33, 0,  8, 8, 49, 3, 87, 5, 67, 6, 86, 1, 77, 
    3, 60, 5, 17, 4, 41, 2, 21, 8, 67, 0, 19, 7, 87, 6, 82, 1, 28, 
    6, 75, 8, 47, 4, 84, 7, 42, 0,  2, 5, 68, 3, 77, 2,  5, 1, 99, 
    2, 64, 1, 86, 6, 30, 3, 98, 8, 87, 4, 81, 7, 61, 5, 63, 0, 87
  };
  const int q0973[] = {
    9, 9, // Number of jobs and machines
    1, 51, 4, 82, 2, 51, 3, 60, 0, 49, 6, 90, 7, 86, 8, 42, 5, 11, 
    4, 44, 1,  7, 2, 30, 0, 28, 3, 45, 8, 85, 7,  2, 5, 48, 6, 95, 
    5, 39, 1, 80, 2, 24, 3, 67, 6, 21, 4, 60, 8, 97, 0, 24, 7, 92, 
    3, 74, 5, 74, 2, 27, 1, 44, 0, 10, 4, 34, 7, 62, 8, 85, 6,  2, 
    4, 13, 2, 22, 3, 11, 8, 72, 7, 28, 5, 31, 1, 37, 6, 26, 0, 13, 
    8,  2, 1, 85, 2, 75, 7, 77, 0, 39, 3, 39, 4, 14, 6, 82, 5, 71, 
    7, 82, 3, 13, 1, 92, 4,  3, 2, 21, 5, 22, 6, 51, 0, 52, 8,  5, 
    7, 43, 6, 75, 4, 81, 3, 18, 1, 27, 2, 30, 8, 17, 0, 48, 5, 18, 
    7,  4, 1, 18, 2, 17, 0, 87, 5, 22, 3, 86, 4, 74, 8, 43, 6, 10
  };
  const int q0974[] = {
    9, 9, // Number of jobs and machines
    8, 39, 3, 57, 4, 23, 6, 93, 0, 89, 5, 14, 2, 58, 1, 54, 7, 69, 
    5, 50, 0, 96, 6, 32, 2,  1, 7, 19, 4, 86, 8, 30, 3, 11, 1, 36, 
    6, 59, 0, 29, 1, 21, 2, 91, 8, 75, 3,  9, 4, 28, 7, 41, 5, 96, 
    6, 46, 3, 34, 2, 96, 5, 79, 8, 96, 0,  2, 7, 66, 4, 79, 1, 78, 
    8, 40, 5, 66, 2, 37, 0, 62, 7, 90, 6, 22, 3, 33, 4, 63, 1, 46, 
    0, 65, 5, 20, 1, 78, 3, 67, 7, 36, 4, 63, 8,  9, 2, 13, 6, 18, 
    2,  4, 0, 37, 4, 31, 1, 40, 8, 19, 6,  3, 3, 81, 5, 84, 7, 67, 
    5, 52, 7, 40, 1, 16, 8, 95, 4, 48, 6, 66, 2,  8, 3, 57, 0, 68, 
    6,  9, 4, 38, 3, 62, 5, 76, 1, 89, 8, 89, 7, 59, 0, 82, 2, 92
  };
  const int q0975[] = {
    9, 9, // Number of jobs and machines
    6, 45, 2, 16, 4, 66, 0, 27, 5, 66, 7, 60, 3, 42, 8, 28, 1, 35, 
    5, 65, 0, 45, 8, 50, 3, 38, 1, 93, 2, 84, 6, 90, 4,  6, 7, 73, 
    1, 63, 5, 50, 7, 88, 6, 83, 8, 22, 0, 96, 2, 39, 4, 70, 3,  6, 
    6, 93, 3, 63, 7, 53, 0,  5, 4,  4, 5, 72, 2, 95, 1, 74, 8, 38, 
    8, 71, 1, 26, 3, 11, 0,  5, 4, 10, 5, 13, 2, 43, 6, 68, 7, 16, 
    6, 57, 2, 68, 3, 39, 7, 88, 5, 67, 4, 44, 8,  8, 1, 15, 0, 48, 
    8, 32, 0, 62, 1, 16, 2, 70, 6, 74, 4, 78, 3, 99, 7, 37, 5, 61, 
    8, 19, 0, 79, 4,  9, 1, 73, 2, 97, 6, 79, 5, 20, 3, 54, 7, 47, 
    8,  2, 2, 30, 4, 96, 3, 14, 7, 64, 6, 49, 5, 38, 0, 31, 1, 49
  };
  const int q0976[] = {
    9, 9, // Number of jobs and machines
    0, 49, 8, 52, 1, 73, 3, 47, 2, 70, 6, 92, 5, 31, 7, 30, 4, 31, 
    8, 23, 5, 82, 1, 80, 0, 99, 4, 19, 7,  1, 2, 71, 6, 41, 3, 25, 
    5, 19, 0, 57, 3, 32, 4, 27, 6, 14, 2,  2, 1, 47, 7, 57, 8, 70, 
    7, 79, 2, 66, 6, 18, 3, 74, 1,  7, 5, 94, 4, 70, 8, 60, 0,  5, 
    0, 47, 8, 50, 7, 23, 4, 51, 6, 49, 1, 97, 3, 68, 2, 42, 5, 54, 
    4, 82, 1,  6, 3, 28, 6,  3, 0, 73, 7, 82, 2, 33, 8, 25, 5, 59, 
    0,  7, 7,  1, 8, 55, 4, 46, 5, 70, 2, 64, 3, 96, 1, 90, 6, 37, 
    1, 37, 3, 37, 5, 69, 8, 91, 4,  7, 7, 22, 2, 82, 0, 93, 6, 67, 
    7, 90, 0, 70, 1,  6, 4, 33, 3, 60, 8, 75, 6, 33, 2, 62, 5, 55
  };
  const int q0977[] = {
    9, 9, // Number of jobs and machines
    8, 68, 1, 28, 5,  7, 0, 20, 3,  6, 2, 44, 7, 71, 4, 21, 6, 15, 
    0, 37, 5, 36, 2,  6, 4,  3, 8, 86, 1, 66, 7, 35, 6, 76, 3, 29, 
    1, 37, 5, 28, 2, 25, 6, 38, 7, 44, 8, 23, 0, 28, 4, 48, 3, 26, 
    0, 15, 2,  6, 8, 16, 3, 30, 7, 58, 1, 52, 5, 13, 4, 55, 6, 76, 
    5, 15, 1, 86, 4, 29, 8, 47, 3, 75, 6, 58, 2, 11, 7, 56, 0, 59, 
    3, 84, 4, 12, 8, 42, 5, 59, 1, 24, 0, 74, 7, 19, 2, 39, 6, 40, 
    5, 57, 2, 58, 3, 63, 0, 85, 4, 28, 7, 74, 1, 57, 6, 57, 8, 10, 
    0, 42, 7, 96, 3, 83, 5, 11, 6, 95, 4, 81, 1, 39, 2, 23, 8, 54, 
    7,  8, 4, 75, 5, 82, 6, 43, 0, 55, 1, 48, 3,  8, 2, 81, 8, 21
  };
  const int q0978[] = {
    9, 9, // Number of jobs and machines
    3, 62, 4, 97, 7, 71, 2, 71, 6, 59, 8, 81, 0, 77, 1, 18, 5, 79, 
    3, 22, 7, 21, 8,  8, 2, 58, 1, 64, 6, 90, 4, 33, 0, 16, 5, 60, 
    7,  8, 4,  3, 3, 78, 6,  7, 0, 43, 2,  2, 8, 88, 1, 91, 5, 55, 
    5, 57, 4, 43, 6, 74, 0, 82, 7, 29, 1, 21, 2, 13, 8, 99, 3,  5, 
    2, 43, 6, 36, 4, 57, 0, 74, 7, 74, 1, 81, 8, 90, 5, 35, 3, 72, 
    7, 51, 5, 53, 2, 64, 0, 93, 3, 36, 4, 62, 1, 61, 8, 59, 6, 31, 
    0, 18, 8, 24, 6, 64, 7, 99, 4, 30, 3, 27, 1, 34, 2, 69, 5, 95, 
    5, 19, 6, 88, 8, 23, 3, 36, 0, 73, 4,  5, 2,  6, 1, 22, 7, 74, 
    2, 89, 8, 22, 1, 10, 3, 25, 7, 87, 5, 54, 4, 22, 0, 94, 6, 23
  };
  const int q0979[] = {
    9, 9, // Number of jobs and machines
    2, 93, 6, 74, 0, 21, 7, 61, 4, 22, 1, 59, 8, 43, 5, 94, 3, 92, 
    7, 81, 8, 73, 0, 83, 1, 31, 2, 81, 4, 33, 6, 86, 3, 12, 5, 98, 
    0, 44, 6, 61, 3, 36, 5, 84, 8, 31, 1, 65, 2, 25, 7, 73, 4, 23, 
    3, 98, 4, 85, 2, 26, 8, 50, 6, 65, 0, 11, 7, 95, 5, 55, 1, 38, 
    4, 28, 1, 74, 3,  6, 7, 84, 8,  2, 6, 26, 0, 97, 5, 26, 2, 27, 
    7,  8, 5, 92, 1,  1, 3, 85, 2,  8, 8, 75, 4, 17, 6, 15, 0, 49, 
    7, 24, 1, 16, 4, 73, 0,  5, 3, 56, 6, 30, 5, 76, 2, 81, 8, 44, 
    7, 86, 8, 54, 1, 96, 0, 87, 3, 60, 5, 49, 4, 89, 6, 68, 2,  2, 
    5, 99, 6, 34, 4, 72, 3, 50, 0, 34, 1, 83, 8,  7, 2, 33, 7, 40
  };
  const int q0980[] = {
    9, 9, // Number of jobs and machines
    8, 15, 6, 50, 3, 79, 7, 97, 2, 34, 5, 30, 0, 86, 1, 45, 4, 61, 
    1, 77, 8, 47, 2, 12, 0, 42, 7,  1, 4, 69, 5, 52, 6, 99, 3, 38, 
    8, 50, 5, 57, 7, 30, 6, 12, 3, 36, 0, 25, 4,  7, 2,  3, 1, 28, 
    4, 27, 3, 36, 6,  3, 5, 99, 1, 45, 0, 82, 8, 40, 7, 19, 2, 51, 
    5, 40, 6, 26, 1, 16, 4, 24, 3, 76, 8, 10, 2, 13, 7, 55, 0, 56, 
    8, 28, 6, 37, 5, 68, 4, 25, 2, 61, 3, 25, 1, 98, 7, 91, 0, 74, 
    2, 43, 5, 51, 7, 93, 1, 52, 4, 76, 8, 61, 0, 38, 6, 31, 3, 73, 
    8, 24, 3, 16, 6, 16, 1, 72, 0, 24, 2, 76, 4,  3, 7, 96, 5, 95, 
    2, 25, 0, 53, 7, 68, 6, 71, 8,  3, 1, 27, 4, 89, 5, 80, 3, 74
  };
  const int q0981[] = {
    9, 9, // Number of jobs and machines
    7, 65, 4, 36, 8, 19, 6, 36, 0, 40, 1, 20, 2, 23, 5, 79, 3,  5, 
    6, 27, 4, 15, 0, 92, 5, 21, 8, 71, 2,  5, 3, 35, 7, 72, 1, 37, 
    1, 27, 0, 72, 4, 80, 7, 50, 8, 30, 2, 45, 6, 93, 5, 36, 3, 78, 
    4, 26, 0, 68, 1, 35, 8, 52, 3, 83, 7, 34, 6, 70, 2, 57, 5, 10, 
    5, 10, 4, 94, 2, 51, 3, 69, 7, 46, 6, 15, 0, 67, 8, 59, 1, 12, 
    3, 63, 1, 11, 4, 27, 8, 47, 2, 14, 6, 58, 5, 32, 0, 87, 7, 97, 
    4, 79, 8,  7, 0, 10, 7, 17, 1,  5, 2, 48, 5, 40, 6, 38, 3, 49, 
    1, 21, 8,  5, 2, 14, 7, 44, 6,  1, 3, 38, 4, 21, 0, 80, 5, 43, 
    0, 23, 6, 97, 8, 79, 2, 69, 3, 53, 7, 79, 1, 51, 4,  9, 5, 12
  };
  const int q0982[] = {
    9, 9, // Number of jobs and machines
    8, 58, 5, 55, 3, 39, 7, 60, 0, 24, 4, 60, 1, 30, 6, 11, 2, 65, 
    4, 52, 7, 56, 0, 64, 1,  9, 5, 90, 8, 17, 6, 73, 3, 85, 2, 25, 
    0, 27, 4, 72, 6, 14, 5, 15, 3, 93, 1, 50, 8, 15, 2, 18, 7, 68, 
    0, 94, 7, 57, 2, 85, 8, 90, 6, 73, 1, 60, 5, 86, 4, 81, 3, 58, 
    1, 63, 6,  3, 8, 84, 4, 29, 7, 94, 3, 86, 0, 43, 2, 94, 5, 79, 
    7, 16, 2, 50, 6,  7, 3, 91, 5, 87, 4, 96, 0, 38, 1, 45, 8, 85, 
    6, 14, 1, 55, 4,  8, 3, 33, 2, 85, 7, 87, 0,  1, 5, 71, 8, 44, 
    1, 34, 8, 51, 0, 99, 3, 91, 7, 60, 6, 55, 5, 84, 2, 80, 4, 82, 
    5, 90, 7, 45, 1, 15, 3, 19, 4, 76, 0, 55, 2, 23, 6, 13, 8, 18
  };
  const int q0983[] = {
    9, 9, // Number of jobs and machines
    6, 60, 0, 35, 2, 33, 1, 15, 4,  5, 8, 85, 7, 20, 5, 94, 3, 86, 
    4, 37, 2, 18, 5, 51, 3, 72, 0, 74, 1, 48, 6, 74, 8, 72, 7, 60, 
    7, 21, 4, 70, 6, 55, 0, 10, 3, 88, 5, 33, 8, 40, 1, 19, 2, 31, 
    4, 68, 7, 68, 1, 58, 5, 72, 2, 37, 3, 38, 8, 94, 6, 59, 0, 87, 
    6, 89, 4, 20, 1, 70, 2, 43, 5, 78, 0, 80, 7, 98, 8, 89, 3, 98, 
    1, 19, 6, 19, 8, 76, 2, 65, 0, 53, 5, 82, 4, 79, 3, 63, 7, 87, 
    0, 63, 7, 87, 8, 46, 2, 96, 1, 76, 6, 13, 5, 81, 4, 25, 3, 46, 
    3, 37, 6, 70, 5, 38, 0, 96, 2, 35, 1, 82, 7, 26, 8, 78, 4, 47, 
    8, 40, 2, 95, 3, 61, 5, 37, 0, 46, 1, 30, 7, 62, 4, 58, 6, 57
  };
  const int q0984[] = {
    9, 9, // Number of jobs and machines
    4,  1, 6, 71, 7,  5, 3,  9, 5, 76, 8, 66, 1, 62, 0, 27, 2, 56, 
    7, 56, 3, 45, 8, 46, 2, 38, 6, 74, 0,  8, 1, 71, 4, 99, 5, 36, 
    2,  3, 5, 33, 0,  5, 6, 98, 8, 16, 4, 32, 1, 80, 3, 78, 7, 92, 
    1, 93, 7, 39, 5, 12, 3, 16, 6, 21, 4, 42, 0, 16, 8, 10, 2,  8, 
    4, 33, 6, 60, 1,  8, 3, 75, 0, 79, 7, 24, 8, 42, 5,  6, 2, 38, 
    5, 95, 2, 36, 8, 84, 3, 30, 4, 11, 7, 46, 0, 41, 1, 34, 6, 26, 
    5, 74, 2, 27, 6, 48, 3, 82, 8, 55, 1, 45, 0, 98, 7, 75, 4, 39, 
    3, 56, 7,  5, 5, 58, 8, 15, 1, 27, 0, 39, 4, 30, 2,  6, 6, 40, 
    6, 13, 4, 20, 7, 55, 1, 67, 5, 92, 2, 20, 8, 10, 3,  1, 0,  3
  };
  const int q0985[] = {
    9, 9, // Number of jobs and machines
    0, 28, 4, 90, 1, 69, 2,  5, 5, 39, 6, 62, 3, 62, 8, 60, 7, 67, 
    0, 57, 8, 87, 7,  4, 3, 88, 1, 45, 4, 25, 2, 81, 5, 93, 6, 84, 
    8, 53, 1, 53, 5, 50, 4, 27, 0, 54, 6, 92, 3, 65, 7, 41, 2, 38, 
    8, 73, 7, 52, 3, 43, 0, 60, 2,  5, 1, 89, 6, 89, 5, 75, 4, 55, 
    8, 71, 7, 23, 3, 87, 1,  7, 0,  7, 2, 96, 5, 18, 6, 40, 4, 42, 
    5, 46, 6, 83, 1, 73, 4, 49, 8, 53, 2, 31, 7, 47, 3, 92, 0, 83, 
    8, 21, 4, 11, 0,  2, 7, 40, 2, 37, 6, 92, 5, 93, 1, 84, 3, 38, 
    5, 61, 1, 33, 7, 51, 8, 41, 2, 43, 0, 10, 3, 83, 4, 28, 6, 26, 
    4, 60, 2, 70, 3, 90, 1, 77, 8, 45, 6, 21, 5, 40, 0, 38, 7, 96
  };
  const int q0986[] = {
    9, 9, // Number of jobs and machines
    3, 27, 2, 50, 8, 49, 7, 52, 4, 41, 0, 96, 5, 39, 1,  3, 6, 82, 
    6, 75, 5, 74, 4, 89, 3, 34, 1, 95, 2, 36, 8, 69, 0, 93, 7, 54, 
    0, 59, 6, 77, 7, 81, 3, 40, 5, 23, 4, 51, 1, 55, 2, 34, 8, 65, 
    1, 56, 3, 21, 7, 70, 4, 12, 0, 99, 5, 28, 6, 18, 8, 60, 2, 82, 
    3,  7, 4, 44, 0, 93, 2, 75, 6, 49, 5, 77, 8, 14, 1, 21, 7, 73, 
    2, 71, 7,  7, 3, 70, 5, 41, 4, 75, 0, 44, 1, 33, 6, 69, 8, 47, 
    7, 91, 6, 27, 1, 63, 3, 25, 0, 54, 2, 26, 5, 32, 4, 26, 8, 59, 
    7, 52, 3, 93, 8, 80, 5, 81, 6, 30, 0,  3, 2, 97, 4, 97, 1, 43, 
    3, 16, 2, 17, 4, 41, 8, 25, 5, 23, 7, 74, 1, 81, 6, 32, 0, 39
  };
  const int q0987[] = {
    9, 9, // Number of jobs and machines
    4, 88, 2, 42, 6, 87, 0, 79, 7,  3, 3, 67, 5, 75, 8,  4, 1, 25, 
    1, 43, 8, 45, 6, 80, 5, 97, 3, 35, 0,  7, 4, 65, 2, 74, 7, 41, 
    6, 56, 3, 29, 1, 50, 0, 17, 5, 90, 4, 53, 2,  6, 8, 66, 7, 43, 
    8, 80, 7, 22, 6, 69, 5, 61, 0, 36, 1, 42, 4, 31, 2, 71, 3, 69, 
    2, 50, 5, 78, 7, 94, 8, 82, 4, 10, 6, 34, 0, 64, 1, 42, 3, 97, 
    8, 10, 1, 40, 0, 92, 3, 74, 4, 37, 6, 98, 5, 29, 7, 78, 2, 94, 
    4,  9, 6, 70, 5,  9, 1, 75, 8, 88, 3, 77, 7,  1, 0, 83, 2,  1, 
    8, 64, 6, 54, 5, 85, 7, 10, 3, 13, 1, 88, 2, 47, 4, 50, 0, 20, 
    2, 25, 1, 82, 3, 65, 4, 67, 7, 69, 6, 89, 0, 15, 8, 57, 5, 49
  };
  const int q0988[] = {
    9, 9, // Number of jobs and machines
    4, 16, 8, 23, 5, 28, 1, 48, 0, 73, 6, 22, 3, 16, 7, 70, 2, 25, 
    5, 13, 4, 78, 0,  1, 8, 54, 6, 18, 7, 31, 1, 81, 2, 97, 3, 32, 
    6, 67, 0, 57, 1, 62, 4, 19, 3, 10, 5, 96, 2, 88, 8,  7, 7, 82, 
    5, 29, 6, 80, 3, 32, 8, 34, 0, 23, 4, 16, 1,  7, 7, 43, 2, 73, 
    7, 95, 6,  1, 1, 42, 0, 73, 4, 44, 2, 17, 3, 72, 8, 83, 5, 27, 
    3, 94, 5, 46, 6,  7, 0, 42, 4, 53, 2, 51, 1,  9, 8, 26, 7, 55, 
    7, 55, 6, 39, 2, 75, 0, 92, 5, 96, 3, 35, 4, 20, 8, 36, 1, 22, 
    2, 80, 1, 69, 8, 14, 7,  1, 0, 72, 3, 98, 4, 11, 6, 37, 5, 88, 
    5, 82, 6, 90, 8, 34, 4, 27, 1, 77, 7, 53, 0, 63, 3, 76, 2, 14
  };
  const int q0989[] = {
    9, 9, // Number of jobs and machines
    8, 38, 3, 59, 6,  4, 4, 93, 7, 16, 1, 58, 5, 24, 0, 46, 2, 47, 
    2, 79, 4, 73, 1, 49, 3, 49, 6, 53, 8, 81, 5, 16, 7, 86, 0, 36, 
    0, 75, 4, 85, 6, 21, 1, 33, 5, 93, 8, 36, 3, 49, 7, 45, 2,  6, 
    5, 27, 7, 16, 1, 82, 8, 52, 2, 95, 0, 85, 3, 55, 6,  1, 4, 26, 
    5, 68, 6, 68, 3, 13, 1,  2, 4, 27, 0, 91, 8, 16, 7, 71, 2,  4, 
    3, 22, 8, 31, 1,  6, 2, 98, 7, 22, 4, 92, 6, 81, 5, 72, 0, 11, 
    1, 55, 3, 96, 7,  3, 6, 95, 4, 21, 8, 84, 5,  7, 0, 54, 2, 41, 
    1, 29, 7, 55, 2, 89, 8, 98, 5, 66, 3, 37, 6, 16, 4, 21, 0,  8, 
    8, 24, 6, 14, 5, 92, 0, 80, 3, 88, 1, 51, 7, 84, 2, 14, 4, 67
  };
  const int q0990[] = {
    9, 9, // Number of jobs and machines
    7, 60, 5, 46, 3, 80, 1,  2, 6, 61, 0, 24, 8, 68, 4, 34, 2, 97, 
    5, 93, 7, 89, 4, 62, 0, 57, 6,  3, 3, 55, 2, 58, 1, 99, 8, 87, 
    5, 69, 6, 52, 8, 94, 1,  8, 0, 72, 3, 69, 4, 81, 2, 15, 7, 60, 
    8, 39, 3, 38, 0, 34, 5, 65, 1, 40, 2, 80, 7, 21, 6, 74, 4, 50, 
    8, 80, 4, 68, 3, 98, 6, 56, 5, 88, 2,  3, 7, 25, 0, 90, 1, 71, 
    2, 60, 0,  4, 4, 68, 1, 69, 5, 74, 3, 77, 8, 73, 7, 59, 6,  4, 
    2, 40, 1, 64, 6, 14, 5, 27, 4, 76, 0,  9, 7, 45, 8, 11, 3, 92, 
    4, 68, 5, 43, 7, 71, 8, 24, 6, 86, 3, 48, 0, 65, 2, 86, 1, 54, 
    6, 20, 7, 24, 8, 83, 4, 25, 0, 21, 2, 79, 1, 65, 3, 12, 5, 60
  };
  const int q0991[] = {
    9, 9, // Number of jobs and machines
    1, 39, 8, 57, 5, 35, 4, 31, 3, 31, 7, 80, 6, 33, 0, 62, 2, 74, 
    6, 51, 0, 17, 1, 39, 2, 38, 8, 95, 5,  1, 3, 42, 4, 81, 7, 19, 
    7, 57, 0,  6, 6, 28, 8, 92, 5, 63, 3, 16, 2, 99, 1, 25, 4, 78, 
    0, 83, 1, 93, 5, 32, 2,  9, 3,  7, 6,  1, 7, 39, 8, 71, 4, 13, 
    8, 85, 3, 65, 1, 86, 0, 53, 4,  5, 5, 46, 7, 75, 6, 65, 2, 71, 
    0, 86, 1, 49, 3, 51, 5, 23, 6, 50, 8,  4, 4, 60, 7,  4, 2, 50, 
    1, 97, 5, 58, 6, 28, 4, 87, 7, 86, 0, 57, 3, 60, 8, 91, 2, 13, 
    2, 31, 0, 91, 1, 19, 6, 99, 3,  1, 8, 64, 4, 29, 5, 96, 7, 94, 
    2, 46, 3,  6, 8, 40, 0, 32, 4, 67, 6, 25, 5, 73, 7, 40, 1, 89
  };
  const int q0992[] = {
    9, 9, // Number of jobs and machines
    1, 77, 2, 56, 0, 22, 3, 37, 7, 75, 8, 33, 5, 56, 4, 39, 6, 32, 
    1, 42, 6, 37, 5,  8, 2, 73, 0, 10, 8, 45, 7, 53, 3, 89, 4, 66, 
    5, 72, 3, 99, 1, 59, 2, 30, 8, 17, 0, 34, 4, 25, 7, 68, 6, 77, 
    0, 57, 2, 22, 3,  4, 6, 11, 7, 47, 5, 62, 8, 48, 1, 23, 4,  7, 
    8,  3, 2,  4, 4, 91, 1, 43, 0, 94, 3, 10, 7, 14, 5, 75, 6, 89, 
    8, 33, 5, 92, 6, 56, 2, 88, 3, 59, 7,  7, 0, 44, 4, 13, 1, 23, 
    4, 84, 5, 59, 1, 46, 0, 81, 6, 97, 8, 37, 2, 18, 3, 22, 7, 21, 
    1, 49, 5, 29, 8, 64, 6, 10, 0, 78, 4, 18, 2, 23, 7,  1, 3, 42, 
    8,  2, 7, 97, 5,  2, 6, 76, 1, 99, 0, 29, 2, 23, 3, 28, 4, 92
  };
  const int q0993[] = {
    9, 9, // Number of jobs and machines
    1, 36, 4, 59, 6, 47, 5, 38, 2, 76, 0,  9, 3, 54, 8,  9, 7, 40, 
    2, 90, 0, 58, 4, 81, 7,  6, 1, 38, 6, 45, 5, 57, 8, 52, 3,  8, 
    0, 65, 3, 43, 1, 92, 8, 71, 5, 56, 6,  2, 4, 35, 7, 39, 2, 79, 
    4,  1, 8, 54, 3,  4, 0, 44, 1, 97, 6, 17, 2, 74, 5, 84, 7, 33, 
    7, 55, 2, 41, 8, 25, 4, 16, 6, 45, 3,  3, 0,  9, 1, 74, 5, 40, 
    4, 40, 7, 58, 8, 25, 1,  3, 5, 21, 0, 48, 3, 22, 2, 47, 6, 26, 
    0, 26, 7, 34, 6, 14, 4, 50, 3,  5, 2, 70, 1, 17, 5, 96, 8, 48, 
    0, 93, 2, 37, 8, 70, 5, 44, 4, 81, 1, 49, 6, 93, 7, 82, 3, 25, 
    5, 46, 3, 23, 6,  6, 7, 36, 2, 42, 8, 95, 0, 39, 4, 80, 1, 19
  };
  const int q0994[] = {
    9, 9, // Number of jobs and machines
    2, 67, 3, 14, 1, 90, 0, 54, 5, 15, 8, 90, 4, 21, 6,  2, 7, 66, 
    4, 66, 3, 86, 1, 55, 5, 24, 2, 75, 8, 91, 6, 75, 7,  3, 0, 98, 
    8, 67, 2, 51, 1, 51, 5, 46, 3, 83, 0, 41, 6, 11, 7, 89, 4, 76, 
    6, 96, 4, 83, 3, 43, 0, 36, 1, 37, 7, 20, 5, 65, 2, 59, 8, 41, 
    4, 84, 1, 52, 7, 28, 0, 20, 2, 17, 6, 69, 8, 39, 5, 12, 3, 45, 
    2, 88, 0,  6, 8, 99, 6, 51, 3, 74, 5, 11, 7, 49, 4, 11, 1, 69, 
    6, 86, 2,  2, 0,  7, 5, 90, 1, 47, 8, 69, 7, 25, 4,  5, 3,  8, 
    3, 90, 6,  8, 1, 56, 5, 94, 4, 83, 2, 97, 8,  5, 0, 47, 7,  5, 
    3, 97, 5, 30, 2, 41, 6, 19, 7, 52, 0, 66, 8, 18, 4, 75, 1, 73
  };
  const int q0995[] = {
    9, 9, // Number of jobs and machines
    2, 37, 4, 32, 1, 83, 7, 90, 0, 44, 3, 91, 5, 74, 8, 92, 6, 75, 
    7,  9, 0, 60, 5, 50, 6, 25, 8, 30, 1,  8, 4, 27, 3, 29, 2, 36, 
    7, 77, 3, 63, 6, 44, 1, 18, 2, 33, 5, 59, 8, 25, 4, 11, 0, 22, 
    5, 75, 0, 66, 7, 28, 8, 33, 6, 32, 1,  4, 4, 79, 3, 76, 2, 69, 
    3, 87, 6, 63, 4, 85, 7, 50, 2, 63, 8, 11, 5, 10, 1, 29, 0, 28, 
    6, 23, 1, 72, 4, 88, 2,  4, 0, 40, 8, 58, 7, 99, 5, 96, 3, 69, 
    5, 57, 8, 37, 6, 37, 2, 40, 7, 74, 3, 69, 0, 47, 1, 36, 4, 50, 
    1, 84, 8, 58, 4, 46, 0, 82, 3, 36, 6, 62, 7, 44, 2, 31, 5, 90, 
    4, 40, 6, 63, 7, 28, 5,  2, 1, 39, 3, 41, 0, 14, 8, 15, 2, 64
  };
  const int q0996[] = {
    9, 9, // Number of jobs and machines
    1,  7, 6, 23, 4, 30, 0, 52, 8, 21, 7, 31, 5, 29, 2, 66, 3, 31, 
    8, 23, 4, 92, 2,  9, 0, 16, 3, 29, 7, 47, 1, 60, 5, 99, 6, 45, 
    7, 87, 3, 47, 6, 21, 2,  2, 5, 77, 1, 22, 8, 48, 0, 77, 4, 22, 
    5, 59, 0, 23, 4, 24, 6, 95, 8, 52, 7, 15, 3,  5, 2, 80, 1, 30, 
    8, 14, 4, 94, 7, 41, 1, 18, 5,  2, 3, 89, 6, 32, 0, 83, 2, 89, 
    5, 25, 4, 29, 6,  7, 8, 50, 0, 19, 7, 30, 3, 52, 2, 98, 1, 54, 
    1, 38, 2, 35, 0, 88, 5, 25, 7,  5, 6, 88, 3, 34, 8,  3, 4,  8, 
    3, 33, 4, 21, 0,  5, 1, 61, 7, 11, 6, 77, 5, 29, 2, 64, 8, 16, 
    6, 80, 5, 41, 8, 68, 0, 62, 3, 42, 2, 69, 1, 22, 4, 23, 7, 15
  };
  const int q0997[] = {
    9, 9, // Number of jobs and machines
    1, 93, 2, 86, 0, 55, 7, 18, 5, 44, 4, 42, 6, 67, 8, 62, 3, 90, 
    2,  8, 6, 79, 5, 79, 1, 49, 7, 76, 3, 23, 8, 54, 0, 30, 4,  5, 
    2, 87, 7, 51, 3, 16, 4, 37, 1, 58, 0, 44, 8, 83, 5, 99, 6, 15, 
    1, 99, 4,  2, 0, 66, 3, 93, 6, 81, 7, 38, 8,  9, 2, 19, 5, 74, 
    0, 13, 2, 25, 4, 95, 1, 55, 3, 20, 6, 93, 5, 90, 7, 65, 8, 55, 
    4,  8, 8, 45, 1, 52, 5, 57, 6, 59, 0, 97, 7, 71, 3,  9, 2, 99, 
    7, 57, 2, 85, 4,  8, 5,  9, 0, 74, 8,  6, 6, 42, 3, 50, 1, 52, 
    8, 97, 2, 37, 3, 44, 1, 84, 0, 24, 5, 54, 7, 37, 4, 29, 6, 48, 
    0,  4, 7,  5, 4, 70, 2, 90, 8, 88, 5, 87, 3, 88, 6, 73, 1, 53
  };
  const int q0998[] = {
    9, 9, // Number of jobs and machines
    1, 94, 3, 26, 0, 60, 6, 26, 5, 84, 4, 94, 8,  7, 2, 71, 7,  2, 
    7, 54, 1, 82, 4, 78, 6, 47, 3, 95, 0, 59, 8, 61, 5, 30, 2, 80, 
    0, 59, 5, 13, 2, 78, 1, 35, 8, 99, 3, 97, 6, 52, 4, 36, 7, 49, 
    5, 26, 2, 98, 4, 28, 3, 14, 6, 66, 7, 46, 8, 57, 1, 64, 0, 90, 
    3,  2, 4, 48, 0, 63, 2, 79, 7, 59, 8, 84, 5, 14, 6, 94, 1, 57, 
    6, 11, 4, 69, 5, 84, 2,  7, 8, 10, 3, 68, 7, 43, 1, 36, 0, 17, 
    5, 94, 0, 54, 3, 27, 4,  3, 7, 98, 2, 14, 6, 28, 1, 33, 8, 74, 
    4, 27, 0, 87, 1, 30, 5, 10, 3, 62, 8, 90, 2,  7, 7,  4, 6, 39, 
    8, 13, 5, 36, 3, 96, 2, 83, 0, 46, 1, 11, 6, 31, 7, 31, 4, 18
  };
  const int q0999[] = {
    9, 9, // Number of jobs and machines
    1,  8, 4, 60, 5, 43, 7, 24, 2, 78, 8,  8, 6, 84, 3, 97, 0, 78, 
    7, 71, 0, 74, 1,  3, 4, 99, 6, 99, 3, 92, 8, 43, 5, 20, 2, 92, 
    6, 84, 0, 15, 2, 12, 1, 47, 5, 46, 8, 78, 4,  5, 3, 95, 7, 12, 
    1, 56, 4, 90, 6, 64, 0, 62, 3, 32, 5, 72, 2, 90, 7, 21, 8, 56, 
    8, 12, 1, 49, 4, 92, 2, 44, 5, 37, 3, 57, 7, 68, 0, 14, 6,  9, 
    4, 41, 8, 11, 2, 62, 5, 99, 3, 80, 1,  1, 0, 60, 6, 45, 7, 30, 
    2, 35, 8, 93, 0, 88, 1, 24, 7, 76, 6, 37, 5, 53, 3,  3, 4, 41, 
    6, 82, 5,  5, 1, 82, 0, 68, 8, 51, 4, 27, 7, 55, 2, 29, 3, 88, 
    8, 75, 3, 28, 1, 62, 4, 97, 2, 21, 7, 81, 6, 10, 0, 39, 5, 54
  };
  const int q1000[] = {
    9, 9, // Number of jobs and machines
    5, 24, 7, 59, 4, 84, 8, 89, 3, 86, 6, 32, 1, 27, 0, 44, 2, 80, 
    0,  1, 5, 74, 2,  1, 1, 50, 6, 98, 4, 37, 8, 71, 3,  7, 7, 70, 
    1, 35, 8, 42, 2, 43, 4, 52, 7, 63, 3, 68, 5, 51, 0, 58, 6,  1, 
    6, 20, 5, 75, 3, 41, 7,  4, 8,  2, 0, 67, 4, 93, 2, 11, 1, 50, 
    2, 72, 7, 38, 8, 95, 3, 79, 5, 12, 1, 73, 6, 12, 0, 79, 4, 52, 
    8, 60, 4, 40, 5, 94, 6, 73, 1, 80, 0, 60, 7, 45, 3, 80, 2, 25, 
    2, 19, 8, 53, 0, 75, 5, 59, 7, 12, 1,  5, 6, 81, 4,  4, 3, 85, 
    6, 78, 2, 55, 0, 86, 4, 68, 3, 39, 8, 59, 1, 10, 7, 85, 5, 93, 
    1,  8, 4,  9, 3, 74, 7, 54, 5, 81, 2,  3, 8, 67, 0, 66, 6, 71
  };
  const int q1001[] = {
    9, 9, // Number of jobs and machines
    1, 89, 3, 63, 5, 14, 4, 90, 6, 79, 2, 98, 8, 57, 7, 24, 0, 19, 
    1,  3, 0, 98, 7, 80, 8, 55, 5, 23, 4, 93, 6, 91, 2, 23, 3,  5, 
    4, 97, 3,  2, 5,  7, 8, 29, 2, 73, 0, 99, 1, 96, 6, 31, 7, 39, 
    8, 65, 4, 18, 3, 54, 0,  4, 7,  6, 6, 65, 5,  5, 1, 55, 2, 46, 
    0, 52, 8, 60, 7, 97, 5, 73, 4, 64, 6, 26, 2, 45, 3, 61, 1, 62, 
    1, 59, 8, 82, 2, 68, 7, 37, 0, 48, 4, 52, 5, 47, 6, 50, 3, 91, 
    5, 19, 0, 31, 8, 67, 6, 21, 1, 50, 7, 79, 4, 40, 2, 48, 3, 14, 
    6,  5, 0, 16, 1,  4, 8, 96, 7, 50, 4, 77, 2, 50, 3, 91, 5, 17, 
    4, 84, 0, 82, 6, 12, 7,  1, 2, 64, 8, 82, 3, 64, 5, 19, 1, 22
  };
  const int q1002[] = {
    9, 9, // Number of jobs and machines
    7, 98, 0, 47, 8,  2, 6, 75, 3, 29, 2,  3, 4, 65, 5, 97, 1, 91, 
    0,  3, 8, 27, 6, 92, 5, 23, 7, 22, 1, 68, 4, 58, 3, 72, 2, 89, 
    7, 87, 3, 88, 4, 26, 8, 50, 6, 58, 2, 47, 0, 65, 1, 14, 5, 85, 
    1, 86, 4, 62, 5, 17, 3, 93, 2, 95, 0, 76, 8, 91, 6, 14, 7, 88, 
    8, 29, 6, 82, 2, 14, 4, 42, 7, 38, 3,  8, 5, 40, 1, 81, 0, 84, 
    3, 57, 8, 56, 5, 71, 2, 20, 6, 28, 1, 11, 7, 48, 4,  6, 0, 98, 
    2, 21, 4, 92, 3, 16, 8, 90, 5, 79, 0, 94, 7, 60, 6, 31, 1, 15, 
    6, 51, 1, 61, 8, 31, 0, 39, 7, 58, 5,  2, 4, 33, 3, 72, 2, 45, 
    7, 30, 4,  7, 2, 66, 8, 86, 5, 82, 6, 35, 0, 73, 3, 30, 1, 45
  };
  const int q1003[] = {
    9, 9, // Number of jobs and machines
    3, 22, 5, 65, 7, 36, 2, 46, 6, 62, 8, 16, 1, 33, 4, 36, 0, 85, 
    8, 40, 2, 38, 3, 38, 0, 29, 7, 24, 1, 18, 4, 63, 5, 63, 6, 68, 
    5, 76, 7, 77, 2, 93, 0, 47, 8, 91, 1, 80, 3, 75, 6, 96, 4, 60, 
    0, 35, 5, 93, 8, 13, 7, 91, 1, 47, 4, 37, 3,  7, 6, 47, 2, 44, 
    5, 84, 8, 37, 7, 31, 4, 76, 2, 29, 3, 44, 1, 57, 6, 89, 0, 68, 
    1, 32, 4, 19, 2, 26, 8, 23, 7, 35, 0, 18, 6, 14, 3, 28, 5, 26, 
    8, 37, 6, 34, 2,  1, 0, 28, 7, 58, 4, 78, 3, 17, 5, 88, 1, 56, 
    0, 72, 2, 15, 5, 30, 8, 84, 6, 81, 4, 67, 7,  1, 3, 10, 1, 74, 
    3, 47, 4, 72, 5, 80, 6, 83, 2, 80, 1,  4, 0, 45, 7, 26, 8, 47
  };
  const int q1004[] = {
    9, 9, // Number of jobs and machines
    6, 32, 2, 87, 8, 39, 0, 51, 3, 29, 5, 22, 4, 55, 7, 33, 1, 81, 
    5, 18, 4, 81, 3, 41, 7, 57, 0,  9, 2, 96, 6, 36, 8, 95, 1, 18, 
    8, 39, 3,  4, 4, 99, 5, 71, 6, 40, 0, 79, 1, 14, 2, 75, 7, 35, 
    3,  3, 2, 82, 5, 83, 4, 36, 6, 48, 7, 22, 1, 28, 8, 80, 0, 22, 
    6, 65, 1,  8, 5, 52, 4, 13, 3, 92, 0, 94, 7, 13, 2, 17, 8, 52, 
    4, 25, 2, 44, 8, 11, 5,  9, 3, 63, 0, 44, 6, 81, 7, 99, 1, 70, 
    0, 59, 6, 63, 5, 34, 2, 23, 4, 43, 7, 33, 8, 10, 1,  9, 3, 93, 
    3, 90, 6, 63, 1, 94, 7, 67, 2, 58, 4, 82, 8, 55, 5, 71, 0,  5, 
    4, 33, 7,  5, 2, 63, 1, 22, 0, 46, 6,  9, 8, 76, 5, 68, 3, 78
  };
  const int q1005[] = {
    9, 9, // Number of jobs and machines
    5, 56, 3, 22, 6, 38, 1, 31, 2, 13, 8,  6, 7, 39, 0, 34, 4, 23, 
    5, 56, 6, 93, 4, 26, 2, 93, 8, 98, 3, 28, 0, 32, 1, 12, 7, 47, 
    5, 50, 6, 94, 8, 33, 0, 99, 2, 17, 1, 85, 3, 99, 7, 64, 4, 48, 
    7, 68, 6, 27, 1, 71, 4, 64, 3, 77, 5, 45, 0, 31, 2, 51, 8, 26, 
    7, 44, 8, 57, 0, 96, 2, 37, 3, 90, 4, 53, 6,  4, 5, 27, 1, 49, 
    1, 91, 8, 55, 4, 11, 2,  8, 6, 53, 0,  1, 7, 98, 3, 34, 5, 98, 
    0, 89, 3, 68, 2, 85, 5, 70, 4, 27, 6, 74, 7, 82, 8, 90, 1,  8, 
    3, 44, 1, 99, 5, 51, 7, 56, 6, 98, 0, 57, 8, 41, 2, 53, 4, 31, 
    8, 39, 5, 13, 1, 26, 6, 74, 7,  7, 3, 22, 4,  2, 0, 42, 2, 79
  };
  const int q1006[] = {
    9, 9, // Number of jobs and machines
    1,  4, 5, 85, 2, 67, 3, 54, 0, 46, 6, 15, 8,  4, 4,  9, 7, 87, 
    3,  4, 5, 60, 4, 94, 7,  6, 1,  2, 2, 82, 6, 18, 8, 45, 0, 71, 
    4, 76, 1, 35, 8, 39, 3, 32, 2, 39, 7, 89, 5, 25, 6, 71, 0,  4, 
    3, 69, 4, 74, 8, 81, 5, 94, 7, 50, 1,  5, 0, 77, 6, 96, 2,  6, 
    7, 16, 3, 61, 4, 23, 2, 82, 6, 99, 1,  6, 8, 76, 5, 36, 0, 63, 
    7, 25, 8, 12, 5, 61, 4,  3, 3,  5, 2,  8, 6, 25, 0, 30, 1,  5, 
    1, 82, 5, 65, 4, 77, 8, 34, 0, 35, 3, 20, 6, 88, 2, 81, 7, 24, 
    6, 38, 1, 74, 0, 31, 2, 83, 3,  4, 4, 34, 5, 90, 7,  3, 8, 72, 
    2, 39, 1, 53, 3, 55, 7, 34, 0, 99, 5, 27, 4, 19, 6, 91, 8, 19
  };
  const int q1007[] = {
    9, 9, // Number of jobs and machines
    6, 49, 1, 56, 7, 35, 3, 24, 5, 15, 0, 60, 8, 94, 4, 68, 2, 64, 
    0, 67, 4, 68, 5, 81, 7, 21, 8,  6, 2, 25, 6, 99, 3, 49, 1, 25, 
    3, 68, 6,  1, 5, 88, 2, 18, 0, 93, 4,  1, 7, 45, 8,  2, 1, 66, 
    1, 24, 0,  8, 5, 47, 8, 91, 4, 66, 3, 78, 6,  3, 7, 34, 2, 35, 
    6, 53, 7, 84, 3, 22, 5, 60, 8, 11, 4, 73, 1, 46, 2, 40, 0,  7, 
    3, 29, 6, 38, 0, 51, 4, 39, 8, 99, 2, 21, 5, 43, 1, 19, 7, 30, 
    1, 88, 2, 54, 3, 69, 5, 53, 6, 85, 7,  6, 8, 15, 4,  8, 0, 58, 
    2, 52, 6, 80, 0, 18, 4, 81, 1, 75, 8, 52, 7,  2, 5, 11, 3,  7, 
    3, 83, 2,  9, 4, 59, 8, 72, 6, 19, 7, 59, 1,  9, 0, 67, 5, 68
  };
  const int q1008[] = {
    9, 9, // Number of jobs and machines
    3, 46, 8, 48, 2, 11, 4, 84, 0, 30, 1, 81, 5, 18, 7, 23, 6, 99, 
    6, 10, 4,  5, 5, 57, 3, 45, 7, 27, 1, 13, 2, 73, 0, 62, 8, 51, 
    7, 17, 3, 99, 0, 82, 4, 76, 8, 42, 5, 70, 2, 90, 6, 22, 1, 78, 
    7, 33, 1, 40, 0, 75, 2, 72, 4, 51, 5, 98, 8, 71, 6, 74, 3,  7, 
    5, 70, 6, 69, 7, 83, 4, 19, 2, 91, 3, 94, 1,  8, 0, 76, 8, 71, 
    0, 91, 5, 66, 7, 91, 8, 46, 4, 45, 2, 22, 6, 23, 3, 48, 1, 42, 
    4, 45, 3, 92, 0, 49, 1, 25, 7, 69, 6, 36, 5,  4, 2, 53, 8, 89, 
    1, 93, 5, 67, 6,  6, 2, 86, 4, 82, 0, 30, 3, 16, 8, 47, 7, 52, 
    4, 37, 2, 47, 0, 38, 8,  8, 6, 25, 7, 82, 1, 86, 5, 31, 3, 60
  };
  const int q1009[] = {
    9, 9, // Number of jobs and machines
    4,  8, 8, 34, 3,  3, 2, 57, 1, 93, 7, 22, 0, 14, 6, 99, 5, 18, 
    7, 68, 0, 80, 2, 99, 3, 36, 1, 94, 6, 37, 4, 48, 5, 84, 8, 93, 
    8, 40, 4, 33, 1, 32, 7, 92, 5, 52, 3,  2, 2, 21, 6, 77, 0, 12, 
    3, 36, 0, 37, 7, 74, 1, 92, 2, 30, 6, 44, 4, 89, 5, 39, 8, 58, 
    7, 42, 1,  4, 3, 64, 2, 39, 8, 32, 5, 77, 6, 23, 4, 23, 0, 92, 
    4, 56, 0, 72, 6, 47, 7, 61, 5, 36, 3, 73, 2, 64, 8, 14, 1,  1, 
    0, 26, 7, 95, 2, 46, 3,  3, 8, 22, 1, 78, 6, 97, 4, 56, 5, 26, 
    1, 65, 2, 18, 5, 69, 3, 25, 8, 87, 4, 42, 0, 13, 7, 26, 6, 29, 
    3, 12, 7, 37, 5, 88, 2, 12, 6, 25, 8, 67, 1,  3, 0, 25, 4, 51
  };
  const int q1010[] = {
    9, 9, // Number of jobs and machines
    4, 95, 3, 93, 1, 24, 5, 78, 2, 51, 8, 21, 0, 31, 6, 68, 7, 14, 
    4,  5, 0, 46, 1, 56, 6, 75, 8, 71, 2, 27, 5, 52, 3, 77, 7, 44, 
    4, 47, 3, 94, 8, 24, 5, 14, 6, 10, 1, 50, 0,  2, 7, 47, 2, 63, 
    1, 52, 0, 15, 7, 99, 3, 11, 8, 89, 2, 49, 5, 73, 4, 93, 6, 33, 
    1, 17, 6, 85, 3,  7, 4, 34, 2, 28, 8, 88, 7, 10, 5,  9, 0, 41, 
    5, 66, 0, 55, 7, 86, 3, 47, 4, 57, 6, 31, 8, 99, 2, 64, 1,  5, 
    5, 43, 3, 70, 2,  9, 6, 70, 8, 89, 1, 74, 7, 74, 0, 46, 4,  8, 
    5, 43, 3, 40, 8, 97, 7, 39, 4, 24, 1, 18, 6, 54, 0, 39, 2, 28, 
    0, 15, 8,  2, 2, 16, 6,  4, 4, 42, 3, 37, 7, 66, 5, 23, 1, 89
  };
  const int q1011[] = {
    9, 9, // Number of jobs and machines
    2, 27, 1, 63, 4, 49, 6, 85, 0, 22, 7, 59, 5, 13, 3, 27, 8,  2, 
    2, 85, 0, 96, 8, 40, 1, 57, 6, 33, 4, 81, 5, 93, 7, 66, 3, 59, 
    6, 63, 5, 40, 0, 99, 8, 56, 3,  8, 2, 60, 4, 53, 7, 49, 1, 48, 
    6, 80, 0, 33, 7, 77, 5, 74, 2, 40, 1,  2, 3, 27, 8, 36, 4, 28, 
    2, 65, 7, 20, 1, 99, 0, 81, 5, 34, 3, 66, 4, 21, 6, 21, 8, 17, 
    6, 33, 0, 45, 3, 28, 8, 83, 7, 42, 2,  1, 5, 11, 1, 16, 4, 35, 
    3, 76, 6, 97, 1, 56, 7, 89, 5, 39, 4, 17, 2, 50, 8, 71, 0, 11, 
    7, 75, 1, 27, 5, 52, 6,  5, 0, 18, 3, 99, 4, 42, 8, 90, 2, 82, 
    5, 59, 1, 82, 2, 75, 6,  3, 0,  2, 8, 79, 7, 69, 3, 80, 4, 52
  };
  const int q1012[] = {
    9, 9, // Number of jobs and machines
    6, 57, 4,  6, 7, 47, 5, 90, 3, 86, 8, 64, 2, 26, 0, 29, 1, 99, 
    1, 34, 7, 16, 6, 45, 5,  5, 8, 30, 0, 22, 2, 86, 3, 56, 4,  2, 
    7, 24, 2, 70, 4, 82, 5, 86, 3,  8, 6, 67, 1, 78, 8, 85, 0, 73, 
    6, 28, 5, 69, 2, 62, 3, 79, 0, 58, 7, 30, 8, 64, 1, 24, 4, 19, 
    6, 86, 4, 14, 8, 60, 7, 21, 2, 56, 0, 74, 1, 33, 5, 11, 3, 87, 
    1, 41, 5, 51, 2, 27, 8, 15, 0, 28, 7, 45, 4, 91, 6,  9, 3, 54, 
    7, 68, 5, 49, 3, 21, 6, 76, 2, 55, 4, 89, 1, 82, 8, 24, 0, 47, 
    8, 91, 3,  2, 7, 61, 4, 44, 2,  3, 5, 30, 1, 18, 0, 75, 6,  3, 
    6, 21, 4, 35, 3, 90, 1, 15, 0, 65, 2, 53, 8, 20, 5,  1, 7, 70
  };
  const int q1013[] = {
    9, 9, // Number of jobs and machines
    1, 73, 6, 83, 7, 59, 0, 88, 4, 33, 5, 65, 8, 17, 2, 40, 3, 69, 
    7, 49, 8, 90, 5, 88, 4, 95, 2, 27, 3, 10, 6, 65, 0, 45, 1, 97, 
    3,  1, 0, 48, 8,  3, 1, 54, 6, 70, 5, 45, 2, 95, 7, 82, 4, 90, 
    1, 28, 2, 35, 7, 13, 5, 64, 4, 43, 8, 63, 6, 96, 0,  4, 3, 34, 
    3,  8, 5, 30, 1, 27, 4,  3, 8, 66, 7, 53, 6, 90, 2, 22, 0, 66, 
    2, 17, 7, 56, 5, 40, 3, 56, 4, 51, 6, 64, 0,  5, 1, 50, 8, 63, 
    0, 64, 5, 82, 2, 77, 7, 85, 1, 43, 4, 23, 3, 63, 8, 57, 6, 43, 
    1, 52, 8, 30, 0,  9, 2, 17, 4, 73, 5, 43, 3, 87, 6, 80, 7, 56, 
    7, 34, 1, 52, 3, 87, 6, 62, 0, 57, 2, 22, 5, 23, 4, 22, 8, 38
  };
  const int q1014[] = {
    9, 9, // Number of jobs and machines
    7, 21, 4, 78, 5, 68, 8, 69, 0, 28, 6, 77, 1, 59, 3, 80, 2, 59, 
    1, 69, 6, 29, 4, 35, 0, 66, 3, 58, 7, 17, 8, 67, 2,  3, 5, 82, 
    5, 94, 6, 58, 2, 45, 0,  9, 3, 27, 8, 90, 7, 16, 1, 72, 4, 70, 
    6,  6, 7, 87, 8, 97, 1,  5, 3, 87, 2, 31, 5, 53, 0, 91, 4, 63, 
    3, 18, 8, 31, 1, 55, 4, 41, 2, 20, 6, 19, 7, 95, 0, 82, 5, 13, 
    4, 81, 6, 71, 1, 47, 0, 57, 8, 72, 3, 56, 5, 43, 2, 60, 7, 17, 
    7, 29, 8, 73, 1, 77, 5, 40, 3, 62, 0, 15, 2, 83, 6, 43, 4, 99, 
    1, 38, 2, 20, 0, 33, 8, 21, 4, 36, 6, 31, 5, 43, 3, 34, 7, 35, 
    4, 85, 1, 89, 5,  4, 0, 84, 3, 38, 6, 48, 2, 73, 7, 64, 8,  6
  };
  const int q1015[] = {
    9, 9, // Number of jobs and machines
    7, 46, 1, 38, 8, 20, 4, 48, 2,  8, 6, 80, 5, 95, 3, 38, 0,  1, 
    2, 63, 5, 56, 1,  6, 3, 44, 4, 65, 7, 26, 8, 68, 6,  8, 0, 86, 
    2, 10, 4, 79, 7, 66, 8, 29, 3, 31, 0, 43, 6, 31, 1, 97, 5, 67, 
    4, 60, 2, 55, 7, 75, 3, 31, 6, 40, 0, 47, 1, 78, 5, 68, 8, 56, 
    5, 81, 8, 69, 2, 50, 1, 66, 3, 19, 4, 31, 6, 21, 7, 56, 0, 59, 
    1, 18, 0, 38, 6, 79, 8, 40, 2,  4, 3, 69, 7, 27, 4, 49, 5, 45, 
    3, 54, 5, 55, 8, 10, 0, 75, 2, 44, 1, 44, 7, 15, 4, 84, 6, 67, 
    2, 41, 6, 83, 7, 88, 1, 88, 5, 19, 8, 29, 3, 38, 4, 97, 0, 80, 
    2, 52, 6,  1, 4,  2, 0, 90, 5, 85, 3, 37, 8, 46, 1, 30, 7,  6
  };
  const int q1016[] = {
    9, 9, // Number of jobs and machines
    5, 15, 1,  9, 7, 84, 4, 47, 8, 47, 3, 41, 0, 89, 6, 14, 2, 77, 
    1,  4, 2, 85, 6, 46, 0, 97, 4, 99, 3, 49, 8,  8, 7, 45, 5, 92, 
    7, 78, 6, 52, 1, 82, 8, 33, 2, 94, 0,  1, 4, 24, 5, 76, 3, 65, 
    4, 84, 1,  9, 2,  6, 7, 13, 3, 77, 6, 98, 8, 83, 0, 68, 5, 40, 
    6, 77, 3, 37, 7, 16, 0, 75, 1, 27, 4, 37, 8, 31, 5, 69, 2, 30, 
    8, 49, 4, 91, 6, 96, 1, 37, 7, 45, 2, 29, 0, 36, 5, 59, 3, 56, 
    4, 54, 8, 92, 7, 13, 2, 61, 1,  1, 6,  8, 0, 82, 3,  8, 5, 12, 
    1, 69, 2, 74, 0, 33, 8, 32, 5, 75, 4,  8, 6, 68, 7, 37, 3, 48, 
    4, 74, 1, 73, 3, 26, 0, 50, 8, 21, 5,  5, 6, 35, 2, 64, 7, 17
  };
  const int q1017[] = {
    9, 9, // Number of jobs and machines
    1, 76, 7, 33, 8, 88, 3, 73, 6, 80, 5, 77, 4, 48, 0, 46, 2, 68, 
    6, 39, 1, 30, 0, 86, 8, 76, 5, 35, 2, 14, 7, 59, 3, 43, 4, 89, 
    1, 30, 6, 38, 7, 37, 0, 50, 5,  8, 3,  4, 2, 11, 8, 89, 4, 91, 
    7,  6, 2, 49, 4, 95, 6, 15, 8, 40, 5, 42, 0, 26, 3, 95, 1, 18, 
    6, 33, 4, 93, 1,  1, 0, 51, 8, 98, 2, 35, 5, 96, 3, 94, 7, 75, 
    5,  6, 1, 79, 8, 65, 2, 67, 7, 31, 3, 99, 6, 23, 4, 83, 0,  1, 
    3, 14, 1, 17, 4,  3, 8, 68, 6, 10, 7, 74, 5, 96, 2, 56, 0, 50, 
    6, 82, 4, 36, 2,  1, 1, 30, 3, 48, 7,  9, 8, 40, 5, 29, 0, 75, 
    3, 26, 5, 30, 1, 16, 2, 29, 6, 96, 4, 50, 7,  8, 0, 47, 8, 61
  };
  const int q1018[] = {
    9, 9, // Number of jobs and machines
    0,  6, 4, 46, 2, 54, 5, 24, 3, 76, 7, 98, 8, 23, 6, 27, 1,  9, 
    6, 96, 7, 61, 2, 42, 4, 98, 8, 40, 1,  4, 3, 25, 5,  4, 0, 16, 
    0, 90, 5, 31, 6,  1, 2, 39, 8, 26, 3, 56, 7, 98, 1, 44, 4, 88, 
    4, 36, 8, 51, 3, 93, 2, 11, 7, 57, 5, 41, 1, 77, 6, 82, 0, 72, 
    7, 50, 0, 13, 8, 12, 4, 65, 1, 31, 6, 18, 5, 39, 2, 26, 3, 45, 
    8, 21, 4, 23, 1, 84, 3, 52, 6, 40, 0, 47, 7, 43, 5, 86, 2, 51, 
    0, 12, 8,  4, 6, 89, 2, 47, 7, 88, 1, 46, 4, 48, 5, 73, 3, 68, 
    4, 27, 5, 96, 0, 84, 7, 72, 8, 95, 3, 58, 2, 60, 6, 50, 1, 24, 
    2, 23, 6, 18, 5, 45, 3,  3, 0, 18, 8, 10, 7, 81, 1, 30, 4,  7
  };
  const int q1019[] = {
    9, 9, // Number of jobs and machines
    7, 34, 3,  3, 8, 19, 6, 51, 1, 85, 0, 59, 5, 31, 2, 60, 4, 96, 
    5, 57, 6, 39, 2, 11, 4,  2, 0, 84, 3, 51, 8, 15, 7, 74, 1, 44, 
    1, 68, 5, 37, 6,  1, 8, 69, 7,  6, 4, 13, 3, 31, 0, 79, 2, 46, 
    6, 95, 8, 50, 1, 68, 0, 25, 4, 52, 3, 47, 2, 70, 5, 51, 7, 87, 
    2, 20, 8, 41, 7, 44, 0, 28, 5, 57, 4, 51, 1, 71, 6,  4, 3, 49, 
    5, 25, 3, 52, 1, 65, 2, 36, 8, 61, 4,  4, 6, 46, 7,  2, 0,  4, 
    5,  6, 1, 64, 6, 44, 7, 50, 0, 28, 2, 81, 8, 73, 3, 49, 4, 22, 
    0, 76, 8, 74, 2, 50, 3, 79, 5,  7, 1,  9, 6,  4, 4, 90, 7, 39, 
    4, 51, 6, 85, 0, 26, 8, 21, 2, 60, 5, 93, 7, 18, 1, 71, 3, 98
  };
  const int q1020[] = {
    9, 9, // Number of jobs and machines
    6, 50, 2, 38, 5, 25, 4,  7, 8, 18, 0, 79, 7, 50, 3, 65, 1, 54, 
    4, 91, 7, 43, 5,  8, 8, 66, 0, 74, 3, 54, 6, 72, 1, 85, 2, 91, 
    0, 68, 3, 47, 8, 77, 7, 67, 5, 50, 2, 81, 6, 28, 4, 87, 1, 93, 
    8, 86, 5,  1, 2, 52, 6, 68, 4,  2, 1,  1, 3, 89, 0, 40, 7,  9, 
    2, 36, 4, 16, 1, 76, 3, 63, 5, 53, 6, 65, 7, 31, 0, 55, 8, 80, 
    3, 82, 5, 45, 4, 81, 1, 63, 2, 18, 6, 24, 7, 42, 0, 73, 8, 24, 
    2, 53, 0, 10, 3, 12, 6, 52, 1, 89, 8, 25, 4, 27, 7, 97, 5, 51, 
    2, 95, 3, 62, 4, 54, 8, 32, 6, 65, 5, 92, 0, 14, 1, 81, 7, 20, 
    2,  8, 7, 82, 6, 79, 3,  2, 1, 87, 4, 24, 5, 63, 0, 19, 8, 50
  };
  const int q1021[] = {
    9, 9, // Number of jobs and machines
    2, 65, 1, 89, 0, 20, 8, 52, 3, 78, 7, 26, 4, 90, 6, 26, 5, 67, 
    4, 34, 2, 56, 8, 76, 6,  3, 0, 58, 3, 22, 5,  3, 1, 73, 7, 24, 
    1, 10, 7, 66, 5, 95, 8,  1, 4, 21, 2, 68, 0, 13, 6, 83, 3, 34, 
    5, 34, 7, 69, 6, 45, 8, 61, 1, 51, 3, 33, 0, 98, 4, 83, 2,  4, 
    8,  8, 1, 12, 3, 30, 4, 40, 0, 24, 5, 18, 6,  1, 7, 55, 2, 48, 
    8, 32, 4, 73, 0, 76, 1, 78, 3, 26, 7, 83, 6, 12, 5, 41, 2, 19, 
    3, 48, 8, 62, 0, 75, 7, 92, 6,  9, 5, 28, 2, 16, 1, 12, 4,  5, 
    1, 38, 2, 99, 7, 11, 0, 63, 3, 60, 5, 95, 8, 59, 6, 23, 4, 68, 
    6,  4, 5, 95, 1, 55, 4, 16, 7,  2, 0, 42, 8,  7, 3, 21, 2, 85
  };
  const int q1022[] = {
    9, 9, // Number of jobs and machines
    3,  7, 5, 19, 0, 82, 1,  2, 2, 69, 7, 75, 6, 52, 4, 55, 8, 93, 
    2,  9, 7, 62, 3, 66, 0, 37, 6, 86, 5, 84, 1, 23, 4, 87, 8, 15, 
    8, 82, 6, 88, 5, 18, 4, 25, 2, 18, 3, 83, 1, 16, 0, 48, 7,  6, 
    5, 39, 8, 36, 1, 27, 7, 12, 4, 14, 0, 86, 2, 72, 3,  9, 6, 41, 
    0, 41, 1, 69, 7, 50, 3, 12, 6, 31, 4, 40, 5,  8, 2, 61, 8, 51, 
    3, 20, 1, 79, 2, 11, 4, 52, 0, 79, 5, 73, 6, 38, 8, 49, 7, 56, 
    5, 53, 4, 93, 0,  2, 6, 97, 8, 22, 7, 78, 1, 28, 3, 92, 2, 14, 
    0, 67, 1, 85, 4, 57, 7, 62, 3, 52, 6, 26, 8, 46, 2, 92, 5, 17, 
    3, 68, 2, 78, 7,  4, 1, 96, 8, 83, 6, 60, 4, 59, 0, 68, 5, 32
  };
  const int q1023[] = {
    9, 9, // Number of jobs and machines
    3, 90, 7, 48, 6, 98, 0, 23, 2, 86, 8, 52, 5, 52, 1, 26, 4, 78, 
    0, 89, 4, 92, 3, 98, 1,  9, 5, 66, 2, 48, 8, 54, 7, 76, 6, 42, 
    2, 99, 7, 26, 3, 70, 5, 58, 0, 55, 8, 50, 6, 26, 4, 82, 1, 26, 
    7, 57, 3, 55, 0, 22, 5, 90, 2, 60, 6, 74, 8, 57, 1, 41, 4, 62, 
    1, 59, 7, 93, 5, 44, 0, 49, 3, 39, 2, 86, 4, 51, 8, 19, 6,  3, 
    7, 32, 3, 21, 0, 39, 1, 20, 8, 65, 4, 86, 2, 19, 5, 16, 6, 12, 
    1, 78, 2, 11, 8, 39, 3, 27, 7, 71, 0, 80, 5, 64, 4, 59, 6, 77, 
    2, 13, 8, 59, 0, 46, 1, 46, 5, 41, 3, 97, 6, 93, 4, 82, 7, 31, 
    6, 97, 4, 24, 1, 16, 2, 93, 7, 99, 8, 52, 3, 68, 5, 68, 0, 54
  };
  const int q1024[] = {
    9, 9, // Number of jobs and machines
    3, 43, 2, 81, 8, 19, 4, 12, 0,  9, 1, 63, 5, 94, 7,  9, 6, 87, 
    4,  3, 1, 88, 8, 80, 2, 56, 0, 49, 6,  1, 7, 77, 5, 39, 3, 62, 
    0, 94, 5, 51, 1, 57, 7, 83, 2, 46, 3, 15, 4, 35, 8, 56, 6, 38, 
    3, 62, 5, 34, 2, 87, 7,  8, 0, 69, 1, 59, 6, 14, 8, 18, 4, 22, 
    4,  2, 8, 45, 6, 51, 1, 72, 0, 64, 7, 20, 3, 60, 2, 67, 5, 92, 
    4, 17, 2, 48, 0, 11, 1, 48, 6, 79, 8, 32, 3, 30, 5, 19, 7, 80, 
    2, 33, 5,  6, 3, 44, 0, 42, 4,  9, 1, 29, 7, 90, 6, 38, 8, 38, 
    8, 94, 3, 67, 0, 29, 2, 69, 7,  9, 4, 80, 1, 25, 6, 23, 5,  9, 
    6, 92, 3, 40, 0, 25, 5, 10, 7, 31, 4, 52, 8, 13, 2, 28, 1, 19
  };
  const int q1025[] = {
    9, 9, // Number of jobs and machines
    0, 86, 6,  2, 2, 18, 3, 95, 4, 23, 7, 83, 1, 31, 5, 66, 8, 32, 
    3, 62, 6, 37, 8, 73, 4, 23, 2, 92, 7, 37, 5, 70, 0, 10, 1, 45, 
    0, 44, 6, 82, 4, 95, 7, 18, 8, 77, 2,  1, 3, 53, 1,  5, 5, 27, 
    3, 25, 7, 12, 1, 81, 6, 52, 4,  6, 5, 95, 8,  5, 0, 38, 2, 70, 
    2, 35, 4, 32, 8, 47, 6, 67, 5,  9, 0, 77, 1, 20, 3, 31, 7, 37, 
    6, 90, 4, 79, 0, 97, 7, 51, 1, 33, 2, 39, 3,  4, 8, 85, 5, 52, 
    6, 69, 3,  4, 8, 64, 7, 58, 2, 70, 4, 41, 1,  7, 0, 29, 5, 72, 
    4, 66, 0, 78, 8, 17, 2, 75, 1, 93, 6, 45, 7, 77, 5, 64, 3,  2, 
    8, 92, 1, 61, 4, 94, 6, 46, 7, 12, 3,  9, 0, 67, 5, 62, 2, 43
  };
  const int q1026[] = {
    9, 9, // Number of jobs and machines
    0, 55, 3, 31, 4, 87, 8, 97, 2, 48, 1, 48, 6, 74, 5, 26, 7, 89, 
    8, 30, 6, 17, 0, 13, 4, 36, 7, 62, 3, 60, 5,  5, 1, 27, 2, 18, 
    4, 72, 0, 15, 6,  9, 8, 62, 2, 99, 5, 49, 3, 70, 1, 15, 7, 75, 
    5, 24, 1, 60, 3, 79, 4,  8, 7, 30, 8, 41, 6,  7, 2, 27, 0, 90, 
    4, 36, 6, 31, 5, 80, 1, 80, 7,  3, 3, 22, 8,  5, 0, 64, 2, 32, 
    1,  4, 0, 50, 2, 51, 6,  5, 3, 31, 8, 30, 4, 16, 7, 69, 5, 19, 
    6, 66, 1, 22, 2, 24, 5, 40, 0,  9, 4, 36, 3, 36, 8,  1, 7, 63, 
    0, 93, 2, 25, 1, 51, 6, 64, 7,  3, 8, 43, 4, 89, 3, 92, 5, 51, 
    5, 79, 6, 75, 7, 82, 2, 43, 1, 68, 8, 84, 4,  5, 0, 27, 3, 72
  };
  const int q1027[] = {
    9, 9, // Number of jobs and machines
    7, 22, 8, 81, 1, 80, 4, 98, 2, 11, 5, 12, 0, 98, 3, 91, 6, 58, 
    1, 25, 5,  4, 6, 93, 8,  6, 7, 12, 0, 44, 4, 32, 3, 43, 2, 88, 
    7, 22, 1, 64, 6, 45, 2,  9, 4,  1, 0, 78, 8, 16, 5, 16, 3, 14, 
    0, 63, 6, 20, 7, 48, 2, 63, 3, 39, 8, 31, 1, 57, 4, 80, 5, 94, 
    0, 56, 5, 61, 3, 32, 1, 71, 4, 61, 8, 88, 7, 79, 6, 77, 2, 67, 
    8,  6, 5, 17, 6, 67, 2, 41, 3, 88, 0, 34, 7, 86, 1, 27, 4, 17, 
    2, 81, 8, 52, 3, 74, 5, 93, 6, 15, 0,  5, 4, 23, 7, 79, 1, 62, 
    3, 92, 2,  3, 8, 88, 5, 29, 1, 41, 7, 61, 4, 30, 0,  1, 6,  4, 
    4, 14, 2, 70, 8, 37, 3, 54, 6, 77, 5, 94, 0, 91, 1, 25, 7, 72
  };
  const int q1028[] = {
    9, 9, // Number of jobs and machines
    0, 14, 1, 52, 5, 61, 3,  8, 2, 25, 7, 85, 4, 30, 6, 77, 8, 59, 
    5, 86, 0, 13, 6, 92, 1, 76, 7, 12, 2, 61, 8, 41, 4, 17, 3, 53, 
    3, 42, 5, 18, 8,  9, 2, 45, 1, 21, 7, 59, 6, 99, 0, 17, 4, 72, 
    3, 94, 8, 84, 2, 17, 0, 52, 5,  9, 1, 40, 4, 55, 6, 76, 7, 52, 
    7, 52, 1, 49, 6, 65, 3, 24, 2, 75, 0, 90, 5, 99, 8, 22, 4, 37, 
    8, 57, 7, 82, 3,  6, 0, 16, 4, 42, 1, 68, 6, 31, 5,  8, 2, 60, 
    2,  5, 4, 51, 1, 53, 7, 79, 0, 92, 3, 27, 8, 46, 5, 48, 6, 10, 
    8, 94, 1, 36, 2, 67, 5,  8, 6, 59, 3, 96, 4, 16, 7, 16, 0, 10, 
    3, 96, 4, 93, 1, 48, 7, 77, 2, 39, 8, 16, 5, 41, 0, 84, 6, 26
  };
  const int q1029[] = {
    9, 9, // Number of jobs and machines
    5, 78, 2, 58, 0, 94, 3, 26, 7, 51, 4, 75, 6, 68, 1, 47, 8, 74, 
    5, 68, 0, 34, 8, 35, 4, 26, 3, 60, 7, 76, 1,  1, 2, 29, 6, 26, 
    4, 76, 3, 22, 6, 11, 8, 53, 5, 85, 7, 16, 0, 94, 2, 54, 1,  3, 
    5, 15, 4, 39, 8, 32, 1, 24, 6, 89, 3, 36, 0, 11, 2, 19, 7, 31, 
    4,  2, 2, 64, 3, 23, 0, 21, 6, 23, 1,  7, 7, 42, 8, 76, 5,  4, 
    0, 37, 2, 62, 4, 95, 1, 91, 7, 57, 5, 38, 3, 69, 8, 97, 6, 26, 
    1, 15, 7, 12, 4, 77, 8, 82, 0, 96, 5, 38, 2,  1, 3, 39, 6, 11, 
    6, 55, 2,  4, 1, 53, 0,  6, 3, 10, 8,  8, 7, 42, 5, 27, 4, 61, 
    7, 38, 2, 28, 4, 81, 5, 71, 3, 50, 0, 93, 6, 16, 1, 95, 8, 96
  };
  const int q1030[] = {
    9, 9, // Number of jobs and machines
    7, 86, 5, 22, 3, 73, 1, 73, 4, 64, 0, 46, 8, 76, 6, 71, 2, 54, 
    4, 94, 7, 54, 5, 36, 3, 62, 8, 85, 0, 36, 6, 38, 1, 36, 2, 52, 
    7, 92, 0, 37, 4, 27, 3, 12, 5, 32, 6,  4, 1,  1, 8, 53, 2, 94, 
    2, 75, 0, 47, 4, 17, 5, 95, 8, 66, 1, 79, 7, 19, 6, 17, 3, 74, 
    2, 20, 8, 33, 0, 17, 4, 55, 7, 65, 5, 78, 6, 66, 3, 48, 1, 30, 
    4, 16, 5,  1, 3, 44, 0, 51, 6,  3, 1, 74, 7, 96, 2, 82, 8, 20, 
    3, 88, 7, 35, 1, 44, 2, 54, 4, 59, 5, 54, 0, 88, 6, 18, 8, 62, 
    8,  5, 1,  6, 2, 68, 4, 26, 5, 36, 3, 43, 6, 73, 7, 86, 0, 87, 
    4, 42, 3, 14, 6, 56, 0,  7, 8, 51, 1, 59, 2, 32, 5, 45, 7, 70
  };
  const int q1031[] = {
    9, 9, // Number of jobs and machines
    1, 94, 8,  9, 5, 20, 7, 86, 2, 30, 6, 23, 3, 10, 0, 60, 4, 16, 
    6, 73, 4, 31, 7, 18, 3, 11, 8, 90, 2, 67, 5, 93, 1,  4, 0, 78, 
    1, 48, 3, 79, 5, 77, 4, 66, 7,  9, 6, 74, 0, 49, 8, 33, 2,  9, 
    7, 33, 8, 48, 1, 36, 0, 28, 5, 72, 4, 83, 6, 58, 2, 35, 3, 91, 
    3, 68, 7, 64, 8, 69, 2, 65, 6, 45, 1, 96, 0, 74, 4, 70, 5, 75, 
    4, 29, 7, 12, 3, 85, 0,  7, 2, 20, 6,  6, 1, 57, 8, 90, 5, 94, 
    0,  2, 6, 38, 4, 22, 7,  9, 1, 42, 5, 13, 2, 71, 8, 96, 3, 22, 
    3, 54, 7, 80, 0, 93, 1, 54, 6, 88, 5, 58, 4, 78, 8, 77, 2,  3, 
    3, 46, 5, 76, 8, 63, 0, 91, 4, 13, 6, 27, 1, 75, 7, 89, 2, 89
  };
  const int q1032[] = {
    9, 9, // Number of jobs and machines
    1, 86, 4, 11, 3, 93, 7, 69, 6,  2, 0, 55, 8, 45, 2,  1, 5, 13, 
    1, 18, 7, 70, 5, 48, 3, 66, 4, 97, 6, 87, 8, 70, 0, 40, 2, 14, 
    7, 12, 0, 76, 5, 59, 1, 71, 8, 12, 6, 38, 3, 39, 4, 58, 2, 79, 
    1, 14, 0, 44, 3, 51, 2, 78, 6, 80, 7, 49, 4,  8, 5, 45, 8, 32, 
    7, 39, 2,  1, 3, 22, 1, 71, 0, 14, 8, 59, 4, 93, 5, 94, 6, 21, 
    8, 24, 1, 12, 3, 69, 5, 55, 7, 48, 4,  3, 2, 70, 0,  7, 6, 52, 
    2, 52, 5, 96, 1, 84, 6, 85, 3, 27, 4, 35, 7, 49, 8, 59, 0, 41, 
    5, 46, 7, 92, 6, 77, 1, 76, 8, 85, 3, 31, 2, 46, 0,  1, 4, 11, 
    7, 12, 8, 41, 0, 16, 4, 79, 2, 55, 6, 41, 3, 27, 1, 35, 5,  3
  };
  const int q1033[] = {
    9, 9, // Number of jobs and machines
    1, 93, 2, 47, 0, 43, 6, 29, 7, 54, 3, 93, 5, 97, 4,  7, 8, 11, 
    0, 10, 4,  7, 8, 51, 1,  3, 7, 79, 5, 36, 3, 64, 6, 31, 2, 89, 
    6, 31, 8, 55, 2,  4, 0, 71, 7,  8, 4, 35, 3, 85, 1, 84, 5, 23, 
    2, 27, 7, 83, 1, 67, 5,  8, 6, 27, 4, 56, 8, 19, 0, 69, 3, 36, 
    4, 51, 7, 21, 5, 15, 1, 39, 3,  4, 8, 85, 0, 39, 2, 82, 6, 10, 
    2, 87, 3, 23, 0, 80, 1, 16, 6, 70, 7, 34, 4, 12, 8, 17, 5, 80, 
    3, 37, 1, 16, 0, 90, 7,  2, 8, 68, 6, 82, 5, 35, 4, 87, 2, 99, 
    0,  5, 6, 92, 4, 93, 5, 44, 7, 18, 1, 87, 8, 67, 2, 14, 3, 90, 
    5, 23, 3, 39, 4, 27, 6, 67, 2, 70, 0, 38, 7, 62, 8, 33, 1, 62
  };
  const int q1034[] = {
    9, 9, // Number of jobs and machines
    6, 87, 5,  7, 7, 32, 2, 21, 3, 22, 0, 88, 1, 47, 8, 46, 4,  1, 
    3, 81, 4,  4, 6, 76, 7, 87, 2, 91, 8, 99, 1, 27, 5, 12, 0, 64, 
    5, 74, 7, 92, 4, 39, 3, 22, 2, 89, 8, 55, 6, 36, 1, 16, 0, 17, 
    2, 10, 7, 15, 5, 21, 8, 23, 0, 54, 6, 29, 3, 51, 1,  3, 4, 81, 
    7, 10, 4, 53, 8, 29, 2, 79, 0, 51, 1, 19, 5, 66, 6, 51, 3, 92, 
    8, 63, 4, 36, 5, 56, 0, 22, 1, 74, 6, 80, 3,  7, 2,  5, 7, 26, 
    2, 70, 0, 36, 8,  7, 4,  6, 5, 68, 7,  9, 1, 12, 3, 23, 6, 14, 
    1, 41, 6, 51, 8, 73, 5, 17, 7, 12, 4, 34, 2, 68, 3,  7, 0, 85, 
    3, 38, 7, 83, 4, 93, 2, 85, 6, 13, 8, 81, 1, 38, 5, 33, 0, 89
  };
  const int q1035[] = {
    9, 9, // Number of jobs and machines
    3, 52, 7, 75, 0, 78, 8, 26, 2, 39, 6,  1, 5, 21, 1,  2, 4,  2, 
    1, 29, 3, 94, 5, 99, 6, 71, 4, 99, 7, 72, 2, 17, 0, 61, 8,  2, 
    6,  2, 7, 56, 5, 85, 2, 41, 0, 35, 3, 70, 1, 39, 4, 34, 8, 33, 
    1,  5, 2, 63, 8,  5, 0, 97, 4, 75, 6, 52, 5, 68, 7, 92, 3, 35, 
    1, 58, 4, 33, 8, 90, 2, 87, 7, 14, 6, 31, 3, 84, 5, 43, 0,  1, 
    5, 88, 3, 52, 4,  7, 6, 50, 7, 88, 0,  1, 8, 71, 2, 40, 1, 78, 
    7, 33, 6, 87, 0, 74, 2,  8, 5, 16, 8, 42, 1, 75, 3, 10, 4, 37, 
    6, 54, 8, 30, 7, 74, 3, 30, 1, 66, 2, 74, 5, 70, 4, 40, 0, 62, 
    0, 74, 6, 60, 2, 99, 3, 81, 1, 31, 8, 39, 7, 61, 5, 60, 4, 61
  };
  const int q1036[] = {
    9, 9, // Number of jobs and machines
    2, 73, 6, 96, 0, 71, 5, 98, 4, 91, 1, 27, 8, 74, 3, 35, 7, 68, 
    3, 24, 4, 59, 5, 44, 0, 34, 8, 19, 6, 42, 2, 51, 1, 43, 7, 45, 
    0, 80, 7, 51, 2,  9, 4, 53, 6, 29, 3, 82, 5,  5, 8, 54, 1, 95, 
    6,  8, 8, 76, 1, 94, 7, 37, 3, 39, 4, 95, 0, 18, 2, 70, 5, 58, 
    6,  2, 2, 32, 3, 50, 7, 20, 5, 32, 4, 61, 8, 67, 0, 68, 1, 19, 
    6, 70, 1, 22, 7, 29, 3, 23, 0, 80, 4, 86, 2, 36, 8, 34, 5, 45, 
    6, 85, 1, 94, 4,  5, 2, 75, 3,  2, 7, 85, 8, 96, 0, 75, 5, 21, 
    8, 50, 4, 33, 5, 86, 1, 68, 6, 45, 0, 80, 7,  2, 2, 89, 3, 49, 
    6, 37, 8, 15, 2, 28, 5, 72, 4, 28, 3, 52, 7, 51, 0,  7, 1, 62
  };
  const int q1037[] = {
    9, 9, // Number of jobs and machines
    1, 71, 6, 40, 0, 84, 5, 91, 8, 85, 7, 16, 3,  1, 4, 25, 2, 24, 
    6, 11, 2, 56, 1, 45, 7, 56, 3, 28, 8, 93, 0, 43, 4, 21, 5, 80, 
    5, 17, 0, 30, 2, 53, 6, 90, 3, 99, 4, 14, 8, 27, 7, 60, 1, 48, 
    8, 74, 4, 54, 3, 29, 7, 35, 2, 69, 5, 98, 6, 75, 1, 36, 0, 54, 
    5, 17, 1,  4, 7, 60, 2, 87, 4, 32, 3, 11, 8, 53, 0, 16, 6, 91, 
    0, 50, 7, 39, 4,  7, 6, 92, 1, 86, 8, 25, 3, 75, 5, 54, 2, 89, 
    1, 26, 4, 21, 3, 25, 8, 77, 7, 83, 5, 14, 6, 10, 2, 12, 0, 98, 
    5, 99, 8, 15, 4, 20, 0, 20, 2,  4, 1,  7, 6, 84, 7, 35, 3,  7, 
    7, 42, 0, 82, 5, 92, 3, 26, 2, 72, 8, 99, 1, 42, 6, 96, 4, 45
  };
  const int q1038[] = {
    9, 9, // Number of jobs and machines
    4, 99, 7, 37, 1, 60, 6, 42, 2, 80, 3, 76, 8, 41, 0, 41, 5, 31, 
    5, 19, 8, 17, 0, 97, 4,  4, 3, 32, 7, 17, 1, 97, 6, 54, 2, 23, 
    3, 27, 5, 82, 1, 78, 0, 46, 7, 92, 2, 99, 8, 78, 4, 66, 6, 74, 
    8,  5, 2, 63, 1, 43, 7, 89, 6, 85, 0,  9, 3, 13, 5, 79, 4, 18, 
    6, 51, 1,  2, 0, 59, 2, 55, 3, 16, 4, 22, 8, 58, 5, 75, 7, 23, 
    5, 29, 2, 78, 3, 39, 6, 91, 4, 20, 8, 94, 1, 82, 0,  7, 7, 29, 
    4, 38, 7, 61, 8, 73, 1, 61, 3, 64, 2, 70, 6, 64, 5, 73, 0,  7, 
    1, 10, 3, 21, 2, 24, 7, 94, 4,  2, 5, 39, 6, 42, 0, 38, 8, 70, 
    3, 73, 2, 58, 1, 34, 8, 64, 5, 26, 7, 82, 6, 10, 0, 78, 4,  6
  };
  const int q1039[] = {
    9, 9, // Number of jobs and machines
    7, 35, 2, 64, 3, 89, 0, 55, 6, 37, 8, 11, 1, 25, 5, 26, 4,  6, 
    7, 23, 1,  2, 3, 12, 5, 23, 6, 16, 0, 52, 2, 59, 4, 89, 8, 28, 
    6,  4, 1, 41, 0, 56, 5, 83, 3, 45, 2, 85, 4, 40, 7, 67, 8,  8, 
    8, 72, 3,  7, 5, 11, 4, 63, 0, 88, 6, 49, 2, 97, 1, 31, 7, 67, 
    0, 96, 3,  4, 8, 64, 5, 78, 6, 57, 4,  2, 2, 68, 1, 18, 7, 84, 
    8, 18, 4, 31, 6, 26, 7, 98, 3, 33, 1, 54, 2, 38, 0, 99, 5, 48, 
    2, 76, 6, 13, 8, 72, 7, 73, 1, 54, 0, 28, 3, 46, 4, 12, 5, 48, 
    8, 97, 3, 55, 6, 55, 1, 28, 5, 39, 0, 59, 7, 35, 4, 98, 2, 32, 
    0, 56, 3, 64, 6, 20, 1, 42, 4, 48, 5, 11, 8, 93, 7, 98, 2,  2
  };
  const int q1040[] = {
    9, 9, // Number of jobs and machines
    8, 39, 1, 26, 3, 10, 5, 99, 0, 69, 4, 44, 6, 24, 7, 66, 2, 67, 
    8, 91, 5, 55, 3, 39, 0, 64, 7,  8, 1,  5, 4, 63, 6, 15, 2, 47, 
    5, 89, 6, 65, 8, 75, 1, 35, 0, 47, 2, 53, 4,  3, 3, 81, 7, 69, 
    1, 34, 8, 42, 2, 60, 0, 46, 4, 36, 3, 25, 5, 82, 6, 16, 7,  1, 
    6,  2, 2,  9, 7, 85, 8, 30, 5, 48, 0, 13, 4, 84, 1, 15, 3, 84, 
    8, 63, 4, 67, 3, 30, 5, 24, 0, 86, 2, 40, 7, 56, 1, 49, 6,  3, 
    1, 73, 3, 55, 0, 59, 2, 97, 5, 82, 8, 89, 4, 22, 7,  7, 6, 15, 
    7, 64, 5,  3, 6, 22, 3, 71, 8, 92, 1,  9, 4, 40, 2, 28, 0,  3, 
    2, 53, 6, 52, 4, 13, 1,  3, 5, 28, 0, 57, 3,  2, 7,  5, 8, 55
  };
  const int q1041[] = {
    9, 9, // Number of jobs and machines
    7, 17, 1,  6, 5, 17, 4, 37, 0, 14, 8, 16, 6, 34, 2, 40, 3, 89, 
    8, 52, 1, 16, 3, 23, 4, 41, 0, 13, 6, 73, 5, 49, 7, 26, 2, 43, 
    7, 85, 3, 80, 0, 49, 5, 56, 6, 96, 4, 39, 2, 30, 1, 39, 8, 70, 
    7, 56, 4, 98, 2, 99, 0, 80, 1,  9, 5, 29, 6,  3, 8, 13, 3, 44, 
    5, 85, 4, 39, 7, 78, 1, 74, 2, 80, 6, 66, 8, 38, 0, 46, 3, 49, 
    8,  1, 4, 88, 6, 65, 2, 26, 1, 92, 7, 10, 0, 14, 3, 14, 5, 34, 
    0, 40, 3, 13, 8, 23, 5, 55, 1, 62, 6, 90, 2, 54, 7, 72, 4, 99, 
    2,  5, 6, 21, 0, 31, 1, 12, 7, 22, 8, 50, 3, 21, 5, 86, 4, 86, 
    6, 18, 2, 21, 3, 82, 5, 54, 4, 76, 7, 54, 1, 60, 8, 29, 0, 20
  };
  const int q1042[] = {
    9, 9, // Number of jobs and machines
    6, 11, 5, 57, 4, 33, 8, 35, 1, 98, 2, 59, 7, 71, 3,  6, 0, 86, 
    5, 41, 6, 46, 8, 83, 2, 70, 7, 55, 4, 58, 0, 46, 1, 50, 3, 33, 
    7, 27, 4, 44, 5, 77, 0, 89, 3, 42, 8, 28, 1, 94, 2, 35, 6, 19, 
    1,  4, 0, 68, 6, 13, 2, 49, 7, 12, 8, 46, 3,  1, 5, 72, 4,  5, 
    1, 18, 6, 52, 0, 82, 7, 73, 5, 71, 3,  3, 2, 71, 4, 12, 8, 63, 
    4, 26, 0,  4, 1,  2, 7, 91, 6, 23, 5, 28, 2, 98, 8, 25, 3, 76, 
    7,  8, 4, 54, 0, 79, 6, 69, 5, 40, 1, 71, 8, 91, 3, 98, 2, 30, 
    7,  7, 3, 69, 8, 16, 0, 20, 1, 98, 6,  3, 5, 75, 2,  4, 4, 73, 
    1, 79, 7, 74, 6, 74, 0, 95, 8, 22, 4, 58, 5,  1, 2, 94, 3, 44
  };
  const int q1043[] = {
    9, 9, // Number of jobs and machines
    0, 34, 8, 64, 3, 56, 2, 14, 5, 48, 7, 98, 6, 11, 4, 73, 1, 50, 
    1,  2, 0, 10, 2, 25, 8,  3, 5, 81, 6, 28, 4, 96, 7, 83, 3, 25, 
    8,  6, 3, 73, 5, 69, 2, 59, 6, 36, 7, 94, 0, 85, 1, 27, 4, 86, 
    3,  3, 4, 49, 2, 62, 1, 93, 0, 94, 8, 28, 7, 69, 5, 16, 6, 60, 
    4, 98, 3, 61, 1, 20, 2, 93, 8, 91, 5, 88, 6, 98, 7, 55, 0, 63, 
    1, 28, 2, 22, 3, 41, 5,  3, 7, 54, 4, 10, 6,  2, 0, 42, 8, 71, 
    6, 94, 2,  9, 4, 46, 7, 63, 3, 61, 5, 66, 0, 53, 1, 20, 8, 48, 
    7, 98, 8, 42, 4, 70, 3, 15, 1, 77, 6, 53, 5, 51, 2, 73, 0, 65, 
    0, 83, 1, 93, 5, 70, 7, 87, 2, 95, 6, 66, 4, 69, 8, 57, 3, 36
  };
  const int q1044[] = {
    9, 9, // Number of jobs and machines
    2, 30, 8, 47, 7, 66, 3, 84, 0, 90, 5, 47, 6, 32, 1, 26, 4, 39, 
    2, 69, 7, 28, 5,  1, 0, 29, 8,  9, 3, 10, 6, 88, 4, 81, 1, 44, 
    0, 63, 8, 76, 7, 65, 2, 55, 5, 64, 1, 98, 4,  7, 6, 85, 3, 69, 
    0, 88, 6, 75, 4, 44, 2, 68, 1, 31, 8, 44, 3, 91, 7, 30, 5, 41, 
    0, 61, 5, 53, 7, 31, 8, 39, 4, 47, 2, 99, 3, 94, 1, 64, 6, 76, 
    3, 77, 7,  7, 1, 17, 2, 57, 0, 29, 6, 26, 4, 90, 5, 87, 8, 48, 
    6, 94, 7, 88, 5, 65, 2, 44, 1, 83, 0, 72, 8, 28, 3, 37, 4, 79, 
    2, 50, 0, 22, 8, 57, 1, 16, 5, 29, 3, 73, 6, 73, 4, 43, 7, 73, 
    8, 56, 5, 60, 0, 47, 6, 39, 1, 46, 7, 22, 2, 40, 3, 90, 4, 52
  };
  const int q1045[] = {
    9, 9, // Number of jobs and machines
    5, 57, 0,  3, 8, 98, 1, 39, 7, 18, 6, 59, 3, 65, 4, 44, 2, 87, 
    4,  6, 3, 15, 0, 31, 2, 69, 8, 80, 1, 46, 5, 81, 6, 94, 7, 66, 
    3, 30, 5, 55, 8, 90, 4, 89, 2, 33, 0, 70, 6,  3, 1, 27, 7, 93, 
    3, 81, 7, 11, 2, 74, 5, 35, 6, 77, 4,  7, 1, 91, 0, 92, 8, 12, 
    2, 64, 0,  9, 3, 28, 5, 95, 4, 38, 8, 76, 7, 84, 1, 24, 6, 46, 
    2, 49, 4, 26, 1, 72, 7, 17, 6, 45, 3, 14, 8, 57, 0, 24, 5, 77, 
    0, 56, 8, 10, 7, 94, 1, 27, 4, 40, 6, 74, 3, 42, 2, 87, 5, 53, 
    7, 73, 0, 70, 2, 85, 8, 73, 6, 24, 4, 83, 3, 71, 1, 23, 5, 11, 
    3,  9, 2, 49, 0, 99, 6, 57, 8, 27, 1, 85, 5, 49, 4, 68, 7, 42
  };
  const int q1046[] = {
    9, 9, // Number of jobs and machines
    2, 61, 1, 70, 6, 64, 8,  6, 7, 84, 3, 16, 4, 75, 0, 46, 5, 27, 
    8, 52, 4, 62, 7, 33, 5, 42, 6, 48, 0, 39, 3, 45, 2, 11, 1, 35, 
    6, 45, 2, 28, 7, 65, 3, 64, 1, 79, 8, 95, 5, 15, 0, 89, 4, 59, 
    7, 54, 8, 18, 5, 77, 2, 47, 1, 25, 3, 26, 4, 26, 0, 68, 6, 45, 
    6, 95, 7, 86, 4, 89, 3, 86, 5, 21, 1, 60, 2, 93, 0, 61, 8, 92, 
    1, 78, 3, 13, 2, 12, 6, 41, 0, 69, 4, 82, 7, 73, 8, 98, 5, 71, 
    3, 68, 6, 68, 0, 63, 5,  5, 4, 96, 1, 10, 7,  5, 8, 46, 2, 34, 
    5, 77, 1, 77, 2, 67, 0, 18, 3, 74, 8, 68, 4, 26, 6, 60, 7, 88, 
    8, 93, 3, 83, 2, 96, 0, 92, 7, 65, 4, 66, 5, 85, 1, 42, 6, 57
  };
  const int q1047[] = {
    9, 9, // Number of jobs and machines
    8, 86, 6, 46, 7,  6, 1, 23, 3, 80, 0, 16, 2, 88, 4, 63, 5, 28, 
    6, 87, 2, 22, 3, 33, 5, 13, 8, 88, 4, 80, 1, 26, 7, 43, 0,  1, 
    7, 64, 3, 10, 2, 17, 1,  2, 5, 77, 4, 92, 0,  9, 8, 63, 6, 20, 
    4, 68, 0, 47, 7, 86, 6, 81, 1, 48, 3, 66, 2, 94, 8, 92, 5, 59, 
    7,  7, 0, 91, 5, 56, 4, 85, 1, 83, 8,  4, 2, 66, 3, 10, 6, 92, 
    5, 24, 8, 43, 7,  1, 4, 18, 1, 44, 3, 32, 2, 88, 6, 24, 0, 87, 
    1, 40, 0, 56, 3, 64, 6, 66, 8, 32, 7,  1, 2, 63, 4, 64, 5, 39, 
    5, 42, 8, 19, 0, 50, 4, 17, 7, 44, 2, 34, 1, 62, 3, 48, 6, 70, 
    1, 94, 5, 27, 6, 98, 8, 38, 2, 53, 0, 16, 7, 31, 4, 27, 3, 89
  };
  const int q1048[] = {
    9, 9, // Number of jobs and machines
    8, 90, 4, 64, 5, 43, 3, 16, 7, 20, 6, 67, 2, 78, 0,  9, 1, 63, 
    7, 42, 3, 85, 5, 96, 4, 55, 0, 73, 2, 95, 6, 95, 8,  8, 1,  1, 
    6, 84, 5, 88, 3, 87, 0,  4, 7, 68, 2, 99, 8, 87, 4, 26, 1, 95, 
    0, 38, 2, 95, 8, 60, 3, 38, 6, 26, 5, 91, 4, 61, 1, 68, 7,  8, 
    5, 93, 4, 73, 2, 62, 6, 99, 8, 96, 1, 40, 0, 87, 7, 95, 3, 11, 
    6, 30, 4, 91, 8,  1, 3, 72, 1, 69, 7, 28, 2, 50, 5, 35, 0, 95, 
    5, 55, 4, 59, 6, 47, 0, 89, 2, 61, 8, 13, 7, 29, 1, 87, 3, 41, 
    8, 57, 0, 56, 3, 10, 7, 52, 5, 76, 6,  1, 1, 17, 2, 68, 4, 91, 
    6, 61, 0,  5, 1,  9, 5, 64, 7, 80, 3, 62, 4, 11, 8, 93, 2, 52
  };
  const int q1049[] = {
    9, 9, // Number of jobs and machines
    2, 51, 6,  7, 7, 47, 5, 15, 3, 94, 8, 46, 4, 94, 0, 59, 1, 50, 
    4, 59, 0, 70, 6, 55, 7, 11, 2, 60, 8, 89, 3, 21, 5, 24, 1, 18, 
    4, 74, 8, 29, 6, 15, 2, 78, 3, 29, 1, 81, 7, 59, 0, 49, 5, 42, 
    4,  4, 7, 31, 8, 31, 0, 22, 3, 75, 6, 83, 1, 79, 5, 37, 2, 58, 
    7, 90, 8, 43, 2, 24, 0, 90, 5, 40, 6, 52, 1, 36, 3, 29, 4, 67, 
    8, 18, 5, 40, 4, 43, 6, 63, 1, 21, 3,  4, 2, 89, 0, 10, 7, 61, 
    3, 70, 7,  2, 5, 53, 0, 51, 6,  4, 4, 99, 2, 61, 1, 95, 8, 54, 
    6, 25, 0, 20, 4, 65, 3, 11, 1, 99, 5, 94, 8, 54, 2, 47, 7, 21, 
    6, 15, 3, 96, 0, 91, 7, 83, 2, 25, 1,  4, 8, 39, 5, 66, 4,  7
  };
  const int q1050[] = {
    9, 9, // Number of jobs and machines
    7, 44, 5, 66, 1, 82, 2, 34, 0, 82, 3, 32, 8,  3, 6,  2, 4, 46, 
    4, 44, 5, 59, 6, 83, 0, 72, 7, 91, 1, 49, 2, 24, 3, 62, 8, 54, 
    6,  4, 7, 15, 4, 45, 0, 14, 3, 43, 5, 60, 8, 48, 1, 32, 2, 15, 
    2, 70, 5, 64, 6, 17, 0, 71, 1, 82, 7, 75, 4, 25, 3, 39, 8, 68, 
    8, 67, 5, 46, 6, 71, 1, 27, 4, 68, 2, 52, 0, 86, 3, 55, 7, 10, 
    0,  4, 4,  7, 8, 69, 2, 66, 7, 61, 6,  5, 5, 59, 1, 77, 3,  8, 
    5, 12, 7, 39, 1, 74, 4, 11, 6, 71, 8, 86, 0,  6, 2, 61, 3, 15, 
    1, 45, 3, 66, 0, 72, 6, 91, 7, 35, 5,  5, 8, 58, 2, 53, 4,  5, 
    8, 77, 5, 27, 1,  4, 6, 99, 0, 58, 7, 31, 4, 70, 3, 86, 2, 18
  };
  const int q1051[] = {
    9, 9, // Number of jobs and machines
    0, 38, 8, 15, 7, 24, 5, 79, 1, 91, 2, 22, 4, 11, 6, 77, 3, 18, 
    6, 37, 7, 23, 1, 36, 5, 30, 3, 58, 0, 39, 8, 44, 2, 70, 4, 23, 
    3, 38, 5, 68, 2, 63, 0, 69, 6, 24, 7, 94, 1, 86, 8, 25, 4, 28, 
    7, 99, 1, 52, 3, 19, 8, 63, 4, 61, 0,  5, 6, 17, 2, 44, 5, 83, 
    6, 94, 3, 77, 7, 12, 1,  7, 2, 48, 5, 50, 0, 11, 8, 40, 4, 81, 
    4, 31, 0, 39, 5, 35, 7, 37, 1, 53, 3, 19, 6, 27, 2, 29, 8,  2, 
    3, 88, 7, 23, 8, 26, 5, 82, 1, 65, 6, 44, 4, 96, 2, 26, 0, 75, 
    4,  2, 2, 79, 1,  5, 8, 45, 6, 37, 5, 17, 3, 25, 0, 50, 7, 91, 
    1, 38, 5, 13, 4,  4, 8, 40, 7, 34, 3,  5, 0, 46, 6, 48, 2, 14
  };
  const int q1052[] = {
    9, 9, // Number of jobs and machines
    3, 99, 8, 83, 6,  6, 4, 69, 0, 99, 7, 76, 5, 14, 1, 50, 2, 24, 
    0, 57, 2, 76, 3, 64, 6, 70, 5, 41, 1, 83, 8, 92, 7, 84, 4, 37, 
    8, 52, 4, 99, 1, 13, 3, 54, 6, 47, 7, 16, 0, 47, 2,  3, 5, 23, 
    3, 74, 0, 62, 7,  2, 4, 19, 1, 17, 6, 80, 2, 75, 5, 68, 8, 89, 
    5, 71, 2, 45, 3, 31, 4, 94, 7, 79, 8,  1, 0, 45, 1, 58, 6, 45, 
    6, 93, 2, 84, 8, 84, 0, 30, 1, 73, 7,  1, 4,  7, 5, 68, 3, 80, 
    5, 76, 6, 53, 0, 40, 7, 77, 4, 71, 2, 33, 8, 59, 1, 13, 3, 76, 
    0, 19, 2, 93, 1, 13, 5, 26, 3, 47, 8, 50, 7, 84, 4, 78, 6, 11, 
    0, 39, 7, 54, 6, 80, 4, 43, 8, 19, 1, 46, 2, 89, 5, 90, 3, 60
  };
  const int q1053[] = {
    9, 9, // Number of jobs and machines
    1, 70, 2, 50, 0, 85, 6, 26, 4, 44, 7, 53, 3, 94, 5, 77, 8,  6, 
    6, 52, 4, 92, 1, 43, 5, 77, 7, 41, 0, 33, 3, 12, 8, 59, 2, 64, 
    3, 33, 7, 55, 2, 91, 6, 23, 4, 66, 8, 51, 1, 69, 0, 43, 5, 99, 
    6, 13, 3, 61, 2,  5, 1, 38, 7, 72, 8, 13, 0, 17, 4, 93, 5, 18, 
    4, 57, 2, 80, 7, 72, 0, 16, 3, 57, 8, 34, 1, 82, 5, 15, 6, 89, 
    3, 83, 6, 74, 4, 18, 8,  3, 5, 23, 0, 43, 2, 17, 7, 41, 1, 62, 
    4, 70, 8, 45, 5,  2, 1, 46, 6, 38, 7, 41, 0, 74, 2, 97, 3, 31, 
    6, 90, 7, 27, 8, 20, 0, 15, 3,  7, 1, 20, 4, 84, 2, 74, 5, 38, 
    6, 45, 8, 21, 7, 84, 1, 52, 0, 20, 3, 11, 2, 64, 4, 69, 5, 51
  };
  const int q1054[] = {
    9, 9, // Number of jobs and machines
    6, 67, 8, 80, 2, 23, 5, 92, 3,  4, 1, 73, 4, 61, 0, 95, 7, 86, 
    4, 47, 6, 29, 7, 95, 5, 89, 2, 88, 3, 68, 8, 70, 1, 24, 0, 52, 
    1, 77, 3, 92, 4, 81, 0,  2, 8, 45, 6, 11, 7, 37, 2, 55, 5, 69, 
    2, 21, 3,  6, 7, 61, 5, 36, 8, 31, 1, 53, 0, 17, 4, 59, 6, 75, 
    5, 20, 1, 86, 4, 12, 8, 30, 7, 89, 3,  3, 0, 18, 2, 94, 6, 16, 
    5, 42, 1, 93, 2, 19, 3, 73, 4, 18, 0,  2, 8,  7, 6, 45, 7, 96, 
    0, 68, 8, 98, 2, 46, 3, 33, 4, 96, 5, 75, 7, 32, 6, 25, 1, 21, 
    1, 26, 8, 31, 5, 20, 4,  7, 2, 46, 7, 87, 6, 94, 0, 40, 3,  4, 
    6, 12, 1, 76, 7,  1, 2, 73, 0, 17, 5, 62, 4, 37, 8, 51, 3, 63
  };
  const int q1055[] = {
    9, 9, // Number of jobs and machines
    2, 22, 5, 18, 6, 30, 8, 62, 1,  6, 7, 15, 0, 87, 3, 86, 4, 72, 
    6, 97, 5, 85, 2,  8, 0, 10, 3, 42, 7, 99, 1, 42, 8, 58, 4, 33, 
    5, 14, 6, 64, 2, 61, 0, 41, 1, 58, 4, 27, 8, 42, 3, 18, 7, 18, 
    0, 78, 4,  1, 2, 94, 1, 26, 3, 31, 5, 91, 6, 35, 8, 78, 7, 98, 
    1, 54, 6, 76, 3, 79, 8, 97, 0, 86, 4, 44, 2, 55, 7, 75, 5, 63, 
    6, 84, 4, 53, 5, 84, 8, 66, 0, 61, 2,  6, 3, 96, 7, 49, 1, 96, 
    8, 94, 3, 38, 1, 50, 4, 88, 5, 46, 0, 52, 6,  6, 2, 85, 7, 86, 
    0,  7, 4, 60, 7, 29, 3, 75, 1,  1, 2, 63, 5,  5, 8, 79, 6,  2, 
    0, 63, 4, 46, 1, 51, 7, 27, 3, 14, 2, 13, 8, 63, 6, 62, 5, 38
  };
  const int q1056[] = {
    9, 9, // Number of jobs and machines
    7, 12, 0, 65, 2, 68, 3, 10, 6, 40, 8, 35, 4, 13, 1, 76, 5,  4, 
    3, 35, 4, 80, 6, 85, 0, 21, 5, 86, 2, 56, 1,  7, 8, 25, 7, 92, 
    6, 53, 2, 61, 0, 52, 8, 65, 4, 70, 5, 27, 1, 34, 3, 99, 7, 99, 
    4, 40, 8, 25, 5, 75, 0, 56, 2, 57, 6,  7, 7, 56, 3, 62, 1, 61, 
    2, 46, 8, 61, 4, 42, 5, 61, 1, 84, 3, 22, 7, 82, 6, 53, 0, 55, 
    8, 24, 3, 46, 6, 29, 7, 68, 1, 96, 5,  4, 2, 76, 4, 32, 0, 10, 
    3, 18, 4, 29, 7, 64, 1, 88, 2, 95, 6, 94, 8, 20, 0, 90, 5, 45, 
    4, 62, 1, 53, 3, 37, 0, 71, 8, 51, 2,  6, 7, 43, 5, 16, 6, 35, 
    1, 91, 3, 49, 0, 31, 5, 85, 2, 83, 4, 27, 7, 86, 8, 18, 6,  4
  };
  const int q1057[] = {
    9, 9, // Number of jobs and machines
    5, 95, 8,  7, 7, 56, 3, 94, 6,  5, 2, 84, 0,  7, 1, 55, 4,  4, 
    5, 15, 6, 33, 7, 86, 3, 81, 0, 61, 8, 79, 2, 24, 4, 87, 1, 26, 
    3, 38, 1, 84, 2, 83, 0, 76, 8, 66, 7, 86, 5, 98, 6, 13, 4, 83, 
    6, 30, 4, 24, 3, 94, 7, 49, 0, 52, 2, 47, 1, 25, 8, 27, 5, 47, 
    7, 63, 2, 23, 4, 81, 3, 96, 5, 84, 6, 80, 0, 68, 1, 17, 8, 14, 
    8, 53, 5, 81, 0, 94, 2, 65, 1, 68, 7, 78, 6, 46, 4, 93, 3, 34, 
    6, 14, 1, 22, 5, 15, 3, 51, 2, 26, 4, 81, 0, 40, 8, 67, 7,  5, 
    1, 61, 2, 32, 3, 38, 8, 92, 6, 75, 0,  8, 5, 20, 7,  2, 4, 83, 
    2, 51, 5, 49, 4, 98, 1, 62, 0, 82, 7, 23, 6, 22, 3, 79, 8, 97
  };
  const int q1058[] = {
    9, 9, // Number of jobs and machines
    6, 80, 8, 45, 5, 61, 3, 95, 7, 43, 1, 31, 0, 85, 2, 36, 4, 90, 
    2,  6, 3, 16, 7, 93, 6, 11, 4, 16, 8, 91, 1, 96, 5, 48, 0, 97, 
    4, 45, 8, 59, 7, 60, 3, 64, 0, 18, 1, 74, 2, 39, 6, 75, 5, 21, 
    7, 14, 6,  9, 1, 49, 4, 21, 5, 47, 0, 58, 3, 17, 2, 62, 8, 51, 
    3, 15, 6, 43, 0, 85, 7, 18, 4, 44, 1,  7, 5, 91, 8, 80, 2, 57, 
    7, 29, 0, 88, 1, 17, 6,  3, 2, 96, 5, 67, 4, 41, 8, 58, 3, 51, 
    3, 22, 5, 89, 8,  4, 6, 66, 2, 21, 0, 39, 1, 59, 7, 87, 4,  7, 
    7, 14, 4, 64, 8, 46, 6, 85, 0, 19, 3, 43, 1, 82, 2, 99, 5, 36, 
    3, 63, 8, 31, 6, 47, 5, 30, 0, 77, 7, 97, 4, 86, 1, 85, 2, 47
  };
  const int q1059[] = {
    9, 9, // Number of jobs and machines
    3, 84, 2, 81, 4, 59, 6, 90, 5, 47, 0, 46, 7, 74, 1, 17, 8, 44, 
    7, 51, 2, 12, 4, 39, 6, 74, 1, 52, 3, 54, 5, 93, 8, 40, 0, 33, 
    1, 51, 0, 79, 6, 94, 3, 38, 7, 72, 8, 65, 4, 35, 2, 17, 5, 24, 
    4, 82, 1,  1, 7, 26, 2,  1, 8, 34, 3, 72, 0,  7, 5, 44, 6, 95, 
    2, 83, 1, 80, 4, 44, 5, 18, 7, 92, 3, 33, 0, 84, 6, 72, 8, 14, 
    0, 20, 7, 98, 2, 50, 5, 68, 6, 96, 4, 37, 1, 43, 3,  9, 8, 39, 
    2, 81, 6, 77, 7, 60, 3, 50, 0, 21, 8, 58, 4, 62, 5, 59, 1, 45, 
    8,  4, 0, 51, 7, 54, 4, 91, 1,  1, 5, 24, 3, 48, 2, 54, 6, 92, 
    8, 55, 7, 42, 6, 33, 5, 34, 1,  4, 4, 17, 3, 59, 0, 14, 2, 79
  };
  const int q1060[] = {
    9, 9, // Number of jobs and machines
    4, 55, 0, 97, 6, 80, 1, 81, 8, 20, 5, 91, 2, 76, 7, 58, 3, 13, 
    0, 16, 2, 71, 8, 47, 1, 27, 6, 34, 4, 61, 7, 44, 5, 97, 3, 66, 
    6, 13, 1, 40, 2, 41, 7, 94, 3, 12, 4, 50, 8, 91, 0, 99, 5, 57, 
    8, 59, 7, 75, 5, 39, 1, 67, 3, 46, 4,  5, 2,  7, 6, 19, 0, 48, 
    1,  1, 5, 96, 6, 75, 0, 24, 4, 20, 3, 24, 8, 26, 7,  7, 2, 97, 
    6, 25, 5, 70, 4, 56, 0, 95, 2, 41, 7,  6, 3, 98, 8, 59, 1, 44, 
    0, 36, 6, 56, 1, 42, 3, 78, 2, 81, 7, 93, 5, 23, 8, 32, 4, 35, 
    7, 16, 8, 15, 6, 63, 3, 47, 4, 54, 5, 86, 2, 12, 0, 51, 1, 73, 
    7, 55, 1, 67, 3, 61, 0, 32, 4, 20, 5, 84, 2, 88, 8, 55, 6, 63
  };
  const int q1061[] = {
    9, 9, // Number of jobs and machines
    3, 27, 0, 85, 1, 25, 5, 41, 6, 89, 8,  3, 2, 18, 4, 60, 7, 24, 
    5, 44, 7, 96, 8, 40, 6, 76, 1, 94, 0, 97, 4, 42, 2, 63, 3, 34, 
    1, 98, 2, 36, 7, 37, 3,  7, 6, 33, 0, 43, 5, 43, 4, 39, 8, 56, 
    5, 89, 0,  2, 1, 48, 2, 30, 8, 33, 3, 50, 6, 83, 4,  3, 7, 45, 
    6, 24, 7, 45, 3, 84, 8, 36, 0, 77, 1, 35, 4, 52, 2, 71, 5, 93, 
    7, 63, 5, 75, 6, 41, 4, 82, 8, 11, 2, 90, 3, 24, 0, 12, 1, 72, 
    8, 52, 0, 82, 7, 74, 4, 61, 6, 20, 5, 79, 3, 17, 1, 56, 2, 50, 
    8, 97, 7, 38, 6, 32, 2,  5, 0, 51, 5, 87, 4,  3, 3, 17, 1, 17, 
    7, 82, 6, 74, 5, 45, 2,  2, 3, 74, 4, 14, 1,  5, 0, 86, 8, 67
  };
  const int q1062[] = {
    9, 9, // Number of jobs and machines
    1, 46, 7, 56, 6, 68, 0, 61, 4, 41, 2, 62, 8, 42, 5, 37, 3, 76, 
    4, 16, 1,  7, 6, 87, 8, 46, 3, 24, 7, 20, 2, 38, 5, 70, 0, 56, 
    3, 30, 1, 12, 4, 76, 7, 59, 5,  1, 8,  6, 6, 48, 0, 95, 2, 83, 
    2, 93, 8, 59, 6, 40, 7,  1, 0, 68, 5,  4, 1, 37, 3, 81, 4, 70, 
    0, 62, 2, 96, 3, 96, 8, 63, 4, 70, 1,  4, 5, 50, 7, 90, 6, 97, 
    5, 84, 4, 79, 1, 10, 2, 14, 3, 24, 0, 30, 6, 43, 8,  2, 7, 23, 
    5, 45, 7, 71, 6, 45, 0, 62, 1, 67, 2, 13, 3, 89, 4, 96, 8, 19, 
    4, 54, 5, 84, 1, 18, 8, 80, 7, 73, 6, 32, 2,  1, 3, 15, 0, 50, 
    3,  5, 6, 33, 5, 90, 7, 53, 4, 68, 8, 93, 1, 78, 2, 38, 0,  5
  };
  const int q1063[] = {
    9, 9, // Number of jobs and machines
    2, 11, 7, 46, 6, 40, 1, 12, 5, 27, 4, 34, 8, 32, 0, 76, 3, 78, 
    7,  3, 8, 46, 6, 16, 3, 58, 1,  5, 0, 18, 5, 92, 4,  9, 2, 85, 
    8,  7, 5, 36, 6, 77, 0, 83, 3, 84, 1, 51, 4,  9, 7, 92, 2, 41, 
    6, 72, 1, 35, 0, 35, 8, 89, 2, 90, 4, 89, 5, 37, 3, 82, 7, 28, 
    0, 38, 1, 11, 6, 25, 8, 75, 2, 39, 4, 14, 5, 74, 3, 79, 7, 42, 
    7, 46, 8,  2, 1, 15, 5, 69, 2, 61, 3,  7, 6, 88, 0, 18, 4, 25, 
    6, 33, 2, 31, 0, 71, 3, 15, 7, 59, 4, 37, 5, 31, 1, 11, 8, 89, 
    5,  8, 2, 27, 3, 99, 0, 30, 1, 51, 4, 85, 7, 70, 6, 58, 8, 13, 
    4, 21, 7, 46, 3, 64, 8, 82, 0, 48, 1, 84, 2, 44, 6, 40, 5, 61
  };
  const int q1064[] = {
    9, 9, // Number of jobs and machines
    5, 75, 1, 26, 3, 57, 8, 35, 0, 20, 4, 70, 6, 86, 7,  2, 2, 37, 
    1, 60, 8, 12, 7,  8, 2, 25, 0, 21, 5, 76, 3, 78, 4, 66, 6,  2, 
    7, 10, 1, 78, 3, 59, 4, 46, 0, 48, 5, 92, 6, 45, 8,  9, 2, 55, 
    3,  9, 2, 61, 6, 42, 1, 51, 5,  1, 0, 15, 8,  9, 7, 56, 4, 73, 
    1, 11, 8, 39, 6, 94, 3, 50, 0, 25, 2, 20, 5, 92, 7, 14, 4, 98, 
    6,  5, 0, 33, 4, 98, 2, 25, 3,  7, 5, 93, 8, 92, 1, 42, 7,  4, 
    7, 66, 0, 53, 5, 70, 1, 87, 2, 18, 4, 76, 6,  4, 8, 32, 3, 41, 
    4, 64, 5, 66, 8, 90, 3, 57, 0, 65, 6, 10, 2, 63, 7, 39, 1, 26, 
    4, 80, 2,  1, 5, 83, 7, 42, 8, 65, 6, 33, 1, 97, 3, 19, 0, 15
  };
  const int q1065[] = {
    9, 9, // Number of jobs and machines
    7, 40, 3, 26, 2, 77, 6, 36, 5, 15, 4,  6, 1, 71, 8, 41, 0, 42, 
    0,  5, 4, 74, 1, 27, 3, 16, 2,  5, 7, 15, 8, 70, 6, 80, 5, 91, 
    0,  5, 1, 16, 6, 70, 3, 39, 8, 50, 4,  9, 5,  7, 2,  5, 7,  5, 
    4, 40, 8, 15, 2, 19, 0, 79, 7, 21, 5, 89, 1, 89, 6, 35, 3,  2, 
    8, 11, 5, 42, 7, 33, 4, 21, 3, 84, 1, 53, 6, 91, 2, 76, 0, 86, 
    0, 45, 3, 33, 8, 75, 5, 46, 2,  7, 6, 69, 4, 68, 1, 18, 7, 12, 
    6, 19, 2, 22, 1,  3, 7, 91, 8, 41, 3, 40, 5,  7, 4, 43, 0, 17, 
    2, 53, 5, 14, 7, 76, 4, 76, 1,  1, 3, 72, 8, 74, 6, 66, 0, 39, 
    3, 56, 8, 46, 0, 52, 2, 89, 5,  8, 6, 13, 1, 34, 4, 68, 7,  5
  };
  const int q1066[] = {
    9, 9, // Number of jobs and machines
    3, 37, 2, 11, 1, 24, 0, 55, 5, 72, 8, 62, 4, 93, 7, 87, 6, 37, 
    2,  7, 8, 95, 1, 20, 6, 25, 0, 67, 7, 98, 3, 16, 5, 93, 4, 84, 
    8, 15, 4, 77, 5, 61, 6, 55, 0, 81, 7, 47, 3, 56, 2, 79, 1, 36, 
    2, 75, 4, 53, 8, 56, 3, 47, 0, 62, 1,  7, 6, 56, 7, 94, 5, 32, 
    3, 87, 6, 29, 1, 51, 5,  8, 8, 45, 4, 50, 2, 31, 7, 72, 0, 10, 
    0, 20, 2, 91, 3, 60, 1, 12, 8, 84, 5, 98, 7, 48, 4,  2, 6, 22, 
    6, 89, 5, 53, 7, 83, 0, 19, 3, 29, 8, 80, 4, 76, 2, 63, 1, 11, 
    6, 13, 3, 67, 8,  6, 5,  2, 0, 35, 2, 16, 4, 30, 1, 42, 7,  4, 
    0, 32, 5, 86, 4, 22, 6, 34, 3, 77, 7, 58, 2, 23, 1, 39, 8, 15
  };
  const int q1067[] = {
    9, 9, // Number of jobs and machines
    5,  4, 7, 42, 2, 30, 8, 28, 4, 42, 0, 75, 1, 67, 3, 51, 6, 62, 
    6, 20, 8, 54, 7, 54, 5, 14, 2, 85, 3, 67, 4, 58, 0,  2, 1, 86, 
    0, 45, 7, 85, 4, 42, 6, 80, 2, 72, 5, 95, 1, 13, 3, 32, 8,  6, 
    2, 60, 4, 96, 0, 16, 1, 71, 6, 52, 8, 39, 3, 65, 7, 76, 5, 71, 
    3,  5, 1, 23, 2, 32, 7, 10, 8, 93, 5,  3, 6, 98, 4, 91, 0, 29, 
    0, 62, 1,  7, 6, 68, 2, 90, 4, 63, 8, 58, 3, 62, 5,  2, 7, 81, 
    0, 97, 4, 29, 2, 64, 6, 89, 8, 69, 7, 36, 5, 34, 3, 75, 1, 28, 
    3, 57, 0, 46, 8, 54, 6, 85, 5, 21, 1, 91, 7, 83, 4, 76, 2, 31, 
    8, 13, 3, 52, 6, 52, 5, 83, 7, 38, 4, 16, 0, 88, 1,  5, 2, 58
  };
  const int q1068[] = {
    9, 9, // Number of jobs and machines
    8, 84, 0, 93, 7, 91, 4, 85, 3, 52, 2,  2, 6, 77, 1, 32, 5, 15, 
    1, 75, 7, 45, 0, 87, 5, 67, 8,  2, 3,  6, 6,  1, 4, 36, 2, 24, 
    5, 24, 0, 14, 1, 33, 8, 14, 4, 81, 2, 21, 6, 68, 3, 98, 7, 62, 
    4,  9, 5, 43, 8,  2, 7, 25, 0, 21, 3, 51, 6, 62, 2, 18, 1, 85, 
    1, 91, 2, 64, 0, 39, 8,  2, 7, 24, 3, 78, 4, 32, 6, 75, 5, 76, 
    4, 13, 0, 56, 3, 68, 5, 56, 6, 21, 1, 97, 8, 37, 2, 57, 7, 99, 
    3,  5, 1, 64, 2, 19, 5, 26, 7, 17, 6,  3, 4, 47, 0, 44, 8, 66, 
    7,  6, 3, 47, 8, 63, 6, 52, 5, 82, 1, 56, 2, 90, 0, 36, 4, 67, 
    1, 19, 0, 45, 5, 15, 2, 73, 7, 66, 6, 91, 3, 36, 4, 11, 8, 80
  };
  const int q1069[] = {
    9, 9, // Number of jobs and machines
    8, 44, 0, 50, 3, 45, 7, 56, 2,  3, 1, 21, 5,  6, 4, 82, 6, 97, 
    0, 44, 1,  1, 5, 69, 3, 90, 7, 38, 8, 31, 4, 73, 2, 87, 6, 68, 
    8, 27, 3, 15, 1, 37, 6,  2, 7, 81, 4, 49, 5, 50, 2, 13, 0, 72, 
    1, 54, 3,  4, 0,  9, 6, 43, 8, 26, 5, 44, 4, 82, 7, 22, 2, 51, 
    5, 89, 2, 67, 3,  4, 7, 99, 8, 81, 0, 50, 1, 82, 6, 12, 4, 21, 
    5, 10, 6, 83, 0, 68, 3, 25, 4,  8, 1,  1, 2, 78, 8, 78, 7, 25, 
    0, 58, 7, 50, 6,  1, 4,  3, 8, 74, 3, 83, 1, 98, 5, 38, 2, 55, 
    6,  7, 2, 37, 5, 51, 4, 54, 8, 38, 0, 51, 7, 34, 3, 97, 1, 68, 
    0, 44, 3, 63, 7, 35, 6, 19, 4, 67, 5, 35, 2, 13, 1, 21, 8, 65
  };
  const int q1070[] = {
    9, 9, // Number of jobs and machines
    4, 11, 8,  6, 7, 23, 6,  7, 3, 34, 2, 56, 5, 79, 1, 92, 0,  3, 
    0, 70, 7, 14, 2, 62, 3, 97, 8, 17, 1, 93, 5, 59, 6, 66, 4, 96, 
    5, 29, 3, 62, 8, 23, 1, 16, 2, 71, 0, 74, 6, 63, 4, 15, 7, 23, 
    4, 46, 1, 41, 6, 88, 5, 47, 8, 26, 0, 94, 3, 99, 2, 81, 7, 51, 
    0, 68, 3, 94, 5, 15, 6, 11, 7, 46, 1, 17, 8, 56, 2, 15, 4, 72, 
    8, 15, 3, 77, 1, 99, 6, 31, 0, 54, 5, 28, 2, 88, 4, 54, 7, 73, 
    6, 55, 8, 27, 3, 63, 2, 65, 5, 60, 1, 26, 0, 79, 4, 92, 7, 18, 
    7, 40, 4, 58, 8, 18, 2, 26, 1, 48, 5, 97, 0, 48, 3, 87, 6,  9, 
    1, 13, 4, 93, 6, 64, 3, 89, 0, 36, 2, 52, 8, 44, 7,  5, 5, 74
  };
  const int q1071[] = {
    9, 9, // Number of jobs and machines
    5, 13, 4, 85, 0, 10, 6, 96, 3, 12, 7, 34, 2, 82, 1, 80, 8, 16, 
    4, 81, 5, 63, 3, 27, 0, 92, 1,  8, 7, 86, 2, 24, 6, 44, 8, 61, 
    1, 92, 3, 48, 7, 14, 4, 27, 0, 28, 8, 75, 6, 11, 5, 36, 2, 53, 
    2, 90, 5, 15, 4, 26, 6, 39, 1, 75, 8,  1, 3, 78, 0,  6, 7,  3, 
    5, 74, 2, 55, 1, 87, 0, 98, 4, 59, 3, 48, 8, 59, 6, 78, 7, 76, 
    4, 21, 6, 49, 7, 58, 5, 29, 2, 44, 0, 90, 8, 15, 1, 50, 3, 72, 
    1, 65, 3, 79, 5, 87, 7, 71, 8, 49, 0, 97, 6, 66, 2, 21, 4, 21, 
    0, 87, 8, 48, 5, 89, 7, 23, 6, 16, 2,  1, 3, 49, 4, 70, 1,  5, 
    0, 55, 1,  1, 2, 18, 4, 55, 7, 28, 3, 88, 6, 28, 8, 80, 5, 26
  };
  const int q1072[] = {
    9, 9, // Number of jobs and machines
    3,  5, 5, 90, 0,  4, 6, 36, 2, 97, 7, 11, 4, 68, 1, 82, 8,  3, 
    8, 86, 6, 45, 0, 51, 4, 22, 5, 14, 7, 13, 3, 24, 2, 67, 1, 46, 
    4, 60, 0, 56, 6, 39, 8, 61, 1, 79, 5, 21, 7, 82, 3, 59, 2, 55, 
    2, 56, 6, 92, 8, 21, 4, 42, 3, 22, 5, 49, 0, 37, 7,  1, 1, 55, 
    7, 90, 2, 86, 6, 53, 3, 31, 0, 45, 4, 17, 1, 65, 5,  4, 8, 75, 
    2, 39, 4, 95, 1,  8, 3, 51, 7, 90, 8, 21, 6, 48, 0, 13, 5, 56, 
    0,  9, 7, 64, 8, 53, 2, 98, 6, 73, 4, 91, 5, 99, 1, 36, 3, 21, 
    5, 62, 1, 15, 4, 13, 8, 79, 0, 32, 6, 86, 7, 43, 3, 20, 2, 34, 
    5, 33, 6, 43, 3, 54, 4, 51, 1, 39, 8, 93, 7, 63, 2, 94, 0, 13
  };
  const int q1073[] = {
    9, 9, // Number of jobs and machines
    3, 45, 2,  4, 5, 70, 1, 14, 7, 57, 4, 92, 8, 17, 6,  5, 0, 81, 
    2,  2, 0, 12, 4, 96, 8, 14, 1, 65, 7,  7, 3, 99, 5, 61, 6, 40, 
    8, 92, 0,  3, 2, 70, 1, 49, 3, 65, 4, 65, 6,  3, 5, 71, 7,  8, 
    0, 45, 8,  9, 6, 32, 2, 41, 4, 59, 1, 68, 5, 81, 7, 11, 3, 69, 
    7, 25, 0, 79, 5, 20, 2, 71, 3, 19, 4,  7, 8, 92, 6, 34, 1, 53, 
    1, 60, 5,  2, 4, 18, 0, 69, 6,  8, 7, 33, 2, 20, 8, 23, 3, 35, 
    5, 40, 2, 83, 0, 92, 4, 76, 1, 95, 3, 62, 8, 84, 7, 86, 6, 46, 
    0, 97, 8, 17, 7, 76, 1, 45, 5,  4, 3, 69, 2, 28, 6, 21, 4, 51, 
    1, 52, 2,  5, 5, 37, 7, 13, 8, 55, 3, 45, 4, 71, 0, 28, 6, 85
  };
  const int q1074[] = {
    9, 9, // Number of jobs and machines
    0, 28, 2, 72, 1, 54, 7, 69, 3, 90, 8, 44, 6, 98, 5, 76, 4, 91, 
    3, 73, 8, 87, 4, 84, 5, 84, 6, 56, 7,  1, 0, 73, 2, 64, 1, 17, 
    4, 20, 6, 30, 8, 46, 3, 56, 5, 28, 7, 30, 1, 19, 0, 16, 2, 24, 
    5, 51, 3, 20, 0, 99, 1, 21, 2, 12, 7, 71, 8, 28, 4, 40, 6,  7, 
    8, 46, 5, 92, 0, 20, 7, 17, 3, 45, 4, 30, 2,  2, 6, 54, 1, 44, 
    0, 44, 3, 39, 1, 61, 2, 10, 6, 34, 7,  5, 8, 81, 5, 12, 4, 34, 
    4, 48, 2, 84, 6, 37, 3, 22, 5, 76, 8, 32, 7, 86, 1, 71, 0, 79, 
    7, 21, 1, 16, 5, 16, 4,  1, 3, 95, 2, 11, 8,  5, 6,  5, 0,  9, 
    3, 76, 5, 81, 8, 31, 4, 14, 7, 76, 1, 64, 2, 87, 6, 81, 0, 28
  };
  const int q1075[] = {
    9, 9, // Number of jobs and machines
    8, 69, 3, 40, 5, 39, 6, 39, 4, 40, 1, 50, 7, 45, 0, 44, 2, 19, 
    6, 25, 4, 22, 5, 40, 2, 32, 1, 61, 0, 54, 3, 43, 8, 86, 7, 22, 
    6, 53, 1, 69, 7, 40, 0, 90, 4, 41, 8, 51, 2, 75, 5,  7, 3, 45, 
    0, 32, 3, 59, 2,  5, 1, 13, 6, 83, 5, 98, 7, 56, 4, 92, 8, 11, 
    2, 10, 8, 38, 7, 38, 0, 48, 6,  9, 3, 10, 4, 73, 1, 71, 5, 47, 
    3, 56, 0, 98, 1,  9, 4, 98, 6, 53, 2, 21, 8, 24, 7, 38, 5, 65, 
    1, 45, 3, 29, 4, 33, 2, 20, 6, 85, 7, 24, 5, 93, 0, 26, 8, 60, 
    5, 32, 8, 64, 4, 44, 7, 74, 1, 60, 6, 46, 3, 78, 2, 56, 0, 37, 
    1, 78, 2, 89, 0,  3, 8, 56, 3, 23, 7, 99, 6, 64, 5, 97, 4, 50
  };
  const int q1076[] = {
    9, 9, // Number of jobs and machines
    7, 29, 8, 58, 3,  2, 1,  4, 0, 92, 6, 92, 4, 27, 5, 41, 2, 29, 
    8,  7, 7, 44, 1, 25, 2, 51, 4, 60, 6, 10, 5,  7, 3, 41, 0, 80, 
    2, 44, 4,  3, 0, 88, 6, 70, 1, 40, 5, 86, 8, 89, 7, 24, 3, 51, 
    0, 33, 8, 50, 6, 12, 3, 17, 7, 92, 4, 63, 2, 94, 5, 77, 1,  2, 
    7, 15, 6, 87, 5, 25, 4, 93, 1, 97, 2, 73, 8, 99, 3, 21, 0, 45, 
    1, 90, 7, 99, 2, 37, 8, 93, 6, 91, 0, 57, 5, 69, 4, 48, 3, 28, 
    7, 89, 8, 31, 3, 55, 2, 32, 5, 54, 0, 56, 4, 40, 6,  6, 1, 27, 
    8, 62, 4, 19, 0, 86, 5, 90, 6, 56, 7, 91, 2, 39, 1, 41, 3,  8, 
    7, 80, 3, 92, 0, 97, 2, 13, 6, 10, 8, 72, 1, 90, 4, 22, 5, 78
  };
  const int q1077[] = {
    9, 9, // Number of jobs and machines
    3, 13, 1,  9, 4, 91, 6, 43, 0, 35, 8, 27, 5, 15, 2, 66, 7, 52, 
    1, 63, 7, 22, 2, 87, 0, 59, 4, 54, 8,  6, 3, 44, 5, 90, 6, 82, 
    2, 80, 3, 33, 0, 97, 1, 65, 7,  6, 8, 31, 5, 84, 6, 52, 4, 46, 
    1, 64, 2,  7, 3, 76, 0, 31, 4, 52, 7, 70, 5, 52, 6, 49, 8, 73, 
    1, 33, 2, 94, 5, 32, 0, 71, 6, 85, 4, 71, 3,  9, 8, 10, 7, 85, 
    4,  7, 0, 44, 7, 32, 8, 28, 5, 62, 2, 28, 1, 60, 6, 18, 3,  9, 
    2, 99, 8, 92, 4, 14, 6, 30, 1, 76, 5, 85, 3, 65, 7, 68, 0, 81, 
    2, 72, 5, 44, 4, 35, 7,  7, 3, 47, 0, 60, 1, 79, 8, 40, 6, 56, 
    3, 42, 0, 17, 4, 80, 6, 69, 1,  3, 8, 41, 7, 20, 5, 64, 2,  5
  };
  const int q1078[] = {
    9, 9, // Number of jobs and machines
    5,  2, 0, 41, 6,  3, 2, 24, 7, 78, 3, 91, 4, 83, 8, 46, 1, 18, 
    7, 67, 0, 82, 2, 61, 5, 19, 1, 29, 8, 34, 4, 10, 6, 55, 3, 75, 
    5, 56, 6, 54, 3, 72, 8,  8, 7, 11, 0, 28, 4, 25, 1, 85, 2, 70, 
    7, 26, 5, 79, 0, 55, 8, 86, 4, 76, 3, 63, 2, 17, 6, 21, 1,  6, 
    8, 24, 3, 11, 6, 83, 1, 87, 7, 54, 5, 70, 0, 42, 2, 56, 4, 12, 
    2, 22, 6,  6, 1, 48, 4, 80, 7, 51, 0, 16, 8, 92, 3, 77, 5,  9, 
    2, 92, 3, 24, 5, 23, 8, 67, 1, 12, 6, 15, 0, 71, 7, 17, 4, 31, 
    8, 17, 1, 58, 6, 52, 4, 39, 7, 33, 3, 31, 5, 81, 2, 29, 0, 86, 
    0, 91, 2, 21, 4, 78, 8, 23, 5, 95, 1, 12, 6, 43, 7, 17, 3,  8
  };
  const int q1079[] = {
    9, 9, // Number of jobs and machines
    2, 15, 6, 27, 5, 65, 3, 31, 4, 24, 0, 38, 8, 40, 7, 78, 1, 16, 
    5, 94, 8, 28, 0, 94, 6, 12, 4, 37, 7,  6, 1, 11, 3,  7, 2, 40, 
    5, 36, 7, 48, 1, 40, 0, 33, 3,  3, 8,  6, 6, 80, 2, 61, 4,  6, 
    5, 68, 0, 16, 7, 72, 3, 29, 6, 28, 2, 13, 8, 70, 1, 40, 4, 37, 
    5, 40, 4, 98, 2, 30, 8, 87, 1, 72, 6, 18, 3, 90, 7, 22, 0, 55, 
    6, 22, 5, 72, 4, 17, 7, 63, 8, 19, 0, 66, 3, 42, 1, 56, 2, 21, 
    6, 22, 2,  7, 5, 88, 3, 97, 4, 59, 8, 30, 1, 33, 7, 10, 0, 91, 
    2, 95, 0,  1, 1, 45, 6, 78, 7, 96, 3, 59, 5, 36, 8, 41, 4, 15, 
    0, 20, 6, 21, 4, 57, 8, 97, 5, 12, 7,  9, 2, 61, 3, 62, 1, 83
  };
  const int q1080[] = {
    9, 9, // Number of jobs and machines
    1, 21, 3, 17, 6, 45, 0, 87, 8, 16, 5,  6, 7,  3, 4, 17, 2, 95, 
    6, 40, 1, 99, 8, 34, 7, 50, 4, 35, 0, 26, 5, 47, 3, 51, 2, 84, 
    7, 77, 8,  3, 0, 92, 5, 96, 3, 56, 2, 64, 1, 43, 6, 44, 4, 80, 
    0, 67, 2, 64, 5, 11, 1, 14, 3, 53, 6, 61, 8, 36, 7, 65, 4, 73, 
    7, 54, 3, 19, 6, 46, 8, 59, 1, 41, 2, 93, 5, 54, 0, 18, 4,  4, 
    4, 56, 6, 23, 7, 79, 0, 55, 1, 64, 8, 14, 3, 29, 2, 91, 5,  2, 
    5, 76, 3, 15, 2, 40, 7, 41, 0, 58, 1, 66, 4, 56, 8, 39, 6, 10, 
    6, 42, 4, 75, 0, 92, 7, 66, 2, 98, 1, 76, 5, 43, 8, 48, 3, 59, 
    4, 63, 7, 87, 8, 54, 6, 41, 3, 18, 1, 90, 2, 73, 5, 14, 0, 84
  };
  const int q1081[] = {
    9, 9, // Number of jobs and machines
    5, 56, 2, 35, 8, 36, 6, 43, 4, 32, 3, 67, 7, 94, 1, 33, 0, 74, 
    8, 55, 0, 68, 3, 58, 2, 19, 4, 57, 5, 35, 6, 54, 7, 64, 1, 78, 
    8, 49, 3, 67, 7, 47, 1, 48, 5, 49, 4, 87, 6, 10, 2, 81, 0, 33, 
    2, 39, 5, 17, 7, 45, 4, 75, 8,  8, 3, 82, 1, 41, 6, 69, 0, 78, 
    0, 80, 6, 93, 7,  7, 8, 94, 4, 77, 1, 33, 5, 78, 3, 37, 2, 82, 
    6, 93, 5, 82, 8, 74, 3, 91, 7, 38, 4, 19, 1, 13, 0, 97, 2, 16, 
    1, 51, 7, 19, 6, 33, 8, 77, 2, 21, 4, 88, 5, 93, 3, 28, 0, 10, 
    5, 29, 3, 27, 4, 17, 8, 46, 6, 63, 7, 93, 2, 33, 0, 13, 1, 45, 
    0, 68, 5,  3, 7, 84, 3, 23, 8, 24, 4, 34, 2, 71, 1,  2, 6, 36
  };
  const int q1082[] = {
    9, 9, // Number of jobs and machines
    4, 62, 1, 11, 7, 88, 6, 76, 8, 62, 3, 81, 5, 35, 2,  3, 0,  1, 
    3, 15, 8, 10, 4, 66, 6, 77, 7, 65, 0, 40, 2, 50, 1, 63, 5, 69, 
    5,  5, 0, 88, 8, 75, 3, 86, 7, 86, 6, 54, 2, 29, 4, 30, 1, 78, 
    4, 72, 6, 98, 0, 15, 5, 50, 8, 78, 2, 45, 7, 20, 1, 31, 3, 50, 
    8,  4, 3, 43, 1, 76, 4, 99, 6,  5, 7, 23, 5, 44, 0, 93, 2, 79, 
    2, 13, 3, 20, 4, 21, 0, 63, 5, 93, 8, 39, 7, 29, 6, 52, 1, 54, 
    3, 84, 8, 54, 1, 99, 6, 38, 2, 49, 0, 44, 5, 81, 4, 67, 7, 13, 
    6, 60, 2, 81, 8, 83, 1, 14, 5, 39, 7, 76, 0, 10, 4, 68, 3, 23, 
    2,  3, 0, 31, 7, 21, 4, 62, 8, 17, 6, 92, 1, 94, 3, 71, 5,  3
  };
  const int q1083[] = {
    9, 9, // Number of jobs and machines
    3, 63, 6, 87, 1, 32, 5, 91, 8, 41, 2, 66, 0, 39, 7, 99, 4, 67, 
    6, 77, 4, 73, 7, 49, 5, 19, 0, 83, 2, 89, 8, 91, 1, 31, 3,  2, 
    0, 23, 6, 37, 2, 88, 3, 70, 8, 40, 5,  5, 1, 99, 4,  5, 7, 80, 
    2, 62, 7, 97, 3,  1, 1, 60, 6, 72, 5, 94, 8, 60, 4, 26, 0, 89, 
    8, 31, 5, 31, 1, 20, 4, 66, 3, 13, 6, 36, 2, 46, 0, 87, 7, 17, 
    4, 13, 5, 56, 0, 35, 7, 97, 6, 11, 8, 61, 3,  2, 2, 91, 1, 93, 
    2, 38, 0,  2, 7, 25, 8,  9, 3, 41, 1, 75, 5, 90, 6, 35, 4, 96, 
    2,  4, 6, 46, 7, 47, 5, 87, 1, 82, 8, 15, 0, 42, 3, 75, 4, 10, 
    4, 59, 8,  8, 1,  3, 3, 59, 5, 75, 7, 16, 2, 31, 6, 28, 0, 12
  };
  const int q1084[] = {
    9, 9, // Number of jobs and machines
    2, 17, 0, 68, 1, 53, 4, 94, 3, 43, 7, 51, 8, 39, 5, 72, 6, 88, 
    7, 83, 4, 46, 2, 96, 1, 87, 6, 52, 3, 35, 8, 95, 0, 75, 5,  9, 
    0, 83, 8, 62, 6, 36, 5, 90, 4, 54, 2, 65, 7, 27, 3, 26, 1, 34, 
    6, 44, 2, 98, 3, 43, 7, 27, 5, 75, 1,  5, 0,  4, 8, 65, 4, 16, 
    3, 79, 4, 46, 2, 10, 6, 25, 8, 38, 0, 32, 7, 31, 1, 44, 5, 39, 
    7, 11, 8, 12, 0, 52, 1, 74, 4, 37, 2, 72, 6, 99, 3, 10, 5, 24, 
    0, 65, 1,  9, 5, 38, 6, 32, 8, 13, 7,  8, 2, 90, 4, 50, 3, 71, 
    3, 80, 2, 12, 6, 20, 0, 73, 1, 87, 8, 50, 7, 18, 4, 32, 5, 75, 
    6, 58, 7, 57, 8, 82, 4, 47, 3, 88, 5, 15, 2, 45, 1, 76, 0, 93
  };
  const int q1085[] = {
    9, 9, // Number of jobs and machines
    6, 83, 2, 88, 5, 69, 0, 33, 1, 13, 8,  4, 4, 35, 7,  3, 3, 41, 
    0, 85, 8, 36, 6, 91, 2, 66, 5, 20, 4, 92, 7, 11, 3, 30, 1, 55, 
    7, 50, 3, 44, 6, 91, 8, 56, 5, 51, 0, 86, 2, 31, 4, 15, 1, 92, 
    3, 98, 2, 59, 1, 17, 8, 27, 0, 84, 5, 78, 6, 12, 7, 93, 4, 82, 
    0, 52, 1, 54, 8, 10, 3, 88, 4, 77, 2, 82, 6, 12, 7, 30, 5, 32, 
    3, 65, 5, 13, 1, 73, 0, 39, 8, 90, 2,  5, 6, 16, 4, 25, 7, 26, 
    6, 28, 2, 94, 7, 77, 0, 70, 3,  8, 8, 65, 5, 93, 1, 74, 4,  3, 
    0, 63, 4, 61, 5, 40, 7, 19, 1, 76, 2, 99, 6, 73, 3, 25, 8, 67, 
    1, 25, 5, 20, 7, 47, 2, 48, 0, 20, 6, 61, 4, 83, 8, 78, 3, 93
  };
  const int q1086[] = {
    9, 9, // Number of jobs and machines
    0, 18, 5, 64, 7, 67, 3, 87, 6, 49, 8, 61, 2, 48, 1, 38, 4, 55, 
    2, 99, 5, 21, 8, 28, 7, 84, 1, 20, 3, 86, 4, 83, 6, 79, 0, 90, 
    8, 41, 1, 27, 2, 94, 5, 30, 4, 34, 7, 74, 6, 74, 0, 89, 3, 58, 
    5, 13, 3,  1, 6, 34, 0, 94, 8, 96, 7, 64, 2, 52, 4,  2, 1, 76, 
    4, 60, 7,  4, 2, 95, 3, 18, 6, 60, 0, 31, 8, 42, 1, 70, 5, 96, 
    6, 21, 3, 17, 4, 59, 8,  6, 5, 54, 2, 36, 1, 34, 7, 71, 0, 94, 
    3, 79, 1,  8, 6, 59, 0, 42, 4, 49, 2, 65, 5, 98, 8, 31, 7, 28, 
    7, 36, 0, 68, 1, 28, 3, 77, 2, 22, 8, 38, 5, 98, 6,  5, 4, 10, 
    6, 54, 7, 51, 4, 90, 1, 50, 5, 32, 0, 28, 3, 11, 8, 70, 2, 64
  };
  const int q1087[] = {
    9, 9, // Number of jobs and machines
    6, 47, 0, 47, 8, 19, 5, 88, 2, 12, 4, 86, 1, 17, 3, 33, 7, 82, 
    7, 10, 8, 74, 3, 79, 5, 92, 4, 37, 6, 51, 0, 43, 1, 95, 2, 63, 
    2, 12, 8,  4, 1, 48, 5, 11, 4, 38, 3, 13, 0, 90, 6, 18, 7,  1, 
    2, 26, 4, 58, 3, 69, 6, 50, 7, 66, 8, 93, 5, 41, 0, 49, 1, 51, 
    5, 76, 0, 46, 3, 96, 8, 57, 1, 92, 2,  3, 7, 65, 6, 21, 4, 24, 
    5, 91, 2, 89, 3, 11, 0, 51, 1, 69, 7, 88, 6, 22, 4, 59, 8, 23, 
    4, 32, 6, 27, 8, 13, 0, 65, 5, 29, 7, 51, 1, 57, 3, 32, 2,  7, 
    3, 77, 2, 27, 6, 82, 8, 47, 0, 55, 1, 52, 5, 53, 4, 96, 7, 60, 
    6, 20, 0,  6, 1, 91, 5, 71, 7, 16, 3, 84, 4, 41, 2, 19, 8, 17
  };
  const int q1088[] = {
    9, 9, // Number of jobs and machines
    0, 70, 2, 88, 4,  1, 1, 88, 3, 28, 5, 42, 8, 31, 6, 75, 7, 53, 
    7, 35, 0, 92, 3, 85, 2, 30, 4, 26, 5, 42, 1, 71, 6,  1, 8, 41, 
    2, 55, 8, 55, 3,  5, 7, 53, 6, 97, 1, 57, 0, 66, 4, 70, 5, 48, 
    8, 50, 5, 57, 3, 86, 0, 13, 7, 63, 1, 55, 4, 34, 6, 34, 2, 65, 
    5, 64, 7, 93, 6, 98, 8, 43, 1, 90, 0, 39, 2, 72, 3, 28, 4, 82, 
    3,  3, 6, 16, 0, 31, 2, 14, 4, 75, 8,  7, 7, 68, 5, 83, 1, 25, 
    1, 96, 3, 77, 6, 20, 7, 70, 5,  6, 4,  9, 0, 14, 8, 33, 2,  6, 
    0, 55, 5, 79, 4, 47, 2, 54, 8, 77, 1, 71, 3, 20, 7, 97, 6, 38, 
    1, 31, 6, 21, 2, 79, 8, 58, 7, 36, 3, 83, 0, 80, 4, 87, 5, 69
  };
  const int q1089[] = {
    9, 9, // Number of jobs and machines
    1, 62, 8, 94, 5, 52, 0, 15, 2,  2, 4, 46, 7, 89, 6,  5, 3, 29, 
    2, 74, 0,  1, 1, 13, 7, 46, 4, 87, 5, 39, 6, 84, 8, 79, 3, 33, 
    2, 54, 4, 56, 1, 84, 5,  1, 7, 55, 3, 56, 8, 23, 0, 71, 6, 56, 
    4,  1, 1, 33, 8, 85, 6, 62, 0, 69, 2, 60, 3,  6, 5, 22, 7, 82, 
    6, 41, 5, 85, 7, 55, 1, 17, 3, 82, 0,  9, 8, 91, 4, 66, 2, 17, 
    7, 63, 0, 52, 6, 12, 2, 53, 3,  9, 4, 85, 5, 55, 8, 40, 1, 31, 
    5, 42, 4, 78, 2,  3, 7, 88, 3, 55, 1, 94, 0, 90, 6, 96, 8, 51, 
    7, 41, 1, 28, 4, 28, 2, 49, 5, 91, 3, 83, 0, 91, 8, 28, 6,  2, 
    4, 50, 7, 65, 1,  4, 2, 17, 5, 60, 0, 78, 8,  2, 6, 97, 3, 65
  };
  const int q1090[] = {
    9, 9, // Number of jobs and machines
    5, 40, 2, 56, 6,  4, 8, 83, 0,  7, 7, 65, 4, 35, 1, 78, 3, 29, 
    5, 15, 7, 41, 2, 94, 0, 54, 4, 61, 6,  8, 3, 64, 8, 50, 1, 32, 
    1, 26, 3, 49, 7, 89, 6, 28, 5, 94, 4, 28, 8, 42, 2, 62, 0,  6, 
    0, 47, 8, 28, 1, 88, 5, 82, 4, 56, 6, 15, 7, 97, 2, 40, 3, 27, 
    6, 33, 8, 98, 7, 78, 1, 23, 4, 71, 5,  2, 3, 51, 0, 65, 2,  6, 
    3, 32, 8, 26, 7, 92, 2, 32, 4, 46, 6, 20, 0, 86, 1,  6, 5, 88, 
    6, 89, 7, 64, 8, 84, 5, 70, 2, 65, 1, 59, 0, 67, 4, 82, 3,  1, 
    5, 49, 7, 45, 6, 59, 0, 75, 1,  2, 8, 96, 3, 29, 4, 45, 2, 21, 
    0, 47, 6, 90, 5, 46, 3, 23, 7, 18, 4, 14, 2, 70, 1, 33, 8, 92
  };
  const int q1091[] = {
    9, 9, // Number of jobs and machines
    0, 45, 5, 63, 7, 23, 1,  1, 2, 77, 8, 62, 6, 73, 4, 16, 3, 99, 
    5, 45, 4, 44, 7, 25, 0, 33, 6, 27, 3, 98, 2, 12, 8, 61, 1, 58, 
    6, 98, 2, 69, 5,  8, 3, 15, 1, 31, 8, 77, 7, 80, 4, 20, 0, 79, 
    6, 61, 5, 91, 7, 30, 3, 44, 1,  9, 8, 82, 2, 70, 4,  7, 0, 29, 
    5, 64, 4, 42, 8, 71, 3, 82, 2, 56, 7, 84, 0,  1, 1, 23, 6, 76, 
    7, 60, 2, 16, 4,  7, 5, 50, 6, 20, 0, 26, 3, 37, 8, 96, 1, 87, 
    6, 17, 4, 69, 7, 62, 1, 42, 0, 96, 2, 57, 3, 23, 8, 54, 5, 25, 
    0, 81, 7,  3, 5, 19, 1, 81, 4, 59, 6, 80, 2, 15, 3, 87, 8, 24, 
    5,  8, 3, 20, 0, 87, 8, 82, 1, 38, 6, 98, 7, 44, 4, 34, 2, 47
  };
  const int q1092[] = {
    9, 9, // Number of jobs and machines
    7, 13, 0, 75, 6, 66, 3, 63, 1, 85, 2,  2, 5, 75, 4, 24, 8,  3, 
    6, 85, 4, 76, 7,  3, 3, 96, 1, 45, 0, 20, 5, 94, 2, 28, 8, 82, 
    7, 23, 4, 80, 0, 44, 6,  5, 2, 19, 5, 17, 1, 86, 8, 21, 3,  4, 
    6, 97, 2, 27, 1, 98, 4,  8, 5, 56, 3, 12, 7,  9, 8,  3, 0, 73, 
    2, 30, 3, 39, 7, 49, 0, 61, 8, 96, 5, 43, 6, 68, 4, 13, 1, 93, 
    0, 63, 6, 18, 1, 66, 7, 44, 2, 49, 8,  3, 4, 75, 3, 71, 5, 19, 
    1,  7, 3, 13, 7,  5, 4, 90, 8, 59, 5, 26, 0, 68, 2, 99, 6, 72, 
    8, 86, 3, 29, 5, 42, 4, 91, 1, 29, 0, 52, 2, 97, 7, 37, 6, 19, 
    5, 96, 7, 96, 3, 99, 0, 44, 6, 10, 1, 25, 2, 33, 4, 83, 8, 46
  };
  const int q1093[] = {
    9, 9, // Number of jobs and machines
    1, 81, 2, 70, 3, 95, 8, 54, 0, 51, 4, 92, 5, 40, 6, 57, 7, 12, 
    3, 94, 2,  4, 4,  9, 0, 14, 6, 26, 1, 47, 5, 41, 7, 24, 8, 31, 
    5, 81, 1, 52, 3, 44, 4, 66, 0, 29, 7, 18, 6, 15, 2, 78, 8,  2, 
    6, 10, 4, 34, 8, 89, 0, 77, 5, 24, 1, 52, 3, 74, 7, 95, 2,  9, 
    2, 73, 0, 58, 4, 16, 3, 57, 1, 78, 5, 37, 6, 84, 8, 47, 7, 47, 
    7, 36, 3, 10, 6, 90, 4, 93, 2, 41, 8, 77, 5, 12, 0, 45, 1,  6, 
    0, 42, 3, 14, 5, 40, 6, 59, 8, 17, 4, 84, 2, 38, 7, 34, 1, 24, 
    8, 81, 0, 73, 4, 28, 2, 68, 7, 10, 1, 69, 5,  1, 6, 77, 3, 15, 
    4, 68, 5,  8, 3, 95, 1, 14, 6, 71, 0, 40, 2, 42, 7, 80, 8, 85
  };
  const int q1094[] = {
    9, 9, // Number of jobs and machines
    8, 25, 2, 68, 3, 32, 6,  8, 5, 11, 0, 83, 4, 29, 1, 65, 7, 15, 
    6, 70, 8, 67, 7, 15, 4, 46, 3, 28, 1, 41, 2, 86, 5, 39, 0, 45, 
    4, 13, 1,  5, 5, 88, 3, 79, 2,  6, 7, 48, 6, 37, 8, 17, 0, 25, 
    4,  6, 7, 59, 5, 19, 2, 84, 1, 22, 8, 37, 3, 87, 6, 65, 0, 29, 
    7, 91, 2, 89, 3, 33, 6, 53, 0, 80, 5, 99, 4, 81, 1, 34, 8, 31, 
    7, 37, 3, 79, 5, 13, 6, 99, 4, 68, 0, 10, 1, 46, 2, 20, 8, 10, 
    2, 20, 8, 82, 3, 74, 7, 44, 4,  6, 5, 50, 1,  5, 6, 74, 0, 89, 
    5,  6, 4, 74, 3, 41, 8, 34, 6, 34, 7, 30, 0, 54, 1, 85, 2, 61, 
    0, 56, 6, 22, 7, 70, 8, 82, 5, 40, 2, 59, 3, 14, 1, 19, 4, 95
  };
  const int q1095[] = {
    9, 9, // Number of jobs and machines
    7, 30, 4,  5, 3, 83, 2, 51, 8, 33, 1, 40, 5, 73, 0, 47, 6, 35, 
    2, 86, 4, 98, 8, 70, 0, 88, 3, 25, 7, 71, 5,  2, 1, 48, 6, 84, 
    3, 48, 7, 27, 8, 85, 4, 79, 5, 75, 6, 26, 0, 80, 2, 24, 1, 68, 
    7, 65, 1, 66, 3, 43, 0, 35, 8, 75, 2, 54, 4, 53, 5, 74, 6, 37, 
    7, 56, 2, 89, 5, 34, 4, 60, 8, 14, 6, 76, 1, 24, 0, 38, 3, 68, 
    0, 25, 2, 21, 5, 38, 7, 40, 1, 69, 6, 99, 3, 20, 4, 13, 8, 49, 
    8, 25, 2, 61, 1, 58, 4, 88, 3, 12, 5,  7, 7, 70, 0,  2, 6, 35, 
    3, 47, 0,  9, 5, 96, 4, 72, 8, 69, 1,  8, 2, 12, 7,  1, 6, 58, 
    4, 54, 0, 24, 1, 86, 5, 30, 2, 29, 3, 58, 6, 10, 7, 14, 8, 86
  };
  const int q1096[] = {
    9, 9, // Number of jobs and machines
    2, 78, 0, 20, 6, 66, 8, 18, 3, 43, 7, 75, 4, 76, 5, 45, 1, 19, 
    1,  5, 6, 68, 5, 31, 2, 64, 3, 54, 7,  5, 8, 33, 4,  3, 0, 22, 
    4, 32, 0, 54, 1, 37, 7, 31, 3,  7, 6, 75, 5, 15, 8, 29, 2,  2, 
    2, 46, 4, 28, 5, 16, 0, 65, 8, 76, 1,  1, 7, 69, 3, 92, 6, 18, 
    7, 62, 0, 64, 3, 95, 1, 90, 8, 98, 5, 42, 6, 69, 4, 32, 2, 46, 
    2,  3, 5, 42, 4, 94, 8, 85, 3, 33, 6, 63, 0, 51, 7, 70, 1, 18, 
    1, 11, 8, 73, 3, 65, 0, 27, 5, 66, 7, 47, 6, 63, 4, 99, 2, 79, 
    0, 89, 8, 43, 4, 99, 1, 51, 6, 96, 2, 29, 5, 45, 3, 70, 7, 55, 
    2, 74, 5,  8, 0, 65, 7, 60, 8, 81, 3, 38, 6, 89, 1,  6, 4, 23
  };
  const int q1097[] = {
    9, 9, // Number of jobs and machines
    2, 34, 6, 51, 1,  2, 8, 30, 5, 47, 7, 53, 4, 61, 3,  1, 0,  6, 
    2, 85, 4, 31, 3, 50, 7, 44, 0, 83, 5, 82, 6, 26, 8, 79, 1, 61, 
    4, 89, 1, 51, 6, 54, 8, 21, 7,  2, 5, 26, 2, 34, 3, 12, 0, 88, 
    0, 37, 8, 18, 5, 66, 7, 89, 3, 29, 4, 67, 6, 35, 2, 35, 1, 16, 
    1, 89, 3, 99, 2, 47, 0, 39, 7, 95, 5, 75, 8, 36, 4, 90, 6, 82, 
    3, 58, 8, 20, 7, 49, 5, 91, 1, 59, 0, 85, 6,  3, 4, 30, 2,  4, 
    0, 76, 4, 79, 7, 60, 2, 31, 8, 16, 5, 19, 3, 59, 6, 12, 1, 61, 
    3, 99, 6, 96, 2, 36, 5, 33, 4, 68, 1, 60, 8, 41, 0, 20, 7, 28, 
    5, 81, 2,  1, 7, 49, 0, 23, 6, 68, 1, 92, 8, 50, 3, 72, 4, 69
  };
  const int q1098[] = {
    9, 9, // Number of jobs and machines
    4, 27, 5, 70, 7,  6, 2, 12, 8, 11, 1, 66, 3, 82, 0, 52, 6, 85, 
    1, 27, 0, 82, 3, 24, 6, 33, 5, 33, 2, 73, 4, 92, 7, 13, 8, 10, 
    2, 76, 7, 17, 8, 80, 1, 15, 6, 55, 4, 19, 0, 91, 5, 27, 3, 14, 
    4, 78, 1, 83, 7,  8, 0, 27, 5, 51, 8, 86, 2, 97, 6, 37, 3, 90, 
    4, 87, 1, 76, 0, 41, 8,  5, 3, 45, 7, 52, 6, 55, 5, 65, 2, 35, 
    5, 34, 6, 18, 8, 23, 4, 82, 3, 95, 2, 49, 0, 54, 7, 94, 1, 87, 
    0, 30, 3,  7, 5, 32, 2, 69, 6, 48, 8, 62, 4, 52, 7, 36, 1, 23, 
    0,  8, 8, 11, 5, 99, 7, 66, 1, 55, 3, 22, 2, 12, 4, 31, 6, 36, 
    4, 81, 6, 68, 8, 63, 7, 25, 0,  6, 2, 21, 1, 34, 5, 90, 3,  7
  };
  const int q1099[] = {
    9, 9, // Number of jobs and machines
    7, 29, 8, 28, 1, 18, 2, 77, 5,  9, 3, 71, 4, 90, 0, 87, 6,  9, 
    5, 39, 6, 88, 1, 67, 8,  8, 0, 11, 4,  4, 2, 66, 7, 66, 3, 13, 
    7, 96, 5, 23, 4, 29, 1,  3, 6,  7, 8, 97, 2, 89, 3, 38, 0, 57, 
    8, 98, 6, 46, 0,  6, 5, 25, 7, 41, 1, 32, 4, 99, 2, 68, 3, 78, 
    7,  1, 5, 45, 2, 47, 8, 41, 4, 62, 0, 53, 1, 99, 3, 27, 6, 75, 
    2, 27, 8, 29, 7, 17, 1, 44, 6, 99, 3, 73, 5,  5, 4,  5, 0, 29, 
    5, 86, 3, 64, 8, 97, 1, 50, 4, 37, 7, 66, 0, 69, 6, 18, 2, 48, 
    0, 92, 8, 28, 3, 63, 1,  7, 7, 84, 5, 65, 2, 20, 4, 65, 6, 85, 
    4, 28, 3, 77, 1, 79, 2, 47, 6, 65, 8, 46, 7, 56, 0, 48, 5, 69
  };
  const int q1100[] = {
    9, 9, // Number of jobs and machines
    0, 53, 4, 60, 1, 60, 5, 88, 8, 13, 2,  6, 3, 72, 7, 80, 6, 93, 
    3, 35, 1, 39, 5, 90, 8, 44, 6, 89, 4, 34, 2, 26, 7, 71, 0, 51, 
    1,  5, 8, 32, 2, 25, 0, 58, 6, 12, 5, 44, 7, 20, 4, 29, 3, 47, 
    1,  6, 5, 28, 8, 80, 2, 94, 4, 34, 7, 80, 0, 16, 6, 64, 3,  3, 
    4, 50, 6, 96, 7, 24, 5, 87, 2, 93, 8, 54, 0, 33, 3, 87, 1, 42, 
    0, 45, 8, 52, 2, 35, 7, 92, 4, 71, 5,  7, 6,  2, 1, 14, 3, 11, 
    0, 52, 6, 37, 5, 90, 7, 40, 3, 27, 8, 29, 1, 87, 2, 11, 4, 87, 
    3, 84, 4, 94, 5, 62, 1, 74, 2, 44, 0, 91, 6, 37, 8, 73, 7, 49, 
    2, 79, 0,  4, 7, 74, 3, 25, 4, 62, 1, 45, 8, 66, 5, 96, 6, 41
  };
  const int q1101[] = {
    9, 9, // Number of jobs and machines
    8, 11, 0, 71, 6, 69, 2, 43, 3, 57, 7, 22, 5, 52, 4, 82, 1, 40, 
    0,  2, 3,  3, 7, 27, 2, 33, 1, 49, 5, 37, 6, 20, 4, 63, 8, 32, 
    8, 14, 3, 84, 6, 34, 5, 71, 2, 62, 0, 77, 1, 43, 7, 92, 4, 64, 
    8,  3, 4, 81, 7, 92, 2, 54, 1, 86, 6, 27, 0, 48, 3,  4, 5, 97, 
    1, 22, 7, 86, 8, 49, 5,  9, 4, 23, 3, 81, 2, 71, 6,  1, 0, 54, 
    0, 22, 3, 21, 8, 49, 6, 41, 5, 36, 1, 97, 4, 74, 2, 67, 7,  3, 
    2, 62, 6, 36, 4, 29, 0, 14, 3, 77, 1, 42, 8, 86, 7, 12, 5, 88, 
    2, 45, 8, 51, 1, 52, 3,  4, 7, 82, 6, 17, 4, 55, 0, 12, 5, 12, 
    6, 99, 2, 65, 8, 36, 1, 71, 7, 89, 3, 27, 5, 41, 4, 92, 0, 13
  };
  const int q1102[] = {
    9, 9, // Number of jobs and machines
    2, 24, 8, 85, 1, 11, 6, 98, 0, 88, 5,  7, 3, 77, 7, 79, 4, 43, 
    4, 85, 1, 29, 3, 46, 5, 46, 0, 49, 7, 37, 8, 69, 2, 31, 6, 43, 
    4, 46, 5, 68, 2, 57, 8, 38, 1, 86, 3, 44, 7, 11, 0, 79, 6, 69, 
    0, 55, 8, 44, 5, 55, 2, 10, 4,  6, 6, 45, 1, 92, 3, 98, 7, 50, 
    7, 39, 3, 35, 8, 55, 4, 37, 2, 89, 6, 90, 0, 53, 1, 87, 5, 47, 
    0, 97, 8, 49, 7, 91, 4, 25, 5, 18, 2, 51, 1,  2, 3, 63, 6, 79, 
    1, 78, 0, 42, 4,  3, 2, 25, 8, 44, 6, 14, 3, 22, 5, 39, 7, 19, 
    4, 36, 2, 77, 0,  4, 5, 19, 8, 61, 1,  1, 3, 10, 7, 94, 6, 66, 
    4, 34, 7, 83, 5, 49, 6,  4, 0, 24, 1, 27, 3,  2, 8, 36, 2, 91
  };
  const int q1103[] = {
    9, 9, // Number of jobs and machines
    2, 91, 5, 84, 1, 39, 7, 32, 8, 93, 0, 99, 4, 98, 6, 67, 3, 78, 
    1, 37, 4, 12, 7, 21, 2,  9, 0,  7, 8, 88, 5, 94, 6, 12, 3, 48, 
    5, 57, 3, 14, 6, 99, 1,  6, 2, 23, 4, 37, 0, 66, 8, 15, 7, 56, 
    1, 21, 6, 17, 0,  4, 3,  6, 2, 64, 4, 35, 7, 23, 5, 85, 8,  7, 
    5, 63, 8, 85, 4, 12, 6, 40, 0, 12, 1, 21, 3, 21, 2, 52, 7,  4, 
    7,  5, 2, 48, 3, 93, 1, 11, 8,  2, 5, 82, 6, 90, 4, 43, 0, 73, 
    6, 36, 0, 13, 8, 12, 4, 67, 5, 22, 3, 15, 7, 59, 1, 52, 2, 61, 
    2, 63, 3, 34, 4, 20, 5,  5, 0, 63, 1,  6, 6, 42, 7, 56, 8, 52, 
    5, 35, 3, 47, 8, 64, 2, 84, 1, 91, 4, 22, 6, 49, 0,  6, 7, 35
  };
  const int q1104[] = {
    9, 9, // Number of jobs and machines
    6, 44, 2, 12, 7, 89, 3, 59, 5, 34, 8,  1, 1, 92, 4, 54, 0, 12, 
    4, 88, 0,  7, 5, 57, 2, 54, 1, 52, 7, 26, 3, 94, 6, 43, 8, 56, 
    3, 90, 0, 63, 2, 33, 1, 90, 6, 81, 5, 72, 7, 99, 4, 20, 8, 10, 
    8, 12, 0, 98, 1, 35, 7, 68, 2, 21, 3, 29, 6, 69, 4,  5, 5, 91, 
    0,  4, 3, 88, 4,  3, 1, 74, 7, 68, 6, 56, 8, 65, 5, 51, 2, 73, 
    3, 29, 1, 72, 2, 30, 8, 95, 7, 73, 4, 68, 6,  8, 0, 45, 5, 30, 
    1, 71, 6, 93, 8, 84, 3, 16, 0, 91, 4, 67, 5, 54, 2, 92, 7, 46, 
    8, 87, 4, 15, 3, 33, 0, 13, 5, 61, 7, 57, 2, 97, 1, 37, 6, 92, 
    1, 29, 6, 97, 5, 66, 8, 14, 4, 81, 2, 35, 7, 55, 0, 43, 3, 16
  };
  const int q1105[] = {
    9, 9, // Number of jobs and machines
    0, 42, 4, 16, 5, 58, 8, 27, 2, 45, 7, 70, 1, 88, 3, 56, 6, 42, 
    5, 14, 6, 79, 0, 87, 1, 56, 7, 81, 4, 53, 8, 29, 3, 47, 2, 33, 
    3, 23, 8, 53, 2, 53, 6, 98, 0, 35, 4, 16, 5, 75, 7, 92, 1, 81, 
    5, 89, 4, 45, 2, 67, 6, 80, 3, 43, 0, 71, 8, 47, 7, 17, 1, 47, 
    6, 12, 7, 14, 5, 98, 2, 76, 0, 75, 8, 66, 3, 36, 1, 80, 4, 53, 
    0, 35, 8, 70, 4, 58, 3, 38, 1, 74, 5, 81, 7,  7, 6, 84, 2, 34, 
    3, 38, 5, 65, 8, 21, 7, 34, 4, 63, 1, 29, 2, 19, 6, 94, 0, 78, 
    6, 49, 5, 44, 2, 65, 0, 37, 4, 30, 7, 74, 1, 36, 3, 57, 8, 10, 
    3, 59, 5, 43, 8,  5, 0, 20, 1, 76, 7, 36, 2, 76, 6, 54, 4, 91
  };
  const int q1106[] = {
    9, 9, // Number of jobs and machines
    5, 87, 3, 81, 4, 96, 8, 13, 0, 87, 1, 42, 2,  6, 7, 44, 6, 65, 
    5, 29, 6, 21, 3, 42, 7,  2, 8, 81, 4, 12, 1, 39, 0, 10, 2, 11, 
    7, 64, 8, 22, 1, 68, 6, 97, 0, 43, 2, 39, 5, 97, 3, 52, 4, 49, 
    2, 44, 1, 73, 8, 62, 7, 45, 3,  1, 4, 35, 0, 50, 5, 94, 6, 83, 
    4, 45, 6, 49, 5, 75, 1, 71, 8, 65, 3, 96, 0, 36, 2, 71, 7, 70, 
    3, 71, 8, 51, 7,  7, 0, 75, 5, 83, 2, 92, 4,  4, 6, 55, 1, 90, 
    4, 92, 1, 79, 6, 97, 7, 83, 5, 57, 8, 76, 0, 62, 2, 65, 3, 64, 
    6,  6, 4,  5, 0, 99, 7, 36, 2, 18, 5, 42, 8, 87, 3, 17, 1, 94, 
    0, 33, 4, 40, 2, 47, 5, 36, 1, 86, 7,  7, 3, 93, 8, 77, 6, 82
  };
  const int q1107[] = {
    9, 9, // Number of jobs and machines
    5,  2, 0, 51, 1, 56, 4, 88, 3, 45, 2, 93, 7, 19, 8, 41, 6, 28, 
    1, 91, 7, 35, 8, 66, 2, 98, 5, 41, 3, 65, 0, 81, 4, 41, 6, 72, 
    8, 94, 1, 78, 6, 90, 2, 27, 0, 64, 4, 97, 3, 92, 7, 79, 5, 77, 
    0, 50, 5, 15, 1, 31, 8, 35, 2, 45, 6, 65, 7, 14, 3, 39, 4, 68, 
    0, 99, 1, 66, 8, 50, 4, 52, 2, 53, 5, 67, 6, 51, 3, 63, 7, 10, 
    2, 96, 3, 77, 6, 47, 8, 63, 5, 50, 7, 98, 1, 39, 0, 55, 4, 12, 
    4, 14, 6, 48, 7, 29, 5, 62, 8, 84, 3, 88, 2, 68, 1, 12, 0, 88, 
    1, 32, 5, 45, 4,  5, 8, 44, 7, 47, 3, 15, 6, 92, 2, 72, 0, 38, 
    4, 64, 6, 96, 2, 81, 0, 86, 8, 36, 1, 32, 3,  3, 5, 97, 7, 49
  };
  const int q1108[] = {
    9, 9, // Number of jobs and machines
    7,  9, 2, 66, 4, 52, 0, 92, 1, 56, 5, 53, 3, 81, 6, 87, 8, 49, 
    7, 88, 4, 84, 8, 97, 6,  7, 2, 89, 1, 20, 0, 16, 3, 17, 5, 32, 
    6,  3, 8, 30, 4, 16, 1, 44, 2, 97, 5, 85, 3, 49, 0, 25, 7, 45, 
    2, 29, 1, 74, 8, 15, 4, 88, 5, 11, 6, 84, 3, 54, 7, 17, 0, 78, 
    6, 71, 4, 20, 2, 38, 0, 11, 1, 88, 7,  1, 8, 12, 5, 75, 3, 55, 
    1, 86, 2, 34, 0,  4, 4, 33, 6, 41, 3, 66, 8, 11, 5, 50, 7, 85, 
    1,  9, 7, 70, 8, 73, 4, 88, 6, 54, 0, 90, 5, 33, 3, 23, 2, 64, 
    5, 52, 4, 39, 8, 47, 7,  7, 6, 65, 3, 99, 1, 91, 0, 89, 2, 66, 
    7, 78, 4, 39, 8,  3, 0, 80, 2, 54, 3, 27, 1, 63, 6,  9, 5, 51
  };
  const int q1109[] = {
    9, 9, // Number of jobs and machines
    3, 92, 8, 92, 2, 61, 4, 28, 1, 50, 0, 13, 5, 47, 7, 17, 6,  2, 
    6, 10, 8, 41, 1, 90, 0, 45, 7, 51, 4, 78, 5, 88, 2, 28, 3, 89, 
    4, 59, 0, 77, 2, 35, 5, 31, 7, 84, 3, 70, 1, 82, 8, 31, 6, 54, 
    5, 15, 8, 41, 2, 88, 4, 36, 7, 19, 1,  4, 6, 40, 3, 33, 0, 27, 
    6, 19, 3, 57, 4, 15, 1, 34, 8, 79, 2, 48, 0, 99, 7, 46, 5, 85, 
    3, 72, 6, 91, 7, 68, 4, 52, 8, 92, 1, 33, 5, 76, 2, 14, 0, 11, 
    2, 40, 5, 94, 3, 42, 6, 40, 0, 72, 1, 54, 8, 43, 7, 33, 4, 73, 
    4, 12, 2, 59, 7, 16, 3, 50, 5, 22, 6, 26, 8, 27, 0, 70, 1, 71, 
    1, 93, 4, 93, 8, 65, 6, 49, 0, 96, 7, 98, 5, 51, 3, 58, 2, 11
  };
  const int q1110[] = {
    9, 9, // Number of jobs and machines
    7, 19, 6, 46, 3, 76, 1, 73, 4, 91, 8, 35, 0, 63, 5, 80, 2, 85, 
    2, 80, 4, 87, 5, 49, 6, 31, 8,  2, 3,  7, 1, 35, 0, 62, 7, 23, 
    7, 89, 2, 19, 4, 88, 8, 10, 5,  9, 1, 47, 6, 43, 0, 22, 3, 13, 
    7, 70, 4, 67, 6, 70, 5, 82, 8, 89, 2, 75, 3, 78, 1, 63, 0, 86, 
    5, 27, 8, 84, 4, 60, 6, 41, 2, 31, 3,  2, 7,  2, 1, 58, 0, 13, 
    3, 53, 8, 69, 2, 62, 1, 40, 4, 26, 5, 23, 6, 87, 7, 32, 0,  4, 
    6, 14, 7, 36, 0, 46, 4, 55, 8, 91, 5, 98, 1, 57, 3, 87, 2, 48, 
    4, 15, 5, 41, 0, 32, 2, 84, 7,  8, 6, 86, 3, 35, 1, 14, 8, 67, 
    1, 85, 4, 63, 2, 99, 3, 36, 0, 10, 5, 70, 6, 41, 7, 89, 8,  1
  };
  const int q1111[] = {
    9, 9, // Number of jobs and machines
    1, 94, 0,  2, 4, 20, 7, 65, 6, 12, 8, 32, 5, 70, 3, 36, 2, 58, 
    5, 74, 8, 22, 3, 63, 4, 65, 0,  9, 2, 47, 7, 97, 1,  7, 6, 48, 
    7, 44, 1, 66, 3, 48, 5, 92, 6, 83, 2, 93, 8,  5, 4, 44, 0, 57, 
    6, 29, 3, 83, 8, 45, 0, 81, 1, 10, 2, 78, 7, 67, 5, 86, 4, 37, 
    7, 35, 3, 68, 4, 10, 5, 42, 6,  1, 8, 78, 1, 46, 2, 74, 0, 42, 
    0, 97, 6, 84, 1, 61, 4, 55, 2, 16, 5, 78, 3, 45, 7, 41, 8, 37, 
    3, 53, 6, 80, 5,  1, 8, 25, 7, 49, 2, 39, 0, 42, 4, 13, 1, 31, 
    6, 80, 1, 28, 7, 73, 4, 65, 3, 26, 5, 76, 0, 59, 8, 46, 2, 98, 
    1, 87, 2, 76, 8,  3, 7, 35, 6, 89, 5, 29, 3, 32, 0, 11, 4, 49
  };
  const int q1112[] = {
    9, 9, // Number of jobs and machines
    1, 56, 6, 31, 7, 71, 2, 31, 8, 37, 4, 95, 5, 40, 0, 61, 3,  8, 
    3, 72, 5, 43, 4,  4, 7, 82, 6, 84, 8, 13, 1, 26, 2, 79, 0, 64, 
    8, 41, 4, 76, 3,  3, 0, 39, 1, 80, 7, 12, 5, 79, 6, 13, 2, 53, 
    0, 67, 4, 74, 5, 75, 2, 82, 7, 31, 8, 43, 6, 23, 3, 75, 1, 10, 
    0, 86, 8,  2, 7, 17, 4, 53, 6, 19, 5, 21, 3, 42, 2, 14, 1, 40, 
    1,  1, 0, 24, 7, 38, 3, 39, 5, 59, 4, 69, 8,  7, 6, 68, 2, 74, 
    1, 80, 8, 68, 6, 32, 2, 34, 0, 74, 4, 84, 5, 22, 7, 71, 3, 58, 
    0,  9, 7, 44, 5, 90, 4, 92, 3, 75, 6, 70, 1, 27, 2, 20, 8, 34, 
    0, 64, 3, 74, 6,  4, 2, 28, 1, 58, 4, 49, 5, 45, 7, 56, 8, 37
  };
  const int q1113[] = {
    9, 9, // Number of jobs and machines
    4, 33, 8, 71, 2, 50, 0, 78, 6, 53, 5, 29, 7, 65, 3, 98, 1,  1, 
    4, 58, 7, 12, 6, 19, 0, 36, 5, 94, 3, 17, 8, 91, 1, 73, 2, 16, 
    4, 28, 2, 36, 6, 11, 7, 71, 0,  7, 3, 58, 8, 58, 5, 13, 1, 93, 
    4,  2, 5, 25, 3, 32, 7, 41, 2, 32, 0, 80, 8, 58, 1, 99, 6, 66, 
    6, 91, 3, 28, 0, 58, 7, 38, 2, 89, 1, 66, 5, 13, 8, 66, 4, 81, 
    8, 20, 1,  6, 3,  7, 6, 26, 2, 29, 0,  7, 4, 16, 7, 57, 5, 29, 
    8, 59, 3, 44, 2, 61, 4, 64, 1, 60, 7, 87, 0, 17, 5, 98, 6, 86, 
    2, 25, 6, 84, 8, 62, 0, 58, 1, 58, 7, 86, 4, 30, 5, 82, 3, 13, 
    8,  9, 5, 12, 0, 22, 4, 79, 3, 52, 6, 71, 1, 88, 7, 76, 2, 31
  };
  const int q1114[] = {
    9, 9, // Number of jobs and machines
    4, 91, 6, 70, 2, 38, 8, 53, 7, 21, 3, 59, 0, 98, 1, 21, 5, 99, 
    3, 81, 1, 89, 0, 37, 5, 95, 8, 66, 4, 39, 7,  2, 6, 35, 2,  1, 
    1, 37, 7, 81, 2, 85, 3, 96, 4, 64, 0, 31, 8, 12, 5, 33, 6,  3, 
    3, 96, 5, 56, 8, 70, 0, 79, 4, 65, 1, 62, 2, 50, 7,  5, 6, 40, 
    0, 32, 3, 60, 6, 65, 1,  6, 2, 26, 4, 22, 7, 63, 8, 65, 5, 20, 
    8, 14, 1,  8, 4, 50, 3,  8, 5, 26, 0, 32, 6,  9, 7, 15, 2, 92, 
    8, 97, 7, 21, 6, 86, 2, 72, 4,  9, 3, 82, 1, 18, 0, 74, 5, 64, 
    6, 62, 8, 88, 0, 12, 5, 61, 1, 77, 3,  2, 4, 65, 7, 29, 2, 87, 
    4, 84, 0, 65, 5, 70, 7,  9, 2, 10, 1, 84, 6, 80, 8, 98, 3, 35
  };
  const int q1115[] = {
    9, 9, // Number of jobs and machines
    5, 49, 7, 25, 6, 20, 0, 87, 2, 63, 1, 46, 8, 32, 3, 88, 4, 47, 
    7, 92, 8, 68, 2, 71, 4, 34, 5, 48, 3, 24, 0, 38, 6, 65, 1,  6, 
    5, 41, 3,  5, 1, 60, 2, 65, 7, 28, 4, 46, 0, 99, 6, 60, 8, 65, 
    2, 32, 1, 90, 5, 76, 3, 49, 8, 60, 4,  4, 0, 56, 6, 94, 7, 82, 
    7,  9, 2, 76, 8,  7, 3, 98, 0, 17, 4, 24, 1, 20, 5, 85, 6, 49, 
    4, 66, 2, 58, 1, 99, 7, 83, 0, 73, 8,  2, 3, 14, 6,  2, 5, 13, 
    0, 69, 7, 88, 2, 79, 6, 27, 8, 73, 5, 26, 3, 51, 1, 32, 4, 78, 
    7, 72, 6, 70, 8, 46, 1, 55, 5, 23, 3, 21, 0, 15, 2, 92, 4, 48, 
    3, 99, 0, 56, 2, 41, 6, 53, 8,  1, 7, 69, 1, 51, 5, 89, 4, 85
  };
  const int q1116[] = {
    9, 9, // Number of jobs and machines
    7, 30, 5, 90, 4, 63, 1, 73, 2, 93, 6, 94, 0, 43, 8, 94, 3, 62, 
    5, 61, 4, 31, 7, 78, 1, 19, 6, 70, 8, 89, 0, 14, 3, 80, 2, 73, 
    7, 45, 2, 44, 0, 92, 6, 94, 5, 98, 8, 24, 1, 17, 4, 26, 3, 74, 
    4, 78, 7, 36, 5, 59, 6, 14, 0, 90, 8,  2, 1, 75, 2, 91, 3, 64, 
    4, 70, 3, 17, 2, 89, 0, 84, 5, 14, 6, 12, 7, 18, 1, 29, 8, 70, 
    1, 85, 0, 67, 7, 14, 5, 46, 6, 53, 3, 68, 2, 83, 4, 99, 8, 75, 
    5, 21, 6, 76, 0, 75, 3, 32, 2,  6, 7, 69, 4, 51, 1, 87, 8, 18, 
    7, 51, 5, 73, 1, 21, 4, 54, 6, 23, 0,  6, 3, 46, 2, 86, 8, 27, 
    0, 77, 1, 46, 7, 93, 6, 62, 3, 85, 8,  4, 2, 21, 4, 75, 5, 57
  };
  const int q1117[] = {
    9, 9, // Number of jobs and machines
    0, 41, 5, 55, 3, 69, 7, 35, 1, 89, 6, 56, 4, 61, 2, 42, 8,  9, 
    2, 62, 6, 54, 8, 60, 1, 68, 0, 49, 4, 57, 7, 74, 3, 22, 5, 80, 
    0,  3, 7, 59, 2, 92, 1, 27, 6, 33, 5, 64, 3, 88, 4, 20, 8, 88, 
    0, 40, 4,  7, 3, 75, 8, 78, 6, 33, 2, 13, 1, 81, 5, 50, 7, 94, 
    1, 86, 3, 15, 2, 90, 4, 64, 0, 31, 5, 96, 6, 93, 7, 49, 8, 10, 
    5, 53, 1,  1, 2, 87, 0, 66, 4,  2, 8,  4, 7, 94, 3, 34, 6, 34, 
    2, 33, 1, 13, 4, 40, 8, 61, 5, 23, 7, 62, 0, 47, 3, 39, 6, 44, 
    4,  4, 7, 63, 6, 69, 0, 85, 2, 21, 3, 35, 1, 79, 5, 15, 8, 86, 
    5, 63, 4, 12, 7, 14, 0, 81, 6, 34, 3, 10, 1, 34, 2, 98, 8, 41
  };
  const int q1118[] = {
    9, 9, // Number of jobs and machines
    5, 45, 0,  2, 6, 49, 8, 44, 3, 67, 4,  2, 7, 24, 1, 93, 2,  3, 
    4, 43, 8, 82, 5, 11, 1, 22, 3, 59, 0,  2, 7, 95, 6, 87, 2, 64, 
    6, 92, 3, 68, 8, 51, 2, 22, 0, 60, 4, 64, 1,  5, 5, 74, 7, 26, 
    4, 95, 3, 23, 6,  7, 8, 53, 0, 97, 2, 69, 7, 90, 5, 95, 1, 14, 
    6, 97, 0, 34, 7, 12, 8, 58, 5, 74, 3, 86, 2, 42, 4, 85, 1,  6, 
    7,  2, 4, 65, 1, 93, 5, 39, 3, 78, 6, 23, 0, 65, 2, 12, 8, 62, 
    7, 36, 0, 42, 8, 91, 1, 77, 4, 41, 5, 10, 6, 37, 3, 43, 2, 98, 
    1, 29, 8, 21, 0, 97, 2,  3, 6,  2, 7, 95, 3,  2, 5, 99, 4, 61, 
    3, 51, 0,  7, 4, 61, 2, 99, 8, 75, 5, 87, 1,  7, 6, 15, 7, 93
  };
  const int q1119[] = {
    9, 9, // Number of jobs and machines
    6, 74, 4,  8, 1, 61, 0, 29, 8, 49, 2,  8, 5, 32, 3, 19, 7, 95, 
    1, 92, 6, 40, 7, 46, 4, 53, 2, 88, 0, 95, 5, 82, 3, 17, 8, 23, 
    3, 25, 1, 17, 6, 14, 7,  8, 5,  8, 0, 97, 2, 99, 4, 28, 8, 75, 
    3, 57, 0, 93, 4, 15, 2, 53, 5, 81, 7, 67, 8, 80, 1, 31, 6, 47, 
    7, 46, 2, 90, 8,  9, 0, 32, 3, 78, 1, 95, 6,  6, 4, 91, 5, 81, 
    0, 56, 4, 65, 1, 55, 3, 26, 6, 19, 8, 99, 7, 23, 5, 53, 2, 93, 
    4, 74, 5, 31, 2, 72, 3, 94, 1,  7, 0, 86, 6, 13, 8, 19, 7, 82, 
    8,  6, 3, 71, 4, 40, 0, 33, 2, 65, 1, 93, 7, 57, 5, 27, 6, 24, 
    3, 29, 0, 83, 6, 94, 7, 51, 2, 89, 8, 65, 4, 18, 1, 29, 5, 69
  };
  const int q1120[] = {
    9, 9, // Number of jobs and machines
    0, 68, 8, 37, 6,  8, 3, 13, 4, 57, 1, 91, 2, 27, 7, 92, 5, 87, 
    3, 92, 4, 88, 2, 16, 8, 44, 7, 14, 5,  7, 1, 59, 6, 89, 0, 88, 
    7, 91, 6, 38, 0, 74, 1,  5, 2, 84, 8, 76, 4, 61, 3,  2, 5, 90, 
    8,  5, 5, 70, 7, 96, 0, 87, 4, 56, 1, 10, 6, 70, 3, 77, 2, 71, 
    2, 71, 7, 14, 3, 30, 8, 60, 6, 56, 5, 86, 0, 92, 1, 24, 4, 90, 
    1, 19, 2, 67, 4, 47, 8, 57, 3, 22, 6,  9, 5, 35, 0, 39, 7, 48, 
    6, 35, 7,  1, 5, 75, 3, 44, 2,  8, 8, 42, 4, 33, 0, 15, 1, 93, 
    8,  7, 7, 90, 3, 35, 1,  6, 0, 68, 5, 82, 6, 65, 4, 78, 2, 34, 
    6,  9, 7, 69, 8, 78, 4, 88, 5, 80, 0, 30, 3, 31, 2, 62, 1, 24
  };
  const int q1121[] = {
    9, 9, // Number of jobs and machines
    8, 60, 4, 54, 1, 67, 2, 38, 7, 23, 0, 32, 5,  2, 6,  5, 3, 72, 
    1, 70, 3, 59, 4, 19, 2, 85, 5, 67, 0, 31, 7, 33, 8, 26, 6, 82, 
    8, 99, 7, 95, 6, 78, 3, 34, 2, 77, 1, 30, 5, 51, 4, 32, 0, 85, 
    8, 67, 0, 21, 5, 67, 4, 76, 2,  7, 6, 13, 1, 65, 7, 62, 3, 28, 
    7, 81, 4,  1, 6, 39, 0, 26, 8, 58, 1, 15, 2,  4, 5, 22, 3, 66, 
    8, 25, 1, 23, 6, 24, 0, 61, 2, 98, 4, 30, 5, 39, 3, 80, 7, 60, 
    1, 60, 6, 84, 0, 40, 7, 93, 2,  8, 3, 97, 4, 22, 8, 49, 5, 69, 
    3, 23, 6, 57, 8, 32, 0, 67, 2, 66, 7, 36, 1, 55, 4, 43, 5, 80, 
    0, 30, 8,  6, 4, 98, 1, 47, 5, 56, 6, 14, 7, 32, 3, 24, 2, 91
  };
  const int q1122[] = {
    9, 9, // Number of jobs and machines
    3, 61, 0, 84, 7, 65, 1,  2, 4, 20, 8, 87, 6, 88, 5, 80, 2, 49, 
    2, 13, 5, 16, 1, 70, 3, 22, 0, 57, 6, 71, 4, 23, 8, 45, 7, 76, 
    6, 39, 8, 27, 0, 37, 5, 76, 2, 37, 1, 59, 3, 13, 4, 54, 7, 43, 
    2, 77, 5, 18, 7, 66, 1,  8, 6, 59, 4, 15, 0, 51, 3, 60, 8, 24, 
    8, 12, 0, 27, 7, 81, 2, 17, 4,  1, 5, 62, 3, 68, 6, 48, 1, 70, 
    0, 93, 7, 94, 1, 53, 3, 31, 2, 48, 5,  6, 6, 31, 4, 40, 8, 70, 
    2, 86, 3, 61, 6,  2, 5, 49, 7, 34, 8, 54, 1, 58, 4, 78, 0, 29, 
    2, 42, 8, 97, 3, 19, 1,  5, 5, 58, 6,  5, 4, 53, 7, 48, 0, 92, 
    4, 39, 2, 75, 7, 76, 5, 76, 1, 90, 6, 67, 8, 58, 3, 28, 0, 18
  };
  const int q1123[] = {
    9, 9, // Number of jobs and machines
    0, 85, 1, 56, 4, 40, 8, 76, 2, 91, 5, 68, 7, 88, 6, 72, 3, 92, 
    2, 23, 4, 83, 5, 10, 6,  1, 3, 57, 1, 50, 0, 67, 7, 83, 8,  4, 
    8, 32, 1,  2, 0, 22, 4, 43, 3, 23, 7, 30, 5, 61, 2, 26, 6, 33, 
    1, 32, 8, 76, 4, 10, 6, 65, 7, 34, 0, 75, 3, 14, 5, 13, 2, 51, 
    7, 62, 6, 76, 3, 23, 4, 80, 1, 10, 5, 74, 0, 14, 8, 42, 2, 90, 
    5, 94, 6, 82, 8, 68, 1, 74, 3, 25, 2, 66, 7, 89, 4, 75, 0, 87, 
    2, 71, 7, 95, 0, 50, 3, 90, 4,  5, 8, 26, 5, 90, 1, 78, 6, 11, 
    3, 33, 5, 66, 7, 41, 8, 41, 4, 70, 1, 84, 0, 64, 2, 18, 6, 27, 
    5, 58, 1, 33, 4, 73, 7, 81, 0, 98, 8, 85, 3, 76, 6, 68, 2,  9
  };
  const int q1124[] = {
    9, 9, // Number of jobs and machines
    0, 58, 3, 55, 7, 84, 1, 14, 8, 79, 5, 27, 6, 71, 2, 16, 4, 82, 
    8,  3, 1, 18, 7, 61, 3, 47, 4, 95, 6, 53, 2, 52, 0, 67, 5,  9, 
    8, 50, 0, 73, 3, 98, 5, 21, 1, 58, 4, 13, 6, 12, 7, 97, 2, 76, 
    3, 12, 1, 70, 6, 12, 8, 78, 4, 84, 2, 80, 7, 97, 0, 31, 5, 95, 
    1, 86, 2,  1, 5, 22, 3, 36, 4, 49, 0, 76, 7, 88, 8, 53, 6, 83, 
    0, 90, 1, 36, 5, 16, 7, 22, 4, 54, 2, 58, 3, 61, 8, 52, 6, 23, 
    8, 18, 6, 13, 0, 60, 2,  8, 7, 69, 4,  4, 3, 31, 5, 79, 1, 32, 
    3, 57, 8, 82, 4, 94, 6, 12, 1, 32, 5, 30, 7, 81, 0, 28, 2, 67, 
    2, 41, 5, 91, 6,  1, 4, 96, 3, 19, 0, 65, 1,  5, 7, 45, 8, 50
  };
  const int q1125[] = {
    9, 9, // Number of jobs and machines
    7,  3, 8, 84, 4, 80, 5, 78, 3, 76, 1, 25, 2, 42, 6, 80, 0, 58, 
    4, 44, 3, 54, 1, 78, 5, 68, 2, 16, 6, 49, 7, 49, 0, 35, 8,  8, 
    3, 69, 4, 98, 5, 74, 2, 64, 6, 93, 7, 61, 1, 30, 8, 52, 0, 51, 
    4, 51, 6, 21, 0, 90, 7, 52, 3, 68, 8, 42, 5, 24, 1, 55, 2, 85, 
    1, 40, 7, 14, 8,  1, 0, 73, 5, 78, 2, 14, 3, 17, 4, 15, 6, 46, 
    6, 58, 2,  8, 3, 64, 5, 68, 8, 98, 0, 88, 1, 48, 4, 68, 7,  5, 
    5, 54, 2, 37, 6, 89, 7, 34, 0, 95, 8, 38, 1, 55, 4, 17, 3, 68, 
    7, 46, 3, 14, 0, 62, 2, 52, 1, 52, 5, 83, 4, 15, 6, 48, 8, 84, 
    2, 99, 5, 52, 7, 24, 1, 44, 6, 24, 8, 42, 4, 40, 3, 37, 0, 54
  };
  const int q1126[] = {
    9, 9, // Number of jobs and machines
    5,  2, 3, 45, 1,  8, 6, 31, 7,  5, 2, 82, 4, 71, 8, 41, 0, 35, 
    6, 28, 5, 64, 1,  6, 7, 61, 2, 95, 8,  5, 4, 65, 3, 71, 0, 10, 
    6, 87, 1, 29, 2, 59, 7, 57, 4, 65, 5,  9, 3, 29, 0, 27, 8, 98, 
    1, 46, 2, 16, 4, 23, 7, 70, 5, 13, 3, 42, 8, 51, 6, 18, 0, 40, 
    2, 55, 1,  3, 4,  6, 8, 50, 6, 60, 3, 91, 7, 21, 5, 38, 0,  1, 
    2, 75, 7, 27, 1,  4, 5, 10, 8, 27, 0, 99, 6, 97, 3, 63, 4,  8, 
    3, 60, 1, 46, 0, 65, 7, 27, 2, 95, 6, 56, 4, 99, 5, 64, 8, 80, 
    0, 61, 5,  9, 6, 96, 7, 75, 1, 43, 2, 43, 4, 81, 3, 39, 8, 44, 
    1, 79, 5, 79, 0, 26, 6, 24, 7, 25, 3,  8, 4, 24, 8,  1, 2, 81
  };
  const int q1127[] = {
    9, 9, // Number of jobs and machines
    5, 68, 6, 67, 2, 99, 4, 30, 8, 61, 7, 29, 1, 74, 3, 80, 0, 20, 
    5, 42, 0, 15, 7,  5, 4, 21, 6,  5, 1, 91, 8, 59, 2,  6, 3, 61, 
    0, 31, 5, 37, 7, 76, 6, 30, 4, 60, 8, 61, 2, 59, 3, 62, 1, 86, 
    6, 17, 2,  4, 7, 32, 3, 28, 4, 32, 1, 93, 8, 54, 0, 70, 5, 82, 
    0, 66, 8, 88, 5, 58, 6, 80, 3, 19, 7, 54, 1, 10, 2, 50, 4, 35, 
    3,  5, 0, 29, 4, 72, 2, 52, 5, 60, 7, 17, 6, 99, 8, 13, 1, 75, 
    1, 19, 5, 84, 7, 88, 6,  9, 0, 93, 2, 13, 4, 28, 8, 65, 3, 82, 
    0, 44, 4, 39, 1, 61, 7, 89, 2, 90, 5, 71, 6, 83, 8, 64, 3, 38, 
    7, 42, 1, 36, 5,  6, 2, 56, 4, 75, 0, 57, 3, 42, 6,  8, 8, 45
  };
  const int q1128[] = {
    9, 9, // Number of jobs and machines
    7, 87, 8, 60, 6,  5, 2, 97, 5, 29, 3, 90, 0, 94, 1, 28, 4, 86, 
    3, 85, 6, 93, 4, 98, 5,  9, 2, 98, 8, 71, 1,  7, 0,  8, 7, 42, 
    2, 78, 0, 26, 1, 32, 5, 93, 3,  7, 8, 23, 7, 51, 6,  4, 4, 66, 
    5, 46, 8, 83, 2,  2, 0, 76, 4, 78, 3, 76, 7,  5, 6, 47, 1,  6, 
    4, 37, 7, 29, 1, 66, 2, 60, 6, 33, 0, 80, 3, 33, 8, 43, 5, 49, 
    1, 48, 7, 99, 5, 92, 6, 18, 4, 42, 2, 54, 3, 68, 8, 12, 0,  8, 
    7, 74, 4,  2, 5,  4, 3, 37, 6,  6, 1, 74, 2, 54, 8, 42, 0, 45, 
    2, 21, 0, 98, 8, 53, 5, 90, 3, 51, 4, 47, 6, 99, 7, 67, 1, 83, 
    1, 96, 6, 88, 7, 76, 8, 27, 3, 90, 0, 57, 2, 12, 4, 71, 5, 48
  };
  const int q1129[] = {
    9, 9, // Number of jobs and machines
    0, 87, 7, 96, 8, 10, 4, 96, 6, 29, 2, 35, 1, 36, 5, 86, 3, 30, 
    5, 50, 3, 98, 1, 57, 0, 87, 7,  1, 2, 31, 6, 14, 8, 76, 4, 23, 
    4, 53, 7, 60, 1, 11, 6, 88, 8, 25, 5, 66, 3, 52, 2, 10, 0, 13, 
    7, 70, 4, 13, 2, 62, 8, 96, 5, 87, 1, 29, 6, 28, 0, 42, 3, 26, 
    2, 18, 4, 63, 8, 71, 5, 26, 1, 82, 6, 33, 7, 42, 0, 24, 3, 67, 
    7, 88, 4, 80, 0, 37, 2, 27, 6, 71, 3, 62, 5, 52, 8, 38, 1, 43, 
    6, 81, 3, 48, 2, 41, 0, 63, 5, 64, 7, 46, 1, 99, 4,  7, 8, 17, 
    2, 63, 6, 13, 4, 28, 3,  4, 1, 29, 8, 55, 0, 40, 7, 89, 5, 91, 
    8, 98, 0, 99, 5, 16, 6, 81, 1, 28, 2, 53, 7, 33, 3, 85, 4, 49
  };
  const int q1130[] = {
    9, 9, // Number of jobs and machines
    4, 64, 6, 60, 0, 36, 7, 71, 3, 48, 5, 24, 2, 50, 8, 41, 1, 97, 
    8, 16, 2, 51, 4,  8, 5, 38, 3, 33, 6, 78, 1, 48, 7, 27, 0, 37, 
    7, 21, 0, 21, 1, 37, 6, 68, 3, 79, 4, 20, 8, 93, 5, 41, 2, 77, 
    7, 28, 1, 68, 8, 47, 6, 84, 0,  6, 4, 91, 5, 80, 2,  6, 3, 71, 
    3, 75, 0, 82, 6,  5, 5, 47, 1, 97, 8,  1, 4, 22, 7, 97, 2, 59, 
    1, 26, 3,  9, 2, 25, 4, 91, 0, 56, 6,  4, 8, 31, 7, 77, 5, 11, 
    2, 23, 4, 79, 6, 96, 8, 62, 5, 80, 7,  1, 1, 23, 3, 34, 0, 74, 
    5, 37, 3, 67, 6, 49, 2, 76, 7, 28, 0, 29, 4, 62, 8, 69, 1, 55, 
    5, 71, 4, 77, 6, 38, 2, 12, 1, 63, 3,  7, 0, 51, 8, 82, 7, 88
  };
  const int q1131[] = {
    9, 9, // Number of jobs and machines
    6, 46, 2, 52, 5, 12, 8, 44, 4, 39, 0,  9, 7, 23, 3, 53, 1, 79, 
    7, 97, 5, 22, 8, 59, 3, 64, 4, 22, 2, 26, 0, 26, 6, 50, 1, 27, 
    0, 48, 8, 61, 5, 57, 6,  3, 4, 86, 1, 33, 7, 46, 2, 42, 3, 41, 
    8,  5, 0, 86, 2, 33, 7, 75, 1, 48, 3, 18, 6, 63, 5, 74, 4, 84, 
    1, 42, 5, 19, 0, 73, 7, 46, 3, 31, 2, 78, 8, 66, 6, 65, 4, 43, 
    5, 43, 2, 74, 1, 17, 4, 78, 7, 19, 6, 26, 0, 47, 3, 37, 8, 13, 
    7, 21, 0, 91, 8, 93, 1, 48, 2,  3, 5, 12, 6, 63, 3, 16, 4, 81, 
    1, 69, 8, 37, 3, 89, 7, 45, 4, 24, 5, 42, 2, 93, 6, 16, 0, 86, 
    4, 15, 3, 84, 2, 14, 6, 79, 8, 57, 1, 24, 7,  1, 0, 92, 5, 65
  };
  const int q1132[] = {
    9, 9, // Number of jobs and machines
    6, 45, 1, 55, 7,  3, 2, 39, 0, 19, 5, 67, 4, 20, 3, 39, 8, 73, 
    4,  8, 3, 85, 5, 61, 7, 64, 2, 81, 8, 89, 6, 55, 1,  6, 0, 87, 
    5,  4, 0, 87, 3, 57, 4, 48, 6, 54, 7, 29, 1, 76, 8, 91, 2, 94, 
    8, 28, 4, 17, 3, 17, 1, 46, 6, 45, 2, 28, 7, 85, 5, 50, 0, 14, 
    7, 63, 2, 89, 5, 42, 3, 38, 8, 25, 1, 45, 0, 37, 4, 60, 6, 31, 
    5, 64, 7, 27, 0, 64, 4,  8, 2, 93, 1, 40, 8, 67, 6, 43, 3, 97, 
    6, 63, 2,  6, 4, 44, 7, 17, 1, 69, 8, 49, 5, 19, 3, 15, 0, 83, 
    2, 76, 1, 97, 3, 49, 0, 47, 8, 19, 5, 22, 6, 66, 7, 30, 4, 19, 
    3, 70, 1, 96, 8, 72, 2,  3, 7, 92, 5, 24, 4, 32, 0, 69, 6, 90
  };
  const int q1133[] = {
    9, 9, // Number of jobs and machines
    8, 81, 6, 20, 5, 18, 4, 82, 0, 88, 3,  1, 1, 57, 7, 29, 2, 31, 
    5, 98, 6, 17, 0, 83, 1, 67, 8,  8, 2, 59, 7, 14, 4,  1, 3, 60, 
    3, 96, 8, 17, 0,  1, 5, 99, 1, 83, 7, 49, 4, 74, 2, 92, 6, 15, 
    6, 37, 4, 61, 1, 25, 0, 14, 8, 31, 2,  8, 3, 50, 7, 51, 5, 69, 
    0, 31, 4, 59, 1,  7, 6, 41, 2, 37, 7, 76, 3,  9, 5, 96, 8, 73, 
    2, 28, 6, 45, 0, 30, 1, 94, 3, 63, 8, 41, 4, 38, 5, 93, 7, 99, 
    6, 63, 1, 53, 2, 96, 0,  7, 5, 11, 7, 16, 8, 88, 4, 31, 3, 93, 
    3, 42, 1, 11, 2, 58, 6, 28, 5, 18, 4, 20, 7, 65, 0, 33, 8, 95, 
    1, 62, 2, 13, 8, 25, 6, 67, 7, 81, 3, 66, 4, 13, 5, 94, 0, 48
  };
  const int q1134[] = {
    9, 9, // Number of jobs and machines
    6, 33, 4, 27, 3,  4, 2,  4, 8, 30, 7, 67, 0, 48, 1, 99, 5, 85, 
    8,  1, 3, 60, 7, 20, 2, 57, 6, 21, 0, 55, 4, 99, 1, 94, 5, 28, 
    6, 12, 8, 84, 2,  1, 3, 51, 0, 82, 4, 40, 7, 58, 1, 27, 5, 39, 
    0, 97, 4, 19, 6, 29, 2, 19, 1, 35, 3, 13, 5, 61, 8, 13, 7, 53, 
    2, 22, 8, 57, 4, 30, 5, 93, 0, 49, 6, 19, 1, 97, 7, 47, 3,  1, 
    0,  6, 3, 99, 1, 43, 6, 15, 8, 78, 5, 95, 7, 83, 2, 76, 4,  2, 
    3, 51, 2, 40, 7, 72, 6, 14, 4, 24, 5, 19, 1, 58, 8, 78, 0, 17, 
    0, 33, 1, 45, 8, 46, 3, 39, 5, 86, 2, 27, 4, 18, 6, 12, 7, 30, 
    1, 29, 8, 34, 3, 12, 0, 74, 2, 64, 5, 34, 7, 87, 6, 64, 4, 62
  };
  const int q1135[] = {
    9, 9, // Number of jobs and machines
    2, 40, 8, 30, 4, 70, 1, 34, 5, 21, 6, 38, 7, 65, 3, 32, 0, 86, 
    0, 78, 4,  4, 2, 69, 1, 97, 3, 58, 5, 19, 7, 31, 8, 57, 6, 31, 
    6, 29, 1, 25, 5, 37, 7, 31, 0,  3, 3, 64, 4,  1, 8, 23, 2, 65, 
    2, 51, 5, 13, 0, 61, 1, 18, 3, 11, 8, 42, 7, 36, 4, 39, 6, 66, 
    6, 21, 5, 20, 0, 74, 7, 40, 1, 80, 2, 22, 8, 77, 3, 12, 4, 11, 
    6, 23, 8, 75, 7, 50, 0, 34, 4, 79, 1, 54, 2, 54, 3, 41, 5, 35, 
    4, 93, 5, 31, 0, 62, 8, 59, 7, 46, 6, 95, 1, 96, 2, 30, 3, 35, 
    3, 57, 8, 46, 7, 24, 4, 37, 1, 92, 2, 40, 0, 25, 6, 31, 5, 59, 
    0, 15, 7, 17, 6, 42, 2, 78, 5, 24, 8,  7, 1, 78, 3, 53, 4, 52
  };
  const int q1136[] = {
    9, 9, // Number of jobs and machines
    0, 11, 6, 71, 5, 21, 3, 42, 1, 53, 7, 28, 2, 71, 4, 46, 8, 82, 
    5, 29, 8, 93, 6, 69, 1, 34, 2, 66, 7, 15, 3, 99, 0, 65, 4, 42, 
    6, 56, 2, 64, 7, 98, 3, 89, 0,  2, 1, 38, 5, 63, 4, 71, 8, 75, 
    6, 58, 0, 85, 3, 38, 2, 90, 4, 62, 7, 55, 1, 68, 5, 77, 8, 75, 
    8, 47, 1, 39, 3, 76, 0, 80, 2, 26, 7, 61, 4, 42, 6, 97, 5, 62, 
    7, 48, 2, 80, 0, 34, 3, 96, 8, 34, 4, 52, 5, 45, 6,  2, 1, 69, 
    7, 49, 4, 55, 8, 76, 2, 88, 3, 32, 5, 87, 6, 80, 1, 99, 0, 10, 
    3, 51, 4, 16, 1,  9, 7, 84, 2, 49, 0, 45, 8, 10, 6, 67, 5, 46, 
    5,  2, 3, 26, 2,  8, 1,  6, 7, 42, 6, 72, 4, 10, 0, 46, 8, 78
  };
  const int q1137[] = {
    9, 9, // Number of jobs and machines
    0, 18, 6, 26, 5, 33, 1, 20, 3, 79, 4, 32, 2, 61, 7, 41, 8, 84, 
    4, 27, 0, 83, 7, 82, 2, 15, 1, 10, 3, 57, 6, 33, 8, 75, 5,  5, 
    8, 14, 5, 17, 6, 80, 4, 72, 1, 90, 7, 46, 2, 33, 0, 24, 3,  1, 
    2, 23, 3, 74, 1, 52, 8, 44, 4, 64, 0, 59, 6, 13, 5, 20, 7, 97, 
    7, 60, 3, 45, 4, 81, 1, 33, 5, 70, 0, 34, 8, 45, 2,  8, 6, 17, 
    6, 37, 2, 74, 8, 87, 0, 28, 5, 31, 7, 55, 3, 93, 1,  8, 4, 69, 
    1, 17, 0,  1, 8, 27, 4,  7, 5, 74, 7, 11, 2, 44, 6, 13, 3, 59, 
    5, 15, 1,  3, 7, 22, 2, 74, 3, 38, 6, 26, 8, 87, 4, 76, 0, 18, 
    1, 75, 6, 19, 2, 13, 8, 64, 0, 11, 4, 91, 7, 64, 3, 95, 5, 32
  };
  const int q1138[] = {
    9, 9, // Number of jobs and machines
    1, 52, 3, 45, 6, 82, 5, 97, 0, 19, 7, 57, 8, 21, 4, 19, 2, 64, 
    8, 57, 4, 50, 3, 86, 5, 53, 0, 46, 7, 81, 6, 79, 2, 91, 1, 79, 
    4, 87, 8, 69, 6, 90, 7, 34, 5, 47, 2, 65, 3, 61, 0, 84, 1, 35, 
    8, 58, 1, 42, 3, 87, 6, 35, 7, 16, 4, 10, 2, 70, 5,  6, 0, 99, 
    5, 34, 2, 17, 1, 52, 6, 61, 4, 38, 7, 99, 8,  8, 3, 93, 0,  7, 
    5,  1, 2, 56, 0, 98, 7, 39, 8, 20, 1, 87, 4, 46, 3, 81, 6, 70, 
    3, 17, 0, 42, 6, 27, 5, 11, 2, 38, 1,  5, 4, 94, 8,  7, 7, 21, 
    2, 74, 0, 66, 3, 48, 5, 46, 6,  8, 4, 42, 7, 58, 1, 32, 8, 34, 
    8,  4, 1, 17, 2, 93, 6, 71, 4, 99, 5,  1, 0, 91, 3,  8, 7, 25
  };
  const int q1139[] = {
    9, 9, // Number of jobs and machines
    0, 97, 7,  3, 2, 83, 4, 96, 1, 54, 5, 38, 3, 56, 6, 35, 8, 55, 
    1, 87, 4, 92, 0, 68, 7, 64, 8, 92, 2, 80, 5, 14, 6, 76, 3, 55, 
    4, 29, 8, 23, 6, 58, 5, 43, 7, 93, 1, 46, 3, 21, 0, 30, 2, 59, 
    2, 91, 6, 61, 7, 43, 8, 90, 0, 64, 5, 17, 1, 92, 3, 82, 4, 65, 
    4, 56, 6, 49, 1, 54, 0, 55, 5, 58, 2, 62, 7, 77, 3,  8, 8, 75, 
    5, 79, 0, 32, 8, 51, 3,  3, 7, 56, 4, 32, 6, 83, 1, 33, 2, 94, 
    2, 34, 5, 70, 1, 94, 6, 93, 7, 13, 8,  7, 3, 85, 4, 37, 0, 14, 
    0, 45, 2, 48, 7, 24, 6, 59, 4, 70, 3, 66, 5, 37, 8, 84, 1, 85, 
    3,  1, 2,  4, 4, 18, 6, 58, 0, 23, 8, 65, 5, 94, 7, 44, 1, 26
  };
  const int q1140[] = {
    9, 9, // Number of jobs and machines
    1,  8, 2,  3, 7, 81, 6, 98, 5, 25, 3, 26, 4, 13, 8, 14, 0, 97, 
    2, 62, 0, 33, 5, 61, 1, 35, 7, 13, 3, 61, 8,  7, 4, 89, 6, 85, 
    1, 23, 7, 93, 5,  3, 8, 55, 2, 78, 4, 34, 0, 66, 6, 89, 3, 13, 
    5, 57, 0, 17, 1, 85, 8, 78, 4, 86, 2, 92, 6, 28, 7, 63, 3, 92, 
    4, 39, 3, 86, 0, 57, 5, 99, 7, 78, 8, 14, 6, 60, 2, 43, 1, 49, 
    2, 77, 7, 35, 6, 73, 5, 99, 1, 55, 4, 52, 8, 39, 0, 76, 3, 65, 
    8, 89, 7, 92, 3, 70, 1, 68, 0, 94, 4, 59, 2, 16, 5, 18, 6, 51, 
    2, 29, 1, 41, 6, 12, 4, 13, 5, 30, 8, 75, 3, 62, 0, 27, 7, 77, 
    6, 62, 0, 61, 1,  6, 5, 22, 2, 25, 8,  6, 3, 81, 4, 48, 7, 65
  };
  const int q1141[] = {
    9, 9, // Number of jobs and machines
    8,  5, 4, 44, 5, 26, 1,  1, 6, 43, 7, 42, 0, 85, 3, 80, 2, 38, 
    6, 45, 3, 22, 7, 71, 1, 74, 0, 21, 4, 21, 2, 41, 5, 78, 8, 11, 
    2, 83, 0, 75, 6, 82, 4,  7, 5, 92, 1, 21, 7, 28, 3, 20, 8, 48, 
    5, 44, 2, 45, 0, 39, 8, 55, 7, 84, 3, 35, 4, 76, 6, 14, 1, 72, 
    7, 21, 0, 25, 2, 61, 8, 46, 1,  8, 5, 73, 3, 69, 4, 99, 6, 17, 
    1, 17, 6, 58, 7, 52, 8, 91, 4, 77, 3, 48, 5, 25, 0, 95, 2, 20, 
    7, 18, 1, 48, 2, 26, 8, 81, 5, 78, 3, 91, 4,  9, 6, 83, 0, 79, 
    5, 28, 6, 68, 1, 32, 4, 30, 3, 56, 8, 61, 2, 62, 0, 54, 7, 45, 
    2,  7, 4, 37, 3, 74, 5, 47, 0, 54, 8, 75, 6, 28, 7, 65, 1, 41
  };
  const int q1142[] = {
    9, 9, // Number of jobs and machines
    6, 21, 5, 64, 0, 82, 1, 74, 7, 36, 8, 39, 3, 57, 2, 66, 4, 64, 
    4, 62, 5, 54, 6, 38, 3, 51, 0, 84, 2, 61, 8,  4, 7, 12, 1,  1, 
    2, 48, 0, 29, 5, 69, 6, 40, 1, 99, 7,  7, 4, 15, 3, 51, 8, 98, 
    2, 78, 6, 21, 5,  1, 7, 26, 0, 13, 4, 60, 3, 17, 1, 14, 8, 25, 
    1, 74, 5, 11, 2,  5, 3, 20, 0, 78, 6, 26, 7, 79, 4, 51, 8, 45, 
    7, 73, 8, 95, 4, 74, 5, 88, 1, 63, 6, 68, 2, 39, 0, 83, 3, 47, 
    2,  1, 6, 12, 0, 93, 3, 29, 4,  7, 5, 98, 1, 56, 8, 93, 7, 38, 
    7, 78, 0, 72, 3,  7, 8, 97, 5, 38, 4, 92, 2, 51, 1, 28, 6, 70, 
    7, 63, 6, 79, 1, 91, 2, 84, 5, 89, 0, 37, 3, 22, 4, 83, 8,  1
  };
  const int q1143[] = {
    9, 9, // Number of jobs and machines
    4, 85, 8, 28, 3, 86, 1, 45, 2, 95, 5, 91, 6, 76, 0, 45, 7, 65, 
    5, 52, 3, 54, 6, 91, 4,  3, 7, 41, 1, 76, 8, 70, 0, 21, 2, 16, 
    0, 12, 8, 76, 5, 50, 3, 97, 4, 43, 7, 38, 2, 98, 1, 82, 6, 74, 
    2, 98, 8, 19, 0, 91, 7, 44, 1,  6, 6, 63, 4, 74, 5,  1, 3,  5, 
    0, 20, 1, 47, 4,  9, 2,  5, 3, 34, 5, 91, 7, 98, 8, 74, 6, 51, 
    5, 96, 0,  3, 8, 99, 7, 30, 6, 37, 1, 48, 2, 29, 3, 34, 4, 26, 
    3,  8, 6, 50, 4,  3, 8, 55, 1, 57, 5,  8, 2, 94, 7, 70, 0, 76, 
    1, 60, 4, 42, 2, 31, 3,  6, 7, 77, 0, 93, 5, 55, 6, 56, 8, 71, 
    3, 10, 2, 41, 1, 39, 0,  2, 7, 87, 6, 42, 5,  2, 4, 73, 8, 84
  };
  const int q1144[] = {
    9, 9, // Number of jobs and machines
    6, 79, 3, 53, 1, 47, 7, 46, 2, 87, 5, 72, 0, 73, 4, 12, 8, 53, 
    5, 36, 6, 58, 7, 12, 4, 18, 3, 81, 2, 16, 0, 83, 8, 33, 1,  6, 
    0, 20, 1, 72, 6, 44, 4, 16, 8, 23, 2, 52, 7, 84, 5, 10, 3, 49, 
    4, 67, 0,  1, 5, 28, 8, 60, 7,  2, 1, 56, 6, 22, 3, 12, 2, 66, 
    4, 64, 0, 40, 7, 22, 2, 44, 1, 87, 5, 56, 6,  4, 8, 90, 3, 43, 
    3, 81, 0, 95, 2, 59, 8, 21, 5, 18, 7, 50, 6, 44, 4, 55, 1, 42, 
    4, 95, 6, 87, 7, 78, 1, 79, 2,  3, 0, 54, 5, 34, 8, 81, 3,  3, 
    4, 35, 7, 41, 8, 24, 3, 87, 6, 65, 0, 77, 2, 42, 1, 73, 5, 79, 
    7, 12, 4, 19, 8, 36, 3, 34, 1, 53, 5, 64, 2, 93, 0, 34, 6, 44
  };
  const int q1145[] = {
    9, 9, // Number of jobs and machines
    1, 64, 2, 62, 6, 17, 7, 37, 3, 48, 0, 68, 4, 10, 5, 41, 8,  1, 
    5, 18, 3, 77, 1, 83, 6, 55, 8, 67, 0, 12, 7, 26, 4, 38, 2, 22, 
    7, 44, 0, 18, 8, 87, 5, 64, 2,  4, 6, 89, 3, 44, 1, 64, 4, 86, 
    5, 71, 7, 81, 0, 70, 6, 22, 8, 30, 3, 68, 4, 52, 1, 36, 2,  7, 
    3, 96, 7, 75, 0, 98, 5, 72, 2, 40, 8, 77, 6, 91, 1, 47, 4, 61, 
    5, 10, 1, 75, 8, 79, 6, 60, 0, 56, 7,  7, 4, 31, 3, 94, 2, 89, 
    0, 53, 6, 47, 8, 90, 2, 63, 1, 69, 3, 22, 4,  8, 5, 66, 7, 43, 
    1, 20, 0, 55, 3, 78, 6, 70, 7, 57, 4, 91, 2, 61, 8,  4, 5, 19, 
    3, 44, 8, 62, 4, 29, 1, 74, 7, 98, 2, 66, 6, 29, 0, 89, 5, 53
  };
  const int q1146[] = {
    9, 9, // Number of jobs and machines
    8, 57, 5, 51, 0, 70, 4, 25, 1,  1, 2, 89, 6, 87, 3, 53, 7, 94, 
    8, 47, 3, 57, 1, 99, 0, 89, 2, 63, 6, 14, 4, 11, 7, 17, 5, 69, 
    8, 56, 3, 90, 2, 82, 5, 20, 7, 17, 6, 10, 1, 89, 0, 95, 4, 79, 
    0,  2, 6, 56, 2,  6, 8, 39, 5, 23, 3, 31, 7, 53, 1, 87, 4, 12, 
    1, 79, 5, 73, 3, 13, 0,  7, 7, 67, 8, 94, 2, 11, 4, 36, 6, 88, 
    4, 84, 7, 38, 0, 65, 3, 48, 2, 16, 1, 69, 6, 81, 8, 16, 5, 81, 
    7, 70, 2, 96, 6,  9, 4, 68, 1, 96, 3, 37, 8, 89, 5,  6, 0,  3, 
    7, 59, 0, 64, 1, 52, 4, 27, 5, 10, 3, 79, 6, 68, 8, 45, 2, 39, 
    6, 19, 2, 74, 7,  7, 4,  4, 8,  9, 5,  9, 3, 32, 0, 96, 1, 45
  };
  const int q1147[] = {
    9, 9, // Number of jobs and machines
    5, 41, 6, 37, 0, 84, 2,  5, 1, 80, 3,  3, 4, 53, 8, 88, 7, 87, 
    4, 34, 1, 23, 5, 57, 2, 61, 3, 74, 0, 38, 8,  3, 6, 14, 7, 48, 
    6,  3, 0, 79, 7, 40, 8, 32, 5, 12, 1, 29, 3, 72, 4, 42, 2, 10, 
    4, 68, 3, 88, 8, 16, 1, 53, 5, 35, 2, 73, 7, 25, 6, 57, 0,  3, 
    2, 33, 0, 84, 7, 30, 6, 91, 8, 66, 3, 27, 1, 14, 5, 43, 4, 85, 
    6, 42, 7, 30, 5,  8, 0,  7, 3, 36, 8, 38, 4, 69, 1, 83, 2, 94, 
    8, 86, 5,  3, 4, 84, 7, 26, 1, 89, 3, 40, 0, 78, 2, 11, 6, 58, 
    7, 61, 8, 49, 1, 56, 5, 76, 4, 16, 0, 65, 2, 29, 3, 37, 6, 26, 
    0, 77, 1, 28, 4, 85, 6, 22, 8, 30, 2, 52, 5, 94, 7, 36, 3, 39
  };
  const int q1148[] = {
    9, 9, // Number of jobs and machines
    0, 93, 2, 72, 3,  3, 7,  3, 8, 39, 5, 46, 6, 48, 4, 53, 1, 19, 
    2, 82, 3, 28, 4, 49, 1, 91, 8, 40, 5, 15, 6, 71, 7, 51, 0,  1, 
    3, 16, 6, 80, 0, 43, 4, 92, 2, 37, 5, 97, 7,  5, 8, 33, 1, 94, 
    8, 85, 3, 12, 4, 64, 0, 84, 6, 89, 5, 66, 7, 96, 2,  9, 1, 51, 
    1, 57, 5, 89, 6, 18, 3, 57, 7, 64, 2, 35, 8, 89, 4, 51, 0, 84, 
    0, 61, 2, 65, 7, 52, 6, 17, 1, 88, 3, 64, 8, 42, 5, 81, 4, 27, 
    3, 89, 2, 34, 5, 93, 7, 16, 8, 82, 1, 70, 6, 80, 4, 65, 0, 57, 
    8, 69, 0,  8, 5, 75, 7, 76, 1, 25, 3, 49, 6, 29, 4, 56, 2, 28, 
    1, 45, 4, 67, 6, 37, 0, 57, 7,  9, 5, 98, 3, 65, 2, 86, 8, 96
  };
  const int q1149[] = {
    9, 9, // Number of jobs and machines
    3, 43, 6, 93, 7, 86, 4, 92, 2, 46, 1,  9, 5, 36, 8, 57, 0, 13, 
    8, 31, 0, 55, 6, 53, 5, 35, 1, 92, 4, 97, 3,  6, 2, 94, 7, 16, 
    5, 22, 2, 40, 6, 42, 7, 80, 0, 44, 4, 50, 3, 23, 8, 84, 1, 98, 
    5, 31, 7, 98, 6, 11, 4, 74, 0, 22, 2, 86, 3, 86, 8, 13, 1, 42, 
    3,  5, 1, 63, 6, 96, 7, 62, 4, 58, 8, 37, 5, 99, 2,  6, 0, 47, 
    5, 75, 3, 14, 1, 47, 0,  8, 7, 73, 2, 37, 8, 54, 6, 11, 4, 36, 
    1, 26, 5, 29, 8, 49, 6, 66, 0,  2, 7, 44, 3, 80, 4, 11, 2, 79, 
    1, 17, 8, 67, 2, 71, 5, 29, 6, 80, 3, 54, 7, 13, 4, 36, 0,  3, 
    7, 87, 6, 37, 4, 82, 3, 94, 5, 98, 8, 41, 2, 74, 0, 54, 1, 23
  };
  const int q1150[] = {
    9, 9, // Number of jobs and machines
    8, 93, 5, 30, 1, 68, 3, 45, 7, 57, 0, 71, 4, 19, 6, 79, 2, 81, 
    8, 65, 7, 84, 2, 33, 6, 57, 1, 25, 3, 26, 4,  7, 5, 85, 0, 41, 
    2, 32, 3, 79, 5, 72, 4, 37, 7, 33, 8, 76, 0, 64, 1, 58, 6, 45, 
    0, 40, 8, 65, 1, 85, 3, 91, 5,  8, 4, 16, 7, 90, 2, 39, 6, 26, 
    6, 53, 0, 73, 7, 31, 2, 43, 3, 30, 5, 37, 4,  4, 8, 43, 1, 74, 
    4, 15, 8, 88, 2,  8, 3, 34, 1, 40, 6, 24, 0,  7, 5, 79, 7, 45, 
    0, 84, 5, 92, 2,  5, 4, 85, 7, 85, 8, 29, 1, 96, 6, 97, 3, 27, 
    3, 54, 0, 13, 2, 44, 4, 97, 8, 65, 6, 64, 1, 58, 7, 67, 5, 70, 
    3, 68, 5, 43, 8, 97, 2, 42, 6, 62, 1, 50, 4, 41, 7,  2, 0, 36
  };
  const int q1151[] = {
    9, 9, // Number of jobs and machines
    4, 77, 8, 68, 7, 41, 1, 71, 6, 24, 3, 49, 5, 34, 2, 11, 0,  9, 
    3, 23, 0, 94, 8, 90, 2, 47, 7, 68, 6, 22, 4, 26, 1, 20, 5, 57, 
    7, 93, 2, 40, 0, 48, 4, 53, 3, 29, 5, 68, 8, 45, 1, 36, 6, 13, 
    8, 74, 0, 10, 5, 84, 4, 38, 1, 41, 3, 88, 6, 77, 7, 17, 2, 28, 
    7, 74, 3, 76, 2, 95, 1, 27, 6, 75, 4, 22, 8, 31, 0, 11, 5, 88, 
    0, 32, 6, 16, 5, 47, 3, 72, 4, 89, 8, 39, 7, 91, 1,  2, 2, 58, 
    1, 75, 0, 45, 2, 63, 5, 64, 3, 15, 6, 19, 7, 10, 4, 63, 8, 10, 
    0,  7, 6, 65, 3, 90, 2, 26, 7, 29, 8, 43, 5, 94, 1,  8, 4, 38, 
    8, 21, 3, 11, 1,  1, 4, 86, 2, 10, 7,  9, 5, 56, 6, 50, 0,  9
  };
  const int q1152[] = {
    9, 9, // Number of jobs and machines
    5, 92, 8, 92, 6, 45, 0, 15, 7, 47, 1, 58, 2, 49, 4, 68, 3, 71, 
    8, 48, 1, 29, 0, 22, 4, 50, 2, 12, 7,  4, 6, 68, 3,  1, 5, 62, 
    7, 90, 2, 42, 3, 46, 0, 55, 8, 53, 6, 69, 1, 43, 4, 24, 5, 91, 
    1, 34, 0, 13, 2, 28, 7, 72, 6, 30, 8, 57, 4, 74, 5, 88, 3, 16, 
    3, 30, 1, 66, 4, 54, 2, 97, 8, 78, 5, 95, 0, 86, 7, 13, 6, 81, 
    8, 78, 4, 16, 0, 34, 1, 99, 5, 28, 3, 37, 7, 87, 6, 73, 2, 70, 
    7, 54, 2, 39, 3, 40, 5, 93, 8, 33, 4, 36, 1, 73, 0,  2, 6, 67, 
    1, 79, 4, 41, 2, 83, 8, 74, 6, 67, 5, 87, 0, 13, 3, 79, 7, 47, 
    0,  5, 5, 99, 3, 67, 6, 98, 8, 10, 1, 13, 2, 49, 4, 59, 7, 47
  };
  const int q1153[] = {
    9, 9, // Number of jobs and machines
    8,  8, 7, 22, 0, 85, 6, 92, 4, 64, 5, 33, 2, 64, 1, 18, 3, 33, 
    6, 89, 5,  1, 3, 20, 7, 11, 4, 25, 0, 81, 1, 31, 2, 24, 8, 86, 
    3,  9, 7, 42, 6, 73, 5,  1, 0, 49, 2, 99, 8, 17, 1, 13, 4, 78, 
    2, 87, 0, 86, 1, 10, 3, 52, 7, 72, 6,  8, 5,  4, 8,  3, 4, 47, 
    2, 95, 0,  6, 6, 91, 4, 45, 1,  2, 8,  8, 5, 51, 3, 17, 7, 35, 
    5, 96, 7, 75, 1, 83, 6, 55, 0, 26, 2, 38, 8,  7, 4, 18, 3, 95, 
    2, 39, 4, 54, 0, 91, 3, 94, 1, 94, 5, 87, 6, 72, 8, 40, 7,  3, 
    5, 82, 0, 62, 1, 37, 7, 99, 8, 21, 4, 77, 2, 98, 3, 96, 6,  2, 
    1, 16, 3, 35, 8,  4, 4, 96, 7,  2, 2, 20, 0, 39, 5, 53, 6, 64
  };
  const int q1154[] = {
    9, 9, // Number of jobs and machines
    2, 65, 7, 28, 8, 53, 1, 45, 5,  4, 3, 96, 0, 40, 4, 15, 6, 35, 
    5, 67, 8, 94, 1, 56, 0, 94, 4, 75, 2, 31, 7, 42, 6, 43, 3, 43, 
    1, 58, 0,  6, 4, 85, 3, 67, 5, 34, 8, 63, 7, 66, 6, 36, 2, 52, 
    4,  5, 2, 14, 7, 10, 3, 53, 0, 98, 8, 20, 5, 26, 1, 88, 6, 69, 
    4, 39, 0, 95, 2, 78, 3, 63, 5, 29, 1, 58, 6, 33, 7, 35, 8, 97, 
    4, 58, 1, 83, 2, 46, 0,  1, 5, 35, 8, 28, 7, 10, 3, 67, 6, 96, 
    1, 63, 2, 58, 4, 42, 6, 68, 0, 80, 3, 66, 8, 18, 5, 58, 7, 52, 
    2, 46, 4, 68, 1, 17, 6, 94, 0, 85, 5, 45, 3, 61, 8, 55, 7, 80, 
    6, 89, 2, 90, 7, 26, 1, 70, 0, 83, 5, 96, 8, 83, 4, 36, 3, 72
  };
  const int q1155[] = {
    9, 9, // Number of jobs and machines
    2, 58, 7, 28, 0, 36, 1, 53, 4, 83, 8, 91, 5,  7, 6, 46, 3, 82, 
    1, 64, 6, 57, 4,  1, 5, 90, 0, 15, 3, 71, 8, 88, 7, 88, 2, 72, 
    1, 85, 5, 94, 0, 46, 2, 28, 6, 36, 7, 57, 4, 89, 8, 50, 3, 28, 
    7, 71, 3, 65, 8,  2, 4, 98, 6,  7, 0, 42, 5, 11, 1,  1, 2, 24, 
    2, 85, 5,  3, 1, 31, 4, 12, 6, 48, 8, 50, 7, 58, 3, 41, 0, 97, 
    2, 73, 3, 40, 4, 27, 5, 58, 1, 42, 7, 26, 8, 77, 0, 38, 6, 87, 
    7, 59, 8, 68, 1, 13, 6, 91, 3, 35, 2,  1, 0,  2, 5, 49, 4, 15, 
    8, 94, 7, 35, 3, 71, 6, 59, 1, 39, 2, 18, 5, 19, 4, 32, 0, 13, 
    2, 19, 1, 19, 3, 98, 0, 19, 4, 12, 8,  7, 7, 37, 5,  1, 6, 88
  };
  const int q1156[] = {
    9, 9, // Number of jobs and machines
    3, 68, 5, 18, 4, 24, 0, 64, 8, 73, 6, 79, 1, 51, 7, 90, 2, 90, 
    3, 79, 5, 22, 4, 25, 8, 50, 1, 53, 2, 59, 0, 50, 7, 74, 6, 82, 
    6, 32, 0, 50, 8, 52, 1,  9, 4, 22, 3, 77, 7, 24, 2, 54, 5, 29, 
    0,  4, 3, 28, 4,  2, 7, 51, 2, 56, 5, 37, 8, 40, 1, 33, 6, 13, 
    0, 64, 1,  7, 2, 53, 6, 93, 8, 46, 7, 49, 4, 78, 5, 89, 3, 83, 
    2, 85, 3, 38, 5, 34, 7, 60, 8, 21, 1, 37, 4, 86, 6, 64, 0, 83, 
    7, 86, 6, 43, 5, 44, 2, 91, 0, 68, 3, 47, 8, 71, 4, 91, 1, 92, 
    3, 28, 2,  7, 0, 56, 6, 34, 4, 29, 8, 78, 5, 53, 1, 55, 7, 70, 
    4, 69, 8, 46, 7, 86, 3,  5, 5, 21, 1, 60, 6, 40, 2, 45, 0,  9
  };
  const int q1157[] = {
    9, 9, // Number of jobs and machines
    4, 47, 7, 98, 3,  3, 0, 74, 2, 49, 6, 76, 8, 25, 1, 51, 5, 15, 
    8, 54, 5,  3, 3, 17, 1, 61, 7,  4, 2, 22, 6, 55, 0, 11, 4, 71, 
    1, 26, 7, 98, 4, 44, 5, 31, 2, 86, 3, 26, 8, 93, 0, 53, 6, 98, 
    4, 12, 5,  5, 6, 28, 7, 99, 0, 76, 2, 87, 8, 51, 1, 99, 3, 20, 
    5, 69, 3, 81, 7, 74, 0, 47, 8,  5, 1, 50, 6, 89, 4, 65, 2,  9, 
    5, 56, 2, 85, 7, 69, 8, 43, 4, 17, 1, 12, 0, 84, 6, 19, 3, 92, 
    5, 25, 3, 30, 6, 46, 0, 60, 2, 80, 8, 30, 1, 73, 7, 52, 4, 14, 
    6, 48, 2, 14, 0, 10, 4, 48, 8, 75, 7, 37, 1,  1, 3, 44, 5, 26, 
    6, 46, 5, 32, 2,  4, 7, 56, 3, 86, 8, 34, 1, 63, 0, 26, 4, 56
  };
  const int q1158[] = {
    9, 9, // Number of jobs and machines
    5, 82, 8, 13, 0, 75, 3, 80, 7, 61, 1, 25, 6, 31, 4,  8, 2, 69, 
    6, 87, 3, 31, 2, 45, 1, 25, 8, 27, 4, 13, 0, 79, 7, 29, 5, 31, 
    0, 87, 8, 90, 3, 99, 4,  5, 7, 84, 2, 33, 1, 62, 5, 32, 6, 24, 
    7, 94, 1, 91, 4, 21, 5, 39, 6, 19, 2, 67, 3, 38, 8, 51, 0, 70, 
    3, 45, 0,  9, 1, 96, 6, 91, 4, 25, 7, 89, 8, 25, 5, 66, 2, 70, 
    4, 49, 0, 44, 7, 81, 1, 63, 6, 57, 5, 51, 8, 58, 3, 93, 2, 34, 
    6, 70, 3, 51, 8, 72, 1, 93, 2, 57, 5, 62, 7, 27, 0, 95, 4,  8, 
    6, 72, 3, 63, 7, 51, 5, 33, 1, 65, 8, 22, 4, 68, 2, 83, 0, 55, 
    8, 19, 7, 56, 6,  3, 5, 70, 3, 44, 2, 91, 0, 42, 4,  1, 1, 76
  };
  const int q1159[] = {
    9, 9, // Number of jobs and machines
    7, 66, 2, 79, 5,  2, 8, 65, 1, 25, 0, 94, 3, 15, 4,  6, 6, 37, 
    3, 72, 2, 14, 0, 36, 6, 34, 4, 52, 7, 64, 8, 66, 1, 52, 5,  5, 
    6, 77, 4, 62, 5, 65, 7, 67, 3, 34, 2, 43, 0, 49, 1, 19, 8, 38, 
    4, 98, 7, 34, 0, 25, 3, 17, 1, 24, 2, 66, 8, 15, 6, 83, 5, 15, 
    7, 21, 3,  8, 4,  8, 5, 20, 6, 81, 2, 24, 1, 20, 0, 82, 8, 96, 
    1,  7, 2,  7, 8,  8, 3, 95, 4, 37, 7, 94, 6, 21, 5, 36, 0, 12, 
    5, 18, 1, 68, 7, 56, 3, 66, 4, 87, 0, 84, 8, 28, 2, 74, 6, 49, 
    8, 41, 4,  4, 0, 58, 6, 26, 7, 96, 2, 18, 1, 65, 5, 75, 3, 25, 
    1, 53, 7, 84, 4, 49, 3, 37, 6, 67, 2, 21, 0, 34, 8, 88, 5, 92
  };
  const int q1160[] = {
    9, 9, // Number of jobs and machines
    5, 25, 7, 92, 8, 38, 3, 38, 6, 95, 1, 82, 0, 27, 4, 27, 2, 23, 
    4, 80, 2,  7, 5, 71, 6, 64, 1, 13, 3, 82, 0, 60, 8, 93, 7, 61, 
    0,  3, 6, 70, 3, 76, 7, 85, 5, 66, 2, 83, 1, 62, 4, 77, 8, 41, 
    4, 13, 7,  6, 3, 83, 8, 11, 2, 47, 5, 48, 6, 35, 0, 53, 1, 41, 
    4, 86, 0, 55, 5, 18, 8, 43, 1, 48, 3, 74, 2, 73, 6, 82, 7, 27, 
    7, 63, 3, 36, 1, 64, 8, 38, 0, 59, 6, 13, 2, 93, 5, 62, 4, 95, 
    2, 72, 6, 14, 7, 22, 0, 45, 4, 28, 5, 36, 1,  6, 8, 92, 3,  1, 
    1, 42, 7, 63, 4, 91, 6, 72, 5, 56, 2, 75, 3, 31, 8,  2, 0, 10, 
    1, 84, 6, 57, 5, 77, 3, 63, 0, 55, 4, 70, 2, 46, 7, 44, 8, 86
  };
  const int q1161[] = {
    9, 9, // Number of jobs and machines
    1, 69, 4, 19, 7, 10, 3, 18, 2, 99, 5, 67, 0, 29, 6, 40, 8, 33, 
    4, 28, 2, 78, 1, 97, 0,  1, 5, 72, 7,  9, 3, 97, 6, 18, 8, 87, 
    3, 41, 4, 79, 7, 92, 0,  2, 6, 59, 2, 87, 5, 26, 1,  3, 8, 45, 
    6, 63, 2, 68, 4, 60, 3, 11, 5, 52, 8, 52, 1, 82, 7, 91, 0,  6, 
    6, 40, 2, 66, 7, 35, 5, 67, 0, 57, 1, 43, 4, 28, 3, 94, 8, 96, 
    5,  3, 1, 69, 4, 17, 3, 77, 2, 13, 6, 65, 7, 85, 8, 51, 0, 15, 
    3, 24, 1, 50, 8, 53, 6, 21, 5,  8, 4, 29, 2, 15, 0, 25, 7, 23, 
    1, 53, 2, 34, 5, 95, 0, 11, 7, 61, 4, 28, 3, 17, 8, 62, 6, 88, 
    7, 26, 2,  4, 3, 64, 1, 93, 8, 33, 5,  3, 6, 92, 4, 63, 0, 24
  };
  const int q1162[] = {
    9, 9, // Number of jobs and machines
    1, 35, 4, 65, 8, 60, 0, 87, 3, 65, 6, 56, 7, 34, 5, 99, 2, 16, 
    5, 72, 6, 69, 1, 67, 2, 60, 0,  7, 7, 80, 3, 88, 4, 44, 8, 34, 
    1, 75, 8, 73, 2, 66, 7, 63, 5, 85, 0, 64, 3, 14, 6, 62, 4, 54, 
    4, 73, 0, 65, 7, 34, 8,  2, 3, 75, 2, 15, 1,  6, 6, 91, 5, 12, 
    5, 36, 6, 58, 0, 65, 7, 64, 4, 26, 2, 27, 3, 61, 8, 24, 1, 86, 
    0, 51, 1, 71, 3, 45, 6, 25, 5, 86, 2, 92, 7, 68, 4, 40, 8, 78, 
    5, 87, 4, 95, 2, 27, 8, 51, 6, 45, 7, 42, 3, 96, 0, 48, 1, 38, 
    7, 49, 5, 29, 1, 64, 2,  9, 4, 12, 8, 68, 3, 82, 0, 56, 6, 34, 
    4, 77, 1, 62, 5, 91, 3, 60, 8, 73, 0, 56, 2,  9, 6, 33, 7, 28
  };
  const int q1163[] = {
    9, 9, // Number of jobs and machines
    0, 97, 8, 78, 4, 52, 7, 60, 3, 43, 1, 94, 6, 58, 5, 12, 2, 26, 
    5, 51, 4, 44, 6, 71, 3, 77, 2, 84, 1, 77, 7, 42, 0, 23, 8, 37, 
    6, 27, 7, 44, 5, 85, 8, 51, 4, 94, 0, 76, 3, 69, 2, 41, 1, 14, 
    2, 29, 0, 67, 6, 75, 1, 82, 7, 82, 3, 61, 8, 49, 5, 42, 4,  8, 
    0, 60, 6, 75, 1, 74, 4, 23, 7, 71, 8, 56, 5,  1, 3, 43, 2, 80, 
    2, 39, 7, 81, 4,  1, 1, 53, 5, 55, 8, 29, 3, 24, 6, 63, 0, 67, 
    5,  6, 6, 71, 0, 59, 2, 85, 3, 30, 1, 24, 4, 60, 8,  7, 7, 72, 
    0, 85, 6, 21, 3, 46, 4, 93, 1, 35, 2, 11, 8, 90, 5, 26, 7, 42, 
    4, 47, 0, 67, 7,  6, 2, 74, 1, 55, 8, 65, 3, 14, 5,  2, 6, 82
  };
  const int q1164[] = {
    9, 9, // Number of jobs and machines
    3, 39, 4,  2, 7, 52, 8, 30, 5, 42, 6, 30, 2, 68, 0, 34, 1, 54, 
    7, 18, 1, 23, 8, 63, 4, 37, 3, 66, 6, 83, 2, 58, 5, 94, 0, 45, 
    1, 89, 3, 11, 7, 82, 2, 38, 4, 69, 0, 37, 8, 27, 5, 89, 6, 95, 
    3, 30, 4, 99, 8, 93, 6, 98, 0, 64, 7, 48, 2, 19, 1, 64, 5, 37, 
    5,  4, 1, 46, 2, 93, 0, 64, 3, 15, 7,  6, 6, 51, 8,  2, 4, 58, 
    7, 75, 6, 29, 2, 73, 5, 42, 8, 95, 3, 80, 0, 87, 4, 64, 1,  3, 
    2, 18, 7, 87, 1, 34, 3, 13, 6, 59, 4, 10, 5, 17, 8, 43, 0,  1, 
    1, 64, 7, 77, 6, 96, 0, 48, 8, 75, 4, 10, 2, 95, 3, 31, 5, 41, 
    7, 29, 4, 76, 8, 90, 3,  7, 2, 12, 1, 60, 6, 40, 0, 36, 5, 15
  };
  const int q1165[] = {
    9, 9, // Number of jobs and machines
    1, 18, 2, 81, 4,  5, 5, 96, 0, 74, 6, 85, 3, 50, 7, 97, 8,  2, 
    6, 10, 7, 54, 1, 62, 8, 49, 3, 46, 0, 56, 2, 39, 4, 87, 5, 96, 
    3, 22, 5, 62, 4,  9, 1, 58, 7, 56, 8, 53, 2, 32, 6, 17, 0, 75, 
    7, 24, 1, 90, 2, 14, 4, 40, 5, 50, 3, 44, 0, 79, 8, 45, 6, 87, 
    1, 53, 7, 52, 2,  4, 6, 59, 5, 29, 3, 47, 8, 10, 4,  3, 0, 12, 
    1, 95, 7, 32, 2, 11, 3,  9, 6, 57, 8, 76, 0, 69, 4, 29, 5,  3, 
    4, 56, 7, 79, 6, 22, 1, 97, 3, 31, 0, 45, 2, 71, 8, 94, 5, 89, 
    0, 95, 5, 77, 1, 55, 6, 87, 7, 56, 4, 88, 2, 49, 3,  4, 8, 97, 
    1, 49, 8,  3, 5, 13, 7, 60, 4, 84, 2, 21, 0, 96, 6,  9, 3, 88
  };
  const int q1166[] = {
    9, 9, // Number of jobs and machines
    7, 12, 6, 94, 8, 51, 5, 28, 0,  1, 1, 91, 2, 32, 3, 47, 4, 79, 
    2, 37, 4, 46, 7, 66, 8, 88, 5, 45, 3, 91, 1, 21, 0, 87, 6, 20, 
    3, 27, 5, 50, 6, 95, 7,  7, 1, 70, 4, 80, 2, 23, 8, 48, 0, 13, 
    3, 38, 4, 79, 7, 12, 6,  6, 0, 93, 2, 96, 8, 94, 5,  5, 1, 36, 
    6, 89, 0, 15, 5, 84, 3, 70, 8, 37, 7, 38, 4, 64, 1, 48, 2, 21, 
    8, 51, 6, 41, 3, 16, 4, 59, 5, 55, 2,  2, 7, 71, 0, 80, 1, 48, 
    3, 36, 7, 18, 0, 38, 2, 99, 4, 97, 6, 61, 1, 60, 8, 94, 5, 81, 
    2, 66, 6, 97, 5, 16, 3, 30, 1, 98, 7, 43, 8, 10, 0, 85, 4, 28, 
    6, 68, 5, 45, 0, 73, 1, 32, 7, 78, 4,  8, 8, 52, 3, 94, 2, 34
  };
  const int q1167[] = {
    9, 9, // Number of jobs and machines
    8, 55, 4, 79, 7, 22, 5,  1, 6, 18, 2, 33, 3, 56, 1, 61, 0, 23, 
    5, 43, 4, 22, 1, 20, 7, 15, 3, 26, 8, 22, 6, 13, 0, 59, 2, 39, 
    7, 70, 1, 75, 4,  5, 5, 46, 6, 49, 0,  7, 2, 95, 3, 95, 8, 27, 
    8, 27, 1, 72, 6, 14, 0, 92, 7,  5, 3, 10, 5, 20, 2, 29, 4, 59, 
    7, 15, 3, 36, 2, 37, 0, 56, 4, 40, 6, 33, 1, 45, 5,  1, 8, 75, 
    7,  5, 2,  6, 4, 99, 8, 58, 5, 97, 0, 13, 1, 76, 6, 61, 3, 77, 
    0, 28, 5, 25, 8, 90, 6, 58, 3, 71, 7, 74, 4, 39, 1, 67, 2, 11, 
    0, 57, 7, 43, 3, 43, 2, 29, 1, 39, 4, 56, 5, 14, 8, 64, 6, 13, 
    2, 93, 0, 69, 3, 71, 1, 50, 7, 65, 5, 85, 8, 96, 6, 49, 4, 94
  };
  const int q1168[] = {
    9, 9, // Number of jobs and machines
    8, 49, 5, 53, 3, 91, 6, 43, 1, 51, 2, 74, 4, 38, 0, 92, 7,  5, 
    4, 86, 0, 68, 7, 79, 5, 60, 6, 74, 1, 24, 2, 35, 3, 81, 8, 34, 
    8, 62, 4, 89, 5, 83, 1, 26, 0,  3, 2,  8, 6, 89, 7,  2, 3, 73, 
    8, 74, 5, 26, 6, 27, 4, 32, 1, 21, 7, 34, 0, 61, 2, 89, 3,  7, 
    8, 39, 7, 68, 0, 73, 2, 85, 4, 96, 6, 84, 3, 45, 1, 85, 5, 40, 
    4,  7, 8, 46, 0, 93, 7, 84, 6, 79, 5,  1, 3, 40, 1, 81, 2, 78, 
    3, 88, 7, 35, 4, 60, 0, 21, 5, 91, 6, 22, 1, 41, 8, 30, 2, 93, 
    8, 21, 7, 64, 0,  9, 1, 89, 3, 71, 6, 36, 2,  5, 4, 19, 5, 79, 
    7, 29, 5, 85, 4, 30, 2, 34, 8, 57, 3, 31, 0, 42, 1, 84, 6, 67
  };
  const int q1169[] = {
    9, 9, // Number of jobs and machines
    8, 30, 1, 67, 4, 36, 0, 93, 6, 59, 7, 25, 2, 48, 3, 63, 5, 94, 
    2, 89, 1, 83, 3, 50, 7, 99, 6, 91, 0, 28, 4, 39, 5, 32, 8, 10, 
    2, 13, 7, 11, 3,  6, 8, 18, 0, 30, 6, 86, 4, 24, 5, 27, 1, 78, 
    5, 24, 2, 32, 8, 54, 0, 72, 7, 70, 1, 40, 3, 11, 6,  6, 4, 75, 
    2, 89, 7, 55, 5, 95, 1, 15, 3, 92, 6,  8, 0,  2, 8, 10, 4, 83, 
    6, 58, 1, 17, 0, 79, 5, 32, 7, 40, 3, 24, 2,  8, 4, 62, 8, 95, 
    0, 68, 7, 51, 5, 95, 1, 49, 2, 63, 3, 62, 8, 49, 4, 92, 6, 77, 
    7, 62, 5, 65, 1, 65, 3, 93, 4, 37, 2, 18, 6, 22, 8, 92, 0, 63, 
    2, 21, 8, 73, 7, 82, 6, 46, 3, 80, 0, 80, 1, 52, 4, 60, 5, 73
  };
  const int q1170[] = {
    9, 9, // Number of jobs and machines
    7, 91, 5, 37, 8,  3, 3, 90, 6, 83, 1, 86, 0,  9, 4, 99, 2, 12, 
    2, 49, 1, 42, 6, 37, 5, 21, 0, 43, 4, 73, 7, 92, 3, 11, 8, 47, 
    7,  7, 5, 99, 3, 55, 6, 26, 0,  2, 2,  7, 8, 68, 4, 57, 1, 22, 
    3, 38, 4, 42, 1, 70, 8, 61, 7, 51, 0, 35, 2, 30, 6, 49, 5, 22, 
    8, 13, 4, 81, 2, 71, 1, 71, 5, 50, 0, 32, 6, 87, 3, 34, 7,  6, 
    4, 30, 5, 51, 2, 32, 6, 98, 8, 95, 1, 38, 0, 32, 7, 87, 3, 36, 
    5, 48, 3, 70, 0, 41, 6, 84, 8, 69, 2,  2, 4,  6, 7, 26, 1, 26, 
    6, 64, 2, 27, 1, 37, 7, 85, 0, 49, 3, 92, 4, 38, 5, 21, 8, 94, 
    8, 55, 5, 75, 0, 15, 1, 69, 7, 12, 3, 94, 6, 34, 2, 54, 4,  3
  };
  const int q1171[] = {
    9, 9, // Number of jobs and machines
    5, 50, 8, 52, 7, 78, 1,  3, 4, 98, 6, 80, 3, 10, 2, 85, 0, 14, 
    0, 46, 7, 13, 5,  5, 4, 39, 3, 74, 6, 20, 2, 70, 8, 15, 1, 30, 
    0, 34, 2, 11, 6, 90, 7, 90, 4, 13, 8, 88, 5,  5, 3, 62, 1, 54, 
    8, 28, 3, 34, 4, 86, 2, 88, 5, 77, 7, 85, 1, 71, 6, 64, 0, 75, 
    4, 28, 5, 27, 2, 66, 7, 50, 6, 48, 1, 42, 8, 71, 3, 21, 0, 21, 
    2, 90, 4, 60, 3, 76, 0, 42, 5, 32, 7, 72, 6, 30, 1, 19, 8,  4, 
    7, 76, 1, 46, 8, 13, 2, 45, 4, 49, 3, 22, 6,  3, 0, 45, 5, 56, 
    8,  5, 3, 20, 4, 50, 1, 44, 7, 58, 5, 63, 2, 38, 0, 53, 6, 96, 
    5, 97, 7, 22, 6, 37, 4, 17, 2, 36, 0, 27, 3, 53, 1, 86, 8, 33
  };
  const int q1172[] = {
    9, 9, // Number of jobs and machines
    3, 18, 8, 62, 5,  6, 7, 59, 1, 52, 0, 34, 2, 59, 4, 10, 6, 40, 
    4, 79, 0, 62, 8, 35, 7, 41, 5, 95, 6, 25, 3, 43, 2, 45, 1,  3, 
    5, 69, 4, 68, 0,  5, 7,  3, 1, 73, 6, 44, 2, 95, 3, 80, 8, 67, 
    6, 12, 3, 38, 4, 60, 1, 79, 7, 43, 8, 54, 0, 87, 2, 50, 5, 97, 
    0, 26, 6, 71, 2, 63, 3, 38, 5, 89, 8, 80, 1, 95, 7,  4, 4, 27, 
    0, 59, 6, 90, 4, 13, 2, 93, 3, 86, 8, 74, 1, 84, 5, 81, 7, 28, 
    0, 11, 2, 61, 5, 39, 4, 70, 1, 82, 3, 37, 6, 79, 7, 10, 8, 51, 
    5, 18, 0, 68, 3, 44, 4, 29, 1, 31, 8, 81, 2, 14, 7, 17, 6, 69, 
    5, 17, 7, 82, 0, 43, 1, 43, 6, 29, 8, 10, 2, 95, 3, 18, 4,  6
  };
  const int q1173[] = {
    9, 9, // Number of jobs and machines
    4, 62, 2, 65, 8, 81, 1, 26, 5, 66, 3, 89, 0, 52, 7, 32, 6,  1, 
    5, 77, 1, 86, 3, 85, 8, 85, 4,  7, 2, 70, 0, 29, 6, 12, 7, 53, 
    0, 63, 8,  7, 2, 34, 7, 39, 5, 26, 6, 41, 1, 65, 3, 32, 4, 81, 
    8, 56, 4, 48, 0, 12, 6, 60, 1, 28, 7, 97, 2, 30, 5,  3, 3, 52, 
    6, 98, 7, 84, 5, 80, 1, 37, 8, 93, 2, 80, 3, 77, 0, 51, 4, 36, 
    4, 79, 3,  4, 2, 92, 6, 59, 8,  4, 0, 42, 5,  2, 7, 29, 1, 23, 
    6, 39, 5, 70, 0, 61, 7,  7, 4, 37, 3, 24, 8, 70, 1, 99, 2, 66, 
    1,  5, 2, 50, 8, 72, 4, 70, 0, 68, 5, 70, 3, 24, 7, 10, 6, 86, 
    6, 29, 5, 87, 1, 26, 3, 46, 7, 45, 0, 73, 4, 39, 8, 64, 2, 43
  };
  const int q1174[] = {
    9, 9, // Number of jobs and machines
    8, 30, 5, 61, 2, 60, 4, 47, 7, 30, 3, 49, 0, 94, 1, 47, 6, 74, 
    1, 69, 5, 59, 3, 10, 7, 77, 6, 17, 2, 88, 8, 47, 4,  1, 0, 16, 
    0, 13, 8, 44, 6, 44, 2, 31, 5, 40, 4, 70, 7,  3, 1, 82, 3, 14, 
    0, 20, 8, 86, 7, 20, 4, 96, 6,  7, 5, 38, 1, 28, 2, 45, 3, 29, 
    0,  6, 2,  8, 3, 62, 6, 92, 7, 70, 1, 23, 5, 87, 8, 97, 4, 87, 
    7, 28, 4,  6, 0, 65, 5, 51, 8, 14, 1, 29, 6, 46, 2, 87, 3, 51, 
    4, 23, 0, 65, 2, 10, 8, 72, 6, 93, 1, 50, 7, 72, 3, 92, 5, 52, 
    8,  7, 5, 86, 4, 63, 1, 87, 6, 52, 7, 31, 0,  6, 3, 61, 2,  5, 
    5, 24, 1, 63, 8, 75, 4, 72, 0, 12, 2, 34, 3, 24, 6, 22, 7, 22
  };
  const int q1175[] = {
    9, 9, // Number of jobs and machines
    4, 42, 1, 60, 3, 77, 7, 33, 5, 62, 6, 46, 2, 95, 0, 68, 8, 36, 
    5, 33, 6, 12, 4, 16, 8, 10, 1, 90, 2, 16, 3, 30, 0,  1, 7, 60, 
    4, 69, 2,  5, 0, 77, 8,  9, 7, 79, 5,  2, 3, 27, 1, 36, 6, 21, 
    3,  2, 8, 22, 2, 66, 1, 76, 4, 45, 0, 28, 5,  3, 6, 50, 7, 45, 
    5, 87, 7, 19, 3, 48, 1,  7, 6, 16, 8, 98, 2, 96, 4,  8, 0, 39, 
    6, 16, 1,  9, 8, 11, 0, 90, 5, 34, 3,  9, 7, 97, 2,  8, 4, 38, 
    0, 94, 5, 22, 6, 42, 8, 25, 7, 20, 2,  2, 1, 91, 4, 42, 3, 84, 
    2, 91, 1, 41, 7, 85, 6, 94, 3, 14, 5, 48, 0, 77, 4, 16, 8, 20, 
    6, 59, 5, 79, 4, 89, 0, 97, 2, 66, 8, 83, 1, 60, 3,  1, 7, 78
  };
  const int q1176[] = {
    9, 9, // Number of jobs and machines
    6, 34, 2, 84, 1, 93, 0, 69, 7, 75, 4, 59, 8, 26, 3, 71, 5, 45, 
    6, 28, 5, 42, 1, 79, 0, 58, 7, 55, 4, 91, 2, 94, 8, 82, 3, 76, 
    2, 90, 6, 46, 5, 96, 4, 14, 0, 70, 1,  1, 3, 49, 8, 75, 7, 18, 
    2, 53, 5, 78, 8, 16, 7, 28, 3, 77, 4, 96, 1, 47, 6,  7, 0, 93, 
    5,  8, 0, 15, 3, 97, 1, 61, 7, 77, 6, 72, 2, 60, 4, 81, 8, 34, 
    0, 30, 1, 72, 8, 88, 3, 29, 2, 96, 7, 17, 5, 65, 4, 52, 6, 41, 
    0, 99, 6, 27, 8, 99, 2, 94, 4, 64, 7, 17, 3, 40, 5, 41, 1, 29, 
    8, 65, 1, 60, 6, 88, 5, 61, 7, 22, 4, 90, 3, 43, 0, 57, 2, 31, 
    7, 13, 0, 62, 6, 47, 5, 38, 2, 71, 8, 22, 3, 36, 1, 51, 4,  2
  };
  const int q1177[] = {
    9, 9, // Number of jobs and machines
    8, 96, 5, 88, 6, 87, 2, 50, 7, 30, 3, 15, 1, 82, 0, 34, 4, 68, 
    4,  7, 1, 82, 0, 46, 2,  7, 8, 18, 3, 69, 5, 85, 7, 83, 6, 14, 
    5, 61, 8, 42, 4, 51, 0, 62, 7, 26, 2, 16, 1, 32, 6, 38, 3, 69, 
    4, 50, 7, 22, 0, 27, 8, 33, 5, 66, 1, 13, 3, 54, 2, 37, 6, 65, 
    8, 42, 6, 35, 7, 45, 3, 76, 5, 35, 2,  3, 4, 32, 0, 40, 1, 50, 
    3, 46, 4, 46, 2, 84, 7, 99, 5, 39, 6,  4, 8, 88, 1, 85, 0, 83, 
    1, 32, 6, 83, 5, 88, 0, 56, 7, 66, 8,  6, 4, 80, 2, 97, 3,  2, 
    4, 96, 0,  9, 8, 71, 1, 69, 3, 22, 2, 82, 5, 48, 7, 39, 6, 69, 
    8,  3, 6, 38, 4, 40, 2, 27, 3, 41, 5, 18, 1, 64, 0, 76, 7, 33
  };
  const int q1178[] = {
    9, 9, // Number of jobs and machines
    0, 63, 2, 57, 4, 26, 1, 27, 3, 44, 5, 65, 6, 57, 7, 35, 8, 97, 
    5, 91, 8, 50, 6, 34, 7, 30, 0, 97, 3, 70, 4, 74, 2, 86, 1, 33, 
    3, 29, 7, 67, 6, 63, 0, 54, 4, 45, 5, 76, 2, 91, 8, 45, 1, 85, 
    4, 66, 5, 43, 0, 29, 7,  5, 1, 11, 6, 26, 2, 45, 8, 53, 3, 81, 
    1, 83, 3, 53, 4, 87, 2, 75, 8, 91, 7, 68, 0, 58, 6, 60, 5,  4, 
    8, 18, 3, 50, 1, 28, 7, 59, 5, 74, 2, 64, 6, 56, 0, 47, 4, 76, 
    0, 41, 8, 16, 7, 44, 5, 83, 4, 21, 3, 20, 6, 14, 1, 92, 2, 67, 
    8, 64, 2, 24, 7, 60, 1, 47, 3, 50, 4, 47, 5,  4, 0, 40, 6, 79, 
    0, 43, 6, 52, 4, 49, 5, 57, 1, 93, 7, 17, 8, 24, 3, 40, 2, 26
  };
  const int q1179[] = {
    9, 9, // Number of jobs and machines
    7, 24, 2, 84, 6, 49, 8,  2, 3, 91, 5, 27, 0, 53, 4, 88, 1, 44, 
    0, 35, 7, 90, 5, 20, 1, 54, 3, 10, 8, 12, 4, 92, 2, 44, 6, 27, 
    2, 10, 1, 46, 3, 12, 8, 91, 7, 53, 5, 18, 0, 19, 4,  7, 6,  7, 
    5, 94, 0, 29, 6, 21, 7, 39, 2, 36, 3, 86, 1, 92, 4, 73, 8, 13, 
    6, 46, 8, 19, 5, 93, 7, 25, 4, 24, 0, 59, 3, 66, 2, 20, 1,  2, 
    2, 31, 4, 97, 1, 28, 8, 63, 7, 21, 3, 40, 6, 94, 5, 98, 0, 85, 
    6, 40, 4, 21, 7, 20, 1, 38, 0, 20, 8, 25, 3, 75, 5, 10, 2, 93, 
    1, 65, 2, 86, 0, 27, 8, 97, 4,  2, 3, 72, 5, 56, 6, 70, 7,  3, 
    2, 59, 5, 99, 7, 71, 0, 60, 1, 25, 6, 18, 8, 73, 3, 37, 4, 35
  };
  const int q1180[] = {
    9, 9, // Number of jobs and machines
    8, 52, 7, 34, 3, 41, 4, 65, 2,  4, 5, 81, 1, 24, 6, 91, 0, 94, 
    6, 96, 2, 67, 0, 47, 1, 31, 7, 48, 5,  2, 4, 81, 8, 24, 3, 73, 
    2, 47, 8, 13, 4, 52, 5, 80, 1, 66, 3, 62, 7, 95, 6, 53, 0, 31, 
    3, 72, 0,  7, 6, 40, 8, 22, 2, 53, 7, 88, 5, 19, 4, 53, 1, 10, 
    4, 59, 7, 63, 0, 76, 6,  3, 5, 87, 2, 44, 3, 17, 1, 19, 8, 31, 
    7, 15, 0, 76, 1, 18, 5, 40, 8, 90, 3, 58, 4, 64, 2, 10, 6, 90, 
    4, 52, 0, 22, 1, 10, 6,  1, 2, 67, 7, 26, 3,  3, 5, 95, 8, 93, 
    6, 19, 2, 14, 4, 83, 1,  9, 0, 10, 5,  5, 3, 83, 8, 87, 7,  3, 
    8, 96, 3, 15, 4, 89, 0, 43, 7, 73, 5, 19, 1, 62, 2, 55, 6, 32
  };
  const int q1181[] = {
    9, 9, // Number of jobs and machines
    5, 22, 8, 93, 6, 91, 1, 23, 7, 57, 2, 34, 3, 18, 0, 91, 4, 94, 
    8, 55, 4, 44, 3, 16, 7, 84, 5, 29, 6, 88, 2, 13, 0, 80, 1, 39, 
    7, 69, 2, 57, 1, 85, 5, 95, 6,  9, 8, 31, 3, 99, 0, 89, 4, 92, 
    6,  4, 5, 10, 4, 79, 0, 19, 1, 67, 7, 10, 2, 23, 8, 32, 3, 84, 
    8, 86, 5, 82, 3, 30, 0, 14, 6, 47, 4, 21, 1, 99, 7, 31, 2, 56, 
    1, 94, 2, 93, 3, 90, 4, 38, 5, 18, 6,  5, 0, 10, 8, 59, 7, 64, 
    6, 92, 1, 34, 2, 45, 0, 75, 3, 99, 8, 84, 5,  6, 4, 33, 7, 24, 
    2, 51, 0, 35, 6, 63, 4, 42, 3, 53, 8,  3, 1,  4, 7, 19, 5, 18, 
    3, 88, 4, 59, 0, 63, 7, 11, 5, 71, 8, 80, 2, 20, 1, 90, 6, 83
  };
  const int q1182[] = {
    9, 9, // Number of jobs and machines
    1, 55, 2, 16, 0, 43, 4, 60, 8, 47, 3, 98, 7, 76, 6, 32, 5, 85, 
    3, 65, 6, 52, 1, 19, 7, 62, 4, 45, 5, 89, 0, 43, 8,  4, 2, 35, 
    6, 74, 8, 72, 1, 48, 5, 77, 0, 21, 4, 62, 3, 36, 2, 30, 7,  5, 
    7, 12, 8, 17, 0,  3, 4, 98, 3, 96, 2, 16, 5, 21, 1, 63, 6,  1, 
    1, 77, 6,  6, 2,  3, 0, 76, 5, 60, 8, 42, 3, 57, 4,  2, 7, 57, 
    8, 32, 1, 15, 5, 59, 2, 41, 3, 12, 4, 72, 6, 95, 0, 65, 7, 82, 
    7, 43, 8, 87, 4, 59, 6, 91, 1, 87, 0, 90, 5, 21, 2, 18, 3, 84, 
    5, 25, 4, 73, 2, 29, 7, 80, 8, 84, 1, 54, 6, 50, 0, 99, 3, 16, 
    5, 89, 3, 68, 6, 85, 8, 81, 1, 48, 2,  7, 0, 57, 7, 31, 4, 48
  };
  const int q1183[] = {
    9, 9, // Number of jobs and machines
    3, 33, 1, 38, 8, 57, 5, 88, 0, 80, 7, 66, 4, 94, 6, 35, 2, 16, 
    2,  4, 6, 86, 7, 49, 8, 56, 5, 61, 4, 80, 0, 79, 1, 62, 3, 85, 
    1, 15, 6, 98, 2, 51, 4, 61, 8, 23, 7,  9, 0, 50, 3, 44, 5, 71, 
    7,  5, 3, 44, 1, 68, 2, 94, 5, 64, 6,  1, 8, 51, 4, 36, 0, 76, 
    5, 35, 6, 62, 7, 71, 2, 63, 3, 75, 8, 41, 4, 34, 1, 44, 0, 93, 
    3, 88, 6, 29, 4, 96, 2, 29, 1, 14, 0, 43, 5, 78, 7,  7, 8, 78, 
    2, 53, 1, 89, 8,  9, 5,  9, 3, 25, 7, 53, 6, 39, 0, 59, 4, 56, 
    1, 12, 3, 28, 7, 54, 4, 28, 6, 11, 2, 75, 8, 12, 5,  1, 0, 77, 
    6, 57, 2, 24, 7, 77, 8,  3, 3, 95, 4,  7, 0, 19, 5, 32, 1, 69
  };
  const int q1184[] = {
    9, 9, // Number of jobs and machines
    7, 14, 2, 45, 8, 13, 4, 90, 0, 69, 3, 25, 5, 87, 6, 46, 1, 95, 
    7, 16, 2, 78, 6, 95, 5, 59, 1, 71, 4, 54, 0, 47, 3, 22, 8, 91, 
    3, 51, 4, 47, 1, 15, 2,  8, 7,  8, 0,  9, 8, 45, 5, 35, 6, 55, 
    5, 41, 6, 35, 7,  4, 0, 64, 2, 38, 4, 85, 8, 67, 3, 44, 1, 66, 
    1, 33, 0, 17, 8, 58, 3, 64, 4, 68, 6, 39, 5, 74, 7, 29, 2, 54, 
    5, 52, 8, 25, 6, 91, 1,  6, 4, 27, 7, 23, 2, 91, 0,  5, 3, 40, 
    3, 46, 6, 44, 7, 50, 5, 85, 2, 17, 4, 83, 1, 24, 0, 51, 8, 33, 
    3, 20, 5, 94, 4, 52, 7, 67, 0, 41, 2, 50, 8, 58, 1, 74, 6, 45, 
    6, 22, 2, 56, 8, 17, 7, 90, 4, 14, 3, 94, 0, 79, 5, 70, 1, 62
  };
  const int q1185[] = {
    9, 9, // Number of jobs and machines
    3, 58, 4,  8, 2, 88, 6, 51, 5, 96, 7, 15, 1, 78, 0, 35, 8, 66, 
    6, 21, 0,  6, 8, 84, 5, 73, 4, 52, 3, 24, 2, 77, 1, 98, 7, 18, 
    6, 72, 0, 66, 5, 97, 3, 71, 7, 45, 2, 18, 1, 71, 4, 94, 8,  2, 
    5, 45, 3,  7, 7, 63, 0, 75, 2, 30, 1,  6, 4, 10, 6, 51, 8, 31, 
    5, 47, 8, 47, 1, 63, 3, 38, 2, 20, 7, 50, 6, 34, 0, 37, 4, 19, 
    0, 81, 8, 54, 3, 53, 7, 99, 4, 78, 6, 22, 1, 11, 5, 93, 2, 97, 
    7,  6, 0, 48, 2, 59, 3, 51, 4, 44, 5, 50, 8, 30, 6, 22, 1, 98, 
    6, 13, 5, 53, 3, 55, 2, 71, 7, 67, 1, 88, 0, 92, 4, 99, 8, 98, 
    5, 65, 0, 53, 4, 37, 7, 86, 8, 25, 1, 99, 3, 26, 6, 50, 2, 56
  };
  const int q1186[] = {
    9, 9, // Number of jobs and machines
    6,  9, 7, 59, 2, 39, 4, 56, 5, 25, 1, 34, 3, 28, 8,  7, 0, 91, 
    8, 71, 0,  7, 5, 48, 3, 97, 1, 85, 4, 32, 7, 80, 2, 39, 6, 51, 
    1, 43, 3, 79, 4, 80, 2, 65, 0, 93, 6, 25, 5, 45, 8, 36, 7, 96, 
    5, 64, 7, 97, 6, 82, 8,  5, 0, 99, 2, 56, 1, 65, 3, 78, 4, 86, 
    2, 81, 1, 37, 0, 50, 6, 86, 8,  3, 4, 30, 7, 15, 3, 15, 5, 56, 
    2, 98, 0, 60, 7, 70, 8, 32, 3,  9, 4, 75, 5, 39, 6, 15, 1, 14, 
    1, 43, 4, 32, 2, 50, 6, 20, 0, 79, 8, 31, 7, 67, 5, 69, 3, 12, 
    8, 53, 5, 78, 1, 28, 6, 14, 3, 14, 0, 59, 2, 58, 7, 83, 4, 64, 
    2,  2, 0, 50, 7, 35, 5, 54, 8, 61, 3, 43, 6, 70, 4, 95, 1, 30
  };
  const int q1187[] = {
    9, 9, // Number of jobs and machines
    4, 15, 1, 86, 5,  9, 3, 32, 0, 39, 8, 66, 7, 27, 6, 89, 2, 57, 
    8, 39, 0, 36, 6, 25, 5, 24, 3, 16, 7, 98, 2, 18, 4, 54, 1,  8, 
    4, 33, 0, 27, 2, 61, 3, 10, 7, 27, 5, 10, 6,  3, 8, 99, 1, 47, 
    6, 86, 3, 81, 7, 88, 0, 77, 5, 32, 4, 66, 8, 91, 2, 51, 1, 29, 
    1, 23, 7, 56, 2, 58, 3, 57, 4, 21, 5, 50, 0, 87, 8, 94, 6, 56, 
    6, 15, 1, 77, 8, 78, 7, 81, 4, 97, 0, 57, 2, 14, 3, 97, 5, 54, 
    4, 97, 2, 55, 5, 63, 7, 93, 6, 85, 0, 48, 8, 47, 1, 93, 3, 48, 
    6, 74, 5, 60, 0, 38, 1, 63, 4, 98, 2, 85, 8, 18, 3, 17, 7, 21, 
    0, 47, 3, 15, 8,  9, 6, 19, 4, 85, 2, 19, 1, 91, 7, 48, 5, 61
  };
  const int q1188[] = {
    9, 9, // Number of jobs and machines
    5, 51, 7,  9, 0, 64, 3, 62, 4, 58, 6, 47, 8, 83, 1, 12, 2, 48, 
    6, 83, 4, 65, 8, 69, 3, 13, 7, 83, 5, 97, 0,  1, 2,  7, 1, 91, 
    4, 18, 3, 13, 2, 14, 5,  3, 8, 65, 0, 45, 1, 10, 7, 66, 6, 31, 
    3, 22, 4, 91, 1, 39, 7, 33, 6, 14, 5, 22, 2, 16, 8, 36, 0, 20, 
    0, 17, 6, 87, 4, 36, 3, 68, 5, 47, 8, 51, 2, 12, 1, 38, 7, 79, 
    6, 17, 3, 18, 2, 39, 0, 24, 4, 92, 7, 88, 8, 42, 1, 24, 5, 94, 
    4, 35, 3,  4, 7, 10, 1, 58, 6, 17, 0, 62, 5, 64, 8, 93, 2, 84, 
    4, 20, 7, 28, 8, 34, 2, 81, 5, 73, 1,  1, 3, 21, 6, 14, 0, 10, 
    7, 42, 0, 70, 5, 10, 1, 98, 6, 68, 3, 29, 4, 51, 2, 70, 8,  4
  };
  const int q1189[] = {
    9, 9, // Number of jobs and machines
    5, 53, 4, 66, 6, 67, 2, 72, 3, 58, 1, 81, 7, 88, 0, 83, 8, 59, 
    6, 22, 5, 76, 3, 89, 2, 92, 0, 58, 8,  6, 7, 35, 1,  8, 4, 55, 
    1, 80, 2, 19, 0, 14, 3, 17, 4, 52, 8, 10, 7,  2, 5, 38, 6, 73, 
    0, 96, 5, 58, 3, 62, 4, 15, 1, 37, 7, 65, 8, 12, 6, 23, 2, 75, 
    3, 92, 8, 40, 7, 97, 4, 18, 5, 54, 2,  6, 6, 47, 1, 83, 0, 59, 
    4, 96, 0, 36, 7, 75, 1, 38, 3, 53, 8, 37, 2, 82, 6,  9, 5, 36, 
    6, 32, 3, 49, 7, 61, 4, 66, 2, 74, 8, 63, 1, 51, 5,  8, 0, 80, 
    2, 92, 5, 39, 3, 94, 0, 37, 4, 19, 1, 10, 8, 98, 7, 15, 6, 80, 
    7, 91, 1, 98, 6, 59, 3, 11, 5, 81, 2, 87, 0, 52, 8, 92, 4, 22
  };
  const int q1190[] = {
    9, 9, // Number of jobs and machines
    8, 12, 2, 70, 1, 50, 0, 18, 7, 20, 5, 23, 4, 34, 3, 14, 6, 86, 
    2,  5, 7, 85, 8, 79, 6, 88, 1, 53, 5, 80, 3, 61, 4, 15, 0, 80, 
    5, 60, 0, 86, 1, 20, 7, 12, 6, 30, 4, 11, 2, 31, 3, 45, 8, 94, 
    1, 42, 7, 71, 3, 74, 5, 91, 0, 36, 4, 76, 2, 61, 8, 12, 6, 57, 
    6, 26, 7, 47, 5, 91, 0, 72, 3, 92, 2, 19, 4, 52, 1, 62, 8,  1, 
    0, 14, 1,  8, 8, 38, 4, 56, 5, 29, 3, 75, 2, 72, 7, 86, 6, 41, 
    5, 43, 4, 76, 2, 88, 1, 21, 3, 75, 7, 47, 0, 19, 8, 28, 6, 13, 
    8, 13, 6,  9, 4, 90, 5,  4, 3, 88, 0, 61, 2, 47, 1, 15, 7, 30, 
    1, 46, 4, 60, 5, 23, 2, 76, 6, 99, 0, 91, 7, 64, 8, 14, 3, 47
  };
  const int q1191[] = {
    9, 9, // Number of jobs and machines
    6, 61, 2, 27, 1, 55, 4, 53, 5, 18, 0, 33, 8, 43, 3, 44, 7, 41, 
    8, 87, 6, 40, 7, 75, 0, 49, 2, 55, 4, 77, 3, 41, 1, 30, 5, 81, 
    8, 62, 2, 52, 1, 23, 5, 97, 7,  6, 6, 61, 3, 28, 0,  6, 4, 21, 
    2, 96, 6, 92, 7, 42, 1, 82, 4, 12, 0, 99, 8, 75, 5, 68, 3, 68, 
    5,  8, 3, 72, 4, 83, 1, 58, 0, 77, 7,  9, 2, 75, 6, 81, 8, 32, 
    4, 44, 0, 94, 8, 53, 3, 79, 7, 40, 2, 30, 1, 81, 6, 60, 5, 34, 
    5, 31, 8, 61, 3, 12, 6, 32, 0, 44, 1, 25, 4, 40, 2, 56, 7, 56, 
    8, 44, 1, 87, 5, 26, 0,  7, 2, 73, 7, 76, 6,  6, 4, 27, 3, 57, 
    1, 79, 3, 20, 4, 78, 6, 84, 0, 87, 2, 13, 8, 28, 7, 78, 5, 18
  };
  const int q1192[] = {
    9, 9, // Number of jobs and machines
    6, 98, 7, 71, 8, 65, 1, 92, 2, 42, 3, 13, 4, 49, 5, 85, 0, 58, 
    1, 40, 3, 63, 4, 80, 0, 48, 2, 95, 6, 59, 8, 77, 7, 97, 5, 52, 
    5, 88, 8, 71, 1, 48, 0,  9, 2, 29, 7,  3, 6, 56, 4, 29, 3, 24, 
    3, 23, 6, 16, 4, 50, 2, 44, 5, 94, 8, 27, 1, 86, 7, 76, 0,  9, 
    7, 48, 5, 36, 4, 56, 2, 11, 1, 31, 3, 70, 6, 71, 0, 65, 8, 68, 
    4, 20, 2, 15, 7, 13, 5, 46, 3, 27, 1, 29, 0, 89, 6, 57, 8, 28, 
    3, 61, 4, 94, 1,  5, 6, 94, 5, 33, 0,  1, 7, 78, 2, 91, 8, 76, 
    2, 89, 1, 44, 7, 95, 6, 69, 5, 68, 4, 83, 0, 53, 8, 70, 3, 14, 
    1, 21, 8, 73, 7, 16, 3, 58, 0, 40, 6, 79, 4, 76, 5, 35, 2, 42
  };
  const int q1193[] = {
    9, 9, // Number of jobs and machines
    4, 85, 6, 47, 1, 57, 0,  1, 5, 60, 2,  9, 7, 68, 3, 99, 8, 90, 
    7, 14, 4, 98, 0, 70, 6, 84, 2, 90, 1, 32, 8, 72, 3, 26, 5, 57, 
    8, 23, 6, 28, 0, 21, 5, 66, 1, 41, 4, 83, 2, 46, 3, 78, 7, 14, 
    0, 18, 3,  2, 4, 77, 2, 58, 1, 32, 5, 23, 7, 35, 6, 94, 8, 20, 
    8, 54, 2, 63, 4, 36, 1, 74, 3, 29, 0, 48, 7,  9, 5, 29, 6, 83, 
    8, 66, 2, 63, 7, 47, 5, 88, 0, 40, 4, 33, 1, 82, 6, 17, 3, 97, 
    2, 96, 1, 39, 0,  4, 6,  4, 5, 46, 3,  5, 7, 52, 4, 11, 8, 44, 
    1, 51, 6, 16, 5, 98, 3, 89, 4, 54, 8, 34, 0,  1, 2, 99, 7, 92, 
    3, 55, 5, 26, 1, 69, 8, 68, 4, 52, 7, 22, 0, 92, 2, 41, 6, 68
  };
  const int q1194[] = {
    9, 9, // Number of jobs and machines
    4, 45, 0, 27, 6, 74, 7, 70, 1, 36, 8, 69, 2, 74, 5, 75, 3, 95, 
    4, 10, 2, 71, 8, 93, 1, 54, 3, 73, 0, 64, 7, 40, 6, 90, 5, 59, 
    6, 63, 5, 83, 7, 23, 1, 90, 3, 47, 4, 85, 0, 18, 2, 58, 8, 97, 
    2, 68, 0, 31, 3, 55, 4, 16, 7,  1, 8, 80, 5, 63, 1, 36, 6, 39, 
    4, 35, 6, 53, 7, 73, 8, 53, 0, 72, 3,  5, 2, 93, 1, 20, 5, 63, 
    2, 77, 5, 65, 6, 25, 0, 94, 7, 77, 8, 27, 3, 90, 4, 95, 1, 51, 
    8, 79, 1, 71, 5, 16, 0, 73, 2, 89, 3, 71, 6, 57, 4, 27, 7, 85, 
    3, 28, 7, 25, 1, 24, 8, 28, 2, 32, 4, 13, 0, 32, 5,  4, 6, 80, 
    3, 48, 5, 92, 1, 95, 0, 34, 7, 46, 2, 23, 6, 44, 4, 20, 8, 17
  };
  const int q1195[] = {
    9, 9, // Number of jobs and machines
    5, 54, 2, 32, 7, 44, 1, 44, 0, 51, 8,  3, 4, 52, 6, 23, 3, 19, 
    3, 89, 7,  7, 4, 53, 6, 87, 5, 72, 2, 48, 0, 29, 1, 92, 8, 30, 
    0,  1, 5, 61, 1, 99, 6, 34, 7, 88, 3,  2, 2, 61, 4, 63, 8, 97, 
    0, 73, 5, 84, 6, 71, 7, 22, 4, 37, 3, 71, 8, 91, 2, 59, 1, 38, 
    4, 35, 3, 85, 7, 89, 1, 30, 0, 39, 8, 85, 6, 59, 2, 49, 5, 58, 
    5, 13, 0,  9, 3, 23, 4, 28, 2, 35, 8, 87, 1,  1, 7, 60, 6, 46, 
    3, 22, 6, 80, 2,  3, 4,  3, 1, 87, 5, 33, 8, 45, 7,  6, 0, 57, 
    5, 56, 7, 72, 1,  6, 3, 27, 2, 26, 6, 18, 0, 46, 4, 39, 8, 55, 
    7, 18, 4,  8, 8,  1, 6,  6, 0, 60, 1, 81, 2,  5, 3, 94, 5, 87
  };
  const int q1196[] = {
    9, 9, // Number of jobs and machines
    2, 71, 0, 81, 5, 76, 6, 75, 1,  9, 4, 22, 3, 65, 7, 45, 8,  8, 
    7, 84, 0,  9, 5, 27, 3, 46, 6, 14, 4, 10, 8, 78, 2, 17, 1,  5, 
    8, 64, 7, 42, 5,  7, 4, 68, 6, 25, 0, 86, 1, 78, 2, 48, 3, 87, 
    1, 21, 6, 15, 2, 44, 8, 56, 5, 65, 3, 79, 4, 40, 0, 24, 7, 15, 
    3, 70, 0,  1, 1, 62, 6, 52, 2, 43, 7, 48, 8, 20, 5, 74, 4, 60, 
    5, 14, 0, 94, 2,  4, 4, 73, 3,  2, 7, 92, 8, 40, 1, 91, 6, 17, 
    6, 35, 1, 60, 5, 74, 7, 48, 3, 24, 2, 73, 4, 50, 8, 43, 0, 11, 
    2, 27, 7, 29, 6, 42, 1, 23, 5, 66, 0, 21, 8, 88, 3, 88, 4, 12, 
    4, 28, 7, 40, 8, 91, 1, 77, 6, 58, 0, 24, 3, 36, 2, 16, 5, 91
  };
  const int q1197[] = {
    9, 9, // Number of jobs and machines
    7, 23, 4, 74, 3, 78, 2, 50, 0, 30, 8, 39, 6, 62, 1, 50, 5,  5, 
    1, 15, 3, 88, 5, 95, 0, 46, 8, 70, 4, 39, 7, 46, 2, 76, 6, 57, 
    5, 39, 6, 62, 0, 31, 7, 54, 8, 88, 1, 97, 2, 98, 3, 18, 4,  7, 
    5, 64, 8, 40, 1, 22, 6, 40, 7,  1, 0, 16, 2, 77, 4, 27, 3, 90, 
    1, 58, 5, 14, 7, 76, 0,  2, 3, 51, 2, 81, 6,  3, 8, 67, 4, 91, 
    4, 14, 2, 59, 5, 57, 0, 63, 7, 17, 8, 34, 6, 99, 3, 50, 1, 31, 
    7, 25, 8, 64, 0, 98, 3, 98, 1, 68, 2, 53, 5, 50, 6, 29, 4, 78, 
    1, 75, 5, 78, 2, 18, 7, 83, 4, 44, 0,  7, 8, 82, 3, 41, 6, 41, 
    1, 45, 3, 95, 2, 72, 7, 66, 0, 60, 5, 21, 4, 42, 6, 36, 8, 79
  };
  const int q1198[] = {
    9, 9, // Number of jobs and machines
    8, 40, 7, 40, 2, 93, 3, 71, 4, 12, 1, 57, 5, 34, 6, 50, 0, 76, 
    7, 68, 5, 51, 1, 36, 6, 14, 8, 11, 3, 33, 4, 30, 2, 58, 0, 20, 
    3, 18, 4, 47, 1, 49, 7, 83, 8, 16, 5, 80, 0, 39, 2, 14, 6, 88, 
    7, 32, 8, 83, 1, 23, 3, 56, 4, 52, 6, 40, 2, 64, 5,  2, 0, 54, 
    4, 56, 2,  4, 0, 60, 3, 88, 8, 30, 6,  6, 5, 15, 7, 57, 1, 92, 
    1, 51, 8, 43, 5, 82, 2, 95, 4,  1, 7, 68, 6, 56, 3, 51, 0, 11, 
    5, 27, 8, 63, 6, 78, 7, 74, 4, 71, 0, 49, 3, 97, 1, 73, 2, 95, 
    5, 40, 3, 51, 7, 66, 4, 42, 6, 59, 0, 33, 2, 41, 8, 91, 1, 79, 
    1, 44, 8, 77, 6, 15, 5,  8, 0, 33, 2, 21, 7, 80, 4, 56, 3, 58
  };
  const int q1199[] = {
    9, 9, // Number of jobs and machines
    5,  8, 2, 91, 4, 78, 0, 44, 8, 24, 1, 84, 7, 31, 3, 88, 6,  7, 
    7, 64, 8, 39, 6, 49, 0, 32, 2, 36, 1, 48, 3, 93, 5, 16, 4, 51, 
    5, 94, 3, 73, 7, 31, 4,  7, 0,  7, 8, 55, 1, 83, 2, 78, 6, 86, 
    2, 32, 5, 85, 1, 88, 8, 37, 6, 91, 3, 14, 0, 18, 4, 11, 7, 17, 
    0, 35, 6, 98, 5, 52, 4, 83, 2, 87, 8, 44, 1, 46, 7, 16, 3, 73, 
    4, 47, 5, 47, 6, 70, 0, 32, 3, 69, 7,  8, 1,  7, 8, 63, 2, 89, 
    1, 63, 5, 64, 7, 89, 8, 25, 3, 28, 4, 78, 0, 88, 2, 42, 6, 36, 
    3, 67, 5, 81, 7,  3, 1, 49, 4,  2, 0, 73, 8, 49, 2, 32, 6, 69, 
    2, 81, 7, 16, 3, 78, 0, 27, 6, 25, 5, 52, 8, 67, 4, 74, 1, 99
  };
  const int q1200[] = {
    9, 9, // Number of jobs and machines
    5, 32, 4, 98, 6, 90, 8, 98, 3, 82, 7, 54, 2, 99, 1, 24, 0, 34, 
    1, 54, 2, 10, 4, 88, 0, 19, 6, 62, 5, 16, 8, 10, 7, 13, 3, 44, 
    2, 75, 4, 99, 3, 49, 5, 30, 6, 37, 1, 61, 8, 27, 7,  4, 0,  2, 
    6, 86, 0, 48, 5, 72, 3, 34, 8, 16, 2, 15, 4, 82, 1, 35, 7, 97, 
    4, 21, 7, 87, 8, 71, 3, 40, 2, 25, 5, 57, 6, 67, 1, 93, 0, 25, 
    0, 78, 4, 38, 7,  3, 1, 88, 8,  9, 6, 37, 2, 79, 5, 77, 3, 74, 
    6, 34, 7, 37, 4, 83, 0, 92, 5, 96, 8, 43, 3, 59, 2, 72, 1, 96, 
    8, 17, 5, 96, 2, 13, 7, 76, 1, 59, 0, 58, 4, 79, 6, 21, 3, 83, 
    2, 65, 3, 17, 1, 34, 4,  9, 7, 51, 5, 84, 0, 52, 6, 98, 8, 25
  };
  const int q1201[] = {
    9, 9, // Number of jobs and machines
    8, 23, 7, 44, 0, 75, 6, 43, 2, 72, 3, 34, 4, 15, 5, 32, 1, 67, 
    3, 49, 2, 41, 7, 53, 1, 70, 4, 35, 0, 33, 6, 89, 5, 27, 8, 61, 
    7, 41, 5, 74, 6, 13, 8,  7, 1, 31, 4,  5, 2, 54, 3, 97, 0, 70, 
    5, 51, 8, 73, 0, 78, 6, 41, 2, 96, 3, 32, 7, 33, 1, 26, 4, 75, 
    4, 53, 3, 58, 5,  4, 2, 86, 1, 47, 8,  6, 6, 65, 7, 85, 0, 38, 
    5, 82, 6, 22, 0, 30, 4, 99, 2, 13, 7, 42, 3, 32, 1, 20, 8, 45, 
    6, 83, 8,  7, 0, 50, 5, 74, 7, 13, 2, 78, 4,  4, 1, 23, 3, 87, 
    0, 29, 3, 52, 5, 48, 6, 32, 1,  6, 2, 58, 7, 43, 4,  8, 8, 72, 
    5, 63, 7, 46, 1, 29, 4, 78, 3, 47, 2, 28, 8, 27, 0, 67, 6, 41
  };
  const int q1202[] = {
    9, 9, // Number of jobs and machines
    0, 91, 5, 70, 1, 98, 4, 47, 6, 51, 3, 51, 8, 14, 7, 77, 2, 55, 
    1, 96, 0, 99, 8, 28, 7, 53, 5, 60, 3, 44, 2, 87, 6, 78, 4, 73, 
    7, 49, 1,  5, 2, 77, 4, 76, 6, 40, 5, 42, 3, 78, 0, 31, 8, 26, 
    5, 20, 8,  6, 7, 75, 3, 54, 2, 59, 6, 77, 0, 68, 1, 39, 4, 16, 
    6, 20, 5, 59, 2,  8, 7, 62, 4, 25, 0, 95, 8, 46, 1, 20, 3, 51, 
    0, 67, 1, 65, 6, 87, 8, 17, 2, 15, 5, 79, 4, 94, 3, 36, 7, 98, 
    0,  8, 7, 14, 8,  1, 2, 38, 6,  1, 5, 47, 3, 56, 1, 36, 4, 79, 
    5, 72, 8, 74, 2, 18, 4, 93, 6, 10, 1, 98, 0, 71, 7, 75, 3, 55, 
    1, 23, 3, 68, 2, 39, 7, 65, 5, 57, 6, 82, 4, 77, 0, 87, 8, 87
  };
  const int q1203[] = {
    9, 9, // Number of jobs and machines
    0, 46, 7,  9, 2, 45, 6, 71, 8, 17, 3, 95, 4, 25, 5, 60, 1, 13, 
    2, 22, 5, 10, 4, 25, 6, 66, 3, 38, 7, 81, 1, 76, 8, 37, 0, 63, 
    4, 89, 7, 53, 1, 55, 2, 18, 0, 82, 6, 83, 5, 82, 3, 22, 8, 37, 
    1, 23, 2, 78, 6, 26, 7, 13, 0, 81, 8, 24, 3, 64, 4, 89, 5, 91, 
    1, 22, 8,  9, 5, 93, 2,  4, 4, 59, 0, 40, 6,  5, 7, 79, 3, 62, 
    1, 58, 7, 73, 2, 32, 6, 42, 0, 57, 8, 51, 3, 10, 4, 56, 5, 10, 
    8, 39, 1, 43, 0, 68, 3, 65, 4, 46, 6, 20, 5, 25, 7, 32, 2, 60, 
    0, 69, 1, 89, 3, 29, 7, 90, 8, 24, 4, 62, 2, 88, 6, 73, 5, 29, 
    7, 37, 5, 15, 3, 99, 2,  2, 8,  3, 1, 15, 4, 33, 0, 94, 6, 58
  };
  const int q1204[] = {
    9, 9, // Number of jobs and machines
    5, 55, 1, 36, 7, 10, 6, 35, 8, 29, 0, 25, 3, 89, 2, 57, 4, 34, 
    3, 30, 1, 36, 7,  1, 2, 47, 5, 42, 8, 17, 6, 82, 4, 10, 0, 21, 
    6, 94, 8, 47, 1, 49, 7, 73, 3, 56, 0, 27, 5, 59, 4, 93, 2, 86, 
    7, 72, 5, 12, 8, 11, 3, 10, 6,  2, 4, 17, 0, 19, 2, 63, 1, 70, 
    3, 47, 8, 99, 7, 98, 4, 46, 1, 30, 0, 80, 2,  3, 5, 74, 6, 97, 
    8, 33, 6, 38, 5, 56, 2, 46, 7, 93, 0, 67, 3, 24, 4, 28, 1, 82, 
    1, 36, 3, 69, 4, 33, 5, 43, 7, 81, 0, 32, 6,  8, 8, 65, 2, 82, 
    8, 85, 0, 87, 6, 67, 4,  2, 3, 42, 2,  1, 7,  9, 5, 68, 1, 20, 
    5,  5, 6, 99, 1, 75, 7, 74, 8, 27, 4, 45, 3, 16, 0, 64, 2, 65
  };
  const int q1205[] = {
    9, 9, // Number of jobs and machines
    6, 53, 3, 15, 8, 49, 2, 57, 5, 77, 7, 36, 4, 81, 1, 76, 0, 19, 
    3, 98, 6,  6, 5, 43, 4, 10, 7, 73, 1, 92, 8, 20, 0,  7, 2, 62, 
    0, 19, 6, 74, 2, 36, 5,  7, 4, 99, 3, 60, 8, 70, 7, 80, 1, 15, 
    5, 66, 8,  1, 2, 17, 7, 53, 3, 36, 6, 20, 4, 16, 1, 32, 0, 35, 
    1, 13, 5, 98, 8, 84, 7, 98, 2, 91, 3, 43, 4, 41, 6, 41, 0, 75, 
    0, 83, 2, 95, 5, 58, 3, 70, 4, 91, 7, 88, 8, 83, 6, 29, 1, 16, 
    4, 49, 0, 25, 6, 46, 1,  8, 2, 99, 8, 52, 7, 45, 3, 79, 5, 48, 
    7,  5, 2, 55, 0, 53, 1, 62, 8, 60, 6, 47, 5, 28, 3, 76, 4, 37, 
    4, 86, 1, 69, 2, 66, 6, 91, 5, 18, 8, 94, 7, 56, 3, 62, 0, 44
  };
  const int q1206[] = {
    9, 9, // Number of jobs and machines
    7, 68, 2, 30, 4,  6, 1, 66, 0, 10, 6, 57, 5, 75, 8, 73, 3, 95, 
    7, 57, 3, 70, 0, 28, 2, 94, 5, 50, 1, 77, 8, 60, 6, 66, 4, 15, 
    4, 59, 2, 21, 7, 77, 3, 88, 5, 15, 1, 29, 0, 30, 8, 68, 6, 39, 
    3, 74, 4, 33, 1, 74, 0, 93, 6, 10, 5, 95, 2, 41, 7, 64, 8, 85, 
    6, 37, 0, 13, 1, 81, 7, 45, 2, 51, 5, 94, 8,  9, 3, 57, 4, 25, 
    5,  1, 4, 98, 2, 26, 3, 24, 8, 42, 6, 18, 1, 35, 7, 25, 0, 37, 
    7, 48, 8, 88, 0, 43, 6, 55, 2, 60, 4, 63, 1,  3, 5, 67, 3, 32, 
    0, 64, 4, 89, 7,  2, 6, 58, 2, 64, 1, 79, 8,  7, 5, 13, 3, 80, 
    8, 34, 0, 30, 1, 50, 5, 45, 7,  7, 6, 89, 2, 78, 4, 15, 3, 85
  };
  const int q1207[] = {
    9, 9, // Number of jobs and machines
    6, 66, 4, 63, 5, 65, 7, 57, 3, 13, 2, 18, 1, 92, 0, 57, 8, 75, 
    7,  3, 4, 61, 2, 84, 8, 97, 1, 67, 3, 84, 5, 52, 0,  6, 6,  3, 
    4, 72, 5, 68, 8,  2, 1, 66, 2, 38, 7, 34, 0, 80, 6, 28, 3, 75, 
    7, 17, 6, 56, 4, 12, 5, 97, 3, 11, 8, 67, 1, 18, 2, 29, 0, 12, 
    7, 76, 2, 63, 5, 94, 1, 12, 8, 87, 6, 29, 0, 91, 3, 27, 4, 88, 
    2, 81, 4, 30, 3, 81, 7, 46, 0, 28, 1, 84, 8, 58, 6, 66, 5, 69, 
    7, 57, 2, 15, 6, 68, 3, 97, 5,  6, 4, 76, 0, 58, 1, 90, 8, 97, 
    5, 50, 8, 16, 1, 21, 0, 73, 7, 49, 2, 94, 4,  4, 6, 28, 3, 89, 
    4, 25, 5, 40, 1, 77, 0, 80, 8, 80, 7, 16, 2, 58, 6, 72, 3, 42
  };
  const int q1208[] = {
    9, 9, // Number of jobs and machines
    4, 50, 7, 75, 2, 75, 1, 78, 8, 18, 3, 82, 0,  5, 5, 37, 6, 83, 
    5, 79, 2, 50, 8, 21, 7, 20, 6, 41, 4, 94, 3, 56, 1,  5, 0, 13, 
    3, 17, 1, 93, 4, 27, 5, 53, 0, 21, 7, 88, 2, 78, 8, 74, 6, 89, 
    7, 82, 4, 69, 5, 71, 6, 71, 1, 33, 3, 93, 2, 63, 0, 22, 8, 10, 
    6,  7, 0, 33, 5, 47, 7,  1, 2, 55, 1, 76, 3, 14, 4, 17, 8, 41, 
    6, 27, 1, 96, 0, 94, 2, 11, 5, 58, 7, 25, 3, 16, 8, 89, 4, 45, 
    7, 43, 6, 87, 3, 79, 2, 84, 5, 83, 1, 82, 0, 85, 4, 14, 8, 75, 
    5, 11, 3, 67, 0, 62, 8, 15, 2, 72, 7, 26, 1, 33, 4, 35, 6,  1, 
    8, 89, 0, 41, 1,  2, 6, 22, 2, 47, 5, 57, 4,  7, 3, 43, 7, 58
  };
  const int q1209[] = {
    9, 9, // Number of jobs and machines
    4, 28, 5, 23, 0, 54, 2, 84, 1, 47, 3, 13, 7, 29, 6, 66, 8, 55, 
    0, 13, 4,  5, 2, 71, 8, 65, 7, 84, 6, 61, 3, 56, 5, 57, 1, 79, 
    6, 68, 0, 53, 3, 43, 4, 47, 5, 21, 1, 85, 2, 83, 8, 29, 7,  1, 
    2, 98, 4, 46, 0, 20, 5, 70, 7, 99, 8, 44, 3, 31, 6, 41, 1, 13, 
    8, 31, 1, 12, 0, 96, 6, 57, 3, 91, 5, 58, 2, 80, 7, 69, 4, 99, 
    3, 94, 5, 68, 1, 82, 2, 90, 0, 16, 4, 27, 6, 91, 8, 60, 7, 35, 
    7,  4, 1, 50, 4, 38, 6, 71, 2, 44, 3,  5, 8, 86, 0, 45, 5, 37, 
    7, 36, 1, 29, 5, 59, 6, 39, 8, 43, 0, 87, 4, 63, 2, 66, 3, 64, 
    8, 39, 5, 34, 2, 83, 6, 28, 4, 65, 0, 76, 3, 56, 7, 86, 1, 85
  };
  const int q1210[] = {
    9, 9, // Number of jobs and machines
    7, 97, 2, 37, 5,  3, 4, 72, 0, 30, 8,  1, 3, 46, 1, 63, 6, 77, 
    4, 44, 8, 73, 5, 78, 7, 90, 2, 51, 6, 71, 3,  5, 1, 80, 0, 51, 
    0, 65, 2,  5, 4, 27, 3, 87, 5, 97, 7, 16, 8, 53, 6, 36, 1, 98, 
    8, 86, 2, 95, 3, 44, 6, 56, 0, 68, 5,  5, 4, 15, 7, 25, 1, 55, 
    3, 34, 0,  5, 4, 21, 1, 13, 6, 67, 5, 18, 8, 52, 2, 40, 7, 43, 
    0, 85, 1, 79, 3, 33, 4, 58, 6, 46, 2, 70, 7, 61, 5, 48, 8, 32, 
    0, 37, 4, 86, 5, 34, 7, 83, 8, 35, 1, 98, 6, 22, 3, 32, 2, 34, 
    3, 83, 2, 76, 4, 57, 1, 67, 8, 42, 5, 85, 6, 98, 7, 56, 0, 78, 
    2, 39, 6, 46, 1,  1, 8, 95, 3, 20, 7, 94, 4, 65, 0, 65, 5, 65
  };
  const int q1211[] = {
    9, 9, // Number of jobs and machines
    5, 63, 0, 55, 7, 52, 4, 36, 3, 58, 2, 31, 8, 54, 6, 91, 1, 80, 
    3, 13, 8,  6, 5, 15, 2, 95, 0, 80, 1, 77, 4, 74, 6, 52, 7, 65, 
    8, 13, 6, 86, 4, 23, 3, 88, 7, 12, 0, 97, 1, 84, 5, 52, 2, 37, 
    6, 65, 3, 26, 1, 87, 4, 64, 2,  9, 8, 98, 5, 97, 0,  9, 7, 42, 
    1, 71, 0, 52, 4,  5, 5, 14, 6, 31, 8, 97, 7, 37, 2, 29, 3, 59, 
    6, 88, 7, 66, 5, 41, 2, 51, 3, 96, 1, 86, 0, 91, 8, 56, 4, 66, 
    6, 45, 1, 12, 2, 90, 3,  9, 0, 36, 8, 60, 4,  8, 5, 19, 7, 73, 
    6, 41, 2, 46, 1, 20, 0, 18, 8, 90, 4, 79, 5, 34, 7, 72, 3, 61, 
    3, 65, 4,  4, 8, 69, 2, 72, 7, 85, 0, 89, 5, 58, 6, 63, 1, 53
  };
  const int q1212[] = {
    9, 9, // Number of jobs and machines
    3, 14, 7, 46, 8, 78, 4, 70, 6, 98, 1, 52, 5, 92, 2, 81, 0, 77, 
    2, 12, 7, 66, 1, 64, 5, 62, 4, 35, 0, 85, 8, 29, 6, 77, 3, 55, 
    0, 98, 8, 74, 3,  2, 7, 74, 6, 46, 2, 71, 4, 80, 1, 69, 5, 88, 
    3, 56, 8,  5, 4, 12, 0, 61, 5, 66, 2, 69, 7, 71, 1, 13, 6, 99, 
    7,  3, 2,  7, 3, 26, 1, 64, 6, 75, 4, 93, 8,  3, 5, 69, 0, 74, 
    6, 80, 2, 49, 1, 56, 5, 45, 7, 73, 8, 44, 4, 50, 0, 79, 3, 61, 
    7, 52, 0, 99, 8,  2, 2, 93, 6, 20, 4, 96, 1, 53, 3, 82, 5, 57, 
    2, 56, 7,  5, 3, 62, 1, 42, 0, 43, 4,  9, 8, 37, 6, 30, 5, 57, 
    1, 48, 5,  2, 8, 53, 2, 46, 0, 67, 4, 26, 3,  3, 6,  9, 7, 84
  };
  const int q1213[] = {
    9, 9, // Number of jobs and machines
    0, 55, 8,  2, 3, 92, 2, 29, 1, 24, 5, 66, 7, 87, 6, 16, 4, 13, 
    4,  7, 5, 84, 1, 73, 7, 47, 2, 56, 6, 26, 8, 88, 3, 83, 0, 93, 
    1, 58, 7, 79, 8, 55, 0, 71, 6, 18, 5,  2, 4,  4, 2, 82, 3, 54, 
    4, 42, 1, 85, 3, 81, 7, 84, 8, 58, 6, 11, 0, 95, 2, 46, 5, 93, 
    0,  3, 7, 84, 3, 35, 2, 10, 5, 64, 4, 72, 6, 22, 1, 71, 8, 55, 
    3, 45, 8, 18, 6, 65, 4, 30, 0,  7, 1, 30, 7, 92, 5, 54, 2, 91, 
    0, 38, 2, 45, 7, 17, 3, 55, 6, 53, 5, 64, 4, 95, 1,  4, 8, 47, 
    4, 60, 3, 13, 2, 46, 5, 67, 0,  4, 1, 11, 7, 97, 8, 15, 6, 16, 
    5, 69, 4, 73, 1, 71, 0, 95, 8, 29, 3, 43, 2, 69, 7, 77, 6, 28
  };
  const int q1214[] = {
    9, 9, // Number of jobs and machines
    7,  2, 0, 99, 3, 34, 6, 83, 1, 94, 2, 78, 5, 35, 4, 45, 8, 18, 
    5, 24, 3, 76, 0, 58, 1,  2, 7, 35, 4, 35, 8, 47, 2, 55, 6, 58, 
    4, 50, 2,  1, 5, 98, 3, 38, 6, 27, 0, 62, 8, 11, 7, 33, 1, 82, 
    0, 49, 3,  2, 8, 30, 4, 73, 1, 78, 2, 46, 6, 36, 5, 56, 7,  1, 
    1, 65, 4, 21, 8, 80, 7, 27, 3, 15, 2, 85, 0, 50, 6, 13, 5,  7, 
    3, 87, 2, 67, 8, 92, 4, 61, 0, 42, 5, 13, 1,  7, 6, 70, 7, 95, 
    7, 62, 3, 62, 1, 18, 0, 86, 2, 73, 4, 91, 8, 61, 6, 49, 5,  9, 
    6, 97, 2, 17, 5, 35, 1, 94, 3, 78, 4,  9, 0, 63, 8, 63, 7, 29, 
    1, 78, 8, 95, 0,  9, 6, 36, 4, 31, 5, 61, 7, 32, 2, 80, 3, 78
  };
  const int q1215[] = {
    9, 9, // Number of jobs and machines
    1, 68, 8, 25, 4, 58, 6, 93, 0, 55, 2, 48, 7, 98, 3, 48, 5, 85, 
    2, 80, 5, 93, 8, 44, 6, 94, 0, 52, 7, 91, 1, 79, 3, 61, 4, 52, 
    1, 49, 8, 31, 2, 98, 6, 66, 3, 75, 0, 89, 7, 74, 4, 83, 5, 11, 
    3, 59, 8, 21, 5, 73, 1, 89, 6, 75, 4, 74, 2, 19, 0, 20, 7, 18, 
    1, 53, 4, 31, 0, 20, 7, 93, 3, 62, 5, 12, 6, 95, 8, 30, 2, 88, 
    8, 94, 4, 85, 2, 78, 3, 36, 7,  5, 5,  8, 1, 50, 0, 93, 6, 56, 
    0, 55, 1,  7, 6, 75, 7, 15, 3, 37, 5, 94, 4, 23, 8,  4, 2, 35, 
    4, 40, 8, 82, 5, 34, 1, 46, 6, 21, 0, 81, 2, 46, 3, 46, 7, 86, 
    1, 15, 7, 74, 8, 31, 4, 26, 2, 74, 6, 60, 5, 11, 0, 62, 3, 28
  };
  const int q1216[] = {
    9, 9, // Number of jobs and machines
    7, 34, 5, 17, 8, 86, 6, 17, 0, 23, 2, 60, 3, 24, 1, 30, 4, 69, 
    1, 65, 0, 42, 4, 18, 6, 88, 5, 69, 8, 34, 3, 49, 2, 19, 7, 52, 
    8, 59, 5, 22, 1, 35, 2, 28, 4, 23, 3, 92, 6, 40, 7, 90, 0,  1, 
    1, 52, 0, 52, 3, 57, 8, 54, 7, 25, 2, 51, 4, 45, 6, 56, 5, 98, 
    5, 24, 2, 25, 4, 10, 0,  7, 6, 84, 3, 13, 1,  5, 8, 16, 7, 11, 
    0, 94, 1, 44, 7, 66, 3, 64, 4, 13, 6, 93, 2,  1, 5, 11, 8, 21, 
    1, 78, 3, 84, 7, 44, 0, 35, 5, 73, 2, 68, 8, 32, 4, 61, 6, 39, 
    8, 78, 0, 59, 5, 29, 7, 19, 2, 16, 1, 51, 3, 12, 6, 90, 4, 52, 
    4, 79, 8, 84, 5, 12, 6, 46, 1, 71, 2, 41, 7, 89, 0, 59, 3, 80
  };
  const int q1217[] = {
    9, 9, // Number of jobs and machines
    4, 67, 3, 56, 8, 79, 5,  7, 7, 36, 0, 69, 6, 59, 2, 99, 1, 10, 
    8, 15, 5, 48, 6, 71, 7, 65, 3, 61, 1, 99, 0, 95, 4, 13, 2, 90, 
    2, 94, 3, 25, 8,  8, 5, 87, 6, 13, 4, 85, 7, 70, 0, 82, 1, 38, 
    1, 19, 8, 37, 2, 72, 5, 34, 4, 14, 7,  5, 0, 72, 3, 42, 6, 44, 
    2, 19, 1, 32, 5, 40, 8, 64, 4, 82, 7, 95, 6, 88, 3, 28, 0, 48, 
    5, 16, 6, 87, 3, 78, 2, 56, 8, 85, 7, 99, 4, 68, 0, 46, 1, 71, 
    1, 25, 0, 62, 7, 55, 6, 15, 2, 57, 8, 61, 5, 82, 3, 25, 4, 79, 
    2, 36, 0, 99, 1, 59, 5, 48, 7, 51, 6, 19, 3, 94, 8, 28, 4, 77, 
    3,  8, 8, 24, 2, 21, 1,  4, 6, 91, 4,  2, 0, 93, 5, 50, 7, 13
  };
  const int q1218[] = {
    9, 9, // Number of jobs and machines
    5, 95, 4, 84, 0, 97, 8, 60, 2, 51, 1, 88, 7, 71, 6, 13, 3,  7, 
    5, 69, 4, 65, 8, 97, 1, 96, 0, 82, 3, 98, 6, 35, 2, 29, 7, 44, 
    2, 69, 6, 30, 4, 34, 8, 87, 5, 12, 7, 90, 0, 56, 3, 41, 1, 98, 
    6, 38, 7, 96, 0, 50, 2,  9, 5, 48, 1, 20, 3, 69, 4, 59, 8, 63, 
    0, 94, 2, 31, 4, 30, 8, 60, 3, 22, 5, 61, 6, 58, 7, 50, 1, 46, 
    1, 46, 4, 80, 3,  4, 8, 16, 6, 80, 7, 57, 0, 76, 2, 28, 5, 69, 
    1, 19, 6, 49, 2, 61, 8, 25, 0, 24, 4, 90, 5, 85, 7, 87, 3, 48, 
    8, 23, 4, 34, 3, 36, 5, 10, 1, 98, 7, 35, 2, 62, 0, 57, 6, 82, 
    7, 41, 6, 70, 4,  7, 8, 98, 3,  8, 1, 85, 2, 63, 5, 91, 0, 92
  };
  const int q1219[] = {
    9, 9, // Number of jobs and machines
    4, 47, 6, 61, 0, 93, 7, 47, 3, 60, 8, 65, 2, 37, 1, 74, 5, 34, 
    3, 69, 8, 25, 5, 60, 1, 41, 4, 39, 6, 23, 7, 90, 0, 42, 2, 77, 
    0,  1, 1,  2, 7, 90, 3, 73, 2, 78, 8,  7, 4, 17, 6,  2, 5, 16, 
    0, 52, 6, 89, 2, 73, 5, 82, 8, 93, 4, 85, 1, 53, 7, 32, 3, 68, 
    4, 74, 1, 64, 3, 53, 8, 69, 5, 48, 2, 35, 7, 30, 0, 94, 6, 17, 
    2, 59, 5, 11, 4,  6, 7, 86, 3,  7, 1, 43, 8, 59, 6, 36, 0, 75, 
    5, 14, 6, 47, 1, 26, 0, 52, 3, 59, 4, 95, 8, 54, 7, 71, 2, 25, 
    2, 70, 1, 49, 7, 29, 6, 91, 4, 96, 5, 45, 0, 10, 8, 25, 3, 20, 
    7, 52, 2, 57, 0, 16, 8, 31, 5, 41, 4, 13, 1, 60, 3, 61, 6, 82
  };
  const int q1220[] = {
    9, 9, // Number of jobs and machines
    0,  4, 8, 74, 2, 39, 6, 66, 4, 77, 7, 33, 1, 39, 3, 23, 5, 74, 
    8, 51, 3, 22, 0,  7, 7, 92, 5, 38, 2, 25, 1, 47, 6,  2, 4, 17, 
    7, 69, 5, 74, 0,  8, 8,  5, 4, 88, 2, 21, 1,  1, 3, 94, 6, 56, 
    6, 91, 0, 55, 7, 96, 1, 38, 2, 29, 3,  6, 4, 29, 8, 10, 5, 12, 
    4, 54, 7, 40, 1, 22, 6, 68, 3, 19, 2, 25, 0, 24, 8, 74, 5, 90, 
    5, 79, 2, 17, 6, 81, 0, 52, 7, 36, 8, 85, 1, 92, 4, 22, 3, 60, 
    8, 82, 6,  4, 7, 71, 0, 30, 5, 76, 2, 68, 3, 53, 1, 54, 4, 57, 
    5, 32, 2,  3, 3, 76, 4, 16, 0, 77, 8, 22, 7, 52, 1, 98, 6, 36, 
    7, 13, 0, 33, 1, 39, 6, 49, 2, 57, 3, 68, 4, 61, 8, 70, 5, 24
  };
  const int q1221[] = {
    9, 9, // Number of jobs and machines
    1, 55, 7, 50, 5, 46, 8, 60, 4, 83, 6, 63, 0,  5, 3, 58, 2, 98, 
    1, 52, 0, 54, 3, 51, 2, 19, 7, 81, 4, 41, 6, 22, 8, 66, 5, 85, 
    0, 47, 4, 94, 2, 41, 6, 33, 3, 92, 1, 74, 7, 25, 5, 67, 8, 29, 
    4, 72, 6, 23, 8, 22, 2, 76, 3, 66, 5, 61, 0, 81, 7, 75, 1, 68, 
    3, 46, 4, 90, 2, 65, 7,  2, 0, 74, 8, 17, 1, 75, 6, 73, 5,  8, 
    5, 79, 4, 79, 3, 72, 6,  2, 1, 63, 2, 82, 8, 26, 7, 59, 0, 76, 
    2, 92, 0,  3, 5, 42, 1,  6, 4, 85, 3, 43, 8, 70, 6, 97, 7, 26, 
    0, 90, 3, 13, 2, 32, 4, 60, 5, 74, 7, 40, 6, 95, 1, 56, 8, 97, 
    5, 48, 2, 14, 0, 81, 1, 57, 7, 20, 6,  4, 4, 43, 3, 32, 8, 39
  };
  const int q1222[] = {
    9, 9, // Number of jobs and machines
    2, 24, 0, 49, 1, 85, 4, 36, 6, 73, 7, 76, 5, 27, 3, 30, 8,  2, 
    5, 20, 8, 89, 0, 48, 6, 78, 3,  3, 1, 10, 7, 38, 4, 75, 2, 22, 
    4, 47, 5, 69, 0, 73, 3, 89, 1, 29, 8, 74, 2, 54, 6, 73, 7, 29, 
    8, 85, 6, 47, 5,  7, 2, 64, 0, 90, 4, 28, 7, 84, 3, 39, 1, 22, 
    8, 13, 4,  6, 7, 73, 0, 94, 3, 86, 1, 37, 5, 35, 6, 87, 2,  8, 
    7, 82, 5, 51, 3, 56, 6, 27, 0, 47, 8, 84, 2, 77, 4, 91, 1, 54, 
    4, 57, 7, 28, 6, 98, 5, 49, 8, 52, 0, 65, 2, 51, 3, 93, 1, 56, 
    5, 89, 8, 12, 2,  3, 7, 29, 0,  3, 1, 49, 4, 18, 3, 86, 6, 95, 
    2, 63, 4, 64, 5, 43, 7, 74, 0, 43, 8, 44, 1, 98, 6, 35, 3, 90
  };
  const int q1223[] = {
    9, 9, // Number of jobs and machines
    3, 33, 6, 49, 0,  7, 1, 17, 8, 20, 7, 61, 4, 66, 5, 17, 2, 32, 
    2, 40, 0,  5, 3, 85, 6, 43, 8, 89, 7,  3, 4, 89, 1, 28, 5,  2, 
    3, 56, 5,  7, 4, 35, 7, 80, 8, 98, 0, 76, 6, 69, 1, 71, 2, 45, 
    6, 87, 3, 95, 0, 59, 2, 41, 1, 54, 4, 73, 7, 91, 5,  5, 8, 63, 
    1, 33, 6, 96, 8, 87, 3, 49, 0, 45, 2, 99, 4, 55, 5,  1, 7, 35, 
    6, 95, 5, 43, 1, 61, 0, 57, 2, 60, 3,  6, 8, 70, 7, 49, 4, 19, 
    4, 34, 1, 22, 7, 22, 5, 66, 2, 81, 6, 43, 3, 11, 8, 14, 0, 66, 
    3, 51, 1, 83, 4, 40, 2, 61, 6, 72, 0, 47, 5, 42, 7, 79, 8, 46, 
    6, 30, 4, 22, 2, 23, 7, 98, 8,  5, 1, 13, 3, 15, 0, 83, 5, 81
  };
  const int q1224[] = {
    9, 9, // Number of jobs and machines
    8, 66, 1, 39, 6, 44, 2, 28, 7, 62, 4, 74, 0, 64, 3, 62, 5, 97, 
    2, 72, 5, 40, 4, 27, 7, 59, 3, 76, 6, 13, 8, 64, 0, 50, 1, 30, 
    0, 90, 3,  7, 6, 93, 2, 24, 7, 29, 5, 74, 1, 73, 4, 50, 8, 61, 
    5, 73, 6, 37, 0, 27, 7, 30, 4, 77, 3, 33, 2, 50, 8, 47, 1, 39, 
    6, 20, 4, 17, 1, 65, 3, 75, 5, 92, 7, 43, 2, 89, 8, 14, 0, 31, 
    5, 88, 3, 73, 1,  5, 8, 71, 2, 52, 0, 80, 4,  9, 7, 31, 6,  7, 
    6,  2, 5, 44, 1, 28, 7, 88, 4, 33, 2, 69, 8, 49, 0,  6, 3, 24, 
    2, 31, 3, 25, 7, 48, 6, 83, 1, 95, 8, 69, 4,  6, 0, 72, 5,  9, 
    2, 52, 5, 67, 6, 47, 7, 22, 1, 55, 0, 81, 4, 49, 3, 66, 8, 12
  };
  const int q1225[] = {
    9, 9, // Number of jobs and machines
    6, 61, 4, 88, 8, 67, 5, 75, 7, 50, 3,  4, 1, 84, 0, 73, 2, 51, 
    6, 28, 7, 13, 5, 58, 8, 22, 3,  6, 4, 37, 1, 63, 2,  2, 0, 56, 
    2, 81, 3, 37, 6, 25, 1, 35, 0, 17, 4, 21, 7, 66, 8, 66, 5,  1, 
    0, 87, 1, 44, 4, 52, 5, 45, 7, 29, 6, 14, 2, 95, 3, 19, 8, 55, 
    1, 82, 0, 99, 3, 78, 4, 26, 7, 27, 2, 52, 8, 58, 5, 65, 6, 59, 
    0, 69, 5, 83, 4,  7, 1, 92, 7, 94, 3, 34, 8, 24, 2, 74, 6, 96, 
    5, 45, 2, 71, 0, 34, 1,  4, 3, 41, 7, 91, 6, 51, 8, 95, 4,  1, 
    8, 74, 4, 35, 1, 60, 0, 52, 3, 64, 5, 96, 6, 10, 2, 59, 7, 65, 
    0,  1, 4, 90, 7, 79, 8, 45, 5,  7, 2, 57, 3, 34, 6, 71, 1, 97
  };
  const int q1226[] = {
    9, 9, // Number of jobs and machines
    2, 76, 4, 87, 6, 71, 3, 61, 1, 47, 7, 21, 0, 90, 5, 68, 8, 41, 
    2, 30, 3, 64, 7,  5, 1, 57, 5, 22, 4, 32, 8, 97, 6, 95, 0, 30, 
    1, 22, 6, 35, 5,  4, 7, 21, 0, 39, 8, 57, 3, 82, 2, 94, 4, 51, 
    6, 49, 4, 46, 3,  9, 8,  2, 5, 87, 7, 37, 0, 44, 2, 58, 1, 25, 
    6, 33, 2, 57, 0,  4, 7,  1, 5, 49, 3, 55, 8, 45, 4,  6, 1, 64, 
    4, 17, 1,  1, 7, 95, 8, 15, 2, 58, 0, 14, 6, 90, 5, 17, 3, 17, 
    0, 80, 1, 49, 3, 88, 5, 52, 2, 50, 6, 47, 7, 62, 4, 54, 8, 89, 
    1, 65, 6, 52, 5, 17, 2, 69, 7,  1, 3, 78, 0, 21, 8, 33, 4,  3, 
    1, 67, 6, 43, 8, 47, 2, 26, 3, 15, 7,  2, 4, 11, 0, 89, 5, 15
  };
  const int q1227[] = {
    9, 9, // Number of jobs and machines
    2, 21, 5,  9, 7, 99, 8, 25, 4, 24, 1, 65, 0,  2, 6, 60, 3, 13, 
    2, 85, 7, 85, 4, 34, 8, 48, 1, 88, 0, 17, 3, 43, 6, 17, 5, 14, 
    2, 85, 3, 55, 4,  6, 8, 90, 0, 17, 7, 75, 5, 64, 6, 11, 1, 30, 
    3, 47, 6, 13, 5, 38, 2, 94, 1, 52, 8, 34, 0, 21, 4, 70, 7,  2, 
    3, 91, 5, 59, 2, 63, 8, 11, 0, 12, 1,  7, 7, 83, 4, 68, 6, 66, 
    7, 31, 6, 87, 5, 43, 2, 26, 3, 93, 4, 95, 0, 56, 1, 91, 8, 93, 
    6, 31, 8, 26, 2, 93, 0, 26, 5, 63, 1, 44, 4,  2, 7, 91, 3, 14, 
    8, 48, 6, 89, 5, 72, 2, 23, 7, 24, 1, 61, 0, 87, 4, 56, 3, 86, 
    6, 13, 3, 44, 8, 92, 4,  4, 1, 81, 5, 96, 7, 24, 0,  7, 2, 68
  };
  const int q1228[] = {
    9, 9, // Number of jobs and machines
    1, 33, 8, 61, 6, 83, 0,  3, 4,  5, 5, 37, 7,  4, 3, 94, 2, 34, 
    3, 89, 1, 96, 7, 21, 8, 28, 5, 50, 4, 83, 2, 58, 0, 41, 6, 87, 
    3, 13, 1, 26, 2, 31, 7, 77, 8, 31, 5, 28, 4, 65, 0, 76, 6, 17, 
    2, 18, 6, 92, 4,  5, 5, 59, 7,  8, 8, 95, 3, 94, 1, 87, 0, 82, 
    6, 80, 5, 81, 0, 93, 8, 81, 4, 71, 3,  1, 7, 38, 1, 15, 2, 47, 
    4, 17, 7, 48, 6, 73, 3, 49, 5, 95, 8, 34, 1, 51, 0, 18, 2,  5, 
    3, 73, 7,  5, 2, 40, 4, 85, 8, 41, 5, 61, 0, 64, 6, 28, 1, 63, 
    7, 40, 1,  7, 2, 19, 3, 25, 4, 49, 5, 23, 0, 95, 8, 78, 6, 63, 
    5, 58, 6, 72, 1, 55, 0, 78, 2, 76, 7, 64, 8, 29, 4, 14, 3, 44
  };
  const int q1229[] = {
    9, 9, // Number of jobs and machines
    0, 39, 8, 46, 3,  6, 7, 27, 4, 46, 1, 53, 5, 10, 2, 60, 6, 92, 
    4, 59, 7, 38, 8, 63, 0, 58, 2, 85, 1, 30, 5, 81, 3,  3, 6, 68, 
    2, 34, 7, 12, 3, 50, 1,  1, 8, 48, 5, 63, 6, 68, 4,  5, 0, 87, 
    3, 28, 7, 94, 1, 51, 6, 57, 4,  4, 0, 47, 8, 74, 5, 64, 2, 40, 
    2, 60, 0, 56, 1, 33, 3, 79, 7, 97, 4, 58, 8, 76, 5,  5, 6, 74, 
    8, 27, 6, 96, 7, 52, 4, 71, 5, 87, 1, 86, 2, 64, 0, 29, 3, 67, 
    4, 19, 1, 80, 8, 35, 2, 17, 0, 26, 3, 84, 6, 53, 7, 89, 5, 55, 
    7, 33, 3, 48, 8, 83, 5, 19, 0, 60, 6, 25, 2, 14, 1,  3, 4, 46, 
    8, 23, 0, 68, 1, 67, 5, 41, 6, 56, 4, 53, 7, 67, 2, 99, 3, 67
  };
  const int q1230[] = {
    9, 9, // Number of jobs and machines
    2, 85, 5, 26, 3, 64, 6, 13, 4, 41, 8, 74, 7, 18, 0, 55, 1, 96, 
    6, 13, 1, 51, 5, 72, 8, 59, 3, 35, 7,  5, 0,  9, 4, 72, 2, 68, 
    1, 60, 8, 39, 3, 94, 7, 30, 0,  9, 2, 10, 4, 60, 6, 54, 5, 85, 
    2, 35, 0, 42, 5, 79, 6, 24, 8, 58, 4, 34, 1, 23, 7, 57, 3, 36, 
    5, 28, 8, 82, 7, 65, 0, 80, 6, 32, 1, 43, 3, 52, 4, 58, 2, 12, 
    5, 41, 6, 80, 1, 25, 7, 85, 3, 35, 2, 94, 4, 42, 8,  1, 0, 93, 
    3, 90, 5, 25, 1, 22, 2, 99, 8, 54, 6, 59, 0, 91, 4, 73, 7, 76, 
    6, 34, 7,  6, 8, 29, 2, 81, 4, 11, 5, 72, 1, 10, 0, 52, 3, 67, 
    2, 26, 8, 74, 4, 98, 5, 68, 6, 33, 0, 35, 3, 17, 1, 81, 7, 83
  };
  const int q1231[] = {
    9, 9, // Number of jobs and machines
    2, 39, 0, 16, 4,  4, 5, 78, 3, 93, 7, 81, 8, 86, 1, 39, 6, 19, 
    6,  6, 4,  9, 2, 28, 1, 28, 0, 83, 5, 85, 3,  8, 7, 10, 8, 47, 
    6, 30, 5, 70, 3, 35, 1, 31, 7, 48, 4, 11, 2, 47, 8, 62, 0, 10, 
    8, 38, 4, 76, 2,  1, 7, 29, 0, 56, 5, 73, 3, 20, 6, 66, 1, 98, 
    0, 37, 1, 83, 2, 52, 8, 32, 5, 17, 6, 85, 7,  3, 4, 76, 3, 81, 
    2, 38, 5, 85, 0, 52, 6, 39, 8, 10, 1,  2, 3, 81, 4, 12, 7, 13, 
    3, 93, 2, 46, 1, 10, 5, 91, 7, 31, 4, 98, 6, 54, 0, 61, 8, 11, 
    5, 78, 0, 81, 7, 67, 8, 34, 6,  5, 2, 59, 4, 22, 3, 71, 1, 48, 
    4, 59, 6, 47, 8, 25, 3, 74, 7, 54, 0, 69, 2, 27, 1, 22, 5, 87
  };
  const int q1232[] = {
    9, 9, // Number of jobs and machines
    0,  2, 7, 25, 3, 47, 4, 87, 1, 32, 5, 40, 6, 96, 2, 50, 8, 33, 
    0, 92, 8, 78, 3, 97, 6,  7, 1, 33, 5, 78, 4, 10, 2, 10, 7, 75, 
    2, 19, 0, 45, 4, 85, 3, 44, 7, 53, 8, 46, 5, 38, 1, 94, 6, 70, 
    4, 12, 1, 62, 8, 27, 0, 94, 6, 71, 2, 15, 5, 87, 7, 24, 3, 11, 
    6, 87, 2, 41, 1, 98, 3, 57, 0, 88, 5, 51, 7, 26, 8, 24, 4, 99, 
    0, 89, 5, 51, 1, 14, 3, 15, 6, 44, 7, 67, 4, 55, 8, 38, 2, 73, 
    3, 82, 7, 44, 4, 71, 5, 97, 8,  3, 2, 35, 0, 90, 1, 11, 6, 27, 
    8, 43, 1, 14, 6, 17, 5, 56, 2, 15, 7, 93, 4, 13, 3, 40, 0, 35, 
    1, 65, 3, 26, 2, 80, 5, 96, 7, 95, 8, 10, 4, 38, 6,  5, 0, 99
  };
  const int q1233[] = {
    9, 9, // Number of jobs and machines
    3, 17, 2,  9, 1, 84, 7, 35, 0, 27, 8, 45, 6, 50, 5, 67, 4, 43, 
    2, 47, 0, 20, 6, 52, 7, 57, 8, 11, 3, 61, 1, 90, 5, 52, 4, 36, 
    8, 68, 2, 97, 0, 58, 3, 76, 4, 42, 6, 89, 5, 62, 1, 87, 7, 22, 
    6, 83, 5, 62, 2, 96, 0, 66, 1, 91, 7, 25, 4, 53, 8, 69, 3, 77, 
    2, 43, 8,  6, 7, 80, 1, 50, 5, 66, 0, 42, 4, 29, 6, 77, 3, 92, 
    5,  3, 2, 90, 0, 78, 7, 92, 6, 60, 4, 44, 3, 24, 8,  5, 1, 84, 
    8, 22, 6, 50, 0, 58, 7, 83, 1, 89, 3, 94, 2, 39, 5, 71, 4, 23, 
    2,  8, 0, 36, 5, 66, 1, 40, 7, 71, 6, 58, 3,  3, 4,  1, 8, 43, 
    4, 70, 0, 71, 5, 67, 8, 57, 2, 82, 3, 35, 7,  5, 6, 58, 1, 35
  };
  const int q1234[] = {
    9, 9, // Number of jobs and machines
    6, 74, 2, 36, 5, 58, 4,  4, 8, 84, 7, 89, 1, 81, 3, 43, 0, 31, 
    3, 66, 5, 17, 7,  5, 1, 76, 6, 25, 2, 71, 0, 21, 8, 13, 4, 35, 
    5, 88, 6, 22, 4, 21, 1, 22, 8, 59, 2, 69, 0, 15, 3, 39, 7, 73, 
    7,  3, 0,  2, 8, 92, 4, 65, 5, 79, 2, 82, 1, 76, 6, 53, 3, 47, 
    8, 61, 1, 34, 6, 98, 3, 56, 7,  8, 4, 97, 5, 73, 2, 17, 0, 63, 
    7, 73, 4, 67, 5, 54, 0, 78, 6,  9, 8, 31, 2, 17, 3, 56, 1, 10, 
    1, 91, 3, 72, 2, 11, 5, 27, 4, 89, 7, 55, 8, 88, 6, 85, 0, 34, 
    0, 89, 8, 40, 5, 53, 2,  3, 7, 28, 4, 58, 6, 36, 3,  2, 1, 35, 
    0, 31, 1, 32, 8, 50, 5, 14, 3, 51, 2,  8, 6, 95, 7, 35, 4, 32
  };
  const int q1235[] = {
    9, 9, // Number of jobs and machines
    5, 33, 0, 25, 4, 47, 6, 38, 3, 56, 1, 82, 8, 41, 2, 89, 7, 72, 
    7, 85, 8,  8, 1, 89, 5, 77, 3, 78, 4, 17, 2, 49, 6, 10, 0, 46, 
    7,  2, 4, 32, 6, 93, 3, 59, 2, 43, 5, 83, 8, 27, 0, 24, 1, 20, 
    7, 87, 1, 29, 5, 44, 3, 76, 4, 70, 6,  7, 2, 99, 8, 74, 0, 39, 
    5, 99, 7, 79, 4, 57, 8, 38, 1, 93, 0, 64, 3, 86, 6, 73, 2, 87, 
    8, 23, 6, 97, 0, 48, 3, 53, 4, 21, 7, 46, 5, 19, 1, 88, 2,  3, 
    2, 91, 0, 21, 8, 89, 5, 79, 7, 98, 4, 44, 1, 36, 3, 80, 6, 72, 
    2, 50, 4, 47, 8, 52, 6, 94, 0, 98, 5, 29, 3,  5, 1, 14, 7, 77, 
    2, 23, 4, 35, 3, 42, 7, 97, 1, 72, 6, 84, 5, 22, 8,  8, 0, 99
  };
  const int q1236[] = {
    9, 9, // Number of jobs and machines
    7, 35, 6,  1, 0, 97, 8, 48, 3, 35, 1, 77, 4,  3, 5,  6, 2, 30, 
    5, 35, 8, 36, 7,  1, 1, 17, 0, 15, 4, 97, 6, 69, 2, 42, 3, 69, 
    1, 22, 3, 35, 4, 90, 2, 97, 6, 44, 7, 67, 8, 25, 0, 33, 5, 23, 
    1, 70, 7, 98, 2, 47, 8, 29, 3, 71, 5, 59, 6,  2, 4,  6, 0, 73, 
    1, 14, 7, 81, 2, 11, 4, 60, 0, 12, 6, 54, 3, 22, 5, 98, 8, 58, 
    3, 95, 1, 33, 4, 20, 2, 90, 0, 49, 7, 76, 5, 13, 6, 83, 8, 51, 
    4, 20, 2, 23, 1, 20, 7, 30, 8, 39, 3, 89, 5, 38, 6, 95, 0, 64, 
    6, 72, 4, 45, 5,  7, 7, 76, 0, 21, 8, 25, 1, 44, 2, 52, 3, 27, 
    7, 51, 2, 76, 6, 73, 1, 44, 5, 37, 0, 59, 8, 85, 4, 87, 3,  2
  };
  const int q1237[] = {
    9, 9, // Number of jobs and machines
    8, 53, 4, 84, 2, 28, 6, 23, 0, 64, 5, 66, 7, 11, 1, 71, 3, 51, 
    8, 91, 0, 29, 6, 88, 4, 94, 3, 60, 2, 14, 5, 28, 7, 40, 1, 93, 
    7, 37, 8, 45, 1, 69, 6, 16, 0, 67, 2, 43, 3, 81, 4, 62, 5, 89, 
    7, 49, 3, 52, 8, 51, 4, 90, 6, 55, 1, 92, 5,  8, 0, 11, 2, 57, 
    6, 97, 1,  4, 7, 76, 2, 68, 0, 79, 3, 43, 8, 62, 5, 17, 4, 37, 
    1, 32, 7, 46, 6, 13, 2, 11, 5, 41, 8, 34, 3, 85, 0, 61, 4, 35, 
    7, 48, 8, 18, 6, 83, 1, 85, 5, 14, 4, 39, 0, 98, 2, 27, 3, 22, 
    6, 16, 0, 17, 5, 79, 2, 91, 1, 37, 7, 53, 3,  4, 4, 73, 8, 42, 
    1,  5, 0, 57, 8, 93, 7, 75, 4,  6, 5, 40, 6, 20, 2,  6, 3,  7
  };
  const int q1238[] = {
    9, 9, // Number of jobs and machines
    0, 88, 8, 11, 5, 34, 7, 58, 3, 30, 4, 90, 2, 11, 6, 93, 1, 56, 
    5, 92, 8, 74, 7, 73, 6, 77, 0, 98, 4,  5, 3, 23, 1,  6, 2, 33, 
    7, 30, 6, 78, 3, 17, 0, 85, 4, 87, 2, 19, 5, 31, 8, 62, 1, 98, 
    2, 91, 3, 18, 8, 82, 1, 96, 7, 14, 4, 17, 5, 79, 6, 80, 0,  2, 
    4, 97, 0, 54, 1, 22, 8, 68, 3,  7, 2, 95, 5,  4, 7, 88, 6, 77, 
    8, 99, 1, 73, 6, 37, 2, 33, 5, 91, 7, 90, 0, 83, 3, 21, 4, 65, 
    2, 46, 1, 13, 7, 19, 4, 39, 8, 10, 6, 47, 0, 10, 5, 19, 3, 25, 
    8,  5, 3, 42, 4, 80, 1, 75, 5, 94, 7, 92, 6, 47, 0, 87, 2, 64, 
    4, 97, 7, 85, 2, 88, 5,  7, 8, 50, 0, 30, 6, 22, 3, 90, 1, 11
  };
  const int q1239[] = {
    9, 9, // Number of jobs and machines
    5, 62, 3, 66, 7, 50, 4, 63, 2,  4, 6, 85, 1,  6, 8, 22, 0, 40, 
    4, 30, 6, 20, 2, 57, 8, 19, 5,  4, 7, 50, 3, 59, 1, 85, 0, 80, 
    7, 53, 4, 30, 1, 82, 5, 67, 6, 15, 3, 35, 2, 81, 0, 55, 8, 41, 
    7, 53, 1,  4, 6, 61, 2, 16, 5, 74, 0, 81, 4, 54, 3,  8, 8, 66, 
    3,  1, 6, 63, 0, 59, 8, 68, 7, 29, 4, 86, 5,  6, 2, 36, 1, 38, 
    7, 41, 4, 30, 3, 70, 2, 67, 6, 73, 8, 68, 5, 43, 1, 91, 0,  5, 
    4, 11, 7, 76, 6, 90, 3, 66, 2, 46, 1, 83, 5, 32, 8, 94, 0, 25, 
    7, 57, 0, 25, 6, 99, 8, 73, 1, 78, 4, 43, 2, 19, 5, 42, 3, 80, 
    0, 31, 7, 47, 4, 32, 3, 12, 6, 79, 1, 92, 2, 19, 5, 74, 8,  2
  };
  const int q1240[] = {
    9, 9, // Number of jobs and machines
    1, 24, 7,  9, 3, 24, 5, 43, 4, 65, 6, 30, 8,  7, 2, 87, 0, 42, 
    1, 14, 5,  9, 4, 34, 2, 19, 7, 93, 0, 32, 3, 81, 8, 12, 6, 91, 
    3, 99, 1,  2, 8, 39, 6, 18, 4,  6, 7,  5, 5, 52, 0, 21, 2, 98, 
    2, 85, 5, 70, 7, 69, 0,  3, 1,  9, 4, 12, 8, 18, 6, 58, 3, 53, 
    3, 52, 6, 27, 1, 94, 5,  6, 2, 12, 7, 59, 4, 30, 8,  3, 0, 43, 
    3, 75, 6, 47, 5, 28, 1, 57, 8, 17, 0, 45, 4, 91, 7,  8, 2, 47, 
    2, 66, 8, 12, 3, 37, 1, 10, 4, 29, 6, 58, 0, 57, 5, 82, 7, 75, 
    1, 94, 7, 11, 8, 94, 6, 18, 4, 50, 0, 21, 2, 12, 5,  3, 3, 59, 
    7, 68, 0, 57, 5, 61, 6, 70, 8, 70, 3, 16, 4, 68, 1, 40, 2, 41
  };
  const int q1241[] = {
    9, 9, // Number of jobs and machines
    8, 96, 1, 68, 3, 30, 2, 24, 6, 49, 5, 40, 4,  5, 0,  3, 7, 66, 
    2, 62, 5, 89, 0, 42, 6, 59, 3, 38, 7,  8, 8, 79, 1, 11, 4, 96, 
    6, 62, 1, 71, 7, 46, 3, 10, 4, 45, 5, 82, 2, 65, 0, 59, 8, 55, 
    8, 68, 1, 36, 5, 60, 2, 24, 3, 22, 7, 28, 6, 29, 0, 17, 4, 63, 
    5, 57, 6, 64, 0, 27, 2, 16, 4, 12, 8, 48, 3,  7, 7, 72, 1, 30, 
    0, 49, 5, 63, 2, 13, 6, 11, 8, 75, 1,  7, 4,  5, 7, 47, 3, 94, 
    6, 47, 0, 55, 4, 29, 2, 29, 3, 12, 5, 70, 8, 27, 1, 27, 7, 23, 
    8, 66, 6, 18, 2,  3, 0, 80, 7, 87, 4, 51, 1, 52, 3, 68, 5, 47, 
    7, 95, 8, 77, 4, 95, 0, 34, 3, 72, 5, 80, 6, 41, 2, 25, 1, 90
  };
  const int q1242[] = {
    9, 9, // Number of jobs and machines
    6, 64, 8, 45, 0, 90, 1, 11, 2, 29, 3, 10, 4, 50, 5, 56, 7, 98, 
    0, 95, 2, 28, 6,  8, 5, 84, 4, 63, 1, 93, 8, 87, 7,  1, 3, 60, 
    4, 95, 8, 13, 1, 93, 0,  5, 6, 49, 3, 32, 5, 74, 7, 13, 2, 86, 
    0, 68, 1, 59, 4, 40, 3, 95, 6, 33, 8,  8, 5,  3, 7, 18, 2, 20, 
    4, 23, 3, 18, 7, 36, 8, 66, 1, 48, 5, 59, 0,  8, 2, 35, 6, 93, 
    4, 56, 5, 64, 2, 39, 8, 64, 3,  8, 1, 53, 7,  2, 0, 48, 6, 92, 
    4, 70, 1, 75, 8, 68, 3, 80, 0, 97, 6, 34, 7, 85, 2, 34, 5, 28, 
    7, 96, 5, 69, 3, 55, 1, 68, 2, 59, 6, 10, 8, 84, 0, 85, 4, 40, 
    4, 78, 0, 37, 8, 50, 5, 54, 7, 24, 3, 32, 6, 57, 2, 10, 1, 67
  };
  const int q1243[] = {
    9, 9, // Number of jobs and machines
    0, 86, 6, 11, 3, 61, 8, 43, 2, 96, 1, 48, 4, 44, 7, 32, 5, 17, 
    0, 44, 2, 66, 6, 38, 7, 27, 3, 11, 1, 94, 5, 17, 8, 36, 4, 21, 
    4, 84, 0, 10, 3, 22, 2, 77, 6, 94, 7,  2, 8, 53, 5, 45, 1, 90, 
    2, 57, 5, 90, 7, 13, 3, 79, 4, 97, 1, 13, 8, 49, 0, 18, 6, 20, 
    7, 94, 5, 68, 3, 51, 1, 94, 2, 73, 4, 17, 6,  9, 0, 23, 8, 82, 
    6, 59, 4, 19, 0, 57, 8, 38, 2, 69, 1, 87, 3, 19, 5, 39, 7, 42, 
    3, 87, 2, 16, 0, 35, 6, 78, 1, 29, 7, 68, 5, 29, 8, 82, 4, 52, 
    4, 93, 3, 24, 2, 26, 0,  5, 6, 71, 7, 35, 5, 34, 1,  9, 8, 87, 
    7, 80, 1, 45, 6,  5, 5, 96, 3, 15, 2, 38, 0,  2, 4, 38, 8, 60
  };
  const int q1244[] = {
    9, 9, // Number of jobs and machines
    4, 22, 6, 67, 1, 83, 0, 72, 7, 18, 8, 67, 5, 16, 2, 99, 3, 18, 
    7, 33, 1, 24, 0, 95, 6, 79, 5, 74, 3, 37, 4, 49, 2, 72, 8, 80, 
    3, 14, 8, 82, 0, 98, 5, 99, 1, 62, 7, 51, 2, 64, 6, 81, 4, 34, 
    6, 58, 4, 55, 1, 82, 0, 38, 3, 73, 5,  4, 8, 71, 7, 29, 2, 18, 
    0, 42, 2, 30, 6, 63, 1, 49, 8, 39, 7, 10, 3, 14, 4, 49, 5, 61, 
    8, 13, 6, 78, 3, 18, 0, 91, 2, 87, 5, 40, 7, 87, 4,  5, 1, 26, 
    5, 64, 3, 42, 2, 82, 1,  6, 4, 60, 0,  2, 8,  3, 6, 17, 7, 28, 
    2, 21, 7,  3, 3, 15, 5, 27, 6, 44, 4, 11, 1, 40, 8, 95, 0, 56, 
    5, 16, 2,  5, 7, 13, 3, 79, 6, 55, 1, 62, 8, 28, 0, 26, 4, 26
  };
  const int q1245[] = {
    9, 9, // Number of jobs and machines
    6, 75, 3,  4, 1, 11, 7, 43, 8, 43, 5, 48, 4, 82, 0, 24, 2, 48, 
    0, 25, 2, 54, 1,  8, 6, 78, 7, 61, 5, 33, 4, 65, 8, 43, 3, 45, 
    2, 34, 7, 89, 0, 96, 5, 29, 1, 62, 4, 14, 6, 44, 3, 95, 8, 15, 
    0,  9, 2,  2, 7, 89, 8, 19, 5, 86, 3,  6, 4, 43, 6,  5, 1, 82, 
    3, 42, 4,  3, 2, 78, 1, 70, 8, 17, 0, 30, 5, 68, 6, 19, 7, 22, 
    4,  5, 1, 28, 6, 47, 0, 98, 3, 53, 7, 40, 8, 19, 2, 63, 5, 60, 
    6, 59, 3,  2, 7, 86, 0, 66, 5, 72, 8, 24, 2, 58, 1, 54, 4, 88, 
    5, 45, 4, 61, 8, 40, 2, 94, 0, 69, 3, 51, 7, 66, 1, 90, 6, 80, 
    2, 55, 5, 14, 7,  4, 6, 78, 1, 99, 3,  9, 8, 77, 0, 25, 4,  1
  };
  const int q1246[] = {
    9, 9, // Number of jobs and machines
    5, 76, 2, 19, 3, 70, 7, 76, 4, 59, 6, 71, 8, 94, 0, 28, 1, 85, 
    4, 59, 8, 80, 1, 54, 0, 22, 5, 95, 2,  1, 6, 24, 7, 44, 3, 26, 
    8, 85, 1, 36, 4, 16, 2, 76, 3, 72, 7, 92, 0, 56, 5, 28, 6, 59, 
    3, 96, 5, 27, 2,  7, 1, 56, 0, 44, 6, 61, 7, 43, 4, 90, 8, 69, 
    0, 32, 3, 26, 2, 69, 8, 31, 7, 36, 1, 28, 4, 51, 6,  6, 5, 43, 
    0, 44, 6, 80, 4, 60, 1, 20, 2, 23, 3, 38, 8, 68, 7, 73, 5, 22, 
    1, 31, 7, 58, 3, 41, 2, 15, 6, 39, 5, 66, 4, 82, 8, 82, 0, 77, 
    6, 18, 5,  4, 2, 84, 7,  2, 1, 38, 4, 10, 3, 52, 8, 63, 0, 10, 
    8, 29, 4, 56, 7, 69, 2, 41, 3, 82, 6, 86, 5, 53, 0, 24, 1, 35
  };
  const int q1247[] = {
    9, 9, // Number of jobs and machines
    5, 27, 4, 31, 7, 82, 1, 76, 8, 26, 2, 11, 3, 13, 0, 42, 6, 23, 
    6, 78, 0, 80, 4, 17, 7, 41, 8, 23, 1, 22, 3, 33, 2, 11, 5, 52, 
    7, 32, 0,  8, 4, 64, 6, 80, 3, 16, 5, 73, 2, 97, 8, 38, 1, 56, 
    2, 29, 3, 85, 5, 87, 0, 79, 1, 70, 4, 17, 8, 91, 7, 29, 6, 54, 
    5, 95, 1, 61, 8, 44, 6, 28, 7,  3, 0, 50, 3, 27, 4, 42, 2, 22, 
    8, 50, 0, 21, 6, 67, 3, 35, 4, 14, 5, 95, 2,  5, 1, 92, 7, 23, 
    1, 36, 8, 62, 5, 72, 3, 51, 2, 56, 6, 51, 0,  6, 4, 76, 7, 92, 
    4, 66, 2, 75, 7, 52, 3, 26, 6, 53, 5, 70, 0, 70, 1, 75, 8, 54, 
    5, 66, 6, 70, 0, 67, 2, 36, 8, 42, 1, 58, 3, 76, 7, 74, 4, 52
  };
  const int q1248[] = {
    9, 9, // Number of jobs and machines
    2, 18, 8, 38, 0,  6, 5, 40, 4, 78, 6, 13, 7, 51, 1, 52, 3, 81, 
    8,  4, 3, 45, 5, 10, 1, 34, 2, 71, 4, 85, 0, 35, 6, 97, 7, 99, 
    0, 19, 7, 12, 8, 13, 2, 76, 6, 75, 1, 92, 5, 14, 4, 86, 3, 67, 
    2, 88, 3, 98, 1, 62, 5, 53, 0, 23, 6, 86, 7, 79, 4, 22, 8, 70, 
    8, 58, 2,  9, 6, 84, 0, 75, 3, 85, 7, 29, 4, 54, 1, 38, 5, 62, 
    1, 73, 5, 76, 2, 80, 4, 93, 3, 61, 0, 28, 7, 61, 8, 52, 6, 28, 
    6,  9, 1, 43, 8, 48, 2, 57, 5, 27, 7, 29, 4, 13, 0,  8, 3, 68, 
    8, 45, 4, 22, 3, 34, 0,  8, 2, 53, 7, 60, 6, 74, 1, 40, 5, 15, 
    1, 99, 8, 93, 0, 50, 6, 68, 5, 66, 4, 73, 7, 46, 3, 27, 2, 54
  };
  const int q1249[] = {
    9, 9, // Number of jobs and machines
    7, 41, 8, 81, 6, 11, 5, 68, 1, 19, 2,  1, 4, 74, 0, 11, 3, 29, 
    7, 19, 2, 25, 5, 49, 6, 29, 1, 34, 0, 38, 8, 39, 4, 73, 3, 71, 
    1, 50, 3, 77, 0, 76, 8, 81, 4,  5, 5, 28, 7, 69, 6, 39, 2, 17, 
    8, 67, 5, 38, 7, 38, 2, 46, 0, 76, 3, 93, 4, 64, 6, 35, 1, 98, 
    2, 55, 5, 46, 8, 91, 7, 12, 3, 62, 4, 72, 1, 60, 6, 20, 0, 74, 
    1, 51, 3, 33, 0, 13, 5, 35, 4, 93, 6, 23, 2, 43, 8, 12, 7, 87, 
    4, 10, 6, 72, 0, 38, 8, 77, 2, 56, 1, 52, 3, 89, 5,  6, 7, 18, 
    3,  1, 2,  5, 7, 55, 1, 96, 4, 95, 0, 92, 6, 41, 8, 45, 5, 99, 
    1, 93, 8, 30, 0, 82, 2, 22, 5, 11, 6,  4, 4, 36, 3, 26, 7, 42
  };
  const int q1250[] = {
    9, 9, // Number of jobs and machines
    8, 39, 6, 56, 7,  3, 4, 83, 1, 81, 3,  7, 2, 67, 5,  8, 0, 22, 
    7, 59, 2, 58, 6, 89, 0, 94, 1, 84, 8, 18, 4, 32, 5, 94, 3, 77, 
    8, 25, 4, 98, 2, 12, 6, 31, 3, 70, 0, 27, 1, 17, 7, 54, 5, 42, 
    5, 51, 6, 77, 4, 84, 1, 56, 8, 21, 0, 39, 3,  5, 7, 96, 2, 75, 
    6, 74, 3, 49, 4, 94, 7, 12, 0, 25, 8, 65, 5, 22, 2, 72, 1, 41, 
    2, 42, 6, 30, 0, 21, 7, 78, 1, 26, 4, 80, 5, 18, 3, 37, 8, 22, 
    6, 38, 4,  7, 0,  8, 7, 50, 3, 26, 2,  5, 5, 47, 1, 94, 8, 44, 
    4, 96, 0, 47, 7, 79, 3, 68, 1, 29, 2, 40, 6,  9, 8, 62, 5, 44, 
    4, 29, 5, 46, 7, 72, 8, 18, 0, 92, 1, 78, 3, 89, 6, 25, 2, 35
  };
  const int q1251[] = {
    9, 9, // Number of jobs and machines
    3, 86, 1, 44, 8, 41, 2, 13, 7, 84, 0, 28, 6, 56, 5, 99, 4,  5, 
    0, 98, 2, 51, 7, 50, 5, 32, 1, 27, 4, 20, 6, 27, 3, 87, 8, 52, 
    1, 97, 8, 46, 0, 56, 2, 85, 6, 93, 3, 41, 5, 94, 4, 54, 7, 50, 
    2, 21, 8, 46, 4, 54, 5, 46, 6, 69, 3, 85, 0, 94, 7, 40, 1, 84, 
    1,  9, 8, 71, 4, 55, 0, 35, 3, 92, 7, 29, 2, 57, 6, 76, 5,  4, 
    5,  1, 4, 80, 2, 90, 6, 65, 7, 16, 3, 88, 1, 58, 8, 56, 0, 78, 
    0, 87, 8, 41, 2, 36, 1, 22, 5, 35, 6, 38, 4, 83, 7, 70, 3, 97, 
    3,  5, 1, 20, 5, 54, 6, 84, 8, 69, 0, 32, 2, 52, 7, 79, 4, 21, 
    5, 52, 7, 29, 3, 20, 0, 40, 6, 61, 8, 99, 2, 41, 1, 10, 4, 37
  };
  const int q1252[] = {
    9, 9, // Number of jobs and machines
    3, 55, 5, 20, 0, 14, 4, 75, 6,  2, 8, 20, 2,  9, 1, 92, 7, 34, 
    4, 41, 2, 17, 6, 24, 1, 48, 3, 30, 5, 23, 7, 88, 8, 28, 0, 84, 
    1, 24, 5, 12, 2, 75, 6, 71, 3, 91, 0, 58, 8, 65, 7, 13, 4, 97, 
    8, 32, 0, 20, 6,  8, 3, 98, 2, 21, 5, 10, 7, 99, 4, 62, 1, 23, 
    8, 52, 4, 68, 5, 73, 3, 66, 1, 42, 7, 78, 0, 34, 2, 22, 6, 14, 
    1,  6, 5, 75, 8, 38, 4, 82, 6, 16, 0, 41, 3, 31, 2, 43, 7, 86, 
    5, 80, 8, 45, 7, 86, 1, 26, 6, 53, 2, 35, 4, 27, 0, 68, 3, 34, 
    5, 80, 8, 55, 4, 16, 0,  1, 6, 44, 3, 48, 2, 88, 7, 91, 1, 22, 
    5, 72, 0, 22, 4,  2, 1, 79, 6, 85, 2, 94, 3, 12, 8, 53, 7, 41
  };
  const int q1253[] = {
    9, 9, // Number of jobs and machines
    4, 31, 1, 55, 6, 70, 2, 18, 5,  8, 0, 93, 7, 94, 8, 11, 3, 10, 
    3, 16, 4, 28, 6,  1, 5, 41, 1, 12, 8, 69, 7, 15, 2, 75, 0, 23, 
    3, 75, 2, 93, 7,  3, 6, 48, 1, 19, 0, 67, 8, 16, 4, 26, 5, 55, 
    0, 63, 3, 87, 7, 76, 1, 40, 4, 73, 5, 43, 6, 86, 8, 99, 2,  2, 
    2, 30, 6, 40, 8, 51, 5, 84, 1, 80, 4, 94, 3, 29, 7, 90, 0, 86, 
    0, 43, 8, 42, 4,  4, 2, 66, 3, 58, 5, 81, 6, 13, 7, 78, 1, 11, 
    2, 33, 8, 74, 6, 10, 1, 70, 5, 55, 4, 72, 7,  5, 3, 95, 0, 43, 
    6, 40, 4, 11, 2, 90, 0, 87, 3,  3, 8, 37, 7, 67, 5, 71, 1, 94, 
    8, 65, 6, 16, 0, 33, 2, 90, 4, 13, 5, 86, 1,  9, 7, 69, 3, 70
  };
  const int q1254[] = {
    9, 9, // Number of jobs and machines
    6, 79, 1, 59, 0, 23, 7, 80, 2,  7, 4, 32, 3, 39, 5, 55, 8, 24, 
    1, 45, 4, 98, 8, 32, 2,  7, 7, 73, 3, 36, 6, 70, 5, 62, 0, 82, 
    8, 35, 2,  3, 6, 98, 5, 91, 1, 68, 7, 55, 3, 10, 0, 98, 4, 10, 
    4, 47, 3, 56, 8, 56, 0, 39, 7, 74, 6, 22, 2, 48, 5, 61, 1, 71, 
    4, 56, 8, 34, 6, 35, 0, 27, 1, 91, 3, 74, 7, 71, 5, 34, 2, 63, 
    0, 85, 8, 42, 2, 69, 6, 22, 5, 10, 7, 25, 4, 53, 1, 58, 3, 89, 
    2, 13, 8, 84, 3, 63, 0, 94, 1, 45, 4, 75, 7,  2, 6, 24, 5, 18, 
    0, 64, 6,  1, 8, 37, 7, 12, 3, 79, 5, 23, 2, 72, 4, 51, 1, 62, 
    6, 56, 7, 97, 3, 42, 2, 83, 1, 46, 0, 58, 4,  9, 8,  5, 5, 65
  };
  const int q1255[] = {
    9, 9, // Number of jobs and machines
    4, 45, 6, 43, 1, 83, 8, 89, 3, 61, 7, 80, 5, 53, 2, 43, 0, 99, 
    2, 99, 5, 27, 6, 13, 3, 60, 4, 34, 7, 32, 1, 48, 0, 11, 8, 49, 
    2, 51, 3, 95, 8, 54, 1, 27, 0, 36, 4, 55, 7, 98, 5, 82, 6, 16, 
    3, 26, 5, 70, 6, 95, 7, 79, 0,  9, 4, 22, 2, 94, 8, 10, 1, 82, 
    4, 67, 2, 80, 6,  9, 8, 45, 7, 46, 5, 78, 1, 56, 0,  2, 3, 97, 
    1, 96, 6, 29, 7, 69, 4, 73, 2, 32, 3, 66, 0, 89, 5, 74, 8, 17, 
    0, 58, 1, 22, 2, 74, 7, 43, 6, 70, 8,  7, 5, 67, 4, 40, 3, 40, 
    7, 46, 5, 57, 6, 52, 8, 26, 2, 43, 3, 83, 4, 65, 1, 17, 0, 88, 
    0, 22, 3, 40, 6, 27, 7,  3, 8, 82, 1, 26, 5, 29, 2, 81, 4, 94
  };
  const int q1256[] = {
    9, 9, // Number of jobs and machines
    1, 21, 3, 53, 7, 10, 6, 54, 4, 43, 0,  5, 8, 86, 5, 32, 2, 90, 
    7, 91, 5, 14, 6, 68, 3, 25, 2, 19, 1, 85, 4, 80, 0, 63, 8,  4, 
    4, 72, 3, 80, 1, 66, 2, 67, 0,  9, 6, 57, 7, 22, 8, 76, 5, 24, 
    4, 78, 2, 75, 6, 77, 7, 75, 0, 74, 5, 92, 8, 99, 1, 12, 3, 33, 
    5, 12, 8, 13, 4, 88, 7, 69, 3, 55, 1, 44, 6, 75, 2, 54, 0, 45, 
    3,  4, 0, 30, 2, 57, 6, 18, 7, 34, 8,  5, 5, 49, 4, 89, 1, 59, 
    8, 77, 3, 11, 0, 96, 4, 87, 5, 48, 1, 52, 6, 35, 7, 46, 2, 50, 
    1, 67, 0, 93, 7, 55, 4, 97, 2, 39, 6, 67, 5, 32, 3,  6, 8, 53, 
    8, 37, 0,  2, 6, 81, 2, 81, 5, 77, 4, 23, 3, 82, 7,  2, 1, 14
  };
  const int q1257[] = {
    9, 9, // Number of jobs and machines
    5,  2, 2, 61, 1, 89, 3, 95, 6, 39, 8, 90, 0, 12, 4, 77, 7, 70, 
    3, 30, 1, 22, 0, 65, 8, 93, 4, 62, 5, 58, 6,  7, 7, 85, 2, 53, 
    8, 44, 2, 72, 3, 46, 6, 47, 1, 72, 5,  5, 0, 17, 7, 13, 4, 94, 
    8, 42, 4, 65, 0, 15, 3, 30, 2, 44, 7, 72, 1, 94, 5, 34, 6,  3, 
    4, 74, 3, 36, 6, 87, 5, 14, 7, 69, 0, 79, 1, 28, 2, 70, 8, 98, 
    3, 28, 4, 93, 7, 19, 0, 66, 8, 35, 5, 64, 6, 18, 1, 25, 2, 87, 
    3, 81, 1, 10, 2, 51, 7, 64, 8, 31, 6, 14, 0, 90, 4, 70, 5, 78, 
    7, 89, 2, 77, 4, 59, 0, 98, 6, 57, 5, 57, 8, 31, 1, 65, 3, 44, 
    7, 68, 6, 45, 8, 58, 0, 21, 1, 16, 5, 58, 2, 64, 3, 31, 4, 15
  };
  const int q1258[] = {
    9, 9, // Number of jobs and machines
    2, 79, 3,  1, 6, 84, 0, 20, 8, 52, 5, 33, 7, 77, 4, 68, 1, 16, 
    7, 67, 8, 37, 5, 53, 6, 99, 2, 45, 4, 44, 1,  9, 0, 32, 3, 83, 
    5, 25, 2, 10, 8, 33, 3, 57, 6,  7, 4, 34, 0, 60, 7,  4, 1, 29, 
    8, 24, 2, 36, 0, 36, 6, 56, 7, 91, 1, 56, 3, 22, 4,  9, 5, 12, 
    3, 82, 5, 48, 6, 22, 8, 60, 2, 97, 1, 15, 7, 71, 4,  6, 0, 41, 
    5, 61, 1, 29, 3, 84, 0, 23, 8,  2, 4, 60, 6, 20, 7, 66, 2, 68, 
    7, 11, 5, 75, 2, 66, 3, 48, 0, 39, 4, 37, 6, 17, 1, 80, 8, 84, 
    6, 86, 1, 22, 3,  9, 7, 29, 4,  1, 5, 29, 8, 51, 2, 84, 0, 66, 
    2, 28, 1,  7, 4, 16, 7, 86, 6, 13, 8, 85, 5, 89, 0, 84, 3, 66
  };
  const int q1259[] = {
    9, 9, // Number of jobs and machines
    5, 29, 7, 84, 8, 86, 6,  6, 3, 85, 0,  9, 2, 64, 4, 23, 1, 96, 
    7, 52, 0, 15, 6, 99, 1, 35, 3, 40, 8, 70, 5, 17, 4, 36, 2, 13, 
    2,  3, 1, 54, 3, 37, 4,  3, 0, 73, 8, 39, 5, 62, 7, 13, 6, 92, 
    1, 98, 7, 78, 6, 99, 3, 25, 5, 52, 2, 59, 8, 55, 0, 83, 4, 15, 
    3, 90, 4, 60, 8, 73, 5, 47, 0, 52, 2, 72, 7, 34, 1, 19, 6, 24, 
    5, 79, 8, 56, 2, 94, 7,  4, 3, 77, 6,  5, 4, 28, 1,  4, 0, 82, 
    3, 57, 4, 54, 6,  6, 0, 32, 7, 67, 2, 76, 8, 75, 5, 77, 1, 65, 
    2, 63, 4, 65, 1, 54, 8,  8, 3, 46, 5, 68, 6, 46, 0, 32, 7, 88, 
    5, 48, 6, 84, 0, 20, 3, 23, 4, 87, 1, 95, 8, 88, 2, 83, 7, 88
  };
  const int q1260[] = {
    9, 9, // Number of jobs and machines
    1, 11, 0, 21, 4, 35, 3, 30, 6, 65, 2, 88, 7, 37, 8, 11, 5, 69, 
    8, 66, 7, 40, 3, 50, 5, 85, 0, 14, 4, 94, 1, 42, 6, 93, 2, 82, 
    4, 25, 6, 93, 0, 58, 2,  7, 3, 22, 1, 31, 7, 16, 8, 64, 5, 52, 
    3, 26, 2, 36, 0, 28, 7, 45, 6, 41, 5, 12, 4, 89, 8, 54, 1, 73, 
    1,  5, 0, 72, 5, 91, 6, 30, 2, 78, 3, 45, 4, 85, 7, 71, 8,  9, 
    3, 46, 2, 88, 1, 36, 4, 45, 0, 20, 7, 19, 6, 87, 5, 83, 8, 21, 
    7, 13, 5, 46, 2, 59, 0, 57, 3, 80, 1, 87, 8, 80, 4,  9, 6, 83, 
    4, 28, 6, 67, 2, 80, 5,  7, 8, 24, 7, 40, 0,  4, 3,  4, 1, 56, 
    8, 96, 2, 23, 5, 26, 4, 33, 7, 15, 3, 81, 0, 25, 1, 83, 6, 38
  };
  const int q1261[] = {
    9, 9, // Number of jobs and machines
    6, 56, 4, 24, 2, 20, 3, 72, 1, 21, 8, 41, 7, 22, 0, 46, 5, 98, 
    3, 39, 2, 11, 4, 78, 0, 14, 1, 91, 5, 62, 6, 84, 7, 21, 8,  6, 
    0, 19, 4, 64, 3, 68, 5, 58, 7,  8, 6, 56, 2, 61, 1, 54, 8, 89, 
    0, 12, 6, 99, 2, 63, 5,  7, 8, 90, 7,  4, 4, 86, 1, 85, 3, 17, 
    6, 84, 3,  6, 4,  6, 2, 15, 1,  4, 8, 71, 0, 24, 5, 34, 7, 36, 
    7,  3, 8,  6, 4, 83, 5, 41, 2,  3, 3, 21, 1,  7, 0, 22, 6, 39, 
    5,  1, 2, 59, 1, 95, 6, 19, 0, 71, 8, 99, 4, 95, 3,  7, 7, 79, 
    6, 82, 1, 14, 5, 89, 8, 63, 3, 26, 0, 64, 7, 59, 4, 18, 2, 99, 
    4, 14, 2, 24, 3, 67, 8, 17, 5, 28, 7, 73, 6, 65, 1, 16, 0,  7
  };
  const int q1262[] = {
    9, 9, // Number of jobs and machines
    4,  4, 2, 64, 5,  7, 6, 54, 3, 96, 8, 56, 7,  1, 0, 85, 1, 52, 
    2, 21, 0, 74, 1, 29, 4, 81, 8, 27, 3, 75, 7, 24, 5, 59, 6, 56, 
    3, 48, 5, 45, 6, 24, 4, 43, 0, 58, 7, 77, 1, 21, 2, 22, 8, 80, 
    5, 94, 3, 49, 4, 71, 1, 95, 8, 94, 6, 52, 7, 12, 2, 41, 0, 20, 
    1, 30, 0, 24, 7, 43, 6, 94, 5, 47, 2,  2, 3, 27, 8, 87, 4, 55, 
    8, 73, 5, 65, 1,  9, 6, 41, 3, 41, 2, 11, 7, 83, 0, 49, 4, 73, 
    7, 49, 0, 74, 6, 13, 4, 95, 8, 47, 1, 32, 2,  4, 5, 17, 3, 72, 
    6, 77, 1, 46, 2, 73, 7, 87, 4, 45, 5,  7, 0, 61, 8, 25, 3, 18, 
    1, 14, 3, 35, 6, 23, 5, 37, 0, 85, 2, 15, 7, 25, 8, 75, 4, 83
  };
  const int q1263[] = {
    9, 9, // Number of jobs and machines
    0, 53, 2, 69, 5, 25, 4, 44, 3, 87, 8, 97, 6, 34, 1, 89, 7, 58, 
    1,  3, 8, 55, 3, 34, 5, 13, 6, 18, 0, 49, 4, 98, 2, 47, 7,  4, 
    8, 43, 1, 57, 2, 43, 6,  7, 5,  6, 0, 66, 4, 41, 3, 63, 7, 92, 
    4, 46, 3, 83, 1, 18, 2, 58, 7, 68, 8, 93, 0, 32, 5,  3, 6, 19, 
    5, 75, 0,  1, 8, 84, 3, 27, 7, 53, 2, 81, 6, 23, 4, 39, 1, 76, 
    4, 34, 6, 73, 3, 53, 8, 47, 7, 12, 0, 79, 1, 48, 2, 71, 5, 85, 
    1, 87, 6, 21, 3, 18, 8, 15, 5, 19, 0, 15, 4, 45, 2, 83, 7, 12, 
    6, 49, 5, 65, 3, 80, 1, 16, 2, 21, 8,  5, 4, 49, 0, 56, 7, 60, 
    2, 36, 1, 24, 0, 45, 3, 40, 8, 29, 5, 59, 4, 88, 6, 44, 7,  3
  };
  const int q1264[] = {
    9, 9, // Number of jobs and machines
    5, 49, 4, 92, 0, 16, 1, 89, 3, 37, 7, 82, 2, 71, 8, 59, 6,  3, 
    1, 79, 2, 28, 3, 48, 0, 71, 8,  8, 5, 80, 7, 15, 4, 60, 6, 62, 
    2, 26, 4, 29, 5, 28, 1, 55, 0, 35, 3, 40, 7, 49, 8, 76, 6, 92, 
    0, 35, 8, 85, 4, 68, 1,  7, 5, 18, 6, 19, 3, 26, 7, 77, 2, 91, 
    3, 94, 0, 28, 6, 20, 8, 50, 2, 57, 1, 93, 4, 11, 5, 72, 7,  4, 
    4, 90, 5, 11, 8, 49, 3,  5, 0,  3, 6, 17, 7, 82, 1, 63, 2, 11, 
    7, 78, 8,  8, 4, 84, 2, 21, 1, 72, 0, 20, 3, 51, 5,  9, 6, 69, 
    0, 81, 7, 94, 5,  7, 3, 33, 2,  8, 8,  2, 6, 11, 1, 71, 4, 88, 
    4, 89, 2, 97, 3, 82, 1, 72, 0, 96, 7, 73, 8,  4, 6, 29, 5,  2
  };
  const int q1265[] = {
    9, 9, // Number of jobs and machines
    8, 78, 7, 11, 3, 59, 0, 94, 2, 68, 1, 78, 4, 54, 6, 84, 5, 28, 
    2, 49, 8, 87, 6, 46, 5, 75, 3, 54, 1,  9, 4, 36, 0,  9, 7, 61, 
    2, 42, 5, 88, 4, 52, 0, 37, 1, 30, 6, 79, 7,  9, 8, 71, 3, 86, 
    6, 78, 2, 97, 5, 72, 8, 14, 0, 36, 7, 76, 3, 88, 1, 92, 4, 31, 
    2,  8, 7, 74, 4, 60, 3, 22, 5, 67, 8, 66, 0, 46, 1, 43, 6, 12, 
    2, 66, 4, 75, 0,  4, 1, 79, 8, 92, 3,  8, 6, 75, 7, 38, 5, 99, 
    6, 78, 1, 96, 7, 19, 4, 83, 0, 82, 2, 67, 8, 58, 3, 74, 5,  4, 
    4, 78, 2, 29, 6, 26, 7, 76, 1, 14, 0, 35, 5, 17, 8, 28, 3, 38, 
    8, 97, 6, 87, 2, 60, 3, 12, 4, 25, 7, 75, 5,  2, 1, 29, 0, 36
  };
  const int q1266[] = {
    9, 9, // Number of jobs and machines
    3, 72, 0, 28, 1, 36, 7, 58, 2, 19, 5, 18, 4, 63, 6, 63, 8, 38, 
    4, 99, 6,  1, 1, 19, 3, 90, 8, 35, 0, 32, 2, 78, 5, 71, 7, 49, 
    2, 62, 3, 30, 7, 21, 8, 23, 6, 11, 5, 96, 4, 96, 0,  9, 1, 57, 
    1, 23, 4, 49, 5, 73, 0, 57, 7, 82, 6, 24, 8, 52, 3, 69, 2, 28, 
    8, 13, 2, 21, 7, 45, 4, 40, 1, 97, 5, 84, 6, 22, 3, 81, 0, 57, 
    1, 99, 8, 44, 7, 48, 5, 65, 3,  9, 0, 94, 2, 89, 4, 20, 6, 28, 
    2, 78, 5, 68, 1, 24, 0, 40, 6, 79, 8, 71, 3, 66, 7, 67, 4, 69, 
    3, 95, 2, 99, 0, 32, 4, 16, 7, 31, 1, 23, 8, 46, 5, 36, 6, 85, 
    8, 61, 1, 64, 6, 25, 5,  4, 7, 94, 3, 52, 2,  1, 4, 85, 0,  4
  };
  const int q1267[] = {
    9, 9, // Number of jobs and machines
    4, 56, 6,  1, 7, 72, 5, 83, 0, 26, 8, 13, 2, 90, 3, 49, 1, 52, 
    0, 69, 2, 40, 4,  2, 5, 48, 8, 42, 3, 54, 6, 66, 1, 86, 7, 66, 
    4, 19, 6, 82, 3, 61, 0, 31, 8, 44, 2, 50, 7, 68, 5, 40, 1, 21, 
    1, 25, 4,  5, 5, 63, 6, 73, 3, 94, 0, 56, 7, 67, 8, 41, 2, 72, 
    7, 99, 4,  1, 6, 23, 8, 33, 0, 26, 2, 88, 3, 22, 5, 61, 1, 32, 
    2, 14, 8, 24, 6, 36, 0, 83, 4, 11, 3, 92, 1, 76, 5, 64, 7, 15, 
    3, 41, 5,  9, 6, 52, 7, 67, 2, 70, 0, 27, 4, 10, 1, 83, 8, 60, 
    3, 74, 5, 33, 4, 27, 6, 13, 7, 94, 8, 65, 1, 86, 0, 97, 2, 42, 
    6, 34, 1, 59, 2, 15, 3, 87, 4, 97, 5, 67, 7,  5, 8,  9, 0,  9
  };
  const int q1268[] = {
    9, 9, // Number of jobs and machines
    5, 80, 7, 91, 1, 63, 0, 86, 2, 10, 8, 67, 6, 23, 4, 43, 3, 76, 
    1, 81, 7, 75, 2, 65, 0, 55, 3, 87, 6, 10, 4, 51, 5, 60, 8, 32, 
    4, 46, 0, 92, 1, 14, 7, 55, 8, 24, 6, 41, 3, 19, 5, 59, 2, 40, 
    0, 15, 8, 24, 2, 53, 3, 82, 4, 37, 6, 27, 7, 33, 1, 12, 5, 38, 
    1, 68, 7, 35, 3, 48, 4, 88, 2, 41, 8, 62, 6, 30, 5, 24, 0, 15, 
    0, 92, 4, 69, 5,  1, 3, 86, 8, 41, 1, 47, 2, 46, 6, 74, 7, 20, 
    4, 62, 6, 98, 1, 79, 7, 93, 3, 18, 0, 84, 2,  2, 8, 80, 5, 33, 
    8, 32, 6, 89, 4, 79, 5,  2, 0, 12, 2, 79, 1, 16, 3, 33, 7, 76, 
    8, 93, 0, 57, 5, 18, 1, 95, 2, 41, 3, 70, 7, 71, 6, 92, 4, 71
  };
  const int q1269[] = {
    9, 9, // Number of jobs and machines
    6, 56, 7, 90, 4, 95, 3, 46, 0,  7, 1, 20, 8, 64, 2, 32, 5, 43, 
    7, 60, 1, 81, 6, 40, 8, 50, 0, 16, 4,  6, 2, 26, 3, 58, 5, 29, 
    1, 13, 4, 54, 3, 42, 2,  4, 0, 53, 8, 21, 7,  1, 6, 54, 5, 23, 
    3, 80, 1, 48, 2, 99, 0, 30, 4, 71, 7, 16, 8, 55, 5, 15, 6, 24, 
    7, 60, 0, 62, 2, 38, 6, 76, 8, 83, 1, 94, 5, 41, 3, 12, 4, 82, 
    8, 24, 5, 89, 0, 67, 4, 97, 7, 92, 3, 28, 1,  6, 6, 45, 2,  5, 
    4, 80, 1, 75, 7,  4, 6, 83, 0, 27, 3, 16, 5,  2, 8, 81, 2, 33, 
    0, 53, 8, 97, 4, 54, 6, 41, 5, 63, 1, 24, 3,  8, 7, 32, 2, 77, 
    8, 37, 6,  9, 7, 42, 4, 88, 1, 19, 5, 41, 0, 76, 3,  1, 2, 54
  };
  const int q1270[] = {
    9, 9, // Number of jobs and machines
    0, 95, 4, 88, 6, 86, 7, 63, 3, 64, 1, 13, 2, 38, 5, 20, 8,  4, 
    5, 40, 1, 13, 7,  9, 6, 46, 2, 95, 3, 70, 0, 66, 4, 80, 8, 26, 
    3, 44, 1, 25, 4, 64, 0, 59, 6, 94, 5, 98, 2,  5, 7, 94, 8, 75, 
    8, 86, 5, 53, 7, 58, 3, 27, 2, 62, 1, 92, 0,  3, 6, 76, 4, 49, 
    0, 25, 8, 11, 4, 62, 2, 50, 7, 37, 1, 51, 5,  7, 3, 53, 6, 92, 
    7, 16, 6, 72, 5, 30, 1, 16, 4, 43, 8, 73, 2, 96, 3, 24, 0, 19, 
    8, 87, 1, 50, 7, 21, 4, 41, 6, 58, 5, 20, 3, 19, 2,  4, 0, 80, 
    1, 20, 4, 37, 5, 74, 0, 52, 7, 32, 3, 93, 2, 55, 8, 28, 6, 92, 
    5, 93, 3, 61, 0, 62, 6, 83, 4, 86, 8, 49, 1, 49, 2, 61, 7, 62
  };
  const int q1271[] = {
    9, 9, // Number of jobs and machines
    3, 87, 6, 50, 5, 76, 0, 53, 1,  4, 2, 97, 8, 81, 4, 48, 7, 89, 
    0, 40, 1, 64, 8, 39, 2, 89, 3, 95, 6, 81, 5, 97, 7, 22, 4, 37, 
    2, 33, 7, 10, 6, 13, 0, 84, 1, 22, 8, 36, 4, 84, 3, 21, 5,  3, 
    0, 83, 4, 36, 2, 29, 5, 53, 6, 11, 8, 88, 1, 51, 3, 32, 7, 78, 
    7,  9, 1, 18, 3, 54, 0, 66, 4,  1, 6, 17, 2, 31, 5, 84, 8, 54, 
    2,  7, 1, 52, 5, 51, 8,  7, 6,  7, 3,  4, 7, 87, 4, 52, 0, 43, 
    6, 50, 0, 36, 5, 60, 8, 78, 1, 17, 4, 70, 2, 84, 7, 64, 3, 10, 
    6, 59, 8, 70, 3, 72, 5, 70, 1, 37, 2, 30, 7,  3, 0, 84, 4, 57, 
    7, 62, 0, 44, 6,  4, 2, 48, 4, 91, 3, 16, 8, 69, 5, 67, 1, 74
  };
  const int q1272[] = {
    9, 9, // Number of jobs and machines
    8, 55, 0, 90, 3, 98, 6, 65, 5, 35, 4, 59, 2, 95, 7, 22, 1,  1, 
    1, 24, 7, 67, 4, 53, 6, 49, 8, 70, 0, 77, 3, 79, 2, 10, 5, 43, 
    3, 37, 7, 56, 4, 11, 2, 57, 8, 32, 0,  7, 1, 27, 5, 85, 6, 52, 
    0, 88, 6, 26, 7, 25, 4, 70, 8, 50, 2, 53, 3, 90, 5, 45, 1, 95, 
    0, 92, 1, 47, 6, 90, 2, 10, 3, 10, 5, 14, 7, 35, 4,  9, 8, 17, 
    8, 86, 3, 83, 2, 97, 5, 11, 6, 11, 7, 70, 0, 28, 4, 94, 1, 11, 
    4, 32, 5, 18, 3, 94, 2, 97, 6, 22, 7, 34, 0, 70, 8, 28, 1, 54, 
    3, 20, 8, 21, 4,  3, 7,  9, 5, 14, 0, 92, 2, 39, 1, 98, 6, 57, 
    8, 53, 4, 88, 6, 55, 0, 30, 5, 44, 1,  4, 7, 74, 3, 95, 2, 64
  };
  const int q1273[] = {
    9, 9, // Number of jobs and machines
    4, 62, 0, 21, 8,  3, 3, 47, 7, 22, 1, 69, 5, 20, 6, 78, 2, 61, 
    1, 70, 2, 87, 5, 45, 7, 62, 8, 15, 6,  3, 3, 61, 4, 82, 0,  1, 
    0, 10, 5, 77, 3, 99, 6, 24, 7, 90, 1, 24, 8, 28, 4, 85, 2, 22, 
    7, 38, 6, 61, 5, 64, 4, 84, 3, 66, 1, 86, 2, 50, 8, 26, 0, 10, 
    4, 15, 8,  1, 7, 32, 2, 71, 1, 37, 6, 50, 5, 39, 0, 45, 3, 91, 
    4,  8, 5, 30, 7, 48, 2, 68, 6,  2, 8, 62, 3, 45, 1, 22, 0, 33, 
    6, 45, 5, 89, 8, 12, 1, 61, 4, 29, 3,  7, 7, 27, 2, 19, 0, 12, 
    3, 41, 2, 71, 4, 59, 7, 83, 5,  8, 8, 14, 6, 64, 0, 49, 1, 14, 
    7, 33, 6, 19, 2, 21, 8, 33, 1, 29, 4, 97, 0, 60, 3, 53, 5,  2
  };
  const int q1274[] = {
    9, 9, // Number of jobs and machines
    5, 92, 2, 64, 6, 47, 7, 91, 4, 72, 3, 43, 1, 54, 0, 61, 8, 54, 
    5, 81, 3,  6, 0, 13, 7, 82, 4, 15, 2, 27, 8, 35, 1, 96, 6, 94, 
    2, 22, 7, 62, 0, 83, 1, 52, 3, 93, 4, 72, 8, 28, 5, 26, 6, 87, 
    1, 40, 2, 48, 7, 93, 4, 72, 6, 80, 0, 20, 8, 64, 3, 22, 5,  5, 
    4, 27, 3, 68, 7, 98, 8, 69, 1, 55, 0, 21, 5, 85, 2, 38, 6,  3, 
    0, 86, 8, 59, 4, 91, 1, 29, 6, 95, 7, 28, 3, 78, 2,  9, 5, 12, 
    5, 71, 2, 94, 7, 13, 3, 44, 0, 57, 4, 79, 8,  5, 6,  9, 1, 24, 
    0, 41, 6, 79, 7, 56, 8, 58, 2, 19, 5, 32, 4, 64, 3, 46, 1, 43, 
    3, 81, 0, 65, 6, 76, 4, 87, 7, 43, 2, 60, 5, 90, 1, 13, 8, 42
  };
  const int q1275[] = {
    9, 9, // Number of jobs and machines
    0, 57, 7, 90, 1, 79, 3, 75, 5, 59, 4, 45, 6, 66, 2, 91, 8, 10, 
    0, 60, 5, 59, 6, 53, 8,  1, 3, 35, 2, 46, 1, 33, 7, 57, 4, 18, 
    5, 16, 4,  2, 3, 69, 0, 78, 7, 72, 8, 11, 1, 50, 6, 32, 2,  3, 
    2, 81, 6, 63, 0, 73, 3, 67, 8, 30, 7, 51, 5, 76, 4, 81, 1, 58, 
    3, 11, 8, 47, 0, 70, 2, 51, 6, 79, 4, 27, 7, 23, 1, 37, 5, 83, 
    5, 63, 2, 20, 6, 56, 7, 57, 0, 80, 8, 42, 1, 34, 4, 56, 3, 96, 
    5, 79, 7,  2, 0, 18, 8, 12, 4,  2, 1,  6, 3, 61, 6, 12, 2, 79, 
    1,  2, 0, 68, 5,  3, 7, 57, 6, 30, 4,  5, 3, 35, 2, 47, 8, 84, 
    5,  7, 2, 79, 7, 16, 3, 88, 1, 28, 0, 32, 4, 21, 8, 18, 6, 67
  };
  const int q1276[] = {
    9, 9, // Number of jobs and machines
    4, 59, 8, 84, 1, 98, 7, 65, 5, 43, 2, 29, 3,  7, 0, 45, 6, 14, 
    4, 73, 0, 30, 6, 84, 3, 47, 8, 30, 5, 23, 7, 52, 2,  4, 1, 35, 
    8, 62, 1, 67, 5, 77, 3, 64, 2, 32, 0, 72, 4, 19, 7, 35, 6, 74, 
    1, 65, 4, 28, 7, 23, 8, 59, 2, 81, 3, 17, 6, 56, 5, 82, 0, 20, 
    8, 73, 1, 97, 7, 23, 4, 66, 3, 84, 6, 70, 0, 20, 2, 94, 5, 79, 
    3, 29, 5, 74, 6,  6, 7, 46, 4, 64, 2, 48, 1, 97, 0, 58, 8, 58, 
    5, 69, 3,  7, 6, 45, 4, 60, 1, 12, 2, 10, 8, 71, 7, 71, 0, 10, 
    8, 59, 2, 86, 1, 96, 3, 72, 4, 89, 7,  9, 6, 64, 0, 72, 5, 50, 
    7, 52, 4, 53, 6, 77, 8, 94, 0, 77, 1, 60, 5, 17, 2, 29, 3, 20
  };
  const int q1277[] = {
    9, 9, // Number of jobs and machines
    4, 48, 7, 51, 0, 95, 3, 72, 2, 54, 5, 83, 6, 15, 1, 40, 8, 20, 
    2, 35, 0, 72, 7, 54, 5, 82, 1, 21, 8, 78, 3, 92, 4, 98, 6, 69, 
    4, 29, 0, 82, 6, 72, 8, 85, 5, 84, 3, 22, 7, 31, 2, 52, 1,  6, 
    4,  4, 2, 85, 0, 60, 7, 70, 1, 26, 6, 17, 5, 81, 8, 33, 3, 32, 
    1, 16, 8, 98, 4, 27, 6, 23, 3,  6, 0, 98, 2, 26, 7, 14, 5, 65, 
    8, 53, 0, 21, 3, 55, 6, 69, 2, 14, 5, 25, 7, 81, 1, 51, 4, 12, 
    3,  5, 4, 78, 1, 26, 7, 60, 2, 62, 5,  4, 8, 83, 0, 27, 6,  6, 
    5, 56, 7, 98, 0, 81, 8, 36, 1, 92, 6, 78, 3, 90, 4, 66, 2,  5, 
    4,  3, 7, 55, 3, 28, 8, 26, 1, 61, 6, 65, 0,  9, 5, 23, 2, 69
  };
  const int q1278[] = {
    9, 9, // Number of jobs and machines
    4, 62, 0, 84, 3, 60, 2, 20, 6, 43, 8, 24, 5,  2, 1, 38, 7, 15, 
    3, 11, 0, 64, 8, 82, 1, 78, 2, 54, 7, 46, 5, 35, 4, 15, 6, 47, 
    2, 30, 1, 37, 5, 66, 4, 95, 0, 87, 3, 32, 8, 92, 7, 43, 6, 74, 
    0, 31, 1, 67, 4, 54, 2, 66, 6, 93, 3, 99, 5,  1, 8, 54, 7, 85, 
    8, 36, 1,  4, 5, 35, 6, 66, 4, 54, 3, 55, 2, 82, 7, 47, 0, 90, 
    7, 95, 4, 70, 1, 63, 3, 36, 5, 19, 8, 54, 6, 27, 0,  1, 2, 11, 
    1, 41, 4, 78, 2, 20, 6, 11, 0, 70, 5, 79, 8, 87, 7, 22, 3, 65, 
    3, 87, 2,  3, 8, 63, 5, 61, 0, 77, 6, 96, 1,  5, 7, 36, 4, 56, 
    2, 87, 3, 31, 8, 70, 7, 67, 6, 39, 4, 28, 0, 19, 1, 22, 5, 96
  };
  const int q1279[] = {
    9, 9, // Number of jobs and machines
    8, 91, 5, 47, 2,  4, 0, 54, 4, 23, 3, 83, 6, 86, 7, 50, 1, 58, 
    1,  3, 4,  3, 5, 17, 7, 28, 0, 45, 2, 29, 3, 15, 6, 30, 8, 27, 
    6, 52, 2, 62, 4, 87, 0, 96, 3, 67, 7, 75, 5, 79, 1, 58, 8, 17, 
    6, 62, 4, 91, 7, 12, 1, 95, 3,  1, 8,  7, 0, 96, 2, 11, 5, 11, 
    2, 61, 6, 61, 0, 79, 4, 40, 1, 23, 3, 59, 5, 98, 7, 96, 8, 12, 
    5, 66, 0, 17, 8,  9, 6,  2, 2, 97, 1, 52, 7, 60, 4, 46, 3, 17, 
    0, 89, 1, 95, 6, 79, 4, 71, 5, 46, 3, 76, 8, 47, 2, 77, 7, 62, 
    7, 23, 3, 80, 6,  9, 2, 42, 5, 74, 4,  6, 1,  3, 0,  8, 8, 74, 
    3, 51, 8, 94, 0, 34, 4, 80, 6, 27, 2, 19, 1, 59, 5,  9, 7, 86
  };
  const int q1280[] = {
    9, 9, // Number of jobs and machines
    3, 79, 8, 36, 4, 72, 1, 10, 7, 80, 5, 25, 6, 35, 0, 58, 2, 63, 
    0, 17, 8, 54, 4, 73, 2, 27, 3, 33, 1, 25, 6, 90, 5, 80, 7, 87, 
    7, 94, 1, 15, 8, 78, 6, 82, 2, 17, 0, 42, 5, 45, 4, 98, 3, 76, 
    4, 71, 0, 95, 7, 67, 5, 85, 3, 13, 2, 12, 1, 80, 6, 31, 8, 22, 
    2, 46, 3, 61, 4, 82, 6, 91, 1, 67, 0, 64, 5, 71, 8, 86, 7, 89, 
    6, 21, 1, 56, 2, 27, 4, 49, 5, 15, 8, 37, 7, 72, 0, 92, 3, 38, 
    8, 70, 5, 24, 4, 33, 6, 76, 3, 91, 7, 18, 0, 22, 2, 54, 1, 48, 
    2, 30, 8, 32, 5, 19, 1, 97, 4, 43, 6, 94, 0,  3, 3,  7, 7, 84, 
    0, 64, 1, 46, 8, 74, 2, 83, 3, 28, 6, 29, 5,  4, 7, 54, 4, 32
  };
  const int q1281[] = {
    9, 9, // Number of jobs and machines
    0, 82, 7, 27, 8, 20, 5, 83, 3, 78, 4, 36, 1,  3, 2, 48, 6, 10, 
    3, 26, 8,  8, 5, 40, 6, 30, 2, 25, 7, 10, 1, 63, 4, 81, 0, 21, 
    6, 37, 2, 84, 5, 79, 7,  2, 1, 32, 3, 73, 8, 88, 4, 69, 0, 80, 
    4, 63, 1, 63, 5, 14, 2, 89, 7, 65, 3, 18, 0, 51, 6, 90, 8, 54, 
    1, 82, 2, 61, 4, 79, 7, 90, 3, 45, 6,  7, 5, 95, 0, 64, 8, 17, 
    2, 95, 0, 73, 8, 49, 5, 20, 4, 70, 3, 76, 6, 15, 7, 98, 1, 60, 
    1, 54, 0, 33, 7, 34, 8, 62, 3, 12, 6, 29, 5, 76, 2, 34, 4, 27, 
    0, 55, 3, 34, 6, 29, 4, 37, 5, 95, 1, 43, 7, 55, 2, 41, 8, 17, 
    1, 93, 8, 72, 6, 89, 2, 26, 7, 85, 4, 66, 0, 34, 3, 94, 5, 25
  };
  const int q1282[] = {
    9, 9, // Number of jobs and machines
    3, 88, 7, 23, 8, 13, 0, 25, 1, 81, 6, 14, 5, 98, 2, 24, 4, 10, 
    0, 17, 7, 87, 2, 51, 1, 45, 3, 71, 6, 68, 5,  3, 4, 92, 8, 69, 
    5, 70, 2, 36, 1, 11, 0, 34, 3,  5, 7, 14, 4, 40, 8, 38, 6, 50, 
    0, 47, 1, 63, 8, 93, 6, 83, 2, 44, 3, 58, 4, 68, 7, 37, 5, 85, 
    7, 46, 8, 76, 3, 29, 1, 28, 4, 10, 5, 76, 2, 91, 6, 20, 0,  4, 
    2, 74, 1, 19, 3, 92, 5, 90, 0, 62, 4, 70, 6, 91, 7, 22, 8, 57, 
    8, 16, 0, 54, 4, 83, 6, 22, 1, 71, 3, 30, 2, 54, 5, 22, 7, 25, 
    6, 34, 7, 91, 1, 70, 3, 40, 0, 77, 5, 95, 8, 62, 2, 12, 4, 23, 
    7, 94, 6, 40, 2, 51, 8,  9, 3, 76, 5, 51, 1, 72, 4, 83, 0, 31
  };
  const int q1283[] = {
    9, 9, // Number of jobs and machines
    2, 98, 5, 20, 1, 97, 4, 37, 7, 17, 3, 50, 0, 21, 8, 89, 6, 71, 
    8, 52, 0, 44, 3, 17, 7, 29, 6, 39, 2, 42, 4, 49, 5,  5, 1, 37, 
    6, 97, 4,  8, 3, 40, 8,  2, 2,  4, 5, 62, 0, 53, 7, 89, 1, 57, 
    4, 48, 2, 23, 8, 84, 6, 15, 0, 45, 5, 39, 3, 18, 1, 42, 7, 40, 
    3, 63, 8, 24, 6, 49, 2, 97, 4, 13, 5,  9, 7, 41, 0, 43, 1, 99, 
    2, 42, 4, 70, 1, 85, 3, 42, 6, 15, 7, 60, 5, 50, 8, 80, 0, 76, 
    6, 56, 4, 49, 2, 17, 8,  6, 7, 62, 0, 56, 5, 68, 3, 83, 1, 57, 
    6, 92, 1, 71, 5, 73, 2, 22, 8, 15, 0, 16, 7, 88, 4, 93, 3, 91, 
    6, 88, 4, 14, 1, 97, 0, 63, 8, 59, 3, 54, 7, 40, 2, 76, 5, 69
  };
  const int q1284[] = {
    9, 9, // Number of jobs and machines
    1, 27, 0, 39, 7, 95, 3, 68, 4, 88, 6, 28, 5, 91, 8, 16, 2, 96, 
    4, 40, 7, 50, 5, 47, 6, 98, 0, 45, 3, 21, 8, 15, 1,  4, 2, 11, 
    7, 37, 8, 33, 3, 39, 6, 64, 1, 93, 5, 28, 2, 21, 0, 70, 4, 79, 
    4,  6, 8, 28, 2, 79, 5, 67, 1, 24, 7, 49, 6, 89, 3, 44, 0, 33, 
    4, 65, 0, 65, 8, 69, 3, 88, 2, 28, 7, 56, 1, 53, 5, 49, 6,  2, 
    7, 90, 1,  5, 0, 77, 2, 99, 6, 70, 8, 59, 4, 61, 5, 52, 3, 91, 
    3, 63, 1, 51, 8, 52, 5, 52, 4, 65, 6, 79, 7, 68, 2,  6, 0,  1, 
    1, 57, 2, 12, 5, 63, 3,  8, 0, 57, 4, 29, 6, 14, 8, 61, 7, 41, 
    6, 51, 0, 78, 3, 35, 4, 33, 7, 28, 2, 90, 1,  3, 8, 14, 5, 83
  };
  const int q1285[] = {
    9, 9, // Number of jobs and machines
    2,  4, 0, 75, 3, 46, 8, 77, 5, 59, 7, 21, 6, 13, 4, 44, 1,  8, 
    3, 11, 5, 78, 7, 19, 1, 20, 0, 91, 8, 80, 2, 80, 6, 72, 4, 48, 
    1, 54, 5,  1, 6, 73, 2, 64, 4, 61, 7, 72, 3, 51, 8, 14, 0, 76, 
    6, 99, 3, 86, 5, 27, 4, 70, 0, 68, 7, 67, 2, 98, 8, 17, 1, 58, 
    5,  1, 2, 35, 0, 14, 1, 28, 7, 88, 3,  8, 4, 78, 6, 86, 8,  6, 
    0, 47, 6, 72, 2, 83, 1, 19, 8, 70, 4, 13, 7,  7, 3,  9, 5, 98, 
    7, 32, 1, 67, 8, 94, 4, 40, 6, 99, 2, 15, 3, 44, 0, 82, 5, 14, 
    7, 89, 1, 19, 5, 24, 4, 57, 8,  2, 3, 75, 6, 77, 0, 38, 2, 37, 
    3, 41, 7, 95, 1,  7, 4, 95, 0, 37, 5,  5, 6, 13, 2, 67, 8, 78
  };
  const int q1286[] = {
    9, 9, // Number of jobs and machines
    6, 85, 0, 14, 7, 87, 4, 82, 3, 92, 5, 24, 2, 68, 1, 44, 8,  5, 
    6, 38, 5, 89, 0,  5, 4, 55, 3, 34, 2, 40, 1, 71, 8, 82, 7,  2, 
    8, 43, 2, 15, 6, 29, 5, 64, 4, 13, 3, 64, 1, 17, 0, 95, 7, 24, 
    5, 68, 4, 51, 1, 28, 2, 53, 0, 34, 3, 96, 6, 86, 8, 28, 7, 97, 
    0,  2, 4, 88, 3, 23, 7, 39, 2, 66, 8, 48, 5, 19, 6, 70, 1, 77, 
    4, 44, 1, 83, 6,  8, 3, 23, 0, 86, 8, 58, 5, 31, 2, 13, 7, 21, 
    6, 41, 4,  9, 2, 41, 8, 44, 5,  7, 0, 30, 3, 84, 7, 76, 1, 86, 
    1, 75, 5, 24, 0, 98, 6, 47, 4, 99, 7, 90, 8,  9, 3, 11, 2, 63, 
    6, 82, 5, 74, 4, 68, 1, 23, 2, 65, 3, 20, 0,  2, 8, 65, 7, 21
  };
  const int q1287[] = {
    9, 9, // Number of jobs and machines
    7, 47, 2, 80, 0,  6, 1,  2, 8, 76, 5, 51, 6, 67, 3, 57, 4, 64, 
    8, 67, 7, 30, 2, 33, 6, 47, 3, 86, 4, 72, 0, 73, 5, 85, 1, 89, 
    8, 69, 6,  1, 3, 53, 1, 17, 5, 15, 7, 30, 0, 36, 4, 63, 2, 72, 
    2, 76, 8, 90, 5, 62, 6, 10, 0, 16, 1, 43, 4, 13, 7, 46, 3, 73, 
    4, 14, 2, 79, 0, 48, 6,  9, 1, 21, 3, 71, 8, 93, 5, 93, 7, 51, 
    3, 40, 1, 43, 7, 43, 8, 89, 2, 46, 6, 36, 0, 13, 5, 28, 4, 56, 
    2, 86, 0,  9, 7, 72, 8, 59, 6, 28, 1, 36, 3, 22, 5, 89, 4, 11, 
    3, 10, 4, 38, 7, 10, 6, 19, 1, 43, 2, 46, 8, 77, 5, 21, 0, 92, 
    3,  5, 5, 44, 1, 57, 0, 84, 8, 38, 2, 43, 7, 91, 4, 92, 6, 85
  };
  const int q1288[] = {
    9, 9, // Number of jobs and machines
    4, 90, 6, 32, 5, 96, 2, 24, 8, 20, 1, 96, 7, 82, 3, 55, 0, 36, 
    0, 18, 4, 14, 8,  9, 1, 59, 3, 22, 2,  5, 5, 63, 7, 19, 6, 39, 
    3, 86, 4, 10, 0, 14, 5, 83, 7, 76, 2, 84, 6, 56, 8, 68, 1, 43, 
    6, 53, 7, 47, 4, 28, 2, 37, 1, 29, 0, 59, 8, 76, 5,  9, 3, 88, 
    7, 29, 4, 28, 6, 47, 3,  6, 0, 65, 8, 78, 2, 84, 1, 74, 5, 81, 
    2, 16, 8, 35, 5, 30, 6, 85, 3, 70, 0, 85, 4, 56, 1, 30, 7, 63, 
    8, 43, 7, 13, 1, 63, 0, 97, 5, 44, 3, 35, 6, 30, 2,  6, 4, 78, 
    7, 38, 3, 49, 1, 42, 0,  2, 8,  9, 6, 37, 2, 25, 4, 63, 5, 67, 
    6, 33, 4, 40, 2, 67, 5, 42, 0, 42, 7,  3, 3,  1, 1, 67, 8, 12
  };
  const int q1289[] = {
    9, 9, // Number of jobs and machines
    8, 42, 7, 56, 1, 72, 3, 84, 4, 19, 5, 83, 0, 80, 2, 11, 6,  9, 
    8, 52, 6, 64, 1, 74, 4, 14, 3, 74, 5, 76, 2, 84, 7, 59, 0, 70, 
    7, 40, 1, 20, 6, 10, 3, 69, 4, 29, 2, 34, 8, 20, 0, 24, 5, 40, 
    1, 68, 5, 39, 3, 40, 2, 92, 0, 22, 6, 56, 8, 54, 7, 97, 4, 23, 
    8, 63, 4, 24, 7, 19, 0, 76, 5,  8, 3, 29, 2,  4, 6,  3, 1, 38, 
    3, 24, 8, 17, 4, 84, 7, 60, 5, 62, 2, 50, 1, 86, 0, 28, 6, 29, 
    3, 99, 2, 58, 5, 46, 7, 29, 8, 56, 1, 16, 4, 32, 0, 34, 6, 97, 
    8, 96, 6, 51, 7, 71, 0, 97, 1, 77, 2, 31, 4, 12, 5, 51, 3, 17, 
    0, 17, 1,  9, 8, 35, 5, 95, 7, 70, 3, 63, 6, 73, 4, 33, 2, 16
  };
  const int q1290[] = {
    9, 9, // Number of jobs and machines
    0,  7, 7,  4, 6, 14, 8, 43, 3, 30, 4, 72, 1,  5, 2, 38, 5, 50, 
    3, 27, 8, 21, 2, 38, 4, 68, 5, 83, 1, 18, 6,  8, 0, 39, 7, 26, 
    4, 74, 1, 56, 7, 15, 5, 42, 2, 80, 8, 78, 0, 75, 3, 80, 6, 63, 
    6, 58, 1,  7, 0, 57, 5, 45, 4, 40, 8, 94, 7, 63, 2, 80, 3, 39, 
    1, 59, 3,  5, 7,  8, 6, 92, 0, 29, 2, 34, 8, 15, 5, 30, 4, 64, 
    4,  9, 5, 23, 2, 59, 6, 35, 3, 91, 7, 10, 0, 96, 8, 25, 1,  5, 
    8, 44, 3, 70, 4, 40, 1, 36, 0, 73, 2, 48, 6, 64, 7, 66, 5, 97, 
    6,  6, 2, 15, 0, 24, 8, 94, 3, 74, 4, 83, 1, 84, 5, 42, 7, 10, 
    3, 45, 2,  5, 7, 57, 0, 63, 6, 66, 4, 60, 1,  2, 5, 80, 8, 33
  };
  const int q1291[] = {
    9, 9, // Number of jobs and machines
    2, 43, 0, 81, 1, 90, 6, 40, 3, 74, 5, 85, 4, 27, 8, 18, 7,  2, 
    1, 38, 7, 26, 5, 57, 4, 91, 2, 23, 3, 56, 8, 61, 0, 83, 6, 57, 
    4, 34, 8, 93, 1, 49, 7, 21, 6, 98, 0, 17, 3, 74, 2, 53, 5, 78, 
    0, 29, 3, 48, 1, 41, 4, 70, 6, 16, 8, 65, 7, 89, 2, 44, 5, 89, 
    2, 41, 5, 79, 1, 82, 7, 32, 6, 61, 0, 99, 3, 90, 4, 76, 8, 22, 
    6, 95, 8, 46, 5, 21, 3, 11, 1, 91, 7, 96, 2, 83, 0, 21, 4, 21, 
    1, 98, 6, 77, 7, 10, 5, 20, 0, 45, 4, 66, 2, 30, 8, 79, 3, 74, 
    8, 46, 5, 10, 0, 93, 4, 72, 1, 60, 2, 45, 7, 96, 3, 44, 6, 38, 
    3, 91, 1,  6, 7, 22, 0, 42, 2, 72, 6, 48, 4, 67, 8, 94, 5, 98
  };
  const int q1292[] = {
    9, 9, // Number of jobs and machines
    4, 34, 0, 63, 5, 89, 8, 84, 6, 47, 2, 34, 1, 58, 3,  1, 7, 58, 
    3, 23, 0, 81, 2, 47, 7, 58, 5, 44, 4, 72, 1, 40, 6, 95, 8, 79, 
    1, 28, 0, 96, 6, 98, 2, 85, 3, 48, 4, 34, 5,  6, 8, 55, 7, 40, 
    2, 33, 7, 91, 8,  8, 6, 44, 3, 38, 5, 58, 1, 48, 0, 21, 4,  2, 
    6, 64, 0, 68, 3, 51, 7, 45, 5, 36, 2, 71, 1, 70, 8, 93, 4, 40, 
    4, 35, 0, 96, 8, 63, 1, 93, 6,  3, 2, 10, 3, 84, 5, 75, 7, 60, 
    6, 84, 1, 41, 3, 90, 5, 60, 0,  9, 2, 65, 7, 99, 8, 15, 4, 67, 
    0, 17, 4, 53, 3, 53, 1, 16, 2, 87, 6, 67, 5, 96, 7, 55, 8, 76, 
    3, 65, 2, 34, 6, 86, 1, 35, 7, 73, 8, 84, 5, 57, 0, 22, 4, 49
  };
  const int q1293[] = {
    9, 9, // Number of jobs and machines
    5, 97, 2, 86, 4, 76, 3, 18, 0, 55, 6, 84, 7, 81, 8, 27, 1, 89, 
    0, 87, 4,  9, 3, 28, 5, 29, 6, 71, 2, 33, 1, 56, 8, 91, 7, 67, 
    4, 28, 2, 63, 8,  2, 1, 39, 5, 86, 3, 31, 0, 29, 7, 29, 6, 40, 
    6, 96, 7, 75, 4, 88, 1, 54, 2, 16, 5, 19, 8, 10, 3, 96, 0, 18, 
    1, 98, 2,  6, 3, 99, 7, 83, 4, 38, 6, 21, 8, 51, 0, 18, 5, 18, 
    7, 54, 0, 43, 5, 61, 4, 55, 3, 97, 1, 86, 2, 79, 6, 63, 8, 72, 
    6, 63, 3, 14, 7, 20, 1, 25, 2, 32, 4,  7, 8, 88, 0, 81, 5, 89, 
    4, 51, 5, 41, 0, 10, 7, 82, 8, 80, 3, 44, 2, 28, 6,  5, 1, 42, 
    5, 67, 6, 70, 3, 41, 4, 97, 0, 34, 7, 98, 2, 13, 8, 66, 1,  9
  };
  const int q1294[] = {
    9, 9, // Number of jobs and machines
    3, 20, 1,  6, 0, 48, 6, 93, 4, 48, 7, 66, 5, 43, 8, 13, 2, 11, 
    0,  4, 1, 24, 5, 56, 6, 65, 3, 86, 7, 85, 2, 10, 8, 17, 4, 66, 
    4, 14, 1,  3, 0, 91, 7, 33, 5, 22, 3, 89, 6, 91, 8, 21, 2, 47, 
    7, 13, 5, 77, 6, 59, 4, 63, 3, 30, 8, 88, 1, 73, 2, 39, 0, 89, 
    6, 65, 4, 57, 7, 43, 8, 11, 2, 65, 0, 79, 3, 74, 5, 39, 1, 23, 
    2, 71, 7, 69, 5, 86, 0, 77, 4,  3, 6, 78, 8, 39, 3, 57, 1, 56, 
    1, 75, 0,  7, 4,  9, 3, 77, 6, 48, 2, 17, 8, 30, 7, 28, 5, 40, 
    2, 49, 3, 48, 5,  5, 8, 59, 6,  7, 7, 15, 0, 30, 4, 90, 1,  2, 
    8,  9, 2, 96, 7, 52, 3, 20, 0, 36, 1, 70, 5, 25, 6,  9, 4, 22
  };
  const int q1295[] = {
    9, 9, // Number of jobs and machines
    4,  4, 2, 27, 7, 70, 5, 62, 1,  5, 3, 53, 8, 87, 6, 82, 0, 90, 
    8,  2, 6, 89, 3, 35, 4, 32, 7, 61, 1, 94, 5, 39, 0, 96, 2, 85, 
    2, 14, 3, 36, 1, 93, 8, 34, 7, 90, 5, 83, 6,  9, 4, 81, 0, 15, 
    7, 51, 0, 36, 1, 99, 5,  6, 2,  4, 8, 39, 4, 85, 3, 23, 6, 72, 
    1, 25, 7, 24, 5, 80, 3, 19, 8, 71, 4, 44, 2, 92, 0, 68, 6, 67, 
    5, 19, 8, 51, 0, 39, 2, 44, 7, 71, 6, 97, 3, 11, 1, 11, 4,  5, 
    4, 63, 5, 36, 7,  8, 2,  6, 0, 57, 1, 19, 8, 48, 3, 35, 6, 93, 
    8, 16, 6, 53, 2, 20, 7, 43, 5, 63, 4, 90, 3, 87, 0, 80, 1,  4, 
    1, 88, 5, 52, 8, 79, 0, 10, 6, 35, 2, 21, 3, 45, 7, 16, 4,  2
  };
  const int q1296[] = {
    9, 9, // Number of jobs and machines
    1, 83, 7, 78, 8, 13, 0,  1, 3, 20, 6, 88, 2,  6, 5, 69, 4, 42, 
    2, 90, 6, 80, 3, 11, 1, 37, 8, 43, 4,  6, 0, 84, 7, 45, 5, 84, 
    4, 93, 2,  3, 3, 59, 1, 45, 5, 83, 0, 47, 8, 53, 7, 31, 6, 88, 
    8,  3, 4, 11, 2, 96, 3, 13, 5, 75, 6, 74, 0, 75, 7, 19, 1, 11, 
    7, 90, 4, 49, 5, 32, 1, 62, 8, 86, 0, 87, 3,  5, 2, 76, 6, 73, 
    8, 27, 2, 75, 4, 34, 1, 62, 5, 32, 7, 94, 6, 27, 3, 20, 0, 33, 
    0, 35, 6, 22, 1, 33, 4, 75, 2, 33, 5, 23, 8,  5, 3, 56, 7, 51, 
    1, 98, 8,  8, 3,  8, 0, 60, 6, 63, 7, 21, 5, 50, 2, 58, 4, 54, 
    0, 38, 1, 40, 4, 57, 2,  2, 8, 36, 7, 60, 3, 45, 6, 92, 5, 79
  };
  const int q1297[] = {
    9, 9, // Number of jobs and machines
    7, 74, 4,  9, 0, 95, 8, 17, 3, 31, 2, 50, 5, 67, 6,  9, 1, 37, 
    3, 92, 0, 23, 6, 67, 7, 99, 1, 79, 8,  2, 4, 23, 2, 62, 5, 11, 
    8,  5, 3, 45, 1, 80, 7, 84, 5, 44, 6, 72, 2, 67, 0, 92, 4, 55, 
    5, 81, 8, 41, 6, 92, 0, 72, 4, 35, 1,  3, 7, 35, 2, 91, 3, 29, 
    8, 27, 2, 21, 0, 97, 6,  1, 4, 81, 3, 89, 5,  9, 1, 35, 7, 82, 
    2, 68, 8, 76, 5, 84, 6, 78, 3, 25, 7, 10, 1, 39, 0,  2, 4, 65, 
    8, 93, 1, 19, 2, 24, 6, 59, 3, 85, 5, 29, 4, 77, 7,  7, 0, 60, 
    1, 96, 2, 16, 6, 81, 4, 90, 5, 46, 3, 23, 7, 90, 0, 74, 8, 83, 
    2, 39, 8, 59, 6, 18, 7, 56, 3, 48, 5, 74, 1, 66, 0, 13, 4, 60
  };
  const int q1298[] = {
    9, 9, // Number of jobs and machines
    3, 43, 2, 67, 1, 43, 5, 72, 6, 81, 4, 45, 8, 79, 0, 85, 7, 85, 
    1, 61, 2, 23, 6, 49, 0, 26, 7, 72, 8, 40, 4, 73, 3, 21, 5, 39, 
    4, 88, 2, 65, 1, 89, 3, 14, 6, 99, 0, 21, 7, 82, 5, 34, 8, 98, 
    6, 58, 4, 28, 8,  3, 3, 17, 1, 20, 0,  3, 7, 79, 5, 35, 2,  4, 
    6, 68, 7, 78, 8, 22, 3, 27, 5, 79, 2, 66, 1, 22, 4, 39, 0, 87, 
    3, 64, 5, 10, 4, 19, 1, 61, 6, 15, 2, 19, 0, 35, 7, 17, 8, 17, 
    1, 73, 0, 37, 5,  1, 4, 46, 8, 44, 2, 49, 6, 64, 7, 96, 3, 65, 
    5, 98, 0, 92, 2, 69, 8, 52, 3, 66, 4, 55, 1, 96, 6, 29, 7,  9, 
    3, 89, 2, 86, 7, 28, 6, 39, 1, 86, 8, 49, 0, 63, 5, 35, 4, 45
  };
  const int q1299[] = {
    9, 9, // Number of jobs and machines
    6, 66, 4, 10, 5, 80, 8,  3, 1, 85, 3, 57, 0, 13, 7, 35, 2, 87, 
    0, 72, 7,  7, 8, 82, 5, 42, 2,  4, 1, 49, 3, 81, 6, 98, 4, 87, 
    3,  3, 0, 73, 7, 66, 5, 69, 4, 72, 2, 80, 6, 81, 1, 62, 8, 45, 
    7, 12, 2, 56, 8, 24, 6, 77, 3, 76, 4, 34, 1, 85, 0, 24, 5,  2, 
    6, 89, 5, 94, 2,  4, 7, 21, 4, 71, 0, 83, 8, 57, 3, 96, 1, 78, 
    5, 69, 7, 85, 8, 56, 0, 38, 1,  9, 6, 88, 2,  8, 3, 37, 4, 36, 
    6, 11, 1, 37, 4,  1, 5, 76, 8, 88, 7, 28, 2, 85, 0, 24, 3, 43, 
    6, 80, 7, 43, 0, 54, 5, 93, 3, 45, 8, 38, 1, 52, 2, 53, 4, 54, 
    8, 75, 3, 15, 4, 80, 6, 56, 5, 19, 1, 69, 2, 25, 7,  8, 0, 80
  };
  const int q1300[] = {
    9, 9, // Number of jobs and machines
    4,  8, 6, 51, 5, 73, 8, 21, 1, 41, 2, 13, 3, 63, 7, 32, 0, 59, 
    2, 55, 6, 24, 3, 94, 0, 35, 8, 26, 4, 63, 5, 57, 7, 93, 1, 65, 
    3,  3, 2, 33, 8, 41, 1, 77, 4,  9, 0, 25, 6, 67, 5, 84, 7, 24, 
    1, 97, 4, 97, 8, 31, 3, 18, 2, 22, 6,  3, 5, 37, 7,  1, 0, 77, 
    5, 89, 4, 66, 8, 14, 7,  7, 3, 36, 0, 99, 2, 26, 6,  8, 1, 71, 
    2, 24, 4, 99, 3, 96, 8, 35, 1, 55, 0, 61, 7, 58, 5, 21, 6, 20, 
    8, 24, 0, 26, 2, 19, 6, 40, 5, 82, 3, 60, 7, 38, 4, 50, 1, 32, 
    8, 20, 6, 42, 2, 13, 4, 83, 5, 53, 1, 34, 7, 33, 0, 43, 3, 55, 
    3, 35, 7, 95, 0, 14, 6, 31, 4, 31, 2, 96, 5, 47, 1, 99, 8, 35
  };
  const int q1301[] = {
    9, 9, // Number of jobs and machines
    2, 22, 4, 95, 1, 54, 7, 34, 0,  4, 3,  2, 8, 12, 6, 29, 5, 65, 
    8, 59, 7,  9, 6, 80, 2, 30, 4, 21, 1, 90, 0, 79, 5, 69, 3, 43, 
    0, 33, 6, 26, 3, 42, 1, 50, 4, 46, 7, 12, 5, 75, 8, 68, 2, 23, 
    0, 25, 2, 97, 4, 35, 6, 72, 3, 60, 1, 45, 8, 53, 7, 18, 5, 10, 
    5, 33, 1, 55, 0, 69, 6, 14, 7, 29, 8, 87, 4, 12, 3, 84, 2, 97, 
    8, 85, 7, 45, 2, 64, 5,  5, 4, 24, 1, 46, 3, 80, 0, 43, 6, 63, 
    1,  5, 8, 38, 5, 47, 6, 55, 4, 57, 0, 18, 3, 23, 2, 50, 7, 95, 
    3, 79, 4, 42, 0, 75, 2, 50, 7, 21, 1, 87, 8,  9, 5, 75, 6, 13, 
    6, 78, 2, 85, 1, 96, 4, 22, 8, 41, 3, 11, 0,  6, 7, 59, 5, 78
  };
  const int q1302[] = {
    9, 9, // Number of jobs and machines
    0, 91, 5, 14, 3, 76, 2, 43, 6, 50, 4, 88, 8, 61, 7, 69, 1, 94, 
    5, 33, 1, 35, 7, 43, 8, 92, 3, 40, 2, 35, 4, 17, 0, 54, 6, 36, 
    3, 95, 1, 46, 8, 98, 4, 71, 0,  6, 2, 39, 7, 28, 6, 38, 5, 62, 
    3, 45, 0, 89, 1, 37, 6, 85, 2, 48, 8,  2, 4, 70, 5, 23, 7, 21, 
    1, 65, 0, 42, 3, 13, 4, 50, 8, 53, 6, 31, 7, 48, 5, 67, 2, 15, 
    0, 68, 8, 28, 2,  6, 6, 64, 1,  1, 5, 64, 4, 63, 7, 58, 3, 85, 
    3, 15, 5, 42, 7,  3, 2, 64, 4, 62, 8, 76, 1, 15, 0, 13, 6, 84, 
    1, 81, 3, 10, 7, 11, 8, 14, 6, 92, 2, 30, 5,  7, 0, 42, 4, 91, 
    1, 48, 6, 86, 7, 36, 0, 74, 4,  7, 8, 53, 2, 36, 5, 33, 3, 56
  };
  const int q1303[] = {
    9, 9, // Number of jobs and machines
    3, 33, 8, 10, 0,  6, 6, 15, 5, 38, 1, 10, 2, 43, 7, 37, 4, 37, 
    6, 48, 7, 72, 3, 18, 2, 91, 5, 29, 4, 47, 8, 88, 0, 51, 1, 41, 
    1, 66, 3, 34, 2, 47, 5, 37, 7, 31, 0, 80, 6, 19, 8, 10, 4, 74, 
    7, 40, 6, 11, 0, 18, 8, 18, 4, 31, 2, 91, 3, 41, 1, 22, 5, 96, 
    6, 39, 5, 28, 8, 92, 3, 32, 2, 72, 0, 26, 7, 84, 1, 94, 4, 75, 
    5, 51, 6, 35, 0, 80, 4, 41, 3, 11, 1, 93, 7, 16, 8, 33, 2, 23, 
    5, 91, 8,  2, 4, 28, 2, 48, 0, 55, 3, 15, 6, 37, 1, 20, 7, 60, 
    4, 27, 3, 92, 8, 27, 7, 14, 5, 47, 1, 44, 0, 12, 2, 89, 6, 76, 
    7, 55, 6, 33, 1, 86, 5, 97, 3, 13, 0, 32, 2, 47, 4,  9, 8, 17
  };
  const int q1304[] = {
    9, 9, // Number of jobs and machines
    7, 54, 5, 46, 6, 66, 0,  1, 8, 22, 3, 99, 2, 63, 4, 69, 1, 70, 
    8, 37, 3, 22, 6, 41, 7, 84, 4, 51, 1, 32, 2, 21, 0, 62, 5, 23, 
    7, 36, 0, 56, 3, 84, 1, 25, 4, 20, 6, 42, 5, 48, 8, 48, 2,  1, 
    0, 94, 2, 64, 1,  1, 6, 85, 4, 11, 8, 93, 7, 99, 5, 92, 3, 77, 
    0, 72, 6, 10, 1, 66, 3, 77, 5, 89, 7, 89, 4,  9, 2, 98, 8, 35, 
    2,  8, 0, 76, 7, 52, 8, 71, 3, 65, 1, 64, 6, 60, 4, 48, 5, 41, 
    7, 69, 3, 71, 2, 12, 0,  1, 4, 29, 6, 96, 5,  6, 8, 54, 1, 95, 
    1, 43, 3,  9, 6,  5, 0, 59, 8, 96, 5, 72, 7,  6, 2, 52, 4, 27, 
    6, 53, 4,  3, 2, 67, 0,  7, 7, 87, 3, 35, 8, 94, 1, 49, 5, 50
  };
  const int q1305[] = {
    9, 9, // Number of jobs and machines
    2, 92, 7, 60, 3,  4, 0, 66, 4, 78, 5, 14, 8, 49, 1, 72, 6, 13, 
    2, 58, 7, 12, 5, 54, 4, 57, 6, 38, 1, 72, 8, 37, 3, 12, 0, 17, 
    8,  5, 4, 71, 5, 18, 0, 43, 7, 82, 3, 35, 1, 16, 2, 92, 6, 74, 
    1, 89, 3, 80, 6, 95, 8, 14, 7, 34, 4, 74, 0, 98, 2, 54, 5, 72, 
    3, 62, 8, 59, 6, 11, 0, 88, 5,  4, 2, 99, 7, 91, 1, 56, 4, 15, 
    0, 11, 5, 81, 7, 54, 4, 85, 2, 52, 6,  3, 3,  1, 8, 26, 1, 96, 
    4, 63, 0, 28, 2, 53, 6,  7, 7, 37, 1, 18, 8, 33, 5, 48, 3, 90, 
    1, 79, 4, 67, 0, 26, 6, 76, 8, 33, 5, 75, 2, 59, 7, 28, 3, 47, 
    5, 88, 2, 59, 7, 63, 8, 34, 6,  4, 0, 91, 4, 57, 1, 10, 3, 79
  };
  const int q1306[] = {
    9, 9, // Number of jobs and machines
    8, 54, 3, 41, 5, 16, 4, 64, 7, 81, 6,  4, 0, 90, 1, 84, 2,  8, 
    0, 46, 6, 58, 3, 54, 1, 82, 7, 25, 2, 22, 8, 92, 5, 67, 4, 45, 
    2, 50, 3, 27, 0, 93, 4, 73, 7, 24, 6, 84, 1, 19, 5, 21, 8, 76, 
    5, 10, 6, 54, 7, 60, 4, 49, 1, 18, 2, 72, 0, 19, 3, 92, 8, 16, 
    3, 60, 7, 57, 6, 84, 2, 99, 8, 87, 4,  4, 0, 68, 5, 58, 1, 87, 
    5, 22, 0, 97, 7, 35, 6, 53, 3, 40, 2, 42, 8, 34, 4,  3, 1, 61, 
    4,  6, 6, 59, 2, 14, 5, 16, 8, 21, 3, 51, 1, 12, 0, 40, 7, 83, 
    0, 95, 6, 16, 7, 37, 8, 36, 3, 42, 2, 81, 5,  3, 4, 37, 1, 10, 
    7, 56, 5, 59, 8,  1, 2, 71, 4,  6, 1, 43, 6, 25, 3,  4, 0, 43
  };
  const int q1307[] = {
    9, 9, // Number of jobs and machines
    4, 54, 3, 23, 6,  4, 0, 44, 7, 47, 2, 22, 1, 67, 8, 96, 5, 60, 
    4, 10, 7, 94, 2, 11, 6,  7, 3, 67, 5, 51, 8, 47, 0, 71, 1, 82, 
    6,  1, 7, 79, 3, 77, 2,  3, 4, 68, 8, 37, 1, 26, 0, 21, 5, 53, 
    4, 82, 1, 72, 0, 48, 8, 61, 2, 26, 5, 28, 7, 87, 3, 49, 6, 87, 
    7, 88, 4, 65, 6, 10, 8, 17, 0,  6, 2, 24, 1, 67, 5, 11, 3, 11, 
    2, 85, 1, 56, 7, 93, 8, 64, 5, 27, 4, 46, 0, 74, 6,  6, 3, 86, 
    6, 16, 0, 92, 2, 40, 8,  5, 5, 94, 4, 46, 1, 45, 7, 93, 3, 99, 
    8,  6, 0, 61, 7, 26, 5,  6, 6,  4, 1, 15, 3, 22, 2, 93, 4, 17, 
    5, 81, 6, 57, 0, 82, 1,  6, 8, 90, 7, 44, 3, 34, 2, 24, 4, 42
  };
  const int q1308[] = {
    9, 9, // Number of jobs and machines
    1, 22, 6, 75, 4, 90, 2, 26, 7, 64, 8, 12, 5, 41, 3, 12, 0, 35, 
    3, 55, 5, 41, 0, 64, 8, 35, 2, 81, 4, 23, 6, 76, 7, 24, 1,  2, 
    4, 60, 1, 95, 8, 33, 6, 60, 2, 35, 3, 70, 7, 82, 5, 97, 0, 64, 
    0, 51, 2, 24, 6,  2, 4, 10, 7, 37, 1, 22, 8, 57, 3, 68, 5,  6, 
    1, 13, 4, 89, 6, 20, 0, 91, 3, 65, 8, 36, 2, 58, 5, 21, 7, 81, 
    7, 79, 2, 79, 1, 59, 6, 13, 0, 41, 4, 75, 3, 61, 8, 23, 5, 47, 
    3, 68, 1, 26, 6, 25, 5, 28, 0, 29, 4, 23, 2, 61, 7, 69, 8, 53, 
    3,  6, 8, 79, 2, 52, 0, 87, 7, 13, 4, 94, 1, 11, 6, 15, 5, 88, 
    4, 50, 0, 83, 5, 50, 8, 89, 3, 49, 2,  5, 1,  1, 6, 57, 7, 27
  };
  const int q1309[] = {
    9, 9, // Number of jobs and machines
    0, 21, 3,  2, 2, 59, 5, 13, 1, 42, 6, 25, 8, 26, 4, 15, 7, 53, 
    3, 75, 5, 17, 6, 62, 7, 55, 4, 23, 1, 32, 2, 81, 8, 24, 0, 76, 
    0, 57, 7, 70, 4, 99, 1, 87, 6, 34, 8, 36, 3, 71, 5, 23, 2, 82, 
    3,  2, 0,  5, 8, 74, 5, 49, 4, 42, 6, 64, 2, 38, 1, 57, 7, 70, 
    4, 28, 6, 95, 8,  1, 7, 26, 3, 17, 2, 60, 5, 19, 1, 82, 0, 75, 
    3,  1, 8, 89, 2, 68, 5, 65, 7, 53, 0, 45, 6,  7, 4, 12, 1, 56, 
    2, 23, 8, 30, 7, 19, 3, 25, 6, 54, 1, 56, 4, 96, 5, 42, 0, 65, 
    3, 77, 5, 37, 7, 40, 1, 64, 6, 67, 2, 41, 8, 48, 0, 72, 4, 63, 
    0, 77, 6, 76, 7, 92, 4, 99, 5, 48, 3, 59, 8, 35, 1, 13, 2, 12
  };
  const int q1310[] = {
    9, 9, // Number of jobs and machines
    7, 70, 4, 69, 5, 81, 6, 96, 0, 88, 2, 79, 8, 37, 1, 93, 3, 36, 
    2, 28, 8,  4, 5, 19, 1, 91, 0, 88, 4, 67, 6, 67, 3, 98, 7, 18, 
    8, 86, 5, 34, 1, 22, 2, 90, 0, 38, 3, 64, 7, 59, 4, 94, 6, 92, 
    8, 80, 3, 62, 0, 20, 7, 52, 5, 76, 6, 59, 1, 22, 2, 68, 4, 10, 
    2, 97, 5, 59, 0, 19, 8,  6, 1,  6, 6, 32, 3, 26, 7, 49, 4, 80, 
    8, 75, 5, 26, 7, 88, 3,  3, 2, 14, 4, 86, 6, 86, 0, 34, 1,  8, 
    1, 32, 4, 76, 8, 92, 6, 13, 0, 26, 3, 10, 2, 12, 7, 64, 5, 29, 
    5, 29, 7,  6, 4, 80, 1, 90, 2, 52, 0, 83, 6, 83, 3, 48, 8, 97, 
    2, 33, 3, 77, 6, 20, 1, 35, 8, 57, 4, 86, 5, 30, 0, 44, 7, 36
  };
  const int q1311[] = {
    9, 9, // Number of jobs and machines
    0, 36, 8, 54, 7, 67, 4, 46, 1,  3, 5,  9, 2, 82, 6,  7, 3, 89, 
    5, 95, 2, 19, 1, 52, 7, 71, 3,  2, 4, 12, 0, 58, 8, 21, 6, 97, 
    8, 68, 1, 73, 0,  6, 5, 18, 6, 38, 7, 87, 4, 88, 3, 78, 2, 73, 
    0,  3, 8, 90, 2, 45, 7, 30, 6, 73, 1, 81, 5,  9, 4, 24, 3, 54, 
    3, 71, 7, 88, 0,  1, 6, 36, 2, 40, 4, 35, 8, 86, 1, 96, 5, 66, 
    6, 67, 4, 78, 2, 42, 5, 43, 0, 29, 3, 15, 7, 91, 1, 61, 8, 53, 
    4, 81, 2, 71, 8, 14, 5, 47, 7, 18, 3, 81, 1, 72, 0, 89, 6, 24, 
    3, 96, 0, 29, 7, 68, 4, 36, 5, 11, 2, 15, 6, 51, 8, 10, 1, 34, 
    8,  1, 0, 52, 3, 39, 4, 39, 6, 51, 2, 76, 1, 60, 5, 51, 7, 78
  };
  const int q1312[] = {
    9, 9, // Number of jobs and machines
    5,  7, 7, 69, 4, 24, 2, 13, 3, 52, 1,  6, 8, 97, 0, 77, 6, 25, 
    1, 49, 7, 92, 0, 17, 8, 72, 5, 12, 3, 81, 6, 45, 2, 44, 4, 16, 
    2, 28, 5, 53, 0, 41, 3, 28, 8, 75, 1, 96, 6, 16, 4, 79, 7, 13, 
    1, 44, 3, 23, 2, 58, 0,  9, 4, 73, 8, 61, 6, 94, 7, 99, 5, 46, 
    5, 49, 4, 68, 6, 84, 3, 68, 2, 86, 1, 17, 8, 31, 7, 38, 0, 33, 
    2, 35, 7, 76, 4,  1, 1, 90, 3, 60, 8,  2, 5, 81, 0, 58, 6,  1, 
    7, 23, 6, 12, 5, 47, 1, 96, 0,  3, 3, 65, 2, 16, 4, 50, 8, 66, 
    4, 67, 3, 15, 1, 87, 2, 99, 7, 74, 5, 41, 6, 88, 8, 74, 0, 45, 
    3, 38, 7, 11, 8, 76, 1, 37, 2,  1, 4, 15, 0,  7, 5, 86, 6, 56
  };
  const int q1313[] = {
    9, 9, // Number of jobs and machines
    4, 82, 8, 96, 0, 67, 3, 22, 7, 54, 2, 80, 5, 68, 1, 29, 6, 74, 
    5, 60, 4, 61, 0, 83, 8,  2, 1, 30, 6, 21, 7, 50, 2, 94, 3, 94, 
    3, 95, 2, 14, 0, 93, 4, 96, 5, 31, 8, 37, 1, 78, 7, 52, 6,  3, 
    8, 90, 1, 19, 2, 40, 0, 23, 5, 34, 7,  6, 6, 73, 4, 92, 3, 88, 
    1, 94, 5, 23, 0, 57, 6, 56, 7, 69, 8, 30, 2, 67, 3, 40, 4, 54, 
    0, 97, 4, 37, 2, 54, 1, 98, 5, 45, 7, 59, 6, 80, 8, 33, 3, 81, 
    1, 50, 3,  4, 4, 13, 6, 11, 7,  8, 5, 89, 0, 15, 8, 12, 2, 67, 
    1, 61, 8, 92, 2, 27, 7, 31, 4,  6, 0, 13, 3, 92, 5, 83, 6, 47, 
    8, 47, 6, 89, 3, 70, 1, 26, 0, 32, 7,  2, 4, 17, 2, 14, 5, 72
  };
  const int q1314[] = {
    9, 9, // Number of jobs and machines
    8, 65, 7, 89, 1, 91, 2, 31, 6, 84, 0, 76, 5, 98, 4, 25, 3, 51, 
    6, 25, 8, 39, 4, 73, 5, 31, 3, 77, 2, 74, 0, 62, 1,  5, 7, 93, 
    5, 10, 0, 19, 1, 35, 8, 58, 4, 76, 2, 88, 6, 61, 3, 65, 7,  8, 
    0, 94, 1, 58, 7,  7, 4, 49, 5, 27, 8, 47, 3,  4, 2, 59, 6, 93, 
    6, 86, 3, 16, 8, 20, 7,  8, 1, 20, 4, 11, 2, 53, 0,  8, 5, 87, 
    8, 46, 2, 86, 0, 65, 7, 71, 5, 12, 3, 74, 4, 14, 6, 19, 1, 15, 
    4, 25, 7,  2, 5, 44, 3, 46, 1, 41, 0, 40, 6, 72, 2,  8, 8, 49, 
    4, 83, 6,  2, 5, 93, 3, 23, 8, 59, 1, 50, 7, 91, 2, 47, 0, 28, 
    8, 28, 3, 29, 2, 61, 1, 47, 4, 16, 5, 43, 6, 93, 0,  6, 7, 18
  };
  const int q1315[] = {
    9, 9, // Number of jobs and machines
    8, 72, 4, 15, 5, 45, 1, 90, 6, 84, 0, 38, 7, 86, 2, 45, 3, 19, 
    7, 51, 4, 67, 3, 72, 5, 61, 8, 18, 6,  7, 0, 14, 2, 74, 1, 93, 
    4, 53, 2, 86, 0, 79, 1, 59, 3, 53, 5, 83, 6, 17, 8, 80, 7, 34, 
    0, 31, 2, 46, 5, 88, 7, 33, 1, 56, 6, 70, 4, 69, 3, 21, 8, 69, 
    2, 71, 8, 45, 5, 69, 7, 44, 3,  2, 0, 21, 1, 15, 6, 15, 4,  6, 
    8, 57, 3,  7, 2,  1, 6, 75, 7, 83, 0, 68, 5, 74, 4, 62, 1, 21, 
    3, 34, 4, 71, 6, 91, 0, 10, 5, 98, 1,  7, 2,  4, 7, 18, 8, 84, 
    3, 41, 4, 32, 2, 19, 5, 66, 8, 20, 1,  9, 0, 66, 7, 54, 6, 64, 
    6, 88, 5, 29, 8, 56, 2, 82, 4, 59, 3,  1, 0, 79, 1, 29, 7,  3
  };
  const int q1316[] = {
    9, 9, // Number of jobs and machines
    3, 83, 5, 54, 4, 89, 8,  1, 7, 50, 2, 76, 1, 70, 6, 68, 0, 98, 
    4, 56, 5, 23, 7, 14, 8,  8, 1, 61, 3, 71, 6, 39, 0, 31, 2, 37, 
    4, 84, 2,  9, 6, 31, 0, 20, 7, 18, 5, 79, 3, 43, 8, 24, 1, 51, 
    0, 84, 6, 35, 3, 90, 5, 15, 4, 64, 8, 69, 7, 76, 2, 24, 1, 14, 
    1, 59, 8,  1, 0, 87, 4, 54, 3, 58, 6, 84, 7, 62, 2, 28, 5, 78, 
    6, 35, 4, 47, 1, 41, 0, 82, 3, 39, 7, 61, 2, 18, 8, 77, 5, 71, 
    1, 46, 7, 17, 4, 43, 3, 27, 6, 64, 2, 33, 8,  9, 0, 76, 5, 36, 
    3, 36, 1,  4, 8, 39, 6, 70, 4, 85, 5, 62, 0,  9, 2, 35, 7, 48, 
    7, 72, 3, 11, 6, 93, 8, 58, 0, 30, 2, 16, 4, 61, 1, 24, 5, 22
  };
  const int q1317[] = {
    9, 9, // Number of jobs and machines
    0, 19, 5, 57, 3, 76, 8,  9, 4,  3, 6,  6, 1, 47, 7, 45, 2, 10, 
    4, 50, 6,  9, 0, 32, 5, 94, 7, 46, 2, 40, 8, 19, 1, 51, 3, 93, 
    7, 85, 3, 52, 0, 52, 1, 87, 8, 57, 4, 80, 5, 94, 2, 63, 6, 17, 
    8, 82, 3, 33, 0, 91, 7, 64, 4, 32, 2, 50, 1, 93, 5, 56, 6, 27, 
    1, 82, 5, 69, 7, 31, 2, 97, 8, 96, 4, 12, 3, 23, 6, 58, 0, 95, 
    0, 66, 3, 44, 4, 63, 7, 86, 5, 31, 1, 74, 2, 99, 8, 54, 6, 45, 
    2, 42, 5, 80, 3, 84, 0, 19, 7, 57, 4, 61, 1, 40, 8, 35, 6, 31, 
    5, 32, 0, 49, 6, 35, 8, 15, 3, 72, 1, 77, 2, 25, 4, 89, 7,  2, 
    5, 86, 7,  6, 8, 74, 2, 38, 3, 15, 6, 52, 0, 30, 1, 85, 4, 42
  };
  const int q1318[] = {
    9, 9, // Number of jobs and machines
    2, 77, 1, 49, 6, 82, 0, 59, 3, 18, 5, 98, 8, 57, 4, 43, 7,  8, 
    6, 79, 3, 19, 7, 33, 5, 27, 0, 43, 2, 44, 8, 36, 4, 91, 1, 29, 
    6,  6, 1, 30, 2, 94, 4, 43, 3, 90, 8, 72, 5, 96, 7, 45, 0, 34, 
    0, 29, 5, 35, 8,  2, 2, 17, 1, 17, 3, 71, 7, 85, 6, 97, 4, 51, 
    1, 94, 2,  3, 6, 45, 5, 73, 8, 55, 3, 87, 4, 34, 0, 75, 7, 20, 
    4, 35, 1, 54, 8,  9, 2, 37, 7, 73, 6, 40, 0, 24, 3, 53, 5, 82, 
    8, 64, 0, 86, 1, 35, 5, 58, 2, 42, 7, 24, 6, 99, 4, 42, 3, 12, 
    6, 89, 8, 22, 2, 38, 5, 83, 0, 37, 7, 67, 3, 58, 1, 49, 4, 55, 
    4, 30, 1, 80, 6, 90, 5, 63, 2, 22, 7, 76, 8, 34, 0,  6, 3, 85
  };
  const int q1319[] = {
    9, 9, // Number of jobs and machines
    5, 82, 8, 15, 6, 39, 7, 24, 3, 21, 4, 24, 0, 68, 1,  5, 2, 78, 
    7, 71, 6, 41, 4, 42, 5, 43, 3, 68, 2, 60, 8, 78, 0, 92, 1, 58, 
    3, 37, 8, 94, 2,  4, 6, 68, 0, 34, 4, 96, 5, 65, 1, 23, 7, 52, 
    7, 11, 1, 52, 3, 63, 0, 50, 2, 18, 8,  6, 6, 74, 5, 11, 4, 83, 
    2, 97, 3, 83, 4, 56, 6, 50, 1, 43, 0, 85, 5, 72, 7, 95, 8, 99, 
    8, 93, 3,  5, 6,  9, 5, 42, 4, 13, 7, 67, 0, 29, 2, 58, 1, 52, 
    3, 26, 5, 62, 2, 70, 4, 65, 1, 60, 0,  5, 7,  2, 6,  5, 8, 91, 
    4, 58, 8, 15, 7, 42, 6, 16, 3, 24, 0, 19, 1, 20, 2, 24, 5, 88, 
    7, 86, 8, 60, 5, 91, 2, 39, 6, 53, 0, 68, 1, 73, 4, 72, 3, 33
  };
  const int q1320[] = {
    9, 9, // Number of jobs and machines
    8, 48, 1, 11, 7, 32, 2, 66, 4, 34, 6, 82, 5, 32, 3, 19, 0, 43, 
    1, 69, 4,  1, 3, 46, 2, 16, 5, 48, 8, 95, 0, 49, 7, 29, 6, 10, 
    7, 54, 0,  6, 1, 98, 2, 70, 6, 94, 3, 35, 4, 81, 8, 86, 5,  3, 
    2, 90, 1, 41, 4, 53, 8,  7, 6, 82, 7, 31, 3, 62, 0, 83, 5, 69, 
    7, 43, 5, 69, 0, 29, 3, 16, 1, 22, 6, 92, 4, 29, 2, 80, 8, 24, 
    4, 55, 8, 87, 7, 80, 5, 39, 1, 81, 6, 70, 0, 13, 3, 89, 2, 85, 
    1, 86, 8, 25, 0, 95, 4, 50, 3, 15, 5, 50, 7, 75, 2, 14, 6, 88, 
    0, 73, 2, 62, 6, 71, 1, 92, 4, 17, 8, 58, 5, 12, 7, 16, 3, 28, 
    7, 26, 0, 72, 4, 50, 6, 46, 1, 50, 5,  9, 8, 78, 2, 37, 3,  3
  };
  const int q1321[] = {
    9, 9, // Number of jobs and machines
    8, 68, 1, 90, 0, 88, 3, 31, 4, 15, 5, 94, 2, 52, 6, 81, 7, 90, 
    6, 69, 0, 56, 2, 61, 7, 91, 5, 72, 8, 85, 3, 85, 4, 34, 1,  4, 
    1,  3, 5, 11, 2, 94, 7, 45, 8, 75, 4, 59, 6, 46, 0, 54, 3, 96, 
    0, 40, 2, 24, 5, 95, 6, 77, 4,  2, 3, 53, 7, 77, 1, 57, 8, 80, 
    3, 10, 8, 54, 7, 81, 2, 53, 4, 32, 6, 19, 1, 48, 0, 63, 5, 22, 
    6, 89, 0, 66, 3, 77, 1, 73, 8, 66, 5, 56, 4,  7, 7,  2, 2, 17, 
    4, 85, 6, 37, 0, 51, 2, 94, 7, 89, 1, 50, 5,  7, 8, 43, 3, 48, 
    3, 24, 6, 67, 7, 27, 1, 46, 4, 17, 2, 53, 5, 54, 8, 76, 0, 81, 
    3, 79, 4,  2, 1, 46, 6, 76, 7, 42, 8, 87, 5, 75, 0, 48, 2, 78
  };
  const int q1322[] = {
    9, 9, // Number of jobs and machines
    6, 19, 5, 24, 2, 98, 8, 41, 7, 59, 0, 38, 1, 61, 4, 63, 3, 31, 
    1, 92, 5, 12, 0, 65, 4, 85, 2,  1, 6, 58, 3, 56, 8, 83, 7, 97, 
    7, 25, 0, 88, 4, 81, 2, 78, 1,  2, 6, 42, 3, 49, 5, 54, 8, 24, 
    0, 64, 4, 61, 8, 85, 3, 68, 7, 26, 5, 22, 1,  8, 6, 47, 2, 82, 
    5,  6, 7, 85, 3, 23, 1, 52, 0,  8, 8, 57, 2, 38, 4,  8, 6,  2, 
    6, 72, 8, 46, 4, 66, 5, 57, 2, 12, 7, 63, 1, 88, 3, 82, 0, 63, 
    4, 54, 8, 68, 3, 31, 1, 39, 0, 70, 5, 44, 7, 39, 6, 97, 2, 34, 
    1, 59, 7, 97, 0, 16, 5, 89, 4, 79, 2, 28, 8, 48, 3, 40, 6,  2, 
    6, 22, 7, 39, 1, 29, 3, 62, 0, 88, 5, 87, 8, 58, 4, 26, 2, 10
  };
  const int q1323[] = {
    9, 9, // Number of jobs and machines
    7, 50, 6, 17, 2,  6, 8, 92, 0, 28, 4, 48, 5, 98, 3, 89, 1, 73, 
    2, 51, 0, 12, 1, 23, 8, 85, 5,  6, 3, 23, 7,  7, 6, 51, 4, 65, 
    3, 48, 8, 54, 0, 24, 6, 66, 5, 28, 1,  7, 4, 87, 2, 18, 7, 24, 
    3, 45, 0,  9, 4, 75, 1, 97, 6, 78, 5, 15, 8, 17, 7, 43, 2, 97, 
    0,  6, 3, 30, 8, 14, 6, 92, 1,  5, 2, 68, 4, 72, 5, 73, 7, 89, 
    5, 61, 0, 40, 6,  5, 3, 90, 4, 79, 2,  1, 1, 66, 8,  8, 7, 63, 
    6, 67, 3, 36, 8, 82, 4,  1, 2, 13, 1, 42, 0, 63, 7, 72, 5,  4, 
    1, 21, 6, 60, 0, 49, 5, 12, 3, 27, 4, 71, 2, 21, 7, 36, 8, 41, 
    3, 66, 1, 33, 8, 64, 5, 80, 2, 37, 7, 84, 0, 59, 6, 28, 4, 66
  };
  const int q1324[] = {
    9, 9, // Number of jobs and machines
    6, 35, 7,  3, 4, 50, 2, 28, 5, 38, 8, 60, 0, 77, 1,  8, 3, 38, 
    3, 40, 2, 52, 0, 61, 1, 13, 8,  4, 6, 20, 5, 68, 7, 50, 4, 17, 
    2,  9, 1, 61, 5, 82, 4, 75, 3, 91, 0, 63, 7, 72, 8, 92, 6, 78, 
    4, 97, 5, 47, 0, 84, 1, 81, 2, 40, 3, 95, 7, 74, 6, 51, 8, 51, 
    7, 52, 2, 15, 1, 33, 8, 68, 6, 43, 0, 41, 3, 52, 5, 61, 4, 14, 
    4, 52, 6, 59, 1, 55, 5, 45, 8, 23, 3, 34, 0, 87, 2, 19, 7, 40, 
    1, 31, 3, 87, 4, 85, 8, 53, 0, 42, 7, 40, 6, 52, 5, 32, 2, 81, 
    8, 82, 4, 39, 2, 20, 1, 74, 3, 49, 6, 51, 0, 97, 7, 11, 5, 98, 
    6,  5, 0, 78, 5, 41, 8, 29, 1, 37, 3, 12, 2, 25, 7,  4, 4, 85
  };
  const int q1325[] = {
    9, 9, // Number of jobs and machines
    7, 23, 0, 95, 8, 71, 1, 40, 6, 73, 4, 41, 3, 61, 5, 95, 2, 18, 
    0, 24, 5, 27, 7, 97, 1, 66, 8, 98, 4, 59, 2, 43, 6, 36, 3, 50, 
    3, 80, 4, 10, 6, 65, 1,  2, 0, 39, 7, 57, 8, 89, 5, 42, 2, 14, 
    4, 79, 5, 58, 7, 29, 0, 52, 3,  9, 8, 41, 6, 30, 1, 28, 2, 34, 
    1, 82, 4,  4, 2, 46, 0,  8, 5, 41, 7,  6, 8, 15, 3, 74, 6, 56, 
    7, 55, 5,  6, 6, 12, 4, 48, 3, 68, 8, 67, 2, 22, 1, 20, 0, 95, 
    3, 28, 8, 91, 5, 86, 6, 78, 7, 29, 2,  3, 0, 10, 1, 50, 4, 21, 
    7, 28, 0, 37, 2, 95, 8, 20, 6, 75, 1, 96, 4,  8, 3, 37, 5, 95, 
    5, 21, 0, 89, 4, 45, 8, 62, 3, 61, 7, 70, 6, 98, 1, 72, 2, 25
  };
  const int q1326[] = {
    9, 9, // Number of jobs and machines
    4, 41, 8, 17, 1, 56, 0, 64, 5, 10, 2, 74, 7, 79, 3, 19, 6, 51, 
    8, 45, 7, 31, 1, 53, 5, 21, 0, 33, 6, 85, 3,  8, 4, 17, 2, 26, 
    6, 20, 2, 15, 8, 91, 1, 11, 3, 99, 0, 87, 4, 51, 7,  3, 5, 53, 
    6, 82, 4, 33, 1, 22, 2,  7, 3, 19, 7, 59, 0, 35, 5, 39, 8, 40, 
    3, 51, 0, 97, 5, 98, 2, 62, 7, 77, 6, 54, 4, 96, 8,  3, 1, 76, 
    0,  4, 7, 86, 5, 89, 8, 49, 6, 46, 2, 54, 3, 79, 4, 27, 1, 24, 
    7, 31, 6, 36, 5,  4, 8, 48, 0, 17, 2, 51, 1, 33, 4, 19, 3, 80, 
    6, 95, 3, 31, 2, 45, 4, 28, 0, 76, 1, 99, 7,  1, 8, 31, 5, 53, 
    0, 80, 1, 70, 3, 90, 2, 34, 6,  9, 8, 99, 7, 62, 4, 76, 5, 26
  };
  const int q1327[] = {
    9, 9, // Number of jobs and machines
    2, 74, 7, 98, 5, 83, 8,  4, 3, 56, 0, 62, 1, 31, 4, 59, 6, 24, 
    1, 47, 2, 74, 3, 87, 8, 40, 4, 35, 5, 30, 0, 58, 6, 89, 7, 91, 
    0, 97, 4, 62, 2, 68, 6, 89, 3, 88, 5, 69, 1,  6, 8, 35, 7, 78, 
    0, 51, 6, 80, 1, 28, 4, 25, 3, 17, 7, 45, 2, 35, 5, 54, 8, 34, 
    0, 73, 1, 53, 2, 67, 7, 86, 5,  7, 3, 93, 8, 98, 4, 34, 6, 46, 
    6, 43, 2, 28, 4,  8, 3, 50, 8, 84, 7, 67, 1, 31, 5, 63, 0, 81, 
    6, 28, 7, 41, 8, 19, 0, 45, 5, 96, 4,  2, 3, 11, 2, 18, 1, 47, 
    0, 84, 3, 86, 8, 83, 6, 98, 4, 87, 2, 49, 7, 40, 5, 66, 1, 76, 
    5, 57, 0, 78, 4, 82, 3, 51, 2, 83, 6, 89, 7, 70, 1, 98, 8, 77
  };
  const int q1328[] = {
    9, 9, // Number of jobs and machines
    7, 89, 3, 53, 5, 60, 1, 88, 6, 43, 2,  2, 4, 71, 0, 16, 8, 40, 
    1, 60, 4, 56, 8, 67, 6, 96, 3,  3, 5, 98, 7, 12, 0,  1, 2, 43, 
    2, 96, 6, 30, 4, 69, 5, 43, 8, 46, 7, 10, 0, 43, 1, 21, 3, 71, 
    0, 17, 4, 98, 1, 20, 8, 90, 5, 93, 2, 65, 6, 52, 7,  8, 3,  9, 
    4, 22, 5, 32, 6, 37, 0, 61, 1, 61, 7,  1, 8, 81, 2, 87, 3, 15, 
    0, 38, 2, 24, 5, 84, 6, 89, 8, 74, 4, 67, 7, 61, 1, 43, 3, 35, 
    3, 56, 0, 68, 2, 35, 4, 38, 7, 93, 8, 30, 6, 99, 5, 15, 1,  9, 
    7,  3, 3, 83, 5, 36, 2, 69, 8, 23, 6, 46, 4, 13, 1, 68, 0, 87, 
    1, 71, 4, 50, 2, 86, 6, 70, 5, 70, 7, 68, 8, 52, 0,  5, 3, 59
  };
  const int q1329[] = {
    9, 9, // Number of jobs and machines
    5, 17, 6, 61, 7, 25, 8, 82, 3, 78, 4, 26, 0, 60, 2, 17, 1, 79, 
    4, 52, 7, 77, 2, 65, 0,  8, 1, 29, 8, 18, 5, 94, 3, 44, 6, 12, 
    5,  5, 3, 66, 4, 91, 7, 84, 0, 93, 6, 40, 2, 31, 1, 48, 8, 39, 
    5, 97, 8, 79, 1,  4, 2, 26, 4,  2, 0, 40, 3, 25, 7, 86, 6, 44, 
    3, 43, 4, 40, 7, 34, 5, 22, 1, 29, 6, 89, 8, 40, 2, 76, 0, 46, 
    2, 66, 1, 79, 4, 58, 8, 58, 7, 28, 0, 84, 6, 70, 5, 34, 3, 34, 
    6,  5, 8, 91, 5, 24, 7, 60, 3,  3, 4, 64, 1,  6, 0, 11, 2, 39, 
    5, 24, 2, 65, 3, 51, 0, 35, 1, 98, 4, 70, 7, 82, 6, 65, 8, 17, 
    6, 96, 5, 57, 8, 27, 2, 17, 3, 52, 7, 22, 0, 83, 4, 66, 1, 43
  };
  const int q1330[] = {
    9, 9, // Number of jobs and machines
    7,  8, 4, 31, 2, 70, 3, 27, 1, 62, 0, 88, 8, 18, 5, 33, 6, 36, 
    8, 20, 7, 42, 3, 96, 0, 62, 5, 11, 4, 67, 2, 24, 1, 82, 6, 39, 
    1, 57, 3, 65, 4, 63, 2, 19, 8, 74, 7, 40, 6, 11, 5, 66, 0, 97, 
    0, 25, 3, 48, 5, 14, 6, 29, 7, 62, 8, 49, 2, 45, 1, 17, 4, 87, 
    7, 64, 2, 74, 5, 32, 3, 24, 6, 35, 0, 21, 8, 25, 1, 72, 4, 69, 
    6, 93, 7, 57, 8, 22, 3, 38, 2, 74, 4, 36, 0, 98, 1, 80, 5, 54, 
    4, 41, 2, 30, 1, 85, 7,  3, 0, 48, 3, 96, 6, 80, 5, 57, 8, 65, 
    3, 33, 7, 30, 4, 81, 5, 80, 1, 58, 0, 12, 2, 38, 8, 51, 6, 45, 
    7, 10, 5, 68, 8, 70, 3, 95, 6, 81, 0, 61, 2, 79, 4, 33, 1, 57
  };
  const int q1331[] = {
    9, 9, // Number of jobs and machines
    5, 76, 1, 99, 4, 45, 6, 96, 3, 94, 8, 83, 7, 76, 2, 76, 0, 36, 
    2, 78, 8, 48, 7, 87, 0, 10, 5, 90, 6, 51, 3,  4, 4, 98, 1, 27, 
    7, 13, 6, 31, 3, 43, 0,  8, 2, 16, 5, 31, 4, 54, 1, 27, 8, 78, 
    1, 24, 2, 15, 8, 52, 5, 56, 3,  1, 4, 41, 7, 94, 6, 89, 0, 12, 
    3,  8, 7, 47, 2, 26, 4, 36, 0, 52, 6, 40, 5, 44, 8, 37, 1, 15, 
    5, 51, 8, 91, 7, 43, 1, 12, 0, 20, 2, 36, 4, 13, 3,  9, 6, 23, 
    1, 39, 7, 12, 0, 29, 4, 76, 8, 18, 2, 86, 3, 90, 6, 16, 5, 67, 
    3, 46, 4, 51, 7, 99, 0, 84, 1, 30, 2, 41, 6, 26, 8, 70, 5, 92, 
    2, 61, 8, 55, 7,  1, 0, 78, 6, 32, 5, 51, 4, 59, 1, 24, 3, 54
  };
  const int q1332[] = {
    9, 9, // Number of jobs and machines
    7, 60, 5,  1, 6, 97, 1, 93, 2,  5, 0, 48, 4, 83, 3, 70, 8,  7, 
    2, 90, 0, 80, 5, 85, 1, 66, 6, 62, 8,  3, 4,  8, 7, 73, 3, 62, 
    5, 18, 3, 93, 1, 76, 2, 36, 7, 53, 6, 45, 8, 78, 0, 78, 4, 39, 
    7, 27, 5, 85, 8, 95, 2, 14, 6, 62, 1, 99, 0, 16, 4, 70, 3, 92, 
    5, 57, 2, 81, 6, 48, 1, 23, 3, 58, 0, 71, 8, 19, 7,  4, 4, 42, 
    8, 43, 2, 62, 0,  8, 5,  3, 1, 86, 4,  7, 7, 50, 6,  9, 3, 26, 
    4, 65, 3, 99, 0, 86, 8, 44, 5, 39, 6, 90, 7, 43, 2, 34, 1, 22, 
    3, 53, 7, 28, 8, 32, 1, 74, 0, 77, 6,  6, 4, 12, 2, 29, 5, 87, 
    7, 99, 0, 19, 4, 93, 8, 31, 3, 72, 1, 45, 6, 20, 2, 55, 5,  3
  };
  const int q1333[] = {
    9, 9, // Number of jobs and machines
    8, 23, 0, 19, 6, 73, 2, 18, 4, 10, 1, 93, 5, 81, 7, 62, 3,  6, 
    1, 10, 8, 91, 6, 83, 5, 64, 3, 33, 4, 97, 7, 31, 0, 12, 2, 74, 
    3, 40, 5, 97, 8, 33, 7, 82, 1, 43, 2,  3, 4, 68, 0, 81, 6,  3, 
    8, 47, 7, 49, 1, 88, 0, 97, 6, 34, 2, 21, 5, 27, 3, 98, 4, 62, 
    8, 89, 1,  6, 0,  6, 6, 41, 7, 28, 3, 36, 2, 84, 5, 23, 4, 46, 
    3, 30, 6, 94, 8, 57, 2, 94, 1,  3, 5, 14, 0, 61, 7, 19, 4, 24, 
    8, 69, 5, 37, 3, 90, 2, 81, 6, 66, 4, 67, 1, 78, 7, 13, 0, 16, 
    8, 44, 2, 60, 4, 70, 5, 77, 1, 15, 0, 35, 6, 41, 7, 69, 3, 31, 
    1, 67, 5, 30, 6, 71, 2, 54, 8, 19, 0, 88, 4, 97, 7, 77, 3, 89
  };
  const int q1334[] = {
    9, 9, // Number of jobs and machines
    0, 72, 7, 52, 4, 47, 2, 42, 3, 36, 5, 83, 6, 10, 8, 80, 1, 69, 
    2, 38, 1, 20, 6, 57, 5,  3, 0, 81, 8, 91, 7, 83, 3, 61, 4, 58, 
    2, 54, 5, 91, 8, 23, 1, 27, 7, 57, 0, 98, 3, 88, 6, 98, 4, 90, 
    6, 75, 3, 93, 1, 31, 2, 99, 7, 79, 5, 99, 8, 78, 0, 92, 4,  4, 
    8, 86, 7, 90, 1,  5, 3, 75, 0, 73, 6, 53, 2, 81, 4, 87, 5, 88, 
    0,  6, 1, 68, 4, 35, 2, 91, 5, 30, 8, 22, 7, 36, 6, 37, 3, 81, 
    3, 44, 8, 11, 6,  7, 5,  4, 7, 44, 0, 16, 4, 83, 2, 94, 1, 55, 
    8, 71, 5, 48, 0, 65, 3,  7, 2, 53, 1, 61, 7, 16, 6, 61, 4, 72, 
    8, 37, 1,  5, 2, 82, 4, 30, 7,  1, 0,  3, 3, 15, 6, 22, 5, 76
  };
  const int q1335[] = {
    9, 9, // Number of jobs and machines
    1, 25, 2, 16, 7,  1, 0, 16, 3, 15, 4, 78, 8, 18, 5, 65, 6, 69, 
    7, 23, 5, 49, 0, 41, 1, 50, 2, 51, 6, 15, 3, 91, 8, 52, 4, 37, 
    6, 75, 1, 46, 2, 98, 0, 66, 4, 45, 3,  6, 5, 49, 8, 36, 7,  2, 
    6,  1, 4, 13, 3, 53, 0, 68, 8, 30, 5, 66, 1, 31, 2, 38, 7, 37, 
    5, 78, 1, 10, 4, 53, 7,  5, 6, 25, 3, 98, 8,  5, 0, 40, 2, 79, 
    1, 16, 2, 56, 0, 56, 7, 14, 5, 11, 4, 31, 3, 92, 8, 65, 6, 60, 
    7, 81, 5,  6, 4, 75, 0, 95, 8,  6, 6, 58, 2, 88, 3, 39, 1, 17, 
    6, 60, 0,  3, 4,  5, 1, 75, 2, 73, 5, 70, 3, 96, 8,  3, 7, 29, 
    7, 28, 0,  3, 3, 67, 6, 74, 4, 61, 1, 67, 8, 56, 5, 58, 2, 35
  };
  const int q1336[] = {
    9, 9, // Number of jobs and machines
    0, 31, 4, 85, 7, 29, 1, 92, 5, 47, 3, 16, 8, 44, 6, 35, 2, 38, 
    8, 47, 0, 14, 6, 46, 2, 57, 3, 18, 7, 40, 4, 85, 1,  5, 5, 62, 
    4,  3, 0,  3, 8, 11, 7, 22, 5, 95, 2, 44, 3, 58, 1,  4, 6, 99, 
    5, 27, 8, 60, 1, 29, 7,  3, 0, 32, 6, 59, 3, 33, 2, 70, 4, 82, 
    5, 16, 6, 10, 7, 86, 8, 83, 2, 99, 3, 54, 1, 42, 0, 94, 4, 61, 
    3,  7, 1, 23, 7, 29, 8, 46, 4, 91, 0, 17, 6, 77, 2, 64, 5, 95, 
    7, 22, 0, 15, 1, 26, 5, 46, 6, 49, 4, 83, 8, 38, 2, 92, 3, 90, 
    2, 83, 4, 42, 6, 94, 0, 59, 8, 17, 3, 91, 1,  5, 5, 90, 7, 50, 
    6, 23, 8, 62, 2, 91, 4, 51, 3, 91, 7, 51, 0, 83, 5, 71, 1, 97
  };
  const int q1337[] = {
    9, 9, // Number of jobs and machines
    2,  7, 3,  8, 0, 56, 1, 43, 5, 90, 4,  9, 7, 66, 8, 78, 6, 21, 
    4, 70, 7, 19, 8, 49, 6, 28, 2, 33, 0, 37, 3, 53, 5, 84, 1, 85, 
    0, 37, 6, 89, 7, 89, 2, 59, 8, 37, 4, 31, 3, 60, 1, 95, 5, 31, 
    8, 71, 6, 91, 2, 10, 4, 83, 7, 53, 3, 36, 1, 88, 5, 16, 0, 47, 
    7, 26, 4, 51, 8, 97, 5, 39, 3, 13, 6, 20, 0, 38, 1, 98, 2, 21, 
    2, 71, 0, 36, 5,  4, 1, 49, 3, 50, 4, 52, 7, 55, 8, 99, 6, 70, 
    6, 32, 3, 46, 4, 83, 7, 12, 8, 37, 1, 78, 5,  8, 0, 52, 2, 16, 
    3,  2, 7, 68, 6, 43, 5, 28, 0,  1, 2, 79, 8, 11, 4, 77, 1, 90, 
    7, 45, 4, 39, 8, 99, 5, 18, 3, 90, 2, 98, 0, 77, 1, 86, 6, 72
  };
  const int q1338[] = {
    9, 9, // Number of jobs and machines
    5, 52, 8, 71, 0,  3, 7, 79, 4, 30, 1, 64, 6,  2, 2,  2, 3, 51, 
    4, 96, 2, 87, 7,  3, 6, 66, 3, 28, 0, 75, 1, 18, 5, 33, 8, 24, 
    4, 36, 5, 84, 3, 67, 1, 68, 7, 78, 0, 48, 6, 21, 2, 94, 8, 11, 
    5, 60, 8, 45, 2, 94, 4, 91, 1,  1, 0, 36, 7, 35, 6, 60, 3, 21, 
    4, 94, 7, 96, 5, 16, 8, 58, 0, 24, 6, 71, 2, 97, 3, 87, 1, 90, 
    1, 34, 4, 76, 7, 60, 2, 14, 5, 45, 6, 93, 8, 75, 0, 29, 3, 25, 
    3,  3, 4,  4, 7, 11, 2, 72, 5, 12, 0, 16, 8, 84, 6, 55, 1, 21, 
    4, 31, 7, 41, 6, 72, 1, 46, 8, 50, 3, 45, 5, 82, 2, 25, 0, 89, 
    1, 21, 0, 54, 5, 30, 8, 55, 7, 82, 3, 21, 2, 27, 4, 90, 6, 29
  };
  const int q1339[] = {
    9, 9, // Number of jobs and machines
    5,  2, 0, 20, 8, 20, 3, 73, 6, 33, 2, 70, 4, 51, 1, 93, 7, 36, 
    4, 76, 2, 54, 3, 67, 6, 57, 5, 22, 0, 31, 8, 25, 7, 70, 1, 44, 
    5, 18, 3, 49, 1, 27, 8,  3, 7, 97, 4, 95, 2, 69, 6, 70, 0, 60, 
    4, 85, 7, 83, 8, 30, 5, 14, 6, 39, 0, 17, 2, 96, 1, 34, 3, 17, 
    7, 74, 6, 45, 0, 80, 3, 97, 4, 73, 2, 70, 1, 18, 5, 99, 8, 57, 
    0, 51, 5, 15, 7, 40, 8, 10, 6, 81, 4, 15, 3, 32, 1, 87, 2, 82, 
    1, 56, 3, 81, 5, 18, 8, 84, 0,  8, 2, 32, 6, 68, 7, 62, 4, 77, 
    0, 45, 6,  1, 1, 69, 5, 22, 7, 91, 3, 75, 8, 68, 4,  8, 2, 78, 
    4, 85, 3, 63, 2, 23, 5, 96, 1, 83, 0,  5, 6,  8, 7, 76, 8,  2
  };
  const int q1340[] = {
    9, 9, // Number of jobs and machines
    6, 91, 5,  9, 8, 19, 1, 38, 0, 93, 3, 97, 2, 65, 7, 22, 4, 30, 
    6, 18, 8, 60, 1, 87, 7, 17, 2, 89, 3, 80, 5, 27, 4, 75, 0, 23, 
    2, 75, 0, 81, 6, 50, 4, 79, 7, 20, 3, 86, 5, 80, 8, 25, 1, 53, 
    1, 19, 8, 69, 0, 83, 2, 33, 4, 57, 3, 45, 6, 73, 5, 59, 7, 78, 
    2, 12, 0, 39, 8, 14, 1, 55, 3, 42, 7, 66, 6, 52, 4, 10, 5, 62, 
    7, 26, 2,  7, 4, 33, 6, 19, 1, 89, 5,  5, 8, 79, 3, 20, 0, 94, 
    8, 57, 2, 91, 6,  6, 4, 79, 5, 53, 7, 58, 0, 59, 3,  2, 1, 80, 
    0, 14, 4, 66, 8, 73, 3, 73, 5, 40, 2, 40, 1, 55, 6, 80, 7, 88, 
    6, 16, 2, 60, 0, 93, 7, 82, 5, 21, 3, 94, 4, 23, 1, 29, 8, 90
  };
  const int q1341[] = {
    9, 9, // Number of jobs and machines
    8, 44, 5, 25, 7, 59, 1, 14, 4, 35, 3, 58, 6, 43, 0, 68, 2, 93, 
    4, 74, 7, 78, 2, 95, 0, 22, 6, 56, 3,  1, 8, 53, 1, 88, 5, 43, 
    5, 40, 6, 95, 4, 87, 0, 90, 8, 30, 2, 32, 1, 46, 3, 75, 7, 88, 
    2, 28, 5,  3, 4, 82, 8,  5, 3, 97, 0, 85, 6, 88, 1, 30, 7, 95, 
    2, 99, 6, 30, 1, 74, 0, 13, 7, 61, 3, 96, 8, 11, 5, 36, 4, 48, 
    3, 79, 1, 68, 7, 50, 2, 48, 0, 69, 5, 17, 6, 27, 8, 44, 4, 90, 
    3, 41, 6, 27, 0, 24, 8, 14, 4, 97, 7, 48, 5, 30, 2, 88, 1, 54, 
    3, 11, 7, 19, 0, 90, 6, 40, 8, 33, 5, 62, 1, 22, 4, 37, 2, 95, 
    0, 55, 8, 96, 2, 58, 4, 70, 3, 60, 6, 45, 1,  4, 7, 24, 5, 96
  };
  const int q1342[] = {
    9, 9, // Number of jobs and machines
    3, 34, 7,  5, 4, 75, 2, 55, 6, 13, 0, 43, 8, 77, 5,  3, 1, 19, 
    6, 68, 1,  6, 7, 53, 5, 43, 3, 78, 0, 48, 4, 89, 2, 48, 8, 72, 
    7, 61, 3, 75, 5, 62, 8, 41, 6, 69, 1,  5, 0, 74, 2, 95, 4, 91, 
    6, 36, 3, 61, 8, 88, 2, 29, 4,  5, 5, 25, 7, 94, 0, 10, 1, 68, 
    4, 97, 3, 16, 7, 10, 1, 41, 2, 78, 8, 33, 6,  4, 0,  7, 5, 89, 
    3, 53, 6, 22, 8, 51, 2, 34, 0, 80, 5, 23, 4, 68, 7, 44, 1, 78, 
    0, 55, 2, 58, 4, 52, 5, 58, 8, 69, 7, 53, 3, 79, 6,  7, 1, 61, 
    7, 57, 1, 20, 3, 73, 6, 23, 0,  1, 4, 38, 5, 18, 8,  9, 2, 78, 
    5, 53, 2, 67, 4, 72, 1, 27, 6, 74, 8, 94, 7, 21, 3, 77, 0, 22
  };
  const int q1343[] = {
    9, 9, // Number of jobs and machines
    2, 62, 3, 99, 1, 31, 8, 94, 4, 31, 7, 33, 0, 61, 5, 44, 6, 83, 
    2, 51, 3, 34, 7, 13, 0, 87, 5, 11, 8, 67, 4,  8, 6, 75, 1, 26, 
    5, 36, 7, 13, 8, 82, 0, 23, 6, 64, 1, 49, 2, 39, 3, 35, 4, 12, 
    2,  4, 6, 68, 8, 70, 7, 85, 3, 31, 1, 47, 5, 55, 0, 66, 4, 98, 
    1, 76, 6, 73, 4, 71, 5, 24, 3, 13, 0,  8, 8, 65, 2, 68, 7, 22, 
    6, 20, 2, 10, 0, 72, 7, 55, 3, 24, 5, 11, 1, 48, 8, 25, 4, 73, 
    2, 28, 7,  3, 8, 38, 4, 25, 3, 72, 6, 49, 0, 69, 1, 18, 5, 91, 
    2, 57, 0, 77, 8, 41, 6, 26, 7, 35, 4, 21, 1, 19, 5, 53, 3,  3, 
    5, 25, 8, 14, 6, 73, 4, 25, 1, 30, 7, 43, 0,  4, 2, 74, 3, 80
  };
  const int q1344[] = {
    9, 9, // Number of jobs and machines
    8, 45, 2, 69, 7, 80, 4, 60, 6, 60, 0,  3, 5, 34, 3, 89, 1, 89, 
    4, 82, 8, 63, 6, 15, 7, 46, 3, 91, 0, 61, 2, 76, 1, 55, 5, 83, 
    0, 30, 1, 57, 6, 13, 3, 38, 4, 24, 7, 54, 2, 84, 8, 58, 5, 40, 
    1, 75, 8,  1, 5,  4, 2, 11, 3, 52, 7,  8, 6, 74, 0, 10, 4, 50, 
    7, 45, 6, 43, 5, 84, 2, 87, 8, 95, 4, 94, 0, 19, 3, 99, 1, 56, 
    1, 50, 2, 98, 4, 49, 8, 46, 7, 90, 6, 19, 0, 89, 3, 31, 5, 43, 
    0,  9, 1, 74, 7, 22, 3, 48, 6, 70, 5, 36, 4, 73, 8, 76, 2, 13, 
    4, 74, 5, 92, 2, 33, 6, 92, 0, 71, 7, 11, 3, 12, 8, 56, 1, 64, 
    8, 42, 2, 47, 7,  8, 5, 64, 4,  1, 1, 56, 0,  9, 3, 47, 6, 84
  };
  const int q1345[] = {
    9, 9, // Number of jobs and machines
    1, 50, 8, 44, 3, 96, 7, 80, 4, 75, 2, 88, 6, 84, 5, 15, 0, 74, 
    8, 65, 4, 87, 6, 70, 7, 32, 0, 82, 1, 43, 5, 36, 2, 46, 3, 66, 
    1, 96, 8, 14, 2, 58, 7,  6, 3, 53, 0, 45, 5, 26, 4,  1, 6, 29, 
    3, 31, 0, 72, 8, 83, 2, 18, 1, 44, 6, 39, 7, 45, 4, 56, 5, 13, 
    4, 14, 8, 29, 6, 33, 1, 20, 3, 33, 5,  1, 7, 57, 2, 30, 0, 96, 
    7, 30, 5, 24, 3, 66, 4, 69, 6,  8, 0, 95, 1, 41, 2, 81, 8,  3, 
    1, 80, 2, 61, 5, 81, 4, 86, 8, 14, 3, 36, 0, 93, 7, 73, 6, 49, 
    1, 22, 4, 44, 3, 54, 2, 73, 8, 89, 7, 91, 5,  4, 0, 50, 6, 35, 
    2, 29, 0, 62, 8, 56, 1, 42, 4, 26, 3, 63, 7, 48, 5, 59, 6, 77
  };
  const int q1346[] = {
    9, 9, // Number of jobs and machines
    1, 50, 6, 77, 4, 18, 0, 30, 7, 76, 3, 95, 8, 90, 2, 16, 5, 80, 
    0, 58, 8, 37, 4, 55, 6, 57, 1, 20, 5,  3, 2, 18, 7,  1, 3, 36, 
    5, 39, 3, 96, 0, 55, 8, 70, 2, 27, 4, 27, 6, 66, 7, 18, 1, 19, 
    8, 60, 7, 49, 3, 39, 6,  4, 1, 52, 5, 28, 2, 16, 0, 10, 4, 83, 
    0, 21, 2,  5, 7, 74, 6, 72, 1, 79, 4, 45, 8, 92, 3, 99, 5, 98, 
    6, 38, 7, 85, 0, 72, 3, 15, 5, 75, 1, 58, 2, 29, 4, 57, 8, 25, 
    3, 85, 0, 55, 5, 72, 7,  9, 8, 32, 2, 20, 4, 26, 6, 12, 1, 90, 
    0, 37, 3, 15, 7,  8, 1, 25, 8, 78, 4, 62, 5, 24, 6, 18, 2,  9, 
    6, 91, 4, 89, 0, 58, 1, 77, 7, 12, 3, 21, 5, 38, 8, 47, 2, 94
  };
  const int q1347[] = {
    9, 9, // Number of jobs and machines
    6, 13, 2, 29, 0, 33, 5, 53, 8, 13, 4, 57, 3, 61, 1,  6, 7, 69, 
    3, 11, 1, 90, 4, 46, 2, 13, 0, 73, 5, 44, 7, 40, 6, 35, 8, 23, 
    8, 40, 4,  5, 1, 76, 3, 23, 0, 17, 6, 30, 5, 11, 7, 21, 2, 67, 
    2, 89, 1, 31, 0, 10, 4, 12, 5, 48, 8, 14, 6, 60, 7, 94, 3, 19, 
    2, 86, 6,  9, 7, 33, 8, 78, 4, 41, 1, 72, 0, 15, 5, 88, 3, 26, 
    3, 36, 4, 99, 5, 59, 7, 68, 2, 16, 0, 49, 6, 24, 8, 65, 1, 65, 
    4, 15, 1, 74, 0, 82, 5, 73, 3, 25, 6, 36, 2, 18, 7,  1, 8, 34, 
    5, 67, 2, 42, 0, 25, 6,  7, 7, 47, 8, 69, 4, 22, 3, 35, 1, 50, 
    7,  7, 2, 55, 1, 46, 3, 54, 0, 55, 4, 73, 8, 51, 6, 60, 5, 87
  };
  const int q1348[] = {
    9, 9, // Number of jobs and machines
    2, 39, 0, 33, 7, 52, 5, 46, 8, 94, 4, 70, 1, 69, 6, 26, 3, 83, 
    3, 60, 0, 63, 5, 56, 6, 22, 8, 53, 1, 45, 7, 40, 2, 60, 4, 16, 
    4, 68, 7, 92, 3, 48, 2, 21, 1, 83, 6, 88, 5, 49, 0, 82, 8, 22, 
    8,  3, 2, 94, 6, 16, 5, 88, 4, 28, 3, 80, 1, 93, 0, 13, 7, 21, 
    3,  2, 5, 38, 7, 51, 0, 90, 1, 81, 2, 94, 4, 17, 8, 39, 6, 49, 
    5, 92, 6,  2, 7,  5, 8, 60, 2, 63, 0,  2, 1,  2, 3, 15, 4, 11, 
    6, 67, 2, 58, 5, 96, 7, 95, 0, 39, 8, 21, 4, 21, 1,  9, 3, 37, 
    6, 11, 4,  3, 8, 19, 0, 53, 2, 66, 7, 79, 5, 64, 3, 76, 1, 65, 
    1, 51, 2, 73, 3, 69, 4, 81, 5, 22, 6, 24, 8, 23, 0,  9, 7, 44
  };
  const int q1349[] = {
    9, 9, // Number of jobs and machines
    3, 24, 7, 66, 4,  1, 0, 54, 5, 45, 1, 50, 6, 56, 8, 20, 2, 62, 
    1, 13, 2,  3, 4, 46, 0, 12, 6, 66, 7, 68, 3, 63, 8, 64, 5, 40, 
    4, 41, 1, 87, 5, 87, 0, 37, 6, 65, 2, 35, 8, 71, 7, 60, 3, 61, 
    6, 38, 8, 52, 4,  8, 0,  8, 2, 34, 3, 70, 5, 51, 1, 52, 7, 97, 
    4, 65, 6, 96, 7, 34, 5, 16, 8, 14, 3, 50, 0, 95, 1, 93, 2, 50, 
    7, 89, 4, 61, 0, 73, 5, 54, 1, 42, 2, 75, 8, 44, 6, 62, 3, 89, 
    5, 24, 1, 17, 3, 33, 4, 74, 6, 80, 8, 49, 2, 97, 7, 14, 0, 21, 
    4, 79, 0, 20, 8, 51, 5, 77, 7, 39, 2, 65, 1, 70, 6, 30, 3, 44, 
    2, 65, 6, 63, 3, 97, 5,  6, 4, 45, 1, 76, 7, 14, 0, 86, 8, 16
  };
  const int q1350[] = {
    9, 9, // Number of jobs and machines
    3, 40, 6, 71, 4, 77, 8, 35, 7, 54, 0, 12, 2,  3, 5, 94, 1, 76, 
    5, 54, 2, 62, 0, 33, 1, 80, 8,  5, 6, 56, 3, 12, 7, 40, 4, 84, 
    1, 46, 0, 68, 2, 40, 3,  5, 8, 71, 4, 35, 5, 35, 7, 15, 6, 33, 
    0, 85, 1,  9, 5, 65, 6, 37, 7, 96, 3, 45, 8, 71, 4, 69, 2,  9, 
    3, 11, 2, 66, 7, 14, 8, 60, 0, 40, 6, 47, 5, 83, 1, 25, 4, 25, 
    7, 50, 5,  7, 3, 59, 4, 89, 6, 82, 0, 63, 8,  7, 1, 23, 2, 52, 
    5, 70, 0, 16, 3, 58, 8, 18, 1, 97, 2, 91, 4, 58, 6, 39, 7,  9, 
    1, 32, 7, 97, 4, 71, 8, 35, 0, 71, 3, 54, 2, 46, 5, 42, 6, 19, 
    8, 16, 1, 46, 5, 69, 6, 57, 0, 48, 2, 35, 7, 27, 4,  5, 3, 31
  };
  const int q1351[] = {
    9, 9, // Number of jobs and machines
    6, 29, 2, 19, 1, 85, 8, 42, 4, 74, 7, 15, 5,  2, 0, 83, 3,  3, 
    5,  6, 0, 44, 8, 33, 1,  5, 4, 55, 3, 21, 2, 86, 6,  3, 7, 36, 
    3, 66, 8, 89, 0, 99, 6, 90, 5, 96, 2, 21, 1, 67, 4, 92, 7, 33, 
    8, 28, 2, 69, 6, 24, 0, 38, 3, 36, 4, 26, 5, 98, 7, 36, 1, 40, 
    6, 35, 8, 39, 2, 71, 1, 76, 5, 90, 4, 54, 7, 21, 0, 40, 3, 35, 
    3,  4, 7, 52, 1, 14, 2, 39, 0, 69, 8, 91, 6, 97, 5, 68, 4, 36, 
    3, 57, 6, 81, 4, 48, 5,  6, 1, 65, 8, 19, 7, 60, 2, 18, 0, 79, 
    2, 69, 8,  6, 0,  1, 1, 25, 7, 93, 4,  9, 6, 76, 5, 49, 3, 96, 
    5, 58, 2, 97, 1, 76, 6, 79, 0, 20, 8, 49, 4, 85, 3,  1, 7, 15
  };
  const int q1352[] = {
    9, 9, // Number of jobs and machines
    7, 64, 2, 71, 8, 75, 1, 67, 5,  6, 4, 81, 6, 19, 0, 78, 3, 72, 
    1, 62, 6, 50, 8, 90, 2,  4, 3, 21, 7,  8, 4, 54, 5, 14, 0, 61, 
    0, 33, 8, 51, 5,  7, 1, 29, 6, 14, 7, 53, 2, 72, 4, 53, 3, 73, 
    5, 93, 3, 49, 6, 20, 0, 88, 2, 91, 8, 99, 1, 93, 4, 74, 7, 48, 
    4, 82, 1, 47, 5, 45, 3, 49, 0, 97, 2, 64, 8, 98, 7, 45, 6, 61, 
    3, 35, 8, 52, 6, 61, 2, 32, 5, 14, 7, 53, 1, 56, 0, 24, 4,  4, 
    6, 24, 1, 39, 8, 21, 4, 78, 5, 69, 0, 66, 3, 18, 2, 40, 7, 54, 
    6, 96, 8, 93, 0, 34, 1, 76, 2, 26, 4, 64, 7, 60, 3, 95, 5, 29, 
    0, 85, 5, 22, 2, 19, 8, 23, 4,  8, 3, 35, 6, 87, 7, 55, 1, 60
  };
  const int q1353[] = {
    9, 9, // Number of jobs and machines
    5, 43, 2, 17, 7, 15, 0, 19, 3,  5, 6, 87, 4, 44, 8, 17, 1, 11, 
    2, 84, 8, 15, 5, 13, 6, 88, 3, 72, 0, 79, 1, 91, 7, 95, 4,  5, 
    7, 93, 8, 77, 4, 51, 2, 68, 5,  6, 0, 98, 1, 11, 6, 24, 3, 10, 
    5, 86, 2, 35, 4, 52, 1, 25, 7, 36, 8, 13, 0, 67, 3, 18, 6, 39, 
    4, 69, 0,  8, 1, 20, 5,  5, 7, 59, 8, 36, 3, 15, 2, 98, 6, 52, 
    7, 57, 1, 28, 3,  5, 5, 18, 8, 51, 2,  5, 0, 98, 4, 59, 6, 31, 
    5, 71, 6, 84, 7, 75, 3, 81, 2, 47, 0, 83, 8, 75, 1, 42, 4,  7, 
    2, 78, 8,  8, 4, 19, 5, 78, 6,  3, 0, 93, 7, 67, 3, 81, 1,  4, 
    1, 77, 5, 90, 8, 95, 3, 29, 0, 44, 6, 44, 4, 52, 2, 10, 7, 22
  };
  const int q1354[] = {
    9, 9, // Number of jobs and machines
    3, 29, 5, 69, 6, 79, 2, 63, 1, 82, 4, 10, 7, 41, 0,  1, 8, 41, 
    6, 66, 2, 24, 3, 43, 5, 24, 4, 65, 1, 48, 7, 65, 0, 24, 8, 98, 
    4,  1, 3, 47, 5, 72, 1, 88, 7, 39, 6, 69, 2, 43, 0, 43, 8, 58, 
    2, 14, 6, 28, 1, 71, 5, 42, 7, 78, 3, 22, 8, 82, 4,  3, 0, 31, 
    6, 15, 2, 31, 3, 75, 7, 86, 4, 76, 8, 31, 0, 11, 1, 81, 5,  8, 
    3, 96, 7, 71, 5, 65, 0, 54, 2, 82, 6,  3, 1, 57, 8, 96, 4, 39, 
    6, 27, 4,  3, 8,  6, 0, 85, 3, 46, 2, 16, 7, 40, 5, 14, 1, 25, 
    4, 97, 5, 49, 7, 14, 6, 36, 3,  8, 8, 17, 2, 22, 1, 92, 0, 75, 
    5, 99, 7, 42, 6, 74, 3, 90, 8, 32, 4, 22, 1, 21, 0, 95, 2,  4
  };
  const int q1355[] = {
    9, 9, // Number of jobs and machines
    8, 64, 4, 72, 3, 17, 5, 60, 0, 49, 7, 65, 2, 26, 1, 29, 6, 61, 
    3, 54, 0, 46, 4, 16, 2, 35, 1,  9, 8, 43, 5, 76, 7, 68, 6, 73, 
    8, 93, 7, 14, 4, 37, 3, 95, 5, 25, 6, 88, 2, 66, 1, 73, 0, 51, 
    2, 76, 5, 87, 1, 93, 8, 20, 0, 40, 7, 79, 4, 10, 6, 24, 3, 95, 
    4, 10, 2, 59, 5, 30, 7,  2, 1, 81, 8,  5, 0, 48, 6, 78, 3, 44, 
    7, 22, 3, 20, 0, 40, 4, 71, 6, 30, 2, 57, 5, 15, 8, 98, 1, 93, 
    0, 91, 4,  6, 5, 43, 1, 38, 6, 27, 7, 83, 3, 87, 2, 74, 8,  8, 
    6, 14, 1, 63, 4, 78, 3, 40, 2,  2, 8, 25, 0, 56, 7, 11, 5, 66, 
    3,  1, 4, 69, 5, 14, 8,  8, 2,  4, 0, 48, 6, 57, 7, 69, 1, 12
  };
  const int q1356[] = {
    9, 9, // Number of jobs and machines
    4, 14, 0, 75, 1, 19, 2, 45, 8, 45, 5, 51, 3, 56, 6, 82, 7, 25, 
    6, 44, 0, 91, 2, 40, 7, 78, 5, 50, 8, 74, 4, 41, 1, 10, 3, 32, 
    4, 90, 3,  2, 6, 90, 0, 77, 8, 44, 2, 71, 1, 74, 7, 50, 5, 59, 
    8, 48, 0, 21, 7, 33, 1, 38, 3, 85, 4, 38, 2, 14, 5,  4, 6, 96, 
    2, 54, 0, 38, 6,  7, 8, 94, 4, 98, 7, 58, 1, 54, 3, 44, 5, 85, 
    7, 97, 3, 44, 1, 42, 6, 78, 0, 48, 5, 56, 4, 59, 8, 64, 2,  1, 
    8,  7, 2, 40, 0, 87, 3, 64, 7, 54, 6,  2, 4, 40, 1, 82, 5, 75, 
    2, 63, 8, 37, 3, 81, 1, 36, 5, 65, 4,  7, 6, 15, 0, 32, 7, 32, 
    1,  7, 5, 17, 6, 48, 4, 52, 7, 39, 8, 79, 3, 64, 0, 26, 2, 74
  };
  const int q1357[] = {
    9, 9, // Number of jobs and machines
    3,  3, 6, 11, 0,  3, 8, 63, 2, 79, 7, 40, 5, 93, 4, 65, 1, 71, 
    4, 74, 0, 91, 7, 72, 8, 85, 2, 82, 3,  1, 6, 27, 5,  2, 1,  6, 
    2, 99, 3, 80, 8, 11, 1, 70, 7, 95, 4, 48, 6, 14, 0, 36, 5,  5, 
    4, 62, 1, 81, 2, 65, 6, 34, 7, 80, 8, 98, 0, 29, 3, 57, 5, 68, 
    2, 83, 7,  7, 8, 85, 4, 97, 1,  5, 0, 50, 5, 97, 3, 88, 6, 97, 
    6, 91, 7,  5, 0, 80, 8, 48, 1, 31, 4, 69, 5, 97, 3, 98, 2, 31, 
    3,  5, 7, 94, 0, 91, 2, 31, 1, 37, 6, 97, 8, 58, 5, 75, 4, 97, 
    7, 65, 3, 95, 5, 67, 8, 44, 4, 30, 0, 24, 1,  8, 2, 80, 6, 70, 
    4, 77, 5, 86, 0, 96, 2, 78, 1,  4, 7, 41, 6, 61, 8, 88, 3,  3
  };
  const int q1358[] = {
    9, 9, // Number of jobs and machines
    0, 19, 4, 97, 1, 22, 5, 28, 3, 43, 7, 49, 2, 92, 6, 51, 8, 99, 
    5, 42, 3, 26, 4, 20, 6, 69, 7, 44, 2, 69, 8,  9, 0, 49, 1, 92, 
    1, 13, 8, 69, 6, 53, 5, 23, 4, 52, 7, 52, 0, 34, 2, 83, 3,  8, 
    0, 45, 2, 20, 3, 72, 4, 46, 6, 18, 1, 80, 7, 95, 8, 63, 5, 57, 
    8, 26, 1, 40, 3, 98, 7, 92, 4, 56, 0, 94, 2, 10, 6, 66, 5, 33, 
    1, 73, 7, 55, 3, 28, 0, 76, 4, 28, 5, 91, 8, 51, 2, 11, 6, 97, 
    6, 59, 3, 74, 7, 64, 0, 58, 5, 60, 8,  2, 2, 81, 1, 23, 4, 68, 
    5, 62, 4, 73, 2, 86, 3, 87, 8, 95, 1, 30, 0, 87, 7,  8, 6, 23, 
    3, 80, 8, 42, 2, 59, 0, 85, 7, 96, 5, 37, 6, 15, 4, 17, 1, 12
  };
  const int q1359[] = {
    9, 9, // Number of jobs and machines
    5, 86, 8, 99, 3,  4, 2, 96, 6, 66, 0, 32, 4, 68, 7, 31, 1, 72, 
    4, 41, 2, 37, 7, 68, 5,  6, 0, 50, 3, 16, 6, 93, 1, 84, 8, 74, 
    7, 66, 4, 42, 1, 75, 0, 12, 5, 92, 6, 85, 8, 69, 2, 56, 3, 22, 
    6, 88, 8, 60, 1, 31, 7, 99, 0, 77, 2, 23, 3, 95, 4, 59, 5, 88, 
    7, 34, 6, 77, 4, 15, 0, 83, 3, 97, 2, 98, 1, 68, 5, 27, 8, 70, 
    8, 33, 0, 48, 2, 82, 3, 49, 6, 93, 1, 99, 5, 18, 4, 31, 7, 87, 
    8, 12, 2, 44, 5, 82, 7, 22, 1, 19, 6, 65, 4, 75, 0, 92, 3, 61, 
    3, 90, 4, 59, 2, 27, 5, 80, 6, 47, 1, 88, 7, 45, 8, 72, 0, 24, 
    1, 59, 2, 59, 6, 78, 7, 78, 8, 68, 5, 44, 3, 52, 0, 12, 4, 44
  };
  const int q1360[] = {
    9, 9, // Number of jobs and machines
    1, 60, 8, 45, 2, 24, 5, 13, 0, 26, 7, 99, 4, 29, 6, 52, 3, 37, 
    4, 99, 6, 42, 3, 95, 2, 18, 8, 38, 0, 39, 1, 87, 7, 35, 5, 12, 
    2, 61, 5, 12, 1, 86, 8, 61, 3, 94, 0, 46, 7, 60, 6, 40, 4, 55, 
    7, 11, 8, 19, 0, 82, 2, 65, 6, 79, 4, 82, 1, 67, 5, 10, 3, 94, 
    0, 84, 8, 65, 3, 63, 2, 35, 5, 30, 7, 64, 4, 19, 1, 31, 6, 11, 
    0, 31, 7, 81, 4, 37, 2, 89, 6, 95, 8, 60, 1, 82, 5, 27, 3, 95, 
    7, 74, 8, 97, 5, 52, 6, 98, 4, 67, 0, 19, 1, 39, 3, 52, 2, 67, 
    2, 59, 7, 61, 8, 54, 6, 12, 4, 69, 0, 80, 1, 12, 3, 64, 5, 14, 
    1, 65, 4, 48, 3, 42, 6, 60, 5, 18, 2, 90, 8, 17, 7,  4, 0, 59
  };
  const int q1361[] = {
    9, 9, // Number of jobs and machines
    8, 17, 5, 74, 4, 63, 1, 23, 2, 68, 7, 40, 0, 17, 3, 94, 6, 42, 
    0, 92, 2, 74, 3,  1, 8, 71, 1, 77, 5, 57, 6, 32, 4, 27, 7, 95, 
    6, 49, 7, 41, 1, 85, 3, 21, 4, 93, 2,  4, 8, 94, 5, 63, 0, 30, 
    6, 82, 3,  9, 0, 80, 8, 59, 1, 20, 4, 37, 5, 72, 2, 67, 7, 99, 
    6, 78, 5, 67, 0, 71, 2, 96, 1, 11, 7, 48, 4, 61, 8, 35, 3, 52, 
    7, 75, 4, 39, 1, 53, 0, 30, 8, 50, 3, 21, 5, 42, 6, 91, 2, 91, 
    3, 52, 5, 84, 0, 99, 1, 13, 6, 45, 2, 33, 4, 52, 8, 85, 7, 87, 
    4, 35, 3, 34, 1, 40, 2, 39, 0, 75, 5, 79, 6, 86, 7, 32, 8, 20, 
    7, 18, 6, 39, 3, 19, 5, 87, 1, 82, 0, 47, 4, 54, 8, 46, 2, 70
  };
  const int q1362[] = {
    9, 9, // Number of jobs and machines
    7, 77, 3, 66, 2, 27, 6, 82, 5, 65, 8, 90, 4, 59, 0,  2, 1, 54, 
    5, 29, 2, 44, 0,  1, 6, 90, 7,  7, 8, 56, 4, 46, 1, 57, 3, 82, 
    7, 71, 6, 33, 1, 36, 0, 19, 5, 72, 4, 42, 8, 12, 2, 44, 3, 51, 
    0, 28, 1, 79, 4, 21, 2, 41, 8, 91, 6, 34, 5,  7, 3,  5, 7, 76, 
    4, 10, 5, 28, 3, 21, 6, 58, 8, 12, 2, 99, 0, 27, 1,  9, 7, 90, 
    0,  7, 8, 90, 4, 48, 2, 16, 7, 80, 5, 12, 3, 96, 6, 39, 1, 45, 
    1, 25, 6, 80, 0, 75, 3, 96, 2, 43, 7, 20, 4, 26, 5, 72, 8, 59, 
    2, 24, 4, 15, 8, 50, 5, 35, 1, 19, 3, 26, 6, 32, 0, 39, 7,  1, 
    7,  5, 0, 68, 1, 65, 6, 34, 5, 18, 8, 38, 3, 23, 2, 29, 4, 42
  };
  const int q1363[] = {
    9, 9, // Number of jobs and machines
    6, 90, 7,  3, 8,  9, 1, 58, 2, 28, 5, 68, 0, 24, 4, 33, 3, 49, 
    0, 70, 5,  1, 1, 40, 7,  4, 2, 79, 4, 48, 6, 56, 8, 37, 3, 46, 
    3,  9, 5, 25, 0, 20, 7, 25, 8, 42, 4,  9, 6, 21, 1, 69, 2,  5, 
    5, 76, 4, 50, 1, 40, 0,  1, 7, 18, 6,  6, 8, 56, 3, 66, 2, 40, 
    2, 37, 8, 75, 4, 21, 5, 75, 0, 19, 6, 84, 3, 56, 1, 61, 7,  1, 
    7, 43, 5, 58, 6, 28, 1, 93, 3, 43, 4, 32, 0, 26, 8,  4, 2, 15, 
    4, 86, 6, 95, 3, 30, 5, 82, 0, 42, 7, 46, 8, 40, 2, 62, 1, 52, 
    2, 33, 1, 25, 6, 32, 3,  8, 5, 41, 4, 59, 0, 13, 8, 17, 7,  6, 
    7, 92, 5, 95, 2, 61, 0, 29, 8, 99, 1, 32, 4, 56, 3,  9, 6, 95
  };
  const int q1364[] = {
    9, 9, // Number of jobs and machines
    0, 94, 4, 85, 3, 71, 5,  4, 7, 71, 8, 77, 1, 28, 6, 55, 2, 40, 
    8, 53, 3, 51, 4, 52, 5,  8, 6, 46, 1, 52, 0, 83, 2, 46, 7, 65, 
    1, 16, 7, 25, 8, 42, 0, 10, 3, 36, 4, 50, 5, 33, 6, 32, 2, 58, 
    3, 21, 4, 37, 0, 84, 1, 97, 5,  8, 2, 27, 7, 63, 8, 40, 6, 20, 
    6, 33, 2, 72, 1, 88, 0,  6, 3, 93, 4, 93, 7, 78, 5, 69, 8,  8, 
    5, 27, 4, 60, 2, 50, 1, 76, 7, 12, 0, 29, 3, 77, 8, 59, 6, 53, 
    2, 74, 3, 11, 0, 30, 6,  8, 1, 51, 5, 18, 8, 27, 7, 87, 4, 47, 
    3, 56, 0, 16, 7,  8, 6, 98, 2, 93, 5, 76, 8, 31, 1, 81, 4, 22, 
    6, 52, 5, 58, 1, 63, 0, 61, 7, 69, 8, 35, 3, 83, 4, 90, 2,  7
  };
  const int q1365[] = {
    9, 9, // Number of jobs and machines
    8,  3, 5, 16, 6, 15, 3, 38, 7, 87, 0, 73, 1, 57, 4, 89, 2, 45, 
    7, 48, 6, 20, 8, 16, 1, 57, 3, 55, 2, 77, 4, 47, 5, 94, 0, 75, 
    0, 98, 3, 36, 4, 15, 1, 63, 8, 74, 5, 16, 6, 85, 2, 50, 7, 46, 
    6, 83, 1, 80, 8,  5, 2, 23, 7,  3, 0, 20, 4,  1, 5, 30, 3, 21, 
    1, 50, 8, 27, 6,  5, 3, 10, 0, 54, 2, 83, 5, 84, 4, 96, 7, 34, 
    5, 57, 4, 54, 7, 27, 0, 44, 1, 92, 2, 55, 3, 63, 6, 31, 8, 60, 
    7, 48, 8, 96, 5, 83, 0, 96, 2, 38, 6, 93, 3, 63, 4, 87, 1, 31, 
    8, 90, 4, 96, 5, 65, 2, 85, 0, 50, 3, 87, 6, 32, 1, 26, 7, 94, 
    1, 37, 2, 96, 6, 28, 5, 40, 7, 93, 0, 76, 8,  4, 3, 68, 4, 24
  };
  const int q1366[] = {
    9, 9, // Number of jobs and machines
    7, 60, 3,  9, 1, 78, 6, 60, 8, 68, 4, 78, 5, 43, 0, 19, 2, 59, 
    6, 16, 7,  5, 2, 69, 8, 85, 4, 97, 0, 18, 3, 70, 1, 25, 5, 63, 
    8, 12, 1, 99, 4, 90, 3, 20, 7, 47, 2, 99, 5, 18, 6, 91, 0, 46, 
    8, 67, 4, 68, 2, 83, 0, 91, 1, 58, 6, 77, 7, 72, 3, 10, 5, 39, 
    0, 12, 6, 93, 1, 72, 7, 40, 5, 96, 4, 62, 3, 47, 2, 77, 8, 90, 
    8, 37, 6, 81, 4, 55, 5, 74, 0, 86, 3, 91, 7, 26, 2, 45, 1, 13, 
    8, 20, 0, 62, 1, 77, 2, 16, 5, 68, 3, 62, 7,  6, 4, 98, 6, 25, 
    8, 81, 0, 40, 5, 90, 7, 45, 4, 87, 1, 30, 3, 44, 6, 95, 2, 43, 
    8, 21, 7,  7, 0, 56, 1, 37, 6, 83, 3, 51, 2, 21, 4, 92, 5, 32
  };
  const int q1367[] = {
    9, 9, // Number of jobs and machines
    5, 28, 8, 55, 3,  6, 6, 67, 1, 20, 0, 19, 7,  8, 2, 13, 4, 12, 
    1, 78, 7, 15, 5, 72, 0, 13, 2, 54, 3, 17, 4, 13, 8, 16, 6, 41, 
    6, 53, 8, 11, 0, 71, 3, 64, 2, 18, 7, 51, 5, 15, 1, 53, 4, 98, 
    5, 26, 0, 95, 8, 85, 7, 53, 6, 90, 4, 92, 2, 41, 1, 23, 3, 70, 
    7, 46, 2, 33, 6, 85, 1, 42, 4, 31, 0, 40, 5, 95, 8, 48, 3, 44, 
    8, 68, 6, 76, 3, 25, 2, 27, 4, 20, 7, 29, 5, 14, 0, 44, 1, 32, 
    8, 21, 2,  5, 0, 13, 6, 83, 3, 21, 4, 20, 7, 28, 5, 11, 1,  8, 
    7, 43, 5, 60, 8, 30, 1, 14, 4, 15, 2,  3, 0, 72, 3, 67, 6, 27, 
    5, 64, 8, 98, 6, 41, 3, 72, 0, 30, 1, 54, 4,  1, 7, 91, 2, 20
  };
  const int q1368[] = {
    9, 9, // Number of jobs and machines
    6, 54, 8, 31, 3, 92, 4, 81, 1, 26, 7, 60, 5,  6, 0,  1, 2, 32, 
    7, 43, 1, 77, 5, 12, 4, 21, 2, 18, 0, 26, 3, 27, 8, 42, 6, 12, 
    5, 48, 7, 97, 4, 96, 8, 46, 3, 39, 6, 71, 2, 33, 1, 87, 0, 89, 
    6, 38, 0, 70, 4, 57, 3, 18, 2, 27, 7, 72, 5, 70, 1, 44, 8, 54, 
    5, 31, 2, 11, 7, 56, 4, 77, 3, 55, 8, 96, 0, 65, 1, 81, 6, 25, 
    4, 41, 7, 16, 6, 15, 0, 67, 2, 71, 5, 17, 3, 43, 1, 24, 8, 75, 
    2, 58, 0, 41, 5, 56, 3, 40, 8, 18, 1,  1, 7, 49, 6, 17, 4, 30, 
    8, 25, 4, 30, 3, 42, 2, 74, 0, 66, 7, 80, 6, 82, 5, 53, 1, 67, 
    6, 11, 5, 44, 8, 87, 4,  5, 2,  1, 3, 28, 7, 30, 1, 50, 0, 84
  };
  const int q1369[] = {
    9, 9, // Number of jobs and machines
    4, 58, 0, 90, 2, 92, 5, 57, 3, 53, 1, 25, 6, 17, 7, 29, 8, 45, 
    2, 63, 1, 77, 6,  6, 4, 61, 8, 94, 3, 82, 7, 28, 5,  5, 0, 53, 
    6, 60, 0, 23, 4, 80, 8, 88, 5, 41, 3, 46, 2, 40, 1, 18, 7, 24, 
    0, 61, 7, 66, 1, 50, 6, 64, 5, 76, 4, 99, 3, 84, 8, 31, 2, 71, 
    1, 87, 2, 25, 0, 91, 8,  5, 4, 77, 7, 41, 5, 71, 3, 14, 6, 31, 
    5, 56, 7, 17, 2, 59, 3,  8, 0, 73, 4, 10, 6, 68, 1, 85, 8, 77, 
    7, 97, 2, 92, 1, 99, 0, 45, 6, 75, 5,  8, 8, 71, 4, 10, 3, 69, 
    0, 93, 8, 96, 7, 78, 2, 89, 4, 13, 1, 80, 6, 13, 3, 96, 5, 81, 
    3, 98, 8, 95, 4, 72, 1, 51, 5, 20, 0, 42, 2, 66, 6, 14, 7, 86
  };
  const int q1370[] = {
    9, 9, // Number of jobs and machines
    6, 35, 3, 63, 4, 36, 7, 59, 8, 33, 1, 82, 0, 20, 2, 94, 5, 94, 
    0, 74, 1, 47, 3, 65, 4, 47, 8, 98, 6, 52, 2, 30, 5, 69, 7, 50, 
    4, 91, 0, 33, 5, 63, 6, 56, 2, 89, 1, 29, 3, 25, 8, 76, 7, 52, 
    5, 85, 3, 90, 7, 54, 2, 81, 6, 22, 4, 93, 8, 65, 1, 51, 0, 88, 
    2, 52, 4, 70, 7, 70, 1, 96, 3, 64, 6,  3, 0, 32, 5,  6, 8, 26, 
    2, 51, 4, 97, 3, 75, 1, 24, 0, 15, 5, 22, 6, 16, 7, 26, 8, 73, 
    4, 62, 6, 74, 7, 92, 0, 69, 8,  7, 5, 12, 2, 15, 1, 41, 3, 13, 
    0, 85, 4, 55, 6, 85, 1, 51, 3, 19, 2, 67, 7, 80, 8, 40, 5,  2, 
    0, 35, 2, 55, 1, 15, 6, 27, 5, 33, 7, 32, 4, 15, 8, 46, 3, 66
  };
  const int q1371[] = {
    9, 9, // Number of jobs and machines
    2, 62, 7, 12, 4, 46, 5, 93, 3, 32, 0, 88, 1, 44, 6,  1, 8,  7, 
    6, 77, 1, 44, 2, 49, 4, 56, 8, 98, 0, 36, 3, 65, 7, 64, 5, 17, 
    5, 78, 3, 56, 1, 28, 0, 19, 2, 80, 6, 97, 4, 56, 7, 78, 8, 36, 
    1, 13, 0, 61, 2, 52, 8, 73, 6, 34, 4, 25, 3, 70, 5, 50, 7, 76, 
    6, 34, 1, 24, 0, 10, 4, 30, 8, 85, 2, 26, 3,  2, 7, 31, 5, 62, 
    0, 62, 1, 72, 8, 57, 7, 70, 2, 82, 4, 76, 5, 76, 6, 45, 3, 67, 
    2,  7, 1, 25, 5, 31, 6, 68, 0, 99, 4, 16, 3, 92, 7, 29, 8, 72, 
    0, 35, 7, 52, 3, 24, 1, 32, 8,  2, 5, 35, 6,  6, 4, 47, 2, 81, 
    2, 32, 8, 66, 5, 18, 6, 24, 4, 35, 3, 64, 0, 49, 7, 22, 1, 61
  };
  const int q1372[] = {
    9, 9, // Number of jobs and machines
    2, 77, 5, 23, 4, 65, 7, 67, 6, 24, 0, 65, 1, 16, 3, 37, 8, 85, 
    7, 29, 8, 37, 4, 58, 6, 82, 5, 94, 1, 51, 3, 78, 2, 30, 0, 78, 
    3, 13, 6, 70, 4, 42, 2, 45, 7, 75, 8, 17, 1, 97, 0, 95, 5, 97, 
    8, 55, 5, 10, 6, 40, 1, 63, 4, 69, 7, 63, 3, 43, 2, 46, 0, 11, 
    2, 80, 6, 56, 1, 88, 4, 65, 8, 62, 0, 41, 5, 41, 3, 10, 7, 50, 
    3, 10, 2, 86, 7, 65, 1, 58, 8, 95, 0, 33, 5, 98, 6, 66, 4, 10, 
    7, 98, 0, 37, 2, 34, 8, 71, 5, 30, 3,  8, 4,  9, 1,  6, 6, 66, 
    5, 87, 6, 79, 7, 47, 2,  8, 4, 72, 0, 45, 1, 38, 3, 61, 8, 55, 
    5, 95, 3, 52, 2, 97, 6, 23, 7, 16, 0, 92, 8, 42, 4, 48, 1, 25
  };
  const int q1373[] = {
    9, 9, // Number of jobs and machines
    6, 13, 2, 51, 4, 89, 3, 20, 8, 73, 5, 81, 0, 88, 1, 17, 7, 23, 
    2, 22, 8, 91, 0, 57, 3, 99, 4, 75, 7, 71, 1, 73, 5, 11, 6, 76, 
    0,  1, 8, 94, 6, 18, 7, 90, 5, 63, 1, 32, 3,  6, 2, 50, 4, 31, 
    4, 49, 0, 84, 7, 66, 2, 26, 1, 78, 5, 80, 6, 48, 3,  4, 8, 20, 
    5, 44, 4, 69, 6, 54, 0, 70, 1, 15, 2, 39, 7, 40, 3, 66, 8, 96, 
    2, 50, 8, 32, 4, 83, 6, 26, 1, 74, 5, 44, 7, 91, 3, 29, 0, 25, 
    1, 90, 4, 20, 7, 40, 2, 88, 3, 11, 5, 50, 6, 16, 0, 51, 8, 73, 
    3, 70, 0, 76, 6, 73, 8, 30, 2, 93, 1, 14, 4, 72, 7, 80, 5, 19, 
    0, 16, 7, 32, 1, 18, 6, 30, 2, 48, 3, 16, 8, 33, 4, 15, 5, 69
  };
  const int q1374[] = {
    9, 9, // Number of jobs and machines
    1, 97, 6, 71, 4, 77, 5, 81, 2, 89, 3,  5, 0,  2, 8, 17, 7, 98, 
    2, 22, 6,  4, 0, 98, 5, 32, 1, 33, 7, 84, 8, 85, 4, 15, 3, 92, 
    2, 57, 3, 71, 7, 85, 0, 94, 8, 17, 1, 63, 5, 36, 4, 26, 6, 99, 
    5, 23, 6, 38, 8, 71, 0, 48, 4, 83, 1, 21, 2, 68, 3, 83, 7, 81, 
    5, 27, 3, 62, 7, 92, 4, 46, 1,  7, 2, 69, 6, 84, 8, 56, 0, 23, 
    2, 30, 6, 80, 1,  2, 0,  1, 4, 65, 7,  1, 3, 70, 5, 27, 8, 69, 
    3, 37, 8, 76, 4, 45, 2, 41, 1, 68, 7, 51, 5, 50, 6, 11, 0, 41, 
    7, 59, 6, 75, 2, 32, 8, 20, 4, 87, 1, 25, 5, 79, 0, 87, 3, 17, 
    5, 83, 0,  5, 6, 84, 4, 65, 3, 67, 8, 56, 2, 49, 7, 92, 1, 78
  };
  const int q1375[] = {
    9, 9, // Number of jobs and machines
    7, 11, 3, 28, 2, 83, 1, 48, 5, 37, 6, 41, 0, 50, 8, 26, 4, 28, 
    5, 74, 0, 50, 8, 30, 4, 46, 7, 79, 2, 17, 3, 98, 6, 84, 1, 30, 
    7, 18, 6, 37, 2, 94, 3, 89, 8, 43, 5, 44, 4, 21, 1, 21, 0, 49, 
    0, 39, 8, 86, 7,  8, 6, 91, 1, 74, 2, 39, 4, 72, 3, 71, 5, 20, 
    3,  1, 8, 87, 2, 25, 1, 97, 0,  2, 4, 75, 5, 73, 7, 60, 6, 35, 
    2, 91, 1, 32, 7, 19, 3, 71, 8, 54, 4, 34, 5, 84, 6, 62, 0,  3, 
    4, 37, 6, 33, 5, 75, 0, 86, 3, 25, 2, 27, 1, 89, 8, 41, 7, 10, 
    1, 68, 5, 68, 0, 75, 6, 30, 2, 62, 3, 45, 8, 53, 4, 76, 7, 51, 
    2, 38, 4, 45, 1, 97, 6, 93, 8, 54, 5, 89, 0, 20, 3, 89, 7, 79
  };
  const int q1376[] = {
    9, 9, // Number of jobs and machines
    0, 76, 2, 55, 5, 21, 3,  7, 6, 35, 7, 12, 4, 67, 1, 25, 8, 59, 
    3,  9, 5, 84, 4, 72, 2, 93, 1, 80, 8, 92, 0, 15, 6, 35, 7,  1, 
    8, 96, 5, 12, 3, 39, 6, 26, 2,  6, 0, 31, 1, 97, 7, 89, 4, 15, 
    4, 66, 8, 53, 3, 16, 6, 40, 0, 81, 5, 68, 7, 12, 2, 15, 1, 28, 
    3, 27, 0, 96, 7,  2, 1, 15, 5, 85, 4, 10, 6, 74, 2, 88, 8, 24, 
    4, 84, 1, 24, 3, 21, 5, 40, 7,  4, 6, 32, 0, 67, 2, 13, 8, 73, 
    8, 49, 1, 23, 6, 19, 4, 13, 2, 80, 7, 15, 3, 33, 5, 62, 0,  3, 
    0, 75, 1, 60, 8, 14, 3, 58, 7, 14, 6, 40, 2, 75, 5, 27, 4, 76, 
    8, 58, 0, 14, 2, 42, 1, 52, 6, 58, 5, 19, 7, 47, 3, 56, 4, 70
  };
  const int q1377[] = {
    9, 9, // Number of jobs and machines
    0, 63, 4, 97, 5, 87, 6,  1, 2, 37, 7, 43, 1, 97, 8, 71, 3, 34, 
    0, 62, 7, 86, 1, 47, 5, 39, 4, 51, 6, 24, 3, 12, 2, 46, 8, 50, 
    0, 76, 6, 65, 2, 48, 4, 96, 5, 32, 3, 13, 8,  7, 7, 53, 1, 75, 
    6, 52, 8,  1, 5, 64, 4,  7, 2,  5, 3, 65, 0, 19, 1, 86, 7, 46, 
    3, 59, 7, 36, 6, 21, 4, 32, 0, 60, 8, 87, 1, 79, 2, 77, 5, 12, 
    4, 72, 6, 15, 2, 32, 7,  4, 1, 81, 8, 62, 0,  4, 5, 82, 3, 41, 
    4, 87, 6, 65, 2, 21, 7, 30, 3, 19, 5, 72, 8, 98, 0, 57, 1, 28, 
    2, 63, 1, 47, 3, 56, 6, 82, 8, 53, 7, 90, 5, 77, 0, 62, 4, 25, 
    7, 29, 0, 64, 5, 72, 8, 48, 4, 59, 6, 41, 3,  7, 2, 17, 1, 12
  };
  const int q1378[] = {
    9, 9, // Number of jobs and machines
    6, 29, 2, 25, 0, 22, 3,  1, 7, 75, 4, 10, 1, 58, 8, 52, 5, 13, 
    3, 21, 8, 47, 2, 86, 0, 39, 5, 42, 7, 29, 1, 32, 4, 61, 6, 20, 
    6, 70, 8, 71, 1, 53, 0, 93, 4, 96, 7, 15, 5, 25, 3, 34, 2, 54, 
    7,  5, 6, 23, 8, 85, 2, 67, 1, 14, 0, 39, 4, 27, 3, 91, 5,  4, 
    7, 46, 6, 79, 4, 94, 5, 71, 2, 49, 3, 22, 1, 73, 0, 74, 8, 51, 
    6, 13, 7, 88, 1, 73, 3,  9, 5, 18, 4, 85, 8, 23, 2, 84, 0, 73, 
    7,  6, 4, 50, 5, 45, 6, 18, 8, 19, 0, 29, 3, 86, 1, 27, 2, 25, 
    5, 58, 8, 13, 6, 32, 1, 60, 4, 30, 7, 14, 3, 94, 2, 85, 0, 22, 
    1, 75, 5, 88, 4, 53, 0, 76, 6, 41, 8, 11, 2, 86, 7,  7, 3, 41
  };
  const int q1379[] = {
    9, 9, // Number of jobs and machines
    6, 45, 7, 79, 4, 84, 2, 82, 8, 19, 5,  8, 3, 40, 0, 68, 1, 92, 
    7, 60, 0, 46, 5,  5, 2, 57, 8, 83, 3, 91, 1, 28, 6, 73, 4, 35, 
    1, 34, 4,  5, 0, 78, 8, 30, 5, 88, 2, 17, 7, 72, 3, 37, 6, 41, 
    5, 29, 6, 26, 3, 32, 7, 75, 2, 64, 4, 25, 8, 38, 1, 38, 0, 71, 
    1, 86, 8, 13, 5, 69, 3, 46, 2, 62, 6, 96, 7, 69, 0, 21, 4,  5, 
    5, 98, 8, 35, 1,  5, 2, 49, 3, 70, 7,  5, 4, 15, 0,  4, 6, 45, 
    1, 37, 8, 78, 7, 44, 0, 41, 3, 80, 4, 86, 5,  5, 2, 65, 6, 43, 
    4, 82, 2, 66, 6, 93, 0, 55, 3, 46, 1, 62, 5, 76, 7, 21, 8, 62, 
    6, 44, 0, 63, 7, 85, 5, 72, 8, 88, 2, 33, 1, 92, 4, 72, 3, 89
  };
  const int q1380[] = {
    9, 9, // Number of jobs and machines
    2, 37, 8, 57, 7, 83, 4, 22, 0, 41, 5, 25, 3,  1, 1, 93, 6,  1, 
    1, 16, 4, 24, 3, 97, 6, 69, 5, 84, 0, 93, 2, 70, 8, 19, 7, 92, 
    4, 19, 5, 55, 8, 31, 3, 66, 2, 99, 1, 72, 6, 68, 0, 93, 7, 79, 
    5, 58, 3, 76, 2, 95, 0, 40, 8, 93, 7, 81, 1, 57, 6, 46, 4, 40, 
    7, 88, 5, 19, 8, 57, 1, 85, 6, 12, 0, 99, 2, 87, 4, 87, 3, 22, 
    1, 82, 2, 81, 3, 82, 5, 16, 6, 42, 8, 87, 0, 14, 7, 88, 4, 90, 
    6, 86, 8, 99, 0,  4, 7, 74, 2, 25, 3,  9, 4,  6, 1, 98, 5, 27, 
    5, 71, 3, 66, 0, 47, 2, 48, 4, 28, 8, 92, 1, 46, 6, 13, 7, 88, 
    3, 34, 5, 25, 2, 65, 6, 91, 0, 56, 4, 95, 8, 61, 1, 18, 7, 34
  };
  const int q1381[] = {
    9, 9, // Number of jobs and machines
    2, 88, 3, 40, 8, 27, 5,  1, 4, 32, 7, 64, 0, 79, 1, 12, 6, 62, 
    7, 31, 3, 80, 2, 76, 1, 18, 6, 23, 5, 80, 4, 88, 0, 36, 8, 63, 
    4, 41, 2, 76, 6, 58, 5, 83, 8, 27, 7, 55, 1, 96, 0, 25, 3, 68, 
    0, 19, 2, 22, 1, 79, 8, 88, 3, 44, 6,  4, 7, 63, 5, 23, 4, 85, 
    8, 84, 3, 87, 5, 34, 0, 72, 2, 26, 4, 91, 7, 95, 6, 76, 1, 41, 
    7, 76, 3, 14, 0, 87, 4, 40, 5, 17, 6,  5, 2, 46, 8, 25, 1, 80, 
    0, 86, 1, 65, 4, 87, 2, 54, 3, 64, 7, 41, 6, 49, 8,  5, 5, 94, 
    3, 76, 7, 97, 2, 26, 5,  5, 6,  1, 4, 45, 1, 70, 8, 56, 0, 94, 
    1, 57, 5, 77, 0, 38, 6, 11, 2,  5, 7, 93, 3, 61, 4, 95, 8, 52
  };
  const int q1382[] = {
    9, 9, // Number of jobs and machines
    0, 66, 4, 52, 6, 16, 3, 52, 1, 63, 2,  6, 7, 48, 5, 85, 8, 94, 
    0, 24, 7, 11, 6, 40, 8, 16, 4, 25, 1, 13, 3, 20, 2, 60, 5, 56, 
    0, 65, 2, 98, 7, 15, 4, 42, 6, 18, 3, 52, 8, 62, 5, 65, 1, 19, 
    2, 43, 8, 14, 4, 34, 3, 99, 1, 41, 0, 24, 5, 89, 7, 48, 6, 99, 
    1, 58, 7, 36, 6, 77, 2, 44, 3, 41, 5, 97, 4, 83, 8,  4, 0, 54, 
    4, 52, 6, 26, 5, 60, 7, 62, 3, 58, 1, 60, 0, 50, 8, 25, 2,  5, 
    3, 72, 5, 45, 1, 42, 7, 18, 0,  4, 6, 65, 4, 19, 2, 11, 8, 38, 
    3, 31, 4, 24, 0, 56, 8, 15, 7, 74, 6, 38, 1, 26, 5, 53, 2, 32, 
    4, 12, 0, 12, 8, 13, 7, 68, 3, 59, 5, 16, 6, 92, 2, 82, 1, 29
  };
  const int q1383[] = {
    9, 9, // Number of jobs and machines
    2, 68, 7, 80, 6, 82, 3, 19, 8, 66, 5, 71, 4,  2, 0, 86, 1, 17, 
    4, 20, 0, 88, 7, 64, 8, 80, 2, 32, 5, 88, 1, 53, 6, 72, 3, 90, 
    2, 87, 3, 78, 1, 87, 7, 92, 4, 10, 5,  6, 6, 69, 8, 79, 0, 33, 
    1, 55, 5, 90, 4, 47, 7, 13, 0, 44, 6, 92, 3,  7, 8, 43, 2,  4, 
    3, 85, 1, 76, 0, 41, 6, 29, 4, 34, 7, 20, 2, 43, 8, 79, 5, 60, 
    5, 85, 1, 23, 2,  5, 4, 60, 8, 98, 6, 35, 0, 19, 3, 15, 7, 77, 
    8, 41, 6, 10, 0, 91, 7, 83, 5, 23, 3, 79, 2, 53, 4, 95, 1, 48, 
    7,  2, 5, 61, 8, 13, 2, 80, 6, 95, 0, 95, 4, 93, 1, 84, 3, 40, 
    6, 41, 4, 61, 2, 28, 5, 42, 1, 87, 0, 19, 8, 34, 7, 47, 3,  8
  };
  const int q1384[] = {
    9, 9, // Number of jobs and machines
    0, 90, 3, 27, 5, 69, 8, 99, 6, 59, 4, 15, 2, 17, 1, 15, 7, 27, 
    7, 68, 0, 12, 6,  2, 1, 82, 5, 92, 2, 41, 3, 23, 4, 35, 8, 51, 
    2,  3, 3,  3, 6, 86, 4, 62, 1, 69, 0, 41, 7, 38, 5, 70, 8, 79, 
    7, 96, 0, 58, 6, 46, 5, 96, 4, 75, 8, 28, 3, 26, 1, 56, 2, 40, 
    0, 30, 5, 27, 6, 56, 3, 46, 2, 68, 1, 83, 4, 80, 7, 88, 8, 74, 
    1, 50, 0, 89, 3, 50, 8,  7, 6, 96, 4, 50, 2, 14, 7,  6, 5, 46, 
    1, 85, 2, 66, 0, 32, 3, 77, 5, 95, 7,  7, 4, 84, 6, 54, 8, 47, 
    5, 14, 6, 47, 8, 55, 7, 86, 3,  3, 2, 90, 0, 85, 1, 75, 4,  5, 
    7, 16, 4, 34, 2, 45, 0, 70, 3, 89, 1, 96, 6, 58, 5, 33, 8, 36
  };
  const int q1385[] = {
    9, 9, // Number of jobs and machines
    6, 85, 2, 78, 7, 21, 5, 92, 3, 27, 0, 64, 8, 73, 1, 12, 4, 75, 
    3, 21, 7, 15, 1,  5, 4, 98, 8, 43, 2, 31, 5, 35, 6, 69, 0, 53, 
    2, 42, 3,  9, 5,  3, 6,  5, 7, 73, 1, 28, 8, 71, 4, 66, 0,  5, 
    4, 69, 7,  9, 0, 70, 6, 13, 8, 63, 2, 13, 5, 27, 3, 63, 1, 15, 
    2, 99, 7, 65, 1, 78, 4, 70, 3, 52, 5, 49, 8, 38, 6, 55, 0, 13, 
    0, 46, 6, 63, 7, 56, 3,  5, 5, 38, 4, 86, 8, 27, 1, 23, 2, 47, 
    4, 27, 3, 74, 2, 68, 6, 16, 8, 88, 1, 96, 7, 28, 5, 76, 0, 45, 
    0,  6, 1, 62, 2, 30, 7, 11, 5, 36, 6, 69, 3, 73, 4, 86, 8, 47, 
    8, 13, 0, 87, 5, 24, 4, 97, 7, 55, 3, 31, 1, 50, 2, 61, 6, 26
  };
  const int q1386[] = {
    9, 9, // Number of jobs and machines
    0, 62, 1, 98, 2, 86, 4, 68, 3, 43, 8, 26, 5, 36, 7, 96, 6, 50, 
    4, 85, 6, 11, 3, 41, 7, 55, 1, 96, 2, 18, 8, 18, 0, 87, 5,  6, 
    2, 27, 4, 64, 1, 68, 8, 64, 6, 73, 7, 18, 5, 50, 3, 79, 0, 14, 
    6, 99, 1, 21, 7, 14, 5, 13, 4, 29, 8, 42, 3, 18, 0, 44, 2, 67, 
    7, 41, 1, 47, 6, 79, 2, 68, 0, 47, 3, 56, 5, 96, 8, 41, 4, 78, 
    2, 16, 5, 76, 0, 10, 8, 61, 1, 95, 3, 49, 4, 25, 6, 94, 7, 87, 
    3, 41, 2,  1, 5,  8, 0, 42, 4, 41, 6, 54, 1, 13, 8, 43, 7, 50, 
    6, 25, 7, 12, 1, 11, 5, 26, 3, 21, 4, 35, 2, 12, 8, 56, 0, 52, 
    0, 67, 5, 90, 7, 73, 6, 29, 4, 51, 3, 68, 8, 28, 2, 57, 1,  1
  };
  const int q1387[] = {
    9, 9, // Number of jobs and machines
    4,  6, 7, 96, 1, 89, 3, 43, 8, 88, 2, 50, 6, 11, 5, 42, 0, 10, 
    3, 37, 1, 95, 0, 54, 4, 64, 8, 69, 6, 45, 2, 79, 5, 27, 7,  3, 
    6, 76, 8, 74, 2, 97, 3, 41, 0, 56, 1, 49, 4,  5, 5, 93, 7, 90, 
    5, 92, 7, 99, 0, 54, 6, 23, 2, 58, 1, 20, 4, 86, 3, 62, 8, 67, 
    3, 62, 4, 95, 2, 19, 5, 57, 1, 11, 7, 73, 0, 18, 8, 86, 6, 28, 
    2, 10, 1,  1, 0, 26, 5, 68, 3, 91, 6, 16, 4, 56, 7, 30, 8, 90, 
    2, 31, 3, 46, 7, 69, 6, 24, 5, 61, 0, 12, 1, 90, 4, 92, 8, 99, 
    1, 75, 4, 15, 2, 86, 8, 68, 6, 75, 7, 77, 3, 67, 0, 54, 5, 38, 
    6, 43, 7, 55, 1, 81, 2, 27, 0, 84, 5, 31, 3, 24, 4, 17, 8,  4
  };
  const int q1388[] = {
    9, 9, // Number of jobs and machines
    5,  5, 2, 47, 6, 24, 4, 80, 1, 24, 8, 98, 3, 63, 7, 24, 0, 38, 
    2,  2, 8, 78, 5, 39, 1, 21, 7, 28, 3, 90, 4, 25, 0, 67, 6, 14, 
    4, 13, 8, 42, 6, 20, 2, 65, 5, 58, 7, 56, 3, 51, 0, 51, 1, 18, 
    7, 69, 2, 74, 5, 92, 0, 40, 1, 84, 6, 93, 3, 22, 4, 15, 8,  9, 
    1, 49, 8, 31, 3, 90, 0, 55, 7, 44, 6, 31, 4, 91, 2, 95, 5, 73, 
    7, 37, 8, 84, 4, 94, 3,  5, 2,  5, 0, 70, 5, 73, 6, 81, 1,  8, 
    4, 56, 1, 65, 7, 25, 3, 94, 5, 45, 2, 49, 0, 18, 6, 24, 8, 52, 
    8, 25, 0, 26, 3, 10, 5, 24, 1, 55, 6, 25, 2, 27, 4, 80, 7, 60, 
    6, 64, 0, 97, 8, 73, 7,  7, 4, 35, 1,  5, 3, 54, 5, 83, 2, 62
  };
  const int q1389[] = {
    9, 9, // Number of jobs and machines
    7, 39, 1, 52, 4, 16, 2, 14, 6, 75, 8, 66, 0, 13, 3, 59, 5, 44, 
    6, 63, 8, 46, 5, 28, 4, 28, 7, 81, 0, 32, 2, 87, 1, 22, 3, 90, 
    8, 18, 5, 16, 2, 69, 6, 56, 1, 13, 4, 88, 0, 80, 3, 89, 7, 69, 
    1, 85, 3, 79, 6, 99, 0, 47, 2, 81, 4, 77, 5, 44, 7, 41, 8, 58, 
    6, 49, 3, 33, 0, 62, 7, 39, 5, 11, 1, 21, 8, 41, 2, 75, 4, 55, 
    1, 57, 2, 46, 4, 83, 8, 43, 5, 82, 3, 90, 6, 23, 7, 44, 0, 85, 
    3, 99, 0, 40, 2, 44, 7, 13, 5, 78, 6, 89, 1, 72, 8, 57, 4, 95, 
    2, 37, 7, 24, 0, 86, 8,  7, 3, 20, 1, 85, 4, 54, 5,  1, 6, 58, 
    1, 49, 3, 19, 6, 65, 7, 45, 4, 19, 8, 27, 5,  3, 0, 32, 2, 30
  };
  const int q1390[] = {
    9, 9, // Number of jobs and machines
    1, 52, 6, 57, 2, 10, 5, 37, 8, 79, 3, 70, 7, 40, 4, 41, 0, 65, 
    6, 83, 4, 25, 7,  4, 8, 63, 1,  4, 0, 49, 3, 25, 5, 13, 2, 86, 
    3,  7, 1, 59, 0, 34, 5, 79, 4, 22, 2,  8, 6, 30, 8, 82, 7, 47, 
    2, 85, 3, 49, 4, 53, 7, 11, 0, 76, 8, 19, 1, 44, 5, 75, 6, 25, 
    0, 50, 1, 96, 5, 81, 6, 90, 8, 36, 4, 74, 2, 95, 7, 56, 3, 55, 
    1, 27, 5, 46, 8, 18, 4, 90, 6, 53, 0, 85, 3, 39, 2,  7, 7, 75, 
    6, 42, 8, 86, 4, 38, 3, 35, 7, 84, 5, 37, 2, 96, 1, 33, 0, 36, 
    0, 75, 1, 53, 4, 52, 6, 50, 7, 95, 8,  5, 5, 50, 3,  9, 2, 84, 
    6, 23, 1, 32, 4,  6, 5, 30, 2, 93, 8, 33, 3, 84, 7, 32, 0, 38
  };
  const int q1391[] = {
    9, 9, // Number of jobs and machines
    5, 76, 7, 27, 3, 24, 0,  2, 2,  9, 6, 25, 1, 68, 8,  6, 4, 94, 
    2,  2, 3, 75, 6, 63, 8, 13, 5, 99, 4, 69, 7, 89, 1,  2, 0, 73, 
    8, 78, 7, 65, 1, 10, 4, 85, 6, 14, 0, 94, 2, 47, 3, 75, 5, 15, 
    7, 37, 4, 76, 1, 63, 8,  3, 2, 26, 6, 39, 3, 36, 0, 66, 5, 79, 
    7, 81, 0, 42, 5, 95, 1, 52, 8, 65, 3, 58, 2,  2, 6,  7, 4, 77, 
    2, 16, 7, 95, 8, 64, 4, 34, 3, 60, 5, 55, 0,  7, 6, 82, 1, 56, 
    0, 32, 3, 70, 8, 67, 6, 73, 4, 60, 1, 79, 5, 20, 2, 97, 7, 96, 
    0, 65, 7, 82, 5, 53, 6, 12, 8, 11, 3,  4, 1, 22, 4, 10, 2, 63, 
    4, 71, 7,  5, 6, 77, 0, 12, 5, 91, 8, 10, 2, 33, 3, 45, 1, 44
  };
  const int q1392[] = {
    9, 9, // Number of jobs and machines
    5, 32, 6, 44, 3, 85, 4, 86, 7, 54, 8, 55, 0, 96, 2, 93, 1, 68, 
    1, 43, 4, 49, 7, 35, 5, 48, 6,  1, 2, 77, 0,  4, 8, 18, 3, 77, 
    4, 53, 5, 69, 6, 12, 2, 44, 7, 72, 3,  3, 1, 78, 8, 58, 0, 69, 
    3, 57, 1, 43, 8, 98, 7, 15, 6, 15, 5, 83, 2, 76, 0, 45, 4, 10, 
    8, 67, 6, 85, 1, 82, 0,  9, 3, 33, 2, 78, 4, 74, 7, 49, 5, 98, 
    6, 13, 7, 63, 5, 45, 1, 43, 2,  7, 3, 39, 8, 20, 4, 16, 0, 65, 
    1, 93, 0, 93, 7, 57, 3, 91, 8, 21, 4, 35, 6, 41, 5, 56, 2, 19, 
    7,  5, 4, 63, 8, 14, 6, 80, 2, 23, 3, 13, 0, 10, 5, 67, 1, 77, 
    5, 96, 3, 26, 4, 25, 7, 21, 2, 65, 8,  4, 6, 26, 1, 49, 0, 22
  };
  const int q1393[] = {
    9, 9, // Number of jobs and machines
    4, 93, 0, 30, 1, 39, 2, 22, 8,  3, 5, 49, 3, 19, 6, 39, 7, 92, 
    6,  3, 8, 22, 3, 13, 0, 87, 2, 77, 7, 55, 1, 82, 4, 68, 5, 87, 
    3, 73, 4,  3, 1, 46, 8, 69, 7, 82, 6, 70, 0, 62, 2, 96, 5, 86, 
    5, 73, 4, 66, 3, 56, 8, 94, 0, 79, 7, 35, 6, 52, 1, 44, 2, 63, 
    7, 46, 4, 98, 2, 42, 3,  4, 6, 90, 8, 79, 1, 12, 5, 28, 0, 71, 
    2, 95, 4, 33, 6, 47, 8, 74, 5,  8, 0, 28, 3, 82, 7, 67, 1, 28, 
    8, 80, 3, 43, 5,  5, 6, 89, 0, 38, 4, 71, 1, 35, 7, 41, 2, 34, 
    3, 42, 2, 47, 0, 93, 1, 60, 5, 24, 7, 38, 8, 14, 4, 91, 6, 19, 
    4,  1, 0, 34, 3, 58, 1, 59, 2, 37, 5, 20, 7, 75, 6, 24, 8, 57
  };
  const int q1394[] = {
    9, 9, // Number of jobs and machines
    5, 86, 8, 27, 2, 23, 3, 43, 1, 65, 6, 76, 7, 40, 4, 44, 0, 41, 
    0, 92, 2, 84, 3, 56, 7, 74, 6,  9, 8, 76, 5, 38, 1, 35, 4,  9, 
    4, 94, 8, 93, 5, 15, 6, 53, 7, 98, 0, 98, 2, 24, 3, 96, 1, 80, 
    1, 15, 6, 46, 3,  9, 4, 27, 5,  8, 8, 62, 7, 45, 0, 12, 2, 36, 
    0, 19, 6,  2, 1, 34, 3, 76, 4, 47, 2,  3, 5, 22, 8, 72, 7,  8, 
    3, 24, 0, 18, 5, 35, 2, 75, 7, 32, 4, 21, 1, 75, 6, 20, 8, 85, 
    2, 97, 3, 69, 0, 64, 8, 68, 5, 35, 4, 47, 6, 13, 7, 84, 1, 60, 
    2,  8, 4, 47, 7, 70, 3,  8, 5, 96, 8, 12, 1, 60, 0, 76, 6, 39, 
    7, 32, 2, 75, 4, 68, 0, 37, 3, 64, 6, 54, 8, 90, 1, 80, 5, 76
  };
  const int q1395[] = {
    9, 9, // Number of jobs and machines
    8, 93, 1, 12, 0, 18, 7, 78, 3, 69, 2, 75, 4, 25, 5, 69, 6, 95, 
    7, 37, 8, 85, 0, 81, 5, 44, 6,  9, 2, 78, 3, 61, 1, 34, 4, 86, 
    4, 48, 0, 72, 6, 61, 7, 69, 8, 42, 5, 41, 1, 61, 2, 27, 3, 63, 
    3, 46, 1, 24, 5, 12, 2, 67, 0, 48, 7, 68, 8, 34, 6, 10, 4, 70, 
    1, 19, 4, 87, 2, 72, 7, 77, 3, 13, 6,  5, 0,  5, 8, 87, 5, 47, 
    5, 72, 8,  6, 2, 64, 7,  6, 4, 83, 3, 79, 1, 34, 0, 66, 6, 40, 
    7, 49, 3, 15, 2, 93, 8, 79, 6, 60, 0, 46, 4, 86, 1, 43, 5, 92, 
    8, 96, 0, 94, 5, 35, 1, 83, 2,  2, 3, 49, 4, 67, 6, 19, 7, 82, 
    4, 78, 3, 35, 8,  6, 5, 76, 7, 98, 2, 82, 1, 73, 6,  7, 0, 47
  };
  const int q1396[] = {
    9, 9, // Number of jobs and machines
    2, 69, 3, 90, 7, 91, 5, 39, 8, 73, 6, 95, 0, 67, 4, 95, 1, 46, 
    2,  2, 4, 31, 8, 73, 3, 56, 1, 56, 5, 19, 0, 70, 7,  9, 6, 66, 
    7, 53, 5, 68, 1, 25, 3, 44, 4,  7, 8, 49, 6, 14, 0, 92, 2, 61, 
    5, 65, 0, 68, 7,  2, 2, 41, 8, 94, 3, 85, 1, 74, 4, 99, 6, 42, 
    2, 78, 3,  7, 5, 15, 6, 89, 7, 37, 1, 12, 0, 57, 4, 94, 8, 26, 
    3, 71, 2, 63, 1, 90, 4, 44, 5, 16, 7, 78, 8, 94, 0, 12, 6, 87, 
    1, 63, 2, 81, 6, 15, 0, 74, 3, 87, 7, 12, 4, 74, 5, 46, 8, 41, 
    1, 89, 6, 43, 5, 10, 7, 63, 2, 92, 4, 80, 3, 12, 8, 49, 0, 59, 
    7, 54, 4, 65, 5, 63, 8, 13, 2, 49, 1, 85, 3, 69, 6, 12, 0, 47
  };
  const int q1397[] = {
    9, 9, // Number of jobs and machines
    4, 55, 2, 78, 8, 31, 3, 22, 7, 39, 5, 57, 1, 41, 0, 41, 6, 65, 
    4, 68, 0, 56, 3, 48, 6, 60, 2, 85, 8, 13, 7, 71, 5, 48, 1, 81, 
    4, 39, 2, 49, 0, 56, 6, 65, 7, 91, 5, 21, 8, 68, 3, 40, 1, 98, 
    7, 32, 1, 53, 0, 51, 4, 98, 2, 70, 3, 64, 8, 67, 5, 19, 6, 34, 
    8, 38, 7, 29, 6, 43, 3,  7, 0, 52, 5, 36, 1, 65, 2, 91, 4, 31, 
    7, 14, 6, 94, 4, 36, 3, 22, 8, 30, 5, 56, 2, 31, 1, 62, 0, 37, 
    2, 62, 5, 95, 3,  1, 4, 57, 7, 75, 0, 43, 6, 15, 8, 88, 1,  8, 
    6, 53, 2, 48, 8, 80, 7, 68, 3, 51, 5, 83, 4, 12, 0, 85, 1, 42, 
    3, 17, 4, 29, 0, 34, 5, 53, 7, 84, 8,  6, 2, 29, 6, 37, 1,  6
  };
  const int q1398[] = {
    9, 9, // Number of jobs and machines
    7, 23, 2,  5, 5, 51, 4, 61, 8, 35, 3, 88, 6, 30, 0, 18, 1, 85, 
    8, 24, 0, 57, 3, 89, 6, 19, 1, 44, 2,  4, 7, 82, 5, 71, 4, 72, 
    0, 19, 7, 31, 8, 92, 5, 90, 2, 71, 4, 91, 6,  2, 3,  4, 1,  4, 
    7,  3, 8, 34, 0, 16, 2, 69, 1, 55, 4, 36, 6, 56, 3, 97, 5, 65, 
    4, 14, 6, 74, 0, 21, 1, 41, 8, 41, 5, 18, 3, 48, 2, 67, 7, 22, 
    6, 42, 8, 49, 4, 70, 3, 14, 1, 32, 7, 33, 2, 10, 5, 18, 0, 85, 
    8, 78, 6, 25, 0, 96, 1, 82, 7, 79, 2, 25, 4, 45, 5,  1, 3, 12, 
    4, 55, 6, 41, 7, 25, 2, 11, 5,  8, 8, 93, 3, 59, 0, 42, 1, 37, 
    1, 38, 4, 98, 3, 59, 2, 87, 0, 10, 8, 65, 6, 42, 5, 12, 7,  3
  };
  const int q1399[] = {
    9, 9, // Number of jobs and machines
    1, 58, 6, 82, 8, 28, 4, 53, 0, 39, 5, 82, 2, 93, 7, 68, 3, 19, 
    2, 73, 0, 58, 3, 66, 4, 52, 8, 94, 7, 73, 5, 33, 1,  7, 6,  1, 
    2, 83, 6, 50, 4, 92, 8, 45, 5, 78, 1, 92, 0, 71, 3, 99, 7, 72, 
    0, 92, 3, 63, 4, 75, 1, 73, 2, 95, 7,  8, 5, 84, 6, 10, 8, 81, 
    7, 95, 1,  7, 3, 70, 5, 36, 8, 80, 6, 91, 2, 76, 4, 26, 0, 94, 
    7, 68, 0, 98, 5, 99, 3, 63, 8, 62, 4,  5, 1, 11, 6, 89, 2, 81, 
    5, 76, 6, 31, 0, 75, 4, 77, 1, 83, 3, 44, 8, 52, 7, 23, 2, 90, 
    5, 80, 0, 19, 7, 92, 8, 35, 3, 60, 6, 90, 4,  5, 2, 17, 1, 76, 
    1, 41, 5, 18, 0, 74, 3, 57, 8, 63, 2, 99, 4, 24, 7, 52, 6, 90
  };
  const int q1400[] = {
    9, 9, // Number of jobs and machines
    2, 29, 7, 16, 4, 22, 3, 42, 8, 99, 1, 70, 0, 39, 5, 84, 6, 75, 
    2, 32, 6,  5, 7, 39, 5, 14, 1, 48, 0, 19, 3, 51, 4, 57, 8, 14, 
    1, 56, 7, 55, 4,  4, 6, 77, 2, 62, 5,  1, 3,  7, 8, 80, 0, 73, 
    4,  7, 5, 40, 3, 77, 6, 66, 2, 52, 1, 70, 7, 89, 0, 82, 8, 41, 
    1, 88, 8,  8, 6,  6, 7, 99, 2, 86, 0, 65, 5, 75, 4, 87, 3, 46, 
    8, 28, 1, 12, 4,  4, 7, 31, 6, 11, 0, 50, 3, 79, 5, 95, 2,  3, 
    4, 34, 0, 78, 8, 45, 1, 83, 7, 14, 3, 39, 2, 38, 6, 80, 5, 93, 
    2, 34, 4, 34, 3,  7, 7, 77, 1, 34, 5, 84, 8, 84, 0, 44, 6, 15, 
    6, 93, 1, 10, 7, 79, 5, 88, 2, 81, 3, 35, 0, 24, 8, 22, 4, 85
  };
  const int q1401[] = {
    9, 9, // Number of jobs and machines
    5, 32, 1, 78, 0, 53, 8, 62, 7, 30, 3, 24, 4, 85, 2, 12, 6, 27, 
    3, 77, 1, 89, 0, 20, 6,  2, 7, 67, 5, 91, 4, 42, 2, 46, 8, 12, 
    8, 82, 0, 17, 6, 87, 1, 49, 2, 13, 7, 49, 5, 69, 3, 85, 4, 99, 
    1, 10, 7, 29, 6, 16, 8, 13, 4, 26, 0, 66, 5, 70, 3, 25, 2, 26, 
    5, 50, 3, 35, 1, 38, 8, 32, 6,  4, 2, 19, 0, 39, 4, 80, 7, 69, 
    0, 99, 5,  9, 3, 77, 8, 16, 7, 14, 6, 81, 4, 10, 2, 24, 1, 92, 
    4, 14, 2, 99, 8, 96, 1, 15, 3, 90, 5, 65, 7, 94, 6, 44, 0, 19, 
    5, 87, 7, 24, 8, 85, 6, 48, 2, 60, 0, 25, 4, 57, 3, 65, 1, 83, 
    2, 83, 6, 26, 0,  2, 8, 10, 4, 65, 7, 96, 3, 28, 5, 33, 1, 77
  };
  const int q1402[] = {
    9, 9, // Number of jobs and machines
    5, 90, 2, 24, 8, 55, 6, 67, 0, 43, 3, 94, 4, 60, 7, 69, 1, 34, 
    0, 26, 8, 32, 7, 34, 5, 15, 4, 43, 3, 28, 1, 91, 2, 37, 6, 26, 
    4, 26, 6, 61, 1, 90, 0, 55, 5, 36, 7, 93, 3, 33, 8, 36, 2, 70, 
    4, 15, 5, 12, 8,  6, 0, 60, 6, 20, 3, 34, 2, 53, 7, 85, 1, 99, 
    3, 63, 7, 28, 6, 64, 1,  9, 4, 78, 2, 51, 5, 92, 8, 76, 0, 65, 
    6,  1, 8, 94, 2, 97, 1, 31, 0, 53, 4,  2, 5, 68, 3, 44, 7, 67, 
    2, 28, 5, 29, 4, 88, 8, 34, 6, 90, 1, 84, 0, 79, 3,  7, 7, 47, 
    1, 32, 6, 98, 8, 59, 7,  9, 3, 80, 0, 24, 2, 61, 4, 88, 5, 85, 
    1, 69, 7, 94, 6, 61, 8, 33, 2, 58, 4, 19, 3, 69, 5, 67, 0, 29
  };
  const int q1403[] = {
    9, 9, // Number of jobs and machines
    6,  2, 3, 78, 7, 14, 8, 63, 5, 75, 1,  3, 0, 79, 4, 78, 2, 43, 
    5, 49, 3, 40, 2, 15, 0, 57, 1, 84, 8, 35, 7, 66, 4, 23, 6, 62, 
    0, 62, 4, 13, 1,  8, 8, 76, 3, 30, 7, 41, 2, 77, 5, 46, 6, 46, 
    3, 57, 8, 75, 2, 65, 7, 53, 4, 54, 1, 33, 5, 79, 6, 76, 0, 39, 
    8, 79, 6, 50, 5, 51, 1,  7, 0, 13, 3, 70, 7, 18, 4, 25, 2, 11, 
    6, 62, 2, 74, 1, 83, 7, 40, 4,  7, 3, 79, 8, 51, 0, 37, 5, 61, 
    2, 14, 8, 12, 0, 70, 1, 33, 6, 83, 5, 68, 7, 42, 3, 31, 4, 65, 
    6, 63, 0, 45, 5, 91, 4, 53, 8, 98, 2, 26, 7, 83, 1,  8, 3, 12, 
    3, 69, 6,  4, 7, 62, 8, 39, 2, 29, 0, 67, 4, 56, 5, 56, 1, 15
  };
  const int q1404[] = {
    9, 9, // Number of jobs and machines
    5, 88, 8, 79, 1, 79, 3, 57, 0, 92, 6, 74, 7, 69, 4,  9, 2, 82, 
    5, 34, 6, 89, 8,  3, 3, 69, 7, 47, 2, 47, 0,  4, 1, 97, 4, 45, 
    4, 17, 8, 99, 6, 90, 2, 83, 5, 28, 0, 40, 1, 30, 7, 23, 3, 57, 
    2, 35, 1, 22, 7, 98, 5, 17, 3, 10, 0, 97, 4, 29, 6, 76, 8, 65, 
    0, 72, 4, 75, 1, 89, 7,  7, 2, 43, 5, 47, 8, 39, 6, 56, 3, 39, 
    5, 93, 8, 85, 7, 59, 6, 55, 2, 45, 4, 92, 0, 39, 1, 54, 3, 22, 
    2, 59, 0, 84, 8, 30, 6, 54, 7, 68, 1, 61, 4, 28, 5, 30, 3, 90, 
    6,  5, 2,  8, 5, 33, 1, 54, 3, 56, 7, 41, 4, 12, 8, 56, 0, 52, 
    6, 11, 7, 95, 3, 64, 1,  9, 5, 12, 2, 72, 8, 18, 0, 33, 4, 89
  };
  const int q1405[] = {
    9, 9, // Number of jobs and machines
    1, 96, 4, 28, 6, 69, 8, 32, 0,  5, 2, 60, 7, 83, 5, 98, 3, 58, 
    0, 46, 3, 29, 8, 83, 4, 42, 2, 75, 6, 83, 5, 69, 1, 19, 7, 64, 
    8, 43, 3, 29, 6, 63, 4, 16, 2, 70, 5, 88, 7, 55, 1, 93, 0, 24, 
    8, 10, 5, 71, 4, 17, 2, 28, 6, 54, 3, 26, 0, 19, 7, 20, 1, 55, 
    0, 99, 4, 19, 6, 60, 5, 49, 2,  4, 3, 38, 7, 72, 8, 47, 1, 29, 
    0, 82, 1, 25, 7, 42, 6,  2, 5,  1, 3, 54, 4, 77, 2, 20, 8, 56, 
    6, 25, 5, 11, 4, 25, 3,  2, 2, 32, 0, 63, 1, 61, 8, 90, 7, 13, 
    4, 22, 5, 72, 7, 72, 2,  1, 6, 96, 0, 30, 8, 59, 1, 58, 3, 64, 
    0, 11, 6, 61, 5, 14, 7, 16, 1, 47, 8, 33, 3, 39, 2, 89, 4, 47
  };
  const int q1406[] = {
    9, 9, // Number of jobs and machines
    5, 72, 8, 65, 3,  6, 6, 94, 4, 55, 1, 79, 0, 73, 2,  1, 7, 97, 
    0, 64, 5, 14, 7, 54, 1, 57, 4, 61, 8, 37, 3, 91, 6,  5, 2, 40, 
    0, 99, 8, 67, 1, 31, 3, 76, 6, 10, 5, 13, 7, 90, 2, 86, 4, 19, 
    5, 20, 2, 24, 1, 94, 7, 33, 0, 79, 4,  9, 3, 65, 8, 98, 6, 69, 
    2, 25, 0, 51, 5, 10, 4, 48, 7, 58, 8, 50, 6, 64, 1, 45, 3, 31, 
    7, 65, 2, 95, 8, 74, 3, 53, 0, 21, 4, 16, 1, 71, 6, 24, 5, 96, 
    7, 81, 5, 23, 3,  5, 4, 54, 6, 47, 1, 76, 0, 14, 8, 93, 2, 33, 
    1, 39, 0, 31, 4, 48, 8, 33, 5, 76, 7, 46, 3, 30, 2, 38, 6, 86, 
    3, 39, 5, 53, 8, 37, 6, 49, 0, 40, 4,  1, 7, 58, 2,  5, 1, 23
  };
  const int q1407[] = {
    9, 9, // Number of jobs and machines
    8, 88, 1, 77, 0, 44, 5,  7, 2, 63, 4, 80, 7, 38, 3, 80, 6, 89, 
    2,  9, 1, 38, 8, 84, 6, 12, 7, 10, 3, 43, 4, 71, 5,  5, 0, 67, 
    7, 60, 8, 20, 0, 61, 2, 70, 5, 67, 4,  4, 1, 16, 6, 80, 3, 52, 
    2, 46, 3, 47, 5, 98, 1, 53, 6, 15, 7, 59, 4, 38, 0, 59, 8, 28, 
    6, 35, 0, 77, 4, 57, 8, 85, 7,  1, 3, 84, 1, 81, 2, 61, 5, 82, 
    3, 17, 2, 94, 6, 89, 5, 50, 7,  4, 4, 77, 0, 23, 8, 37, 1, 63, 
    2, 59, 8, 35, 5, 47, 4, 67, 7, 47, 3, 58, 6, 66, 1, 42, 0, 56, 
    5, 97, 6, 22, 3, 12, 8, 30, 2, 18, 1, 58, 4, 95, 0, 71, 7, 16, 
    7,  6, 6, 44, 3, 91, 2, 65, 1, 88, 4, 53, 8, 76, 5, 50, 0, 30
  };
  const int q1408[] = {
    9, 9, // Number of jobs and machines
    2, 10, 5, 71, 4, 99, 8, 16, 6, 66, 0, 72, 1,  6, 3, 24, 7, 86, 
    3, 72, 0, 31, 5, 10, 2, 78, 1, 99, 8, 50, 6, 81, 4, 59, 7,  9, 
    0, 61, 3, 53, 8, 75, 6, 49, 4, 62, 2, 30, 1, 58, 5,  1, 7, 55, 
    4, 95, 7, 92, 2, 79, 3, 45, 5,  1, 1, 69, 8, 75, 6, 91, 0,  9, 
    5, 28, 7, 92, 3,  9, 2, 70, 0,  3, 1, 82, 4, 91, 8, 94, 6,  1, 
    5, 61, 8, 83, 1, 46, 3, 48, 6, 53, 4, 82, 7, 81, 2, 53, 0, 41, 
    7, 77, 4, 33, 2, 30, 5, 12, 1, 13, 8, 38, 3,  6, 6, 23, 0, 99, 
    6, 29, 1, 90, 2, 65, 5, 84, 4, 73, 7, 73, 3, 99, 0, 50, 8, 25, 
    5, 30, 0, 14, 4, 91, 6, 19, 3, 30, 1, 30, 8, 55, 2, 40, 7, 61
  };
  const int q1409[] = {
    9, 9, // Number of jobs and machines
    8, 38, 3, 46, 1, 29, 7, 20, 2, 16, 0, 42, 5, 74, 4, 62, 6, 75, 
    1, 46, 7, 15, 5, 17, 8, 48, 3, 13, 0, 14, 2, 20, 6, 46, 4, 23, 
    7, 12, 2, 72, 4, 92, 1, 10, 3, 16, 5,  9, 6, 95, 8, 98, 0, 54, 
    8,  2, 2, 79, 0, 66, 6, 35, 4, 78, 7, 38, 3, 52, 1, 79, 5, 45, 
    8, 37, 0,  4, 6, 32, 5, 13, 1, 19, 2, 11, 4, 44, 7, 87, 3, 11, 
    8, 75, 2, 44, 1, 66, 5, 24, 0, 93, 4, 48, 6, 92, 7, 61, 3, 36, 
    6, 28, 4, 44, 5, 92, 0, 61, 3, 69, 2, 39, 8, 50, 7, 49, 1, 14, 
    0, 88, 5, 48, 3, 57, 8, 24, 6, 65, 2, 47, 7, 47, 1, 30, 4, 39, 
    5, 34, 4, 98, 8, 90, 6, 70, 7, 43, 2, 67, 1, 55, 0, 98, 3, 76
  };
  const int q1410[] = {
    9, 9, // Number of jobs and machines
    5, 64, 4, 15, 7, 46, 1, 61, 3, 96, 6, 22, 0, 28, 8, 47, 2, 68, 
    7, 71, 2, 84, 3,  8, 4,  4, 5, 48, 8, 33, 1, 80, 6, 28, 0, 83, 
    2, 92, 5, 59, 6, 69, 7, 43, 0, 28, 1, 95, 4, 25, 8, 33, 3, 24, 
    7, 53, 1, 21, 6,  2, 4, 47, 0, 66, 5, 28, 2, 10, 8, 69, 3, 93, 
    5,  9, 2, 25, 4, 72, 3, 45, 7, 48, 6, 56, 8, 10, 1, 19, 0, 22, 
    6, 61, 7, 73, 1, 72, 2, 57, 8, 73, 4, 90, 0, 34, 5, 72, 3, 58, 
    6, 30, 0, 47, 4, 88, 2, 50, 5, 27, 7, 20, 8, 43, 3, 58, 1, 30, 
    1, 16, 3, 50, 0, 65, 5, 25, 4, 43, 7, 13, 8,  1, 6, 86, 2, 26, 
    3, 17, 2, 14, 1, 99, 4, 98, 5, 81, 7, 69, 8, 70, 0, 65, 6, 98
  };
  const int q1411[] = {
    9, 9, // Number of jobs and machines
    1, 47, 7, 53, 2, 28, 4, 53, 6, 59, 5, 25, 0, 28, 8, 16, 3, 96, 
    1,  9, 4, 70, 7, 92, 5, 12, 3, 54, 8, 99, 6, 49, 0, 22, 2, 98, 
    6, 90, 8,  4, 7, 32, 0, 90, 3, 95, 4, 90, 5, 70, 2, 59, 1, 92, 
    7, 62, 4, 60, 3,  7, 6,  5, 2, 28, 8, 88, 1, 21, 5,  1, 0, 12, 
    5, 42, 0,  9, 7, 68, 2, 42, 4, 39, 6,  2, 3, 78, 8, 27, 1, 68, 
    3, 65, 6,  8, 4, 78, 0, 77, 7, 59, 8, 94, 2, 18, 1, 71, 5, 51, 
    8, 22, 5, 76, 3,  7, 4, 86, 0, 38, 7, 86, 6, 19, 2, 27, 1, 46, 
    1, 78, 8, 32, 5, 96, 7, 61, 4, 31, 0,  4, 6,  4, 3, 63, 2, 25, 
    3, 45, 8,  4, 2, 94, 4, 72, 5, 50, 1, 71, 6, 56, 0, 80, 7, 22
  };
  const int q1412[] = {
    9, 9, // Number of jobs and machines
    5, 55, 4, 73, 2, 64, 6, 25, 0, 69, 8, 53, 3, 18, 1, 49, 7, 13, 
    1, 10, 4, 12, 7, 56, 5, 91, 6, 77, 2,  5, 0, 58, 3, 58, 8, 98, 
    7, 80, 4, 91, 5, 41, 3, 34, 0, 18, 8, 35, 6, 61, 1, 78, 2, 11, 
    8, 24, 4, 32, 7, 68, 0, 94, 5, 17, 1,  7, 6, 30, 3, 48, 2, 39, 
    1, 86, 0, 42, 4, 50, 8, 85, 6, 73, 3, 20, 2, 55, 7, 58, 5, 56, 
    5,  9, 2,  3, 8,  9, 0, 97, 6, 47, 3, 85, 7, 99, 4,  3, 1, 62, 
    3, 37, 8, 41, 6, 22, 1, 44, 0, 57, 5, 33, 7, 74, 2, 36, 4, 89, 
    6, 89, 4, 93, 3, 42, 7, 40, 1, 74, 8, 45, 2, 20, 0, 69, 5, 20, 
    0, 92, 3, 70, 4, 66, 2, 82, 5, 26, 7, 76, 1, 61, 6, 64, 8, 28
  };
  const int q1413[] = {
    9, 9, // Number of jobs and machines
    5, 77, 0, 73, 7, 37, 1, 37, 4, 43, 3, 51, 2, 69, 8, 24, 6, 74, 
    1, 55, 8, 43, 7,  1, 3, 11, 2, 22, 6, 36, 0, 26, 4, 10, 5, 58, 
    5, 26, 6, 95, 7, 96, 1, 83, 0, 84, 8, 66, 2, 33, 4, 51, 3, 89, 
    5, 94, 4, 55, 0, 44, 1, 19, 8,  1, 3, 42, 6, 67, 2, 79, 7, 89, 
    2, 49, 1, 86, 0, 50, 4, 73, 6, 42, 8, 46, 3, 79, 5, 54, 7,  6, 
    6, 46, 2, 80, 7, 35, 3, 38, 1, 83, 4, 17, 5, 28, 8, 87, 0,  4, 
    3, 75, 1, 99, 6, 12, 4, 75, 0, 20, 5, 90, 2, 17, 8,  4, 7, 79, 
    5, 76, 7,  3, 2, 97, 8, 27, 6, 40, 1, 62, 0, 10, 4, 25, 3, 79, 
    4, 11, 5, 51, 8,  5, 7, 92, 1, 32, 0,  3, 3, 79, 2,  3, 6, 47
  };
  const int q1414[] = {
    9, 9, // Number of jobs and machines
    3, 28, 6, 20, 2, 95, 7, 74, 0, 58, 1, 69, 8, 22, 4, 23, 5, 86, 
    4, 29, 5, 69, 1, 42, 2, 81, 0, 99, 6, 62, 7, 58, 8, 42, 3,  9, 
    8, 95, 2, 79, 4, 49, 5, 41, 3, 62, 1, 65, 6, 17, 0, 51, 7, 76, 
    2,  4, 3, 62, 0, 26, 4, 15, 1, 70, 6, 14, 7, 59, 5, 29, 8, 37, 
    1, 69, 2, 76, 3, 58, 4, 91, 7, 83, 6, 20, 5, 76, 0, 32, 8,  6, 
    7, 89, 5, 99, 0, 59, 2, 56, 3, 82, 8, 46, 6,  3, 4, 64, 1, 91, 
    6, 93, 3, 93, 5, 72, 4, 39, 8, 66, 7, 53, 1, 31, 0, 31, 2, 50, 
    0, 31, 6, 86, 5, 10, 1, 85, 4, 97, 3, 95, 7,  9, 8, 44, 2, 53, 
    3, 14, 5, 40, 6, 13, 7, 29, 2, 31, 4, 74, 1, 79, 0, 58, 8, 25
  };
  const int q1415[] = {
    9, 9, // Number of jobs and machines
    8,  3, 6,  7, 4, 19, 7, 21, 0, 89, 5, 61, 3, 26, 1, 35, 2, 56, 
    4,  5, 7, 32, 1, 76, 8,  7, 2, 58, 3, 33, 0, 89, 6, 45, 5, 62, 
    1,  4, 0,  4, 3, 14, 6, 39, 7, 97, 4, 43, 5, 94, 2, 98, 8,  4, 
    3, 26, 8, 26, 4, 34, 6, 32, 0, 72, 2, 35, 5, 65, 7,  6, 1, 92, 
    5, 45, 0, 62, 8, 71, 6, 82, 1, 75, 4, 13, 2, 74, 7, 65, 3, 47, 
    7,  9, 5, 85, 6, 59, 3, 22, 1, 55, 4, 27, 8, 55, 0, 68, 2, 45, 
    0, 54, 8, 11, 4, 13, 2, 67, 7, 70, 3, 70, 1, 93, 5, 33, 6, 92, 
    3, 17, 8, 81, 4, 53, 7, 40, 1, 84, 2,  5, 5, 94, 6, 93, 0, 43, 
    7, 12, 8, 71, 1, 52, 6, 46, 5,  7, 3,  6, 2, 25, 0, 87, 4, 57
  };
  const int q1416[] = {
    9, 9, // Number of jobs and machines
    4, 86, 3,  5, 8, 22, 5, 38, 1, 74, 2, 28, 7, 29, 6, 88, 0, 93, 
    5, 13, 2, 90, 7, 31, 1, 75, 4, 69, 8, 40, 6, 16, 3, 71, 0, 73, 
    3, 20, 2, 32, 7, 50, 8, 62, 6, 52, 0, 64, 5, 43, 4, 36, 1, 44, 
    1, 48, 7, 70, 0, 79, 2, 91, 6, 71, 8, 32, 3, 35, 4, 81, 5, 90, 
    0, 95, 5, 60, 3, 69, 7, 38, 8, 96, 2,  3, 6,  7, 1, 47, 4, 65, 
    7,  1, 4, 95, 1, 27, 5, 48, 3, 70, 2, 20, 0, 79, 6, 88, 8, 57, 
    8, 44, 2, 73, 6, 28, 5, 42, 3, 89, 4, 10, 7, 34, 0, 71, 1, 94, 
    5, 81, 8, 15, 7,  9, 3, 60, 0, 81, 1, 23, 6, 31, 2, 81, 4, 80, 
    2, 70, 0,  7, 3, 40, 6, 21, 1, 96, 4, 89, 8, 57, 5, 25, 7, 29
  };
  const int q1417[] = {
    9, 9, // Number of jobs and machines
    7, 64, 1, 68, 5, 55, 4, 81, 6, 14, 2, 69, 8, 67, 3, 87, 0, 59, 
    5, 56, 4, 44, 8, 71, 0, 68, 3, 63, 6, 91, 1, 64, 7, 89, 2, 22, 
    7, 71, 8, 36, 1, 57, 4, 22, 3, 85, 2, 26, 6, 11, 0, 63, 5, 25, 
    4, 74, 8,  4, 3, 66, 5, 71, 6, 67, 1, 91, 7, 70, 2, 48, 0, 89, 
    1, 10, 0, 79, 6, 23, 8, 87, 5, 17, 4, 81, 3, 54, 7, 67, 2, 28, 
    6, 51, 2, 39, 8, 48, 0, 20, 5, 15, 4, 28, 7, 45, 1, 45, 3, 20, 
    1,  5, 5, 63, 3, 48, 2,  6, 7, 89, 6, 73, 0, 25, 8, 42, 4, 44, 
    4, 32, 5,  8, 6,  1, 0, 33, 3, 52, 2, 42, 7, 41, 8, 79, 1, 64, 
    7, 86, 5, 62, 4, 21, 6, 86, 8, 67, 0, 14, 1, 37, 2, 86, 3, 34
  };
  const int q1418[] = {
    9, 9, // Number of jobs and machines
    1,  2, 5, 31, 3, 74, 2,  6, 8, 86, 0, 77, 7, 26, 6, 24, 4, 82, 
    4, 54, 0, 44, 8, 57, 6, 82, 7, 72, 5, 56, 3,  1, 1, 33, 2,  4, 
    7, 37, 5, 22, 4, 14, 1, 44, 3, 64, 0, 73, 6, 63, 2, 71, 8, 38, 
    5, 53, 1, 89, 8, 26, 3, 23, 7, 89, 4, 14, 2, 54, 0, 39, 6,  3, 
    7, 60, 1, 25, 2, 89, 0, 14, 5, 19, 4, 58, 3, 56, 6, 88, 8, 61, 
    1,  4, 4, 59, 6,  1, 8, 99, 5, 89, 7, 89, 3, 74, 0, 16, 2, 19, 
    3,  1, 5, 71, 8,  7, 0,  1, 2, 71, 7, 44, 6, 31, 4, 51, 1, 32, 
    8, 88, 4, 50, 1, 30, 6, 13, 5, 67, 3, 48, 0, 66, 7, 79, 2, 86, 
    5, 72, 7, 10, 1, 57, 6, 24, 8, 31, 4, 91, 0, 31, 3, 16, 2, 41
  };
  const int q1419[] = {
    9, 9, // Number of jobs and machines
    0, 44, 4, 82, 5, 76, 3, 88, 7,  7, 8, 89, 2, 64, 6, 75, 1, 79, 
    4, 82, 2, 97, 0, 40, 8, 36, 3, 87, 1,  9, 6, 37, 7, 81, 5,  6, 
    2, 84, 5, 75, 1, 83, 8, 79, 0, 14, 4, 81, 6, 44, 3, 33, 7, 99, 
    6, 63, 8, 22, 7, 21, 1, 10, 2, 27, 3, 10, 0, 64, 5, 78, 4, 23, 
    6, 57, 8, 99, 0, 73, 7, 92, 5, 18, 1,  3, 3, 47, 4, 64, 2, 58, 
    3, 71, 7, 39, 1, 55, 2, 30, 8, 72, 5, 85, 4, 76, 6, 97, 0, 69, 
    8, 17, 5, 23, 6, 85, 4,  2, 3, 67, 1, 97, 7, 70, 2, 44, 0, 15, 
    7, 71, 6, 49, 5, 26, 4,  9, 8, 29, 3, 69, 2, 10, 0, 22, 1,  3, 
    2, 63, 7, 22, 0, 47, 4, 10, 1, 46, 3, 13, 8, 69, 5, 82, 6, 37
  };
  const int q1420[] = {
    9, 9, // Number of jobs and machines
    8, 23, 6, 16, 7, 80, 0, 28, 4, 44, 2, 50, 3, 99, 1, 36, 5, 43, 
    0, 13, 5,  6, 1,  7, 7, 87, 4, 57, 2, 97, 8, 13, 3, 98, 6,  5, 
    3, 81, 5,  1, 7, 43, 6, 27, 1, 26, 2, 49, 0, 52, 4, 27, 8, 93, 
    6, 34, 7, 21, 1,  6, 0,  6, 3, 91, 8, 51, 4, 42, 5, 83, 2, 70, 
    2,  5, 8, 68, 3, 10, 1, 70, 4, 40, 5, 18, 0, 15, 7, 99, 6, 81, 
    5, 53, 4, 37, 6, 71, 7, 12, 0, 43, 3, 41, 2, 18, 1,  2, 8, 93, 
    2, 32, 6, 74, 7, 19, 0, 65, 4, 40, 1, 19, 3, 17, 5, 54, 8, 52, 
    0, 32, 7,  3, 3,  4, 5, 29, 1,  2, 8, 55, 4, 27, 2, 17, 6, 57, 
    1, 30, 3, 21, 4, 39, 8, 60, 2, 61, 0, 93, 7, 60, 6, 82, 5, 82
  };
  const int q1421[] = {
    9, 9, // Number of jobs and machines
    6, 47, 7, 58, 8,  1, 4, 74, 5, 96, 0, 24, 3, 51, 1, 85, 2, 41, 
    1, 40, 0, 62, 5, 77, 4, 24, 6, 44, 8, 93, 2, 66, 7, 92, 3, 92, 
    4, 23, 3, 23, 8, 21, 7, 83, 6, 19, 2, 17, 0, 99, 5, 98, 1, 83, 
    2, 65, 5, 20, 6, 68, 4, 71, 0, 73, 7, 60, 1, 45, 3, 22, 8, 73, 
    7, 75, 4, 69, 3, 45, 5, 25, 8, 31, 2, 54, 6, 35, 0, 15, 1, 64, 
    3, 44, 4, 57, 8, 51, 6, 40, 1, 47, 7, 44, 5, 66, 2, 52, 0,  1, 
    8, 50, 7, 20, 0, 77, 1, 51, 2, 17, 6,  8, 3, 39, 5, 67, 4, 68, 
    8, 17, 4, 34, 0, 40, 3, 98, 5, 81, 2,  2, 1, 60, 6, 10, 7, 65, 
    7, 21, 4, 47, 6, 41, 1, 41, 8,  4, 5, 38, 0,  6, 3, 89, 2, 67
  };
  const int q1422[] = {
    9, 9, // Number of jobs and machines
    6, 58, 3, 83, 2, 27, 5, 31, 1, 10, 4, 52, 8, 34, 0, 61, 7, 23, 
    3, 94, 4,  7, 8, 98, 7, 19, 0, 86, 6, 25, 1, 40, 5, 36, 2, 20, 
    1, 27, 5, 37, 8, 74, 4, 14, 6, 12, 0, 18, 7, 76, 3, 72, 2, 44, 
    4,  3, 7, 22, 3, 98, 8, 94, 1, 49, 0, 48, 2, 59, 5,  9, 6, 98, 
    5,  7, 2, 96, 1, 55, 4,  7, 3, 32, 7, 64, 6, 89, 8, 32, 0, 49, 
    2, 38, 5, 35, 0, 51, 7, 51, 6, 89, 3, 96, 4, 78, 8, 17, 1, 19, 
    6, 55, 2, 87, 3, 17, 8, 37, 4, 20, 7, 94, 5, 83, 1, 71, 0, 58, 
    5, 98, 6, 14, 7, 11, 8, 40, 2, 12, 3, 65, 1, 86, 4, 32, 0, 56, 
    1, 44, 3, 49, 5, 65, 7, 34, 8, 72, 2, 45, 6, 69, 0, 13, 4,  5
  };
  const int q1423[] = {
    9, 9, // Number of jobs and machines
    5, 85, 7, 38, 2, 36, 4, 43, 6, 76, 1, 41, 0, 41, 8, 21, 3, 64, 
    8, 42, 1, 24, 4, 44, 7, 92, 3, 32, 5, 62, 0, 91, 6, 24, 2, 28, 
    0, 37, 6, 25, 4, 53, 7, 79, 1,  3, 3, 77, 5, 33, 2, 12, 8, 90, 
    0, 55, 7, 43, 1,  8, 6, 46, 8, 74, 2, 63, 5, 15, 3, 14, 4, 97, 
    7, 50, 1, 13, 3, 93, 8, 16, 6, 55, 4, 71, 5, 33, 0, 39, 2, 21, 
    6, 99, 4,  4, 7, 17, 3, 88, 0, 10, 2, 18, 5, 35, 1, 34, 8, 22, 
    7, 25, 5, 25, 0, 69, 4, 16, 1, 12, 6, 79, 3, 57, 8, 17, 2, 85, 
    3,  5, 5, 46, 2, 97, 0, 46, 4, 73, 6, 52, 8, 52, 7, 32, 1, 78, 
    8, 24, 6,  3, 7, 30, 1, 27, 2, 42, 3, 27, 4, 97, 0,  7, 5, 83
  };
  const int q1424[] = {
    9, 9, // Number of jobs and machines
    2, 95, 1,  7, 5, 48, 3, 47, 6, 25, 0, 31, 7, 50, 4, 99, 8, 11, 
    3, 81, 7, 35, 4, 15, 6, 71, 5, 54, 8, 19, 2, 40, 1, 31, 0, 81, 
    3, 13, 8, 31, 2, 34, 7, 89, 6, 17, 1, 93, 5, 47, 0, 70, 4, 24, 
    6, 49, 8, 99, 3, 64, 2, 68, 7, 87, 4, 56, 1, 55, 5, 42, 0, 88, 
    3,  8, 2,  6, 4, 29, 0, 22, 8, 96, 1, 82, 6, 24, 7, 40, 5, 77, 
    6, 16, 1, 39, 4, 33, 8, 47, 0, 54, 5, 89, 7,  4, 3, 43, 2, 46, 
    3, 56, 7, 67, 8, 66, 1, 73, 0, 26, 2, 16, 6, 75, 4, 67, 5, 15, 
    3, 65, 6, 52, 4,  4, 2, 47, 7,  9, 1, 52, 5, 61, 8, 53, 0, 30, 
    0, 32, 3, 54, 1, 67, 6, 47, 8, 60, 5, 62, 7, 55, 4, 16, 2, 42
  };
  const int q1425[] = {
    9, 9, // Number of jobs and machines
    4, 11, 2, 40, 5, 51, 6, 54, 3, 97, 0, 63, 1, 22, 7, 79, 8, 22, 
    3, 58, 0, 17, 5, 73, 6, 83, 4, 70, 2,  3, 1, 82, 8, 73, 7, 43, 
    7, 52, 4, 36, 3, 51, 6, 73, 0, 79, 1,  7, 8, 74, 5, 93, 2, 32, 
    6, 53, 2, 49, 5, 97, 7, 47, 3, 24, 0, 86, 8, 88, 4, 68, 1, 35, 
    7, 95, 5,  5, 4, 64, 0, 26, 3, 93, 6,  4, 8, 68, 2, 75, 1, 53, 
    8, 98, 3, 43, 2, 36, 6, 80, 1, 98, 7, 88, 4, 39, 5, 36, 0, 73, 
    8, 54, 0, 81, 4, 41, 2, 34, 1, 72, 5, 23, 3, 61, 7, 98, 6, 88, 
    4, 35, 8, 16, 6, 29, 3, 45, 0, 50, 2, 34, 7, 89, 5, 87, 1, 40, 
    8, 48, 3, 30, 0,  4, 6, 24, 7, 31, 2, 36, 4, 59, 5, 68, 1, 43
  };
  const int q1426[] = {
    9, 9, // Number of jobs and machines
    7, 66, 0, 24, 5, 76, 8, 59, 6, 30, 3, 25, 1, 69, 2,  9, 4, 98, 
    6, 47, 3, 44, 1, 97, 2, 49, 4, 55, 8, 75, 5, 95, 0, 93, 7, 18, 
    6, 66, 7, 56, 4, 76, 3, 30, 0, 84, 2, 33, 8, 38, 5, 97, 1,  9, 
    1, 46, 3, 95, 8, 65, 0, 33, 4, 69, 5, 25, 6, 87, 2, 59, 7, 94, 
    2, 39, 4,  5, 0, 78, 6, 84, 3, 28, 8, 75, 7, 94, 5, 29, 1, 99, 
    2, 74, 8, 84, 4, 51, 1,  9, 6, 13, 5, 35, 3, 52, 7, 60, 0,  6, 
    0,  8, 3, 75, 8, 96, 2, 90, 1, 97, 5, 14, 6, 65, 4, 36, 7, 73, 
    4, 35, 2, 83, 8, 71, 3, 73, 6, 78, 1, 44, 5,  5, 0, 83, 7, 18, 
    6, 82, 7, 57, 5, 61, 8, 22, 3, 33, 1, 74, 2, 53, 0, 82, 4, 26
  };
  const int q1427[] = {
    9, 9, // Number of jobs and machines
    6, 71, 2, 16, 4, 66, 8, 96, 0, 44, 5, 90, 7, 57, 1, 96, 3, 42, 
    5, 99, 7, 26, 0, 32, 1, 89, 3, 59, 4, 51, 2, 40, 8, 19, 6, 24, 
    1, 73, 3, 82, 7,  2, 6,  4, 5, 32, 4, 15, 2, 16, 0, 46, 8, 32, 
    0, 84, 5, 39, 6, 66, 2, 72, 8, 31, 4, 53, 3,  5, 7, 56, 1, 58, 
    6, 86, 0, 47, 3, 78, 8, 11, 7, 67, 1, 11, 5,  2, 4, 70, 2, 11, 
    0, 12, 6, 92, 7, 27, 1, 87, 5, 97, 4, 96, 2, 20, 3,  1, 8, 19, 
    7, 10, 0, 60, 6, 22, 3,  9, 1, 26, 2, 75, 5, 54, 8, 30, 4, 41, 
    7, 96, 6, 35, 1, 17, 2, 83, 4, 21, 3, 88, 0, 22, 8, 34, 5, 94, 
    7, 94, 1, 70, 6, 18, 4, 87, 2, 74, 5, 19, 0, 34, 3, 43, 8, 52
  };
  const int q1428[] = {
    9, 9, // Number of jobs and machines
    0, 67, 5, 46, 2, 47, 8, 52, 7, 46, 3, 29, 6, 97, 4, 20, 1,  8, 
    0, 10, 8, 72, 6, 64, 2, 96, 3, 26, 5, 89, 7, 47, 4, 83, 1, 32, 
    0, 41, 2, 41, 4, 22, 7, 61, 1, 90, 8, 90, 6, 83, 3, 55, 5, 76, 
    6, 32, 7,  1, 3, 70, 5, 86, 8, 91, 0, 72, 1, 79, 2, 18, 4, 39, 
    0, 14, 8, 61, 4,  7, 2, 46, 5,  9, 6, 40, 3, 90, 1, 96, 7, 47, 
    2,  7, 1, 14, 6, 22, 7, 34, 5, 31, 0, 89, 3, 55, 8, 41, 4, 39, 
    7, 90, 1, 94, 2, 66, 8, 85, 0, 73, 4, 23, 5, 65, 3, 42, 6, 75, 
    6, 10, 1, 61, 4, 15, 7, 14, 8, 81, 0,  6, 3, 76, 2, 28, 5, 86, 
    4, 74, 1, 49, 7, 15, 0, 73, 8, 39, 6, 74, 3, 10, 5, 33, 2,  3
  };
  const int q1429[] = {
    9, 9, // Number of jobs and machines
    2, 71, 5, 67, 4, 80, 0, 85, 1, 67, 7, 43, 6, 76, 8, 56, 3, 43, 
    1, 41, 7, 72, 4, 11, 3, 14, 6, 64, 0, 56, 8, 29, 2, 53, 5, 32, 
    0, 34, 8, 69, 3, 77, 1, 60, 7, 48, 2, 56, 6, 21, 5, 74, 4, 68, 
    5, 23, 4, 86, 7,  7, 2, 66, 3,  5, 1, 81, 6, 44, 8, 27, 0, 31, 
    8, 60, 4, 77, 6, 83, 7, 91, 2, 90, 5, 49, 1, 86, 0, 68, 3, 40, 
    0, 77, 4, 52, 1, 93, 7, 83, 3, 72, 6, 66, 8, 84, 5, 69, 2, 50, 
    0, 79, 8, 87, 1, 68, 4, 63, 3, 58, 5, 58, 6, 50, 7, 18, 2, 95, 
    2,  7, 4, 50, 7, 45, 8, 60, 0, 18, 6, 82, 3, 40, 5, 32, 1, 14, 
    5, 83, 3, 62, 1, 89, 8, 54, 2, 68, 6, 34, 7, 45, 4, 15, 0, 56
  };
  const int q1430[] = {
    9, 9, // Number of jobs and machines
    2, 31, 6, 25, 0, 27, 4,  2, 8, 73, 5, 97, 3, 54, 1, 81, 7, 59, 
    8, 83, 7, 21, 1, 47, 6, 15, 3, 25, 5, 35, 0, 84, 4, 19, 2, 35, 
    3, 27, 2, 58, 1, 70, 6, 50, 5, 35, 7, 73, 8, 81, 4, 21, 0, 30, 
    1, 84, 7, 52, 4, 33, 8, 75, 0, 84, 6, 22, 5, 67, 2, 75, 3,  1, 
    0, 85, 5, 72, 8, 47, 6, 50, 1, 88, 2, 60, 7, 84, 4, 17, 3, 41, 
    5, 54, 3, 16, 7, 29, 1, 86, 6, 70, 8, 92, 0, 45, 4, 49, 2, 62, 
    8, 50, 6, 98, 0, 84, 5, 61, 4, 32, 3, 23, 1, 99, 2, 99, 7,  9, 
    3, 84, 8, 84, 7,  6, 2, 13, 0, 77, 5, 23, 4, 51, 6, 61, 1, 35, 
    6, 36, 2, 28, 8, 18, 5, 24, 7, 70, 0, 96, 4, 74, 1, 91, 3, 27
  };
  const int q1431[] = {
    9, 9, // Number of jobs and machines
    3, 40, 4, 54, 1,  6, 2, 68, 5, 50, 8, 29, 7,  1, 6, 47, 0, 35, 
    5, 49, 1, 83, 7, 37, 2, 14, 8, 49, 0, 65, 6, 33, 4, 67, 3, 73, 
    2,  1, 7, 49, 0, 61, 8, 85, 6, 94, 3, 93, 1, 71, 4, 79, 5, 38, 
    8, 64, 7, 38, 5, 28, 2, 60, 1, 67, 0,  1, 3, 39, 4, 55, 6, 40, 
    1, 38, 7, 68, 8, 36, 2, 90, 3, 80, 5, 94, 4, 34, 0, 27, 6, 77, 
    0, 15, 1, 45, 2, 33, 3, 13, 8, 77, 5, 59, 6, 19, 4, 57, 7, 23, 
    0,  7, 5, 83, 3, 92, 6, 33, 4, 55, 7, 50, 8, 61, 2, 94, 1, 74, 
    3, 58, 8, 56, 1, 96, 7, 22, 0, 50, 4, 47, 2, 53, 6, 53, 5, 16, 
    0, 54, 2, 68, 3, 49, 6, 72, 4, 55, 7, 64, 1, 62, 8,  5, 5, 53
  };
  const int q1432[] = {
    9, 9, // Number of jobs and machines
    2, 34, 7, 42, 3, 11, 4, 15, 1, 47, 8, 61, 6, 18, 5, 72, 0, 71, 
    5, 36, 0, 34, 8, 21, 2, 73, 1, 73, 4, 91, 3, 41, 7, 71, 6, 46, 
    1, 90, 8,  6, 4, 31, 0, 93, 6, 23, 2, 88, 3, 20, 7, 92, 5, 45, 
    1, 12, 4, 89, 0, 97, 2, 46, 6,  1, 7, 32, 5, 54, 8, 28, 3, 19, 
    4, 82, 8, 70, 5, 12, 7, 82, 2, 30, 6, 74, 1, 62, 3, 12, 0, 31, 
    4, 82, 7,  2, 1, 25, 3, 88, 8, 14, 5, 83, 0, 59, 2, 40, 6, 69, 
    7, 75, 3, 16, 0, 82, 6, 70, 4, 91, 5, 53, 8, 81, 1, 98, 2, 10, 
    8,  9, 0, 47, 6, 23, 4, 11, 2, 46, 3, 22, 1, 58, 7, 26, 5, 67, 
    0, 41, 5, 66, 6, 60, 7, 57, 2, 30, 1, 62, 8, 49, 3, 10, 4, 51
  };
  const int q1433[] = {
    9, 9, // Number of jobs and machines
    3, 11, 2, 34, 6, 68, 7, 28, 8, 77, 1, 85, 0, 56, 5, 57, 4, 41, 
    1, 87, 6, 18, 8, 51, 5, 50, 0, 82, 3, 64, 2, 29, 4, 91, 7, 85, 
    1, 55, 2, 38, 0,  4, 3, 10, 6, 86, 5, 31, 4, 21, 7,  5, 8, 43, 
    8, 71, 5, 55, 0, 75, 6, 23, 2, 83, 1, 18, 3, 26, 4, 34, 7, 37, 
    3, 74, 5, 95, 2, 17, 0, 63, 6, 72, 4,  2, 8, 49, 1, 29, 7, 15, 
    6, 64, 5, 25, 0, 16, 4, 21, 8, 58, 7, 11, 1, 16, 2, 70, 3, 19, 
    0, 30, 6, 17, 3, 53, 7, 97, 1, 14, 4, 22, 8, 91, 2, 41, 5, 51, 
    4, 31, 7, 73, 6, 47, 2, 40, 8, 53, 5, 36, 0, 83, 3, 76, 1, 83, 
    7, 44, 5, 74, 6, 60, 4, 15, 2, 16, 0, 34, 8, 20, 3, 83, 1, 52
  };
  const int q1434[] = {
    9, 9, // Number of jobs and machines
    2, 47, 8, 45, 3,  5, 1, 42, 5, 94, 7, 44, 6, 84, 4,  1, 0, 48, 
    3, 41, 4, 65, 7, 37, 6, 83, 5, 16, 8, 47, 1, 39, 0, 78, 2, 71, 
    2, 77, 5, 49, 8, 70, 4,  6, 0, 10, 1, 14, 7, 45, 3, 19, 6, 69, 
    5, 85, 0, 71, 3, 65, 1, 92, 7, 26, 8, 24, 2, 14, 6,  5, 4, 66, 
    1, 60, 4, 20, 5,  3, 6,  3, 8, 37, 3, 35, 2, 21, 7, 78, 0, 98, 
    1, 80, 4, 34, 5, 63, 3, 27, 7, 97, 0, 49, 8, 92, 6, 28, 2,  8, 
    2, 69, 0, 50, 7, 28, 5, 25, 1, 13, 6, 95, 8, 27, 3,  4, 4, 94, 
    2, 80, 8, 63, 5,  5, 3, 17, 1, 73, 6, 73, 7, 89, 0, 59, 4,  1, 
    0, 21, 3, 94, 5, 68, 8, 63, 7, 93, 1,  6, 4, 86, 2, 21, 6, 43
  };
  const int q1435[] = {
    9, 9, // Number of jobs and machines
    2, 10, 0, 76, 4, 69, 8, 27, 5, 12, 7, 29, 1, 37, 6, 24, 3, 30, 
    1, 69, 7, 49, 4, 13, 3, 98, 8, 90, 6, 42, 2, 42, 5, 43, 0, 33, 
    0, 10, 3, 48, 1, 40, 8, 70, 7, 36, 4,  5, 6, 53, 2, 76, 5, 59, 
    3, 13, 0, 69, 7, 53, 6, 62, 2, 86, 4, 66, 8, 70, 1, 33, 5, 19, 
    5, 29, 2, 69, 7,  9, 3, 96, 1, 95, 4, 25, 6, 67, 8, 52, 0,  7, 
    1, 13, 0, 77, 6, 65, 7, 86, 5,  9, 2, 94, 3, 19, 8, 91, 4, 28, 
    3, 59, 5,  8, 1,  4, 0, 63, 4,  9, 7, 54, 2, 64, 8, 12, 6, 57, 
    3, 52, 2, 58, 6, 52, 7, 91, 0, 41, 5, 19, 4, 69, 1, 35, 8, 74, 
    0, 11, 1, 92, 5, 80, 2, 61, 7, 67, 8, 49, 6,  4, 3, 95, 4, 83
  };
  const int q1436[] = {
    9, 9, // Number of jobs and machines
    0, 64, 7, 31, 8, 43, 5, 61, 1, 68, 6, 52, 4, 53, 2, 48, 3, 66, 
    2, 16, 6, 94, 8, 38, 3, 19, 4, 53, 7, 64, 0, 65, 5, 48, 1, 17, 
    4, 48, 3, 16, 7,  3, 2, 17, 5, 39, 1, 66, 6, 31, 0, 64, 8, 26, 
    3, 94, 0, 21, 2, 68, 6, 83, 1, 23, 5, 79, 8, 13, 7, 15, 4, 60, 
    1, 15, 7,  5, 4, 33, 3, 88, 6, 26, 5, 69, 8, 19, 0, 48, 2, 84, 
    5, 27, 4, 48, 0, 43, 6, 92, 2, 19, 1, 80, 3, 65, 8, 19, 7, 15, 
    1, 22, 4, 83, 2, 33, 0, 18, 3,  6, 5, 73, 6, 19, 7, 87, 8, 64, 
    7, 90, 2, 11, 6, 49, 3, 59, 1, 93, 0, 37, 4, 32, 8, 40, 5, 84, 
    6, 44, 8, 64, 3, 75, 2, 22, 5, 53, 7,  5, 0, 51, 4, 61, 1,  2
  };
  const int q1437[] = {
    9, 9, // Number of jobs and machines
    8, 35, 4, 81, 1, 88, 7, 73, 2, 76, 5,  5, 0, 22, 3, 36, 6, 60, 
    4, 29, 7, 11, 6, 45, 5, 48, 3, 87, 0, 75, 8, 69, 1, 91, 2,  2, 
    4, 31, 7, 86, 2, 23, 5, 16, 0, 76, 6, 43, 3, 72, 1, 36, 8, 38, 
    6, 19, 5, 11, 0, 46, 1, 21, 3,  8, 8, 77, 2, 62, 7, 47, 4, 69, 
    1, 37, 0, 17, 4, 66, 2, 44, 7, 78, 5, 50, 3, 43, 6, 19, 8, 40, 
    2, 28, 0, 64, 3, 36, 6, 40, 8, 42, 1, 41, 7,  3, 5,  1, 4, 26, 
    1, 66, 4, 54, 6, 38, 0, 97, 2, 81, 8, 21, 7,  6, 5, 46, 3, 91, 
    4, 51, 5, 61, 0, 86, 2, 12, 1, 24, 7, 71, 8, 26, 3, 51, 6, 34, 
    0, 27, 1, 31, 4, 89, 3, 90, 8, 34, 2,  9, 7, 22, 6, 76, 5, 92
  };
  const int q1438[] = {
    9, 9, // Number of jobs and machines
    8, 32, 1,  4, 2, 56, 5, 47, 0, 12, 7, 72, 4, 90, 6, 54, 3, 31, 
    3, 13, 0,  2, 2, 36, 6,  1, 7, 55, 4, 45, 1, 25, 5, 85, 8, 63, 
    3, 72, 8, 32, 6, 30, 7, 35, 5, 33, 2, 87, 1, 23, 0, 13, 4, 55, 
    1, 75, 0, 88, 3, 12, 5,  5, 4, 38, 6, 62, 2, 54, 7, 15, 8,  5, 
    0, 69, 7, 11, 8, 39, 2, 60, 1, 38, 5, 55, 3, 29, 4, 59, 6, 94, 
    1, 33, 7,  4, 6, 33, 8, 82, 5, 99, 2, 82, 3, 36, 4, 56, 0, 14, 
    3, 35, 8, 13, 6, 65, 0, 10, 1, 47, 2, 59, 5, 86, 7, 45, 4, 36, 
    5, 50, 7, 75, 4, 32, 0, 87, 6, 83, 8, 62, 2, 40, 1, 54, 3,  9, 
    6, 81, 7, 24, 0, 89, 1, 42, 2, 37, 4, 57, 3, 79, 8, 67, 5,  8
  };
  const int q1439[] = {
    9, 9, // Number of jobs and machines
    4,  4, 2, 95, 1, 59, 5, 19, 0, 51, 7, 76, 3, 61, 6,  9, 8, 75, 
    8, 20, 1, 66, 6, 10, 0, 50, 4, 30, 3, 20, 5, 16, 2, 23, 7,  7, 
    8, 79, 1, 79, 2,  4, 4, 94, 3, 92, 7, 36, 6, 30, 5, 75, 0, 71, 
    7, 82, 0, 97, 3, 15, 5, 12, 6,  2, 4, 13, 8, 12, 1,  2, 2, 54, 
    1, 88, 3, 45, 0, 48, 5, 47, 6,  6, 7, 42, 8, 68, 2, 84, 4, 97, 
    4, 90, 2, 88, 5, 32, 1, 13, 0, 85, 8, 43, 7, 15, 3, 51, 6, 31, 
    2, 56, 5, 27, 0, 74, 6, 31, 4, 30, 7, 99, 1, 65, 3, 58, 8, 77, 
    8, 56, 1, 88, 5, 78, 0, 99, 6, 56, 3,  5, 4,  9, 2, 73, 7, 29, 
    0, 35, 8, 18, 7, 26, 1, 36, 2, 88, 3, 93, 6, 62, 5, 10, 4,  4
  };
  const int q1440[] = {
    9, 9, // Number of jobs and machines
    8, 54, 1, 20, 4, 29, 0,  7, 5, 65, 3,  8, 6,  2, 7, 21, 2, 40, 
    6, 87, 0, 41, 1, 38, 2, 62, 5, 26, 4, 75, 3,  7, 8, 41, 7, 67, 
    8, 80, 0, 71, 3, 82, 4, 77, 5, 68, 2, 75, 6, 10, 1,  4, 7, 85, 
    7, 26, 1, 72, 0, 84, 2, 87, 5, 59, 8, 83, 6, 85, 4,  1, 3, 29, 
    4, 12, 3, 47, 8, 33, 2, 14, 5, 45, 7, 21, 1, 89, 0, 53, 6, 77, 
    1, 42, 6, 11, 8,  3, 2, 10, 5, 87, 0, 75, 4,  7, 7, 49, 3,  3, 
    2, 86, 3, 13, 5, 24, 6, 72, 0, 91, 4, 29, 7, 59, 1, 71, 8, 32, 
    3, 52, 5, 60, 7, 48, 8, 98, 0, 61, 6, 53, 1, 21, 4, 74, 2, 57, 
    7,  8, 0, 80, 5, 79, 4, 75, 6, 76, 1, 92, 8, 62, 3, 80, 2, 18
  };
  const int q1441[] = {
    9, 9, // Number of jobs and machines
    7,  8, 0, 99, 4,  3, 8, 60, 3, 58, 1, 85, 2, 46, 5, 90, 6, 76, 
    0, 89, 6, 17, 2, 93, 5, 73, 3, 48, 8,  7, 4, 39, 1, 27, 7, 27, 
    4, 51, 0, 44, 6, 74, 5, 61, 7, 79, 2, 14, 3, 85, 1, 61, 8, 48, 
    0, 58, 7, 40, 4, 97, 5, 20, 2, 18, 1, 88, 3, 81, 8, 64, 6, 33, 
    8, 32, 5, 79, 3, 65, 1, 91, 6, 79, 2, 62, 4, 78, 7, 15, 0, 61, 
    0, 15, 1, 68, 4, 80, 8, 89, 5, 68, 7, 46, 6, 98, 2, 11, 3, 27, 
    0, 56, 3, 34, 4, 35, 2, 41, 1, 56, 6, 90, 5, 74, 7, 27, 8, 58, 
    0, 58, 2,  3, 3, 72, 8, 18, 6,  8, 5, 34, 7, 93, 4, 98, 1, 51, 
    0, 63, 6, 53, 7, 18, 3, 18, 4, 79, 1, 45, 2, 68, 8, 79, 5,  6
  };
  const int q1442[] = {
    9, 9, // Number of jobs and machines
    7, 75, 8, 77, 0, 11, 6, 51, 2, 88, 4, 98, 1, 19, 3, 69, 5, 38, 
    2, 89, 5, 36, 0, 48, 4, 34, 6, 63, 7,  4, 8, 76, 3, 99, 1, 28, 
    6, 20, 7, 11, 5, 70, 0, 43, 1, 21, 4,  7, 2, 58, 3, 90, 8, 24, 
    1, 89, 5, 55, 3, 39, 4, 58, 7, 46, 8,  7, 6, 11, 0, 66, 2, 16, 
    3, 10, 7, 60, 8, 65, 6, 76, 1, 85, 4, 70, 2, 33, 5, 83, 0, 16, 
    3, 34, 2, 30, 0, 64, 8, 76, 5, 93, 1,  7, 7, 47, 6, 70, 4,  4, 
    3, 91, 1, 75, 8, 71, 5, 10, 7,  1, 4, 23, 6, 98, 0, 38, 2, 79, 
    8, 13, 1, 72, 7, 55, 0, 10, 2, 83, 6, 95, 5, 44, 4, 93, 3, 87, 
    4, 68, 0, 99, 3,  4, 6, 59, 1, 63, 7, 58, 5, 12, 2,  7, 8, 55
  };
  const int q1443[] = {
    9, 9, // Number of jobs and machines
    0, 57, 1, 58, 4, 41, 3, 25, 6, 81, 8, 57, 7, 96, 5, 77, 2, 65, 
    8, 65, 4, 17, 6, 85, 3, 73, 2, 65, 1, 67, 5, 36, 0, 51, 7, 11, 
    3, 94, 8, 12, 5, 53, 0, 84, 1, 97, 7, 93, 4, 37, 2, 27, 6, 44, 
    8, 73, 5, 48, 3, 16, 0, 31, 2, 33, 7, 46, 4, 32, 6, 80, 1, 87, 
    6, 57, 2, 96, 1, 18, 7, 61, 4, 78, 5, 91, 0,  6, 8, 16, 3, 77, 
    5, 15, 6,  3, 0, 39, 4, 93, 1, 62, 2, 26, 7, 90, 8, 50, 3, 77, 
    1, 49, 2, 24, 5, 65, 3, 51, 7, 80, 6, 95, 0, 19, 4, 62, 8, 86, 
    7, 45, 3, 28, 2, 39, 4,  3, 8, 68, 0, 49, 6, 23, 5, 73, 1, 29, 
    0, 86, 2, 48, 4, 64, 6, 93, 7, 89, 1, 67, 5, 69, 3, 95, 8, 20
  };
  const int q1444[] = {
    9, 9, // Number of jobs and machines
    5, 13, 3, 71, 8, 32, 1, 46, 4, 73, 6, 10, 0, 10, 2, 54, 7, 98, 
    1, 35, 2, 40, 6, 71, 8, 46, 0,  7, 5,  2, 7, 30, 3, 82, 4,  2, 
    5, 52, 0, 37, 3, 55, 4, 99, 1, 86, 6, 86, 7, 97, 8,  6, 2, 69, 
    3, 31, 1,  6, 2, 30, 5,  6, 4, 74, 0, 49, 7,  5, 8, 27, 6, 83, 
    6, 24, 7, 56, 8, 25, 3, 99, 2, 50, 4, 63, 5, 37, 0, 70, 1, 43, 
    7, 78, 0,  8, 2, 49, 5, 37, 8, 95, 6, 14, 3, 91, 1, 17, 4, 68, 
    5, 53, 0, 54, 3, 13, 6, 68, 1, 57, 4, 11, 2, 82, 7, 46, 8, 79, 
    8, 45, 5, 47, 6, 19, 1, 11, 0, 55, 7, 55, 3, 97, 2, 55, 4, 51, 
    7, 72, 3,  2, 6,  4, 2, 21, 5, 53, 0, 37, 1,  7, 8,  6, 4, 74
  };
  const int q1445[] = {
    9, 9, // Number of jobs and machines
    3, 57, 0, 11, 7, 56, 6, 28, 5, 82, 4, 79, 1, 54, 2, 80, 8, 30, 
    4, 99, 7, 34, 8, 96, 5, 76, 0, 95, 3, 55, 6, 70, 1, 81, 2, 15, 
    4,  1, 0, 77, 6, 29, 8,  1, 7, 67, 1, 71, 2,  1, 5, 76, 3, 24, 
    6, 65, 1, 75, 4, 40, 0, 94, 7, 99, 5, 85, 2,  2, 8, 94, 3, 79, 
    0,  5, 2, 65, 3,  8, 5, 99, 7, 37, 1, 98, 8, 56, 6, 59, 4, 37, 
    8, 50, 5,  4, 1, 36, 6, 22, 2, 97, 0, 17, 7, 51, 4,  6, 3, 96, 
    8, 32, 7, 42, 3, 40, 1, 84, 4, 77, 2, 85, 0, 44, 5, 70, 6, 97, 
    2,  9, 6, 60, 5, 14, 1,  1, 8, 95, 0, 51, 7, 17, 3, 40, 4, 75, 
    7, 97, 1, 51, 8, 66, 2, 99, 4, 13, 3,  7, 5,  1, 6, 90, 0, 40
  };
  const int q1446[] = {
    9, 9, // Number of jobs and machines
    4, 51, 8, 25, 7, 75, 5, 10, 6, 11, 2, 76, 1, 14, 0, 16, 3, 86, 
    5, 52, 4, 77, 1,  9, 0, 47, 3, 40, 6, 19, 7, 90, 2, 91, 8,  5, 
    8, 27, 6, 54, 0, 58, 7, 49, 5, 69, 3, 54, 4, 79, 1, 38, 2, 25, 
    1, 58, 6, 56, 5, 96, 8, 22, 4, 65, 7, 39, 2, 52, 0, 73, 3, 72, 
    8, 34, 5,  5, 2, 66, 1, 26, 4, 91, 7, 75, 6, 76, 0, 59, 3, 77, 
    6, 94, 2, 96, 8, 24, 7, 59, 0, 17, 4, 77, 1, 88, 5, 84, 3, 60, 
    4, 38, 1, 58, 6, 50, 3, 51, 5, 16, 0, 65, 7, 36, 8, 67, 2, 82, 
    0, 55, 5, 36, 1, 42, 4, 65, 2, 11, 6, 24, 8, 77, 3, 11, 7, 59, 
    0, 77, 1, 27, 8, 80, 5, 47, 3, 21, 2, 61, 7, 28, 6, 60, 4, 93
  };
  const int q1447[] = {
    9, 9, // Number of jobs and machines
    0, 12, 4, 87, 2, 23, 1, 88, 3, 14, 5, 94, 8, 86, 7, 80, 6, 99, 
    7, 71, 3,  4, 0, 90, 5, 95, 8,  3, 2, 86, 6, 96, 4, 46, 1, 73, 
    7, 88, 8, 17, 2, 46, 4, 59, 0, 73, 1, 50, 6, 74, 5,  5, 3, 73, 
    1,  1, 7, 89, 3, 11, 6, 52, 8, 76, 0, 52, 4, 50, 5, 22, 2,  6, 
    3,  8, 4, 90, 6, 41, 1, 50, 0, 25, 2, 20, 5, 16, 8, 41, 7, 38, 
    3, 69, 8, 12, 5, 48, 0, 52, 6, 96, 1, 44, 7, 45, 2, 88, 4, 73, 
    1, 12, 3, 56, 8, 52, 2,  7, 5, 92, 4, 50, 0, 18, 7, 46, 6, 62, 
    3,  2, 5, 95, 4, 35, 8, 10, 6, 97, 0, 87, 2, 23, 1, 55, 7, 13, 
    2, 68, 3,  8, 7, 21, 8, 17, 1, 49, 6, 76, 4, 10, 5, 46, 0, 29
  };
  const int q1448[] = {
    9, 9, // Number of jobs and machines
    7,  5, 0, 72, 5, 85, 3, 38, 6, 92, 4, 34, 1,  9, 8,  4, 2, 25, 
    6, 72, 1, 81, 8, 68, 5, 81, 4, 90, 7, 31, 3, 47, 0, 28, 2, 45, 
    1, 59, 5, 25, 4, 86, 6, 71, 3, 12, 7, 95, 2, 65, 8, 22, 0, 77, 
    4, 68, 6, 10, 0, 99, 2, 42, 3, 66, 1, 34, 7, 89, 5, 10, 8, 83, 
    6, 56, 7, 94, 2, 95, 3, 47, 1, 29, 5, 14, 4, 87, 8, 64, 0, 83, 
    8,  5, 5, 91, 7, 62, 3, 63, 4, 13, 6, 90, 2, 27, 1, 48, 0, 68, 
    2, 59, 3, 19, 5, 15, 7,  1, 0, 43, 1, 28, 4, 78, 8, 91, 6, 62, 
    5, 54, 7, 20, 2, 12, 3, 74, 0, 97, 4, 87, 8, 62, 6, 23, 1, 79, 
    4, 77, 5, 46, 6, 67, 7, 44, 1, 64, 3, 45, 8, 49, 2, 31, 0, 37
  };
  const int q1449[] = {
    9, 9, // Number of jobs and machines
    3, 29, 4, 49, 1, 75, 6, 14, 8, 90, 5, 50, 0, 29, 2, 73, 7, 36, 
    7, 18, 1, 15, 0,  7, 5, 69, 2, 90, 6, 47, 4, 88, 3, 66, 8, 47, 
    3, 12, 0, 24, 1, 48, 2, 23, 4, 67, 6, 33, 5, 77, 7, 38, 8, 23, 
    6, 55, 7, 23, 1, 86, 5, 26, 2, 19, 3, 78, 8, 96, 0, 34, 4, 98, 
    4, 15, 3,  3, 2, 40, 5, 32, 8, 40, 0, 95, 6, 70, 7, 43, 1, 42, 
    8, 31, 7, 25, 6, 90, 2, 77, 5, 29, 1, 23, 3, 95, 4, 99, 0, 22, 
    8, 42, 5, 93, 0, 99, 3, 53, 7, 41, 1, 27, 4, 27, 6, 70, 2, 70, 
    8, 94, 3, 68, 6, 18, 7, 48, 4, 16, 5, 96, 2, 61, 1, 79, 0, 30, 
    6,  1, 0, 24, 8, 91, 5, 74, 4, 15, 7, 99, 3, 97, 1, 30, 2, 45
  };
  const int q1450[] = {
    9, 9, // Number of jobs and machines
    6, 15, 3, 91, 0, 38, 8, 20, 7, 33, 1, 77, 5, 72, 2, 78, 4, 61, 
    3, 35, 2, 46, 6, 63, 8, 37, 0, 48, 1, 21, 4, 24, 5, 65, 7, 17, 
    8, 16, 7, 85, 3, 66, 1, 15, 6, 11, 4, 34, 2, 38, 0, 23, 5, 73, 
    0, 48, 8, 91, 3, 18, 6, 36, 4, 79, 2, 26, 7, 37, 1, 27, 5, 36, 
    6, 80, 0, 60, 8, 72, 4, 73, 1, 24, 5, 52, 2, 35, 7, 37, 3, 62, 
    1, 62, 6, 42, 8,  1, 0, 17, 5, 41, 4, 21, 2, 49, 3, 53, 7, 79, 
    6, 81, 2, 89, 0,  8, 8, 97, 5,  3, 3, 17, 1, 59, 7, 10, 4, 97, 
    5, 12, 2,  9, 6, 85, 8, 68, 0, 16, 4, 29, 1, 64, 3, 39, 7, 71, 
    3, 78, 2, 56, 1, 58, 6, 48, 7, 80, 8, 34, 0, 71, 5, 82, 4, 72
  };
  const int q1451[] = {
    9, 9, // Number of jobs and machines
    1, 89, 5, 67, 2, 24, 4, 16, 3,  9, 0, 68, 7, 97, 6, 22, 8, 52, 
    2, 70, 7, 25, 0, 52, 6, 39, 8, 48, 1, 51, 4, 21, 5, 97, 3, 10, 
    2, 36, 8, 62, 6, 28, 1, 39, 7, 48, 4,  7, 3, 88, 5, 84, 0, 81, 
    2, 78, 8, 87, 1, 18, 5, 39, 0, 99, 3, 15, 7, 70, 4, 11, 6, 17, 
    1, 52, 8, 72, 2, 94, 7, 22, 5,  3, 3, 96, 4, 88, 0, 67, 6, 86, 
    8,  4, 2, 17, 6, 97, 4, 78, 1, 30, 5, 37, 3, 87, 7, 46, 0, 78, 
    8, 36, 0, 72, 4,  4, 7, 31, 5, 51, 3, 47, 6, 79, 2, 77, 1, 48, 
    1, 82, 0, 24, 8, 10, 2, 58, 6, 19, 7, 84, 4, 71, 3, 83, 5, 17, 
    7, 80, 0, 43, 2, 70, 8, 19, 6,  2, 3, 36, 1, 16, 4, 76, 5, 72
  };
  const int q1452[] = {
    9, 9, // Number of jobs and machines
    3, 12, 1, 76, 5, 17, 4, 76, 2, 33, 8, 90, 6, 22, 0, 81, 7,  2, 
    4, 17, 3, 27, 0, 36, 1, 81, 8, 58, 5, 13, 7, 52, 2, 81, 6, 69, 
    5, 60, 1, 59, 0, 40, 3, 18, 8, 76, 4, 66, 6, 11, 2, 58, 7, 46, 
    6, 41, 0, 68, 8, 83, 5,  8, 3, 57, 7, 37, 4, 45, 1, 64, 2, 42, 
    2, 48, 5, 57, 4,  5, 1, 40, 6, 66, 8,  1, 0, 69, 7, 85, 3, 33, 
    6, 95, 1, 10, 0,  4, 2, 68, 7, 12, 5, 28, 8, 13, 4, 99, 3, 39, 
    5, 86, 6, 30, 4, 35, 3,  4, 8, 71, 1, 95, 7, 15, 2, 61, 0, 65, 
    8, 15, 5, 73, 1,  7, 6, 45, 3, 79, 0, 55, 4, 48, 7, 81, 2, 79, 
    6, 57, 1, 30, 4, 38, 0, 78, 7, 54, 5, 73, 3, 45, 2, 82, 8, 64
  };
  const int q1453[] = {
    9, 9, // Number of jobs and machines
    6, 92, 2, 57, 7, 34, 3, 70, 5, 63, 8, 33, 0, 63, 1, 94, 4, 51, 
    0, 84, 6, 92, 8, 47, 3, 29, 4, 51, 5,  7, 7, 21, 1,  1, 2, 90, 
    2, 57, 6,  9, 0, 61, 8, 37, 4, 65, 5, 79, 1, 58, 7, 12, 3, 84, 
    3, 31, 8,  4, 0, 34, 7, 31, 4, 65, 5,  3, 1,  3, 2, 12, 6, 14, 
    0, 89, 2, 30, 8, 14, 7, 47, 5, 31, 4, 93, 3, 82, 6, 74, 1, 73, 
    1, 31, 8, 35, 6, 63, 2, 39, 4, 34, 3, 21, 0, 82, 5, 89, 7, 74, 
    4, 53, 3, 24, 8, 74, 2,  9, 6,  7, 7, 71, 5, 60, 1, 25, 0, 53, 
    5, 14, 8, 33, 2, 75, 4, 67, 6, 51, 7,  4, 3, 34, 1,  4, 0, 56, 
    3, 47, 1, 73, 8, 87, 5, 17, 7, 33, 6, 85, 4, 79, 2, 14, 0, 39
  };
  const int q1454[] = {
    9, 9, // Number of jobs and machines
    2, 18, 3, 20, 4, 87, 1, 54, 8, 13, 5, 60, 7, 31, 0, 76, 6, 55, 
    6,  6, 3, 27, 4, 41, 1, 94, 2, 73, 8, 60, 7,  2, 0, 36, 5, 57, 
    2, 41, 8, 20, 1, 91, 3, 27, 0, 25, 6,  8, 4, 78, 5, 60, 7, 53, 
    8, 73, 0, 34, 1, 82, 7, 69, 5, 76, 4, 51, 6, 96, 3, 12, 2, 45, 
    6, 51, 7,  6, 8, 82, 5, 37, 1, 86, 3, 90, 4, 60, 0, 70, 2, 32, 
    0, 76, 6, 61, 3, 90, 8, 20, 5, 86, 2, 83, 7, 73, 4, 31, 1, 59, 
    1, 23, 4, 81, 7, 29, 5,  1, 2, 38, 8, 23, 3, 24, 6, 51, 0, 12, 
    6, 63, 7, 38, 8, 95, 4, 45, 3, 62, 2, 27, 1, 14, 0, 63, 5, 79, 
    6, 55, 1,  1, 8, 16, 2, 27, 3, 87, 0, 20, 7, 48, 4,  7, 5, 99
  };
  const int q1455[] = {
    9, 9, // Number of jobs and machines
    3, 78, 4, 68, 5,  5, 2, 77, 7, 74, 8, 63, 0, 63, 6, 56, 1,  5, 
    3, 43, 0, 23, 2, 24, 5, 22, 6, 43, 4, 99, 7, 78, 8, 26, 1, 57, 
    3, 19, 8, 20, 4, 32, 5, 49, 1, 91, 2, 47, 6, 41, 7, 67, 0, 88, 
    4, 49, 3, 28, 8, 91, 6,  3, 5, 76, 7,  1, 2, 25, 0, 11, 1, 49, 
    4, 86, 2, 54, 6, 58, 8, 82, 7, 17, 3, 56, 1, 65, 0, 50, 5, 70, 
    1, 13, 7, 53, 5, 29, 6, 26, 2, 70, 8, 78, 4, 60, 3, 17, 0, 40, 
    1, 61, 4, 44, 8, 82, 6, 99, 3, 22, 2, 29, 7, 90, 0, 78, 5, 88, 
    6, 77, 5, 58, 1, 70, 3, 45, 4, 90, 7, 18, 0, 82, 2, 61, 8, 45, 
    0, 50, 6, 65, 1, 72, 8, 42, 4, 58, 7, 48, 2, 30, 3, 14, 5, 25
  };
  const int q1456[] = {
    9, 9, // Number of jobs and machines
    1, 31, 8,  7, 7, 95, 3, 57, 0, 86, 6, 70, 5, 61, 4, 16, 2, 38, 
    7, 94, 1, 15, 8, 71, 5, 31, 3, 23, 4, 80, 2, 70, 6, 28, 0, 29, 
    3, 73, 4, 34, 0, 32, 8, 61, 1,  6, 7, 82, 2, 49, 6,  8, 5, 97, 
    1, 59, 3, 33, 6, 25, 0, 54, 5, 38, 4, 48, 8, 36, 2, 51, 7, 31, 
    0, 16, 3, 34, 4, 14, 1, 48, 8, 83, 6, 40, 2,  3, 5, 51, 7, 36, 
    4, 41, 5, 14, 3, 53, 2, 41, 8, 26, 1, 39, 6, 91, 7, 38, 0, 99, 
    8, 32, 5, 56, 7, 78, 6, 67, 4, 99, 1,  9, 0, 54, 3, 31, 2,  9, 
    6, 30, 7, 84, 0, 92, 4, 68, 5, 40, 8, 23, 3, 80, 2, 36, 1, 20, 
    7, 93, 3, 46, 8, 14, 4, 96, 2, 63, 5, 91, 1, 37, 0, 89, 6,  6
  };
  const int q1457[] = {
    9, 9, // Number of jobs and machines
    4,  6, 2, 97, 6, 44, 3, 88, 7, 65, 8, 92, 1, 55, 0, 25, 5, 29, 
    5, 48, 6, 60, 8, 86, 2, 28, 0, 64, 4, 49, 7, 81, 3, 64, 1, 42, 
    6, 80, 4, 76, 0, 92, 7, 80, 5, 94, 3, 96, 2, 29, 8, 64, 1, 98, 
    7, 99, 0, 82, 4,  9, 2, 21, 6, 39, 3,  2, 1, 23, 5,  4, 8, 38, 
    8, 76, 4, 18, 0, 20, 3, 58, 2,  8, 7,  3, 5, 60, 6, 70, 1, 72, 
    0, 13, 6, 56, 4, 58, 2, 28, 3, 62, 8, 51, 1, 66, 7,  9, 5, 70, 
    3, 88, 1, 24, 6, 97, 5, 45, 0, 41, 4, 48, 8, 81, 2, 82, 7, 54, 
    3, 26, 4, 99, 1, 39, 2, 17, 5, 29, 8, 74, 7,  2, 6,  5, 0, 66, 
    7, 64, 3,  7, 1, 97, 6, 29, 5, 26, 8, 33, 4, 79, 0, 57, 2, 55
  };
  const int q1458[] = {
    9, 9, // Number of jobs and machines
    6, 86, 8, 10, 3, 75, 2, 26, 1, 97, 0, 92, 7, 94, 5, 20, 4,  8, 
    8, 52, 4, 85, 5, 79, 3, 62, 2, 55, 1, 53, 6, 31, 0,  7, 7, 52, 
    3, 59, 1, 25, 5, 92, 8, 52, 6, 99, 4, 13, 2, 19, 7, 44, 0, 76, 
    5, 65, 0,  5, 1, 14, 4, 90, 6, 16, 7, 61, 3, 35, 2,  3, 8, 50, 
    7, 52, 0, 48, 8, 64, 1, 31, 4, 89, 6, 93, 5, 76, 3, 91, 2, 68, 
    2,  2, 1, 93, 4,  7, 7, 37, 0, 28, 8, 58, 5, 31, 6, 60, 3, 59, 
    1, 92, 5, 69, 7, 55, 4, 63, 8, 39, 3,  6, 6, 97, 0, 67, 2,  9, 
    4, 15, 1, 47, 7, 34, 5, 95, 2, 77, 6, 25, 8, 90, 0, 30, 3, 73, 
    4, 42, 0, 95, 3, 68, 1, 66, 8, 40, 6, 89, 7, 99, 5, 23, 2, 98
  };
  const int q1459[] = {
    9, 9, // Number of jobs and machines
    5, 22, 6, 72, 3, 87, 7, 98, 4, 89, 0, 52, 1, 73, 2, 16, 8, 77, 
    7, 98, 5, 48, 2, 95, 0, 34, 6, 78, 4, 22, 3, 64, 1,  6, 8, 36, 
    5, 53, 2, 52, 8, 38, 6, 45, 4, 85, 7, 85, 0, 35, 1, 71, 3, 94, 
    7, 12, 6, 28, 4, 10, 1, 99, 2, 24, 8, 51, 3, 73, 0, 78, 5, 68, 
    2, 32, 6, 20, 7, 16, 0, 79, 8, 82, 3, 72, 4, 33, 5, 30, 1, 85, 
    6, 95, 1, 15, 2, 71, 3, 35, 5,  4, 8, 80, 7, 95, 4, 48, 0, 52, 
    3, 29, 0, 61, 1, 82, 2, 51, 5, 17, 4, 17, 8, 10, 6, 11, 7, 71, 
    4, 62, 5, 94, 1, 98, 2, 29, 7, 68, 8, 80, 3, 18, 0, 11, 6, 75, 
    5, 87, 0, 42, 6, 43, 4, 14, 2, 36, 7, 43, 1, 52, 8, 42, 3, 64
  };
  const int q1460[] = {
    9, 9, // Number of jobs and machines
    6, 18, 2, 15, 8, 49, 0, 70, 7,  9, 3,  7, 4,  5, 5, 66, 1, 36, 
    8, 45, 6,  9, 5, 56, 1, 31, 2, 29, 0, 32, 7, 89, 3, 94, 4, 13, 
    6, 46, 5, 96, 7,  9, 0,  6, 4, 54, 1, 86, 8, 99, 3, 31, 2, 16, 
    0, 17, 4, 75, 6, 90, 1, 45, 8, 81, 7, 67, 3, 19, 5, 57, 2, 73, 
    4, 27, 0, 14, 8, 77, 6, 88, 3, 18, 5, 16, 1, 30, 2, 45, 7, 34, 
    7, 17, 5, 44, 0, 94, 2, 40, 8, 68, 1, 33, 4,  7, 6, 97, 3, 20, 
    1, 37, 8,  6, 0, 45, 5, 69, 2, 76, 3,  1, 7, 93, 4, 73, 6, 72, 
    6, 32, 4, 85, 7, 93, 5, 64, 8, 41, 2, 72, 1, 75, 3, 67, 0, 16, 
    5, 38, 7, 33, 2, 21, 8, 27, 6, 22, 3, 14, 1, 37, 0, 47, 4, 38
  };
  const int q1461[] = {
    9, 9, // Number of jobs and machines
    3, 61, 0, 30, 4, 85, 2, 47, 5, 57, 8, 52, 7, 52, 6, 96, 1, 84, 
    3, 69, 7, 62, 6, 43, 5,  1, 8, 92, 4, 21, 1, 69, 0, 71, 2, 25, 
    4, 49, 0, 48, 6, 43, 1, 49, 7, 66, 8, 33, 2,  4, 3, 22, 5, 47, 
    7, 66, 1, 29, 6,  8, 5, 82, 0, 56, 4, 17, 8, 62, 3, 82, 2, 46, 
    0, 51, 7, 51, 5, 34, 2, 45, 3,  8, 8, 53, 1,  2, 6, 56, 4, 23, 
    0, 11, 8, 32, 5,  7, 3, 73, 1, 20, 6, 77, 2, 47, 4, 51, 7, 47, 
    6,  6, 5, 92, 7, 41, 1, 19, 2, 18, 3, 36, 0, 16, 4, 23, 8, 26, 
    1, 15, 3, 71, 8, 87, 5,  4, 6, 50, 4, 24, 0,  8, 2, 31, 7, 84, 
    4, 19, 5, 41, 1, 64, 8, 71, 0, 43, 2, 64, 7, 69, 6, 15, 3, 70
  };
  const int q1462[] = {
    9, 9, // Number of jobs and machines
    6, 84, 5,  2, 3,  5, 7, 31, 1, 71, 2, 99, 0, 76, 4, 63, 8, 45, 
    0, 20, 2, 28, 3, 69, 8, 56, 6, 65, 1, 59, 4, 45, 5,  2, 7, 39, 
    4, 41, 0, 68, 5, 66, 1, 43, 2,  2, 8,  4, 6, 16, 7, 51, 3, 91, 
    6, 41, 5, 19, 7, 67, 0, 82, 1, 81, 2, 28, 8, 83, 3,  6, 4, 87, 
    2, 92, 4,  9, 8, 23, 5, 97, 1, 74, 7, 58, 6, 17, 0, 68, 3, 12, 
    0, 91, 2, 36, 6, 93, 3, 41, 7, 39, 8, 22, 1, 37, 5, 89, 4, 24, 
    6, 30, 3, 76, 7, 51, 1, 38, 2, 62, 4, 93, 0,  4, 5, 97, 8, 56, 
    2, 47, 3, 55, 6, 90, 7, 97, 4, 31, 1, 74, 8, 70, 0, 15, 5, 73, 
    3, 69, 8, 58, 6, 98, 7, 29, 2, 47, 4, 98, 1, 80, 0, 16, 5, 72
  };
  const int q1463[] = {
    9, 9, // Number of jobs and machines
    7, 32, 5, 54, 0, 35, 6, 48, 2, 96, 4, 64, 1, 13, 8, 96, 3, 28, 
    1, 81, 7, 31, 3, 55, 5,  4, 2,  4, 6, 99, 0,  9, 8, 92, 4, 41, 
    4, 29, 7, 66, 0, 22, 5, 47, 2, 98, 6,  8, 8, 78, 3, 15, 1, 21, 
    3, 79, 8, 24, 7, 88, 5, 76, 6, 70, 2, 33, 0, 59, 1, 82, 4, 65, 
    4,  3, 6, 94, 7, 14, 0, 76, 1, 46, 8,  4, 2, 97, 3, 98, 5, 73, 
    2, 53, 3,  1, 0, 49, 1, 39, 5,  2, 8, 21, 4, 38, 6, 55, 7,  4, 
    8, 14, 2, 55, 1, 91, 3, 65, 4, 39, 6, 29, 5, 32, 0, 61, 7,  3, 
    8, 34, 0, 75, 7,  6, 3, 92, 6, 95, 2, 69, 4, 36, 5, 52, 1, 60, 
    0, 80, 3, 71, 6, 41, 2, 31, 5, 70, 7, 20, 1, 45, 8, 51, 4, 13
  };
  const int q1464[] = {
    9, 9, // Number of jobs and machines
    7, 40, 6, 87, 4, 74, 2, 54, 3, 78, 5, 83, 1, 27, 0, 38, 8, 96, 
    3, 51, 2,  5, 5, 70, 6, 96, 1, 23, 4, 53, 8, 61, 7, 48, 0, 56, 
    8, 68, 5, 38, 1, 67, 0, 48, 7, 50, 2, 26, 3, 26, 4, 95, 6, 73, 
    1, 96, 2, 51, 6, 31, 4, 96, 7, 79, 0, 89, 3, 44, 5, 85, 8, 66, 
    4, 73, 1, 66, 7, 77, 3, 49, 8, 51, 6, 96, 2, 69, 5,  1, 0, 31, 
    5, 87, 7, 26, 1, 57, 8, 22, 4,  1, 6, 39, 0,  3, 2,  2, 3, 92, 
    5,  2, 1, 59, 0, 84, 2, 71, 4, 22, 3, 72, 8, 92, 7, 21, 6, 57, 
    7, 97, 4, 68, 6, 82, 8, 37, 5, 73, 3, 49, 1, 48, 2, 20, 0, 69, 
    8,  4, 6, 42, 0, 25, 2, 64, 5, 89, 4,  5, 1, 80, 3, 71, 7, 52
  };
  const int q1465[] = {
    9, 9, // Number of jobs and machines
    4, 79, 8, 71, 3, 22, 6, 54, 0, 59, 5, 52, 1,  1, 2, 24, 7, 20, 
    8, 76, 1, 75, 2, 64, 7, 49, 0, 21, 4, 67, 6, 45, 3, 37, 5, 91, 
    6, 11, 1, 67, 2, 11, 0, 32, 4, 95, 8, 59, 7, 32, 5, 57, 3, 45, 
    7, 41, 8, 11, 0, 96, 6, 66, 5,  1, 2,  2, 4,  8, 3, 10, 1, 80, 
    5, 75, 4, 13, 8, 38, 2, 35, 1, 92, 7, 29, 6, 65, 0, 80, 3, 88, 
    3, 72, 7, 22, 2, 91, 0,  7, 1, 13, 8, 33, 6, 39, 5, 82, 4, 21, 
    1, 57, 5, 81, 4, 95, 0, 88, 6,  9, 8, 66, 2, 67, 3, 91, 7, 59, 
    1, 57, 8, 81, 3, 42, 5, 67, 6, 50, 0, 19, 7, 61, 2,  3, 4, 51, 
    1, 66, 7, 65, 0, 93, 2, 23, 6, 44, 8, 31, 4, 34, 5,  5, 3, 90
  };
  const int q1466[] = {
    9, 9, // Number of jobs and machines
    2, 80, 5, 65, 6, 23, 1, 34, 3, 59, 8, 91, 7, 23, 4, 61, 0, 50, 
    3, 88, 2, 17, 5, 73, 4, 31, 0, 97, 1, 45, 7, 98, 8, 66, 6, 55, 
    7, 28, 5, 71, 2,  9, 8, 23, 0, 17, 1, 24, 6, 58, 3, 41, 4, 27, 
    5, 74, 8, 47, 4, 15, 7, 74, 6, 37, 0, 67, 3, 93, 1, 19, 2, 85, 
    7, 88, 2, 50, 4, 66, 1, 98, 3, 36, 5, 60, 8, 83, 0, 43, 6, 92, 
    1, 89, 7, 71, 2, 61, 4, 55, 8, 55, 5, 52, 0, 36, 6, 47, 3, 65, 
    0, 48, 6, 49, 5, 61, 1, 46, 4, 61, 2, 23, 3, 67, 8, 72, 7, 27, 
    2, 41, 5, 48, 1, 78, 4, 52, 7, 31, 3, 57, 6, 83, 0, 62, 8, 83, 
    5, 70, 0, 29, 6, 50, 1, 48, 4, 85, 2,  4, 8, 62, 3, 28, 7, 90
  };
  const int q1467[] = {
    9, 9, // Number of jobs and machines
    8, 11, 3, 96, 7, 18, 5, 78, 2,  5, 0, 31, 6, 98, 4, 41, 1, 75, 
    2, 61, 6, 85, 1, 30, 3, 39, 7, 66, 5, 93, 4, 71, 8, 27, 0, 43, 
    4, 22, 5, 98, 8, 71, 1, 69, 7, 78, 2,  2, 6, 74, 0, 79, 3, 46, 
    6, 69, 3, 25, 2, 49, 1, 59, 4, 62, 7, 94, 5, 43, 8, 66, 0, 91, 
    3, 12, 6, 55, 0, 67, 4, 14, 2, 65, 1, 92, 8, 62, 5, 67, 7, 27, 
    6, 57, 5, 53, 7,  1, 8, 29, 3, 14, 1, 99, 0, 95, 2, 93, 4,  1, 
    3, 63, 6, 76, 2, 96, 5, 60, 1, 10, 4, 77, 0, 19, 8, 92, 7,  5, 
    7, 24, 0, 21, 5, 78, 1, 62, 2,  2, 8, 21, 4, 14, 6,  4, 3, 19, 
    4,  9, 6, 40, 2, 96, 0, 65, 5,  5, 7, 36, 8, 39, 3, 13, 1, 85
  };
  const int q1468[] = {
    9, 9, // Number of jobs and machines
    7, 30, 0, 20, 8, 35, 5, 93, 3, 38, 4, 11, 6, 73, 1, 18, 2, 22, 
    1, 26, 5, 16, 8, 58, 3, 64, 6, 25, 2, 68, 0, 56, 4, 54, 7, 91, 
    5, 58, 4, 78, 3, 86, 2,  7, 8, 67, 6, 83, 7, 96, 0, 30, 1, 16, 
    6, 56, 3, 56, 7, 67, 0, 53, 2, 43, 8,  4, 5, 26, 4, 38, 1, 65, 
    6, 55, 5, 66, 8, 12, 3, 67, 1, 80, 7, 44, 4, 82, 2, 32, 0, 65, 
    7, 42, 6, 37, 0, 32, 8, 27, 4, 93, 5,  8, 3, 45, 2, 58, 1, 12, 
    7, 27, 3, 95, 4, 15, 2, 20, 1, 51, 0, 53, 6, 50, 8, 92, 5, 61, 
    3, 97, 2, 22, 8, 42, 6, 31, 0, 43, 5,  1, 1, 86, 4, 97, 7, 33, 
    7, 82, 4, 38, 8, 92, 1, 30, 2, 97, 6, 80, 0, 61, 5, 22, 3, 51
  };
  const int q1469[] = {
    9, 9, // Number of jobs and machines
    3, 18, 1, 89, 0, 68, 8, 54, 5, 19, 6, 99, 4, 52, 7, 50, 2, 37, 
    1, 79, 5, 74, 4, 64, 7, 10, 2,  5, 8, 29, 3, 87, 0, 71, 6, 59, 
    3, 46, 4, 50, 5, 12, 0, 35, 2,  1, 7, 58, 6, 53, 1, 37, 8, 86, 
    1, 26, 2, 94, 3, 40, 5, 36, 8, 55, 6, 22, 4, 74, 7, 35, 0, 99, 
    2, 29, 7, 62, 6, 89, 5, 89, 4, 92, 0, 50, 1, 87, 8, 71, 3, 28, 
    3,  3, 1, 54, 6, 59, 7, 82, 2, 36, 0, 16, 8, 38, 5, 18, 4, 68, 
    0, 32, 1, 17, 3, 80, 5, 62, 2, 17, 6, 90, 7, 86, 8, 91, 4, 67, 
    7, 68, 5,  2, 6, 57, 8, 69, 1, 12, 3, 81, 4,  9, 2, 50, 0, 55, 
    8, 29, 6,  2, 1, 67, 2, 53, 4, 61, 7, 28, 0, 18, 3, 13, 5, 86
  };
  const int q1470[] = {
    9, 9, // Number of jobs and machines
    0, 97, 3,  3, 4,  5, 6, 70, 2, 55, 7,  5, 1,  6, 5, 58, 8, 64, 
    1, 29, 6, 47, 5, 61, 3,  4, 7, 38, 8, 26, 4, 40, 0,  4, 2, 86, 
    3, 48, 7, 58, 5,  9, 0, 12, 6, 17, 2, 10, 4, 71, 1, 31, 8, 11, 
    0, 67, 3, 67, 7, 77, 6, 95, 5, 75, 8, 99, 2,  4, 1, 22, 4, 70, 
    8, 19, 7, 70, 1, 89, 3, 89, 2, 96, 4,  5, 0,  3, 6,  2, 5, 95, 
    4,  1, 2, 63, 0, 50, 5, 15, 8, 21, 7, 46, 6, 70, 3, 58, 1, 20, 
    3,  1, 4,  9, 1,  8, 2, 69, 0, 55, 7, 89, 5, 64, 6, 72, 8, 97, 
    3, 14, 7, 37, 1, 61, 8, 20, 5, 20, 2, 14, 4,  1, 0, 40, 6, 93, 
    2, 20, 7, 45, 6, 60, 4, 75, 0, 20, 1, 18, 5, 35, 3, 49, 8, 35
  };
  const int q1471[] = {
    9, 9, // Number of jobs and machines
    3, 39, 2, 92, 0, 83, 8, 60, 6, 14, 7, 89, 5, 88, 1,  9, 4, 31, 
    1, 84, 2, 18, 0, 53, 6,  5, 7, 34, 8, 61, 3, 94, 4, 45, 5, 71, 
    7, 27, 5, 56, 6, 24, 8, 57, 1, 24, 0, 75, 4, 41, 3, 33, 2, 87, 
    6,  1, 8, 63, 3, 58, 5, 33, 4, 31, 1, 13, 7, 32, 0, 35, 2, 38, 
    6, 79, 7, 98, 2, 71, 8,  5, 4, 61, 0, 36, 5, 91, 3, 66, 1, 64, 
    1, 24, 7, 43, 0, 13, 3, 32, 2, 90, 5, 17, 8, 43, 4,  4, 6, 36, 
    5, 16, 6, 77, 3, 50, 8, 93, 7, 58, 4, 63, 2, 81, 1, 65, 0, 16, 
    5, 60, 2, 10, 7, 49, 1,  2, 8, 99, 4, 66, 0, 21, 6, 50, 3,  1, 
    5, 98, 8, 17, 1, 82, 2, 43, 0, 94, 6, 92, 4, 18, 7, 61, 3, 26
  };
  const int q1472[] = {
    9, 9, // Number of jobs and machines
    7, 11, 1, 93, 0, 13, 5, 25, 4,  4, 2, 17, 8, 59, 3, 69, 6, 28, 
    5, 89, 3, 46, 0, 37, 4, 46, 6, 13, 1, 86, 7, 11, 2, 38, 8, 74, 
    7, 62, 8, 15, 2,  8, 1, 85, 5, 48, 0, 49, 6, 57, 4, 21, 3, 16, 
    7,  4, 0, 86, 3, 81, 4, 38, 2, 44, 5, 95, 6,  6, 1, 69, 8, 70, 
    7, 51, 8, 13, 6, 96, 4,  8, 2, 43, 3, 57, 5, 73, 1, 62, 0, 18, 
    1, 72, 6, 28, 3, 94, 4, 68, 0, 60, 8, 17, 5, 56, 2, 89, 7,  4, 
    7, 68, 6, 52, 5, 16, 1, 70, 3, 73, 8, 92, 2, 72, 0, 40, 4, 67, 
    5, 88, 4, 18, 1, 29, 8,  5, 2, 88, 7, 28, 3, 41, 6, 24, 0, 40, 
    2, 36, 1, 97, 3, 48, 0, 44, 5, 39, 6, 82, 7, 13, 4, 17, 8, 50
  };
  const int q1473[] = {
    9, 9, // Number of jobs and machines
    5, 44, 1, 37, 8, 59, 2, 49, 4, 88, 6, 13, 3, 19, 7, 11, 0, 44, 
    3, 20, 1, 90, 5, 24, 4, 51, 2, 87, 7, 19, 6, 25, 0, 62, 8, 46, 
    7, 77, 3, 14, 1, 60, 6,  9, 2, 73, 5, 15, 0, 49, 8, 89, 4, 45, 
    4, 94, 2, 28, 7, 63, 5,  2, 0, 83, 3, 20, 6, 71, 8, 69, 1, 46, 
    5, 96, 8, 76, 0, 25, 6, 13, 3, 58, 2, 39, 7, 16, 1, 70, 4, 88, 
    5,  7, 6, 21, 3, 84, 2, 81, 0, 54, 4, 97, 7, 99, 8, 28, 1, 89, 
    5, 86, 6, 30, 2, 54, 0, 25, 4, 10, 1, 98, 7, 99, 8, 75, 3, 77, 
    1,  8, 6, 46, 7, 51, 3, 46, 4, 30, 5, 83, 8, 66, 0, 41, 2, 26, 
    1, 90, 0, 32, 8, 72, 2, 78, 4, 36, 3, 15, 6, 97, 7, 46, 5, 16
  };
  const int q1474[] = {
    9, 9, // Number of jobs and machines
    3, 29, 5, 51, 4, 19, 8, 71, 2, 11, 0, 39, 6,  6, 7, 32, 1, 93, 
    7, 66, 2, 22, 0, 27, 6, 25, 8, 82, 5, 33, 3, 57, 4, 36, 1, 61, 
    6, 96, 5, 29, 1, 61, 0, 73, 7, 32, 3, 23, 8, 87, 4, 95, 2,  7, 
    8, 13, 1, 53, 7, 67, 4, 65, 2, 16, 0, 85, 6,  8, 3, 95, 5, 89, 
    4, 28, 7, 28, 6, 84, 2, 52, 3, 21, 5, 59, 8, 67, 1,  9, 0, 78, 
    5, 89, 2, 88, 4, 24, 0, 83, 7, 24, 3, 34, 1,  2, 8, 12, 6, 19, 
    3, 33, 1, 97, 2,  3, 6, 96, 4, 14, 7, 44, 5, 13, 8, 77, 0,  6, 
    3, 51, 8, 55, 7, 63, 5, 69, 4, 98, 0, 79, 1, 96, 6, 11, 2, 20, 
    7, 46, 6, 75, 1, 48, 2,  8, 5, 88, 4, 70, 8, 27, 3,  6, 0,  6
  };
  const int q1475[] = {
    9, 9, // Number of jobs and machines
    4, 61, 0, 69, 6, 72, 1,  5, 5, 19, 8, 67, 2, 44, 7, 25, 3, 99, 
    2, 34, 5, 13, 3, 79, 4, 34, 0, 79, 8, 96, 7, 38, 1, 12, 6, 30, 
    7, 68, 5, 40, 0, 92, 1, 85, 4, 11, 3, 40, 2,  7, 8, 89, 6, 27, 
    0, 11, 8, 15, 3, 65, 4, 71, 5, 89, 7, 19, 6, 94, 2, 78, 1, 43, 
    6, 40, 3, 95, 4, 53, 8, 52, 5, 83, 7, 79, 2, 86, 1, 82, 0, 98, 
    0, 18, 8, 57, 3, 42, 6, 55, 1, 53, 5, 68, 2, 82, 7, 66, 4, 92, 
    3, 88, 2, 16, 1,  7, 0, 42, 5, 86, 4, 88, 6, 20, 8, 95, 7, 16, 
    4,  8, 0, 73, 3, 38, 1, 95, 6, 32, 2, 94, 5, 61, 7, 62, 8, 86, 
    6, 80, 4, 39, 0, 20, 5, 56, 2,  2, 1, 22, 7, 44, 8, 27, 3, 98
  };
  const int q1476[] = {
    9, 9, // Number of jobs and machines
    1, 44, 8, 96, 3, 14, 7, 97, 5, 71, 6,  4, 4, 75, 0, 53, 2, 94, 
    4, 26, 5, 38, 1, 96, 7, 44, 6, 52, 3, 44, 0, 91, 8, 81, 2, 98, 
    7, 98, 1, 22, 0, 52, 4, 39, 6, 46, 2, 22, 8, 12, 3, 38, 5, 14, 
    3, 85, 8,  1, 2, 95, 1, 75, 0, 59, 6, 78, 4, 89, 7, 95, 5, 45, 
    7, 37, 8, 26, 3, 13, 0, 64, 4, 95, 1, 15, 6, 75, 2, 51, 5, 37, 
    4, 19, 3, 19, 7, 32, 0,  2, 1, 43, 6, 19, 5, 88, 2, 68, 8, 93, 
    8, 14, 6,  2, 2, 91, 3, 43, 7, 58, 0, 70, 5, 10, 4, 52, 1, 99, 
    4, 11, 7, 82, 6, 35, 3, 59, 1, 74, 5, 59, 0, 63, 2, 58, 8,  6, 
    7, 86, 6, 44, 0, 31, 8, 20, 1, 44, 5, 96, 3, 57, 2, 38, 4,  3
  };
  const int q1477[] = {
    9, 9, // Number of jobs and machines
    3, 84, 7, 80, 2, 48, 5, 45, 0, 46, 1, 51, 8, 78, 6, 39, 4, 50, 
    7, 17, 3, 39, 1, 42, 8, 92, 6, 59, 0, 64, 2, 51, 4, 98, 5, 56, 
    5, 19, 8, 54, 0, 38, 3, 52, 7, 97, 4,  2, 1, 26, 6, 95, 2, 37, 
    8, 92, 3, 73, 7, 32, 2, 61, 6, 31, 5, 90, 0,  9, 4, 15, 1, 86, 
    2, 11, 8, 87, 7, 81, 1, 41, 4, 26, 6, 33, 0, 84, 5, 15, 3, 45, 
    4, 68, 7,  6, 6,  8, 2, 66, 5, 95, 8, 34, 3, 89, 1, 12, 0, 10, 
    2, 52, 6,  8, 1, 82, 7,  6, 3,  7, 4, 62, 0, 77, 5, 60, 8, 12, 
    0, 40, 1, 74, 7, 66, 3, 58, 4, 10, 8,  2, 6, 26, 2, 24, 5, 42, 
    3, 54, 4, 90, 1,  8, 2, 74, 0, 60, 7, 41, 6, 54, 5, 70, 8, 81
  };
  const int q1478[] = {
    9, 9, // Number of jobs and machines
    5, 65, 7, 99, 0, 59, 1, 77, 4, 58, 3, 48, 2, 26, 8, 40, 6, 37, 
    0, 40, 5, 28, 6, 62, 2, 57, 3, 24, 1, 93, 4, 63, 8,  3, 7, 14, 
    5, 83, 1, 76, 2, 25, 7, 32, 6, 16, 4, 10, 3, 19, 8, 80, 0, 68, 
    2, 14, 1, 58, 4, 63, 0, 41, 7, 88, 3, 86, 5, 73, 8, 58, 6,  5, 
    7, 69, 8, 14, 3, 20, 1, 93, 5, 78, 6, 27, 2, 87, 4, 29, 0, 67, 
    0, 32, 3, 13, 5, 93, 1, 85, 6, 32, 4, 98, 7, 59, 8, 52, 2, 52, 
    8, 76, 5, 53, 2, 87, 1, 40, 6, 51, 7, 80, 3, 78, 4, 95, 0, 59, 
    3,  5, 4, 27, 2, 81, 1, 95, 5, 66, 7, 35, 6, 68, 0, 10, 8, 78, 
    2, 43, 6, 40, 4, 84, 5, 62, 0, 70, 7, 29, 3, 42, 1, 27, 8, 54
  };
  const int q1479[] = {
    9, 9, // Number of jobs and machines
    4, 41, 2, 69, 3, 12, 8, 31, 0, 95, 5, 18, 7, 68, 6, 22, 1, 54, 
    2, 60, 3, 34, 4, 24, 1, 23, 6, 24, 0, 97, 5, 59, 8, 34, 7, 82, 
    3, 77, 5, 93, 4, 81, 2, 76, 0, 99, 8, 91, 1, 10, 7, 14, 6, 97, 
    5, 46, 2, 69, 7, 64, 4, 71, 6,  3, 3, 25, 1, 92, 8, 21, 0, 63, 
    7, 23, 2, 90, 0, 64, 6, 95, 5, 51, 1, 83, 4, 59, 8, 67, 3, 50, 
    4, 91, 5, 84, 6, 50, 3,  8, 7, 20, 8, 89, 0, 54, 2, 24, 1, 74, 
    1,  7, 2, 40, 5, 15, 3, 71, 4, 49, 8, 24, 6, 28, 0, 67, 7, 94, 
    0, 68, 1, 32, 6, 82, 4, 11, 8, 35, 2, 61, 5, 71, 7, 47, 3, 89, 
    3, 65, 6,  5, 0, 19, 8, 88, 2, 17, 4,  6, 1, 15, 5, 28, 7, 91
  };
  const int q1480[] = {
    9, 9, // Number of jobs and machines
    7, 90, 1, 33, 4, 70, 8, 48, 3, 11, 6,  7, 0, 40, 2, 23, 5, 10, 
    0, 60, 4, 77, 2, 80, 8, 16, 3, 56, 1, 64, 6, 87, 7, 47, 5, 55, 
    3, 73, 7, 34, 2,  2, 0, 43, 1, 14, 8, 47, 4, 59, 6, 67, 5, 63, 
    7, 20, 6, 27, 8, 38, 4, 44, 3, 69, 5, 76, 2,  3, 0, 41, 1, 49, 
    8,  6, 7, 98, 5, 93, 1, 12, 3, 87, 0, 79, 4, 50, 6, 52, 2, 98, 
    4, 37, 2, 49, 0, 23, 5, 88, 1, 67, 8, 63, 3, 45, 7, 96, 6,  7, 
    4,  1, 5, 15, 6, 77, 3, 85, 7,  1, 0, 64, 2, 12, 1, 17, 8,  5, 
    7, 71, 3, 72, 0, 49, 8, 20, 1, 91, 5, 24, 4, 64, 2, 10, 6, 83, 
    2, 87, 1, 95, 8, 31, 6, 59, 0, 43, 5, 40, 7, 67, 4, 69, 3, 82
  };
  const int q1481[] = {
    9, 9, // Number of jobs and machines
    7, 57, 6, 51, 0, 66, 4, 45, 3, 26, 5, 21, 2, 53, 1, 46, 8, 22, 
    7, 14, 5, 57, 2, 93, 6, 64, 3, 78, 4, 87, 1, 54, 8, 94, 0, 34, 
    3,  6, 6, 88, 0, 38, 8, 74, 5, 63, 2, 31, 4, 57, 1, 98, 7, 73, 
    1, 94, 0, 15, 6, 78, 2, 42, 7, 35, 8, 53, 3, 31, 4, 40, 5, 19, 
    1, 93, 2, 67, 3, 67, 4,  5, 8, 80, 0, 43, 5, 35, 7, 78, 6, 74, 
    3, 91, 0,  5, 2, 47, 1, 41, 7, 74, 5, 52, 8,  6, 4, 33, 6, 43, 
    6, 76, 4, 61, 7, 56, 1, 65, 2, 88, 3, 63, 5, 85, 0, 68, 8,  6, 
    5, 32, 2, 80, 3, 17, 1, 27, 0, 26, 4, 47, 7,  5, 8, 91, 6,  5, 
    5, 20, 8, 20, 0,  7, 6, 69, 3, 83, 1, 83, 4, 64, 7, 56, 2, 97
  };
  const int q1482[] = {
    9, 9, // Number of jobs and machines
    4, 93, 6, 76, 3, 20, 0,  1, 5, 17, 2, 34, 8, 69, 1, 63, 7, 53, 
    6, 87, 0, 23, 4, 26, 8, 48, 7, 74, 5, 62, 2, 92, 3, 71, 1, 11, 
    0, 10, 6, 72, 5, 52, 2, 16, 3, 36, 8, 68, 1, 54, 7, 10, 4,  2, 
    6,  5, 3, 59, 2,  7, 4, 66, 5, 20, 0, 39, 1, 95, 8, 13, 7, 86, 
    2, 63, 0, 78, 1, 33, 7, 28, 5, 26, 4, 57, 8, 76, 3, 30, 6, 44, 
    6, 40, 2, 38, 5, 26, 0, 37, 4, 68, 3, 46, 1, 27, 7, 22, 8, 35, 
    4, 10, 2, 28, 3, 75, 5, 87, 7, 59, 1, 46, 6, 31, 8, 35, 0,  4, 
    6, 72, 3,  3, 1, 90, 4, 60, 8, 61, 7, 23, 2, 86, 5, 68, 0, 44, 
    2, 73, 0, 55, 3, 91, 7, 32, 4, 88, 1, 78, 8, 44, 5, 62, 6, 35
  };
  const int q1483[] = {
    9, 9, // Number of jobs and machines
    0, 94, 7, 59, 1, 28, 5, 29, 4, 21, 8, 84, 2, 99, 3, 35, 6,  6, 
    5, 94, 1, 99, 7, 35, 3, 46, 2, 78, 4, 11, 6,  8, 8, 87, 0,  3, 
    8, 72, 2,  5, 3, 79, 5, 91, 6,  8, 7, 29, 1, 28, 4, 30, 0, 50, 
    8, 49, 1, 45, 5, 29, 3, 65, 6, 31, 4, 19, 2, 31, 0, 21, 7, 78, 
    4, 76, 8,  3, 0, 98, 7, 41, 6, 29, 1, 40, 5, 79, 3, 98, 2, 18, 
    1, 75, 2, 44, 7, 52, 5, 10, 6, 51, 3, 55, 4, 10, 8,  2, 0, 50, 
    0, 55, 8,  1, 2, 39, 6, 79, 5, 45, 7, 25, 4, 74, 1, 80, 3, 10, 
    7, 12, 2, 92, 0, 95, 4, 92, 1, 40, 3, 33, 8, 81, 5, 76, 6, 16, 
    1, 37, 5,  4, 7, 46, 3, 60, 6, 14, 8, 30, 0, 10, 2, 31, 4, 11
  };
  const int q1484[] = {
    9, 9, // Number of jobs and machines
    0, 67, 2,  8, 1, 89, 5, 65, 4, 76, 6, 41, 3, 52, 7, 68, 8, 18, 
    3, 79, 8, 27, 6, 52, 5, 28, 2, 59, 7, 70, 0, 23, 1, 61, 4, 38, 
    0, 76, 2, 65, 8,  3, 5, 60, 6, 61, 3, 35, 7, 53, 1, 39, 4, 31, 
    6, 76, 1, 33, 2, 87, 5, 20, 0, 35, 3, 69, 7,  8, 8, 20, 4, 69, 
    4, 40, 8, 40, 7, 60, 1, 67, 5, 21, 0, 85, 2, 16, 3,  2, 6, 72, 
    0, 80, 5, 50, 3, 72, 8, 62, 2, 29, 1, 11, 7,  9, 4, 63, 6, 29, 
    7, 56, 3, 29, 4, 42, 6, 50, 2, 12, 8, 49, 1, 87, 5,  3, 0, 28, 
    5, 62, 8, 50, 2, 50, 6, 90, 0, 92, 4, 49, 1,  7, 7, 63, 3, 38, 
    1, 68, 4, 80, 0, 23, 7, 25, 8, 68, 5, 79, 3, 49, 2, 38, 6, 70
  };
  const int q1485[] = {
    9, 9, // Number of jobs and machines
    4, 58, 5, 16, 6, 24, 0,  2, 7, 45, 1, 68, 3, 63, 2, 25, 8, 13, 
    7, 90, 6, 38, 2, 91, 4, 58, 8,  9, 0, 31, 1, 74, 3, 85, 5, 21, 
    7, 56, 5, 86, 0,  7, 1,  8, 8,  8, 4, 50, 3,  3, 6, 97, 2, 55, 
    2, 88, 8, 34, 6, 53, 7, 38, 5, 58, 1, 64, 0, 48, 4,  3, 3,  7, 
    1, 64, 2, 96, 5, 46, 7,  2, 8, 37, 0, 69, 4, 13, 3, 89, 6, 76, 
    4, 26, 1,  3, 0, 63, 8, 17, 6, 31, 7, 25, 2, 79, 5, 50, 3, 37, 
    7, 71, 5, 62, 6, 27, 8, 38, 0, 29, 4, 15, 1, 85, 3, 47, 2, 85, 
    6, 30, 0, 85, 8, 71, 7, 51, 4, 11, 1, 94, 3, 23, 5, 64, 2, 71, 
    6, 83, 8, 24, 0, 39, 4,  5, 7,  6, 3, 47, 5, 79, 1, 71, 2, 34
  };
  const int q1486[] = {
    9, 9, // Number of jobs and machines
    4, 69, 8, 64, 1, 97, 5, 91, 7, 15, 6, 95, 2, 58, 0, 33, 3, 24, 
    4, 91, 8, 60, 0, 76, 7,  8, 5, 44, 6,  6, 2, 40, 3, 68, 1, 38, 
    5, 69, 6,  7, 3, 67, 2, 63, 7, 55, 1,  1, 4, 28, 0, 60, 8,  6, 
    4, 68, 2, 50, 3, 82, 7, 43, 6, 63, 5, 16, 8, 38, 1, 36, 0,  2, 
    5, 45, 7, 42, 1, 81, 4, 47, 3, 43, 6, 28, 0, 34, 8, 46, 2, 88, 
    0, 82, 5, 49, 2, 88, 6, 84, 3, 50, 7, 35, 8, 23, 1, 12, 4, 58, 
    7, 13, 6, 27, 5,  9, 3, 41, 2, 82, 8, 74, 1, 61, 0, 19, 4, 72, 
    8, 34, 2, 67, 7, 38, 0,  7, 3, 84, 4,  7, 5, 61, 6, 35, 1, 69, 
    7, 28, 6, 16, 3, 69, 4, 74, 1, 19, 8, 88, 5, 29, 0, 68, 2, 99
  };
  const int q1487[] = {
    9, 9, // Number of jobs and machines
    1, 61, 4, 87, 5, 96, 7, 59, 6, 12, 2, 35, 3, 73, 0,  6, 8, 52, 
    1, 38, 7, 11, 6, 89, 3, 82, 4, 73, 5, 50, 2, 64, 0, 67, 8, 57, 
    6,  5, 8,  9, 4, 14, 0, 18, 7, 19, 2, 34, 3, 79, 1, 67, 5, 86, 
    2, 26, 1, 85, 3, 69, 4, 53, 6, 11, 8, 82, 0, 65, 7, 49, 5, 14, 
    5, 34, 1, 24, 0, 76, 4, 22, 3,  4, 2,  8, 6, 31, 8, 84, 7, 93, 
    1, 47, 7, 21, 8, 95, 0, 94, 4,  2, 6, 94, 3, 60, 5, 84, 2, 70, 
    2, 52, 6, 91, 3, 74, 8, 70, 5, 53, 4,  1, 1, 93, 0, 55, 7, 40, 
    5, 56, 7, 80, 0, 30, 8, 31, 2, 76, 1, 44, 4, 59, 6,  8, 3, 56, 
    0, 62, 4,  5, 6, 37, 7, 46, 1, 12, 5, 57, 3,  1, 2, 80, 8, 68
  };
  const int q1488[] = {
    9, 9, // Number of jobs and machines
    0, 92, 3, 74, 5, 63, 7, 85, 1, 36, 4,  3, 8, 65, 6, 36, 2, 69, 
    2, 35, 4, 18, 1, 40, 5, 77, 8, 13, 0, 55, 6, 37, 3, 73, 7, 78, 
    6, 88, 4, 38, 5, 83, 2, 31, 1, 97, 3, 11, 8, 98, 7,  5, 0, 98, 
    7, 67, 5, 56, 6,  8, 4, 51, 1, 46, 0, 54, 2, 49, 8, 63, 3,  8, 
    7, 83, 6, 88, 0, 36, 2, 30, 5, 39, 8, 89, 4, 74, 1, 10, 3, 29, 
    1, 57, 5, 41, 0, 92, 3, 23, 2, 17, 4, 40, 8, 17, 7,  6, 6, 82, 
    4, 47, 1, 86, 5, 68, 6, 91, 0, 42, 2, 28, 7, 33, 8, 67, 3, 31, 
    4, 57, 5, 21, 2, 58, 3, 21, 0, 40, 6, 46, 8, 64, 7, 83, 1, 23, 
    8, 66, 5, 44, 0, 59, 1,  1, 2, 96, 3, 34, 7, 51, 6, 89, 4, 90
  };
  const int q1489[] = {
    9, 9, // Number of jobs and machines
    7,  9, 0, 14, 1, 59, 8, 31, 5, 65, 2, 28, 6, 10, 4, 60, 3, 86, 
    5, 61, 3, 91, 6, 70, 0, 72, 4, 29, 7, 59, 1, 56, 8, 42, 2, 40, 
    3, 91, 5, 29, 0, 28, 8, 11, 2, 71, 4, 90, 6, 54, 1, 32, 7, 37, 
    1, 74, 3, 72, 6, 75, 5, 56, 8, 92, 7, 87, 4, 24, 0, 10, 2, 95, 
    3, 82, 5, 88, 7, 14, 0, 74, 6, 76, 1, 10, 8, 82, 2, 97, 4, 89, 
    1, 39, 7, 96, 0, 80, 4, 28, 2, 52, 5, 41, 8, 98, 6, 46, 3, 90, 
    8, 37, 5, 15, 4, 90, 7, 62, 6, 46, 2, 42, 1, 74, 3, 64, 0, 18, 
    0, 92, 5, 56, 2,  7, 6, 36, 7, 43, 8, 34, 1, 55, 4, 61, 3, 36, 
    7, 40, 0, 25, 2, 48, 1,  1, 5, 86, 3, 40, 6, 47, 4, 75, 8, 69
  };
  const int q1490[] = {
    9, 9, // Number of jobs and machines
    1, 95, 2, 16, 4, 64, 3, 37, 6, 77, 8, 46, 0, 22, 7, 90, 5, 98, 
    4, 69, 5, 52, 7, 86, 0, 82, 6, 99, 1, 30, 2, 31, 8, 22, 3, 66, 
    5, 24, 7, 85, 8, 15, 6, 61, 1, 37, 2, 37, 0, 82, 3,  5, 4, 65, 
    5, 50, 3, 35, 0,  7, 4,  1, 1, 81, 8, 96, 6, 33, 2, 97, 7, 36, 
    3, 65, 1, 89, 5, 82, 7, 48, 4, 78, 8, 68, 0, 97, 6, 45, 2, 66, 
    2, 63, 8, 86, 3, 24, 1, 58, 7, 32, 5, 94, 4, 68, 0, 87, 6, 47, 
    7,  1, 1, 13, 8, 28, 0, 44, 5, 56, 3, 38, 2, 50, 4, 54, 6, 40, 
    1, 25, 4, 65, 0,  7, 2, 42, 7,  3, 6, 77, 3, 23, 5,  7, 8, 15, 
    0, 55, 6, 57, 1,  7, 4, 65, 5, 88, 7, 17, 3, 96, 8, 40, 2, 65
  };
  const int q1491[] = {
    9, 9, // Number of jobs and machines
    7, 38, 3, 19, 6, 32, 0, 45, 2, 65, 4, 29, 5, 94, 8, 82, 1, 23, 
    8, 45, 2, 27, 3, 97, 1, 72, 4, 12, 5, 65, 0, 29, 6, 19, 7, 33, 
    3, 47, 4, 91, 7, 45, 0, 53, 6, 38, 2, 34, 8, 39, 1, 62, 5, 31, 
    7, 76, 3, 18, 4, 88, 6, 76, 8, 82, 5, 85, 0, 45, 1, 31, 2, 75, 
    7, 94, 1, 97, 2, 70, 4, 91, 6, 57, 5,  3, 3, 30, 0, 42, 8, 32, 
    4, 20, 2, 53, 1, 83, 0, 80, 7, 61, 8, 45, 5, 30, 6, 21, 3, 72, 
    1, 59, 4, 39, 0, 20, 5, 22, 2, 98, 3, 19, 8, 43, 6, 31, 7, 75, 
    3, 28, 5, 24, 8, 42, 2, 25, 7, 49, 1, 35, 6, 55, 4, 66, 0, 72, 
    4, 83, 0, 12, 6, 99, 1, 42, 5, 97, 2, 49, 8, 65, 3, 27, 7, 95
  };
  const int q1492[] = {
    9, 9, // Number of jobs and machines
    3, 31, 4, 65, 7,  4, 6, 82, 5,  3, 1, 76, 8, 12, 2, 58, 0, 56, 
    6, 83, 4,  7, 3, 97, 0, 83, 5, 34, 1, 88, 2, 45, 7, 26, 8, 81, 
    1, 18, 6, 75, 2, 80, 7, 89, 5, 73, 0,  1, 3, 46, 4, 41, 8, 35, 
    5,  5, 1, 41, 6, 65, 8,  6, 0, 36, 2, 86, 3, 31, 7,  9, 4, 21, 
    2, 99, 3,  6, 5, 35, 0, 40, 1, 15, 6,  3, 7, 59, 8, 72, 4, 45, 
    7, 80, 5, 25, 8, 18, 4, 16, 3,  3, 0, 95, 1, 53, 2, 84, 6, 21, 
    8, 53, 2, 71, 1, 88, 5, 76, 6, 64, 3, 76, 7, 71, 0, 60, 4, 93, 
    8, 59, 2, 74, 3, 11, 4,  3, 0, 58, 5, 43, 6, 24, 1,  2, 7,  9, 
    5, 33, 8, 94, 1, 38, 0, 69, 7, 20, 4, 98, 2, 83, 3, 54, 6, 55
  };
  const int q1493[] = {
    9, 9, // Number of jobs and machines
    4, 97, 0, 62, 8, 12, 3, 13, 5, 91, 7, 64, 1, 53, 6, 76, 2, 28, 
    2, 32, 3, 81, 7, 77, 5, 93, 6, 18, 0, 94, 1,  4, 8, 98, 4, 56, 
    6, 55, 7, 57, 8, 36, 4, 49, 5, 24, 2, 15, 0, 23, 1, 28, 3, 11, 
    2, 61, 7,  1, 0, 10, 5, 72, 3, 80, 4, 98, 1, 11, 8, 34, 6, 19, 
    3,  9, 2, 78, 8, 58, 4,  5, 6, 27, 0, 34, 7, 11, 1, 25, 5, 81, 
    6, 25, 2, 12, 8, 28, 7, 26, 0, 69, 1, 20, 4, 22, 3, 34, 5, 65, 
    7, 42, 5, 34, 2, 28, 6, 27, 8, 25, 0, 50, 1, 84, 3, 84, 4, 45, 
    2, 25, 8, 16, 5, 59, 1, 56, 4, 63, 6, 51, 3, 77, 7, 49, 0, 35, 
    2, 68, 6, 59, 0, 25, 3,  9, 4, 18, 1, 78, 5, 61, 8, 21, 7, 47
  };
  const int q1494[] = {
    9, 9, // Number of jobs and machines
    6, 72, 5, 98, 3, 31, 7, 48, 2, 47, 8, 29, 4, 41, 0, 22, 1, 17, 
    3, 43, 6, 16, 4, 90, 7, 16, 1, 58, 2, 54, 0, 40, 5, 54, 8, 74, 
    6,  3, 5, 55, 4, 24, 2, 75, 7, 52, 1,  8, 8, 65, 3, 82, 0, 48, 
    4, 44, 3, 21, 6, 39, 5,  6, 2, 98, 8, 62, 1, 17, 7, 84, 0, 46, 
    5, 15, 0, 11, 3, 54, 8, 48, 2, 24, 4, 94, 6, 12, 7, 85, 1, 95, 
    4, 45, 0, 70, 7, 18, 1, 19, 5, 20, 3, 21, 2, 21, 8, 13, 6, 47, 
    3, 16, 1, 68, 0, 12, 6, 29, 5, 90, 2, 32, 7, 99, 4,  9, 8, 22, 
    5,  4, 0,  4, 4, 93, 2, 86, 8, 85, 1, 96, 3, 73, 7,  2, 6, 57, 
    2, 39, 1, 26, 0, 97, 7,  7, 5, 10, 4, 58, 8, 65, 3, 84, 6, 58
  };
  const int q1495[] = {
    9, 9, // Number of jobs and machines
    1, 13, 4, 81, 5, 22, 7, 37, 8, 14, 0, 57, 6, 66, 3, 94, 2, 85, 
    8, 62, 1, 55, 7, 67, 0, 17, 4, 74, 6,  5, 5, 67, 2, 68, 3,  9, 
    8, 22, 6, 40, 0, 99, 2, 46, 4, 98, 3, 69, 5, 79, 7, 74, 1, 41, 
    6, 81, 7,  6, 8, 30, 0, 29, 3, 83, 4, 72, 1, 86, 2, 62, 5, 95, 
    2,  9, 4, 88, 0, 13, 6, 99, 5, 61, 8, 59, 1, 40, 7, 36, 3, 97, 
    2, 70, 6, 14, 8, 26, 3, 63, 4, 69, 7, 12, 5, 55, 0, 90, 1, 21, 
    5, 94, 3, 68, 8, 98, 4,  4, 7, 59, 2, 50, 0,  6, 1, 92, 6, 66, 
    3, 48, 7, 10, 4, 36, 2, 59, 6, 69, 1,  5, 0, 12, 8, 66, 5, 17, 
    4, 60, 3, 19, 8, 29, 5, 11, 0, 83, 6, 99, 1, 34, 2, 15, 7, 67
  };
  const int q1496[] = {
    9, 9, // Number of jobs and machines
    1, 21, 8, 61, 2, 13, 7,  5, 4,  3, 6,  3, 3, 95, 0,  9, 5, 87, 
    7, 96, 3,  7, 6, 57, 2, 35, 0, 67, 4, 57, 8, 85, 5, 41, 1, 98, 
    3, 32, 0, 44, 4, 94, 2,  2, 1, 60, 6, 96, 7, 77, 5, 66, 8, 97, 
    3, 90, 5, 43, 0, 49, 2, 24, 8, 71, 6,  2, 7, 42, 4,  4, 1, 95, 
    0, 21, 2, 22, 7, 16, 4, 12, 8, 47, 3, 48, 1, 66, 5, 76, 6, 52, 
    5, 61, 4, 11, 2, 11, 1, 54, 7, 96, 0, 69, 8, 23, 3, 54, 6, 39, 
    8, 45, 4,  5, 0, 39, 3, 76, 2, 55, 7, 89, 1, 25, 5, 78, 6, 38, 
    4, 60, 7, 26, 6,  2, 8,  7, 2, 52, 1, 78, 3, 53, 5, 24, 0, 74, 
    1, 89, 3, 63, 5, 76, 2, 23, 7, 24, 8, 98, 0, 79, 4, 91, 6, 41
  };
  const int q1497[] = {
    9, 9, // Number of jobs and machines
    1, 12, 4, 14, 3, 75, 7, 18, 5, 76, 6, 25, 2, 58, 0, 60, 8, 66, 
    7, 94, 2, 98, 3, 96, 1, 89, 4, 72, 0, 64, 5,  6, 8, 80, 6, 55, 
    4, 69, 3, 52, 2, 95, 7, 23, 1, 93, 6, 45, 8, 26, 5, 23, 0, 56, 
    3, 51, 1, 17, 6, 54, 8, 93, 5, 30, 0, 39, 2,  6, 7,  9, 4, 33, 
    7, 75, 8, 92, 3, 53, 1, 70, 0, 43, 6, 44, 5,  7, 4, 95, 2, 28, 
    1, 95, 2, 10, 7, 26, 0, 93, 4,  1, 8, 43, 3, 40, 6, 83, 5, 43, 
    4, 85, 0, 78, 7, 95, 8, 66, 6, 61, 5, 36, 2, 96, 3, 33, 1, 88, 
    7, 34, 0, 22, 8, 25, 6, 74, 2, 92, 4, 31, 1,  1, 3,  1, 5, 72, 
    0, 85, 7, 10, 4,  2, 5, 49, 2, 99, 6, 86, 1,  1, 8, 49, 3, 47
  };
  const int q1498[] = {
    9, 9, // Number of jobs and machines
    3, 24, 8, 21, 6, 55, 0, 50, 5, 43, 2, 56, 7, 34, 1, 18, 4, 67, 
    2, 43, 6, 44, 3, 79, 7, 74, 5, 63, 0, 47, 4, 40, 8,  6, 1, 90, 
    3,  5, 8, 77, 2, 73, 1, 89, 0, 41, 5, 94, 7, 94, 6,  3, 4, 47, 
    4, 94, 8, 66, 2, 98, 1, 93, 0, 24, 5, 66, 7, 27, 6, 43, 3, 45, 
    5, 59, 7, 34, 2, 17, 4, 23, 8, 33, 1, 67, 0,  5, 6, 98, 3, 13, 
    0, 89, 2, 97, 5, 23, 3, 17, 4, 41, 6, 38, 8, 27, 7, 26, 1, 86, 
    1, 62, 7, 13, 3, 90, 0,  8, 5, 42, 4, 13, 2, 11, 8, 36, 6, 61, 
    0, 51, 5, 78, 4, 17, 2, 28, 1, 46, 7, 37, 6, 13, 8, 27, 3, 94, 
    6, 54, 8, 76, 5, 11, 2, 16, 4, 65, 0,  2, 1, 71, 3, 82, 7, 13
  };
  const int q1499[] = {
    9, 9, // Number of jobs and machines
    1, 99, 6, 97, 3, 19, 5, 95, 0, 69, 8, 67, 4, 55, 7, 70, 2, 10, 
    1, 40, 3, 10, 7,  4, 0,  5, 5, 71, 6, 32, 8, 76, 2, 57, 4, 83, 
    7, 42, 6, 62, 1,  2, 8,  1, 3, 89, 5, 73, 4, 68, 0, 14, 2, 68, 
    7, 77, 1,  6, 8, 44, 0, 45, 4, 81, 2, 95, 3, 47, 5, 81, 6, 30, 
    4, 54, 6, 38, 5, 67, 1, 31, 7, 43, 0, 58, 3,  8, 2, 26, 8, 76, 
    3, 33, 2, 49, 0, 60, 1, 74, 5, 84, 8, 84, 7, 62, 4,  9, 6, 84, 
    6,  7, 5, 77, 4, 42, 3,  8, 2, 79, 8, 28, 0, 71, 7, 86, 1,  2, 
    2, 99, 3, 45, 4, 94, 8, 94, 0, 99, 6, 49, 5, 53, 1, 69, 7, 90, 
    6, 94, 8, 56, 0, 30, 4, 42, 7, 57, 5, 90, 3, 38, 2, 50, 1, 23
  };
  const int q1500[] = {
    9, 9, // Number of jobs and machines
    6, 74, 0, 49, 2, 84, 4, 75, 1,  7, 3, 35, 7, 49, 8, 74, 5, 51, 
    3, 48, 5, 94, 2, 66, 6, 52, 4, 73, 1, 35, 7, 55, 0, 32, 8, 74, 
    6, 53, 7, 87, 0, 94, 4,  2, 2, 71, 1, 61, 8, 39, 3, 54, 5,  4, 
    5, 21, 0, 21, 8,  4, 1, 19, 3, 10, 4, 24, 7, 97, 2, 55, 6, 94, 
    2, 29, 0, 37, 7, 56, 4, 39, 5, 37, 6, 22, 3, 41, 8, 72, 1, 62, 
    0, 93, 7, 82, 4, 18, 1, 70, 3, 42, 5,  2, 8, 55, 2, 13, 6, 94, 
    0, 23, 5, 54, 1, 14, 2, 92, 6, 79, 4, 39, 7, 77, 8, 45, 3,  9, 
    6, 70, 0,  1, 2, 55, 8, 99, 5, 64, 3, 90, 4, 22, 7, 33, 1, 50, 
    2, 62, 8, 91, 4, 58, 3,  7, 7, 44, 1, 13, 6,  8, 5, 83, 0, 49
  };
  const int q1501[] = {
    9, 9, // Number of jobs and machines
    1, 95, 6, 24, 8,  9, 0, 25, 5, 37, 3, 91, 2, 26, 7, 81, 4, 91, 
    2, 52, 6,  8, 8, 37, 7, 38, 5, 79, 0, 53, 4, 87, 1, 24, 3, 52, 
    2, 12, 6, 25, 5,  8, 8, 51, 0, 54, 7, 66, 4, 66, 1, 67, 3, 69, 
    4, 21, 8, 68, 7, 11, 0, 85, 2, 21, 3, 89, 1, 42, 5, 25, 6, 13, 
    0, 69, 2, 11, 3, 85, 7, 29, 5, 80, 8, 73, 4, 29, 1,  5, 6, 76, 
    0, 12, 3, 21, 1, 10, 6, 95, 5,  4, 4, 33, 8, 12, 7, 98, 2, 70, 
    4, 97, 8, 51, 7, 66, 6,  3, 3, 49, 1, 33, 2, 36, 5, 38, 0, 65, 
    8, 79, 7, 42, 3,  9, 2, 90, 4, 76, 6, 23, 1, 90, 0, 83, 5, 67, 
    6, 50, 3, 42, 5, 27, 4, 67, 0, 60, 2, 13, 8, 18, 1, 19, 7, 20
  };
  const int q1502[] = {
    9, 9, // Number of jobs and machines
    1, 63, 5, 17, 4, 49, 6, 89, 3, 53, 8, 41, 2, 84, 7, 39, 0,  6, 
    8, 54, 2, 80, 6, 51, 5, 79, 4, 37, 0, 66, 3, 64, 1, 44, 7, 83, 
    8, 35, 1, 75, 7, 99, 4, 92, 5, 90, 6, 26, 0, 75, 3,  3, 2,  7, 
    1, 24, 6, 12, 2, 57, 8, 11, 3, 38, 5, 17, 4, 76, 0,  8, 7, 90, 
    4, 76, 0, 34, 2, 84, 1, 16, 8, 51, 3, 72, 6,  4, 5, 74, 7, 11, 
    5, 15, 2, 69, 7, 59, 6, 71, 1, 36, 8, 20, 3, 63, 0, 65, 4, 51, 
    2, 41, 0, 67, 6, 60, 4, 70, 8, 64, 5, 47, 1, 23, 3, 30, 7,  3, 
    6, 40, 3, 49, 0, 35, 2, 98, 8, 90, 7, 28, 1, 37, 4, 59, 5, 18, 
    8,  8, 4, 10, 6, 99, 2, 73, 5,  2, 1, 19, 0, 82, 7, 87, 3, 65
  };
  const int q1503[] = {
    9, 9, // Number of jobs and machines
    1, 67, 0, 80, 8, 53, 5, 73, 7,  1, 6, 25, 4, 78, 3, 74, 2, 17, 
    7, 97, 1, 86, 3,  8, 2, 38, 4, 50, 6, 21, 8, 23, 5, 85, 0, 57, 
    7,  2, 1, 90, 2,  9, 4, 40, 3, 16, 6, 93, 8, 66, 5, 73, 0, 91, 
    2, 92, 4, 63, 8, 36, 5, 65, 1, 28, 6, 27, 7, 31, 3, 66, 0, 74, 
    3, 43, 4, 69, 2, 25, 5, 23, 6, 61, 1, 29, 8, 76, 7, 12, 0,  9, 
    2, 34, 8, 17, 3, 45, 4, 63, 5, 55, 7, 68, 0, 71, 1, 21, 6, 67, 
    8, 98, 6,  3, 7, 81, 3, 50, 1, 47, 2, 23, 0, 26, 4, 58, 5, 76, 
    0, 97, 8, 63, 1, 81, 4, 38, 6, 62, 5, 37, 2, 87, 7, 99, 3, 89, 
    7, 72, 0, 36, 1, 58, 6, 93, 3, 97, 8, 28, 4, 78, 5, 20, 2, 84
  };
  const int q1504[] = {
    9, 9, // Number of jobs and machines
    6, 74, 4, 13, 3, 43, 0, 22, 2, 85, 5, 57, 7, 90, 1, 44, 8, 37, 
    4, 34, 7, 52, 2, 60, 5, 54, 8, 33, 0, 38, 1, 40, 3,  2, 6, 73, 
    8, 67, 5, 50, 3,  3, 2, 11, 4, 95, 0, 96, 1, 20, 6, 68, 7, 60, 
    4, 83, 7,  9, 6,  1, 1, 70, 5, 98, 8, 53, 0, 16, 2, 86, 3, 26, 
    2, 19, 1, 91, 5, 35, 6, 86, 7, 52, 3, 89, 8, 46, 0, 79, 4, 43, 
    7, 29, 2, 29, 0, 26, 8, 80, 4, 25, 3,  3, 6, 47, 1, 15, 5, 13, 
    6, 41, 4, 34, 1, 24, 2, 56, 5, 17, 7, 55, 8, 31, 3, 71, 0, 12, 
    3, 90, 0, 69, 8, 62, 6, 38, 7, 27, 1,  7, 4, 90, 5, 51, 2, 54, 
    7, 84, 8, 11, 0, 58, 4, 43, 2,  7, 3, 58, 1,  4, 6, 98, 5, 87
  };
  const int q1505[] = {
    9, 9, // Number of jobs and machines
    1, 94, 0, 88, 2,  6, 7, 79, 3, 21, 4, 21, 6, 33, 8,  2, 5, 57, 
    4, 92, 1, 72, 5, 84, 6, 37, 2,  4, 7, 91, 8, 92, 0, 37, 3, 69, 
    4,  9, 0, 53, 8, 32, 1, 83, 2, 71, 6, 87, 5, 78, 7, 97, 3, 29, 
    4, 95, 8, 15, 3, 51, 6, 45, 0, 59, 5, 69, 1, 31, 2, 91, 7, 65, 
    4, 27, 5, 74, 3, 63, 6, 33, 0, 44, 8, 28, 1,  5, 2,  2, 7, 56, 
    7, 53, 1, 16, 0, 26, 8, 46, 2, 67, 3, 12, 6, 55, 5, 87, 4,  2, 
    2, 57, 5, 24, 1, 16, 3, 57, 8, 41, 4, 42, 7, 32, 6, 29, 0, 79, 
    3, 55, 6,  6, 5, 13, 1,  3, 2,  9, 0, 49, 4, 21, 7, 17, 8, 78, 
    4, 51, 0,  4, 2,  6, 5, 50, 7, 68, 6,  3, 8, 62, 1, 20, 3, 78
  };
  const int q1506[] = {
    9, 9, // Number of jobs and machines
    3, 36, 6, 93, 8, 27, 0, 23, 5, 63, 2, 74, 4,  1, 1,  2, 7, 58, 
    2, 33, 7, 14, 8, 65, 6, 97, 0, 54, 1, 26, 4, 39, 5, 53, 3, 47, 
    2, 51, 5, 82, 3, 28, 0, 87, 1, 38, 6, 53, 4, 82, 7, 30, 8, 90, 
    5, 57, 1, 62, 0, 26, 4,  9, 7, 90, 8, 74, 3, 40, 2, 14, 6, 78, 
    0, 84, 7, 71, 3, 20, 5, 60, 6, 51, 4, 73, 2, 93, 1, 95, 8, 96, 
    7, 25, 2, 12, 8, 12, 4, 53, 3, 85, 5, 83, 6, 81, 0, 59, 1, 94, 
    3, 29, 5, 43, 8, 47, 6, 30, 0, 78, 1, 50, 7, 39, 4, 59, 2, 74, 
    8, 84, 2, 88, 1,  6, 0, 96, 4, 81, 7, 55, 5, 21, 6, 26, 3, 82, 
    8, 76, 4, 86, 2, 27, 5, 83, 6, 42, 0, 93, 7, 75, 3, 44, 1,  1
  };
  const int q1507[] = {
    9, 9, // Number of jobs and machines
    2, 36, 7, 80, 6, 88, 1,  2, 0, 98, 8, 70, 3, 70, 4, 73, 5, 59, 
    4, 67, 8, 26, 5, 22, 1,  6, 6, 17, 0,  9, 3, 17, 7, 94, 2, 65, 
    7, 70, 3, 86, 2, 67, 8, 36, 1, 48, 4, 94, 0, 19, 5, 27, 6, 48, 
    7, 69, 3, 59, 5, 55, 4, 11, 8, 48, 6, 83, 0, 68, 2, 75, 1, 68, 
    3,  4, 6, 37, 7, 62, 1, 99, 8, 99, 2, 81, 4, 59, 5, 73, 0, 14, 
    7, 82, 5, 41, 3, 88, 8, 83, 6, 52, 2,  9, 1, 55, 0, 98, 4, 68, 
    3, 79, 8, 50, 1, 22, 5, 57, 4, 24, 0, 92, 7, 44, 6, 80, 2, 99, 
    6,  7, 5, 64, 8, 73, 1, 76, 2, 61, 4, 63, 3, 86, 7, 19, 0, 27, 
    4, 56, 5, 58, 7, 91, 8,  9, 2, 74, 1, 42, 0, 99, 6, 43, 3, 14
  };
  const int q1508[] = {
    9, 9, // Number of jobs and machines
    6, 84, 7, 80, 1, 80, 2, 88, 3, 90, 4, 28, 0, 62, 8, 50, 5, 11, 
    1, 50, 4, 88, 2, 17, 8, 28, 6, 86, 5, 42, 7, 98, 3, 33, 0, 60, 
    6, 85, 2, 34, 5, 72, 1,  5, 8, 90, 7, 52, 3, 55, 4, 64, 0, 80, 
    1, 31, 4,  9, 5, 93, 3, 62, 7, 49, 8, 11, 6, 72, 0, 24, 2,  6, 
    4, 72, 2, 94, 0,  8, 1, 77, 8, 25, 7, 92, 6, 69, 5, 75, 3, 14, 
    8, 17, 7, 68, 4, 83, 3, 73, 6, 49, 1, 20, 2, 19, 5, 74, 0, 90, 
    8, 87, 1, 18, 4, 67, 5, 58, 0, 94, 3, 99, 7,  5, 2, 27, 6, 38, 
    8, 60, 6, 82, 5, 28, 1, 31, 2, 51, 7, 99, 0, 93, 3, 57, 4, 30, 
    6, 66, 1, 80, 0, 88, 8,  9, 2,  1, 7, 87, 4, 41, 5, 18, 3, 56
  };
  const int q1509[] = {
    9, 9, // Number of jobs and machines
    8, 20, 3, 74, 4, 78, 7, 58, 5, 49, 0, 98, 2, 61, 1, 67, 6,  8, 
    5, 12, 6, 76, 7, 27, 1, 39, 4, 77, 2, 20, 8,  2, 0, 57, 3, 94, 
    4,  5, 6,  3, 7, 10, 0, 77, 3, 49, 1, 49, 5, 83, 2, 11, 8, 27, 
    2, 50, 0, 79, 7, 15, 5,  2, 3, 51, 1, 83, 4, 48, 6, 59, 8, 64, 
    2, 54, 3, 57, 8, 49, 6, 42, 4, 73, 7, 40, 5, 97, 1, 39, 0, 19, 
    0, 24, 5, 10, 6, 98, 8, 80, 2, 84, 3, 33, 1, 19, 4, 72, 7, 25, 
    3, 99, 8,  8, 1, 25, 2, 20, 4, 82, 7, 74, 0, 39, 5, 17, 6, 68, 
    7, 81, 1, 81, 2, 30, 8, 11, 0, 35, 3, 27, 4, 55, 6, 49, 5, 20, 
    3, 29, 5, 43, 1, 11, 0, 74, 2, 91, 4, 65, 6, 47, 7, 45, 8, 42
  };
  const int q1510[] = {
    9, 9, // Number of jobs and machines
    1, 32, 2, 68, 8, 10, 0, 63, 3, 23, 5, 60, 7,  6, 4, 80, 6, 31, 
    2,  1, 8,  3, 0, 19, 3, 79, 1, 11, 7,  3, 4, 48, 5,  2, 6,  7, 
    4, 72, 2, 50, 1, 79, 3, 31, 8, 78, 0,  7, 6, 49, 5, 23, 7, 28, 
    8, 77, 3, 23, 1, 16, 6, 65, 4, 85, 7, 73, 5, 38, 2, 94, 0, 40, 
    1, 39, 2, 18, 7, 82, 6,  2, 4, 65, 8, 78, 0,  8, 3, 72, 5, 11, 
    2, 67, 4, 63, 0, 45, 8, 85, 6, 43, 1, 20, 3, 25, 7, 43, 5, 44, 
    2, 50, 3, 43, 7, 78, 6, 80, 8,  2, 4, 23, 0, 30, 1, 54, 5, 82, 
    5, 52, 8, 19, 4,  3, 3, 86, 6, 82, 1, 29, 0, 25, 2, 84, 7, 44, 
    8, 32, 2, 80, 0, 34, 6, 55, 1, 54, 5,  5, 4,  9, 3, 77, 7, 26
  };
  const int q1511[] = {
    9, 9, // Number of jobs and machines
    7, 41, 3, 33, 4, 25, 8, 93, 5, 49, 6, 69, 2, 95, 1, 57, 0, 83, 
    0, 18, 4, 79, 1, 95, 2, 72, 6, 76, 7, 43, 5, 46, 3, 85, 8, 79, 
    0, 75, 8, 71, 7, 46, 2, 19, 3, 45, 6, 40, 4, 47, 1, 53, 5, 28, 
    3, 61, 1, 70, 0, 14, 7, 16, 2, 11, 5, 77, 8, 74, 4, 62, 6, 43, 
    4, 48, 3, 21, 1, 25, 0, 44, 7, 30, 8, 62, 5, 33, 6, 62, 2, 98, 
    0, 12, 4, 53, 2, 59, 6, 70, 1, 68, 5, 76, 8, 85, 7, 87, 3, 81, 
    6, 31, 2, 69, 8, 41, 3, 19, 4, 91, 7, 53, 5, 23, 0,  2, 1, 27, 
    7, 54, 5, 15, 4, 50, 3, 97, 0, 39, 8, 47, 6, 71, 1, 97, 2, 87, 
    2, 70, 8, 77, 0, 12, 6, 24, 7,  2, 1, 84, 5, 71, 3, 60, 4, 76
  };
  const int q1512[] = {
    9, 9, // Number of jobs and machines
    5, 75, 3,  3, 8, 13, 4, 45, 7,  2, 2, 92, 0, 51, 6, 64, 1, 30, 
    0, 86, 6, 79, 8, 31, 7, 16, 2, 60, 4, 40, 3, 33, 5, 53, 1, 87, 
    0, 77, 4, 37, 8, 93, 2, 57, 7, 11, 1, 25, 6, 18, 5,  1, 3, 10, 
    8, 62, 7, 95, 1, 40, 2, 67, 3, 27, 6, 44, 0, 42, 5,  7, 4, 37, 
    5, 12, 1,  7, 2, 90, 0, 52, 3, 84, 8,  5, 4, 86, 7, 38, 6, 52, 
    2, 18, 4, 16, 6, 94, 7,  1, 5, 78, 8, 80, 0, 77, 1, 76, 3, 66, 
    6,  9, 3, 52, 2, 82, 0, 23, 4, 53, 5, 99, 1, 42, 7, 31, 8, 98, 
    1, 46, 3, 76, 6, 48, 5, 53, 0, 16, 7, 18, 2, 17, 4, 52, 8, 88, 
    6, 60, 5, 93, 4, 36, 7, 52, 0,  3, 2, 84, 1, 50, 3, 60, 8, 94
  };
  const int q1513[] = {
    9, 9, // Number of jobs and machines
    5, 44, 0, 81, 8, 90, 2, 46, 4, 98, 3, 99, 1, 20, 7, 90, 6,  2, 
    8, 14, 2, 74, 0, 29, 5, 14, 4, 50, 6, 33, 3, 56, 1, 85, 7, 99, 
    7, 22, 6,  8, 4,  3, 3, 54, 1, 49, 2, 89, 0, 20, 8, 22, 5, 48, 
    2, 99, 4, 46, 6, 12, 3, 87, 5, 70, 7, 85, 8, 71, 0, 64, 1, 89, 
    7, 41, 2, 74, 0, 40, 6, 53, 8, 25, 4, 18, 5, 92, 1, 51, 3, 54, 
    4, 68, 1, 53, 5, 19, 0, 39, 3, 51, 7, 57, 6, 15, 2, 49, 8, 34, 
    2, 44, 4, 63, 8, 63, 6, 29, 0, 36, 1, 32, 3, 63, 7, 38, 5,  6, 
    7, 90, 5, 36, 1, 72, 3, 81, 0, 54, 2, 61, 8, 42, 4, 92, 6, 54, 
    5, 16, 7, 29, 0, 98, 8, 50, 3, 48, 4, 18, 2, 42, 6, 64, 1, 23
  };
  const int q1514[] = {
    9, 9, // Number of jobs and machines
    2, 26, 4, 79, 1, 66, 7, 46, 6, 57, 0, 60, 5, 23, 3, 16, 8, 58, 
    3, 52, 5,  2, 8, 19, 2, 92, 0, 36, 6, 99, 1, 30, 4, 43, 7,  5, 
    4, 51, 0,  2, 2, 98, 5, 10, 6, 34, 8, 14, 3, 67, 1, 81, 7, 47, 
    3, 83, 4, 96, 0, 42, 2,  1, 8, 10, 7, 71, 6, 12, 1, 57, 5, 40, 
    5, 43, 6, 13, 3, 62, 1, 33, 7, 49, 0, 83, 2, 75, 4, 51, 8, 84, 
    4, 56, 6, 35, 0, 11, 1, 73, 3, 34, 2, 32, 8, 36, 5, 43, 7, 35, 
    6, 49, 2, 66, 8, 95, 1, 98, 5, 86, 7, 44, 0, 58, 3, 45, 4, 34, 
    1, 31, 3, 63, 5, 41, 2, 89, 0, 70, 8, 38, 4, 88, 6, 10, 7, 90, 
    6, 48, 8, 68, 4, 41, 5, 33, 2, 50, 1, 65, 0, 38, 7, 73, 3, 89
  };
  const int q1515[] = {
    9, 9, // Number of jobs and machines
    2, 87, 7, 98, 3,  1, 0, 63, 8, 27, 5, 16, 1, 85, 4, 29, 6, 13, 
    2, 58, 5, 29, 0, 62, 7, 97, 4, 63, 6, 16, 3, 90, 8, 29, 1, 50, 
    0, 67, 7, 58, 1, 45, 5, 10, 4, 14, 2, 16, 3, 45, 6, 44, 8, 76, 
    8, 99, 4, 41, 1, 69, 7, 63, 6,  3, 5, 12, 0,  8, 3, 52, 2, 38, 
    5, 94, 8, 69, 6, 47, 3, 18, 1, 18, 2, 24, 4, 18, 0, 19, 7, 19, 
    5, 20, 7, 28, 3, 10, 0, 62, 8, 14, 4, 53, 1, 35, 6, 75, 2, 47, 
    7, 50, 0, 54, 6, 48, 2, 12, 8, 90, 5,  7, 3, 27, 4, 60, 1, 61, 
    5, 89, 1, 57, 8, 25, 3, 35, 7, 39, 2, 85, 0, 25, 6, 30, 4, 51, 
    8, 93, 2, 38, 0, 19, 6, 99, 7, 74, 5, 84, 3, 30, 4, 75, 1, 35
  };
  const int q1516[] = {
    9, 9, // Number of jobs and machines
    6, 98, 3, 58, 7,  2, 0, 89, 5, 99, 4, 78, 2, 35, 1, 78, 8, 90, 
    0, 48, 3,  5, 7, 48, 8, 41, 6, 47, 1, 90, 4, 55, 5, 15, 2, 77, 
    7,  8, 1, 47, 5, 16, 4, 67, 6, 40, 3, 13, 8, 24, 2, 24, 0, 25, 
    6, 85, 7, 31, 0, 91, 2, 91, 4, 58, 8, 74, 1, 99, 3, 43, 5, 98, 
    6, 91, 7, 23, 4, 32, 1, 17, 2, 43, 5,  5, 0, 53, 3, 91, 8, 21, 
    5, 11, 1, 85, 8, 57, 6, 28, 4,  4, 2, 25, 7, 85, 0, 50, 3, 23, 
    1, 77, 4, 78, 7, 18, 3,  7, 5, 81, 6,  9, 2, 57, 0, 48, 8, 44, 
    6, 31, 7,  4, 1, 33, 4, 75, 5, 23, 8, 79, 0, 31, 2, 77, 3,  1, 
    7, 85, 5, 68, 4, 39, 1, 26, 3, 75, 0, 21, 8, 57, 6, 58, 2, 86
  };
  const int q1517[] = {
    9, 9, // Number of jobs and machines
    6, 42, 5, 32, 4, 95, 1, 87, 2, 74, 8, 16, 3, 94, 0, 45, 7, 40, 
    8, 28, 4, 47, 5, 80, 6, 62, 0, 28, 3,  4, 1, 89, 2, 60, 7, 11, 
    3, 63, 8, 61, 7, 82, 6, 60, 5, 51, 2, 99, 4, 15, 1, 73, 0, 74, 
    4, 98, 7, 43, 1, 36, 5, 26, 3, 64, 8, 52, 6, 60, 2, 49, 0,  6, 
    5, 19, 3, 16, 2, 10, 7,  7, 0, 33, 6, 92, 4, 93, 8, 46, 1, 97, 
    5, 38, 7, 24, 2, 38, 3, 25, 4, 36, 1, 22, 6, 86, 0, 19, 8, 14, 
    2, 70, 6, 81, 0, 17, 4, 17, 3, 44, 7, 73, 8, 70, 5, 80, 1, 80, 
    1, 59, 4, 67, 3, 34, 7, 60, 5, 97, 8, 11, 0, 78, 6, 35, 2, 47, 
    6, 19, 1, 28, 4, 92, 3, 88, 2, 46, 5, 56, 0, 42, 8, 71, 7,  9
  };
  const int q1518[] = {
    9, 9, // Number of jobs and machines
    4, 21, 5, 89, 7, 67, 8, 24, 2, 29, 1, 22, 3, 15, 0, 68, 6, 45, 
    8, 14, 6, 16, 0, 23, 4, 81, 5, 57, 7, 43, 1, 61, 3, 59, 2, 35, 
    5, 97, 4, 90, 6, 98, 2, 89, 8, 84, 7, 62, 3, 98, 1, 13, 0, 52, 
    5, 87, 2, 38, 6, 46, 4, 61, 3, 80, 7, 40, 1, 64, 8, 42, 0, 51, 
    0, 98, 3, 24, 8, 45, 6, 70, 4, 80, 1, 58, 2, 71, 5, 19, 7, 39, 
    3, 56, 0, 78, 2, 21, 7, 36, 4,  8, 5, 75, 8, 43, 6, 92, 1, 56, 
    5, 81, 7, 77, 6, 63, 2, 54, 0,  3, 4, 98, 8,  2, 3, 45, 1, 93, 
    5, 96, 0, 92, 2,  7, 1, 64, 4, 41, 6, 53, 8, 38, 3, 12, 7, 57, 
    7, 58, 1, 35, 4, 24, 5, 50, 6, 93, 3, 48, 0, 52, 8, 12, 2, 77
  };
  const int q1519[] = {
    9, 9, // Number of jobs and machines
    1, 46, 4, 52, 0, 39, 5, 72, 6, 49, 3, 33, 2, 96, 8, 88, 7,  5, 
    7, 76, 3, 98, 1,  2, 6, 69, 4, 43, 2, 77, 8, 19, 5, 18, 0, 21, 
    5, 19, 8, 79, 4,  8, 3, 15, 2, 85, 0, 10, 1, 80, 7, 18, 6, 36, 
    4, 89, 1, 73, 2, 58, 8,  7, 0, 84, 5, 55, 3, 92, 6, 58, 7,  4, 
    7, 18, 1, 29, 8, 93, 2, 17, 5, 80, 3, 79, 4,  3, 0, 42, 6, 83, 
    2, 92, 0, 89, 7, 73, 3, 48, 8, 39, 4, 16, 6, 79, 5, 30, 1, 19, 
    2, 67, 7, 45, 1, 97, 4, 98, 3, 87, 0, 78, 6, 69, 5, 87, 8, 56, 
    7, 61, 4, 50, 8, 47, 6, 88, 0, 14, 1, 95, 2, 87, 5, 45, 3, 10, 
    5, 49, 3, 77, 6, 10, 7, 60, 8,  4, 1, 53, 4, 57, 0, 79, 2, 41
  };
  const int q1520[] = {
    9, 9, // Number of jobs and machines
    4, 90, 6, 65, 1, 42, 8, 87, 2, 57, 7, 85, 0, 54, 5, 83, 3, 51, 
    2, 33, 4, 93, 3, 59, 8, 50, 1, 57, 0, 55, 5, 20, 6, 75, 7, 35, 
    4, 35, 6, 35, 7, 93, 5, 82, 2, 76, 8, 86, 0, 58, 1, 68, 3, 62, 
    1, 69, 2, 44, 7, 31, 0, 53, 3, 32, 5,  5, 4, 17, 8, 82, 6, 98, 
    8, 65, 2, 54, 0, 20, 6, 75, 5, 20, 3, 39, 1, 46, 7, 72, 4, 93, 
    4,  2, 8, 94, 2, 76, 5, 87, 0, 60, 3, 61, 1, 63, 6, 93, 7, 57, 
    8, 19, 4, 33, 2, 42, 7, 89, 6, 70, 5, 86, 3, 97, 0, 78, 1, 92, 
    6, 60, 5, 45, 8, 86, 3, 73, 7, 78, 4, 60, 0, 46, 1, 99, 2, 33, 
    3, 12, 2,  6, 5, 19, 1, 69, 6, 80, 7, 17, 4, 39, 0,  6, 8, 57
  };
  const int q1521[] = {
    9, 9, // Number of jobs and machines
    0, 19, 2, 41, 8, 82, 5, 51, 1,  8, 3, 86, 6, 91, 7, 46, 4, 32, 
    5, 99, 3, 76, 1, 72, 4, 16, 7, 22, 0, 88, 8, 60, 2, 99, 6,  6, 
    5, 49, 0, 68, 7, 35, 4, 78, 3, 78, 2, 37, 8, 30, 1,  7, 6, 23, 
    1, 97, 8, 13, 5, 74, 6, 43, 2, 67, 0, 66, 7, 42, 3, 56, 4, 37, 
    6, 39, 2, 85, 0, 12, 1, 94, 5, 39, 8,  4, 4, 94, 7, 42, 3, 28, 
    7,  9, 0, 26, 6, 97, 8, 70, 4, 84, 5, 32, 1, 56, 3, 15, 2, 52, 
    8,  7, 0, 55, 4, 75, 7,  2, 5, 82, 3, 68, 1, 84, 2, 57, 6, 69, 
    1, 37, 0, 68, 8, 46, 2, 24, 5, 98, 7, 72, 3, 32, 6, 57, 4, 90, 
    8, 67, 1, 71, 6, 36, 7, 44, 2, 24, 0, 98, 4, 97, 5, 81, 3, 24
  };
  const int q1522[] = {
    9, 9, // Number of jobs and machines
    2, 44, 6, 72, 3, 47, 0, 97, 1, 86, 7, 15, 8, 81, 4, 20, 5, 94, 
    8, 55, 1, 30, 6, 99, 4, 56, 5, 72, 2, 27, 7, 27, 0, 13, 3, 66, 
    0, 69, 1, 20, 2, 58, 5, 46, 3, 84, 4,  2, 6, 74, 7, 80, 8,  7, 
    2, 86, 0, 67, 7, 62, 5, 40, 8, 49, 3,  8, 1, 82, 4, 89, 6,  8, 
    0, 50, 6,  9, 8, 78, 3, 68, 5, 50, 4, 32, 7, 37, 2, 52, 1, 11, 
    5, 88, 3, 29, 6, 62, 4,  9, 8, 76, 7, 14, 0, 61, 1, 64, 2, 20, 
    3, 68, 1, 18, 7, 29, 6, 85, 8, 37, 2, 82, 4, 52, 5, 49, 0, 67, 
    7, 32, 5, 71, 3, 47, 4,  6, 6, 96, 0, 50, 1, 28, 8, 44, 2, 84, 
    3, 17, 0, 82, 1, 95, 7, 37, 2,  3, 8, 15, 5,  6, 6, 24, 4, 85
  };
  const int q1523[] = {
    9, 9, // Number of jobs and machines
    5, 76, 0, 55, 1, 14, 2, 52, 8, 67, 3, 70, 6,  3, 7, 38, 4, 86, 
    3, 17, 0, 29, 8, 49, 5, 63, 1, 95, 4, 71, 6,  3, 2, 27, 7, 79, 
    1, 93, 3, 41, 7, 89, 5, 35, 4, 99, 8, 98, 0, 63, 6, 80, 2, 55, 
    0, 42, 1, 31, 3, 61, 4, 76, 2, 87, 6, 42, 8, 85, 7,  4, 5, 22, 
    2, 98, 1, 60, 5, 36, 3, 83, 6, 37, 0, 72, 8, 16, 7, 67, 4, 91, 
    5, 39, 2, 10, 8, 78, 7,  9, 6, 96, 3, 38, 1, 53, 0, 26, 4, 93, 
    0, 18, 5, 91, 7, 86, 6, 36, 2, 87, 3, 90, 8, 72, 1, 71, 4, 87, 
    3, 77, 8, 14, 7, 31, 0, 61, 4, 33, 1, 13, 5, 90, 6, 10, 2, 88, 
    7, 65, 3, 95, 8, 81, 2, 93, 6, 74, 4, 81, 5, 13, 0, 43, 1, 83
  };
  const int q1524[] = {
    9, 9, // Number of jobs and machines
    3, 97, 5, 62, 8, 66, 0, 86, 1, 81, 4, 24, 2, 37, 6, 95, 7, 68, 
    1, 98, 2, 73, 8, 76, 6, 51, 3, 40, 4, 75, 5, 45, 0, 76, 7, 84, 
    4, 46, 8, 35, 5,  3, 1, 29, 7, 39, 0, 83, 3, 26, 2, 98, 6, 16, 
    3, 39, 2, 66, 7, 29, 6, 23, 1, 88, 5, 54, 8, 46, 4, 30, 0, 80, 
    1, 59, 0, 70, 7, 48, 4, 99, 3, 60, 8, 70, 6, 44, 2, 87, 5, 30, 
    6, 40, 5, 79, 4,  4, 8, 24, 0, 70, 7, 67, 1, 42, 2, 46, 3, 61, 
    6, 19, 5, 84, 4, 47, 7, 52, 8,  7, 1, 88, 3, 96, 2, 86, 0,  8, 
    4,  1, 5, 27, 2, 22, 6, 36, 7, 29, 3, 34, 1, 72, 8, 37, 0, 19, 
    5,  1, 1, 91, 3, 45, 4, 45, 6,  1, 7, 31, 2, 86, 0, 30, 8, 62
  };
  const int q1525[] = {
    9, 9, // Number of jobs and machines
    4, 42, 3,  7, 1, 61, 8, 85, 0, 46, 5, 37, 7, 77, 2, 44, 6, 97, 
    0, 71, 6, 21, 7, 68, 5, 94, 4, 83, 1, 44, 8, 11, 3, 42, 2, 31, 
    1,  2, 4, 97, 3, 81, 8, 81, 0, 56, 6, 59, 7, 72, 2,  4, 5, 90, 
    0, 23, 5, 49, 1, 85, 6,  2, 4, 22, 8, 99, 2, 61, 7, 48, 3, 95, 
    2, 94, 1, 81, 0, 50, 7, 43, 8, 71, 6, 53, 4, 80, 3, 33, 5, 54, 
    6, 30, 0, 36, 2, 63, 3, 11, 7, 93, 8, 20, 4, 50, 5,  6, 1, 57, 
    3, 31, 7, 29, 2, 84, 6, 61, 5,  9, 8, 14, 1, 48, 4, 27, 0, 45, 
    8, 44, 7, 13, 4, 99, 0, 37, 3, 68, 1, 24, 5, 15, 6, 72, 2,  9, 
    6, 38, 7, 66, 3, 87, 8, 71, 4, 35, 2, 22, 1, 66, 0, 58, 5, 39
  };
  const int q1526[] = {
    9, 9, // Number of jobs and machines
    8, 64, 4, 57, 0,  9, 3, 50, 2, 99, 1, 29, 6, 19, 5, 82, 7, 34, 
    8, 26, 6, 30, 2, 21, 4, 53, 1, 75, 5, 76, 7, 49, 3, 50, 0, 25, 
    6, 92, 0,  7, 8, 36, 3, 99, 1, 75, 5, 53, 2, 11, 7, 55, 4, 62, 
    1, 31, 5, 40, 2, 33, 3, 81, 7, 54, 4, 28, 8, 10, 6,  8, 0, 29, 
    7, 88, 2, 11, 1, 51, 0, 85, 4, 57, 6, 11, 3, 38, 5, 38, 8, 49, 
    4, 77, 7, 25, 5,  1, 2, 14, 8, 68, 1, 82, 3, 92, 0, 58, 6,  6, 
    2, 71, 7, 69, 5, 89, 6, 27, 3, 96, 8, 76, 4, 90, 0, 85, 1, 22, 
    4, 87, 5, 16, 0, 32, 6, 57, 1, 46, 7, 53, 2, 66, 3, 32, 8, 47, 
    3, 65, 1, 28, 8, 99, 2,  7, 4, 70, 0, 91, 5, 45, 7, 17, 6, 90
  };
  const int q1527[] = {
    9, 9, // Number of jobs and machines
    2, 72, 4, 12, 6, 14, 1, 51, 7, 78, 5, 37, 3, 62, 0, 30, 8, 43, 
    0,  3, 5, 95, 2, 95, 1,  2, 8, 38, 6, 52, 4, 85, 7, 73, 3, 47, 
    6, 90, 8, 16, 7, 45, 5,  7, 1, 96, 3, 31, 0, 73, 2, 51, 4, 93, 
    6, 22, 3, 64, 7, 14, 0, 42, 2, 62, 4, 99, 1, 30, 5, 70, 8, 84, 
    5,  2, 8, 97, 6, 34, 4,  8, 0,  1, 1,  3, 7, 43, 2, 36, 3,  6, 
    6, 35, 1, 91, 5,  9, 0,  2, 2, 78, 4, 46, 7, 38, 8, 39, 3, 60, 
    3, 44, 8, 64, 6, 39, 5, 63, 0, 16, 2, 17, 4, 45, 7,  6, 1, 50, 
    0, 72, 3, 85, 4, 65, 1, 10, 7, 41, 8,  6, 2, 15, 5, 76, 6, 76, 
    3,  7, 2, 70, 7, 54, 5, 71, 0, 87, 1, 21, 6, 92, 4, 27, 8, 72
  };
  const int q1528[] = {
    9, 9, // Number of jobs and machines
    7, 44, 6, 33, 0,  6, 2, 59, 1, 42, 3, 56, 4, 90, 8, 23, 5, 34, 
    0, 32, 3, 91, 6, 86, 4,  6, 5, 47, 7,  1, 8, 69, 2, 41, 1, 90, 
    0, 38, 5, 30, 2, 32, 8, 51, 4, 62, 7, 86, 3, 63, 6, 64, 1, 82, 
    4, 21, 5, 12, 1, 27, 0, 17, 8,  5, 2, 98, 3, 38, 7, 14, 6, 49, 
    1, 90, 8,  3, 7, 58, 0, 96, 3, 98, 4, 44, 6, 60, 5, 87, 2, 11, 
    1,  3, 7, 30, 4, 21, 0, 47, 6, 50, 8, 77, 5, 82, 3, 93, 2, 29, 
    1, 54, 6, 71, 7, 19, 8, 44, 0, 38, 5, 97, 3,  2, 4, 46, 2, 62, 
    4, 91, 7, 48, 6, 44, 8, 28, 5, 32, 2, 58, 3, 80, 1,  6, 0, 83, 
    2, 29, 5, 20, 3, 51, 6, 40, 4, 66, 0, 88, 8, 56, 7, 23, 1, 52
  };
  const int q1529[] = {
    9, 9, // Number of jobs and machines
    5, 98, 2, 51, 7, 69, 0, 10, 8, 99, 1, 54, 4, 97, 6, 67, 3, 69, 
    1, 60, 6, 22, 8, 12, 3, 60, 0, 74, 4, 11, 7, 67, 5, 30, 2,  2, 
    4,  3, 6, 63, 5, 72, 8, 27, 2,  8, 3, 66, 7, 87, 0, 65, 1, 26, 
    7, 77, 4, 92, 1, 14, 3,  9, 0, 82, 2,  9, 6, 64, 5, 10, 8, 94, 
    8,  4, 3, 38, 2, 65, 6, 31, 7, 57, 1, 96, 5, 60, 4, 81, 0, 43, 
    0, 92, 1, 49, 2, 68, 4, 21, 8, 53, 5, 62, 3, 21, 6, 13, 7, 11, 
    3, 97, 6, 91, 4, 28, 0, 59, 5, 60, 7, 43, 2, 63, 8, 63, 1, 10, 
    3, 19, 7,  9, 4, 63, 8, 44, 0, 55, 6, 36, 1, 15, 2, 84, 5, 84, 
    0,  6, 2,  5, 5, 87, 6, 17, 3, 66, 4, 84, 1, 26, 8, 98, 7, 38
  };
  const int q1530[] = {
    9, 9, // Number of jobs and machines
    8, 24, 2, 18, 7, 41, 5, 22, 0,  8, 3, 32, 6, 82, 4, 27, 1, 12, 
    3,  2, 8, 67, 5, 11, 1, 26, 6, 65, 4, 89, 2, 66, 0, 99, 7, 73, 
    4, 25, 5,  5, 1,  7, 0, 16, 2, 18, 8, 89, 3, 29, 6, 97, 7, 52, 
    0, 29, 1, 37, 7, 45, 8, 77, 2, 36, 3, 72, 6, 40, 5, 41, 4,  1, 
    5, 51, 0, 38, 8, 51, 6, 68, 3, 55, 1, 99, 7, 14, 2, 29, 4, 66, 
    0, 10, 5, 10, 8, 23, 1, 40, 3, 76, 6, 21, 7, 27, 4, 84, 2, 72, 
    8, 67, 5, 39, 3, 11, 4, 25, 2, 30, 7, 66, 1, 34, 0, 80, 6, 78, 
    2, 87, 6, 57, 4, 18, 0, 99, 1, 47, 7, 99, 3, 83, 8, 34, 5, 23, 
    1, 62, 7,  5, 0, 12, 5, 25, 8,  6, 2, 75, 6, 96, 4, 22, 3, 34
  };
  const int q1531[] = {
    9, 9, // Number of jobs and machines
    6, 71, 4,  5, 0, 20, 5, 33, 7, 65, 8,  7, 3, 30, 1, 51, 2, 90, 
    1, 86, 5, 43, 2, 28, 7, 77, 4, 30, 6, 67, 0, 95, 8, 89, 3, 55, 
    5, 73, 8, 49, 0, 26, 2, 54, 6, 37, 7, 22, 4, 83, 1, 89, 3, 22, 
    5, 10, 7, 22, 3, 96, 6, 37, 1, 51, 2, 76, 4, 94, 0, 74, 8,  9, 
    4, 75, 1, 74, 0, 93, 7, 28, 8, 22, 3, 91, 5, 55, 2, 56, 6, 55, 
    0, 85, 2, 42, 1, 69, 8, 74, 7, 21, 6, 92, 4, 53, 5, 39, 3, 41, 
    2, 63, 3, 25, 6, 94, 5, 80, 0, 92, 1, 91, 8,  7, 4, 51, 7, 20, 
    3, 22, 6,  9, 8, 16, 5, 23, 0, 37, 2, 40, 7, 48, 4, 43, 1, 78, 
    2, 65, 8, 87, 7, 60, 0, 19, 3, 14, 5, 20, 6, 87, 4, 89, 1, 36
  };
  const int q1532[] = {
    9, 9, // Number of jobs and machines
    5, 61, 6, 80, 3, 90, 2, 19, 8, 54, 0, 12, 1, 75, 7,  7, 4, 13, 
    5,  8, 7, 58, 0, 62, 2, 60, 8,  1, 6,  1, 3, 38, 1, 46, 4, 92, 
    2, 97, 7, 14, 3, 52, 4, 63, 5, 98, 1, 18, 6, 64, 0, 91, 8, 79, 
    2, 64, 0, 39, 7, 14, 3, 20, 4, 87, 6, 82, 8, 89, 1, 67, 5, 56, 
    0, 73, 7, 13, 1, 75, 4, 32, 5, 76, 2, 89, 8, 47, 6, 25, 3, 45, 
    2, 57, 3, 81, 0, 83, 6,  5, 7, 99, 4,  7, 1, 69, 8, 62, 5, 53, 
    3, 22, 0, 84, 7, 26, 6, 55, 8, 43, 2, 80, 5, 75, 1,  8, 4, 92, 
    2, 78, 7, 10, 6, 80, 8, 72, 1, 89, 4, 35, 3, 43, 0, 78, 5, 95, 
    5, 71, 4, 26, 6, 86, 7, 84, 8, 93, 1, 45, 3, 75, 0, 41, 2, 67
  };
  const int q1533[] = {
    9, 9, // Number of jobs and machines
    3, 29, 6, 42, 2, 83, 5, 33, 8, 98, 0, 83, 1, 60, 7, 16, 4, 69, 
    4, 68, 6, 31, 2, 41, 1, 63, 7, 65, 0, 57, 3,  3, 8, 45, 5, 20, 
    1, 72, 2, 55, 8, 79, 3, 19, 6, 52, 0, 41, 5, 83, 7, 28, 4, 66, 
    8, 66, 0, 99, 3, 57, 2, 81, 7, 12, 4, 38, 1, 87, 6, 34, 5, 19, 
    0, 91, 8, 62, 1, 38, 2, 71, 5, 21, 7, 19, 4, 67, 3, 31, 6, 38, 
    4, 90, 1, 79, 3, 13, 8, 51, 6, 73, 7, 75, 2, 15, 5, 98, 0, 56, 
    1, 13, 7, 59, 3, 70, 8, 55, 5, 96, 4, 50, 6, 67, 2,  4, 0, 25, 
    6, 89, 5, 16, 1, 75, 2, 14, 7, 78, 3, 29, 4, 13, 8,  8, 0, 28, 
    6, 81, 0, 90, 4, 28, 5, 21, 7, 16, 1, 98, 3, 70, 8,  9, 2, 63
  };
  const int q1534[] = {
    9, 9, // Number of jobs and machines
    7,  7, 4, 35, 0, 83, 6, 47, 8, 48, 5, 69, 2, 72, 1, 74, 3, 14, 
    2, 16, 0, 30, 5, 24, 3, 27, 6, 60, 1, 69, 8, 98, 4, 65, 7, 81, 
    7,  8, 2,  9, 1, 99, 4, 78, 8, 37, 5, 15, 0, 79, 3, 70, 6, 61, 
    2, 37, 8, 72, 6, 16, 4, 53, 3, 51, 5, 63, 7, 20, 1, 83, 0, 77, 
    2, 81, 6, 45, 4, 34, 3, 99, 0, 29, 1, 98, 5, 32, 8, 61, 7,  7, 
    7, 63, 0, 85, 8, 64, 4,  1, 2, 45, 6, 65, 1, 28, 3, 52, 5, 78, 
    0, 18, 4, 20, 3, 73, 5, 89, 1, 91, 2, 92, 8, 30, 7, 44, 6, 14, 
    7, 74, 3, 71, 4, 75, 2, 73, 0, 57, 8, 24, 5, 18, 6, 99, 1, 20, 
    1, 33, 3, 37, 5, 76, 2, 54, 7, 75, 6, 96, 8, 58, 0, 86, 4, 75
  };
  const int q1535[] = {
    9, 9, // Number of jobs and machines
    7, 81, 8, 44, 0, 76, 4, 29, 1, 64, 6,  3, 5, 48, 3, 52, 2,  2, 
    5, 90, 8, 12, 4, 33, 6, 46, 7,  9, 2, 66, 1, 80, 3, 41, 0, 63, 
    2, 12, 6, 23, 4, 39, 0, 14, 7, 81, 1, 72, 3, 24, 5, 13, 8, 75, 
    3, 45, 7, 34, 4,  9, 6, 41, 8, 40, 0, 76, 5, 24, 1, 67, 2, 87, 
    1, 78, 4, 42, 2, 58, 6, 74, 3, 19, 7, 10, 0, 55, 8, 86, 5, 98, 
    4, 10, 7, 41, 8, 48, 0, 72, 2, 77, 1, 77, 3, 73, 5, 92, 6, 54, 
    1, 77, 4, 45, 3, 76, 8,  7, 0, 70, 5, 98, 2, 64, 7, 10, 6,  3, 
    3, 66, 1, 96, 4, 45, 6, 45, 2, 82, 8, 17, 7, 68, 0, 27, 5, 80, 
    1, 86, 2, 39, 0, 62, 7, 32, 4, 40, 8, 63, 3, 91, 5, 11, 6, 60
  };
  const int q1536[] = {
    9, 9, // Number of jobs and machines
    4, 67, 2, 42, 8, 51, 7,  1, 3, 98, 0, 92, 1, 26, 6, 47, 5, 70, 
    8, 38, 6, 82, 2, 54, 4, 38, 5,  8, 1, 81, 3, 60, 7,  1, 0, 58, 
    3, 84, 5, 71, 7, 32, 8, 31, 6, 36, 4, 61, 1, 51, 2, 66, 0, 98, 
    2, 76, 1, 98, 7, 79, 8, 19, 0, 14, 4, 59, 3, 47, 6,  8, 5, 57, 
    4,  5, 8,  1, 5, 51, 6,  3, 2, 63, 3, 20, 1,  1, 0, 32, 7, 38, 
    1, 28, 7, 19, 6, 87, 3, 11, 4, 51, 2, 53, 0, 44, 5, 98, 8,  1, 
    2, 11, 1, 68, 4, 67, 8, 12, 6, 41, 5, 36, 3, 62, 0, 97, 7, 39, 
    5, 12, 6,  6, 1, 23, 4, 77, 0, 43, 3, 70, 8, 58, 7, 64, 2, 26, 
    4, 65, 3, 28, 7, 83, 1, 77, 6, 75, 5, 61, 8, 82, 2,  3, 0, 18
  };
  const int q1537[] = {
    9, 9, // Number of jobs and machines
    2,  4, 5, 10, 1, 12, 7,  3, 6, 32, 4, 39, 0, 65, 8,  1, 3, 21, 
    5, 27, 0, 67, 4, 84, 2, 75, 6, 19, 1, 13, 3, 36, 8, 23, 7, 87, 
    7, 31, 8, 99, 2, 58, 0,  7, 3, 31, 6, 70, 4, 75, 1, 60, 5, 82, 
    8, 66, 3, 31, 4, 31, 7, 17, 0, 59, 5, 64, 2, 57, 6, 26, 1, 81, 
    3,  1, 7, 78, 5, 13, 2, 14, 8,  4, 6, 67, 4, 29, 1, 51, 0, 22, 
    2, 51, 7, 87, 8, 85, 6, 81, 5, 88, 4, 83, 0,  4, 3, 29, 1, 18, 
    4,  5, 6, 69, 5, 52, 2, 40, 1, 13, 3, 57, 0, 15, 7, 89, 8, 76, 
    1, 35, 0, 31, 4, 19, 6, 94, 5, 72, 8, 76, 2, 41, 3, 55, 7, 80, 
    2,  5, 8, 76, 6, 52, 1, 61, 0, 73, 3, 83, 5, 98, 7, 91, 4,  7
  };
  const int q1538[] = {
    9, 9, // Number of jobs and machines
    5, 29, 8, 19, 3, 28, 6, 66, 2, 99, 7, 47, 0, 62, 4, 31, 1, 52, 
    3, 77, 1, 29, 4, 99, 0, 73, 7, 21, 8, 65, 6, 14, 5, 67, 2, 17, 
    3, 69, 5,  2, 1, 46, 6, 78, 2, 49, 8, 71, 0, 66, 4, 85, 7, 31, 
    4, 24, 3, 19, 8, 68, 6, 38, 5, 69, 7, 89, 2, 72, 0, 92, 1, 60, 
    3, 52, 1, 40, 8, 19, 2, 94, 0, 40, 6, 41, 5, 12, 7, 12, 4, 30, 
    3, 93, 0, 60, 7, 87, 6, 34, 4, 85, 5, 51, 1, 15, 2, 34, 8, 64, 
    5, 60, 2,  2, 8, 21, 7, 63, 3, 35, 6,  7, 0, 93, 1, 98, 4, 78, 
    4, 75, 8, 93, 3, 58, 6, 42, 0, 73, 5, 76, 7, 77, 2, 34, 1, 54, 
    2, 42, 3, 53, 6, 77, 5, 33, 8, 66, 7,  1, 1, 84, 0, 50, 4,  5
  };
  const int q1539[] = {
    9, 9, // Number of jobs and machines
    8, 76, 5,  7, 0, 77, 7, 46, 6, 30, 2, 28, 4, 66, 3, 50, 1, 42, 
    1, 99, 3, 87, 4, 35, 2, 22, 0,  1, 7, 40, 6, 83, 5, 80, 8, 26, 
    0, 73, 8, 93, 3, 55, 6, 50, 5, 92, 2, 77, 4, 50, 1, 13, 7, 29, 
    6, 81, 3, 85, 4, 33, 0, 75, 8, 32, 5, 91, 7, 95, 1, 37, 2, 27, 
    6, 55, 2, 35, 3, 61, 7, 82, 4, 19, 0, 11, 8, 17, 5, 75, 1, 46, 
    6, 76, 2, 16, 7, 53, 1, 82, 0, 20, 5, 79, 3,  2, 8, 75, 4, 12, 
    2, 11, 7, 24, 1, 68, 5, 89, 3, 19, 6, 79, 8, 45, 4, 86, 0, 23, 
    4, 86, 8,  5, 7, 84, 2, 91, 0, 73, 3, 51, 1, 35, 6, 25, 5, 73, 
    4, 55, 1, 41, 5, 43, 2, 39, 6, 78, 3, 93, 8, 89, 0, 74, 7, 92
  };
  const int q1540[] = {
    9, 9, // Number of jobs and machines
    8, 25, 1, 61, 6, 88, 4, 75, 7, 48, 3, 49, 2, 76, 0, 90, 5,  9, 
    0, 46, 5, 25, 6, 21, 2, 55, 8, 81, 3, 65, 1, 17, 4, 15, 7, 61, 
    1, 84, 3, 65, 7, 34, 8, 11, 4, 29, 6, 38, 0, 81, 2, 98, 5, 43, 
    1, 65, 4, 60, 8, 29, 5, 57, 3, 12, 2, 26, 7, 67, 0, 59, 6, 40, 
    4, 79, 5, 16, 0, 29, 3, 75, 2, 17, 6, 59, 1, 54, 8,  4, 7, 99, 
    8, 35, 4, 84, 6, 72, 0, 19, 2, 30, 3, 77, 7, 94, 1, 39, 5, 34, 
    3, 81, 5, 16, 2, 41, 4, 64, 8, 87, 1, 60, 7, 75, 0, 56, 6, 68, 
    6, 62, 0, 82, 4, 29, 1, 10, 8, 60, 3, 94, 5, 66, 7, 65, 2, 25, 
    1, 39, 4, 91, 5, 68, 2, 69, 0, 61, 7, 21, 8, 85, 6, 64, 3, 52
  };
  const int q1541[] = {
    9, 9, // Number of jobs and machines
    3, 71, 0, 77, 2, 38, 5,  5, 8, 58, 4, 20, 6, 13, 7, 15, 1, 66, 
    1, 48, 4, 84, 2, 41, 0, 34, 8, 89, 7, 54, 5, 99, 3, 38, 6, 17, 
    4, 69, 5,  6, 0,  4, 8, 65, 2, 55, 1, 52, 6, 47, 3, 15, 7, 52, 
    5, 66, 2, 77, 0, 85, 6, 12, 3, 10, 1, 45, 4,  8, 8, 85, 7, 21, 
    3, 66, 5, 26, 6, 89, 0,  5, 1,  6, 7, 55, 8, 79, 4, 89, 2, 43, 
    0, 34, 7, 30, 1, 19, 8, 86, 6, 52, 2, 99, 3,  9, 4, 40, 5, 65, 
    5, 71, 4, 11, 7, 19, 1, 95, 2, 63, 6, 20, 3,  2, 0, 56, 8, 80, 
    2, 48, 0, 80, 5, 85, 6, 37, 7, 49, 4, 38, 8,  7, 3, 42, 1,  2, 
    8, 45, 7, 43, 5, 50, 3, 48, 1, 32, 4, 83, 0, 37, 6, 82, 2, 67
  };
  const int q1542[] = {
    9, 9, // Number of jobs and machines
    6, 94, 4, 91, 2, 80, 1,  3, 7, 22, 8, 69, 5, 98, 3, 84, 0, 45, 
    2, 39, 5, 94, 7, 95, 8, 73, 3, 12, 6, 20, 4, 87, 1, 64, 0, 58, 
    7, 26, 5, 31, 6, 28, 8, 70, 4, 36, 2, 28, 0, 16, 1, 75, 3, 37, 
    0, 63, 5, 12, 3, 50, 8, 75, 4, 17, 7, 94, 6, 63, 2, 69, 1, 77, 
    7, 84, 4, 64, 6, 85, 8, 81, 1, 30, 5, 96, 0,  4, 2, 82, 3, 87, 
    3, 85, 5, 68, 4,  9, 7, 61, 6, 67, 0, 85, 1, 98, 2, 21, 8, 83, 
    0, 64, 8, 50, 5, 42, 1, 18, 2, 36, 6, 75, 4, 19, 3, 30, 7, 60, 
    8,  8, 1, 69, 2, 95, 0, 46, 6, 60, 5, 17, 7, 18, 3, 68, 4, 36, 
    4, 90, 2, 88, 0, 37, 3, 13, 5, 83, 6, 72, 7, 88, 1, 28, 8, 77
  };
  const int q1543[] = {
    9, 9, // Number of jobs and machines
    6, 28, 5, 17, 7, 53, 4, 83, 1,  4, 2, 10, 3, 22, 8, 99, 0,  9, 
    5, 29, 0,  1, 4, 15, 1,  3, 2, 98, 8, 48, 6, 10, 7, 81, 3, 82, 
    4, 89, 7, 74, 6, 56, 5, 28, 3,  7, 2, 14, 1, 57, 0,  5, 8, 77, 
    7, 22, 4, 31, 2, 93, 6, 35, 0, 52, 3, 46, 1, 82, 5,  2, 8, 79, 
    1, 60, 5, 65, 0, 42, 4, 36, 8, 30, 2, 85, 3, 89, 6, 99, 7,  2, 
    3, 24, 2, 35, 6,  1, 4, 82, 7, 98, 1, 89, 0, 36, 5, 11, 8, 37, 
    5, 56, 0, 64, 2, 99, 6, 79, 3, 42, 1, 36, 7, 81, 8, 65, 4, 39, 
    7, 83, 3, 55, 4, 84, 6,  5, 1, 91, 8, 80, 0, 46, 5, 43, 2, 38, 
    4, 40, 7,  2, 1,  7, 6, 92, 3, 90, 8, 46, 0, 44, 2,  1, 5, 30
  };
  const int q1544[] = {
    9, 9, // Number of jobs and machines
    2, 23, 5, 79, 7, 50, 4, 63, 1, 69, 0, 78, 6, 56, 8, 37, 3, 14, 
    8, 28, 5, 75, 0, 29, 1, 94, 2, 62, 4, 79, 7,  3, 6, 72, 3, 55, 
    3, 97, 8, 59, 6, 64, 4, 72, 5, 66, 1, 49, 2, 82, 0, 85, 7,  3, 
    7, 90, 6, 47, 2, 14, 0, 16, 8, 67, 5, 97, 3, 89, 4, 58, 1,  9, 
    5, 96, 7, 93, 1, 89, 2, 43, 0, 52, 4, 76, 6,  8, 3,  6, 8, 67, 
    7,  4, 8, 96, 0, 15, 3, 17, 2, 70, 4, 68, 1, 34, 5, 27, 6, 75, 
    1, 48, 4,  9, 3, 24, 6, 33, 8, 16, 7, 82, 5, 83, 2, 40, 0, 15, 
    1, 65, 4, 40, 6, 69, 8, 40, 3, 97, 2,  1, 0, 44, 7, 25, 5, 19, 
    4, 73, 3, 97, 1, 40, 2, 91, 6, 57, 5, 70, 7, 12, 0, 25, 8, 85
  };
  const int q1545[] = {
    9, 9, // Number of jobs and machines
    8, 65, 4, 65, 6, 83, 5,  9, 2, 48, 3, 90, 7, 16, 0, 51, 1,  2, 
    0, 90, 5,  5, 6, 97, 4, 90, 2, 34, 8, 76, 7, 46, 1,  8, 3, 28, 
    6, 54, 1, 95, 0, 77, 8, 65, 3, 41, 7, 87, 2, 68, 4, 82, 5,  4, 
    0, 95, 7, 76, 8, 76, 4, 61, 3, 14, 5, 41, 1, 34, 2, 75, 6, 97, 
    8, 30, 4, 70, 2, 53, 5, 96, 3, 60, 1, 19, 7, 97, 6, 66, 0, 42, 
    0, 13, 3, 54, 6, 39, 1, 55, 7, 10, 8, 40, 5, 26, 2, 69, 4, 71, 
    7, 14, 3, 92, 5, 69, 0, 18, 1, 90, 8, 37, 6, 75, 4, 20, 2, 92, 
    0, 97, 4, 42, 6, 68, 7, 17, 5, 65, 1, 61, 2, 46, 8, 34, 3, 89, 
    0, 42, 8, 85, 4, 82, 3, 46, 7, 64, 5, 68, 2, 40, 1, 57, 6, 99
  };
  const int q1546[] = {
    9, 9, // Number of jobs and machines
    2, 96, 7, 42, 5, 99, 3, 15, 4, 58, 1, 41, 6, 63, 8, 24, 0, 51, 
    8, 87, 7, 50, 3, 60, 6, 91, 2, 47, 5, 17, 1, 41, 0,  1, 4, 99, 
    2, 94, 3, 25, 0, 76, 4, 93, 7, 35, 5, 20, 1, 89, 6, 35, 8, 72, 
    5, 86, 4, 20, 1, 32, 0, 69, 3, 67, 2, 20, 8, 20, 6, 14, 7, 92, 
    3, 63, 5, 77, 4, 61, 7, 59, 2, 65, 6, 97, 0, 35, 1,  4, 8, 28, 
    4, 83, 7, 12, 3, 85, 8, 59, 2, 87, 6, 76, 1, 18, 0, 73, 5, 86, 
    4, 33, 3, 33, 1, 57, 6,  3, 8, 82, 0, 39, 5, 10, 2,  8, 7, 26, 
    0, 73, 6, 54, 5, 43, 2, 53, 3,  2, 1, 45, 7, 97, 8, 79, 4, 24, 
    1, 32, 6, 29, 0, 57, 4,  8, 7, 31, 2,  1, 8, 53, 3, 92, 5, 27
  };
  const int q1547[] = {
    9, 9, // Number of jobs and machines
    2, 56, 0, 47, 7, 57, 5, 74, 8, 64, 1, 95, 4, 33, 3, 26, 6, 75, 
    8, 54, 6, 61, 4, 34, 7, 24, 0, 78, 5,  6, 3, 65, 1, 96, 2, 17, 
    6,  1, 1, 51, 4, 81, 3,  8, 2, 12, 8, 88, 5, 29, 0, 45, 7,  2, 
    3, 37, 5, 84, 8, 70, 7, 65, 0, 18, 2, 48, 6, 60, 1, 99, 4, 70, 
    6, 50, 7,  1, 4, 60, 0, 92, 1,  4, 2, 43, 3, 16, 8, 10, 5, 96, 
    1, 19, 5, 22, 7, 10, 8, 88, 3, 95, 0, 90, 2, 84, 6, 35, 4, 43, 
    2, 47, 3, 20, 0, 39, 4, 78, 6,  9, 1, 84, 5, 86, 8, 77, 7, 69, 
    4,  8, 3, 62, 8, 95, 7, 96, 6,  1, 1,  8, 5, 80, 0, 54, 2, 59, 
    3, 18, 7, 24, 6, 55, 1, 29, 4, 65, 8, 82, 0, 89, 2, 42, 5, 28
  };
  const int q1548[] = {
    9, 9, // Number of jobs and machines
    6, 50, 7, 35, 8, 45, 2, 73, 1, 69, 4, 80, 5, 12, 0, 19, 3, 44, 
    3, 65, 5, 44, 0, 39, 8, 29, 1, 51, 4,  9, 2, 99, 7, 59, 6, 29, 
    8, 58, 4, 25, 6, 95, 5, 81, 3, 81, 2, 29, 1,  5, 7, 93, 0, 82, 
    1, 13, 3, 15, 6, 37, 8, 54, 7, 41, 0, 59, 5, 32, 4, 76, 2,  7, 
    8, 60, 0, 57, 2, 33, 1, 47, 3, 45, 5, 24, 4, 11, 7, 44, 6, 15, 
    7,  7, 8, 86, 3, 12, 1, 58, 5, 50, 2, 92, 0, 31, 6, 38, 4, 67, 
    6, 57, 2, 89, 3, 84, 7, 62, 0, 81, 8, 33, 4, 30, 1, 50, 5, 12, 
    2, 21, 4, 19, 3, 66, 0,  1, 7, 72, 8, 85, 1, 93, 5, 20, 6, 14, 
    7,  4, 6, 35, 2, 12, 0, 78, 5, 16, 8, 42, 3, 47, 1, 49, 4, 81
  };
  const int q1549[] = {
    9, 9, // Number of jobs and machines
    4, 61, 7, 12, 2, 44, 8, 63, 6, 59, 0, 12, 3, 18, 5,  5, 1, 10, 
    0, 94, 4, 93, 3, 12, 7, 81, 1, 53, 8, 11, 6, 25, 5, 76, 2, 70, 
    0, 49, 5, 42, 4, 44, 7, 98, 8,  6, 6, 60, 2, 54, 1,  1, 3, 73, 
    6, 32, 0, 40, 4, 96, 8, 66, 7, 57, 5, 53, 3, 59, 1, 60, 2, 19, 
    0, 82, 2, 25, 1, 52, 7, 69, 5,  3, 6, 96, 3, 13, 4,  9, 8, 28, 
    2, 86, 8, 58, 6, 56, 1, 60, 0, 84, 7, 67, 3, 62, 4, 52, 5, 76, 
    3, 29, 7, 61, 5, 45, 2, 58, 6, 33, 4, 27, 8, 73, 0, 33, 1, 48, 
    3,  9, 0, 34, 6, 57, 1, 63, 7, 75, 8, 21, 4,  5, 5, 97, 2, 22, 
    3, 63, 8, 50, 6, 81, 0,  1, 1, 71, 7, 75, 4, 32, 2, 34, 5,  8
  };
  const int q1550[] = {
    9, 9, // Number of jobs and machines
    5, 52, 4, 66, 3, 36, 2, 97, 7, 51, 1, 41, 0,  7, 6, 16, 8, 92, 
    4,  3, 7, 38, 0, 69, 6,  6, 1, 92, 5, 14, 2, 90, 3, 14, 8, 93, 
    6, 19, 5, 13, 1,  2, 7, 40, 4, 90, 3, 49, 8,  7, 2, 50, 0, 74, 
    3, 99, 7, 32, 2, 12, 5, 58, 8, 53, 4, 65, 0, 40, 6, 51, 1, 54, 
    8, 97, 1, 82, 7, 43, 5, 21, 6, 16, 2, 49, 4,  4, 3, 90, 0,  7, 
    1, 89, 2, 22, 4, 35, 0, 93, 6, 56, 8, 37, 5, 67, 3, 35, 7, 35, 
    1, 79, 7, 18, 0, 73, 8, 59, 6,  9, 4, 26, 2,  1, 5, 70, 3, 81, 
    3, 69, 7, 89, 8, 16, 0,  4, 6, 32, 4, 35, 5, 35, 2, 40, 1, 26, 
    2, 11, 1, 23, 3, 74, 7, 56, 6, 11, 4, 33, 8, 32, 0, 54, 5, 22
  };
  const int q1551[] = {
    9, 9, // Number of jobs and machines
    2, 11, 6, 96, 1,  5, 7, 23, 5, 51, 0, 95, 3, 38, 8,  9, 4, 49, 
    2, 10, 5, 98, 8, 33, 3, 48, 7, 75, 4, 78, 6, 94, 0, 46, 1, 82, 
    3, 68, 8, 15, 0, 75, 6, 50, 2,  3, 5, 16, 7,  9, 1, 31, 4, 52, 
    0, 58, 3, 86, 2, 66, 5, 25, 7, 41, 8,  4, 6, 78, 4,  5, 1, 93, 
    4, 38, 6, 68, 8, 10, 5, 58, 7,  1, 3, 60, 2, 22, 0, 21, 1, 69, 
    0, 13, 1, 78, 8, 29, 2, 48, 7, 38, 5, 67, 4, 14, 6, 32, 3, 26, 
    0, 16, 3, 76, 6,  6, 2, 10, 8, 56, 7, 51, 5, 41, 4, 33, 1, 40, 
    3, 14, 1, 86, 4, 18, 7, 24, 2, 15, 0, 70, 6, 57, 5, 71, 8, 79, 
    3, 87, 1, 61, 5, 41, 6, 10, 8, 78, 7, 61, 4, 76, 2, 13, 0, 91
  };
  const int q1552[] = {
    9, 9, // Number of jobs and machines
    7, 23, 1, 27, 4, 58, 0, 77, 3, 77, 5, 50, 2, 80, 6, 41, 8,  4, 
    6, 49, 3,  7, 7, 50, 2, 13, 5, 73, 1, 77, 4, 55, 8, 58, 0, 11, 
    1, 70, 2, 55, 3,  1, 0,  4, 5, 81, 7, 66, 8, 80, 6, 24, 4,  8, 
    7, 87, 6, 94, 1, 60, 5, 85, 3, 58, 8, 94, 4, 77, 0, 58, 2, 40, 
    3, 69, 0, 20, 7, 18, 8, 16, 2, 74, 1, 91, 5, 53, 4, 36, 6, 17, 
    7, 56, 4, 93, 2, 19, 6, 85, 5,  6, 1, 33, 3, 65, 8, 57, 0, 94, 
    7, 14, 0, 66, 4, 24, 8, 69, 5, 96, 1, 44, 6, 22, 2, 23, 3, 18, 
    5, 63, 8, 56, 2, 58, 0, 44, 7, 17, 1, 88, 6, 80, 4, 70, 3, 19, 
    1, 99, 6, 84, 8, 62, 2, 68, 3, 79, 7, 36, 0, 99, 5, 94, 4, 10
  };
  const int q1553[] = {
    9, 9, // Number of jobs and machines
    2, 19, 5, 23, 3, 23, 7, 79, 6, 73, 0, 80, 4, 78, 8, 83, 1, 76, 
    3, 49, 0, 62, 2, 26, 4, 93, 7, 30, 6, 90, 1, 93, 5, 59, 8, 50, 
    8, 98, 7, 70, 0, 46, 5, 73, 2, 85, 1, 88, 3, 61, 4, 39, 6, 79, 
    8, 23, 1, 49, 0, 31, 4, 68, 2, 77, 5, 93, 6, 93, 7, 97, 3, 77, 
    0, 66, 6, 23, 3, 59, 7,  5, 1, 11, 2, 70, 8, 73, 4, 28, 5,  3, 
    1, 81, 0, 50, 5, 49, 6, 44, 8,  1, 3, 45, 7, 32, 4, 45, 2, 32, 
    3, 22, 1,  2, 6, 76, 7, 53, 0, 28, 4, 65, 5, 44, 2, 22, 8, 61, 
    7, 95, 3, 18, 8, 69, 2, 76, 1, 71, 5, 59, 6, 75, 4, 14, 0, 39, 
    2, 91, 5, 43, 7, 77, 3, 26, 6, 49, 8, 24, 0, 99, 1, 45, 4, 81
  };
  const int q1554[] = {
    9, 9, // Number of jobs and machines
    5, 27, 0, 58, 2, 93, 4,  8, 7, 42, 6,  8, 1, 10, 3, 62, 8, 81, 
    4, 76, 8, 58, 3, 36, 6, 91, 0, 49, 2,  9, 7, 25, 5, 98, 1, 98, 
    5, 54, 7, 99, 1, 76, 2, 51, 8, 59, 0, 70, 3, 88, 6,  9, 4,  8, 
    6, 72, 8, 42, 5, 45, 0, 85, 7,  7, 1, 19, 2, 96, 3, 86, 4, 53, 
    7, 65, 4,  7, 0, 74, 8, 99, 3, 57, 1, 45, 2, 74, 6, 76, 5,  4, 
    3, 49, 6, 49, 4,  1, 5, 45, 0, 65, 1, 33, 2,  7, 7, 25, 8, 66, 
    2, 86, 5, 30, 1, 47, 3, 13, 0, 46, 6,  2, 8, 64, 4, 46, 7,  9, 
    3, 26, 5, 63, 0, 44, 7, 38, 2,  5, 4, 38, 6, 22, 1, 17, 8, 30, 
    7,  2, 5, 74, 2, 12, 8, 28, 3, 64, 0, 52, 6, 43, 4, 30, 1, 87
  };
  const int q1555[] = {
    9, 9, // Number of jobs and machines
    4, 90, 2, 78, 1, 93, 5, 30, 7, 80, 6, 45, 3, 89, 0, 52, 8, 47, 
    7, 77, 8, 67, 0,  9, 2, 64, 5,  5, 3, 23, 4,  2, 1, 26, 6, 66, 
    0, 25, 7, 13, 3,  9, 5, 62, 1, 22, 2, 85, 6, 62, 4, 98, 8, 83, 
    4, 96, 7, 79, 3, 67, 1, 23, 0, 50, 6, 24, 8, 29, 5, 75, 2, 80, 
    3, 95, 6, 92, 5, 79, 4, 90, 8, 63, 1, 32, 2, 65, 0, 61, 7, 17, 
    8, 80, 7, 40, 3, 43, 1, 99, 2, 21, 0, 98, 5, 93, 4, 66, 6, 76, 
    8, 20, 3, 81, 1, 24, 7, 52, 4, 99, 5, 33, 6, 88, 2,  4, 0, 41, 
    7,  4, 3, 62, 5, 99, 4, 22, 1, 69, 2, 27, 8, 14, 0, 80, 6, 25, 
    5,  4, 7, 77, 1, 60, 8, 28, 2, 36, 6, 39, 4, 92, 3, 43, 0, 16
  };
  const int q1556[] = {
    9, 9, // Number of jobs and machines
    8, 67, 1, 87, 5, 65, 3, 83, 4,  5, 0, 92, 7, 87, 6,  6, 2, 56, 
    8, 61, 1, 77, 0,  6, 6, 14, 7, 36, 4, 68, 2, 41, 5, 14, 3, 95, 
    2, 19, 7, 44, 8, 61, 1, 33, 0, 82, 6, 90, 4, 96, 3,  3, 5, 15, 
    2, 10, 8,  2, 5, 77, 1,  8, 4, 99, 6, 38, 3, 82, 0, 93, 7, 28, 
    0, 86, 1, 25, 5, 81, 3,  1, 2, 52, 4, 77, 8, 99, 7, 65, 6, 91, 
    6, 62, 5, 11, 1, 99, 0, 34, 8, 42, 4, 84, 7, 58, 2, 49, 3, 20, 
    4, 88, 6, 99, 5, 34, 3, 85, 0, 39, 8, 17, 2, 39, 7, 28, 1, 69, 
    2, 21, 4, 66, 5, 70, 1, 61, 8, 98, 6, 21, 7, 71, 0, 46, 3, 14, 
    2, 90, 1,  9, 4, 10, 0, 41, 8, 29, 3, 60, 6, 19, 5, 46, 7, 49
  };
  const int q1557[] = {
    9, 9, // Number of jobs and machines
    0, 45, 1, 17, 8, 43, 3, 59, 4, 97, 6, 86, 7, 23, 2, 46, 5, 25, 
    3,  9, 6, 31, 5,  3, 1, 44, 8, 95, 0, 10, 4, 41, 2, 77, 7, 63, 
    4, 76, 7, 65, 8, 27, 2, 26, 6, 83, 5, 41, 1,  6, 0, 76, 3, 38, 
    6, 82, 5, 32, 7, 41, 1, 39, 0, 72, 4, 90, 3, 65, 2, 25, 8, 42, 
    4, 78, 5, 11, 8,  5, 6, 21, 2, 42, 0, 39, 1, 94, 7, 36, 3,  7, 
    6, 57, 4, 24, 1, 77, 3,  7, 8, 71, 7, 54, 0, 49, 5, 77, 2, 45, 
    6, 23, 1, 68, 3, 36, 4, 13, 5, 15, 7, 20, 2, 75, 0, 72, 8, 45, 
    3, 65, 8, 76, 0, 68, 1, 10, 2, 42, 6, 21, 5,  1, 4, 13, 7, 43, 
    8, 33, 6, 15, 1, 95, 7, 51, 4, 59, 2, 67, 5, 60, 3,  1, 0, 21
  };
  const int q1558[] = {
    9, 9, // Number of jobs and machines
    1, 70, 5, 45, 6, 14, 8,  6, 7, 20, 2,  7, 3, 22, 4, 33, 0, 88, 
    0,  8, 1, 35, 2, 83, 5, 70, 6, 13, 3, 84, 7, 74, 4, 21, 8, 37, 
    4, 74, 2, 33, 1,  5, 3, 48, 8, 79, 0, 22, 7, 47, 6, 20, 5, 88, 
    2, 21, 1, 96, 3, 55, 6, 91, 8, 31, 4, 45, 7, 51, 0, 96, 5, 33, 
    8, 16, 0, 68, 2,  3, 5, 36, 4, 39, 7, 93, 1, 41, 3, 53, 6, 32, 
    2, 82, 8, 90, 0, 21, 6, 86, 4, 25, 1,  5, 3,  8, 5, 78, 7, 46, 
    6, 94, 3, 16, 7, 31, 5, 51, 1, 14, 8, 53, 0, 97, 4, 62, 2, 89, 
    3,  9, 2, 75, 7, 17, 5, 44, 4, 97, 6, 88, 8, 21, 0, 78, 1, 71, 
    4, 51, 1,  6, 5, 79, 8, 35, 7, 57, 0, 93, 2,  8, 6, 62, 3, 22
  };
  const int q1559[] = {
    9, 9, // Number of jobs and machines
    5, 90, 1, 38, 2, 14, 0, 40, 4, 69, 3, 68, 6, 89, 7, 40, 8, 66, 
    0, 10, 2, 26, 8,  9, 3, 65, 7, 81, 4, 61, 5, 62, 6, 48, 1, 48, 
    3, 35, 5, 86, 0, 47, 6, 19, 1, 75, 8, 32, 2, 94, 4, 54, 7, 93, 
    3, 19, 0,  9, 7, 42, 5, 87, 1, 89, 2, 17, 6, 63, 4, 98, 8, 95, 
    4, 66, 3, 16, 0, 42, 1, 37, 8, 85, 5,  1, 7, 78, 6, 52, 2, 94, 
    5, 44, 2, 64, 0, 75, 6, 18, 7, 12, 8, 58, 4, 49, 3, 28, 1, 63, 
    8, 82, 5, 12, 6, 84, 7, 33, 4, 31, 1, 55, 2, 72, 3, 26, 0, 43, 
    2, 67, 1, 76, 7, 99, 4, 86, 8, 51, 0, 97, 5,  4, 3, 79, 6, 56, 
    6, 88, 3, 76, 8, 16, 4, 50, 5, 65, 7, 72, 1,  4, 0, 48, 2, 13
  };
  const int q1560[] = {
    9, 9, // Number of jobs and machines
    7,  9, 0, 52, 3, 64, 1, 35, 8, 81, 5, 78, 2, 16, 6, 40, 4, 31, 
    0, 66, 6, 34, 1, 40, 7, 63, 8, 27, 2, 52, 5, 80, 4, 71, 3, 54, 
    5, 81, 3,  2, 4, 39, 1, 38, 0, 82, 6, 46, 2, 50, 7, 26, 8, 46, 
    7, 38, 1, 87, 5, 15, 4, 98, 6, 61, 0, 32, 3, 31, 2, 21, 8,  6, 
    0, 21, 4, 26, 2, 52, 1, 92, 5, 98, 3, 61, 6, 74, 7, 67, 8, 24, 
    0, 39, 8,  8, 6, 15, 3, 57, 4, 70, 2, 40, 7, 33, 5,  1, 1, 16, 
    7, 41, 5, 78, 4, 60, 6, 15, 8,  3, 3, 60, 1, 33, 2,  1, 0,  5, 
    4, 80, 8, 22, 3, 39, 5, 90, 7, 99, 6, 60, 0, 84, 2, 86, 1, 60, 
    6, 99, 3, 19, 0, 14, 7, 60, 8, 62, 1, 11, 5, 69, 4,  5, 2, 21
  };
  const int q1561[] = {
    9, 9, // Number of jobs and machines
    6, 33, 8, 18, 4, 26, 5, 52, 0, 34, 7, 56, 3,  6, 2, 23, 1, 82, 
    4, 67, 1, 53, 6, 79, 2, 45, 5, 54, 3, 66, 0, 32, 7, 90, 8, 28, 
    0, 89, 7, 34, 8, 48, 5, 86, 2, 26, 6, 86, 1, 49, 4, 75, 3, 20, 
    2,  3, 8, 30, 3, 44, 5, 18, 1, 27, 7, 38, 4, 17, 6, 14, 0, 69, 
    6, 54, 5, 96, 4, 76, 2, 77, 0, 79, 7, 84, 8, 64, 3, 68, 1, 41, 
    4,  7, 3, 96, 5, 90, 0, 71, 2, 38, 7, 94, 6, 22, 8, 75, 1, 45, 
    1, 43, 8, 74, 5, 27, 6, 22, 3, 51, 4, 48, 7, 10, 0, 48, 2,  1, 
    8, 26, 1, 80, 4, 73, 5, 21, 7,  7, 2, 70, 0, 57, 6, 81, 3,  6, 
    8, 30, 0, 81, 6, 39, 3, 55, 2, 22, 4, 16, 7, 90, 1, 14, 5, 77
  };
  const int q1562[] = {
    9, 9, // Number of jobs and machines
    4, 52, 8, 45, 2, 46, 5, 73, 3, 80, 6, 51, 1, 92, 0, 32, 7, 81, 
    0, 33, 6, 78, 2, 88, 3, 33, 4, 71, 5, 15, 7, 63, 1, 14, 8, 76, 
    1, 16, 2, 11, 8, 71, 5, 30, 7, 19, 0, 52, 3, 44, 4, 54, 6, 59, 
    8, 61, 6, 20, 7, 13, 2, 83, 5, 17, 0, 85, 4, 89, 1, 94, 3, 92, 
    7, 29, 8,  2, 1, 26, 6, 83, 0, 65, 3, 57, 4, 54, 2, 81, 5, 18, 
    2, 66, 3, 73, 1, 47, 8, 27, 0, 87, 5, 77, 7, 91, 4, 14, 6, 93, 
    7, 81, 1, 65, 8, 75, 5, 89, 2, 22, 4, 55, 3, 64, 0, 19, 6, 42, 
    8, 14, 5, 60, 1, 16, 6, 35, 3, 48, 7, 78, 2, 42, 0, 44, 4, 70, 
    4, 37, 2, 69, 6, 64, 0, 56, 3, 25, 5, 58, 1, 24, 7, 72, 8, 98
  };
  const int q1563[] = {
    9, 9, // Number of jobs and machines
    4, 56, 0, 69, 8, 50, 5, 24, 2, 99, 6, 91, 7, 48, 3, 37, 1, 38, 
    3, 87, 8, 32, 0, 48, 1, 87, 4, 72, 6, 64, 7, 81, 5, 85, 2,  2, 
    2, 74, 6, 32, 3, 68, 5,  5, 7, 84, 8, 40, 1, 18, 0,  9, 4, 65, 
    8, 57, 5, 96, 7, 58, 2,  2, 6, 55, 1, 57, 4, 86, 3, 93, 0, 41, 
    8, 35, 3, 66, 4, 41, 6, 32, 0,  7, 7, 60, 2,  4, 1, 87, 5, 52, 
    2, 85, 7, 60, 1, 49, 6, 27, 5, 32, 4, 33, 8, 43, 0, 66, 3, 76, 
    0, 10, 1,  8, 2, 50, 8, 76, 3, 93, 7, 87, 6, 53, 5, 68, 4, 97, 
    6, 92, 8, 15, 1, 92, 4, 93, 2, 98, 3, 68, 5, 15, 0, 77, 7, 93, 
    6, 81, 7, 62, 4, 71, 2, 70, 5, 88, 3, 34, 1, 71, 8, 15, 0, 50
  };
  const int q1564[] = {
    9, 9, // Number of jobs and machines
    1, 32, 2, 96, 4, 14, 0, 50, 8, 91, 6, 75, 3, 71, 5, 84, 7, 65, 
    4, 95, 2, 17, 3, 30, 0, 56, 5, 87, 8, 71, 6, 78, 7, 73, 1,  6, 
    7, 16, 0, 16, 2, 53, 5, 62, 8, 87, 3, 13, 1, 96, 6,  1, 4, 91, 
    3, 63, 8, 33, 7, 11, 1, 35, 0, 48, 6, 96, 2, 90, 5,  3, 4, 97, 
    8, 19, 7,  2, 0, 29, 5, 85, 3, 40, 2, 87, 1, 58, 4, 24, 6, 57, 
    5, 12, 0, 27, 3, 21, 2, 96, 6, 64, 4, 71, 8, 69, 7, 87, 1,  2, 
    0, 35, 6, 37, 2, 17, 5, 77, 3, 74, 1,  5, 8, 42, 7, 72, 4, 57, 
    3, 73, 8, 98, 6,  2, 2, 67, 5, 20, 4, 32, 0, 95, 1, 62, 7, 61, 
    2, 77, 8, 39, 6, 89, 0, 20, 3,  9, 4, 55, 5, 30, 7, 40, 1, 99
  };
  const int q1565[] = {
    9, 9, // Number of jobs and machines
    6, 42, 4, 83, 8, 18, 1, 11, 2, 10, 0, 16, 7, 90, 3, 71, 5, 91, 
    2, 49, 8, 25, 0, 58, 3, 17, 5, 64, 7,  2, 6, 77, 1, 36, 4, 82, 
    8, 18, 5, 50, 7, 18, 2, 33, 1,  2, 6, 26, 3, 16, 0,  6, 4, 74, 
    8, 18, 3, 76, 6, 34, 4, 76, 5, 89, 1, 87, 7,  2, 2, 28, 0, 16, 
    3, 26, 0, 92, 4, 37, 2, 60, 8, 15, 1, 69, 7, 72, 6,  4, 5, 67, 
    7, 51, 1, 47, 4, 85, 5, 74, 2, 10, 8, 72, 0, 80, 3, 26, 6, 77, 
    6, 37, 4, 23, 8,  2, 1, 51, 3, 85, 0, 88, 5, 60, 7, 93, 2, 44, 
    5,  7, 0, 70, 8, 96, 2, 78, 7, 38, 6, 44, 1, 41, 3, 37, 4, 15, 
    3, 16, 5, 97, 1, 83, 2, 32, 7, 37, 4, 52, 6, 47, 0, 14, 8, 81
  };
  const int q1566[] = {
    9, 9, // Number of jobs and machines
    0, 82, 1, 69, 4, 26, 6, 11, 5, 56, 8, 17, 3, 92, 7,  1, 2,  7, 
    1, 15, 8, 20, 0, 73, 5, 84, 4, 28, 6, 66, 3, 46, 7,  5, 2, 14, 
    0, 24, 6, 88, 1, 62, 5, 22, 3, 16, 4, 25, 8, 57, 7, 91, 2, 31, 
    2, 64, 7, 25, 8, 88, 6, 15, 4, 11, 3, 40, 5, 81, 1, 36, 0,  1, 
    8, 92, 4,  8, 7, 67, 0,  7, 2,  6, 5, 29, 1, 94, 6, 87, 3, 21, 
    2, 79, 6, 93, 0, 64, 8, 71, 7, 13, 4, 31, 3, 98, 1, 29, 5, 12, 
    1, 49, 5, 11, 2, 98, 4, 87, 0, 89, 3, 67, 6, 33, 8, 11, 7, 18, 
    3, 63, 5, 19, 6, 68, 1, 11, 8, 76, 7, 52, 0, 53, 2, 65, 4, 31, 
    2,  7, 0, 59, 6, 69, 4, 94, 5, 99, 3, 42, 8, 66, 7, 54, 1,  5
  };
  const int q1567[] = {
    9, 9, // Number of jobs and machines
    3, 76, 2, 93, 6, 63, 7, 37, 1,  7, 4, 30, 0, 25, 8,  4, 5, 89, 
    7, 70, 3, 62, 8, 36, 0, 97, 5, 85, 1, 63, 2, 72, 6, 36, 4, 29, 
    5, 10, 2, 18, 3, 19, 1, 41, 8, 31, 0, 85, 6, 94, 7, 93, 4, 60, 
    2, 45, 7, 36, 5, 34, 6, 76, 0, 32, 1, 84, 4, 80, 8, 50, 3, 66, 
    0, 42, 1,  9, 8, 94, 6, 40, 7, 35, 4, 28, 5, 81, 3, 65, 2, 57, 
    5, 42, 6, 13, 3, 88, 1, 98, 8, 22, 7, 42, 0, 18, 2, 83, 4, 42, 
    5, 93, 2, 61, 7, 83, 4, 78, 1, 96, 0, 13, 8, 21, 3, 16, 6, 28, 
    1, 83, 0, 16, 7, 74, 8, 33, 6, 43, 2, 47, 4, 96, 5,  8, 3,  5, 
    4, 78, 1, 90, 2, 43, 7, 97, 3, 45, 8, 29, 6, 86, 5, 32, 0, 24
  };
  const int q1568[] = {
    9, 9, // Number of jobs and machines
    3, 58, 0, 77, 6,  7, 7, 41, 5, 26, 2, 49, 4, 44, 8, 17, 1, 58, 
    8, 88, 6,  8, 7, 87, 5, 41, 2, 33, 3, 60, 1, 47, 0, 56, 4, 72, 
    1, 53, 2, 49, 4, 58, 8, 57, 6, 71, 7, 14, 0, 75, 5, 42, 3, 16, 
    0, 76, 6, 31, 5, 89, 1, 67, 8, 99, 4, 25, 3, 34, 7, 72, 2, 52, 
    7, 85, 6, 62, 2,  8, 3, 43, 1, 59, 4, 14, 8, 49, 5, 33, 0,  9, 
    1, 14, 8, 51, 7, 89, 6,  1, 0, 42, 2, 23, 3, 91, 5, 50, 4, 15, 
    0, 78, 4, 91, 6, 95, 2, 85, 3,  1, 7, 32, 5, 35, 1, 85, 8, 38, 
    0, 32, 3, 82, 5, 46, 1,  4, 4, 22, 2,  6, 7, 41, 6, 58, 8,  2, 
    8, 35, 6, 34, 1, 38, 5,  9, 4, 71, 2, 28, 0, 64, 3,  7, 7, 64
  };
  const int q1569[] = {
    9, 9, // Number of jobs and machines
    2,  3, 1, 25, 5, 21, 3,  5, 0, 49, 7, 77, 4, 55, 8,  9, 6, 19, 
    1, 22, 0, 81, 6, 90, 7, 67, 4, 78, 8, 99, 3, 37, 2, 66, 5, 92, 
    6, 90, 1, 24, 7,  2, 8, 41, 4, 90, 5, 85, 2, 67, 3, 54, 0, 18, 
    0, 23, 2, 90, 4, 21, 1, 55, 3, 29, 7, 55, 6, 12, 5, 82, 8, 44, 
    3, 16, 8, 92, 1, 95, 5, 13, 4,  4, 0, 27, 2, 26, 6, 83, 7, 27, 
    4,  5, 3, 53, 7, 10, 5, 42, 8, 39, 1, 44, 2, 25, 6, 33, 0, 29, 
    8,  9, 6, 63, 0, 53, 2, 65, 1, 35, 5, 59, 4, 57, 7, 32, 3, 49, 
    7, 11, 0, 83, 5, 84, 3, 56, 4, 38, 8, 50, 1, 91, 6, 36, 2, 79, 
    2, 81, 6, 12, 4, 18, 1, 43, 0, 47, 8, 13, 5, 22, 3, 50, 7, 70
  };
  const int q1570[] = {
    9, 9, // Number of jobs and machines
    6, 39, 5, 18, 4, 28, 2, 41, 1, 63, 8, 85, 0, 21, 3, 13, 7, 45, 
    0,  9, 7, 80, 2, 99, 1, 92, 4,  2, 5, 33, 8, 34, 3, 33, 6, 90, 
    6, 19, 8, 14, 3, 57, 4, 10, 2, 47, 1, 60, 0, 35, 7, 98, 5, 63, 
    8, 46, 0, 35, 3,  3, 1, 68, 6, 75, 4, 17, 7, 31, 2, 38, 5, 19, 
    5, 69, 6, 97, 4, 99, 7, 34, 3, 73, 2, 42, 1, 30, 8, 80, 0, 54, 
    5, 23, 8,  1, 3, 48, 4, 60, 0, 55, 2,  2, 7, 16, 1, 87, 6, 28, 
    8, 63, 3, 59, 5, 91, 6, 26, 1, 75, 7, 67, 4, 98, 2, 83, 0, 37, 
    0, 61, 3, 32, 5, 21, 7, 31, 1,  6, 8, 87, 2,  9, 6, 51, 4, 75, 
    8, 62, 2, 46, 0, 83, 7, 71, 5, 96, 4, 71, 6, 10, 3, 78, 1, 15
  };
  const int q1571[] = {
    9, 9, // Number of jobs and machines
    1, 30, 5, 37, 8, 47, 7,  5, 6, 94, 3, 52, 4, 28, 2, 56, 0,  2, 
    8,  5, 6, 37, 1, 17, 0, 20, 4, 93, 3, 26, 2, 39, 5, 35, 7, 89, 
    5, 51, 4, 28, 0, 43, 1, 75, 8, 68, 2, 45, 3, 77, 7, 43, 6, 14, 
    0, 45, 1, 35, 6, 60, 4, 66, 3,  8, 8,  3, 5, 73, 7, 82, 2, 73, 
    2, 22, 0, 94, 4, 54, 5,  8, 3, 12, 8, 47, 1, 49, 6, 57, 7, 35, 
    6, 21, 3, 32, 5,  5, 8, 62, 7, 32, 4, 30, 1, 75, 0, 59, 2, 56, 
    2, 21, 1, 17, 0, 27, 6, 52, 8, 32, 7, 62, 3, 20, 4, 96, 5, 66, 
    4, 59, 3, 67, 0, 55, 5, 58, 1, 53, 7, 45, 2, 98, 8, 70, 6, 26, 
    4, 50, 3, 16, 2, 98, 1, 74, 8, 57, 5, 15, 7, 55, 6, 52, 0, 18
  };
  const int q1572[] = {
    9, 9, // Number of jobs and machines
    8, 76, 2,  4, 5, 46, 0, 95, 6, 74, 4, 96, 7, 26, 1, 57, 3, 42, 
    8, 65, 4, 40, 2, 52, 1, 58, 0, 57, 5,  1, 7, 12, 6, 53, 3, 93, 
    5, 70, 8, 55, 2, 82, 7, 93, 1, 77, 0, 52, 4, 82, 6, 89, 3, 51, 
    3, 67, 0, 63, 8, 91, 5, 38, 6, 87, 7, 25, 2, 30, 1, 27, 4, 74, 
    0, 49, 1, 58, 3, 22, 4,  4, 5, 41, 8, 32, 2, 66, 6, 21, 7, 86, 
    3, 58, 6, 27, 0,  9, 7, 32, 2, 65, 5, 76, 1, 80, 8, 90, 4,  6, 
    6, 70, 3, 39, 2, 43, 7, 88, 8, 23, 1, 47, 5, 45, 0, 39, 4, 66, 
    6, 79, 5,  6, 2, 83, 8, 91, 3, 27, 4, 12, 1, 66, 7, 96, 0, 22, 
    0, 86, 4, 12, 8, 36, 5, 39, 1, 59, 3, 24, 7, 44, 2, 97, 6,  4
  };
  const int q1573[] = {
    9, 9, // Number of jobs and machines
    4, 16, 8, 22, 7, 22, 5, 47, 1,  2, 6, 77, 0, 63, 3, 33, 2, 69, 
    3, 56, 4, 10, 0, 89, 8, 54, 2, 75, 5, 35, 1, 86, 6,  8, 7, 36, 
    2, 63, 3, 52, 8, 82, 6, 66, 4,  4, 1,  4, 7, 53, 0, 52, 5, 52, 
    0, 59, 5, 82, 2, 90, 7, 37, 1,  9, 4, 65, 3, 46, 6, 68, 8, 66, 
    6, 10, 8, 56, 4,  5, 2, 99, 0, 22, 7, 25, 5, 11, 3, 82, 1, 93, 
    0, 50, 1, 35, 4, 58, 3,  8, 7, 34, 8, 11, 2, 22, 6, 41, 5, 85, 
    2, 23, 7, 24, 3, 72, 4, 54, 0, 94, 5, 59, 1,  6, 8,  8, 6, 80, 
    4, 64, 3, 46, 6, 73, 7, 82, 2, 61, 1, 11, 5, 78, 0, 94, 8, 69, 
    8, 97, 4, 80, 7, 23, 6, 27, 3, 98, 5, 73, 0, 78, 2,  8, 1, 33
  };
  const int q1574[] = {
    9, 9, // Number of jobs and machines
    1, 85, 3, 98, 2, 19, 6, 20, 5, 63, 0, 56, 8, 23, 4, 99, 7, 48, 
    1, 98, 2, 46, 4, 82, 5,  5, 6, 44, 7, 98, 8, 92, 0, 70, 3, 75, 
    2, 93, 8, 70, 7, 76, 0, 25, 6, 51, 4, 73, 3, 16, 1, 99, 5, 96, 
    5, 52, 1, 90, 0, 15, 6, 63, 4, 30, 8, 49, 2, 99, 7, 31, 3, 53, 
    5, 20, 4, 96, 1, 78, 3, 91, 8, 94, 0,  4, 2, 75, 7, 30, 6, 16, 
    8, 24, 1, 54, 6, 77, 4, 66, 2, 39, 3, 17, 7,  7, 0, 24, 5, 86, 
    6, 81, 1, 87, 8, 10, 4, 61, 0, 87, 3, 32, 2, 48, 7, 31, 5,  9, 
    2, 75, 5, 27, 1, 29, 3, 68, 0, 41, 4, 21, 8,  7, 6, 43, 7,  2, 
    6, 47, 5, 56, 3, 73, 1, 99, 4, 67, 7, 94, 0, 58, 8, 11, 2, 91
  };
  const int q1575[] = {
    9, 9, // Number of jobs and machines
    0, 88, 4, 43, 6, 49, 3, 40, 1, 37, 2, 75, 5, 15, 8, 72, 7, 72, 
    6, 54, 8, 85, 7,  3, 0, 20, 4,  3, 1, 15, 3, 81, 2, 98, 5, 18, 
    2, 64, 4, 28, 6, 38, 8, 31, 7, 76, 5, 86, 3, 36, 0, 10, 1, 64, 
    2,  5, 6, 20, 1, 27, 4, 10, 8, 88, 5, 28, 7, 41, 0, 56, 3, 58, 
    7, 63, 1, 28, 4, 14, 2, 23, 0, 49, 5, 32, 6, 79, 8, 75, 3, 66, 
    6, 44, 8, 18, 7, 98, 5, 72, 4, 28, 1, 53, 0, 69, 2,  5, 3, 61, 
    6, 60, 5, 93, 8, 49, 7,  2, 2, 30, 3, 31, 1, 65, 0, 58, 4, 90, 
    6, 27, 7, 43, 8, 86, 0, 45, 1, 42, 3, 76, 4, 78, 2, 91, 5, 72, 
    4, 92, 7, 19, 0, 69, 6, 13, 2, 63, 5, 73, 8, 12, 1, 10, 3,  4
  };
  const int q1576[] = {
    9, 9, // Number of jobs and machines
    8, 40, 2, 59, 0, 34, 6, 97, 3, 13, 1, 28, 5,  3, 4, 80, 7, 46, 
    0, 74, 8, 57, 1, 29, 2, 11, 4, 20, 5, 61, 6, 93, 3,  2, 7, 31, 
    0, 52, 7, 43, 6, 44, 2,  7, 4, 12, 8, 58, 3, 78, 1, 58, 5, 69, 
    1, 43, 3, 50, 7, 35, 6, 41, 4, 32, 0, 34, 2, 87, 5, 24, 8, 86, 
    1, 77, 5, 64, 6, 32, 4, 38, 3, 62, 7, 70, 0, 13, 8, 11, 2, 42, 
    1, 39, 6, 59, 3, 25, 4, 57, 2, 25, 7, 13, 0, 23, 8, 64, 5,  2, 
    7, 27, 2, 94, 3, 27, 6, 36, 8, 36, 0, 44, 5, 61, 4, 35, 1, 16, 
    2, 19, 4, 49, 1, 13, 6, 36, 3, 13, 7, 63, 8, 16, 5, 19, 0, 86, 
    6, 17, 7, 75, 8, 39, 4, 16, 2, 27, 5, 45, 0, 55, 3, 55, 1, 58
  };
  const int q1577[] = {
    9, 9, // Number of jobs and machines
    1, 74, 7, 27, 5, 72, 8, 24, 0,  5, 4, 81, 6, 28, 2, 57, 3, 89, 
    2, 54, 4, 43, 7, 71, 8, 43, 3, 36, 1, 91, 5, 87, 0, 13, 6, 46, 
    2, 67, 3, 89, 7, 13, 8, 80, 5, 55, 1, 93, 4, 76, 0, 37, 6, 35, 
    5, 62, 6, 20, 8, 58, 1, 91, 7, 52, 2, 80, 3,  5, 0,  3, 4, 49, 
    1, 25, 4, 25, 5, 97, 8, 55, 0, 49, 6, 44, 2, 49, 7, 96, 3, 27, 
    0, 57, 1, 44, 8, 11, 7, 18, 4, 63, 6, 58, 5, 15, 3, 37, 2, 18, 
    3,  3, 2, 71, 5, 59, 4,  3, 8, 56, 6, 70, 7, 97, 1, 15, 0, 53, 
    7, 28, 6, 87, 8, 12, 4, 73, 0, 89, 5, 35, 3, 83, 1, 41, 2, 25, 
    3, 68, 8, 41, 2, 58, 7, 41, 0, 46, 4, 71, 1, 54, 5,  3, 6, 13
  };
  const int q1578[] = {
    9, 9, // Number of jobs and machines
    5, 66, 1, 20, 7, 78, 4, 30, 2, 11, 0, 32, 6, 55, 8, 50, 3, 80, 
    3, 71, 0, 80, 7, 17, 1, 21, 6, 58, 5, 33, 4, 52, 2, 41, 8,  1, 
    5, 50, 7, 60, 3, 50, 4,  5, 2, 33, 1, 66, 0, 46, 6, 38, 8,  4, 
    8, 77, 0, 12, 1, 52, 3, 22, 5, 11, 7, 72, 2, 94, 4, 36, 6, 21, 
    6, 92, 5, 73, 4, 60, 0,  6, 1, 34, 3, 18, 7, 95, 8, 18, 2, 77, 
    2, 55, 3, 11, 0, 35, 6, 73, 1, 49, 5, 43, 4,  9, 7, 26, 8,  7, 
    0, 65, 7, 73, 6, 41, 2, 97, 3, 13, 5, 69, 8, 12, 1, 33, 4, 14, 
    8, 46, 0, 41, 1, 44, 5,  4, 7, 44, 6, 24, 4, 79, 3, 62, 2, 47, 
    4, 76, 8, 91, 3, 21, 5, 89, 7, 46, 6,  4, 2, 92, 1, 19, 0, 31
  };
  const int q1579[] = {
    9, 9, // Number of jobs and machines
    3,  8, 7, 11, 0, 54, 1, 77, 4, 24, 5, 38, 2, 68, 6, 23, 8, 21, 
    2, 96, 4, 33, 3, 55, 8, 71, 7, 28, 1, 72, 5, 76, 0, 19, 6, 64, 
    4, 61, 0, 27, 6, 79, 5, 81, 8, 85, 2, 85, 3, 55, 1, 41, 7,  1, 
    4, 46, 3, 86, 0, 59, 7, 47, 5, 41, 6, 74, 8, 52, 1, 98, 2, 35, 
    7, 62, 3, 63, 0, 64, 4, 34, 1, 40, 2, 82, 8, 16, 5, 23, 6, 69, 
    1,  9, 3, 52, 8, 31, 2, 63, 6, 23, 5, 57, 4, 26, 0, 36, 7, 47, 
    4,  3, 8, 57, 7, 58, 2, 39, 1, 72, 0, 56, 5, 14, 6, 82, 3, 83, 
    3, 23, 7, 43, 1,  8, 5, 72, 8, 22, 2, 35, 0, 19, 6, 27, 4, 89, 
    0, 82, 5, 99, 4, 51, 1, 89, 8, 95, 6, 66, 3, 60, 2, 74, 7, 16
  };
  const int q1580[] = {
    9, 9, // Number of jobs and machines
    7, 42, 8, 44, 4, 59, 2, 62, 5, 92, 0, 76, 1, 27, 3, 61, 6, 33, 
    4, 80, 8, 92, 3, 98, 6, 26, 7, 57, 0, 18, 2, 76, 5,  2, 1, 30, 
    5, 22, 3, 87, 8, 21, 4, 28, 7, 74, 0, 67, 6, 79, 1, 32, 2, 41, 
    7, 60, 1, 48, 5, 49, 6, 21, 8, 25, 3, 26, 0, 77, 2, 82, 4, 30, 
    5, 27, 2, 16, 1, 96, 7, 10, 8,  2, 6, 78, 4, 81, 0, 58, 3, 27, 
    2, 16, 5, 79, 3, 56, 8, 91, 7, 12, 0, 41, 4, 56, 6, 15, 1, 78, 
    5, 61, 6, 69, 0, 42, 7,  2, 8, 50, 3, 72, 1, 94, 4, 62, 2, 93, 
    5, 91, 2, 36, 7, 96, 3, 76, 0, 36, 8, 45, 1, 79, 6, 13, 4, 37, 
    6, 67, 2, 35, 0, 96, 3, 50, 8, 64, 4,  3, 1, 19, 5, 10, 7, 49
  };
  const int q1581[] = {
    9, 9, // Number of jobs and machines
    2, 39, 1, 54, 3, 33, 6, 85, 4, 93, 7, 35, 0, 77, 8, 39, 5, 94, 
    4, 79, 6, 15, 5, 21, 7, 13, 1,  4, 2, 19, 0,  4, 8, 48, 3, 88, 
    6, 78, 3, 78, 2, 88, 7, 31, 8,  5, 4, 29, 1, 12, 0, 24, 5, 94, 
    1, 76, 7, 92, 3, 54, 6, 34, 0, 25, 5, 45, 8, 96, 4, 30, 2, 64, 
    1, 32, 0, 85, 4, 79, 5, 26, 2, 13, 8, 76, 7, 43, 6, 70, 3, 66, 
    8, 94, 6, 41, 1, 80, 0, 90, 2,  6, 3, 80, 5, 29, 4, 78, 7, 58, 
    6, 87, 2, 85, 1, 31, 5, 71, 4, 53, 3, 66, 7, 30, 8, 53, 0, 51, 
    5,  9, 7,  2, 1, 78, 4, 26, 6, 82, 8,  3, 2, 79, 0, 33, 3, 98, 
    3, 70, 2, 11, 7, 34, 6, 23, 0, 62, 4, 21, 1, 29, 5, 79, 8,  3
  };
  const int q1582[] = {
    9, 9, // Number of jobs and machines
    5, 70, 7, 54, 6, 74, 3, 76, 0, 75, 1, 36, 8, 28, 2, 37, 4, 11, 
    5, 48, 7,  7, 8, 18, 4, 41, 1,  6, 0, 93, 6, 55, 3, 90, 2, 75, 
    4, 61, 7, 62, 3,  5, 5, 25, 0, 38, 1, 31, 2, 48, 6, 91, 8, 14, 
    3, 23, 2, 77, 4, 29, 6, 13, 5, 14, 1, 40, 0, 99, 7, 89, 8, 75, 
    8, 26, 4, 15, 7, 64, 0, 52, 2, 51, 6, 11, 1,  2, 3, 87, 5, 56, 
    3, 49, 2, 65, 0, 38, 6, 62, 8, 47, 7, 19, 4, 93, 1, 11, 5, 48, 
    8, 30, 1, 42, 6, 36, 3, 16, 0, 51, 2, 54, 4, 73, 5, 99, 7, 42, 
    1, 25, 8, 96, 2, 32, 4, 13, 0, 96, 6, 93, 3, 13, 5, 11, 7, 25, 
    5, 39, 0, 26, 8, 44, 1, 76, 4, 44, 2, 84, 7, 14, 6, 72, 3, 47
  };
  const int q1583[] = {
    9, 9, // Number of jobs and machines
    8, 66, 1, 99, 5, 76, 6,  3, 3, 97, 7, 61, 4, 49, 2, 66, 0, 19, 
    0, 16, 5, 35, 1, 47, 8, 43, 4, 54, 7, 95, 2, 95, 6, 66, 3, 52, 
    5, 18, 1, 51, 7, 17, 4,  3, 2, 47, 6, 56, 8, 41, 0, 35, 3, 32, 
    3, 59, 1, 95, 0, 80, 4, 58, 7,  8, 2, 67, 5, 73, 6, 51, 8, 41, 
    2, 13, 4, 16, 3, 82, 5, 14, 6, 74, 7, 12, 0, 20, 8, 19, 1, 29, 
    6, 59, 1, 64, 5, 96, 2, 73, 0, 40, 4, 62, 7, 81, 8, 42, 3, 56, 
    2, 76, 4, 58, 6, 83, 7, 33, 8,  9, 1, 86, 5,  9, 0, 17, 3, 89, 
    5, 76, 1, 23, 3, 57, 6, 80, 7, 55, 2, 64, 0, 73, 8, 46, 4, 64, 
    0, 11, 8, 70, 4, 49, 1, 43, 2, 82, 3, 13, 5,  6, 7, 94, 6, 70
  };
  const int q1584[] = {
    9, 9, // Number of jobs and machines
    7, 68, 4, 61, 0, 63, 8, 14, 6, 52, 5, 84, 1, 45, 3, 61, 2, 12, 
    7, 15, 0, 62, 1, 49, 3, 62, 5, 50, 8,  3, 2, 78, 4, 13, 6, 65, 
    2, 21, 8, 35, 0, 36, 5, 45, 1, 92, 3, 89, 7, 65, 4, 71, 6, 91, 
    8, 36, 7, 73, 0, 24, 2, 89, 3, 55, 1, 62, 6, 24, 5, 95, 4, 22, 
    7, 26, 6, 56, 3, 26, 4, 61, 1, 37, 8, 78, 2, 34, 5, 42, 0, 57, 
    7, 88, 5, 32, 2, 87, 1,  8, 3,  3, 4,  6, 0, 14, 6, 37, 8,  5, 
    5,  9, 2, 99, 8, 75, 6, 80, 7, 54, 3, 99, 0,  6, 4, 62, 1, 63, 
    2, 28, 0, 21, 7, 55, 3, 28, 5, 36, 6, 58, 1, 65, 4, 33, 8, 23, 
    5, 33, 6, 16, 0, 21, 3, 69, 2, 72, 1,  2, 8, 90, 4, 82, 7, 23
  };
  const int q1585[] = {
    9, 9, // Number of jobs and machines
    8, 38, 5, 39, 4, 44, 3, 56, 1, 21, 6, 53, 0, 31, 2, 12, 7,  9, 
    0, 64, 2, 75, 5, 50, 8, 77, 6, 90, 7,  4, 1, 18, 3, 86, 4, 64, 
    4, 79, 7, 32, 5, 72, 0, 40, 6,  3, 3, 85, 8, 86, 2, 93, 1, 39, 
    3, 55, 7, 52, 1, 19, 8, 85, 6, 68, 5, 94, 2, 36, 0, 59, 4, 72, 
    7,  4, 6,  1, 3, 86, 0, 53, 1, 90, 5, 74, 4, 56, 2, 39, 8,  4, 
    4, 84, 6, 28, 0, 49, 7, 24, 8, 28, 3, 97, 5, 31, 2, 11, 1, 94, 
    3, 24, 7, 20, 6, 78, 2,  4, 4, 73, 0, 17, 1, 24, 5, 18, 8, 98, 
    1, 13, 5, 58, 4, 19, 3, 41, 6, 18, 2, 81, 8, 65, 0,  9, 7, 98, 
    6, 59, 2,  7, 5, 36, 1, 12, 8, 42, 7, 69, 3, 65, 0, 91, 4, 14
  };
  const int q1586[] = {
    9, 9, // Number of jobs and machines
    6, 73, 7, 45, 3, 51, 8, 89, 2, 77, 0, 12, 1, 44, 4, 16, 5, 66, 
    0, 37, 7, 64, 1, 51, 5, 78, 2, 57, 6, 45, 8, 94, 4, 81, 3, 63, 
    7,  6, 3, 48, 5, 78, 1, 70, 6, 23, 8, 50, 2, 63, 4, 21, 0, 26, 
    6, 47, 2, 21, 4, 59, 3, 52, 8, 33, 0,  4, 1, 70, 5, 39, 7, 67, 
    6, 18, 0, 58, 5, 93, 1, 53, 4, 24, 3, 41, 7, 91, 2, 99, 8, 99, 
    8, 76, 4, 88, 3, 55, 5, 76, 6,  9, 1, 50, 0, 63, 7, 92, 2,  7, 
    6, 89, 8, 38, 7, 37, 4, 75, 0, 96, 3, 92, 1, 39, 5, 59, 2, 44, 
    5, 18, 2, 88, 3, 81, 6, 51, 1, 17, 7, 92, 8, 66, 4, 58, 0, 74, 
    4,  7, 0, 36, 6, 22, 5, 84, 3, 31, 2, 16, 8, 42, 7, 16, 1, 28
  };
  const int q1587[] = {
    9, 9, // Number of jobs and machines
    7, 60, 3, 42, 5, 44, 1, 66, 0, 85, 8, 37, 6, 98, 4, 11, 2, 56, 
    8, 22, 4, 17, 1, 83, 7, 81, 5, 64, 3, 23, 2, 71, 6, 83, 0, 40, 
    0, 91, 3, 23, 4, 36, 6, 90, 1, 33, 5,  4, 2, 94, 8, 83, 7, 82, 
    6,  2, 5, 49, 7, 93, 2, 18, 8, 96, 1, 88, 0, 47, 3, 78, 4, 60, 
    8,  7, 5, 56, 2,  9, 1, 97, 3, 84, 4,  8, 0, 90, 7, 48, 6, 10, 
    8, 73, 3, 35, 1, 95, 6, 38, 4, 12, 2, 18, 7, 64, 5, 14, 0, 73, 
    8, 27, 1, 32, 5, 20, 6, 73, 7, 88, 0, 20, 4, 31, 3, 60, 2, 43, 
    7, 69, 4, 44, 3, 22, 8, 61, 1, 17, 0, 31, 2, 61, 6, 58, 5, 69, 
    6, 47, 0, 45, 3, 54, 4, 33, 7, 34, 1, 10, 2, 93, 5, 70, 8, 94
  };
  const int q1588[] = {
    9, 9, // Number of jobs and machines
    3, 73, 7, 74, 0, 12, 2, 87, 5, 32, 6, 68, 1, 64, 8, 14, 4, 96, 
    5, 42, 4, 75, 8, 36, 0, 59, 1, 11, 7, 51, 6,  4, 2, 35, 3, 74, 
    6, 59, 3,  4, 8, 25, 5, 83, 2, 89, 0, 43, 4, 18, 1, 94, 7, 25, 
    4, 87, 6, 46, 0, 60, 2,  1, 1, 14, 3, 96, 5, 68, 7, 74, 8, 51, 
    5, 92, 3, 76, 8, 30, 4, 98, 0, 60, 7,  7, 2,  7, 6, 96, 1, 97, 
    0, 22, 3, 50, 4, 52, 5, 72, 2, 71, 6, 99, 8, 35, 1, 94, 7, 39, 
    1, 40, 3, 42, 0, 79, 5,  2, 7, 77, 6, 96, 2, 14, 8, 83, 4, 42, 
    7, 27, 2, 46, 0, 74, 4, 41, 8, 38, 1, 43, 5, 81, 3, 74, 6, 47, 
    7, 58, 0, 24, 3, 59, 2, 89, 4, 22, 5, 10, 8, 99, 1, 11, 6, 81
  };
  const int q1589[] = {
    9, 9, // Number of jobs and machines
    5, 15, 4, 14, 1, 41, 7, 77, 3,  9, 2, 94, 0,  8, 6, 24, 8, 56, 
    3, 57, 1, 23, 5, 23, 4, 52, 2, 80, 7, 74, 6, 67, 0, 83, 8,  2, 
    6, 40, 1, 12, 4, 24, 5, 96, 8, 35, 0, 80, 3, 79, 2, 39, 7, 69, 
    2, 23, 8, 37, 5, 29, 7, 27, 0, 75, 6, 73, 4, 59, 3, 94, 1, 79, 
    8, 11, 2, 46, 6, 78, 0, 90, 4, 43, 1, 45, 3, 19, 7, 82, 5, 96, 
    7, 45, 6, 81, 1,  8, 5, 33, 4, 68, 3, 36, 2, 41, 0, 84, 8, 86, 
    4, 32, 1, 94, 8, 45, 6, 40, 2, 98, 7, 96, 0, 34, 5, 25, 3, 87, 
    5,  9, 1, 41, 2, 55, 3, 22, 0, 78, 8, 51, 7, 72, 6, 55, 4, 87, 
    7, 20, 1,  9, 6, 90, 0, 52, 8, 79, 4, 55, 3, 35, 5, 16, 2, 61
  };
  const int q1590[] = {
    9, 9, // Number of jobs and machines
    0, 65, 8, 81, 3, 31, 4, 99, 7, 57, 1,  8, 5, 66, 2, 77, 6, 14, 
    2, 84, 0,  1, 6, 10, 4, 42, 7,  2, 1, 33, 3, 35, 5, 36, 8, 40, 
    6, 33, 3, 62, 1, 91, 8, 26, 0, 97, 5, 57, 4, 48, 7, 32, 2,  1, 
    2, 40, 4, 21, 0, 17, 3, 63, 1, 43, 8, 64, 5, 57, 6, 59, 7, 50, 
    7,  6, 6, 50, 2, 15, 3, 28, 0, 53, 4, 46, 5,  4, 8, 64, 1, 53, 
    4,  9, 3, 88, 0, 24, 7, 50, 2,  5, 8, 94, 6, 90, 5, 35, 1,  4, 
    0, 40, 2, 50, 7, 32, 1, 48, 6, 96, 3, 39, 4, 58, 5, 22, 8, 75, 
    8, 25, 4, 17, 3, 27, 7, 81, 1, 55, 0, 60, 5, 47, 2, 63, 6, 36, 
    6, 31, 8, 99, 4, 44, 2, 96, 0, 39, 5, 38, 3, 72, 7, 52, 1, 51
  };
  const int q1591[] = {
    9, 9, // Number of jobs and machines
    0, 77, 8, 33, 3,  8, 2, 82, 4, 98, 1, 25, 6, 31, 7, 42, 5, 92, 
    5, 79, 6, 53, 3, 83, 4, 66, 7, 59, 2, 36, 0, 22, 8, 58, 1, 29, 
    5, 56, 3, 22, 7, 16, 8, 17, 1, 13, 4, 57, 6, 48, 2, 89, 0, 67, 
    7, 59, 8, 90, 5, 30, 3, 35, 4,  1, 0, 33, 1, 48, 2, 18, 6,  9, 
    2, 14, 6, 35, 8, 31, 7,  3, 0, 84, 1, 19, 4, 53, 3, 51, 5, 52, 
    0, 34, 4, 69, 7,  5, 6, 37, 5, 63, 3, 50, 1, 70, 2, 45, 8, 32, 
    4, 71, 7, 33, 8, 66, 1, 64, 5, 85, 6, 51, 3, 76, 2, 87, 0, 19, 
    1, 83, 3, 53, 5, 55, 7, 65, 6, 91, 0, 44, 2, 18, 4, 24, 8, 70, 
    2, 95, 7, 37, 6, 38, 1, 84, 5, 47, 0, 12, 4, 25, 3, 22, 8,  4
  };
  const int q1592[] = {
    9, 9, // Number of jobs and machines
    5, 34, 8,  2, 4, 10, 0, 23, 3, 89, 1, 86, 7, 48, 2, 74, 6, 20, 
    2, 42, 8, 44, 3, 40, 5, 51, 4, 13, 6, 57, 0, 16, 1, 91, 7, 71, 
    3, 33, 6, 51, 8, 89, 7,  6, 0, 46, 4, 72, 5, 63, 1, 97, 2, 25, 
    0, 36, 3, 58, 1, 11, 4, 23, 2, 71, 8, 69, 5, 55, 7, 14, 6, 46, 
    6, 18, 3, 26, 4, 78, 8, 29, 7, 45, 1, 15, 2, 66, 0, 30, 5, 79, 
    7, 78, 0, 39, 3,  6, 1, 28, 2, 97, 8, 87, 5, 22, 4, 27, 6, 23, 
    7, 84, 4, 31, 2, 85, 5, 42, 6, 73, 3,  5, 8, 51, 1, 48, 0, 91, 
    4,  5, 6, 41, 8, 96, 7, 83, 3, 91, 0, 87, 5, 64, 1, 42, 2, 12, 
    8, 44, 7, 30, 1, 22, 2, 48, 4, 67, 6, 83, 0, 17, 5, 96, 3, 50
  };
  const int q1593[] = {
    9, 9, // Number of jobs and machines
    3, 31, 8, 88, 5, 13, 7,  7, 1, 32, 4, 52, 2, 26, 6,  3, 0, 55, 
    1, 78, 4, 81, 3, 43, 5, 92, 2, 46, 8, 90, 0, 93, 7, 63, 6, 77, 
    1, 33, 5, 12, 4, 67, 0, 24, 3, 21, 6, 74, 7, 10, 2, 48, 8, 36, 
    3, 39, 2,  8, 1, 18, 5, 49, 8, 16, 6, 72, 0, 82, 4,  5, 7, 32, 
    7, 11, 4, 76, 6,  2, 2, 31, 8, 64, 1, 87, 5, 74, 3, 35, 0, 15, 
    3, 49, 0, 39, 7, 79, 2, 89, 8, 13, 1, 68, 4, 14, 6, 42, 5, 92, 
    4, 74, 6, 72, 3, 70, 0, 17, 7, 33, 5,  6, 1, 15, 8, 89, 2, 60, 
    2, 65, 7, 24, 5, 63, 3, 53, 0, 25, 6, 29, 4, 19, 8, 36, 1, 81, 
    5, 40, 4, 23, 3, 12, 8, 38, 6, 79, 7, 52, 0, 44, 2, 85, 1,  4
  };
  const int q1594[] = {
    9, 9, // Number of jobs and machines
    8, 42, 5, 29, 1, 39, 0, 17, 3, 25, 7, 91, 6, 59, 4,  8, 2, 77, 
    6, 82, 1, 75, 7, 90, 0, 22, 3, 42, 5, 88, 2, 36, 8, 53, 4, 56, 
    3, 55, 2, 11, 7, 54, 8, 11, 0,  5, 4, 99, 5, 34, 6, 23, 1, 18, 
    6,  5, 7, 37, 5, 26, 8, 82, 2, 86, 4, 21, 3, 68, 1, 43, 0, 57, 
    8, 21, 1, 69, 7, 97, 6, 21, 3, 80, 4, 90, 5, 29, 0, 73, 2, 98, 
    7, 79, 2, 72, 4, 42, 5, 37, 6, 80, 8, 76, 3,  8, 1, 52, 0, 33, 
    3, 64, 4, 92, 5, 13, 0, 74, 7, 81, 2, 98, 8, 11, 1, 27, 6,  1, 
    6, 76, 4,  4, 3, 89, 5, 64, 0, 25, 2, 58, 1,  8, 8, 83, 7,  9, 
    2, 36, 0, 77, 7, 28, 1, 92, 3, 95, 8, 94, 6, 46, 4, 99, 5, 60
  };
  const int q1595[] = {
    9, 9, // Number of jobs and machines
    0, 84, 1, 36, 6, 19, 2, 93, 5, 15, 7, 76, 4, 62, 3, 40, 8, 50, 
    5, 58, 1, 32, 0, 70, 3, 10, 8, 29, 4, 84, 2, 96, 6, 58, 7,  5, 
    0, 13, 2, 62, 8,  1, 4, 45, 3, 96, 6, 38, 5, 49, 7, 41, 1, 79, 
    0, 39, 6, 29, 5, 97, 2, 91, 4, 93, 3, 26, 7, 88, 1, 83, 8, 12, 
    8, 53, 2, 68, 4, 38, 3,  3, 1,  5, 0, 72, 6, 43, 5, 61, 7, 41, 
    6, 23, 3, 27, 5, 63, 7, 68, 8, 68, 2, 63, 4, 45, 0, 53, 1, 60, 
    4, 44, 8, 62, 1, 31, 5, 37, 0, 82, 2, 21, 7,  7, 3, 91, 6, 56, 
    1, 96, 0, 33, 7, 65, 6,  4, 2, 41, 4, 58, 3, 48, 5,  2, 8, 26, 
    7, 13, 2, 95, 6, 32, 4, 78, 8, 56, 5, 62, 0, 51, 1, 85, 3, 75
  };
  const int q1596[] = {
    9, 9, // Number of jobs and machines
    3, 28, 1, 25, 0, 82, 8, 61, 6,  8, 7,  2, 2, 37, 5, 63, 4, 56, 
    4, 78, 1, 36, 5, 78, 2, 26, 6, 50, 3, 25, 8, 94, 0, 56, 7, 64, 
    1, 68, 2, 74, 5, 52, 8, 33, 6,  9, 3, 98, 4,  5, 0, 54, 7, 51, 
    4, 54, 6, 17, 5, 15, 2, 72, 8, 17, 7,  4, 3, 60, 0, 37, 1, 46, 
    0, 89, 7, 88, 8, 14, 4,  7, 3, 37, 2, 66, 6, 47, 1, 85, 5, 99, 
    7, 95, 2, 40, 8, 12, 0, 33, 3, 22, 1, 39, 4, 33, 5, 11, 6, 85, 
    3, 47, 2, 40, 6, 33, 0, 51, 5,  2, 1, 42, 7, 56, 8, 61, 4, 91, 
    4,  5, 2, 97, 1, 34, 0, 69, 7, 74, 3, 29, 6,  6, 8, 38, 5, 95, 
    8, 71, 1, 51, 3, 99, 2, 30, 6,  2, 7, 94, 4, 64, 0,  3, 5, 64
  };
  const int q1597[] = {
    9, 9, // Number of jobs and machines
    4, 13, 1, 54, 5, 14, 7, 57, 6, 37, 0, 71, 2, 38, 8, 84, 3, 28, 
    8, 72, 2, 79, 4, 95, 0, 10, 6, 20, 7, 46, 5, 33, 3,  2, 1, 33, 
    5, 48, 4, 27, 3, 35, 7, 54, 0, 67, 8, 38, 2, 81, 6, 57, 1, 41, 
    4,  6, 2,  8, 7, 45, 1, 84, 3, 99, 0, 73, 6, 85, 8, 95, 5, 41, 
    2, 26, 5, 46, 8, 80, 3, 18, 6, 89, 0, 18, 1, 14, 7, 81, 4, 35, 
    1, 66, 7, 37, 6, 99, 2, 12, 0, 92, 8, 85, 5, 27, 4, 69, 3, 73, 
    6,  4, 8, 96, 2, 59, 7,  8, 0, 77, 1,  5, 4, 38, 5, 92, 3, 22, 
    1, 53, 5, 91, 3, 20, 6, 14, 0, 87, 7, 14, 2,  4, 8, 33, 4, 73, 
    7, 33, 3, 16, 4, 26, 2, 68, 6, 74, 1, 23, 5, 61, 0, 69, 8, 41
  };
  const int q1598[] = {
    9, 9, // Number of jobs and machines
    3, 89, 2, 58, 8, 38, 5, 64, 7, 97, 1, 79, 4, 32, 6, 44, 0, 57, 
    1, 32, 8, 27, 7, 42, 5, 15, 3,  5, 2, 76, 6, 72, 4, 15, 0,  7, 
    5, 39, 7, 74, 8, 95, 6,  9, 4, 96, 2, 59, 1, 48, 3, 18, 0, 82, 
    4, 25, 0, 84, 2, 37, 7, 25, 5, 79, 1, 75, 3, 95, 6, 59, 8, 52, 
    3, 84, 2, 70, 4, 94, 6, 66, 0, 71, 1, 63, 7, 23, 5, 54, 8,  1, 
    6, 78, 4, 80, 8, 53, 1, 12, 3, 11, 5, 57, 7, 27, 0, 41, 2, 77, 
    4, 26, 1, 96, 0,  6, 8, 82, 7, 82, 5, 67, 6, 47, 3, 98, 2, 96, 
    6, 12, 2, 74, 8, 45, 0, 93, 3, 78, 5, 72, 1, 21, 7, 71, 4, 12, 
    6, 53, 8, 82, 0, 43, 1,  4, 7, 99, 3, 92, 2, 43, 5, 21, 4, 73
  };
  const int q1599[] = {
    9, 9, // Number of jobs and machines
    1, 14, 8,  4, 4, 56, 7,  4, 2, 18, 0, 31, 3, 62, 6, 81, 5, 94, 
    8, 71, 1, 37, 5, 71, 6, 65, 0, 54, 4,  7, 3, 50, 7, 67, 2, 23, 
    2, 26, 6, 80, 8, 90, 1, 28, 3,  3, 4, 63, 5, 34, 0, 50, 7, 74, 
    6, 54, 7, 23, 1, 63, 5, 73, 8, 11, 0, 36, 4, 42, 2, 99, 3, 69, 
    1, 25, 4, 71, 6, 46, 8, 58, 5, 24, 2, 59, 0, 99, 3, 11, 7, 62, 
    0,  6, 3, 82, 1, 45, 7, 87, 8, 59, 6, 53, 4, 31, 2, 96, 5, 53, 
    0, 37, 6, 21, 2, 13, 5, 81, 3, 86, 4,  1, 7, 60, 1, 73, 8, 19, 
    1, 99, 8, 48, 2, 21, 0, 83, 4, 31, 7, 59, 5, 69, 3, 15, 6, 50, 
    5,  2, 6, 53, 8, 54, 2, 12, 1, 24, 4, 23, 7, 14, 3, 35, 0, 83
  };
  const int q1600[] = {
    9, 9, // Number of jobs and machines
    7, 98, 3,  4, 4, 80, 1,  8, 5, 48, 2, 26, 8, 54, 6,  2, 0, 59, 
    1, 80, 6, 16, 2, 50, 5, 11, 7,  9, 0, 93, 3, 42, 4, 34, 8, 72, 
    5, 85, 3, 83, 1, 64, 7, 11, 2, 93, 6, 15, 0, 76, 8, 26, 4, 37, 
    2, 38, 3, 61, 1, 50, 6, 70, 7, 97, 4, 29, 8, 10, 0, 91, 5, 18, 
    1, 78, 5, 93, 2, 30, 6, 77, 4, 62, 8, 49, 0, 45, 3, 90, 7, 58, 
    7, 85, 0, 69, 8, 45, 2, 47, 5, 29, 4, 67, 3, 31, 1,  4, 6, 31, 
    3, 30, 6,  6, 7, 31, 8, 39, 4, 83, 5, 80, 1, 57, 2, 48, 0, 72, 
    5, 42, 8, 41, 7, 26, 1, 86, 6, 11, 3, 77, 4, 38, 0, 27, 2, 37, 
    4, 37, 8, 14, 0, 40, 3, 50, 1, 11, 2, 13, 6, 92, 7, 36, 5, 13
  };
  const int q1601[] = {
    9, 9, // Number of jobs and machines
    3, 47, 0, 59, 2, 95, 7, 74, 4, 56, 6, 56, 8, 18, 1, 67, 5, 49, 
    7, 21, 4, 47, 5, 54, 8, 69, 0, 94, 2, 70, 6,  5, 1, 98, 3,  4, 
    1, 99, 8, 96, 6, 50, 2, 25, 3, 32, 7, 32, 4, 82, 5, 95, 0, 88, 
    2, 17, 5, 95, 6, 60, 7, 41, 8, 43, 4,  8, 0, 53, 3,  8, 1, 62, 
    5, 24, 1, 66, 3, 65, 2, 30, 8, 58, 4,  8, 7, 24, 0, 22, 6,  8, 
    7,  4, 2, 82, 6, 55, 0, 90, 8, 80, 4, 11, 3, 40, 1, 50, 5, 64, 
    3, 89, 2, 69, 1,  9, 4, 70, 0, 83, 7, 76, 6, 53, 8, 22, 5, 89, 
    1, 81, 6, 26, 4, 29, 7, 84, 2, 98, 3, 34, 5,  6, 0, 79, 8, 50, 
    3, 34, 0, 97, 8, 51, 4, 64, 1, 73, 6, 78, 2, 86, 5, 23, 7, 13
  };
  const int q1602[] = {
    9, 9, // Number of jobs and machines
    4, 98, 1, 80, 3, 61, 5, 22, 0, 85, 7, 27, 8, 39, 2, 96, 6, 42, 
    3, 14, 1, 46, 0, 89, 6, 33, 8, 60, 2, 32, 5, 13, 7, 46, 4, 16, 
    1,  8, 4, 75, 7, 85, 2, 73, 8, 43, 3, 30, 0, 91, 5, 93, 6, 89, 
    6, 25, 0, 84, 8, 43, 4, 44, 1, 88, 3, 40, 7, 77, 5, 79, 2, 76, 
    1, 70, 7, 65, 6, 71, 4, 40, 2, 82, 8, 60, 0, 60, 3, 13, 5, 28, 
    3, 26, 1, 83, 5, 77, 6, 88, 4, 75, 2, 66, 7, 18, 8, 25, 0, 44, 
    7, 33, 2, 47, 6, 72, 3, 81, 4, 53, 1, 28, 8, 14, 5, 73, 0, 18, 
    8,  6, 7, 10, 0, 74, 2, 97, 6, 51, 1, 61, 3, 93, 4, 72, 5, 14, 
    6,  2, 8, 22, 1, 87, 0,  2, 3, 24, 4, 70, 5, 33, 7, 52, 2, 24
  };
  const int q1603[] = {
    9, 9, // Number of jobs and machines
    2,  5, 8, 22, 0,  4, 5, 16, 6, 15, 3, 41, 4, 58, 7, 83, 1, 59, 
    6, 71, 4, 95, 3, 41, 7, 35, 8, 54, 1, 67, 5, 44, 0, 51, 2, 14, 
    3, 15, 2, 85, 6, 95, 1, 67, 4, 56, 5, 52, 7, 28, 0, 18, 8, 98, 
    7, 49, 1,  9, 3, 59, 2, 67, 0, 75, 4, 25, 6, 31, 8, 97, 5, 12, 
    5, 62, 2, 60, 1, 52, 8, 95, 6, 30, 4, 80, 3,  4, 7, 56, 0, 38, 
    0, 89, 4, 57, 3, 84, 2, 71, 8, 84, 7,  5, 1, 71, 5, 25, 6, 53, 
    1, 69, 6, 14, 2, 39, 4, 97, 3,  9, 0, 47, 8, 92, 5, 34, 7, 31, 
    1, 50, 7, 29, 4, 86, 3, 65, 0,  8, 8, 11, 2, 45, 5, 41, 6, 66, 
    1, 68, 2, 65, 3, 60, 8, 75, 7, 62, 0, 29, 6, 57, 4,  5, 5, 79
  };
  const int q1604[] = {
    9, 9, // Number of jobs and machines
    4, 28, 3, 19, 8,  5, 5, 29, 1, 40, 6, 65, 7, 26, 0, 77, 2, 37, 
    1, 29, 6, 42, 3, 20, 8, 79, 7,  9, 0, 80, 5, 12, 4, 51, 2, 46, 
    4, 80, 8, 78, 3,  5, 2, 75, 1, 21, 7, 14, 5,  9, 0, 59, 6, 49, 
    4, 14, 2, 58, 5, 13, 7, 23, 8, 51, 6, 89, 3, 40, 0, 83, 1, 93, 
    3, 89, 0, 23, 2, 19, 8, 52, 7, 96, 5, 45, 6, 48, 1, 31, 4, 80, 
    2, 30, 0, 18, 4, 56, 1, 79, 7, 39, 6, 49, 8, 49, 5, 41, 3, 38, 
    1, 79, 3, 76, 7, 50, 0, 66, 5, 70, 8,  7, 4,  2, 2,  9, 6,  4, 
    8, 77, 4, 80, 5, 43, 6, 83, 3, 62, 1,  7, 2, 67, 0, 76, 7, 93, 
    2, 81, 8, 58, 6, 14, 3, 61, 7, 72, 5, 45, 4, 62, 1, 59, 0, 39
  };
  const int q1605[] = {
    9, 9, // Number of jobs and machines
    3, 43, 1, 11, 5, 88, 6, 50, 2, 43, 8, 72, 4, 46, 0, 58, 7, 13, 
    4, 60, 6, 34, 3, 42, 2, 19, 5, 94, 1, 60, 8, 53, 0, 72, 7, 23, 
    0,  8, 3, 33, 6, 96, 1, 34, 8,  5, 5, 24, 2, 18, 4, 45, 7, 65, 
    1, 27, 5, 82, 2, 38, 6, 88, 8, 47, 3, 24, 0, 59, 4,  2, 7, 27, 
    8, 70, 3, 49, 2, 97, 4, 29, 7, 96, 1, 91, 6, 77, 5,  3, 0, 45, 
    5, 74, 6, 68, 4, 58, 2, 53, 0, 86, 8, 73, 7, 99, 1, 18, 3, 18, 
    4, 58, 2, 18, 6, 46, 7, 45, 0, 53, 1, 68, 8,  3, 5, 30, 3, 86, 
    5, 39, 2, 64, 8, 80, 1, 59, 0, 43, 4, 80, 3, 68, 7, 25, 6, 72, 
    1, 89, 3, 11, 2, 69, 0, 25, 5, 53, 8, 13, 7,  8, 6,  4, 4, 56
  };
  const int q1606[] = {
    9, 9, // Number of jobs and machines
    8, 64, 6, 77, 1, 85, 0, 70, 4, 69, 5, 55, 2, 24, 7, 37, 3, 13, 
    8, 60, 7, 23, 3, 56, 0, 66, 6, 17, 1, 79, 4, 34, 2, 57, 5, 73, 
    7, 71, 6, 12, 1, 13, 8, 16, 2, 17, 5, 98, 3, 31, 0,  2, 4, 53, 
    5, 22, 6, 20, 1, 29, 3, 98, 2, 61, 0, 16, 7, 57, 4, 13, 8, 16, 
    5, 84, 1, 63, 4,  9, 2, 84, 7, 52, 0, 99, 8, 15, 6, 65, 3, 52, 
    4, 67, 8, 74, 5, 79, 3, 23, 6, 82, 1, 83, 0, 40, 7, 78, 2, 91, 
    1, 52, 0, 77, 8, 76, 2, 81, 6, 91, 7, 92, 3, 34, 4, 91, 5, 22, 
    5, 66, 0, 98, 3, 97, 2, 54, 6, 46, 8, 40, 4, 72, 7,  4, 1, 73, 
    8, 99, 2, 17, 3, 53, 6, 14, 7, 59, 1, 44, 5, 33, 0, 43, 4, 87
  };
  const int q1607[] = {
    9, 9, // Number of jobs and machines
    4, 46, 8, 62, 3, 61, 7, 43, 6, 74, 2, 62, 0, 76, 1,  5, 5,  7, 
    3, 13, 6, 32, 1, 60, 7, 50, 8, 42, 5, 69, 0, 84, 2, 94, 4, 89, 
    6, 90, 3, 47, 2, 34, 5,  2, 4, 81, 0, 46, 1, 20, 7, 24, 8, 69, 
    2, 78, 7, 25, 3,  8, 8, 11, 1, 79, 4, 97, 5, 27, 6, 77, 0, 10, 
    8, 43, 1, 30, 7, 21, 6, 23, 5, 43, 2, 46, 4, 37, 0, 43, 3, 30, 
    5, 81, 3, 32, 8, 23, 4,  8, 6, 37, 1, 65, 0, 57, 2, 24, 7, 76, 
    1, 16, 2,  2, 0, 85, 6, 55, 7, 91, 4, 85, 5, 99, 8, 32, 3, 72, 
    0, 67, 4, 96, 1, 55, 8, 12, 6, 46, 5, 49, 2, 45, 7, 40, 3, 24, 
    8, 10, 0, 65, 7, 88, 1, 13, 2, 64, 6, 94, 5, 28, 3, 49, 4, 13
  };
  const int q1608[] = {
    9, 9, // Number of jobs and machines
    5, 48, 4, 56, 7, 83, 2, 87, 8, 42, 3, 22, 6, 51, 1, 40, 0, 12, 
    7, 76, 0, 32, 2, 86, 3, 55, 4, 98, 1,  8, 5, 51, 8, 18, 6, 51, 
    7, 85, 3,  4, 1, 36, 2, 42, 8, 12, 0, 91, 6, 90, 5, 48, 4, 99, 
    0, 25, 7, 57, 2, 43, 1, 73, 4, 98, 5,  6, 8, 48, 6, 98, 3, 41, 
    8, 32, 0, 28, 5, 93, 6, 34, 4, 48, 1, 19, 3, 58, 7,  5, 2, 92, 
    0, 55, 8, 77, 1, 71, 3, 91, 7, 16, 6, 73, 4, 51, 2, 59, 5, 79, 
    2, 22, 0, 34, 7, 80, 8, 52, 1, 81, 3, 48, 6, 76, 4, 22, 5, 38, 
    2, 29, 3, 81, 1, 39, 5, 69, 0, 17, 6, 29, 7, 26, 8, 31, 4, 36, 
    3, 95, 4, 95, 0, 68, 7, 31, 5, 92, 6, 73, 1, 13, 2,  9, 8, 68
  };
  const int q1609[] = {
    9, 9, // Number of jobs and machines
    7, 75, 0, 68, 6, 72, 3, 14, 4, 27, 8, 36, 1, 34, 2, 56, 5, 72, 
    6, 39, 7, 19, 0, 56, 1, 57, 2, 85, 8, 11, 3, 42, 4, 50, 5, 36, 
    0, 33, 3, 11, 7, 25, 2,  5, 4, 19, 5, 29, 1, 45, 6, 63, 8,  1, 
    5, 84, 6, 20, 2, 17, 7, 19, 1, 22, 3, 33, 8, 93, 0, 27, 4, 67, 
    1, 40, 6, 46, 5, 27, 3, 33, 0, 98, 2, 91, 4, 74, 8, 41, 7, 96, 
    6, 59, 1, 47, 2, 96, 3, 85, 4,  7, 0, 66, 7, 66, 8, 86, 5, 63, 
    7, 64, 1, 10, 6, 75, 4,  7, 5, 29, 3, 91, 0, 94, 8, 45, 2, 86, 
    7,  5, 6, 37, 4, 81, 2, 51, 5, 47, 3, 27, 8, 93, 1, 99, 0, 63, 
    6, 66, 0, 78, 5, 68, 3, 94, 2, 35, 1, 82, 4, 52, 8, 92, 7, 22
  };
  const int q1610[] = {
    9, 9, // Number of jobs and machines
    0, 87, 6, 47, 3, 10, 7, 90, 2,  4, 5,  6, 8, 19, 1, 68, 4, 17, 
    8, 38, 2, 33, 3, 22, 7,  1, 6, 17, 0, 52, 4, 16, 1, 84, 5, 19, 
    3, 11, 7, 58, 1, 28, 2, 94, 4, 74, 0, 39, 6, 95, 8, 67, 5, 74, 
    5, 14, 4, 48, 2, 79, 8, 42, 0, 34, 3, 49, 7, 76, 1, 48, 6, 32, 
    8, 69, 1, 54, 2, 49, 3, 41, 7, 50, 5, 43, 6, 97, 0, 19, 4, 97, 
    2, 98, 8, 89, 3, 17, 4,  5, 1, 85, 6, 89, 5, 20, 7, 99, 0, 43, 
    5, 91, 1, 20, 0, 20, 8, 18, 7, 71, 6, 71, 3, 81, 2, 65, 4, 78, 
    0, 14, 8, 40, 7, 32, 6, 14, 5, 74, 2, 90, 3, 49, 1, 42, 4, 34, 
    3, 39, 6, 59, 7, 69, 5, 24, 4, 72, 1,  2, 8, 25, 2, 48, 0, 71
  };
  const int q1611[] = {
    9, 9, // Number of jobs and machines
    5, 44, 8, 39, 7, 15, 0, 89, 4, 53, 3, 79, 2,  6, 1, 81, 6, 34, 
    8, 21, 1, 29, 6, 74, 2, 68, 7, 87, 4, 11, 0, 18, 5,  6, 3, 59, 
    1, 12, 5, 68, 4, 19, 6, 56, 7, 15, 3, 29, 8, 92, 2, 53, 0, 22, 
    4, 47, 3, 84, 2, 92, 5, 86, 8, 47, 6, 43, 1, 39, 0, 56, 7, 95, 
    2, 98, 6,  8, 4, 99, 1,  1, 3, 34, 8, 16, 7, 15, 5, 41, 0, 58, 
    0, 66, 3, 71, 5, 27, 4, 73, 7, 13, 2, 29, 6, 69, 1, 68, 8, 82, 
    3, 20, 1, 16, 4,  1, 8,  8, 0, 15, 7, 87, 2, 23, 6, 40, 5, 95, 
    3, 23, 4, 45, 2, 36, 5,  1, 1, 86, 8, 38, 7, 68, 6, 62, 0, 74, 
    1, 29, 7, 48, 2, 52, 8, 39, 0, 26, 4, 77, 5, 83, 3, 16, 6, 34
  };
  const int q1612[] = {
    9, 9, // Number of jobs and machines
    0, 15, 3, 45, 6,  9, 2, 72, 8, 95, 1,  8, 7, 62, 5, 98, 4, 48, 
    6, 49, 0, 22, 3, 44, 2, 86, 1, 19, 7, 93, 8, 54, 5, 10, 4, 69, 
    3, 64, 1, 91, 8, 10, 0, 87, 6, 55, 2, 23, 5, 47, 7, 70, 4, 60, 
    4, 19, 6,  1, 7, 79, 2, 87, 3, 59, 5, 12, 8, 99, 1, 34, 0, 10, 
    8, 89, 1, 38, 3, 33, 2, 81, 6, 62, 4, 10, 7, 72, 5, 13, 0, 54, 
    2, 56, 0, 98, 1,  5, 6, 47, 4,  5, 3, 87, 7, 57, 5, 82, 8, 90, 
    5, 84, 3, 75, 2, 17, 1, 44, 7, 39, 0, 94, 8, 85, 6, 46, 4, 42, 
    6, 57, 0, 19, 8,  1, 5, 56, 7, 46, 3, 58, 4, 27, 2, 18, 1, 73, 
    4, 87, 3, 61, 7, 75, 0, 69, 6, 62, 2,  1, 8, 21, 1,  4, 5, 76
  };
  const int q1613[] = {
    9, 9, // Number of jobs and machines
    7, 65, 0, 75, 8,  3, 6, 22, 5, 30, 1,  1, 4, 88, 3, 56, 2, 81, 
    7, 65, 2, 82, 6, 68, 0,  3, 1, 73, 4, 42, 3, 36, 8, 34, 5, 42, 
    3, 70, 5, 89, 8, 68, 2, 89, 4, 61, 0,  3, 1, 76, 7, 59, 6, 34, 
    6, 67, 0,  3, 2,  7, 5, 18, 3, 12, 4, 99, 7, 50, 1,  7, 8, 99, 
    4, 22, 3, 38, 0, 15, 1, 43, 2, 25, 6, 39, 5, 73, 7, 29, 8, 50, 
    5, 75, 2, 61, 1, 57, 4, 54, 6, 75, 7, 62, 8, 30, 0, 47, 3, 11, 
    2, 46, 6, 38, 7, 75, 0, 71, 4, 53, 8, 32, 3, 19, 5, 69, 1,  5, 
    7, 62, 3, 75, 0, 99, 5, 41, 2, 84, 4, 42, 8, 93, 6, 63, 1,  6, 
    6, 42, 8, 40, 3, 35, 1, 81, 0, 31, 2, 90, 7, 30, 4, 34, 5, 11
  };
  const int q1614[] = {
    9, 9, // Number of jobs and machines
    1, 31, 4, 64, 0, 40, 2, 20, 6, 76, 8, 32, 3, 53, 7, 97, 5, 46, 
    3, 59, 8, 67, 2, 15, 0, 12, 1,  1, 6, 67, 7, 85, 4, 88, 5, 93, 
    6,  1, 5, 56, 2, 94, 1, 86, 4, 89, 3, 71, 8, 29, 7, 65, 0, 75, 
    0, 47, 7, 28, 8, 37, 3, 93, 6, 47, 1, 89, 2, 42, 5, 40, 4, 21, 
    1,  4, 0, 71, 8, 25, 3, 70, 2, 80, 7, 18, 4, 90, 6, 76, 5, 49, 
    4, 45, 7,  6, 8, 16, 2, 47, 6, 96, 5, 74, 0,  5, 1, 66, 3, 89, 
    0,  9, 7, 32, 8, 88, 4, 90, 6, 95, 1, 38, 3, 75, 2, 23, 5, 21, 
    8, 38, 2, 34, 4, 68, 0, 87, 7, 15, 1, 34, 5, 57, 3, 98, 6, 31, 
    1, 33, 2, 67, 5, 67, 6, 74, 0, 55, 8, 25, 7, 74, 3, 54, 4, 52
  };
  const int q1615[] = {
    9, 9, // Number of jobs and machines
    3, 10, 2, 12, 1, 59, 7, 90, 8, 65, 4,  1, 6,  9, 5, 52, 0, 52, 
    6, 58, 2, 26, 7,  3, 0, 41, 3, 41, 4, 32, 5, 18, 1,  4, 8, 45, 
    8, 46, 0, 97, 2, 69, 3, 56, 1, 27, 6, 47, 4, 55, 7, 11, 5, 15, 
    3, 37, 0, 62, 8, 42, 5,  3, 2,  1, 4, 76, 1, 15, 6, 99, 7, 30, 
    6, 51, 3, 58, 5, 94, 2, 90, 8, 85, 4, 44, 1, 13, 0, 62, 7, 92, 
    4, 90, 6, 51, 8, 45, 5,  5, 2, 94, 7, 14, 1, 64, 0,  9, 3,  7, 
    5, 81, 4, 29, 3, 69, 6, 63, 0, 51, 8, 60, 2, 95, 7, 24, 1, 92, 
    6, 42, 2, 38, 3, 43, 5, 79, 1, 77, 7, 34, 4, 44, 0, 11, 8, 23, 
    2,  3, 1,  5, 3, 85, 4, 95, 6,  2, 0, 77, 5, 42, 8, 76, 7, 67
  };
  const int q1616[] = {
    9, 9, // Number of jobs and machines
    4, 72, 2, 37, 0, 36, 1, 40, 7, 24, 8,  9, 6, 99, 3, 51, 5, 24, 
    2, 95, 8, 56, 0, 11, 1, 59, 5, 17, 4, 31, 6, 47, 7, 73, 3, 23, 
    4, 29, 6, 27, 1, 65, 8, 56, 2, 26, 3, 88, 7, 20, 5, 68, 0, 53, 
    7, 12, 1, 69, 0, 75, 6, 36, 5, 22, 3,  4, 4, 75, 8, 33, 2, 94, 
    0, 29, 6, 18, 3, 28, 1,  7, 4, 60, 8, 56, 2, 16, 5, 37, 7, 59, 
    3, 10, 2, 60, 6, 61, 1, 80, 5, 19, 4,  6, 8, 36, 7, 21, 0, 37, 
    6, 45, 4, 94, 1, 79, 0, 29, 2, 72, 3, 64, 5, 73, 7, 89, 8,  8, 
    1, 35, 8, 75, 5, 93, 2, 90, 0, 36, 3, 46, 7, 34, 4, 46, 6, 90, 
    2, 12, 1, 91, 0, 77, 5, 75, 6, 34, 7, 26, 3, 68, 8, 98, 4, 16
  };
  const int q1617[] = {
    9, 9, // Number of jobs and machines
    0, 29, 6, 35, 3, 32, 5, 48, 7,  2, 8, 27, 4, 46, 1, 22, 2, 89, 
    5, 32, 0, 92, 8, 68, 2, 92, 6, 42, 4, 44, 7, 10, 1, 21, 3, 22, 
    2, 71, 6, 13, 4,  5, 3, 55, 1, 35, 0, 75, 7, 24, 5, 61, 8, 48, 
    2, 44, 6, 15, 1, 30, 5, 60, 0, 85, 8, 69, 7, 86, 4, 85, 3,  7, 
    4,  2, 2, 80, 0, 67, 1, 44, 3, 29, 6, 43, 8, 97, 7, 87, 5, 62, 
    6, 85, 0, 11, 1, 60, 8, 83, 5, 79, 3,  2, 2, 37, 7, 10, 4, 91, 
    4, 22, 0, 16, 8, 39, 5, 14, 7, 66, 6, 20, 3, 53, 2, 99, 1, 66, 
    2, 21, 0, 97, 6, 73, 1, 32, 8, 24, 7, 49, 5, 62, 3, 95, 4, 35, 
    1, 37, 6, 69, 5, 63, 0, 98, 3, 83, 8, 25, 7, 83, 2, 23, 4, 27
  };
  const int q1618[] = {
    9, 9, // Number of jobs and machines
    8, 78, 1, 33, 2, 20, 5, 62, 4, 62, 6, 93, 7, 68, 0, 53, 3, 16, 
    4, 24, 7, 79, 0, 46, 6, 10, 1, 67, 3,  4, 5, 44, 8, 11, 2,  4, 
    7,  4, 3, 82, 2, 93, 8,  9, 0, 19, 1, 61, 6,  7, 4, 78, 5,  2, 
    4,  3, 2, 45, 8, 30, 1, 50, 5, 75, 0, 73, 6,  6, 7, 18, 3, 96, 
    8, 76, 7, 90, 6,  6, 2, 91, 4, 31, 0, 45, 3, 87, 5, 86, 1, 83, 
    0,  5, 2, 66, 4, 53, 6,  2, 5, 48, 1, 75, 7, 42, 8, 67, 3, 82, 
    5, 85, 1, 17, 0, 11, 2, 33, 7, 41, 8, 69, 4,  1, 6, 19, 3, 25, 
    8, 44, 0, 87, 2, 52, 3, 92, 7,  4, 5, 61, 1, 67, 6,  5, 4, 18, 
    7, 45, 2, 17, 1, 29, 0, 29, 5, 56, 8, 42, 4, 63, 3, 14, 6, 51
  };
  const int q1619[] = {
    9, 9, // Number of jobs and machines
    0, 31, 7,  7, 2, 98, 4, 83, 1, 27, 5, 43, 6, 50, 8,  7, 3, 23, 
    7, 40, 5, 51, 0, 96, 1, 73, 3, 57, 4, 83, 8,  8, 2, 51, 6,  8, 
    8, 95, 7, 84, 5, 74, 2, 79, 4, 58, 0, 20, 1, 18, 3, 50, 6, 76, 
    3, 58, 7, 40, 1, 21, 0, 65, 4, 79, 6, 70, 8, 58, 5, 65, 2, 77, 
    0, 47, 6, 66, 3, 31, 7, 74, 5, 57, 8, 90, 4, 82, 1, 17, 2, 13, 
    2, 88, 8, 91, 4,  8, 0, 16, 6,  7, 1,  5, 5, 99, 7, 51, 3, 37, 
    3, 61, 4,  8, 5, 19, 2, 85, 1, 84, 0,  6, 8, 32, 6, 80, 7, 35, 
    8, 49, 5, 34, 1, 44, 6, 62, 3, 37, 4, 43, 7, 98, 0, 21, 2, 97, 
    1, 58, 0, 43, 7, 84, 8, 39, 5, 80, 2, 10, 3, 71, 4, 51, 6,  3
  };
  const int q1620[] = {
    9, 9, // Number of jobs and machines
    8, 19, 0,  7, 3, 49, 4,  8, 2, 37, 7, 24, 1, 92, 5, 17, 6, 76, 
    7, 24, 5, 83, 6, 71, 1, 27, 3, 68, 2, 12, 0, 70, 8, 39, 4,  8, 
    2, 92, 5, 40, 1, 39, 7, 31, 0, 48, 4, 57, 8, 56, 3, 89, 6, 57, 
    2, 84, 3, 81, 4, 59, 8, 73, 7, 54, 6,  1, 5, 12, 0, 15, 1, 49, 
    4, 95, 1, 27, 7, 47, 6, 42, 5, 97, 2, 50, 0, 52, 3, 48, 8, 11, 
    7,  9, 8, 60, 5, 32, 3,  7, 0, 17, 4, 38, 1, 77, 6, 11, 2, 74, 
    4, 45, 2, 20, 3, 60, 1,  3, 6, 41, 8, 56, 0, 55, 5, 70, 7, 60, 
    0, 99, 6, 37, 3, 11, 1, 96, 5, 23, 2, 93, 8, 43, 7, 18, 4, 50, 
    1, 46, 7, 63, 8, 26, 0, 14, 3, 48, 2, 83, 4, 36, 6, 50, 5, 97
  };
  const int q1621[] = {
    9, 9, // Number of jobs and machines
    7, 59, 0, 98, 6, 98, 1, 93, 5, 37, 2, 92, 8,  6, 4, 65, 3, 76, 
    6, 15, 7, 50, 8, 86, 3, 58, 4, 59, 1, 71, 2, 62, 5,  9, 0, 69, 
    1,  3, 4, 69, 5, 77, 2,  2, 8, 39, 3, 20, 6, 82, 0, 39, 7,  1, 
    5, 51, 4, 19, 2, 21, 6, 35, 3, 67, 7,  6, 0, 15, 1, 27, 8, 93, 
    2, 52, 7, 46, 5, 51, 4, 51, 1, 79, 3,  1, 0, 92, 6, 58, 8, 67, 
    5, 47, 1, 77, 8, 74, 6, 26, 0, 46, 3,  2, 2, 94, 7, 89, 4,  5, 
    7, 47, 8,  6, 5, 79, 4, 34, 1, 21, 6,  9, 3, 19, 0, 38, 2, 67, 
    6,  4, 1, 94, 8, 39, 5, 61, 4, 79, 2, 84, 0, 27, 7, 78, 3, 39, 
    3, 56, 1, 64, 2, 58, 6, 74, 8, 37, 4, 93, 7, 47, 5,  6, 0, 11
  };
  const int q1622[] = {
    9, 9, // Number of jobs and machines
    3, 75, 1, 60, 6, 96, 8,  8, 0, 78, 4, 11, 2, 27, 7, 26, 5, 33, 
    4, 40, 7, 48, 5, 28, 6,  9, 0, 18, 1, 10, 8, 16, 2, 80, 3, 12, 
    1, 15, 2, 85, 4, 31, 0, 10, 3, 90, 5, 96, 8, 92, 6, 45, 7, 80, 
    4, 37, 5, 55, 3,  3, 7, 22, 0, 15, 1, 45, 8, 47, 2, 34, 6, 33, 
    8, 22, 4, 92, 5, 41, 3, 29, 2, 18, 1, 74, 7, 87, 6, 75, 0, 17, 
    6, 36, 8, 45, 5, 42, 7, 29, 2, 44, 1, 31, 4, 90, 3, 43, 0,  9, 
    6, 30, 3, 18, 1, 11, 2, 79, 5,  2, 0, 63, 4, 70, 7, 75, 8, 30, 
    0, 37, 8, 28, 4,  6, 3, 92, 7,  7, 2, 57, 1, 95, 6, 99, 5,  4, 
    3, 98, 1, 36, 5, 66, 8, 40, 6, 22, 0, 61, 2, 64, 4, 33, 7, 43
  };
  const int q1623[] = {
    9, 9, // Number of jobs and machines
    8, 60, 3, 52, 0, 95, 2, 59, 5, 96, 4, 84, 6, 88, 1,  4, 7, 26, 
    8, 35, 5, 52, 6, 60, 2, 90, 0, 68, 7, 55, 3, 17, 4, 12, 1, 83, 
    7,  4, 1, 85, 3, 85, 4, 23, 2, 50, 6, 73, 8, 36, 0, 44, 5, 73, 
    5, 83, 2, 13, 1, 54, 4, 33, 8, 62, 0, 72, 7, 50, 3, 95, 6, 65, 
    1, 79, 7, 51, 8, 83, 6, 41, 2, 34, 0, 13, 5, 24, 4, 23, 3, 94, 
    2, 79, 4, 92, 6, 92, 5, 92, 0, 65, 7, 84, 3, 57, 8, 43, 1,  9, 
    1, 61, 2, 44, 6,  8, 3, 31, 7, 18, 8, 21, 5, 93, 4, 48, 0, 71, 
    4, 61, 1, 63, 6, 33, 2, 45, 5, 42, 0, 12, 7, 58, 8, 69, 3, 68, 
    5,  6, 6, 20, 7,  5, 0, 26, 4, 40, 2, 22, 8, 50, 3, 15, 1, 49
  };
  const int q1624[] = {
    9, 9, // Number of jobs and machines
    6, 14, 3, 19, 1, 22, 7, 93, 8, 47, 5, 88, 4, 23, 2,  1, 0, 12, 
    5, 70, 1, 89, 4, 88, 2, 13, 8, 54, 6, 24, 0, 81, 7, 18, 3, 63, 
    6, 25, 1, 29, 0, 91, 7, 13, 4, 57, 5, 94, 8,  6, 2, 45, 3, 82, 
    2, 11, 3, 44, 8, 35, 7, 53, 4, 59, 5, 68, 1, 85, 0, 63, 6, 34, 
    2,  4, 1, 19, 7, 53, 3,  7, 0,  6, 8, 12, 5, 77, 6, 68, 4, 44, 
    5, 80, 6, 91, 2, 92, 3, 33, 8, 21, 1, 89, 7, 58, 0, 53, 4, 94, 
    7, 82, 2, 45, 4, 92, 6, 91, 1, 40, 3, 85, 5, 42, 0, 42, 8, 79, 
    2, 80, 1, 81, 4, 98, 8, 94, 7, 59, 6,  1, 3, 16, 0, 81, 5, 90, 
    4, 58, 3, 30, 2, 84, 8,  9, 7, 32, 5, 31, 0,  5, 1, 21, 6, 91
  };
  const int q1625[] = {
    9, 9, // Number of jobs and machines
    8, 55, 1, 18, 4, 64, 2, 67, 3, 30, 6, 16, 0, 11, 7, 37, 5, 16, 
    1, 42, 5, 37, 3, 28, 8, 28, 6, 95, 2,  6, 0, 13, 4,  8, 7, 10, 
    8, 12, 0, 18, 4, 20, 3, 82, 1, 19, 5, 76, 6, 38, 2, 46, 7,  2, 
    8, 95, 0, 70, 7,  7, 6, 81, 1, 59, 4, 89, 3, 97, 5, 59, 2, 25, 
    8, 50, 3, 15, 5,  7, 1, 31, 2, 43, 7, 28, 6, 22, 0, 82, 4, 80, 
    2, 93, 7, 64, 8, 89, 1, 37, 4, 89, 6, 73, 0, 38, 3, 60, 5, 38, 
    7, 34, 5, 59, 1, 37, 8, 52, 0, 79, 6,  3, 2, 76, 4, 91, 3, 51, 
    0, 67, 5, 30, 6, 38, 1, 61, 3, 49, 8, 26, 2, 96, 4, 74, 7, 58, 
    8,  7, 1, 75, 7, 39, 0, 66, 2, 86, 4, 25, 6, 48, 5, 69, 3, 66
  };
  const int q1626[] = {
    9, 9, // Number of jobs and machines
    8, 74, 3, 88, 0, 76, 4, 92, 1, 32, 2, 82, 6, 46, 7, 27, 5,  6, 
    3, 16, 2, 97, 5, 15, 0, 53, 7, 24, 8, 57, 4, 24, 1, 56, 6, 51, 
    7, 89, 4, 54, 0, 83, 1, 81, 8, 61, 3, 39, 5, 80, 2, 99, 6, 67, 
    1, 94, 5, 83, 4, 14, 8, 34, 7,  7, 0, 59, 2, 67, 6, 42, 3, 46, 
    3, 39, 4, 72, 0, 34, 5, 25, 1, 98, 2, 27, 8, 12, 7, 99, 6,  2, 
    0, 52, 1, 54, 6,  1, 2, 60, 5, 38, 4, 97, 8, 61, 3, 53, 7, 30, 
    7, 83, 3, 62, 8,  7, 6, 46, 4, 30, 2,  7, 0, 73, 5,  9, 1, 47, 
    8, 76, 3, 55, 2, 72, 5, 22, 1, 77, 0,  1, 4, 86, 6, 90, 7, 70, 
    0, 77, 6, 18, 3, 75, 4, 29, 2, 83, 8, 43, 5, 91, 1, 36, 7, 15
  };
  const int q1627[] = {
    9, 9, // Number of jobs and machines
    6, 64, 4, 73, 8, 53, 5, 90, 1, 15, 7, 92, 2, 39, 3, 85, 0, 11, 
    8, 48, 2, 36, 3, 59, 4, 58, 0, 26, 7, 71, 5, 79, 6, 58, 1, 54, 
    6, 16, 0, 56, 5, 38, 7, 41, 4, 62, 1, 13, 3, 70, 8, 63, 2, 49, 
    8, 12, 7,  2, 3, 73, 1, 68, 2, 35, 5, 76, 6, 93, 0, 99, 4, 23, 
    3, 16, 0, 29, 4, 60, 5, 10, 1, 83, 8, 68, 6, 44, 2, 29, 7, 49, 
    8, 68, 5, 71, 0,  8, 1, 35, 7, 76, 3, 54, 6, 79, 4, 94, 2, 49, 
    0, 63, 7, 55, 1, 83, 3, 39, 4, 32, 6, 17, 2,  4, 8, 13, 5, 59, 
    0, 48, 6, 54, 3, 11, 5, 45, 2, 24, 8, 13, 4, 77, 1, 86, 7, 77, 
    8, 71, 2, 45, 5, 65, 3, 99, 1, 94, 0, 41, 6, 77, 4, 56, 7, 39
  };
  const int q1628[] = {
    9, 9, // Number of jobs and machines
    6, 40, 5, 98, 2, 22, 0, 91, 7,  6, 4,  1, 8, 34, 3, 47, 1,  1, 
    8, 54, 1, 29, 0, 28, 3, 12, 6, 34, 7, 92, 2, 75, 5, 45, 4, 18, 
    3,  5, 5, 42, 0, 32, 7, 94, 2, 64, 6, 47, 1, 80, 4, 58, 8, 13, 
    5,  3, 4, 90, 6, 84, 3, 58, 0, 10, 7, 66, 2,  5, 8, 33, 1, 90, 
    1, 95, 2, 63, 8, 95, 6, 58, 3, 24, 4, 97, 5, 10, 7, 97, 0, 16, 
    4, 73, 1, 62, 8, 14, 0, 24, 3, 98, 5, 76, 2, 32, 6, 19, 7, 80, 
    0, 22, 2, 61, 4, 72, 6, 81, 7, 84, 1, 54, 3, 47, 5, 43, 8, 55, 
    0,  2, 7, 39, 1, 81, 3, 99, 4, 35, 2, 89, 8, 60, 5, 80, 6, 40, 
    0, 58, 2, 88, 5, 53, 3, 12, 7, 91, 6, 67, 8, 42, 4, 99, 1, 92
  };
  const int q1629[] = {
    9, 9, // Number of jobs and machines
    7, 46, 2, 82, 4, 75, 0, 43, 6, 25, 8, 30, 1, 43, 5, 91, 3, 72, 
    4, 28, 2, 17, 6, 20, 5, 76, 8, 74, 3, 53, 0, 25, 1, 75, 7, 34, 
    8, 40, 2, 92, 5, 91, 0, 76, 7, 46, 6, 34, 4, 19, 1, 93, 3, 45, 
    8, 74, 4, 91, 5, 62, 2,  1, 7, 11, 3, 45, 6, 44, 0, 16, 1, 66, 
    6, 20, 7, 48, 5, 87, 4, 36, 0, 19, 8, 69, 3, 50, 2, 49, 1, 37, 
    7, 96, 2, 96, 6, 74, 8,  2, 0,  9, 3, 94, 4,  8, 5, 97, 1, 17, 
    0,  7, 6, 10, 5, 22, 8, 47, 1, 58, 3, 76, 7, 74, 2, 37, 4, 94, 
    4, 97, 1, 68, 0, 42, 8, 92, 2, 76, 7, 12, 6,  3, 5, 30, 3, 68, 
    0, 27, 6,  6, 8, 37, 7,  2, 4, 27, 1, 89, 3, 97, 2, 39, 5, 37
  };
  const int q1630[] = {
    9, 9, // Number of jobs and machines
    0, 22, 2, 54, 4, 50, 5, 96, 7, 30, 8, 98, 1, 10, 3, 83, 6,  5, 
    5, 29, 3, 38, 0, 57, 6, 81, 2, 39, 1, 69, 4, 83, 8, 81, 7, 26, 
    5, 31, 2, 21, 7, 21, 6, 61, 8,  7, 1, 97, 3, 35, 0,  2, 4, 71, 
    0, 17, 3, 28, 1, 64, 4, 95, 5, 81, 6, 46, 8, 17, 7, 53, 2, 59, 
    1, 84, 7, 37, 4,  5, 8,  8, 5, 79, 3, 24, 2, 96, 6, 55, 0, 56, 
    3, 13, 7, 23, 8, 12, 5, 18, 0, 35, 6, 55, 1,  7, 4, 38, 2, 28, 
    5, 37, 4, 79, 0, 96, 7, 66, 1, 46, 6, 11, 3, 73, 2, 87, 8, 65, 
    0,  9, 5, 59, 1,  6, 3, 29, 6, 59, 8, 91, 7, 15, 2, 63, 4, 58, 
    0, 47, 6, 55, 3, 82, 5, 44, 2, 10, 7, 99, 1, 44, 8, 30, 4, 92
  };
  const int q1631[] = {
    9, 9, // Number of jobs and machines
    8, 48, 0,  2, 5, 88, 2, 99, 3,  6, 7, 97, 4, 37, 6, 14, 1, 30, 
    5, 52, 7, 86, 8, 64, 2, 65, 1, 35, 0, 13, 3, 85, 4, 61, 6,  3, 
    4,  7, 2, 29, 7, 84, 0, 72, 3, 22, 6, 80, 5, 25, 1, 12, 8, 94, 
    8, 49, 7, 19, 6,  6, 0, 62, 5, 79, 3, 11, 1, 37, 2, 43, 4, 85, 
    2, 12, 8, 59, 0, 33, 4, 59, 5, 85, 3, 18, 1, 91, 7,  8, 6, 63, 
    0, 65, 4, 23, 2, 80, 5, 50, 1, 40, 8, 30, 7, 46, 3, 75, 6, 88, 
    0, 48, 1, 85, 2, 73, 3, 69, 6, 15, 5, 36, 7, 87, 4, 89, 8, 93, 
    6, 73, 1,  4, 0,  7, 5, 81, 4, 77, 7,  3, 8, 54, 2, 16, 3, 37, 
    6, 56, 8, 48, 1, 89, 2, 20, 3, 70, 7, 41, 4, 30, 0, 29, 5, 60
  };
  const int q1632[] = {
    9, 9, // Number of jobs and machines
    3, 99, 5, 85, 4, 67, 8, 25, 1, 28, 2, 99, 7, 33, 0, 29, 6, 16, 
    6, 20, 0, 59, 7, 90, 3, 79, 8, 93, 2, 10, 1, 16, 5, 85, 4, 89, 
    6, 81, 7, 28, 5, 39, 3, 15, 0, 84, 2, 26, 4,  8, 8, 54, 1, 79, 
    5, 22, 4, 94, 0, 12, 7,  7, 2, 27, 8, 74, 3,  3, 6, 25, 1, 42, 
    5, 71, 4, 64, 2,  9, 0, 50, 6,  3, 8, 24, 3, 12, 7, 54, 1, 34, 
    7, 96, 2, 68, 4, 80, 8, 83, 3, 26, 1, 64, 6, 91, 0, 65, 5, 61, 
    2,  7, 1, 86, 6, 34, 0, 88, 5, 80, 8, 10, 4, 44, 3, 79, 7, 22, 
    2, 22, 7, 84, 4, 13, 6, 63, 8, 15, 3, 34, 5, 51, 0,  4, 1, 21, 
    7, 69, 6, 81, 3, 94, 5, 93, 8, 95, 2, 58, 4, 50, 0, 43, 1, 76
  };
  const int q1633[] = {
    9, 9, // Number of jobs and machines
    7,  8, 6, 50, 3, 67, 5, 90, 0, 79, 8, 62, 2, 70, 4, 44, 1, 95, 
    4,  4, 1, 50, 3, 40, 7, 58, 0, 84, 5, 27, 8, 50, 2, 55, 6, 21, 
    2, 99, 0, 26, 1, 51, 7, 60, 4, 61, 6, 86, 5, 41, 3, 97, 8, 77, 
    7, 21, 5, 34, 6, 32, 4, 22, 3, 45, 2,  5, 1, 44, 8, 90, 0, 55, 
    5, 98, 4, 53, 7, 45, 3, 63, 1, 73, 6,  4, 2, 18, 8, 75, 0, 81, 
    7, 65, 2, 75, 5, 32, 0, 57, 1, 83, 4, 63, 8, 13, 3, 34, 6,  4, 
    5, 39, 0, 11, 1, 75, 8,  2, 2,  6, 7,  3, 6, 95, 3, 27, 4, 75, 
    5, 26, 8, 76, 1, 57, 4, 22, 2, 90, 0, 85, 3, 17, 6,  7, 7, 41, 
    4, 51, 0, 50, 5, 44, 6, 48, 3, 25, 8, 80, 7, 93, 1, 38, 2, 58
  };
  const int q1634[] = {
    9, 9, // Number of jobs and machines
    1, 97, 5, 66, 6, 11, 2, 82, 3, 53, 0, 67, 4, 44, 8, 96, 7, 46, 
    7, 57, 2, 39, 3, 15, 0, 24, 8, 81, 5, 13, 6, 91, 1, 49, 4, 41, 
    7, 80, 8, 61, 0, 16, 6, 17, 3, 52, 1, 61, 5, 49, 2, 85, 4, 18, 
    2, 63, 7, 33, 5, 15, 1,  5, 4, 62, 8,  3, 6, 58, 3, 87, 0, 16, 
    1, 81, 7, 95, 5, 33, 6, 63, 2, 65, 3, 62, 0, 76, 8, 89, 4, 79, 
    5,  5, 1, 94, 2, 98, 0, 76, 8,  3, 7, 42, 6, 71, 4, 11, 3, 88, 
    6,  5, 8, 92, 1, 41, 3, 88, 2,  3, 7, 92, 0, 69, 4, 66, 5, 96, 
    5, 86, 1, 76, 8, 76, 6, 71, 3,  4, 0, 10, 4, 33, 7, 59, 2,  7, 
    5, 85, 8,  7, 3, 17, 2, 46, 6, 13, 7, 22, 0,  3, 1, 91, 4,  6
  };
  const int q1635[] = {
    9, 9, // Number of jobs and machines
    5, 90, 6, 84, 8, 68, 7, 75, 0, 81, 4, 40, 3, 49, 1, 60, 2, 52, 
    4, 24, 8, 63, 3, 14, 7, 72, 5, 17, 0, 63, 2,  1, 6, 10, 1, 19, 
    2,  3, 7, 42, 0, 74, 4, 55, 5, 50, 8, 47, 3,  7, 1, 64, 6, 24, 
    4, 84, 8,  4, 0, 19, 6, 74, 2, 55, 3, 17, 5, 24, 7, 98, 1, 68, 
    5, 34, 4, 98, 0,  5, 1, 86, 7, 61, 3, 77, 6, 72, 2, 59, 8, 74, 
    0, 79, 7, 48, 5, 10, 8, 96, 1, 37, 6, 44, 3, 71, 2, 73, 4, 68, 
    7, 68, 3, 79, 8, 36, 0, 23, 1,  6, 4, 23, 2, 32, 5, 34, 6, 28, 
    8, 49, 7, 75, 6,  2, 1, 28, 4, 53, 3, 59, 5, 41, 0, 70, 2, 33, 
    5, 40, 2, 79, 7, 82, 6, 63, 1, 95, 3, 49, 4, 48, 0, 34, 8, 37
  };
  const int q1636[] = {
    9, 9, // Number of jobs and machines
    5, 61, 8, 91, 6, 11, 0, 98, 1, 77, 7, 26, 4, 25, 3, 28, 2, 84, 
    5, 86, 8,  5, 1, 20, 4,  7, 2, 17, 6, 58, 3,  1, 7, 89, 0, 87, 
    2, 23, 4, 97, 5, 36, 0, 76, 6, 32, 3, 30, 1, 71, 7, 85, 8, 74, 
    6, 79, 5, 85, 3, 35, 4,  6, 8, 10, 0, 50, 2, 53, 1, 33, 7, 50, 
    8, 12, 1, 66, 2, 50, 3,  3, 0,  7, 7, 40, 6, 61, 4, 39, 5, 34, 
    7, 54, 1, 52, 2, 22, 0,  4, 3, 51, 6, 78, 5, 54, 4, 80, 8,  2, 
    3, 85, 4, 86, 6, 37, 7, 23, 2, 64, 5, 81, 1, 50, 0, 42, 8, 58, 
    4, 66, 5, 52, 8, 83, 3, 49, 6, 75, 2, 75, 7, 93, 0, 60, 1, 72, 
    2, 27, 5, 36, 1, 43, 7, 68, 8, 89, 0, 80, 6, 14, 4, 64, 3, 91
  };
  const int q1637[] = {
    9, 9, // Number of jobs and machines
    5, 62, 4, 46, 2, 88, 1, 45, 3, 72, 6, 26, 8, 75, 0, 23, 7, 64, 
    1, 87, 0, 77, 2, 41, 4, 35, 3, 22, 6, 14, 5, 57, 8, 49, 7, 35, 
    6, 82, 2, 95, 8, 49, 3, 74, 0, 25, 5, 46, 7, 94, 4, 46, 1,  3, 
    4, 14, 3, 96, 8, 26, 2, 39, 5, 55, 0, 80, 7, 12, 6, 49, 1, 93, 
    4, 21, 0, 98, 8, 23, 2, 15, 5, 23, 7, 20, 6, 35, 3, 53, 1, 18, 
    6, 62, 1, 14, 8, 42, 0, 77, 3, 27, 5, 85, 4, 98, 7,  2, 2, 83, 
    4, 48, 0, 51, 6, 65, 3, 21, 2, 23, 1, 65, 8, 21, 5, 67, 7, 79, 
    6, 86, 5, 21, 4, 53, 7, 27, 3, 30, 2, 77, 8, 99, 0, 28, 1, 59, 
    2, 16, 3, 37, 6, 87, 8, 86, 0, 83, 1, 21, 7, 55, 5, 60, 4, 92
  };
  const int q1638[] = {
    9, 9, // Number of jobs and machines
    1,  9, 8, 45, 5, 96, 3, 34, 2, 27, 0, 75, 6, 58, 7, 21, 4, 50, 
    2,  6, 5, 41, 0, 38, 1, 18, 3, 78, 8, 25, 7, 70, 4, 51, 6, 73, 
    4,  3, 1, 71, 8, 35, 2, 13, 5, 40, 7, 28, 3, 74, 0, 60, 6, 50, 
    6, 53, 1,  6, 8, 68, 4, 89, 3, 54, 7, 78, 2, 18, 0, 13, 5, 52, 
    4,  7, 3, 92, 6, 84, 8, 90, 7, 68, 2, 31, 1, 57, 0, 48, 5, 89, 
    3,  3, 1,  7, 6, 29, 2, 71, 0, 35, 8, 25, 5, 49, 7, 89, 4, 23, 
    2, 28, 3, 43, 7, 25, 4, 81, 8, 70, 1, 57, 5, 67, 0, 75, 6, 75, 
    7, 77, 5, 15, 4, 48, 2, 34, 3, 41, 8, 49, 1, 91, 6, 21, 0, 60, 
    5, 15, 8, 88, 3, 75, 2, 17, 4, 63, 0, 98, 6, 41, 1, 38, 7, 87
  };
  const int q1639[] = {
    9, 9, // Number of jobs and machines
    2, 52, 0, 78, 8, 84, 7, 47, 5, 80, 3,  8, 4, 72, 1, 66, 6, 94, 
    0, 15, 1, 38, 8, 17, 2, 97, 5, 19, 7, 66, 3, 97, 4, 83, 6, 73, 
    8,  9, 6, 72, 2, 43, 4, 97, 1, 42, 5, 54, 7, 84, 3,  2, 0, 85, 
    3, 65, 0, 63, 6, 62, 7, 43, 1, 80, 2, 68, 5, 84, 4, 94, 8, 67, 
    0, 23, 5, 37, 4, 49, 7, 95, 8, 79, 1, 98, 2, 84, 6, 35, 3, 11, 
    3, 61, 8, 44, 1, 13, 0,  6, 6, 20, 5,  5, 4, 96, 7,  9, 2,  9, 
    0, 32, 6, 28, 4, 59, 2, 15, 3, 58, 7, 65, 8, 24, 1, 23, 5, 90, 
    6, 30, 4, 23, 2, 99, 3, 79, 8, 46, 7,  8, 0,  3, 5, 50, 1, 56, 
    3, 88, 0, 75, 6, 10, 7, 99, 4, 14, 5, 41, 8, 87, 1, 73, 2, 95
  };
  const int q1640[] = {
    9, 9, // Number of jobs and machines
    8, 19, 5, 98, 6,  6, 3, 99, 7, 35, 1,  7, 2, 33, 0, 26, 4, 44, 
    4, 46, 5, 61, 7, 26, 1,  6, 3, 78, 0, 27, 8, 70, 2, 95, 6, 32, 
    1, 18, 8, 69, 0,  7, 4, 78, 3, 35, 5, 46, 6, 26, 7, 36, 2, 86, 
    0, 94, 5,  6, 4, 62, 7, 13, 6, 82, 2, 65, 8, 20, 1, 95, 3, 31, 
    6,  8, 7, 80, 8, 47, 3, 71, 4, 80, 5, 62, 1, 47, 0, 38, 2,  7, 
    3, 84, 6, 51, 7, 73, 5, 28, 0, 67, 2, 57, 4, 67, 1,  3, 8, 11, 
    3, 20, 5, 20, 0, 43, 7, 36, 2, 27, 8, 64, 4, 23, 6, 97, 1, 31, 
    4, 73, 6, 46, 8, 94, 1, 15, 7, 46, 3, 14, 0, 93, 5, 19, 2, 26, 
    3, 18, 7, 75, 2, 16, 0, 10, 1, 94, 8, 85, 6, 17, 5,  5, 4, 71
  };
  const int q1641[] = {
    9, 9, // Number of jobs and machines
    2, 21, 1, 82, 3, 37, 0, 87, 6, 31, 7, 36, 5, 16, 8, 57, 4, 39, 
    1, 29, 2, 14, 0, 66, 3, 34, 8, 19, 7, 40, 5, 63, 6, 14, 4, 54, 
    6, 77, 2, 40, 8, 75, 5, 65, 0, 58, 4, 82, 1,  2, 3, 70, 7, 16, 
    6, 99, 7,  2, 3, 24, 4, 86, 0, 19, 2, 74, 8, 89, 1, 24, 5, 29, 
    2, 26, 7, 81, 1, 89, 5,  5, 6, 39, 8, 40, 0,  8, 3, 64, 4, 79, 
    4, 44, 7, 84, 1, 87, 5, 83, 2, 30, 0, 45, 8, 80, 6, 30, 3, 11, 
    0, 80, 2, 38, 7, 86, 8, 74, 6, 89, 1, 61, 5, 89, 4,  2, 3, 24, 
    2, 40, 6, 50, 7, 15, 0, 44, 1, 52, 5, 30, 3, 11, 8, 60, 4, 12, 
    0, 38, 6, 22, 7, 72, 3, 17, 4, 92, 8, 13, 5, 50, 1, 69, 2, 92
  };
  const int q1642[] = {
    9, 9, // Number of jobs and machines
    8, 37, 1,  1, 6, 31, 5, 97, 4, 26, 3, 74, 0, 53, 7, 56, 2, 51, 
    4, 61, 3, 47, 0, 16, 5, 50, 1, 13, 8, 72, 6, 10, 7,  6, 2, 80, 
    0, 10, 8,  6, 2,  8, 4, 89, 7, 84, 1, 20, 5, 44, 6, 33, 3, 90, 
    0, 66, 2, 99, 5, 37, 4, 88, 7, 96, 8,  6, 1, 38, 6, 60, 3, 80, 
    1, 69, 8, 88, 7, 52, 3, 33, 2, 74, 6, 64, 0, 47, 5, 39, 4, 23, 
    0, 11, 2, 92, 7,  8, 3, 57, 6, 62, 1, 94, 5, 63, 8, 49, 4, 71, 
    7, 65, 5, 74, 1, 17, 2, 11, 0, 52, 4, 15, 6, 78, 3, 33, 8, 18, 
    8, 48, 3, 17, 4,  6, 5, 88, 0, 71, 1, 99, 6, 77, 2, 50, 7, 26, 
    5, 69, 2, 49, 3,  7, 6, 36, 4, 16, 7, 95, 8, 45, 0, 79, 1, 15
  };
  const int q1643[] = {
    9, 9, // Number of jobs and machines
    4, 64, 3, 91, 7, 13, 0, 91, 6, 87, 5, 43, 2, 97, 1, 93, 8, 74, 
    0, 10, 8, 25, 4, 74, 7, 92, 2,  9, 6, 48, 3, 53, 5, 10, 1, 71, 
    7, 51, 1, 61, 2, 25, 4, 82, 3,  6, 5, 93, 6, 32, 8, 46, 0, 84, 
    2, 98, 1, 42, 3, 43, 7, 36, 8, 19, 6, 51, 4, 59, 0, 89, 5, 40, 
    4, 60, 2, 19, 6, 52, 8, 99, 7,  3, 0,  6, 5, 79, 1, 94, 3, 71, 
    2, 92, 4,  1, 6, 22, 3, 28, 0, 73, 7, 57, 1, 30, 5, 45, 8, 61, 
    2, 68, 8, 49, 5, 96, 4, 19, 1, 42, 0, 96, 7, 31, 6, 89, 3,  7, 
    3, 39, 7, 90, 5, 54, 1, 83, 4, 64, 0, 24, 6, 28, 8, 20, 2,  7, 
    4, 51, 3, 25, 6, 72, 1, 73, 7, 23, 8, 34, 2, 98, 0, 12, 5, 65
  };
  const int q1644[] = {
    9, 9, // Number of jobs and machines
    4, 14, 8, 89, 1,  4, 5, 92, 0, 41, 6,  9, 7, 34, 2, 59, 3, 53, 
    2, 47, 4, 79, 8, 89, 7,  8, 3, 62, 6, 80, 1, 31, 0, 17, 5, 74, 
    4, 42, 0, 13, 6, 85, 2, 64, 5, 46, 8, 48, 7, 69, 3, 76, 1,  1, 
    6, 44, 1, 12, 2, 69, 4, 96, 5, 70, 8, 70, 3, 20, 0, 43, 7, 17, 
    7, 44, 2, 32, 8, 21, 3, 71, 6, 46, 1, 30, 5,  5, 4, 40, 0, 44, 
    8, 18, 5, 10, 2, 89, 7, 51, 0, 39, 6, 39, 1, 54, 4, 24, 3, 71, 
    1, 25, 2, 66, 3, 23, 6, 80, 5, 22, 4, 30, 0, 63, 8, 46, 7, 19, 
    6, 28, 0,  2, 3, 89, 4, 34, 8, 59, 1, 44, 2, 64, 7, 42, 5, 46, 
    6, 56, 4, 50, 0, 63, 1, 88, 2, 98, 7, 75, 3, 68, 8, 42, 5, 28
  };
  const int q1645[] = {
    9, 9, // Number of jobs and machines
    8, 89, 1, 40, 3, 38, 0, 40, 2, 57, 5, 29, 7, 72, 6, 44, 4, 26, 
    6, 80, 8, 49, 5, 94, 4,  8, 7,  5, 0, 40, 2, 47, 1,  5, 3, 69, 
    2, 68, 6, 20, 3, 69, 1, 85, 7,  2, 4, 45, 0, 68, 5, 56, 8, 26, 
    4, 73, 3,  4, 0,  5, 5, 32, 7, 95, 2, 46, 8, 71, 1,  8, 6, 23, 
    8, 86, 5, 35, 6, 71, 2, 17, 7, 19, 0, 61, 4, 56, 1,  7, 3, 87, 
    6, 87, 7,  9, 8,  2, 1, 78, 4, 18, 2, 83, 5, 23, 0, 52, 3, 52, 
    1, 77, 8, 24, 5, 91, 6, 93, 0,  7, 4, 18, 3, 73, 2, 49, 7, 11, 
    8, 26, 1, 24, 0, 19, 3, 28, 7, 54, 4, 92, 6, 60, 2, 26, 5, 35, 
    0, 23, 1, 15, 8, 96, 2, 27, 5, 75, 4, 64, 3, 19, 6, 96, 7, 97
  };
  const int q1646[] = {
    9, 9, // Number of jobs and machines
    1, 84, 8, 67, 3, 60, 7,  4, 4, 19, 5, 74, 6, 40, 0, 88, 2, 46, 
    5, 20, 3, 41, 2, 56, 0, 43, 7,  1, 8, 33, 4, 70, 1, 87, 6, 54, 
    2, 20, 3, 36, 5, 78, 6, 34, 4, 13, 7, 24, 8, 51, 1, 94, 0, 98, 
    0, 53, 1, 80, 8, 27, 6,  4, 4, 95, 3, 73, 7, 84, 2, 11, 5, 62, 
    3, 99, 0, 59, 4, 46, 7, 79, 5, 30, 1, 16, 8,  2, 6, 84, 2, 48, 
    2, 13, 5, 10, 3, 51, 1, 26, 4, 22, 6, 63, 0, 63, 8, 62, 7, 40, 
    7, 52, 0, 87, 4, 61, 3, 53, 1, 70, 6, 66, 8, 95, 5, 21, 2,  9, 
    7, 19, 2, 56, 1, 81, 5, 33, 8,  7, 4, 49, 0,  5, 6, 28, 3, 76, 
    7, 82, 1, 15, 0, 40, 6, 59, 8, 79, 2, 26, 5, 33, 4, 77, 3, 10
  };
  const int q1647[] = {
    9, 9, // Number of jobs and machines
    7, 85, 5, 86, 0, 43, 3,  6, 8, 73, 4, 11, 2, 95, 1, 16, 6, 62, 
    0, 87, 3, 82, 5, 97, 8, 85, 4,  9, 7, 47, 6, 91, 1, 89, 2, 64, 
    3, 57, 0, 84, 2, 18, 8, 64, 7, 40, 1, 58, 6,  1, 4, 27, 5, 80, 
    3, 80, 7, 88, 6, 85, 4, 86, 2, 38, 5, 24, 0, 26, 1,  3, 8, 69, 
    6, 10, 4, 51, 7, 31, 2, 39, 8, 74, 0, 44, 3, 27, 1, 30, 5, 93, 
    3,  9, 2, 74, 6, 92, 7, 97, 4, 79, 1, 18, 8, 32, 0, 14, 5, 94, 
    3, 73, 0, 33, 6,  1, 7, 50, 2, 19, 4, 11, 8, 39, 1, 37, 5, 45, 
    0, 87, 5, 43, 6, 57, 4, 89, 1, 54, 8, 59, 3, 50, 2, 29, 7,  5, 
    5, 69, 0, 47, 3, 45, 6, 73, 2, 40, 4, 90, 8, 41, 1, 13, 7, 38
  };
  const int q1648[] = {
    9, 9, // Number of jobs and machines
    8, 53, 0, 21, 4, 45, 3, 62, 2, 53, 1, 50, 5, 34, 6, 14, 7, 87, 
    0,  8, 5, 71, 6, 34, 7, 13, 8, 57, 4,  8, 3, 53, 2, 86, 1, 56, 
    1, 40, 0,  2, 5,  6, 2, 99, 6, 10, 4,  5, 7, 83, 8, 65, 3,  8, 
    0, 14, 7, 27, 5, 75, 3, 69, 8, 90, 6, 94, 4, 36, 2, 71, 1, 36, 
    5, 68, 2, 45, 7, 86, 6, 19, 3, 84, 4, 22, 8, 24, 0, 56, 1, 33, 
    3, 82, 2, 98, 7, 26, 5, 53, 8, 77, 1, 17, 4, 73, 0, 61, 6, 12, 
    2,  5, 0, 95, 8, 59, 5, 74, 3, 10, 7, 26, 1, 54, 6,  3, 4,  5, 
    5, 65, 2, 76, 0, 77, 6, 51, 7,  1, 3, 23, 8, 10, 1, 45, 4, 46, 
    1, 15, 5, 90, 4, 38, 8, 57, 3, 51, 0, 28, 6, 58, 2, 16, 7, 53
  };
  const int q1649[] = {
    9, 9, // Number of jobs and machines
    8,  9, 0, 37, 7, 29, 1,  9, 4, 17, 6,  7, 5, 79, 2, 39, 3, 23, 
    2, 16, 8, 82, 6, 55, 3, 38, 5, 82, 0, 31, 7, 80, 4, 72, 1, 47, 
    6, 51, 7, 40, 1, 61, 4, 89, 5, 87, 2,  4, 8, 35, 3, 89, 0, 37, 
    6, 43, 4, 17, 3, 33, 5, 60, 1,  2, 7, 59, 8, 32, 2, 43, 0,  1, 
    2, 81, 8,  9, 1,  6, 6, 17, 5, 29, 7, 56, 0, 85, 3, 10, 4, 30, 
    5, 21, 6, 34, 1, 26, 2, 92, 3,  6, 7,  4, 8, 83, 4, 33, 0, 51, 
    4, 77, 5, 25, 7, 93, 8, 37, 6, 50, 2, 38, 1, 64, 0,  9, 3,  7, 
    4, 17, 0, 34, 6, 46, 7, 57, 5, 82, 1, 22, 8, 52, 2, 14, 3,  2, 
    2, 54, 3, 44, 0, 81, 8, 37, 6, 33, 1, 26, 7, 30, 4, 73, 5, 88
  };
  const int q1650[] = {
    9, 9, // Number of jobs and machines
    3, 53, 6, 84, 2, 34, 0, 70, 8, 65, 4, 75, 1, 34, 5, 70, 7, 74, 
    5, 42, 7, 82, 8, 49, 0, 56, 6, 83, 3, 60, 1, 14, 4,  1, 2, 19, 
    0,  2, 4,  5, 5, 43, 2, 66, 8, 42, 7, 46, 1, 69, 3, 20, 6, 43, 
    5,  8, 6,  9, 2,  8, 1,  1, 0, 46, 8, 81, 7, 66, 4, 42, 3, 44, 
    2, 83, 1, 61, 7, 75, 5, 17, 3, 80, 0,  6, 8, 92, 4, 76, 6, 72, 
    1, 69, 2, 83, 8, 42, 4, 84, 3, 37, 0, 62, 7, 84, 5, 95, 6,  6, 
    7, 58, 5, 53, 0, 97, 4, 31, 8,  5, 2, 65, 3, 48, 6, 45, 1, 32, 
    1, 15, 4, 19, 5, 56, 8, 80, 6,  9, 7, 55, 0,  5, 3,  7, 2, 79, 
    3, 83, 1, 36, 5, 74, 7, 36, 2, 51, 0, 20, 6, 92, 4, 18, 8, 98
  };
  const int q1651[] = {
    9, 9, // Number of jobs and machines
    0, 41, 6, 12, 7, 52, 4, 56, 3, 53, 5,  3, 1,  5, 8, 80, 2, 55, 
    2, 57, 7, 92, 4, 89, 6, 48, 0, 92, 1, 34, 8, 78, 5, 42, 3, 96, 
    1, 25, 0, 50, 2, 84, 5, 28, 3, 23, 8, 35, 6, 61, 4, 79, 7, 68, 
    0, 56, 7, 16, 3, 10, 8, 99, 6, 28, 2, 81, 1, 93, 4,  4, 5, 70, 
    0, 85, 2, 56, 8, 97, 3, 69, 4, 89, 6, 24, 5, 52, 1, 70, 7, 12, 
    7,  3, 3, 17, 0, 42, 5, 48, 1, 43, 2, 82, 8, 27, 6, 56, 4, 43, 
    6, 89, 0, 38, 2, 48, 4, 91, 1, 25, 8, 91, 7,  1, 3,  6, 5, 28, 
    2, 15, 1, 23, 8, 49, 3, 98, 6,  7, 7, 36, 4,  2, 0,  6, 5, 80, 
    1, 60, 6, 57, 3, 25, 7, 20, 4,  1, 0, 53, 8, 31, 5, 26, 2, 94
  };
  const int q1652[] = {
    9, 9, // Number of jobs and machines
    0, 20, 3, 88, 7, 22, 4, 64, 2, 54, 1, 16, 5, 87, 8, 93, 6, 32, 
    5,  1, 3, 82, 2, 90, 7, 77, 1, 69, 6, 46, 8, 92, 0, 51, 4, 22, 
    2, 80, 5, 22, 3, 13, 7, 11, 4, 11, 1, 74, 0, 84, 8, 77, 6, 84, 
    2,  7, 3, 77, 8, 57, 5, 96, 0, 19, 4, 73, 7, 33, 6,  5, 1, 70, 
    7, 55, 0, 63, 5, 48, 3, 59, 4, 58, 2, 69, 8, 27, 6, 92, 1, 44, 
    4, 95, 8, 84, 7, 79, 0,  9, 5, 86, 2, 95, 6, 78, 1, 88, 3, 66, 
    5, 89, 3, 70, 6, 63, 2, 92, 4, 48, 0, 34, 7, 33, 1, 68, 8, 16, 
    2, 27, 6, 17, 4, 38, 8, 94, 5, 54, 3,  5, 1,  4, 7, 73, 0, 47, 
    0, 84, 8, 92, 4, 48, 2, 25, 3, 99, 6, 71, 1, 90, 7, 82, 5, 86
  };
  const int q1653[] = {
    9, 9, // Number of jobs and machines
    1, 89, 5, 79, 4, 30, 8, 58, 6, 51, 2, 58, 3, 37, 7, 45, 0, 45, 
    2, 84, 1, 61, 4, 88, 7, 32, 8, 33, 6, 37, 0, 88, 5, 12, 3, 96, 
    5, 82, 1, 64, 6, 12, 2, 99, 0, 28, 7, 81, 4, 90, 3, 57, 8, 78, 
    7, 98, 1, 72, 2, 85, 8, 19, 6, 89, 3, 52, 4, 75, 5, 49, 0, 35, 
    8, 54, 1,  5, 7, 41, 3, 38, 2, 53, 0, 44, 5, 96, 4, 57, 6,  3, 
    7, 70, 3, 30, 1,  4, 2, 56, 5, 84, 8, 17, 6, 98, 4, 53, 0, 18, 
    1, 61, 0, 31, 7, 24, 2, 73, 4, 15, 3, 63, 8, 90, 5,  1, 6, 72, 
    3, 68, 4, 77, 0, 49, 6,  3, 1, 33, 8, 13, 5, 60, 2, 95, 7, 38, 
    7, 97, 3, 48, 8,  9, 0, 67, 4, 18, 2, 13, 5, 58, 1, 60, 6, 41
  };
  const int q1654[] = {
    9, 9, // Number of jobs and machines
    8, 14, 6, 47, 3, 23, 5, 74, 7, 36, 4, 43, 0, 67, 1, 37, 2, 38, 
    0, 29, 6, 10, 3,  5, 8, 70, 7, 65, 5, 53, 2,  4, 4, 64, 1, 35, 
    3, 45, 1, 66, 6, 93, 5, 30, 7, 30, 2, 11, 0, 68, 8, 87, 4, 57, 
    6, 21, 8, 35, 7, 72, 1, 24, 4, 80, 2, 91, 5, 32, 3, 24, 0, 96, 
    1, 49, 2, 77, 8, 10, 6, 57, 0,  6, 3, 55, 4, 83, 5, 22, 7, 31, 
    7, 95, 3, 87, 4,  8, 2,  8, 6, 33, 8, 98, 1, 17, 5, 34, 0, 91, 
    0, 51, 3, 95, 4, 90, 5, 75, 6, 76, 8, 80, 7, 95, 2, 29, 1, 56, 
    0, 92, 4, 38, 3, 54, 7, 13, 1, 29, 6,  7, 5,  1, 2, 85, 8, 16, 
    6,  4, 7, 87, 0, 49, 3, 66, 8, 31, 4, 72, 5,  7, 1, 28, 2, 13
  };
  const int q1655[] = {
    9, 9, // Number of jobs and machines
    4, 19, 0, 68, 6, 74, 3, 45, 5, 15, 1, 59, 8,  1, 2, 51, 7, 85, 
    6, 74, 8, 89, 5, 80, 2, 89, 7, 55, 0, 51, 4, 85, 1, 87, 3, 25, 
    7, 58, 6,  1, 3, 34, 1, 69, 2, 13, 0, 43, 5, 39, 4, 18, 8, 92, 
    3, 65, 7, 21, 8, 31, 2, 87, 0,  5, 1, 42, 6, 50, 5, 80, 4, 26, 
    6, 25, 8,  6, 5, 35, 0, 76, 7, 78, 2, 19, 1, 13, 4, 95, 3, 15, 
    7, 59, 0, 48, 2, 33, 8, 73, 4, 74, 6,  8, 1, 57, 3, 57, 5, 18, 
    6, 39, 5, 56, 0, 76, 2, 79, 3, 55, 8, 71, 4, 88, 7, 19, 1,  8, 
    2, 34, 0, 22, 3, 68, 1, 97, 8, 67, 7, 15, 5, 15, 4, 73, 6,  2, 
    8,  9, 1, 83, 7, 64, 3, 99, 0, 12, 4,  1, 5, 83, 2, 77, 6, 67
  };
  const int q1656[] = {
    9, 9, // Number of jobs and machines
    7, 78, 2, 31, 1, 44, 3,  7, 4, 63, 6, 88, 5, 45, 8, 89, 0, 24, 
    1, 57, 7, 69, 8, 96, 3, 54, 0, 29, 2, 71, 6, 41, 4, 82, 5, 97, 
    2, 79, 7, 78, 0, 36, 1, 77, 3, 20, 4, 77, 8, 39, 6, 64, 5, 46, 
    5, 66, 3, 68, 4, 82, 2, 66, 7, 97, 1, 30, 6, 93, 0, 83, 8, 99, 
    0, 21, 1,  3, 5, 46, 8, 76, 2, 95, 7, 18, 3, 28, 4, 38, 6, 87, 
    3, 61, 1, 42, 8, 34, 5, 79, 7, 37, 6, 42, 0, 88, 2, 79, 4, 89, 
    2, 58, 5, 77, 3, 20, 0, 81, 4, 21, 1, 29, 6, 64, 7, 61, 8, 67, 
    7, 57, 8, 79, 3, 83, 5, 17, 2, 71, 4, 88, 1,  3, 6, 39, 0, 30, 
    3, 79, 6, 11, 8, 57, 1,  1, 4, 70, 2, 44, 5, 32, 0, 50, 7, 16
  };
  const int q1657[] = {
    9, 9, // Number of jobs and machines
    6, 36, 8, 37, 4, 67, 5, 72, 1, 90, 0,  4, 3, 87, 2, 83, 7, 79, 
    2, 65, 3, 53, 8, 82, 1, 69, 5, 48, 7, 30, 0, 85, 6, 87, 4, 29, 
    2, 97, 7, 58, 0, 60, 1, 62, 4, 27, 8, 99, 5, 53, 3, 90, 6, 41, 
    0, 84, 6, 45, 1, 43, 5, 80, 7, 57, 8, 51, 3, 13, 4, 61, 2, 22, 
    2, 86, 4, 73, 7,  7, 0, 33, 6,  9, 8, 66, 1, 27, 3, 29, 5, 49, 
    4, 74, 7, 85, 6, 48, 8, 85, 1, 40, 2, 94, 3, 29, 0, 59, 5, 76, 
    6, 31, 3, 17, 2, 35, 0, 11, 7, 88, 5,  5, 4, 39, 1, 93, 8, 65, 
    7, 24, 6, 44, 1, 85, 8,  7, 0, 80, 5, 77, 3,  4, 4, 24, 2, 49, 
    7, 85, 1, 87, 4, 65, 3, 85, 5, 25, 8, 96, 6, 63, 0, 42, 2, 43
  };
  const int q1658[] = {
    9, 9, // Number of jobs and machines
    2, 31, 5, 96, 6, 29, 1, 17, 3, 96, 0, 53, 4, 15, 7, 21, 8, 33, 
    0, 36, 8,  5, 1, 93, 7, 53, 3, 21, 4, 35, 6, 72, 5, 36, 2, 71, 
    7, 12, 3, 50, 1, 55, 8, 23, 6,  2, 2, 29, 5, 98, 4, 56, 0, 66, 
    0, 74, 6, 64, 7, 68, 8,  1, 5, 60, 3, 13, 2, 87, 4, 40, 1, 52, 
    8, 95, 6, 46, 5,  3, 2, 94, 4, 78, 1, 41, 7, 65, 3, 99, 0, 96, 
    7, 68, 8, 57, 4, 76, 5, 31, 3, 42, 1, 13, 0, 60, 2, 36, 6, 90, 
    5,  3, 4, 65, 0, 68, 3, 34, 8, 45, 1, 80, 2, 63, 7, 37, 6, 34, 
    2, 97, 0, 93, 3, 42, 1, 63, 6, 56, 7, 60, 5, 91, 8, 83, 4, 86, 
    5, 13, 1, 27, 6, 42, 3, 71, 7, 29, 8, 84, 0,  4, 4, 59, 2, 34
  };
  const int q1659[] = {
    9, 9, // Number of jobs and machines
    3, 85, 7, 17, 2, 67, 1, 48, 5, 10, 8, 78, 4, 14, 0, 94, 6, 45, 
    0, 97, 3, 24, 5, 70, 1, 44, 6, 81, 4, 86, 7, 36, 8, 57, 2, 56, 
    7, 94, 2, 56, 4, 69, 5, 45, 8, 48, 3, 20, 0, 28, 1, 28, 6, 57, 
    1, 56, 8, 95, 6, 69, 5, 89, 0, 42, 3,  3, 2, 73, 7, 36, 4, 67, 
    1, 60, 3, 68, 5, 94, 4, 15, 8, 98, 7, 12, 6, 60, 2, 10, 0, 91, 
    7, 13, 0, 80, 3, 38, 6, 13, 4, 37, 2, 76, 1, 77, 5, 68, 8, 74, 
    6,  9, 1, 67, 5,  7, 7, 25, 4, 96, 2, 20, 3, 11, 8, 57, 0, 83, 
    5, 14, 7, 78, 1, 35, 2, 35, 0, 65, 3, 31, 8, 66, 6, 38, 4, 18, 
    8, 29, 1, 83, 3, 64, 5, 41, 2, 19, 4, 78, 7, 79, 0,  8, 6, 82
  };
  const int q1660[] = {
    9, 9, // Number of jobs and machines
    6, 48, 8, 57, 5, 62, 2, 71, 3, 45, 1, 62, 0, 84, 4, 56, 7, 34, 
    7, 82, 3, 75, 6, 56, 2, 66, 1, 69, 5, 58, 0, 56, 8, 95, 4, 31, 
    5, 18, 7, 35, 2, 22, 1, 78, 8, 89, 0, 51, 6, 72, 4, 18, 3, 88, 
    0, 89, 6, 75, 3, 54, 2, 55, 8, 80, 4, 17, 5, 12, 7,  8, 1,  9, 
    4, 78, 6, 63, 2, 86, 8, 95, 7, 42, 1, 85, 0, 90, 5, 40, 3, 93, 
    2, 85, 4, 30, 7, 89, 8, 44, 5, 86, 1, 71, 0, 19, 3, 95, 6, 14, 
    5, 60, 3, 19, 6, 88, 2, 82, 7, 75, 0, 11, 1, 90, 4,  5, 8, 40, 
    0, 93, 4, 18, 7, 30, 8, 18, 1, 86, 6, 89, 2, 83, 5,  7, 3, 29, 
    3, 35, 1, 28, 5, 93, 6, 29, 8, 29, 7, 29, 2, 11, 4, 68, 0, 60
  };
  const int q1661[] = {
    9, 9, // Number of jobs and machines
    4, 54, 7, 19, 8, 34, 3,  4, 6, 33, 1, 67, 2, 15, 5, 47, 0,  8, 
    0,  5, 4, 13, 3, 34, 2, 37, 7, 60, 1, 72, 8, 93, 5, 23, 6, 40, 
    0, 50, 7, 87, 5, 48, 4, 23, 1, 80, 8, 92, 2, 13, 3, 42, 6, 26, 
    2, 30, 4,  9, 3, 96, 5, 35, 6, 86, 0, 40, 7, 69, 8, 29, 1, 30, 
    4, 69, 2, 86, 7, 47, 6, 17, 0, 54, 5,  5, 3,  4, 8, 80, 1, 45, 
    0, 10, 8,  1, 5, 78, 3, 96, 4, 18, 2, 79, 1, 91, 6, 91, 7, 19, 
    6, 66, 2, 95, 4, 74, 8,  8, 0, 12, 1, 36, 7, 22, 3,  1, 5, 34, 
    4, 45, 1,  4, 6, 24, 8, 62, 7, 64, 0, 34, 2,  6, 3, 98, 5, 34, 
    0,  1, 8,  9, 3, 50, 7, 39, 5, 32, 2, 11, 4, 74, 6, 85, 1, 10
  };
  const int q1662[] = {
    9, 9, // Number of jobs and machines
    7, 16, 2, 57, 1, 38, 8, 64, 4, 53, 6, 52, 0,  5, 3,  5, 5, 87, 
    7, 51, 4, 32, 5, 56, 3, 42, 2, 35, 8,  2, 1, 81, 6, 37, 0, 22, 
    6, 13, 1,  7, 4, 16, 5, 92, 7,  1, 0, 22, 3, 39, 2, 34, 8, 15, 
    2, 68, 0, 17, 6, 38, 4, 19, 7, 17, 5, 68, 1, 46, 8, 55, 3, 64, 
    6, 28, 1, 66, 8, 96, 3, 23, 2, 38, 0, 84, 7, 97, 5, 71, 4, 73, 
    0, 30, 2, 79, 6, 90, 4, 51, 8,  3, 5, 68, 7,  7, 3, 38, 1, 35, 
    6, 81, 5, 63, 4, 50, 1, 37, 8, 68, 3, 24, 2, 69, 7, 19, 0, 56, 
    8, 94, 1, 52, 6, 92, 3, 29, 5, 60, 2,  3, 4, 31, 0, 82, 7, 42, 
    1, 97, 0, 70, 2, 73, 7, 71, 8, 86, 3,  4, 6,  4, 4, 36, 5, 67
  };
  const int q1663[] = {
    9, 9, // Number of jobs and machines
    0, 65, 2, 94, 7, 22, 5, 97, 4, 56, 3, 77, 6, 86, 8, 95, 1, 35, 
    2, 12, 4, 37, 0, 98, 1, 67, 5, 22, 8, 53, 3,  1, 6, 22, 7, 44, 
    5, 50, 2, 31, 7, 23, 8,  9, 0, 87, 6, 41, 3, 26, 1, 37, 4, 99, 
    3, 94, 8, 21, 0, 37, 1, 30, 5, 19, 6, 68, 7, 93, 2, 30, 4, 90, 
    8, 87, 7, 58, 3,  9, 6, 97, 4, 34, 2, 14, 5, 71, 0,  9, 1,  6, 
    0, 45, 1, 49, 2, 81, 6, 84, 8, 96, 5, 33, 3, 41, 7, 76, 4, 60, 
    5, 16, 3, 62, 2,  8, 8, 40, 4, 73, 6,  4, 1,  9, 0, 65, 7, 92, 
    0, 38, 3, 39, 6, 50, 4, 13, 8, 33, 2, 79, 1, 13, 7, 10, 5, 82, 
    3, 86, 2, 81, 4, 24, 6, 62, 7,  4, 1, 12, 0, 63, 5, 53, 8, 40
  };
  const int q1664[] = {
    9, 9, // Number of jobs and machines
    7, 14, 5, 78, 6, 80, 3, 95, 1,  7, 0, 78, 4, 89, 8, 84, 2, 44, 
    7, 86, 6, 66, 2, 51, 8, 27, 0, 84, 5, 63, 1, 30, 4, 88, 3, 54, 
    0, 30, 7, 94, 1, 39, 3, 40, 5, 16, 6, 93, 8,  4, 4, 44, 2, 16, 
    7, 38, 6, 91, 0,  1, 4, 38, 5, 41, 8, 65, 2, 50, 3, 88, 1, 31, 
    6, 35, 2, 24, 1, 27, 3, 60, 7, 33, 5, 97, 4, 34, 8, 52, 0, 48, 
    7, 89, 4, 88, 5, 16, 2, 30, 8, 79, 1, 23, 0, 57, 6, 10, 3, 66, 
    1, 73, 2, 66, 6, 56, 7, 68, 4, 21, 0, 35, 8, 13, 3, 30, 5, 54, 
    8, 60, 0, 85, 3, 58, 4, 99, 2, 50, 5, 62, 6, 55, 7,  2, 1, 42, 
    3, 40, 7, 32, 8, 22, 2, 48, 6, 47, 5, 34, 1, 78, 4, 10, 0, 10
  };
  const int q1665[] = {
    9, 9, // Number of jobs and machines
    3, 47, 4,  9, 2, 71, 8, 70, 5, 99, 1, 63, 0, 82, 6, 69, 7, 85, 
    1, 61, 4, 11, 2, 16, 6, 50, 5, 63, 7, 72, 8, 12, 0, 94, 3,  9, 
    2, 77, 5,  2, 8, 24, 3, 66, 1,  5, 0, 61, 6, 55, 4, 64, 7, 31, 
    0, 12, 4,  2, 1, 29, 7, 59, 3, 62, 5, 11, 8, 82, 2, 60, 6, 18, 
    3, 58, 6, 43, 5, 11, 2, 28, 0, 45, 7, 35, 8, 24, 4, 14, 1, 35, 
    1,  8, 8, 44, 7, 53, 6,  7, 0, 86, 3, 99, 2, 81, 5, 13, 4, 44, 
    0, 23, 8, 59, 6, 98, 1, 38, 7, 71, 4, 24, 5, 26, 3, 67, 2, 37, 
    4, 20, 1, 16, 3, 31, 8, 84, 6, 79, 5,  3, 7, 10, 0, 13, 2, 57, 
    7,  1, 6, 58, 1, 63, 4, 69, 8,  6, 5, 58, 2, 35, 3, 73, 0, 21
  };
  const int q1666[] = {
    9, 9, // Number of jobs and machines
    3, 95, 8, 85, 7, 12, 5, 33, 1, 91, 6, 29, 2, 78, 4,  5, 0, 60, 
    4, 44, 1, 49, 7,  5, 2, 99, 3, 89, 0, 94, 6, 75, 8, 59, 5, 84, 
    2, 55, 5, 21, 0, 98, 1, 50, 7, 72, 8, 21, 6, 47, 4,  4, 3, 92, 
    3, 76, 5, 16, 2, 94, 0, 55, 7, 45, 8, 95, 1, 76, 4, 60, 6, 38, 
    6, 59, 7, 32, 2, 28, 3, 85, 8, 90, 5, 98, 0, 72, 1, 92, 4, 76, 
    7, 91, 6, 90, 1, 21, 8, 93, 5, 43, 0,  2, 2, 43, 4,  6, 3, 47, 
    0, 95, 1, 13, 3, 95, 4, 95, 6, 32, 2, 93, 7, 44, 8,  4, 5, 23, 
    3,  6, 5, 40, 8, 47, 0, 79, 4, 77, 2, 18, 1, 52, 7, 27, 6, 80, 
    3, 30, 7, 77, 0, 16, 8, 87, 1, 51, 5, 37, 6, 86, 4, 17, 2,  3
  };
  const int q1667[] = {
    9, 9, // Number of jobs and machines
    6, 18, 3, 93, 7, 51, 0, 62, 8, 69, 2, 68, 4, 57, 1, 97, 5, 82, 
    5,  6, 8, 33, 2, 88, 4, 32, 3, 61, 1, 39, 6, 24, 7, 21, 0, 52, 
    8, 32, 0, 35, 1, 46, 3, 11, 5, 47, 2, 34, 7, 14, 6, 90, 4, 60, 
    8, 28, 0, 98, 3,  4, 4, 65, 7,  1, 2, 61, 5,  9, 1, 31, 6, 12, 
    4, 54, 5, 83, 0, 91, 2, 19, 8, 27, 6, 35, 7, 33, 3, 49, 1, 18, 
    2, 51, 4, 26, 1, 74, 8, 74, 7, 70, 6, 41, 5, 50, 0, 81, 3, 35, 
    3,  9, 2, 11, 5, 29, 6, 98, 1, 60, 8, 73, 7, 26, 4, 91, 0, 61, 
    6, 78, 3, 37, 0, 10, 4, 38, 1, 81, 7, 98, 8, 75, 2, 26, 5, 14, 
    3, 42, 8, 36, 2, 18, 7, 99, 6, 57, 5, 43, 0, 80, 1, 71, 4, 24
  };
  const int q1668[] = {
    9, 9, // Number of jobs and machines
    0, 66, 8, 83, 3, 40, 2, 66, 1, 11, 5, 50, 7, 74, 4, 33, 6, 60, 
    8, 54, 4, 23, 1, 30, 5, 22, 3, 87, 6, 12, 2, 88, 0, 23, 7,  4, 
    4, 55, 2, 80, 7, 96, 6, 66, 0, 76, 8, 76, 3, 90, 5, 13, 1, 15, 
    3, 62, 7,  7, 6, 55, 1, 19, 2, 26, 8, 19, 5, 44, 4, 56, 0,  1, 
    6, 29, 2, 37, 5, 14, 7, 32, 4, 80, 8, 48, 3, 25, 0, 40, 1, 79, 
    4,  6, 8, 82, 0, 52, 6, 93, 1, 52, 3, 64, 5, 98, 2, 73, 7, 71, 
    5, 13, 7, 21, 1, 84, 4, 22, 8, 13, 6, 33, 2, 37, 0, 73, 3, 64, 
    4, 37, 8, 57, 2, 44, 1, 30, 5, 93, 6, 60, 0, 18, 7, 47, 3, 54, 
    5, 19, 4, 35, 3, 97, 2, 94, 1, 32, 0, 37, 7, 83, 8, 55, 6, 61
  };
  const int q1669[] = {
    9, 9, // Number of jobs and machines
    0, 69, 7, 67, 8, 43, 3, 82, 6, 20, 1, 75, 5, 13, 4, 98, 2, 27, 
    8, 22, 3,  8, 5, 88, 7, 51, 6, 49, 2, 56, 4, 46, 1, 78, 0, 70, 
    8, 15, 5, 48, 2, 34, 1, 96, 3, 11, 7,  9, 0, 57, 4, 29, 6, 47, 
    0, 69, 6, 49, 5, 81, 7, 45, 4, 34, 3,  4, 2, 80, 8, 97, 1, 44, 
    3, 67, 2, 62, 7, 64, 4, 18, 5, 74, 8, 45, 6,  2, 1, 88, 0, 67, 
    6, 11, 4, 85, 0,  1, 1, 93, 2, 25, 7, 56, 3, 36, 8, 70, 5, 85, 
    8, 18, 4,  6, 1, 49, 6, 95, 3, 72, 5, 66, 2, 66, 7, 56, 0, 35, 
    6, 17, 0, 60, 4, 55, 1, 61, 5, 96, 8, 16, 2, 10, 7, 20, 3, 96, 
    7, 53, 1, 92, 3, 34, 2, 76, 0, 85, 5, 35, 6, 47, 4, 49, 8, 29
  };
  const int q1670[] = {
    9, 9, // Number of jobs and machines
    6, 36, 1, 67, 2, 27, 4, 26, 0, 40, 8, 27, 3, 68, 5, 70, 7, 90, 
    3, 72, 6, 15, 0, 79, 2, 32, 1, 96, 8, 35, 7, 65, 5, 67, 4, 23, 
    6, 38, 7, 61, 8, 95, 4, 48, 1, 77, 5, 98, 2, 62, 0, 76, 3, 21, 
    1, 94, 2, 84, 4, 81, 6, 12, 8, 36, 0, 92, 5,  2, 3, 43, 7,  8, 
    3, 76, 0, 10, 4, 26, 7, 75, 8, 96, 6,  6, 5, 74, 1, 35, 2, 10, 
    2, 81, 3, 23, 4, 24, 5, 86, 8, 36, 7, 84, 1, 69, 6, 71, 0, 60, 
    6, 25, 4, 86, 7, 68, 2,  3, 8, 63, 1, 48, 3, 21, 5, 47, 0,  8, 
    1, 25, 4, 14, 3, 59, 8, 96, 5,  7, 2,  5, 6, 45, 7, 33, 0, 54, 
    4, 95, 0, 59, 3, 20, 6, 27, 7, 63, 8, 31, 5, 13, 2, 78, 1, 56
  };
  const int q1671[] = {
    9, 9, // Number of jobs and machines
    3, 79, 5, 87, 2, 43, 1, 80, 0, 79, 4, 67, 7, 58, 6,  3, 8, 55, 
    5, 54, 0, 14, 7, 34, 4, 32, 3,  7, 6, 67, 2, 48, 8, 79, 1, 97, 
    2, 51, 0, 16, 3, 32, 7, 10, 8, 95, 6, 97, 1, 34, 5, 75, 4, 72, 
    6, 65, 2, 93, 5, 14, 0, 65, 4, 62, 3, 84, 1, 76, 8, 13, 7, 51, 
    8, 40, 0, 93, 4, 10, 6, 49, 5,  5, 1, 92, 3, 78, 2, 39, 7, 20, 
    5, 99, 2, 16, 3, 24, 1, 11, 8,  5, 6, 42, 0, 61, 4, 88, 7, 36, 
    4, 52, 2, 26, 7, 53, 8, 92, 0, 87, 1, 95, 5, 74, 3, 58, 6,  7, 
    2, 33, 8, 77, 3, 47, 4, 25, 1, 30, 7, 93, 0, 75, 6,  8, 5,  6, 
    7, 84, 8,  1, 1, 86, 5, 79, 0, 63, 6, 53, 2, 89, 4, 82, 3,  3
  };
  const int q1672[] = {
    9, 9, // Number of jobs and machines
    7,  6, 6, 50, 0, 79, 2, 10, 3, 98, 8, 19, 4, 24, 1, 13, 5, 34, 
    5, 77, 4, 47, 7, 81, 3, 66, 8, 41, 1, 38, 0, 21, 2, 14, 6, 13, 
    3, 46, 4, 38, 5, 54, 1,  2, 8, 50, 0, 93, 7, 93, 2,  3, 6, 84, 
    4, 28, 7, 48, 6, 78, 0, 72, 1, 14, 8, 90, 5, 24, 3, 98, 2, 58, 
    6, 49, 4, 98, 8,  7, 7, 49, 5, 33, 0,  1, 2, 63, 3, 99, 1, 40, 
    6, 17, 5,  4, 4, 65, 1, 87, 2, 31, 7, 93, 8, 69, 0, 19, 3, 85, 
    3,  3, 2, 39, 1, 12, 0, 25, 4, 59, 8, 91, 7,  5, 6, 79, 5, 28, 
    6, 91, 3, 52, 4, 74, 7, 19, 1, 80, 2, 16, 8, 98, 5, 96, 0, 21, 
    0, 19, 6, 81, 2, 10, 7, 10, 1, 62, 4, 32, 3, 64, 5, 97, 8, 82
  };
  const int q1673[] = {
    9, 9, // Number of jobs and machines
    4, 65, 1, 54, 0, 80, 2, 81, 7, 59, 8, 70, 6,  9, 5, 12, 3, 73, 
    2, 45, 4, 21, 0, 57, 8, 94, 1, 59, 6, 37, 3, 10, 5, 98, 7, 84, 
    6,  3, 0, 13, 7, 21, 5, 24, 8, 66, 4,  9, 2, 90, 1, 68, 3, 66, 
    1, 94, 0,  4, 5, 46, 6, 57, 3, 23, 4, 26, 2, 46, 8, 84, 7, 85, 
    5, 54, 0, 47, 1, 37, 8, 26, 7, 83, 3, 12, 4, 93, 6, 13, 2, 32, 
    2, 72, 1, 74, 6, 75, 3, 30, 5, 28, 7, 54, 8, 70, 0, 43, 4, 44, 
    4, 48, 2, 68, 8, 47, 6, 85, 1, 61, 0, 89, 3,  9, 7, 65, 5, 35, 
    2, 24, 4, 41, 1,  1, 7,  2, 0, 77, 8, 17, 5, 59, 6, 58, 3, 31, 
    7, 99, 5, 21, 3, 45, 4,  1, 8,  8, 0, 99, 2, 10, 6, 29, 1, 63
  };
  const int q1674[] = {
    9, 9, // Number of jobs and machines
    1, 78, 0, 13, 8, 75, 2, 24, 4, 28, 3, 62, 6, 52, 5, 40, 7, 40, 
    7, 22, 1, 26, 6, 83, 8, 32, 4, 74, 5, 33, 3, 21, 0, 37, 2, 70, 
    1, 87, 7, 55, 3, 22, 2, 32, 0, 99, 8, 15, 6, 61, 5, 23, 4, 64, 
    6, 87, 1, 90, 2, 63, 7, 12, 3, 11, 4, 48, 0, 71, 5, 78, 8, 28, 
    2, 61, 0, 10, 5, 24, 6, 73, 7, 28, 4, 68, 1,  3, 3, 91, 8, 39, 
    5, 12, 7,  8, 0, 96, 1, 93, 2, 98, 3, 57, 8,  9, 4, 48, 6,  3, 
    3, 21, 6, 38, 4,  6, 7,  2, 2, 91, 0, 69, 5, 80, 1,  7, 8, 12, 
    1, 68, 2, 94, 3, 12, 4, 57, 7, 22, 0,  8, 6, 51, 8, 90, 5, 74, 
    1, 16, 0, 37, 3, 84, 2, 72, 8, 77, 6, 55, 7, 91, 5, 59, 4, 13
  };
  const int q1675[] = {
    9, 9, // Number of jobs and machines
    3, 23, 7, 90, 1, 72, 8, 87, 0, 51, 2, 62, 4, 94, 5, 44, 6, 29, 
    1, 53, 8, 57, 0, 75, 6, 53, 4, 87, 3, 33, 5, 71, 2, 32, 7, 32, 
    8, 33, 0,  2, 2, 48, 5, 37, 6, 98, 3, 88, 4, 55, 7, 32, 1, 27, 
    5, 48, 8, 22, 1, 59, 2, 44, 3, 32, 0, 14, 7, 65, 4, 10, 6, 90, 
    0, 72, 2, 37, 6,  5, 1, 93, 4, 14, 7, 28, 3,  5, 8, 97, 5, 43, 
    2, 80, 3, 98, 5,  9, 6,  4, 1, 80, 8, 98, 4, 62, 0, 53, 7,  2, 
    2, 65, 4, 35, 7,  2, 0, 60, 8, 10, 5, 61, 6,  4, 3,  6, 1, 44, 
    0, 81, 3, 84, 4, 94, 6, 75, 8, 41, 5, 74, 1, 83, 7, 61, 2, 24, 
    4, 19, 1, 70, 5, 97, 8, 56, 7, 66, 0, 55, 3, 93, 2, 48, 6, 39
  };
  const int q1676[] = {
    9, 9, // Number of jobs and machines
    3, 97, 2, 71, 1, 10, 7, 56, 4, 13, 8, 28, 6, 18, 0, 17, 5,  9, 
    3, 51, 1, 38, 8, 89, 0, 35, 7, 63, 2, 76, 6, 80, 4, 40, 5, 92, 
    4, 72, 2, 93, 0, 94, 1, 20, 8, 31, 5, 30, 6, 21, 7, 88, 3, 81, 
    2, 83, 3, 40, 0, 39, 4, 34, 1, 57, 6, 98, 7,  8, 8, 94, 5, 92, 
    6, 18, 4, 82, 0, 90, 7, 63, 5, 31, 1, 32, 8, 12, 2, 94, 3, 69, 
    7, 50, 0, 21, 8,  5, 4, 76, 2, 33, 1, 38, 3,  8, 5, 44, 6, 34, 
    7, 17, 0,  8, 1,  8, 2, 83, 3, 52, 6, 14, 4, 71, 8, 80, 5, 55, 
    2, 21, 3, 87, 1, 93, 0, 79, 6,  7, 4, 92, 8, 74, 7, 30, 5, 96, 
    5, 47, 1, 50, 6, 30, 3, 91, 8,  2, 7, 79, 0, 57, 2, 78, 4, 22
  };
  const int q1677[] = {
    9, 9, // Number of jobs and machines
    6, 17, 3, 14, 8, 59, 5, 18, 1, 75, 7, 70, 0, 21, 4, 75, 2, 95, 
    8, 77, 7, 46, 3, 17, 4,  1, 2, 60, 5, 75, 6, 94, 1, 11, 0, 10, 
    1, 99, 5, 87, 2, 82, 6, 54, 0, 46, 8, 29, 3, 30, 7,  9, 4, 55, 
    5, 99, 3,  4, 1, 80, 7, 64, 8, 15, 0, 33, 2, 91, 4, 76, 6, 85, 
    0, 55, 8, 27, 4, 26, 6, 11, 1, 77, 7, 10, 5, 57, 2, 15, 3,  5, 
    3, 15, 8, 99, 1, 48, 2,  5, 4, 85, 0, 65, 6, 99, 7, 49, 5, 19, 
    0, 86, 5, 98, 1, 87, 8, 36, 2, 10, 4,  8, 3, 58, 6, 20, 7, 91, 
    7, 85, 4, 80, 6, 82, 5, 91, 2, 48, 3, 64, 0, 77, 8,  7, 1, 47, 
    0, 68, 8, 94, 6, 71, 5,  5, 3, 24, 4, 14, 1, 86, 7, 88, 2, 85
  };
  const int q1678[] = {
    9, 9, // Number of jobs and machines
    7, 88, 0, 56, 3, 70, 2, 76, 4, 52, 8, 52, 6, 27, 1,  4, 5,  2, 
    2, 95, 5, 93, 1,  7, 3, 49, 4, 16, 0, 20, 6, 88, 8, 32, 7, 51, 
    2, 11, 6, 53, 1, 33, 7, 65, 3, 71, 0, 67, 5, 99, 4, 78, 8, 19, 
    2, 49, 7, 43, 1, 33, 3,  6, 4, 84, 5, 73, 8, 54, 6, 39, 0,  6, 
    2, 96, 1, 69, 4, 89, 7, 41, 6, 34, 3, 97, 0, 99, 8,  4, 5, 54, 
    5, 60, 0,  9, 6, 51, 4, 99, 3, 47, 7,  7, 1, 14, 2, 13, 8, 49, 
    2, 26, 6, 99, 1, 26, 3, 86, 4, 94, 7, 95, 8, 59, 5,  6, 0, 20, 
    1, 43, 3, 20, 4,  6, 2, 36, 0, 70, 8, 71, 5, 18, 6, 49, 7, 76, 
    1,  6, 6, 94, 4, 52, 0, 10, 2, 68, 8, 43, 3,  6, 7, 33, 5, 56
  };
  const int q1679[] = {
    9, 9, // Number of jobs and machines
    5, 31, 3, 55, 4, 58, 7, 30, 1, 80, 8, 64, 2, 92, 0, 26, 6, 42, 
    4, 88, 6, 13, 0, 49, 7,  6, 1, 43, 2, 51, 3, 50, 5,  4, 8, 32, 
    3, 38, 0, 89, 7, 37, 2, 34, 4, 28, 6, 31, 1, 32, 5, 98, 8, 66, 
    7, 56, 0, 55, 8, 69, 6, 84, 4, 66, 2,  7, 1, 45, 5,  5, 3, 50, 
    8, 10, 3, 96, 4, 98, 1, 31, 5, 22, 7, 71, 6, 77, 2, 35, 0, 95, 
    4, 31, 1, 25, 2, 33, 0, 38, 3, 93, 8, 31, 5, 13, 6, 29, 7, 46, 
    0, 45, 2, 45, 7, 41, 5, 17, 4, 32, 3, 83, 8, 99, 6, 12, 1, 47, 
    5, 93, 4, 33, 1,  6, 3, 14, 6, 21, 7, 99, 8, 86, 0, 19, 2, 24, 
    3, 66, 8, 42, 0, 63, 7, 19, 4, 15, 6, 64, 1, 43, 2, 46, 5,  4
  };
  const int q1680[] = {
    9, 9, // Number of jobs and machines
    4, 67, 0, 48, 2, 69, 6, 60, 5, 73, 3, 20, 1, 68, 7, 81, 8, 40, 
    6, 84, 2, 88, 1, 49, 3, 81, 8, 13, 7, 83, 5, 18, 4, 66, 0, 80, 
    6, 89, 8, 74, 7, 52, 2, 36, 4, 54, 3, 61, 0, 65, 5, 23, 1, 81, 
    6, 74, 8, 74, 5,  5, 4, 74, 7, 21, 0, 66, 3, 99, 1, 84, 2, 83, 
    4, 82, 7, 13, 1,  6, 2, 25, 6, 91, 0, 48, 5,  3, 8, 62, 3, 29, 
    4, 79, 5, 17, 2, 90, 3, 64, 7, 79, 8, 26, 6, 57, 0, 66, 1, 55, 
    4, 17, 7, 32, 0, 15, 6, 82, 5, 99, 3, 86, 2, 54, 1, 82, 8, 91, 
    6,  9, 1, 76, 7, 80, 5, 74, 0, 71, 8, 87, 4,  3, 2, 59, 3, 98, 
    4, 83, 1, 38, 6, 70, 0, 79, 3, 41, 5, 99, 2, 37, 7, 42, 8, 78
  };
  const int q1681[] = {
    9, 9, // Number of jobs and machines
    3, 78, 5, 14, 0, 71, 7, 16, 2, 72, 4, 96, 8, 24, 6, 24, 1, 33, 
    4, 76, 5, 70, 6, 40, 1, 22, 0, 74, 2, 32, 8,  5, 3, 39, 7, 28, 
    0, 58, 4, 58, 2, 56, 5, 79, 6, 22, 7, 40, 1, 15, 8, 32, 3, 84, 
    0, 17, 6, 95, 5, 30, 8, 43, 1, 83, 2,  9, 3, 82, 7, 47, 4, 87, 
    3, 14, 6, 45, 2, 71, 4, 29, 1, 87, 5, 78, 7,  6, 0, 90, 8, 77, 
    7, 77, 6, 64, 8, 17, 4, 10, 3, 41, 1, 40, 0, 92, 2, 21, 5, 51, 
    2, 25, 3, 90, 4, 91, 6, 19, 0,  8, 1, 72, 7, 55, 5, 32, 8, 36, 
    8, 70, 0, 65, 1, 53, 5, 89, 6, 84, 4,  8, 3, 62, 2, 59, 7, 63, 
    5, 51, 7, 30, 8, 21, 2, 15, 6, 43, 0,  4, 3, 92, 4, 59, 1, 45
  };
  const int q1682[] = {
    9, 9, // Number of jobs and machines
    5, 37, 6, 91, 0, 35, 1, 87, 4, 51, 8, 27, 2, 96, 7, 93, 3, 17, 
    7,  7, 8, 55, 6, 63, 3,  8, 5, 98, 0, 26, 2, 40, 4, 21, 1, 47, 
    0, 91, 8, 95, 2, 11, 5, 86, 7, 70, 6, 65, 3, 43, 4, 72, 1, 83, 
    5, 73, 7, 73, 3, 77, 1, 93, 4, 31, 6, 62, 0,  6, 2, 25, 8, 69, 
    2, 67, 0, 50, 7, 68, 1,  1, 6, 86, 3, 25, 4, 45, 8, 45, 5, 55, 
    4, 32, 0, 45, 2, 95, 1, 87, 7, 69, 8, 89, 3, 19, 6, 48, 5,  4, 
    2, 69, 4, 86, 6, 80, 0,  7, 1, 78, 3,  6, 5, 42, 7, 25, 8, 87, 
    2, 93, 3, 47, 6, 50, 0, 24, 4, 44, 1, 20, 8, 71, 5, 37, 7,  3, 
    3, 51, 0, 27, 5, 87, 6, 11, 7, 90, 8, 44, 4, 86, 2, 82, 1, 28
  };
  const int q1683[] = {
    9, 9, // Number of jobs and machines
    4,  9, 2,  5, 0, 94, 8, 74, 3, 19, 6,  2, 5, 36, 1, 69, 7, 67, 
    5, 56, 0, 22, 7, 76, 2, 57, 4, 49, 3, 61, 6, 87, 8, 35, 1, 25, 
    7,  2, 0, 89, 1, 36, 8, 33, 6, 49, 3, 31, 5, 79, 4, 21, 2, 74, 
    8, 18, 3, 25, 5, 20, 0, 88, 7,  4, 6, 64, 2, 49, 4, 70, 1, 79, 
    7, 67, 8, 69, 6, 30, 1, 45, 5, 83, 4, 99, 2, 51, 0, 87, 3,  8, 
    0, 45, 2, 63, 7, 41, 3, 57, 5, 69, 1,  4, 6, 78, 4, 67, 8, 85, 
    1, 85, 2, 63, 5, 23, 8, 33, 6, 75, 0, 75, 7, 15, 3, 14, 4, 90, 
    4, 94, 0, 88, 7, 70, 5, 58, 8, 22, 3, 60, 6, 62, 2, 76, 1, 23, 
    2, 86, 7, 36, 0, 46, 8, 34, 4, 61, 6,  8, 1, 64, 3,  5, 5,  7
  };
  const int q1684[] = {
    9, 9, // Number of jobs and machines
    3, 46, 6, 76, 5, 57, 2,  4, 8, 84, 4, 90, 7,  4, 1, 61, 0, 72, 
    5, 48, 0,  5, 2, 31, 8, 72, 6, 39, 3,  3, 1, 91, 7, 92, 4, 23, 
    6, 66, 3, 56, 1, 59, 8, 74, 4, 10, 0, 21, 5, 38, 7, 73, 2, 30, 
    7, 21, 6, 41, 2, 35, 5, 43, 3, 65, 0,  6, 8, 77, 4, 35, 1, 37, 
    4, 50, 6, 88, 7, 96, 2,  9, 1, 58, 5, 42, 0, 96, 3, 66, 8, 80, 
    6, 39, 0, 33, 2, 57, 3, 97, 8, 47, 1, 10, 7, 70, 5, 33, 4,  2, 
    7, 93, 5, 96, 0, 77, 2, 48, 3, 38, 4, 20, 1, 56, 8, 31, 6, 74, 
    5, 13, 0, 51, 3, 34, 2, 60, 4, 61, 1, 65, 8, 81, 7, 70, 6, 32, 
    8, 69, 5, 76, 2, 38, 0, 87, 4,  6, 3, 22, 6, 79, 1, 74, 7, 29
  };
  const int q1685[] = {
    9, 9, // Number of jobs and machines
    1,  4, 2, 33, 5, 50, 0, 75, 7, 63, 3, 31, 8, 56, 4,  5, 6, 47, 
    3, 36, 0, 78, 7, 70, 5, 13, 4, 65, 8, 32, 6, 62, 1, 29, 2, 11, 
    2, 66, 1, 93, 8, 90, 6,  9, 5, 52, 3, 47, 7, 97, 4, 27, 0, 61, 
    1, 42, 8,  9, 2, 26, 6, 78, 7, 46, 5, 33, 3,  2, 4, 30, 0, 49, 
    3, 55, 8, 80, 6, 54, 0, 99, 2, 63, 4, 63, 1, 86, 7, 24, 5,  4, 
    3, 91, 4, 61, 6, 48, 8, 29, 5, 46, 0, 48, 2, 38, 7, 93, 1, 63, 
    2, 91, 8, 17, 1,  8, 5, 81, 7, 78, 4, 56, 0,  3, 3, 53, 6, 74, 
    3, 64, 8,  7, 7,  7, 6, 91, 2, 78, 4, 14, 1, 74, 0, 19, 5, 34, 
    8, 83, 7, 53, 6, 22, 2, 72, 1, 37, 5,  2, 4, 17, 3, 75, 0, 21
  };
  const int q1686[] = {
    9, 9, // Number of jobs and machines
    0, 15, 5, 97, 8, 16, 2, 26, 7, 85, 6, 54, 4, 65, 1, 75, 3, 89, 
    2, 67, 8, 61, 1, 35, 5, 32, 7, 76, 6, 73, 0, 49, 4, 99, 3, 98, 
    2,  5, 7, 61, 3, 25, 4, 88, 5, 15, 0,  5, 1, 21, 6, 61, 8,  4, 
    6, 78, 5, 13, 4, 41, 7, 12, 2, 57, 3, 57, 8, 45, 1, 14, 0, 37, 
    5, 53, 8, 37, 6, 22, 0, 59, 1, 74, 2, 79, 3, 58, 7, 41, 4,  1, 
    5, 15, 8, 34, 4, 17, 7, 93, 3, 33, 1, 74, 0, 66, 6, 17, 2, 23, 
    4, 65, 3, 52, 5, 45, 1, 15, 6, 63, 7, 84, 8, 79, 2, 32, 0, 36, 
    4, 68, 5,  1, 7, 89, 3, 58, 0,  2, 8, 50, 6, 72, 1, 87, 2, 31, 
    8, 37, 6, 48, 4, 53, 5, 25, 3, 50, 0, 48, 2, 21, 7,  5, 1, 70
  };
  const int q1687[] = {
    9, 9, // Number of jobs and machines
    3, 21, 1, 87, 0, 81, 6, 87, 4,  2, 5, 66, 7, 33, 8, 75, 2,  3, 
    4, 99, 0, 10, 3, 74, 7, 66, 2, 18, 5,  1, 1, 95, 6,  8, 8, 50, 
    0, 77, 1, 70, 4, 15, 5, 70, 2, 19, 7, 75, 6, 78, 3, 10, 8,  3, 
    2, 79, 1, 35, 8, 63, 4, 25, 0, 18, 3, 75, 7, 81, 6,  1, 5, 77, 
    5,  2, 3, 43, 2, 56, 8, 24, 6, 41, 7, 96, 4, 75, 1, 82, 0, 61, 
    8, 81, 1, 11, 6, 64, 2, 36, 4, 14, 3, 52, 7, 88, 0, 87, 5,  5, 
    8, 24, 3, 26, 5, 37, 2, 55, 6, 82, 4, 40, 0, 33, 1, 13, 7, 54, 
    2, 92, 1, 61, 6, 11, 0, 65, 3, 68, 5, 88, 4, 77, 8, 98, 7, 30, 
    8, 22, 5, 88, 4, 80, 1, 98, 6,  3, 3, 32, 7,  2, 2, 86, 0, 79
  };
  const int q1688[] = {
    9, 9, // Number of jobs and machines
    4, 98, 2, 58, 8, 65, 5, 55, 3, 91, 0, 66, 7, 15, 6, 11, 1, 93, 
    1, 97, 7, 64, 4, 83, 3,  8, 2, 90, 8, 15, 6, 53, 0, 92, 5,  1, 
    0, 75, 5, 17, 8, 72, 3, 33, 2, 45, 6, 23, 4, 85, 7, 84, 1, 86, 
    8, 37, 3, 34, 5, 75, 4, 49, 2, 24, 1, 35, 0, 97, 6, 27, 7, 49, 
    3, 39, 6,  2, 7, 15, 0, 58, 2, 86, 4, 89, 5, 88, 8, 90, 1, 73, 
    6, 33, 8, 48, 3,  7, 1, 85, 5, 34, 2, 29, 7, 21, 4, 64, 0, 39, 
    2, 79, 0, 28, 5,  2, 6, 33, 7, 93, 1, 14, 3, 95, 8, 79, 4, 37, 
    3,  2, 8, 87, 2, 39, 1, 73, 7, 38, 6, 55, 0, 63, 4, 10, 5, 11, 
    0, 93, 1, 27, 7, 89, 4,  6, 8, 44, 2, 86, 5, 54, 3, 75, 6, 49
  };
  const int q1689[] = {
    9, 9, // Number of jobs and machines
    3, 61, 2, 24, 0, 15, 8, 20, 5, 17, 7, 92, 1, 56, 4, 72, 6, 30, 
    8, 46, 1, 24, 0, 83, 3, 42, 5, 95, 6, 39, 7, 52, 2, 68, 4, 96, 
    3, 67, 4, 47, 1, 19, 0, 79, 6, 67, 2, 16, 7,  5, 5, 75, 8, 39, 
    0, 34, 2, 30, 8, 25, 5,  8, 7, 98, 6, 81, 3, 43, 4, 87, 1, 86, 
    4, 22, 2, 10, 8, 96, 5, 86, 3, 99, 6, 95, 7, 88, 0, 52, 1,  1, 
    7, 72, 8, 15, 0, 10, 4, 25, 5, 34, 2, 86, 3, 72, 1,  7, 6, 94, 
    3, 63, 8, 30, 5, 90, 1, 50, 2, 28, 6, 96, 0, 84, 4, 81, 7, 25, 
    1, 98, 5, 33, 7, 26, 4, 47, 6, 81, 0, 40, 2, 46, 3, 56, 8, 56, 
    8, 74, 1, 21, 0,  1, 3, 11, 6,  1, 4, 13, 2, 58, 7, 99, 5, 72
  };
  const int q1690[] = {
    9, 9, // Number of jobs and machines
    7, 72, 3, 47, 2,  9, 6,  9, 1, 81, 0,  2, 4, 36, 8, 53, 5, 73, 
    2, 92, 0, 98, 1, 92, 5, 21, 4, 96, 6, 80, 3, 91, 8, 21, 7,  4, 
    3, 57, 2, 96, 6, 18, 5,  5, 8, 96, 7, 13, 4, 88, 0, 46, 1, 74, 
    0, 35, 7, 44, 4, 80, 2, 34, 6, 25, 5, 68, 8, 99, 1, 10, 3, 82, 
    0, 58, 5, 21, 6, 96, 1, 45, 4, 64, 8, 79, 7, 69, 3, 59, 2, 56, 
    6, 42, 2, 36, 5, 58, 3, 71, 1, 99, 0, 89, 7, 39, 8, 72, 4,  6, 
    2, 52, 3, 19, 7, 80, 4, 97, 0,  8, 6, 56, 1, 99, 5, 29, 8, 89, 
    2, 74, 7, 97, 6, 69, 0, 59, 8, 97, 4,  1, 3, 76, 5, 70, 1, 60, 
    3, 91, 6, 85, 0, 15, 1, 42, 2, 77, 7, 46, 5, 10, 8, 52, 4, 69
  };
  const int q1691[] = {
    9, 9, // Number of jobs and machines
    1, 29, 6, 74, 2, 83, 4, 63, 0, 61, 7, 58, 5, 29, 8,  9, 3, 23, 
    5, 40, 2, 60, 8, 54, 0, 67, 1, 72, 6, 52, 4, 16, 3, 23, 7,  8, 
    3, 88, 2, 50, 4, 55, 1, 28, 6, 43, 7, 42, 5,  1, 0, 92, 8, 11, 
    1, 99, 8, 57, 7, 20, 6, 22, 3, 91, 5, 15, 4, 95, 2, 80, 0, 20, 
    3, 63, 5, 45, 4, 95, 8, 83, 1,  5, 6, 70, 0, 37, 2, 12, 7, 56, 
    3, 85, 2, 11, 8,  7, 1, 98, 0, 26, 7, 12, 4, 91, 5, 54, 6, 81, 
    6, 76, 3, 90, 2, 22, 1, 63, 5, 70, 8, 89, 7,  3, 4, 70, 0, 92, 
    5,  5, 1, 43, 3, 91, 6, 56, 4, 93, 0, 40, 7, 73, 2, 67, 8, 95, 
    4, 64, 6, 66, 0, 16, 5, 77, 7, 22, 8, 73, 1, 75, 3,  8, 2, 90
  };
  const int q1692[] = {
    9, 9, // Number of jobs and machines
    3, 66, 8, 49, 0,  2, 2, 70, 7, 46, 6,  3, 4, 60, 5, 31, 1, 23, 
    5, 98, 2, 62, 0,  2, 7, 51, 6, 79, 1, 59, 3, 53, 4, 95, 8, 42, 
    6, 90, 3, 25, 8, 18, 0, 87, 1, 59, 7, 49, 5,  8, 4, 51, 2, 88, 
    1, 95, 4, 20, 7, 63, 0, 68, 2, 60, 3, 98, 6, 12, 5, 43, 8, 28, 
    7, 30, 8, 65, 2, 92, 1, 46, 4,  1, 5, 73, 3, 35, 6, 83, 0, 13, 
    4,  6, 8,  8, 1,  7, 6, 43, 0, 72, 2, 45, 7, 91, 5, 29, 3, 46, 
    3, 17, 6, 76, 2, 50, 1, 81, 0, 71, 5,  6, 7, 83, 4, 74, 8,  6, 
    8, 83, 3,  7, 6, 48, 4, 18, 0, 34, 5, 79, 1, 87, 7,  3, 2, 90, 
    2, 32, 0, 21, 5, 85, 8, 74, 7, 46, 3, 10, 4,  9, 6, 15, 1, 64
  };
  const int q1693[] = {
    9, 9, // Number of jobs and machines
    3,  2, 5, 62, 7, 10, 4,  7, 2, 30, 0, 40, 1, 37, 8,  8, 6, 27, 
    1, 23, 0, 43, 8, 57, 4, 22, 5, 10, 7, 68, 3, 69, 2, 54, 6, 75, 
    4, 58, 0, 85, 7, 50, 8, 95, 5, 37, 1, 19, 2, 95, 3,  1, 6, 51, 
    3,  4, 5,  7, 2, 21, 6,  7, 4, 87, 8, 78, 7, 65, 1, 74, 0, 61, 
    8, 97, 2, 37, 1, 83, 7, 74, 4, 80, 3, 93, 6, 57, 5,  2, 0, 17, 
    3, 92, 2, 99, 7, 28, 0, 74, 4,  5, 5, 29, 1, 34, 8, 29, 6, 30, 
    2, 34, 3, 72, 1, 94, 7, 16, 0,  6, 6, 19, 8, 37, 4, 55, 5,  3, 
    7, 72, 0, 36, 3, 32, 2, 82, 6, 29, 4, 13, 5,  8, 1, 62, 8, 87, 
    1, 37, 4, 25, 2, 22, 7, 81, 0, 94, 5, 28, 6, 98, 8, 59, 3, 32
  };
  const int q1694[] = {
    9, 9, // Number of jobs and machines
    7,  2, 8, 68, 1, 73, 5, 78, 2, 83, 3, 50, 0, 73, 4, 29, 6,  5, 
    0, 17, 4, 56, 6, 67, 7, 18, 5, 92, 1, 75, 8, 19, 2, 26, 3, 24, 
    4, 83, 1, 29, 8, 84, 2, 21, 0, 95, 7, 55, 3, 98, 6, 85, 5, 88, 
    7, 76, 1, 24, 6, 71, 8, 78, 0, 10, 3, 17, 4, 60, 5, 61, 2, 22, 
    5, 40, 1, 40, 7, 98, 8, 52, 0, 34, 6, 41, 3, 32, 4, 99, 2, 17, 
    8, 14, 1, 40, 6, 38, 3, 10, 5, 80, 7,  7, 4, 11, 0, 97, 2, 49, 
    7, 82, 1, 59, 0, 92, 4, 74, 3, 69, 6, 98, 5, 45, 2, 19, 8, 67, 
    7,  8, 3, 44, 5, 73, 8,  7, 0, 26, 4, 56, 2, 36, 6, 67, 1, 15, 
    6, 53, 1, 63, 2, 28, 7, 90, 4, 52, 8, 50, 3, 29, 0, 97, 5, 60
  };
  const int q1695[] = {
    9, 9, // Number of jobs and machines
    5, 75, 0, 32, 3, 72, 7, 31, 6, 81, 4, 94, 2, 27, 8, 53, 1, 64, 
    5, 31, 4, 94, 1, 95, 3, 47, 2, 30, 8, 17, 0, 97, 7, 91, 6, 94, 
    0, 75, 7, 42, 8, 81, 2, 50, 4, 95, 3, 57, 5, 71, 1, 60, 6, 32, 
    4, 19, 7, 27, 6, 14, 8, 84, 0, 25, 1, 70, 2, 50, 3, 29, 5, 40, 
    1, 92, 8, 75, 4, 27, 2, 17, 3, 49, 0, 70, 6, 48, 5, 22, 7, 18, 
    4, 62, 2, 19, 5,  9, 0, 71, 3, 91, 7, 48, 6, 57, 1, 49, 8, 40, 
    7,  4, 3, 83, 8, 77, 0, 73, 4, 46, 5,  3, 2, 92, 1, 35, 6, 21, 
    8, 97, 3, 56, 2, 98, 0, 29, 7, 10, 4, 51, 5, 39, 1, 64, 6, 29, 
    1, 10, 3, 10, 8,  1, 2, 15, 7, 31, 5, 78, 4, 92, 0, 29, 6, 40
  };
  const int q1696[] = {
    9, 9, // Number of jobs and machines
    4, 28, 2,  6, 7, 13, 1, 33, 6, 24, 5,  9, 0, 37, 8, 82, 3,  2, 
    7, 11, 0,  6, 1,  6, 5, 97, 8, 94, 6, 80, 2, 71, 4, 29, 3, 86, 
    5, 58, 6, 49, 3, 75, 8, 78, 4,  1, 2, 17, 7, 20, 1, 17, 0, 17, 
    1, 44, 5, 94, 0, 91, 7, 44, 2, 39, 4,  6, 6, 54, 3, 31, 8, 27, 
    3,  8, 5, 14, 7, 26, 6, 80, 0, 46, 2,  8, 1, 89, 4, 32, 8, 83, 
    3,  6, 2, 53, 5,  8, 0, 20, 4, 14, 7, 58, 8, 88, 6, 41, 1, 26, 
    8, 63, 7, 32, 4, 35, 3, 27, 0, 22, 2, 40, 5, 96, 1, 42, 6, 19, 
    4, 54, 7, 33, 0, 31, 8, 95, 1, 75, 2, 79, 3, 46, 5,  8, 6, 92, 
    4, 76, 7, 93, 2, 53, 6, 48, 0, 82, 1, 35, 5, 10, 8,  2, 3, 17
  };
  const int q1697[] = {
    9, 9, // Number of jobs and machines
    1, 65, 2, 44, 5, 40, 3, 16, 7, 12, 6, 99, 0, 98, 8, 94, 4, 59, 
    3,  4, 0, 69, 6, 78, 1, 28, 4, 76, 8, 27, 7, 81, 2, 88, 5, 10, 
    5, 79, 0, 78, 2, 61, 1, 77, 8, 55, 3, 87, 6, 72, 4, 18, 7, 73, 
    4, 66, 8, 57, 5, 26, 3, 23, 1, 66, 7, 81, 0, 36, 6,  6, 2, 36, 
    8, 54, 4, 52, 2, 60, 1, 49, 7, 22, 3, 93, 5, 30, 0, 91, 6, 96, 
    7, 47, 8, 67, 6, 74, 1,  1, 0, 38, 2, 60, 5, 39, 4, 51, 3,  3, 
    1, 32, 5, 94, 3, 66, 4, 64, 7, 91, 6, 95, 8, 81, 2, 67, 0, 26, 
    4, 95, 2,  7, 5, 97, 1, 54, 8, 81, 7, 71, 0, 36, 3, 85, 6, 15, 
    1, 85, 7, 66, 8, 99, 2, 53, 5, 53, 0, 26, 4, 17, 6, 83, 3,  9
  };
  const int q1698[] = {
    9, 9, // Number of jobs and machines
    8, 98, 6, 48, 2, 11, 7, 32, 0, 92, 1, 42, 5,  6, 3, 17, 4, 30, 
    2, 33, 8, 82, 3, 71, 0, 36, 4, 55, 5, 56, 6, 84, 1, 70, 7, 93, 
    2, 92, 7, 18, 1, 36, 3, 17, 8, 54, 6,  2, 0, 73, 4, 24, 5, 28, 
    0, 86, 3, 91, 8, 29, 7, 23, 1, 57, 4, 30, 6, 41, 5, 76, 2, 86, 
    4, 89, 0, 40, 6, 24, 8, 47, 2, 56, 5,  9, 3, 62, 7, 27, 1, 96, 
    4, 33, 6, 93, 8, 44, 0,  9, 1, 45, 3, 24, 2, 80, 5, 89, 7, 98, 
    4, 27, 5, 89, 2, 97, 7, 11, 1, 31, 0, 17, 8, 34, 6, 32, 3, 80, 
    6, 73, 0, 36, 3, 92, 8, 27, 4, 64, 5, 59, 1, 33, 7, 75, 2, 88, 
    4, 91, 2, 92, 3, 85, 8, 47, 5, 94, 6, 51, 1, 22, 7, 23, 0, 25
  };
  const int q1699[] = {
    9, 9, // Number of jobs and machines
    2, 34, 1,  7, 0, 45, 4, 99, 6, 23, 3,  1, 8, 66, 5, 57, 7, 35, 
    6,  7, 5, 36, 8, 22, 4, 24, 0, 46, 2, 65, 3, 15, 7,  5, 1, 44, 
    0, 73, 5, 25, 4, 30, 7, 48, 2,  8, 8, 25, 6, 92, 1,  8, 3, 73, 
    1, 91, 0, 26, 6, 73, 4, 10, 5, 59, 2, 89, 3, 82, 8, 13, 7, 61, 
    4, 19, 6, 96, 2, 24, 5, 24, 7, 57, 1, 54, 3, 58, 0, 26, 8, 49, 
    0, 66, 6, 66, 7, 38, 3, 28, 2, 25, 4, 94, 1, 62, 8, 57, 5, 43, 
    4, 95, 3, 14, 5, 17, 1, 53, 8, 43, 0, 77, 7, 19, 6, 85, 2, 52, 
    8, 65, 7, 24, 5, 37, 2, 52, 4, 78, 0, 70, 6, 11, 1, 58, 3, 15, 
    6, 28, 0, 32, 1, 23, 3, 55, 5,  3, 8, 72, 2, 80, 4, 67, 7, 19
  };
  const int q1700[] = {
    9, 9, // Number of jobs and machines
    6, 98, 3, 13, 5, 13, 4, 31, 1, 51, 8, 83, 0, 97, 7, 59, 2, 42, 
    5, 73, 3, 37, 7, 68, 6, 81, 1, 43, 2, 97, 4, 90, 8, 56, 0, 40, 
    8, 68, 6, 93, 7, 76, 0, 40, 1, 93, 5, 76, 2, 70, 3, 52, 4, 72, 
    2, 95, 7, 32, 5, 47, 8, 53, 4, 55, 1, 90, 3, 75, 6, 96, 0, 43, 
    7, 97, 6, 69, 0, 39, 8, 34, 1, 34, 3, 62, 2, 50, 4, 13, 5, 10, 
    0, 87, 4, 26, 6, 94, 8, 36, 2, 80, 5, 77, 7, 71, 1, 24, 3, 41, 
    5, 95, 8, 54, 6, 17, 0, 15, 1, 22, 3, 19, 2, 68, 7, 75, 4, 95, 
    7, 14, 4, 68, 6, 29, 5, 52, 2, 36, 8, 43, 1,  2, 3, 64, 0, 27, 
    3, 87, 4, 99, 1, 47, 2, 61, 5, 76, 8, 99, 6, 98, 7, 62, 0,  9
  };
  const int q1701[] = {
    9, 9, // Number of jobs and machines
    8, 80, 6, 49, 5, 60, 2, 26, 0, 23, 3, 68, 4, 52, 7, 24, 1,  6, 
    5, 91, 2, 48, 4,  5, 7,  6, 8, 61, 0, 88, 3, 78, 6, 16, 1, 63, 
    1, 67, 7, 47, 0, 60, 4, 74, 2, 61, 8, 92, 3, 30, 5, 90, 6, 91, 
    5, 77, 0,  7, 8,  2, 7, 67, 3, 60, 4,  4, 1, 78, 2,  4, 6, 99, 
    8, 65, 7, 67, 1, 49, 4, 90, 6, 88, 3, 96, 2, 27, 5, 66, 0, 73, 
    2, 56, 4, 63, 8, 58, 3,  8, 6, 59, 0, 53, 1, 74, 5, 45, 7, 24, 
    1, 41, 7, 60, 4,  4, 3, 19, 2, 63, 8, 48, 6, 42, 5, 65, 0, 56, 
    1, 15, 3, 75, 4, 50, 6, 58, 0, 86, 5, 57, 2, 65, 7, 71, 8, 47, 
    7, 90, 0, 47, 6, 15, 1,  5, 5, 55, 2, 94, 3, 37, 4, 29, 8, 50
  };
  const int q1702[] = {
    9, 9, // Number of jobs and machines
    8, 90, 0, 52, 7, 95, 6,  8, 5, 18, 1, 39, 3, 10, 2, 77, 4, 72, 
    3, 61, 6, 37, 5, 89, 1, 26, 0, 16, 2, 79, 4, 38, 7, 57, 8, 53, 
    3, 42, 0, 43, 8, 18, 5, 13, 2, 83, 1, 80, 4, 72, 6, 97, 7, 93, 
    6, 41, 1, 43, 5, 47, 8, 22, 7, 30, 3, 23, 2, 15, 0, 44, 4, 14, 
    1, 12, 0, 83, 7,  2, 6, 68, 8, 54, 5, 94, 3, 18, 2, 15, 4, 25, 
    3, 50, 6, 25, 8, 65, 4, 79, 0,  2, 2,  4, 5, 60, 7, 53, 1, 46, 
    7, 13, 3, 92, 4, 58, 2, 67, 0, 82, 5, 18, 1,  7, 6, 82, 8, 66, 
    6, 86, 7, 39, 8, 11, 2, 15, 5, 49, 1, 63, 4, 63, 3, 82, 0, 35, 
    6, 40, 2, 24, 7, 73, 1, 57, 4,  8, 0, 25, 8,  9, 3, 15, 5, 99
  };
  const int q1703[] = {
    9, 9, // Number of jobs and machines
    3, 92, 6, 14, 0, 65, 8, 87, 4, 99, 5, 76, 7, 48, 2, 37, 1, 37, 
    4,  4, 0, 59, 8, 91, 7,  6, 5,  2, 1,  9, 6, 84, 2, 74, 3, 47, 
    7, 72, 4, 64, 6,  7, 8, 91, 3,  3, 0, 23, 5, 17, 1, 15, 2, 77, 
    1, 77, 0,  9, 8, 46, 2, 95, 6, 94, 5, 95, 3, 65, 4, 77, 7, 67, 
    7, 13, 6, 65, 3, 86, 8, 10, 0, 87, 1, 28, 5, 16, 2,  6, 4, 37, 
    7, 16, 3, 75, 0, 73, 5, 97, 6, 56, 8,  3, 1,  9, 2, 69, 4, 48, 
    6, 83, 4, 86, 1, 47, 3, 69, 7, 21, 5, 20, 0, 66, 2, 31, 8, 41, 
    4, 46, 5, 75, 0, 60, 3, 87, 6, 65, 2, 23, 8, 86, 7, 80, 1, 28, 
    8, 75, 0, 98, 3, 12, 7, 15, 1, 56, 4, 44, 5, 61, 2, 66, 6, 68
  };
  const int q1704[] = {
    9, 9, // Number of jobs and machines
    5, 32, 1,  4, 8, 35, 7,  6, 3, 91, 2, 60, 4,  6, 0, 47, 6, 53, 
    2, 93, 0, 73, 7, 78, 5, 16, 1, 60, 3, 27, 6, 73, 4, 51, 8, 88, 
    7, 32, 3, 67, 0,  6, 4, 94, 8, 52, 6, 67, 5, 44, 2, 21, 1, 90, 
    8,  4, 0, 53, 7, 75, 5, 64, 6, 68, 4, 10, 3, 87, 1, 45, 2, 85, 
    7, 51, 0, 31, 6, 81, 2, 28, 8, 98, 3, 90, 1, 21, 4, 27, 5, 26, 
    4, 51, 5, 10, 8, 27, 0, 32, 3, 71, 6, 45, 1, 23, 2, 62, 7, 20, 
    4, 13, 3, 81, 1, 31, 7, 29, 2, 53, 5, 70, 8, 72, 6,  8, 0, 48, 
    5, 28, 4, 55, 1, 50, 0, 77, 7,  9, 3, 60, 2, 46, 8, 95, 6, 94, 
    4, 57, 5, 35, 3, 27, 0, 81, 8,  5, 7, 51, 6, 80, 1, 63, 2, 15
  };
  const int q1705[] = {
    9, 9, // Number of jobs and machines
    0,  8, 5, 32, 8,  8, 4, 68, 2, 96, 1, 37, 6, 90, 7, 26, 3, 34, 
    2, 24, 3, 76, 0, 74, 7, 17, 5, 82, 1, 42, 8,  1, 4, 72, 6, 28, 
    8, 14, 6, 82, 3, 99, 5, 78, 4, 21, 0, 38, 7, 36, 1, 38, 2, 25, 
    1, 81, 5, 76, 0, 38, 6, 86, 3, 55, 4, 97, 7, 59, 2, 26, 8, 93, 
    3, 69, 6, 16, 7, 32, 1, 85, 8, 87, 4, 99, 0, 30, 5, 56, 2, 51, 
    3, 37, 4,  5, 6, 87, 1, 91, 5, 60, 0, 10, 2, 17, 8, 20, 7, 49, 
    8, 60, 3, 78, 5, 93, 0, 43, 4, 70, 1, 55, 6, 24, 2, 86, 7, 53, 
    4, 25, 1, 85, 2, 21, 6,  9, 8, 82, 7, 59, 0, 29, 5, 23, 3,  3, 
    3, 37, 7, 30, 1, 10, 2, 66, 5, 46, 0, 37, 6, 57, 4,  6, 8, 25
  };
  const int q1706[] = {
    9, 9, // Number of jobs and machines
    5, 77, 2, 64, 7, 16, 8, 51, 3, 37, 0, 19, 4, 75, 6, 68, 1, 90, 
    2, 26, 3, 72, 7,  1, 4, 44, 8, 41, 5, 19, 1,  7, 6,  1, 0, 80, 
    1, 49, 3, 84, 8, 87, 5,  1, 6, 32, 7, 76, 4, 83, 0, 18, 2,  7, 
    7, 84, 2, 30, 5, 48, 3,  7, 4, 32, 0, 83, 8, 80, 1, 90, 6, 81, 
    8, 51, 4, 41, 0, 89, 7, 37, 1, 95, 2, 44, 6, 10, 5, 29, 3, 82, 
    3, 95, 5, 31, 7, 59, 6, 98, 1, 11, 8, 67, 2, 30, 4,  4, 0, 49, 
    8, 36, 3,  5, 1, 69, 4, 16, 5, 26, 6, 24, 7, 73, 0, 54, 2, 67, 
    6, 62, 2, 17, 7, 21, 4, 84, 5, 21, 8, 82, 0, 61, 3, 92, 1, 42, 
    8,  9, 7, 15, 1, 19, 0, 87, 3, 62, 2,  2, 4, 20, 6, 30, 5, 38
  };
  const int q1707[] = {
    9, 9, // Number of jobs and machines
    6, 31, 1, 38, 5, 46, 7,  4, 3, 82, 2, 42, 0, 10, 4, 86, 8, 83, 
    1, 25, 0, 91, 3, 47, 4, 13, 2, 61, 5, 43, 7, 25, 6, 63, 8, 44, 
    4, 99, 1, 58, 0, 13, 3, 87, 7, 69, 8, 60, 2, 25, 6, 28, 5, 84, 
    7, 69, 4, 89, 3, 21, 2, 52, 1, 68, 6,  7, 8, 23, 0, 30, 5, 54, 
    2, 60, 3, 44, 4, 57, 1, 43, 5, 43, 6, 62, 8,  3, 0, 73, 7, 88, 
    4, 34, 7, 26, 2, 65, 6, 62, 8, 37, 1, 20, 0, 33, 3, 37, 5, 19, 
    5, 64, 0, 90, 8, 72, 7, 99, 6, 36, 1, 92, 2, 95, 3, 63, 4, 64, 
    2, 35, 5, 97, 8, 56, 6, 53, 0, 64, 4, 95, 1, 45, 7, 21, 3, 87, 
    1, 56, 7, 77, 8, 32, 6, 62, 3, 30, 5, 51, 0, 90, 2, 78, 4, 56
  };
  const int q1708[] = {
    9, 9, // Number of jobs and machines
    0, 25, 8, 42, 4, 90, 7, 65, 3, 90, 1, 70, 2, 87, 5, 79, 6, 54, 
    1, 28, 2, 65, 7, 76, 6, 68, 5, 69, 3,  3, 0, 79, 4, 45, 8, 80, 
    7, 52, 3,  2, 2, 28, 4, 53, 0, 56, 6, 10, 5,  9, 1, 30, 8, 86, 
    6, 64, 7, 68, 8, 88, 5, 40, 1, 23, 3, 61, 4, 78, 0, 35, 2, 71, 
    6, 55, 5, 62, 1, 91, 0, 30, 4, 40, 2, 66, 7, 54, 8, 68, 3, 36, 
    1, 39, 3, 24, 7, 11, 6, 59, 0, 79, 8, 86, 2, 32, 4, 21, 5, 44, 
    5, 95, 4, 13, 2, 61, 6, 55, 3, 20, 1, 81, 0, 26, 8, 51, 7, 66, 
    8, 62, 7, 10, 6,  5, 0,  6, 1, 11, 2, 10, 4,  7, 3, 22, 5, 43, 
    8, 41, 1, 54, 5, 88, 2, 83, 3, 88, 4, 37, 7, 98, 0, 34, 6, 20
  };
  const int q1709[] = {
    9, 9, // Number of jobs and machines
    7, 27, 5, 63, 2, 93, 0, 87, 3, 42, 1, 59, 4, 18, 6, 99, 8, 66, 
    1, 65, 5, 59, 3, 10, 8, 90, 7, 41, 6,  6, 2, 66, 0, 75, 4, 12, 
    1, 89, 7, 31, 0, 24, 4, 40, 8, 65, 6, 82, 3, 18, 2,  6, 5, 68, 
    1, 55, 8, 54, 2, 26, 0, 39, 3, 19, 6, 12, 7, 64, 5, 96, 4, 84, 
    7, 33, 1, 28, 0, 28, 5, 13, 3, 53, 6, 41, 2, 59, 4, 14, 8, 35, 
    5, 67, 1,  9, 4, 69, 6, 79, 3, 94, 2, 81, 0, 17, 7, 23, 8, 32, 
    0, 94, 4, 94, 3, 52, 8, 66, 5,  9, 1,  5, 6, 91, 7, 84, 2, 45, 
    6, 29, 8, 86, 5,  6, 2, 55, 1, 14, 7, 99, 0, 33, 3, 26, 4, 16, 
    4, 45, 0, 28, 8, 65, 1, 14, 7, 94, 2, 51, 5, 92, 3, 24, 6, 13
  };
  const int q1710[] = {
    9, 9, // Number of jobs and machines
    7, 64, 0, 60, 8, 48, 3, 73, 5, 80, 2, 88, 1, 77, 6, 23, 4, 78, 
    6, 89, 1, 59, 8, 30, 0, 52, 4, 97, 7, 92, 3, 18, 2, 49, 5, 36, 
    6, 80, 5, 11, 0,  4, 3, 34, 2, 27, 4, 37, 1, 35, 8, 96, 7, 59, 
    7, 58, 3, 36, 5,  2, 8, 38, 4, 21, 2, 74, 0, 73, 1,  4, 6, 21, 
    7, 65, 6, 50, 4, 59, 3, 40, 5, 67, 8,  8, 2, 94, 1, 89, 0, 19, 
    5, 74, 3, 48, 0, 12, 4, 78, 1, 62, 7, 98, 6, 92, 2, 59, 8,  5, 
    1, 79, 6, 41, 0, 99, 3, 89, 5, 57, 7,  4, 4, 35, 8, 20, 2, 83, 
    2, 19, 3, 37, 6, 84, 4, 68, 8, 13, 7, 80, 1, 28, 5, 27, 0, 12, 
    0, 20, 8, 22, 6, 68, 7, 88, 3, 63, 2, 13, 4, 89, 1, 31, 5, 94
  };
  const int q1711[] = {
    9, 9, // Number of jobs and machines
    8, 96, 4, 49, 2, 52, 5, 91, 7, 63, 1, 49, 6,  2, 0, 90, 3, 73, 
    0, 75, 1, 56, 4, 23, 2, 70, 6, 43, 8, 13, 3, 84, 7,  2, 5, 58, 
    0, 74, 1, 44, 8, 64, 3, 13, 2, 91, 7, 64, 5, 75, 6, 38, 4, 24, 
    4, 36, 7, 64, 1, 97, 3, 25, 2,  1, 6, 49, 5, 14, 0, 37, 8, 26, 
    4, 37, 6, 22, 8, 85, 1, 67, 2, 11, 3, 62, 0, 71, 7, 61, 5, 95, 
    6, 32, 7, 78, 3, 42, 8, 33, 0, 52, 1, 76, 4, 61, 5, 81, 2, 65, 
    5, 24, 4, 82, 1, 48, 7, 48, 2, 14, 0, 90, 3, 66, 6, 31, 8, 34, 
    7, 53, 6, 33, 2, 11, 5, 88, 0, 65, 3, 45, 8, 96, 4,  5, 1, 25, 
    8, 16, 7, 92, 3, 76, 0, 85, 2, 65, 1, 78, 5, 51, 6, 40, 4, 16
  };
  const int q1712[] = {
    9, 9, // Number of jobs and machines
    6, 42, 8, 40, 7, 70, 5, 85, 4, 26, 1, 65, 2, 63, 3, 67, 0, 58, 
    7, 69, 0, 61, 3, 79, 4, 98, 2, 12, 6, 30, 8, 19, 1, 69, 5, 55, 
    2, 25, 7, 14, 4, 23, 5, 84, 6, 15, 3, 73, 8, 93, 0, 83, 1, 21, 
    4, 78, 2, 65, 8, 33, 1, 20, 0, 77, 5, 84, 6, 24, 7, 62, 3, 38, 
    8, 21, 6, 53, 1, 38, 2, 97, 7, 59, 3, 90, 0, 78, 5, 13, 4, 18, 
    3, 64, 2, 31, 6, 90, 5, 57, 1, 31, 4,  2, 0, 19, 8, 46, 7, 42, 
    8, 49, 1,  3, 0,  3, 5, 73, 2, 53, 3,  3, 7, 67, 4, 21, 6, 79, 
    3, 16, 0,  6, 2, 44, 6, 12, 4, 29, 1, 77, 5, 57, 7,  2, 8, 88, 
    2,  9, 5, 53, 4,  9, 1, 62, 7, 46, 0, 94, 3, 13, 8, 46, 6, 65
  };
  const int q1713[] = {
    9, 9, // Number of jobs and machines
    5,  4, 0, 48, 6, 78, 3, 31, 8, 65, 4, 25, 2, 17, 7, 12, 1, 85, 
    6, 38, 1, 80, 5, 83, 3, 96, 4, 48, 2, 56, 0, 33, 8, 14, 7, 11, 
    7,  1, 4,  7, 1, 64, 3, 91, 8, 78, 0, 43, 5,  6, 6, 29, 2,  9, 
    3, 30, 4, 14, 8, 94, 1, 96, 0, 25, 6, 18, 2, 97, 5, 88, 7, 77, 
    7, 27, 0, 34, 2, 34, 3, 35, 4, 93, 5,  1, 6, 89, 1, 55, 8, 67, 
    1, 47, 0, 32, 7, 53, 5,  5, 4, 90, 6,  8, 8,  5, 3, 32, 2, 16, 
    7,  2, 3, 24, 6, 53, 1, 70, 4, 74, 5, 87, 2, 74, 0, 11, 8, 72, 
    7, 92, 2, 79, 4, 39, 1, 27, 0, 49, 6, 75, 3, 39, 8,  8, 5, 48, 
    6, 44, 1, 23, 7, 86, 8, 41, 0, 12, 2, 18, 4, 67, 3, 73, 5, 25
  };
  const int q1714[] = {
    9, 9, // Number of jobs and machines
    8, 50, 2,  3, 7,  9, 1, 88, 4, 27, 3, 64, 0, 50, 5, 39, 6,  2, 
    3, 74, 2, 48, 0, 64, 5, 11, 4, 54, 8, 66, 1, 35, 7, 53, 6, 14, 
    4, 36, 3, 20, 6, 58, 2, 37, 8, 47, 1,  6, 5, 65, 0, 45, 7, 55, 
    6, 61, 3, 40, 1, 26, 0, 82, 7, 29, 8, 63, 4, 61, 2, 65, 5, 12, 
    1, 52, 5,  6, 7, 14, 3, 64, 0, 44, 6, 16, 2,  5, 4, 42, 8, 18, 
    8, 94, 6, 63, 4, 15, 5, 37, 7,  4, 2, 66, 3, 51, 0, 35, 1,  1, 
    0, 61, 1, 77, 2, 80, 5, 43, 8, 42, 6, 23, 4, 69, 7, 65, 3, 45, 
    0, 45, 7,  8, 4, 53, 6, 83, 3, 95, 1, 58, 2, 16, 5, 28, 8, 26, 
    4, 40, 2, 48, 0, 80, 6,  6, 7, 18, 5, 62, 8, 38, 3, 32, 1, 93
  };
  const int q1715[] = {
    9, 9, // Number of jobs and machines
    2, 67, 6, 14, 8, 37, 7, 41, 4, 22, 0, 14, 5, 80, 3, 44, 1, 21, 
    5, 50, 0, 65, 3, 12, 8, 65, 7, 14, 6, 45, 4, 66, 1, 21, 2, 40, 
    8, 86, 6, 21, 7, 71, 1, 94, 3, 16, 5, 95, 2, 37, 0, 99, 4, 42, 
    7, 15, 1, 17, 0, 58, 6, 32, 3, 51, 5,  1, 8, 66, 4, 45, 2, 68, 
    0, 64, 6, 45, 7, 20, 1, 88, 2, 45, 4, 80, 8, 98, 5, 97, 3, 17, 
    4, 87, 8, 20, 7,  3, 6, 83, 0, 87, 2, 61, 5, 77, 3, 22, 1, 57, 
    2, 87, 5, 68, 6, 12, 4, 32, 1, 15, 8, 44, 7, 68, 3, 15, 0, 76, 
    0, 45, 2, 76, 1, 94, 3, 15, 4, 12, 5,  6, 8, 85, 6, 69, 7, 12, 
    0, 78, 2, 34, 6, 62, 4, 21, 7, 44, 5,  6, 1,  4, 3,  7, 8, 84
  };
  const int q1716[] = {
    9, 9, // Number of jobs and machines
    7, 17, 3, 11, 8, 32, 1, 57, 4,  8, 6, 91, 0, 62, 5, 68, 2,  5, 
    5, 75, 7, 45, 0, 84, 4, 60, 2, 45, 6, 76, 8, 27, 3, 15, 1, 23, 
    5, 22, 4, 13, 0, 85, 3,  5, 7, 73, 1, 51, 6, 20, 8,  6, 2, 84, 
    1, 17, 5,  3, 4, 99, 2, 65, 8, 55, 3, 55, 6, 39, 0,  9, 7, 29, 
    1, 90, 3, 27, 6,  5, 0, 11, 2,  1, 7, 86, 4, 73, 8,  7, 5, 53, 
    0, 17, 4, 51, 8, 45, 7, 82, 1, 17, 2, 68, 5, 33, 6, 67, 3, 26, 
    4, 82, 5, 57, 7, 20, 2, 41, 0, 63, 8,  3, 1, 71, 6, 59, 3, 69, 
    0, 70, 3, 71, 5, 75, 1, 74, 7, 46, 8,  7, 6, 83, 2, 63, 4, 83, 
    6,  1, 8, 65, 0, 28, 3, 74, 4, 77, 2, 48, 5, 19, 1, 95, 7,  6
  };
  const int q1717[] = {
    9, 9, // Number of jobs and machines
    7,  8, 4,  2, 0, 96, 6, 42, 2, 24, 1, 56, 8, 64, 5, 35, 3, 91, 
    6, 34, 0, 52, 3, 36, 2, 44, 1, 11, 5, 60, 7, 99, 8, 51, 4, 71, 
    0, 49, 1, 73, 7, 14, 2, 89, 3,  8, 6, 52, 5, 24, 8,  6, 4, 62, 
    8, 31, 5, 50, 2, 88, 4, 97, 6, 22, 7, 73, 0, 83, 3, 19, 1, 82, 
    6, 42, 8, 98, 4, 46, 3,  1, 7, 51, 5, 93, 1, 52, 2, 86, 0, 77, 
    1,  1, 6, 56, 0, 10, 8, 53, 5,  5, 3, 98, 2, 77, 4, 64, 7, 21, 
    0, 21, 1, 65, 5, 46, 3, 80, 6, 50, 2, 10, 8, 36, 7, 30, 4, 64, 
    0, 59, 7, 73, 3, 80, 1, 62, 5, 62, 8, 56, 4, 83, 6,  1, 2, 31, 
    4, 22, 5, 40, 3, 26, 2, 39, 7, 68, 8, 37, 0,  9, 6, 20, 1, 41
  };
  const int q1718[] = {
    9, 9, // Number of jobs and machines
    1, 65, 5, 14, 6, 93, 0,  3, 8, 51, 3, 39, 2,  9, 4, 78, 7, 95, 
    1,  4, 5, 17, 2, 11, 8, 58, 3, 92, 6, 10, 4, 33, 7, 50, 0, 25, 
    1, 62, 4, 78, 3, 69, 6, 61, 2, 31, 0, 63, 5, 57, 7, 53, 8, 34, 
    1, 77, 2, 30, 3, 25, 7, 84, 6, 58, 0, 96, 5, 37, 8, 38, 4, 65, 
    8, 82, 5,  9, 2, 61, 1, 87, 7, 63, 3, 62, 6, 69, 4, 28, 0, 48, 
    6, 26, 1, 65, 7, 80, 0, 31, 2, 65, 8, 74, 5,  5, 4, 59, 3, 81, 
    2, 22, 7, 23, 0, 59, 4, 75, 8, 61, 5, 99, 3, 50, 1, 13, 6, 19, 
    8, 58, 7, 76, 6, 37, 1, 37, 5, 67, 3, 76, 0, 63, 2, 66, 4, 95, 
    4, 75, 7, 12, 2, 69, 5, 56, 3, 87, 1, 12, 6, 85, 8, 30, 0, 84
  };
  const int q1719[] = {
    9, 9, // Number of jobs and machines
    1, 21, 0, 94, 8, 93, 2, 98, 7, 72, 4, 27, 5, 52, 6, 83, 3, 96, 
    5, 95, 3, 17, 4, 88, 6, 24, 8, 85, 1, 37, 7, 75, 0, 65, 2, 89, 
    0, 34, 5, 23, 1, 42, 7, 95, 8, 29, 3, 15, 6, 60, 4, 61, 2, 51, 
    5, 96, 3, 43, 4, 82, 1, 41, 7, 86, 0, 66, 8, 59, 6, 54, 2, 88, 
    0,  7, 2, 89, 8, 80, 4, 70, 7, 75, 5, 79, 6, 19, 1, 45, 3, 78, 
    1, 63, 8, 26, 6, 30, 4, 69, 0, 18, 7,  6, 5, 16, 3, 81, 2, 58, 
    3, 38, 6, 27, 7, 29, 4, 10, 8, 39, 5, 22, 1, 23, 0, 22, 2, 33, 
    5, 50, 2, 43, 3, 14, 8, 14, 4, 26, 7, 44, 1, 17, 6, 16, 0, 72, 
    4, 23, 2, 18, 3, 61, 7, 69, 5, 54, 0,  1, 8, 58, 6, 66, 1,  6
  };
  const int q1720[] = {
    9, 9, // Number of jobs and machines
    8, 69, 7, 70, 1, 92, 2, 47, 0, 55, 4, 42, 3, 28, 5,  7, 6, 69, 
    1, 88, 3, 18, 0, 13, 2, 70, 6,  7, 8,  6, 4, 78, 5,  9, 7, 52, 
    6, 54, 1, 46, 4, 84, 2, 75, 3, 99, 0, 34, 5,  5, 8,  6, 7, 35, 
    1, 43, 5, 70, 7, 18, 3, 56, 2, 47, 4, 76, 8, 42, 6, 97, 0, 40, 
    7, 47, 4, 88, 3, 69, 6, 87, 2, 32, 1, 52, 8, 72, 5, 51, 0, 23, 
    5, 58, 6, 41, 2,  2, 4, 41, 3, 83, 7, 90, 8, 21, 0, 74, 1, 39, 
    0, 50, 1, 88, 6, 34, 4, 94, 5, 25, 3, 92, 2, 35, 7, 14, 8, 24, 
    4, 51, 1, 66, 2, 38, 0, 84, 6, 88, 3, 24, 8, 24, 5, 94, 7,  6, 
    8, 56, 4, 39, 7, 33, 5, 27, 3, 87, 2, 94, 0, 26, 1, 11, 6, 51
  };
  const int q1721[] = {
    9, 9, // Number of jobs and machines
    0, 45, 2, 37, 4, 58, 3, 97, 5, 95, 1, 60, 7, 25, 8, 22, 6,  9, 
    4, 35, 2, 64, 8, 40, 3, 64, 0,  4, 5, 39, 7, 41, 6, 50, 1, 53, 
    4, 66, 2, 97, 7,  2, 8, 62, 0, 20, 3, 18, 5, 67, 1, 26, 6, 50, 
    6, 82, 2, 30, 5, 24, 4, 97, 7, 11, 3, 74, 0, 37, 8, 57, 1, 31, 
    1, 55, 8, 85, 7, 73, 2,  4, 0,  2, 4, 68, 6, 53, 3, 62, 5, 69, 
    5, 45, 1, 90, 0, 62, 2, 77, 4, 21, 6, 12, 3, 90, 7, 24, 8,  1, 
    2, 89, 6, 51, 3, 20, 1, 66, 5, 58, 4, 96, 0, 63, 8, 85, 7, 41, 
    4, 81, 3, 20, 2, 50, 5, 19, 6, 88, 1, 59, 0, 57, 7, 74, 8, 97, 
    4, 40, 2, 20, 3, 97, 8, 96, 7, 66, 0, 55, 5, 22, 6, 38, 1, 32
  };
  const int q1722[] = {
    9, 9, // Number of jobs and machines
    0, 86, 4, 66, 8, 52, 7, 19, 3, 34, 6,  2, 2, 61, 1, 78, 5, 36, 
    1, 16, 7, 10, 6, 26, 2,  8, 8, 80, 4, 10, 0, 86, 3, 36, 5,  4, 
    4, 42, 2, 70, 7, 90, 5, 43, 6, 74, 1, 48, 0,  3, 3, 34, 8, 46, 
    0, 23, 7, 20, 8, 63, 2, 20, 6, 54, 5, 43, 3, 82, 4, 98, 1, 70, 
    8, 88, 1, 62, 5, 45, 6, 20, 4,  6, 7, 85, 2, 19, 3, 35, 0, 64, 
    7, 32, 2, 85, 5, 87, 4, 29, 8, 69, 0, 96, 3, 73, 1, 41, 6, 74, 
    5, 53, 8,  6, 7, 68, 3, 10, 0, 63, 2, 31, 4,  6, 1, 25, 6,  8, 
    7, 93, 5, 49, 4, 47, 0, 43, 8, 74, 2, 99, 6, 19, 3, 59, 1, 76, 
    7, 56, 1, 97, 5,  4, 6, 68, 8, 34, 0, 96, 4,  9, 3, 68, 2, 64
  };
  const int q1723[] = {
    9, 9, // Number of jobs and machines
    4, 58, 3, 42, 8, 10, 7, 58, 1, 70, 2,  3, 0, 63, 6, 27, 5, 68, 
    8, 85, 0,  1, 3, 16, 2,  7, 6, 13, 5, 12, 1, 18, 7, 21, 4, 98, 
    3, 74, 5, 10, 4, 32, 6, 48, 0, 25, 1, 81, 2, 92, 8, 51, 7, 61, 
    4, 54, 1,  2, 7, 42, 3, 79, 6, 43, 0, 64, 8, 83, 5, 25, 2, 68, 
    1, 14, 4, 72, 3, 16, 0, 87, 8, 60, 7, 96, 2,  9, 6, 97, 5, 39, 
    1, 21, 7, 54, 5, 70, 4, 48, 2, 80, 0, 83, 3, 68, 8, 74, 6, 40, 
    4, 25, 1, 27, 8, 36, 5, 54, 0, 86, 7, 92, 2, 15, 6, 47, 3, 17, 
    7, 46, 3, 48, 1, 40, 2,  5, 4, 68, 6, 77, 0, 73, 8, 57, 5, 12, 
    3, 22, 5, 28, 6, 52, 4, 90, 1, 44, 0, 89, 7, 84, 2, 55, 8, 10
  };
  const int q1724[] = {
    9, 9, // Number of jobs and machines
    5, 90, 2, 63, 8, 16, 3, 90, 6, 24, 4, 24, 7, 99, 0, 40, 1, 89, 
    6, 36, 2, 67, 7, 21, 5, 31, 3, 94, 1, 88, 8, 48, 4, 56, 0, 54, 
    3, 53, 1, 71, 5, 39, 7, 15, 4, 59, 8, 48, 0, 65, 6, 54, 2, 12, 
    3,  9, 5, 54, 6, 26, 7, 95, 1, 29, 8, 66, 2, 54, 0,  9, 4, 76, 
    0,  4, 5, 94, 6, 81, 3, 98, 2, 32, 4, 33, 7, 98, 8, 65, 1, 26, 
    4, 18, 6, 54, 7, 95, 1,  6, 2, 84, 8, 35, 0, 99, 5, 37, 3, 75, 
    7, 63, 0, 63, 1,  5, 4, 31, 3, 52, 5,  5, 8, 47, 6,  3, 2, 34, 
    3, 91, 0, 78, 4, 86, 6, 24, 5, 83, 1, 59, 8, 18, 2, 81, 7, 79, 
    3, 67, 4, 96, 0, 77, 5, 63, 2, 16, 8, 24, 7, 74, 1, 11, 6, 17
  };
  const int q1725[] = {
    9, 9, // Number of jobs and machines
    5, 41, 0, 30, 3, 23, 1, 78, 6,  1, 2, 23, 7, 53, 8, 74, 4,  5, 
    5, 47, 3,  7, 1, 27, 0, 96, 2, 18, 4, 55, 8, 57, 7, 54, 6,  8, 
    4, 63, 7, 63, 6, 39, 0, 57, 3,  2, 5, 56, 1, 53, 2, 72, 8, 97, 
    5, 87, 2, 77, 8, 59, 0, 73, 1, 95, 3, 64, 7, 39, 4, 54, 6, 54, 
    8, 98, 0, 34, 3, 35, 7, 50, 6, 35, 2, 93, 4, 96, 5, 77, 1, 42, 
    7, 12, 2,  3, 5, 91, 8, 94, 4, 12, 0, 78, 1, 37, 6, 16, 3, 86, 
    4, 60, 1, 90, 3, 75, 6, 52, 7, 10, 2, 74, 8, 38, 5, 91, 0, 54, 
    8, 91, 7, 90, 5, 96, 2, 93, 1, 26, 0, 99, 4, 91, 6, 79, 3, 49, 
    2, 33, 6, 57, 7, 37, 3, 87, 8, 45, 0, 91, 1,  2, 5, 34, 4,  4
  };
  const int q1726[] = {
    9, 9, // Number of jobs and machines
    6, 78, 4,  6, 2, 60, 3, 10, 1, 98, 8, 62, 5, 16, 7,  3, 0, 72, 
    8, 81, 3, 19, 7, 50, 5, 96, 4, 71, 0, 58, 2, 53, 1, 21, 6, 91, 
    8, 97, 0,  6, 7, 10, 3, 61, 2,  6, 4, 51, 1, 58, 6, 76, 5,  5, 
    5, 69, 2, 97, 8, 60, 1, 49, 3, 27, 0, 61, 4, 31, 6, 11, 7, 33, 
    3, 77, 6, 34, 1, 56, 8, 90, 2, 87, 5, 95, 7, 80, 4, 16, 0, 41, 
    4,  6, 2, 79, 3, 15, 5, 90, 7, 55, 0, 74, 1, 87, 6, 21, 8, 89, 
    7, 57, 5, 61, 1,  6, 4, 14, 0, 71, 8, 54, 6, 86, 2, 59, 3, 86, 
    2, 16, 7, 36, 3, 31, 5,  4, 0, 40, 1, 95, 4, 19, 8, 70, 6, 31, 
    0, 38, 6,  1, 7, 74, 1, 47, 8, 66, 3, 94, 2, 93, 5, 34, 4, 18
  };
  const int q1727[] = {
    9, 9, // Number of jobs and machines
    7, 14, 1, 76, 5, 91, 0, 49, 2, 93, 6, 74, 8, 14, 4, 43, 3, 74, 
    4,  5, 8, 46, 3, 32, 6, 19, 2, 32, 1, 51, 0, 22, 7, 52, 5, 25, 
    1,  3, 7, 91, 8, 65, 5, 84, 3, 85, 6, 60, 4, 92, 0, 32, 2, 74, 
    5, 54, 1, 73, 7, 60, 2, 49, 8, 66, 4, 17, 0, 93, 3, 75, 6, 51, 
    6, 46, 2, 42, 8, 52, 3, 82, 5,  9, 1, 90, 4, 96, 0, 47, 7, 94, 
    7, 81, 5, 79, 8, 54, 2, 85, 0, 64, 4, 73, 6, 11, 1, 31, 3, 43, 
    7, 46, 8,  4, 5, 90, 0, 74, 2, 56, 4, 47, 6, 99, 3, 28, 1, 56, 
    1, 77, 0, 77, 8, 64, 3, 13, 2, 78, 5, 46, 6, 39, 7, 51, 4, 80, 
    6, 61, 4,  5, 8, 16, 0, 84, 3, 84, 5, 57, 1, 89, 2, 40, 7,  3
  };
  const int q1728[] = {
    9, 9, // Number of jobs and machines
    7, 93, 8, 16, 1, 23, 4, 39, 3, 59, 5, 71, 6, 97, 2, 36, 0, 73, 
    2, 35, 6, 79, 3, 74, 7, 49, 5, 30, 4, 48, 1, 44, 8, 61, 0,  1, 
    6, 17, 4, 34, 7, 30, 5, 50, 0, 34, 2, 58, 3, 15, 1, 55, 8, 12, 
    4, 57, 8, 89, 6, 20, 0, 93, 7, 46, 1, 93, 3, 67, 5, 85, 2, 38, 
    4, 41, 5, 94, 3, 85, 2,  7, 6, 19, 1, 97, 7, 69, 8, 66, 0, 33, 
    5, 49, 1, 31, 6, 90, 4, 34, 2, 60, 8, 14, 0, 54, 3, 41, 7, 42, 
    8, 74, 7, 41, 2, 74, 5, 45, 1, 16, 3,  7, 4, 36, 6, 66, 0, 50, 
    7, 47, 2, 14, 4, 29, 5,  6, 0, 93, 3, 69, 6, 49, 1, 35, 8, 65, 
    8, 72, 5, 33, 4, 96, 2, 24, 3, 68, 0, 39, 7, 75, 1, 32, 6, 77
  };
  const int q1729[] = {
    9, 9, // Number of jobs and machines
    1, 35, 0, 69, 8, 94, 5, 23, 6, 40, 3, 41, 7, 24, 4, 68, 2, 62, 
    6, 61, 4, 15, 7, 63, 3, 17, 1, 14, 0, 74, 2, 85, 8, 74, 5, 28, 
    7, 91, 1,  8, 3, 93, 5, 23, 4, 81, 2, 31, 0, 37, 6, 68, 8, 38, 
    6, 79, 4, 17, 1, 92, 8, 36, 2,  5, 7, 23, 0, 88, 3, 77, 5, 80, 
    4, 81, 7, 89, 6, 14, 1, 19, 5, 60, 0, 93, 8, 33, 2,  8, 3, 97, 
    2, 62, 1, 10, 4, 41, 5, 19, 3, 99, 8, 98, 0, 51, 7, 77, 6, 58, 
    8, 93, 0, 70, 6, 91, 3, 23, 5, 28, 2, 65, 1,  6, 7, 40, 4, 56, 
    7,  8, 8, 37, 1, 82, 2, 78, 5, 46, 3, 35, 0, 32, 4, 82, 6, 80, 
    3, 72, 0,  3, 4, 49, 8, 54, 7, 78, 6, 86, 2,  7, 1, 70, 5, 13
  };
  const int q1730[] = {
    9, 9, // Number of jobs and machines
    8, 98, 3, 85, 2, 51, 5, 99, 7,  8, 6, 83, 4, 61, 1, 19, 0, 74, 
    6, 33, 2, 42, 0, 96, 4, 24, 5, 23, 8, 99, 7, 33, 3, 28, 1, 59, 
    5, 68, 0, 54, 2, 98, 4, 35, 8, 74, 6, 84, 3, 71, 1, 24, 7, 31, 
    7, 94, 1, 62, 3, 84, 8,  7, 6, 12, 2, 78, 5, 22, 4, 52, 0, 67, 
    0, 83, 1, 95, 3, 42, 5, 95, 8, 53, 7, 34, 6, 40, 2, 84, 4, 72, 
    0, 24, 6, 68, 3, 96, 7, 81, 8, 16, 1, 86, 4, 74, 5, 60, 2, 87, 
    4, 55, 3,  1, 7, 37, 8, 78, 1, 71, 0, 96, 6, 25, 2, 75, 5, 54, 
    6, 75, 0, 66, 4, 26, 3, 76, 5, 72, 8, 22, 7, 15, 2, 28, 1, 19, 
    6, 48, 2, 55, 3, 44, 8, 18, 4, 42, 7, 21, 0, 14, 5, 52, 1, 25
  };
  const int q1731[] = {
    9, 9, // Number of jobs and machines
    4, 82, 6, 77, 7, 51, 1, 60, 3, 45, 0, 74, 2, 14, 5, 23, 8,  3, 
    3, 23, 4, 24, 7, 44, 1,  3, 8, 82, 6, 85, 5, 79, 2, 95, 0, 36, 
    6, 83, 8,  7, 5, 75, 4, 50, 1, 42, 7, 72, 3, 61, 2, 39, 0, 81, 
    6, 65, 5, 93, 2, 17, 0, 94, 4, 87, 7, 57, 1,  5, 8, 73, 3, 34, 
    7, 25, 6, 74, 4, 38, 8, 67, 5, 36, 3, 45, 2, 38, 0, 84, 1, 39, 
    8, 84, 3, 48, 2, 18, 7, 63, 5, 12, 4, 55, 1,  5, 0, 90, 6, 10, 
    4, 61, 3, 50, 7, 55, 8, 55, 0, 46, 1, 83, 5, 81, 2, 21, 6, 52, 
    1, 38, 8,  2, 4, 35, 6, 36, 3,  5, 0, 81, 5,  1, 2, 71, 7, 39, 
    7, 33, 8,  7, 4, 13, 0, 82, 1, 22, 2, 97, 5, 24, 3,  1, 6, 26
  };
  const int q1732[] = {
    9, 9, // Number of jobs and machines
    6, 13, 5, 23, 8, 34, 0, 67, 2, 68, 4, 40, 1, 87, 3, 47, 7, 47, 
    3, 47, 5, 35, 7, 95, 2,  8, 0, 91, 4, 91, 8, 93, 6, 51, 1, 87, 
    4, 14, 8, 34, 1, 58, 5, 81, 7, 88, 2, 18, 6, 95, 3, 81, 0, 47, 
    4, 79, 2, 76, 7, 66, 8, 65, 5, 76, 0, 68, 3, 57, 1, 50, 6, 63, 
    5, 63, 0, 80, 8, 51, 6, 50, 3, 85, 7, 95, 2, 66, 1, 11, 4, 61, 
    3, 41, 7, 32, 0, 85, 2, 95, 5, 74, 8, 17, 6, 84, 4, 70, 1, 15, 
    5, 68, 0, 61, 2, 74, 4, 53, 8, 53, 7, 89, 6, 86, 1, 33, 3, 75, 
    5, 52, 2, 66, 1, 97, 0, 95, 6, 49, 7, 94, 3, 89, 4, 74, 8, 13, 
    5, 29, 1, 21, 0, 12, 3, 65, 6, 96, 8, 65, 2,  2, 4, 56, 7, 26
  };
  const int q1733[] = {
    9, 9, // Number of jobs and machines
    1, 59, 2, 84, 0, 17, 6, 60, 8, 64, 5, 74, 7, 29, 4, 91, 3,  4, 
    8, 98, 6, 52, 2, 46, 1, 61, 3, 14, 0, 77, 7,  3, 5, 14, 4, 79, 
    6,  6, 7, 89, 1, 98, 3, 20, 2, 78, 5, 69, 8, 73, 0, 94, 4, 97, 
    0, 26, 8,  6, 3, 36, 4, 17, 5, 97, 6, 56, 1, 64, 2, 18, 7, 14, 
    6, 23, 4, 49, 1, 94, 5, 81, 0, 96, 7, 29, 2, 34, 3, 48, 8,  1, 
    1, 17, 3, 42, 6, 71, 8, 57, 4, 31, 2, 33, 7, 40, 0, 30, 5, 86, 
    3, 25, 4, 13, 8, 31, 0, 49, 1, 30, 6, 90, 2, 81, 7, 25, 5, 31, 
    3,  6, 8, 96, 6, 34, 5, 24, 1, 65, 2,  7, 4, 63, 0, 61, 7, 46, 
    0,  9, 6, 33, 4,  8, 7, 17, 5, 75, 2, 82, 8, 65, 3, 14, 1, 24
  };
  const int q1734[] = {
    9, 9, // Number of jobs and machines
    4,  3, 5, 28, 0, 18, 2, 36, 7, 44, 3, 41, 8, 36, 1, 43, 6, 50, 
    2, 57, 7,  8, 5, 29, 6, 96, 3, 29, 8, 81, 4, 73, 0, 23, 1, 99, 
    6, 57, 5, 11, 8, 17, 7, 71, 0, 43, 4, 54, 2,  5, 3, 26, 1, 32, 
    1, 87, 0, 87, 7, 84, 3, 41, 4, 85, 2, 20, 8, 89, 6, 26, 5, 81, 
    1, 49, 5,  8, 6, 72, 3, 93, 8, 23, 7, 89, 0, 66, 4, 15, 2, 15, 
    0, 54, 5, 45, 3, 52, 1, 79, 6, 18, 2, 46, 4, 44, 8,  2, 7, 71, 
    0, 80, 1, 62, 4, 80, 7, 94, 2, 31, 3, 70, 5, 42, 8, 87, 6, 28, 
    1, 48, 5, 67, 2, 84, 3, 53, 8, 94, 7, 99, 4, 18, 6, 32, 0, 99, 
    5, 57, 3, 40, 4, 38, 8, 99, 6, 12, 7, 62, 0, 78, 2, 13, 1, 10
  };
  const int q1735[] = {
    9, 9, // Number of jobs and machines
    5, 47, 6, 71, 0, 80, 4, 17, 3, 13, 1, 69, 7, 28, 2, 60, 8, 93, 
    2, 60, 4, 46, 7, 96, 0, 87, 5, 59, 6, 79, 3, 35, 8,  2, 1, 91, 
    5, 39, 4,  5, 7, 29, 1, 94, 6, 38, 2, 48, 8, 72, 0,  1, 3, 87, 
    1, 39, 2, 37, 0, 65, 8, 15, 3,  1, 7, 37, 6, 21, 4, 33, 5, 19, 
    8,  1, 3, 93, 4, 82, 5, 52, 0, 93, 7, 89, 2, 68, 6, 99, 1, 12, 
    4, 94, 2, 74, 0, 57, 7, 58, 8, 14, 6, 44, 1, 19, 5, 16, 3, 26, 
    8, 57, 1, 91, 0, 91, 5, 36, 4, 59, 7,  3, 6, 95, 2, 85, 3, 51, 
    4, 22, 2, 86, 3, 98, 0, 36, 5, 26, 6, 26, 8, 13, 7, 63, 1, 56, 
    6, 14, 3, 39, 0, 82, 2, 75, 5, 52, 7, 94, 4, 17, 1,  8, 8, 42
  };
  const int q1736[] = {
    9, 9, // Number of jobs and machines
    3, 38, 1, 98, 5, 44, 8, 95, 4, 19, 0, 91, 6, 81, 7, 68, 2, 90, 
    2, 99, 8, 61, 6, 15, 7, 26, 0, 64, 4, 47, 5, 13, 1, 68, 3, 34, 
    0, 85, 1, 46, 8, 23, 2, 91, 6, 86, 5,  4, 4, 36, 7, 94, 3, 23, 
    0, 82, 3, 17, 5, 16, 4, 62, 2, 27, 6, 34, 7, 58, 1, 51, 8, 63, 
    0, 95, 2, 17, 7, 88, 4, 94, 3, 74, 8, 41, 6, 82, 5, 41, 1, 20, 
    2, 73, 7, 13, 6, 94, 5, 76, 0, 35, 4, 97, 1, 16, 3, 48, 8, 95, 
    5, 36, 7, 17, 1,  9, 8, 21, 3, 22, 6, 89, 0, 93, 2,  8, 4,  9, 
    8, 73, 7, 47, 1, 14, 4, 73, 5, 25, 6, 62, 2, 39, 0,  5, 3, 12, 
    0, 29, 6, 28, 1, 19, 7, 37, 4, 70, 5, 41, 3, 92, 2, 34, 8, 76
  };
  const int q1737[] = {
    9, 9, // Number of jobs and machines
    4, 47, 7, 41, 6, 47, 3,  7, 8, 97, 5, 37, 1, 23, 0, 54, 2, 18, 
    7, 78, 0, 69, 8,  8, 2, 11, 6, 43, 1, 43, 5, 51, 3, 60, 4, 63, 
    6, 15, 1, 18, 2, 54, 0, 27, 5, 44, 3, 32, 8, 50, 4, 27, 7, 82, 
    6, 58, 3, 91, 8,  8, 4, 65, 5,  2, 2, 51, 1, 17, 0, 33, 7, 55, 
    2, 79, 0, 50, 6,  2, 5, 84, 7, 57, 1, 31, 4, 56, 3, 79, 8, 39, 
    5, 71, 6,  6, 1, 38, 4, 40, 2, 29, 7, 25, 3, 33, 0, 95, 8, 82, 
    3, 26, 6, 71, 7, 72, 8,  3, 5,  2, 0, 58, 4, 33, 2, 70, 1,  6, 
    0, 59, 6, 62, 2, 40, 7, 12, 4, 21, 8, 98, 5, 37, 3, 89, 1, 25, 
    3, 35, 4, 88, 1, 69, 5, 99, 8, 51, 6, 27, 2, 26, 0, 15, 7, 57
  };
  const int q1738[] = {
    9, 9, // Number of jobs and machines
    1, 90, 4, 46, 3, 20, 7, 36, 5, 44, 0, 11, 8, 91, 2, 37, 6,  4, 
    7, 84, 5, 60, 0,  4, 2, 32, 6,  3, 3, 13, 8, 63, 1, 51, 4, 84, 
    4, 95, 1, 23, 5, 87, 3,  1, 8, 20, 0,  7, 2, 71, 7, 95, 6, 69, 
    1, 93, 6, 80, 0, 73, 2, 96, 8, 90, 3, 46, 7, 31, 5, 87, 4, 42, 
    7, 43, 6, 33, 0, 97, 8, 59, 1, 83, 3, 27, 2, 38, 5, 99, 4, 17, 
    2,  3, 3, 19, 1, 56, 0, 34, 5, 64, 6, 97, 4, 37, 7, 45, 8, 50, 
    6, 19, 7, 36, 3, 61, 5,  8, 4,  2, 8, 37, 0, 62, 1, 74, 2, 58, 
    1, 32, 0, 39, 7, 45, 2, 96, 4, 41, 3, 98, 8, 15, 6, 13, 5, 72, 
    1, 65, 6, 84, 5, 35, 0, 61, 8, 20, 3, 33, 2, 49, 4, 82, 7, 82
  };
  const int q1739[] = {
    9, 9, // Number of jobs and machines
    1, 38, 4, 19, 7, 86, 0, 10, 3, 93, 5, 67, 8, 55, 6, 62, 2, 22, 
    1, 29, 3,  3, 2, 17, 0, 59, 7, 30, 5, 25, 4, 95, 6, 37, 8, 12, 
    5, 52, 7, 44, 2, 76, 4, 19, 6, 21, 0, 85, 3, 17, 1, 88, 8, 11, 
    3, 73, 1, 86, 0, 79, 6, 88, 4,  9, 8, 34, 2, 50, 5, 32, 7,  7, 
    2, 94, 0, 11, 1, 65, 4, 78, 5, 92, 8, 24, 3, 89, 6,  5, 7, 52, 
    8,  7, 2, 22, 7, 13, 6, 76, 4, 17, 1, 66, 5, 74, 0, 67, 3, 22, 
    6,  3, 3, 72, 4, 82, 5, 90, 2, 35, 1, 28, 0, 52, 8, 48, 7, 90, 
    1, 48, 4, 80, 5, 75, 3, 38, 2,  5, 8, 36, 0, 48, 6, 86, 7, 81, 
    8, 37, 6, 37, 3,  2, 2, 76, 1, 75, 0, 59, 7, 41, 4, 15, 5, 67
  };
  const int q1740[] = {
    9, 9, // Number of jobs and machines
    1, 31, 0, 98, 2, 94, 7, 53, 3, 26, 5, 43, 6, 60, 4,  6, 8, 42, 
    0,  4, 6,  7, 3, 74, 7, 18, 8, 16, 5, 57, 4, 84, 2, 10, 1, 74, 
    8, 28, 5, 50, 7, 18, 2, 90, 3, 49, 6, 36, 4, 81, 0, 57, 1, 57, 
    0, 13, 1, 71, 2, 68, 3, 40, 6, 99, 4, 34, 5, 61, 8, 66, 7,  6, 
    8, 97, 7, 87, 1, 96, 4, 33, 2, 50, 0, 90, 5, 19, 6, 84, 3, 63, 
    2, 14, 5, 70, 7, 52, 3, 51, 8, 61, 6, 32, 0, 19, 1, 77, 4, 44, 
    8, 21, 7, 78, 2, 56, 6, 62, 3, 59, 5, 17, 0, 97, 1, 82, 4, 31, 
    3, 51, 0, 50, 8, 18, 2, 60, 7, 21, 6, 23, 1, 34, 4,  8, 5, 43, 
    0, 78, 1, 21, 2, 12, 5, 33, 3, 95, 4, 72, 6, 44, 8, 54, 7, 53
  };
  const int q1741[] = {
    9, 9, // Number of jobs and machines
    3, 47, 4, 44, 8, 14, 1, 26, 6, 25, 7, 87, 5, 86, 2, 17, 0, 38, 
    1, 98, 5, 36, 2, 83, 6, 96, 4, 45, 7, 67, 0, 66, 8, 93, 3, 12, 
    3, 75, 4, 96, 8, 13, 6, 75, 5, 53, 0, 77, 7, 31, 1, 72, 2, 99, 
    2, 44, 4,  9, 8, 45, 6, 76, 1, 75, 0, 53, 7, 13, 5, 90, 3, 76, 
    7,  2, 4, 57, 1, 12, 0, 65, 5, 54, 6, 36, 2, 99, 3, 73, 8, 42, 
    7, 35, 0, 14, 6, 22, 4, 87, 8, 68, 2, 89, 1, 62, 5,  5, 3, 23, 
    5, 41, 0, 41, 8, 50, 1, 18, 6, 66, 3, 80, 2, 39, 4, 83, 7,  9, 
    7, 16, 5, 61, 1, 12, 2, 78, 6, 71, 4, 30, 8, 27, 3, 33, 0, 22, 
    3, 74, 7,  3, 5, 47, 0,  9, 4, 69, 2, 85, 6, 15, 8, 47, 1, 24
  };
  const int q1742[] = {
    9, 9, // Number of jobs and machines
    7, 86, 0, 30, 4, 77, 5, 50, 6, 50, 2, 82, 1, 63, 8, 92, 3, 11, 
    2, 10, 4, 38, 3, 18, 5, 87, 1, 84, 8, 45, 0, 29, 7, 38, 6, 60, 
    4, 80, 6, 54, 0, 48, 7, 67, 8, 34, 5, 13, 3, 40, 1, 24, 2, 79, 
    3, 42, 0, 29, 7, 52, 2,  9, 4, 44, 8, 26, 6, 57, 1, 50, 5, 81, 
    2, 90, 7, 85, 4, 55, 6, 10, 5, 49, 3, 67, 0, 28, 8, 53, 1, 25, 
    6, 54, 3, 39, 2,  8, 8, 94, 4, 54, 7, 64, 1,  3, 5, 57, 0, 68, 
    6, 12, 7, 82, 4, 90, 5, 79, 3, 30, 8, 26, 2, 91, 0, 34, 1, 75, 
    5, 29, 6, 86, 2, 29, 7, 92, 1, 78, 3, 63, 4, 64, 0, 73, 8, 60, 
    4, 67, 3, 95, 2, 57, 5, 56, 6, 15, 0, 48, 1, 69, 8,  4, 7, 62
  };
  const int q1743[] = {
    9, 9, // Number of jobs and machines
    8, 87, 7, 19, 0, 70, 5, 51, 1,  5, 6,  4, 2, 86, 3, 29, 4, 89, 
    3, 35, 0, 48, 8, 85, 1, 27, 2, 33, 5,  1, 6, 83, 4, 98, 7, 19, 
    7, 41, 4, 29, 5, 87, 3,  9, 0, 67, 2, 73, 6, 60, 1, 46, 8, 67, 
    6,  1, 5, 18, 3,  8, 2,  7, 4, 26, 1, 87, 7, 20, 8, 42, 0, 60, 
    3, 66, 4, 59, 7, 36, 6, 14, 0, 73, 2, 71, 5, 11, 8, 48, 1, 22, 
    6, 89, 3, 40, 0, 12, 4, 88, 1, 43, 8, 13, 5, 28, 2, 31, 7, 30, 
    6, 23, 8, 95, 0, 85, 2, 91, 5, 67, 3, 95, 4,  5, 1, 86, 7,  6, 
    3, 29, 4, 67, 1, 67, 7, 13, 2, 92, 5, 94, 0, 70, 8, 15, 6, 46, 
    4, 84, 0, 14, 2, 20, 5, 92, 3, 71, 7, 85, 6, 43, 1, 88, 8, 27
  };
  const int q1744[] = {
    9, 9, // Number of jobs and machines
    7, 46, 4, 32, 5, 31, 8, 21, 1, 39, 3, 85, 2, 45, 0, 77, 6, 52, 
    1, 74, 8, 53, 0,  2, 2, 79, 7, 54, 6, 15, 5, 83, 3, 15, 4, 25, 
    5, 40, 2, 28, 8, 94, 1, 33, 3, 62, 0, 94, 7, 26, 6, 97, 4, 91, 
    1, 31, 3, 66, 8, 58, 7, 51, 6, 38, 0, 90, 4, 35, 5, 73, 2,  6, 
    3, 77, 6, 76, 1, 49, 4, 89, 2, 52, 7, 17, 8, 57, 5, 12, 0, 70, 
    6, 48, 8, 16, 4, 71, 5, 29, 0, 42, 7, 33, 3, 83, 1, 33, 2, 62, 
    4,  3, 5, 79, 7, 60, 3,  5, 1, 80, 6,  5, 8, 85, 0, 74, 2, 36, 
    8, 97, 4, 56, 5, 80, 1,  7, 7, 41, 6, 24, 2, 35, 3, 31, 0, 61, 
    8, 30, 6,  1, 4, 73, 5, 27, 7, 45, 2, 43, 0, 97, 1, 55, 3, 49
  };
  const int q1745[] = {
    9, 9, // Number of jobs and machines
    6, 32, 3, 54, 2, 59, 8, 63, 1, 41, 5, 67, 0, 40, 4, 86, 7, 36, 
    5, 79, 2, 24, 6, 94, 1, 46, 7, 78, 0, 45, 3, 55, 4, 28, 8, 25, 
    4, 11, 0, 17, 6,  4, 7, 66, 3, 81, 5, 21, 1, 57, 8, 57, 2, 20, 
    1, 99, 4, 88, 0, 69, 2, 90, 8, 47, 5, 80, 6, 97, 3, 52, 7,  2, 
    6, 81, 0, 32, 4, 70, 5, 74, 3, 86, 8,  5, 1,  5, 7, 60, 2, 71, 
    0, 59, 4, 72, 7, 50, 2, 28, 5, 54, 6, 60, 8, 93, 1, 57, 3, 38, 
    7, 67, 4, 44, 1,  9, 2, 72, 5, 43, 8, 66, 0, 58, 6, 43, 3, 22, 
    0, 17, 4, 22, 6, 41, 1, 79, 7, 78, 3, 69, 5, 84, 2, 57, 8, 87, 
    8,  7, 6, 50, 7, 22, 5, 85, 0, 51, 1, 78, 3, 31, 2, 60, 4, 40
  };
  const int q1746[] = {
    9, 9, // Number of jobs and machines
    4, 56, 1, 24, 8, 10, 0, 11, 2, 54, 3,  5, 7, 54, 5, 94, 6, 69, 
    0, 71, 3, 16, 8, 38, 2, 39, 7,  1, 4, 97, 6, 74, 5, 11, 1, 61, 
    2, 25, 7, 57, 6, 82, 5, 96, 0, 51, 1, 99, 4, 29, 8, 10, 3,  8, 
    3, 47, 0,  6, 6,  7, 8, 25, 7, 85, 2, 74, 4, 74, 5, 34, 1, 52, 
    8, 64, 4, 92, 2, 25, 0, 32, 1, 53, 6, 99, 3, 66, 5,  7, 7, 42, 
    4, 42, 7, 78, 1, 67, 5, 66, 3, 78, 0, 16, 2, 57, 8,  7, 6, 40, 
    1, 12, 3, 64, 5, 15, 2, 62, 6, 66, 0, 17, 8, 25, 7, 94, 4, 61, 
    5, 74, 6, 99, 2, 80, 1, 40, 0, 11, 3, 64, 7, 11, 8, 67, 4,  8, 
    7, 49, 0, 10, 8,  5, 5, 30, 6, 39, 2,  2, 4, 75, 3, 98, 1, 92
  };
  const int q1747[] = {
    9, 9, // Number of jobs and machines
    7, 17, 8, 31, 5, 54, 1, 13, 0, 82, 2, 37, 4, 47, 3, 32, 6, 84, 
    7, 26, 3, 50, 1, 75, 4, 34, 0, 73, 8, 49, 2, 11, 5, 80, 6,  2, 
    7, 88, 8, 90, 5, 65, 1, 55, 3, 18, 2, 31, 6, 33, 4, 98, 0, 82, 
    6,  5, 1, 41, 3, 18, 4, 38, 5, 31, 0, 53, 7, 63, 8, 46, 2, 98, 
    8, 55, 2, 51, 4,  3, 7, 84, 0, 54, 6, 60, 3, 86, 5, 32, 1, 50, 
    6, 17, 4, 58, 1, 12, 7, 25, 3, 96, 0, 12, 8, 65, 2, 10, 5, 49, 
    3, 10, 0, 45, 6, 39, 7, 31, 4, 55, 5, 92, 1, 75, 8, 21, 2, 73, 
    4, 18, 7, 19, 6, 66, 1, 54, 5, 50, 3, 68, 0, 77, 2, 99, 8, 85, 
    1, 90, 3,  4, 4, 92, 8, 52, 2, 77, 6, 61, 7, 16, 5, 81, 0, 78
  };
  const int q1748[] = {
    9, 9, // Number of jobs and machines
    1, 62, 0,  1, 5, 29, 4, 75, 3, 59, 8, 18, 6, 81, 7, 59, 2,  2, 
    6, 99, 0, 51, 3, 47, 5, 52, 7, 30, 1, 31, 8, 68, 2,  5, 4, 87, 
    2,  2, 1, 73, 5, 23, 8, 73, 0,  7, 3, 77, 7, 49, 6, 32, 4,  5, 
    5, 84, 6, 43, 7, 21, 0, 77, 2, 82, 4, 12, 8, 17, 1, 31, 3, 96, 
    3,  1, 2, 51, 7, 13, 1, 22, 4, 36, 5, 98, 0, 21, 6, 44, 8, 22, 
    8, 22, 4, 79, 7, 58, 2, 86, 3, 91, 0, 17, 6,  8, 1, 80, 5, 89, 
    5, 42, 3, 66, 2, 15, 8, 53, 6, 50, 4, 41, 0, 35, 7, 90, 1, 61, 
    1, 98, 7, 35, 2, 70, 8, 41, 6, 45, 4, 76, 3,  8, 0, 86, 5, 29, 
    0, 57, 7, 94, 8, 45, 5,  9, 1, 18, 2, 79, 6, 37, 4,  4, 3, 73
  };
  const int q1749[] = {
    9, 9, // Number of jobs and machines
    4, 72, 8, 59, 0, 80, 2, 39, 5, 39, 1, 46, 7, 75, 3, 89, 6, 80, 
    3,  3, 0, 57, 6, 46, 2, 66, 7, 22, 8, 11, 4, 40, 5, 88, 1, 38, 
    6, 49, 3, 14, 1, 17, 2, 33, 5, 29, 7, 72, 4, 75, 0, 42, 8, 42, 
    7, 89, 8, 33, 5, 23, 6, 86, 3, 50, 0, 99, 2, 73, 1, 24, 4, 93, 
    0, 72, 2, 35, 5, 13, 6, 68, 7, 25, 3, 62, 8, 24, 4, 48, 1, 13, 
    3, 56, 6, 24, 5, 30, 0, 68, 1,  7, 2, 92, 7, 93, 4, 90, 8, 45, 
    6, 75, 4, 78, 3, 71, 1, 12, 2, 63, 7, 86, 0, 12, 8, 52, 5,  2, 
    7, 38, 3, 10, 1, 99, 2, 60, 0, 36, 6,  8, 4, 23, 5, 18, 8, 71, 
    5,  3, 3, 50, 4,  4, 7, 60, 8, 59, 6, 39, 0, 97, 2, 80, 1, 17
  };
  const int q1750[] = {
    9, 9, // Number of jobs and machines
    5, 33, 1, 55, 0,  1, 6,  3, 8, 84, 2,  5, 3, 34, 4, 56, 7, 20, 
    0, 60, 6, 47, 5, 75, 1, 63, 3, 75, 8, 48, 7, 55, 2, 36, 4, 96, 
    6, 36, 5, 30, 4, 70, 7,  8, 0,  5, 3, 75, 8, 88, 2, 27, 1, 53, 
    6, 79, 7, 30, 8, 52, 0, 23, 5, 86, 2,  6, 1, 41, 3, 68, 4, 32, 
    4, 72, 2, 82, 0, 70, 7, 20, 5, 65, 1, 56, 6, 25, 8, 80, 3, 91, 
    4, 62, 3, 34, 0, 98, 8,  9, 5, 25, 6, 63, 1, 37, 7, 76, 2, 78, 
    7, 23, 6, 56, 5, 93, 0, 16, 2, 92, 8, 69, 4, 35, 1,  6, 3,  9, 
    5, 53, 3,  2, 4,  3, 2, 76, 0, 85, 1,  3, 7, 64, 8, 89, 6, 53, 
    1, 55, 4,  2, 8, 59, 7, 77, 5, 49, 2, 65, 6, 59, 0, 62, 3, 90
  };
  const int q1751[] = {
    9, 9, // Number of jobs and machines
    2, 83, 1, 33, 4,  3, 0, 50, 8, 49, 3, 35, 6, 12, 7, 51, 5, 47, 
    8, 68, 1, 79, 7,  2, 5, 70, 3, 68, 0, 52, 2, 55, 4, 30, 6, 79, 
    4, 84, 1,  7, 3, 81, 0, 27, 5,  7, 6, 40, 7, 84, 8, 26, 2, 36, 
    8, 10, 5, 24, 2, 93, 7, 93, 4, 13, 0, 72, 6, 85, 3, 63, 1, 68, 
    3, 37, 5,  8, 1, 81, 2, 78, 8, 40, 7, 67, 0, 94, 4, 18, 6, 16, 
    3, 86, 6, 86, 5, 88, 8, 18, 1, 72, 7, 65, 0, 39, 4, 95, 2, 65, 
    2, 48, 5, 35, 1, 26, 3, 97, 0, 78, 8, 12, 7, 94, 4, 44, 6, 31, 
    3, 93, 4, 74, 5, 43, 0, 12, 6,  9, 1, 12, 7, 60, 2,  1, 8,  4, 
    0, 66, 7, 20, 6, 41, 5,  4, 3, 47, 2, 94, 8, 89, 1, 49, 4, 51
  };
  const int q1752[] = {
    9, 9, // Number of jobs and machines
    8, 60, 2, 58, 3, 75, 4, 50, 6, 40, 5, 26, 0, 75, 1,  1, 7, 83, 
    5, 45, 6, 34, 7, 12, 1, 69, 2, 28, 4, 19, 8, 37, 0, 98, 3, 79, 
    0, 64, 4, 42, 8, 40, 1, 96, 3, 76, 5, 85, 2, 40, 7, 68, 6, 34, 
    4, 26, 7, 32, 3, 52, 6, 71, 0,  9, 5, 76, 2, 56, 8, 33, 1,  9, 
    3, 80, 8, 77, 1, 16, 2, 16, 6, 51, 0,  3, 5, 70, 4, 46, 7, 74, 
    3, 78, 0, 15, 5, 80, 7, 42, 8,  4, 4, 24, 1,  4, 6, 57, 2, 51, 
    3, 61, 1, 74, 5, 76, 7, 44, 6, 62, 4, 75, 0, 67, 8, 90, 2, 26, 
    6, 88, 2, 27, 8, 37, 7, 91, 3,  1, 4,  6, 1, 67, 0, 29, 5, 42, 
    5, 62, 6, 74, 3, 89, 7, 49, 2, 34, 8, 80, 1, 58, 4, 59, 0, 94
  };
  const int q1753[] = {
    9, 9, // Number of jobs and machines
    3, 82, 4, 15, 5, 22, 8, 89, 1, 35, 6, 33, 7, 15, 2, 60, 0, 44, 
    5, 38, 1, 39, 7, 92, 8, 80, 4, 10, 6, 15, 2, 90, 3, 92, 0, 14, 
    7, 30, 5, 15, 2, 67, 0, 95, 3, 76, 6,  9, 4, 29, 8, 82, 1, 88, 
    6, 58, 4, 84, 2, 47, 5, 98, 8, 52, 7, 69, 3, 19, 1, 54, 0, 97, 
    0, 27, 1, 42, 5, 48, 6, 89, 3, 74, 4, 27, 7, 27, 8, 52, 2, 17, 
    7, 88, 2, 82, 5, 15, 6, 32, 1, 70, 8, 99, 0, 51, 4, 44, 3,  2, 
    0, 38, 8, 44, 7, 51, 6, 33, 1, 74, 3, 19, 5,  8, 4, 24, 2,  1, 
    5, 82, 6, 25, 8, 65, 2, 83, 0, 34, 4, 90, 3, 50, 1, 28, 7, 97, 
    1, 65, 3, 38, 7, 32, 8, 87, 6, 36, 4,  1, 0, 46, 2, 77, 5, 63
  };
  const int q1754[] = {
    9, 9, // Number of jobs and machines
    6, 18, 7, 38, 2, 89, 5, 93, 4, 40, 0, 62, 8, 70, 1, 11, 3, 15, 
    7, 24, 6, 14, 2, 25, 1, 22, 3, 95, 4, 83, 0, 56, 8, 31, 5, 92, 
    8, 73, 1, 53, 3,  7, 4, 18, 6, 57, 5, 26, 7, 34, 0, 55, 2, 34, 
    0, 19, 5, 99, 2, 56, 6, 61, 3, 63, 8, 34, 4, 94, 7, 17, 1, 54, 
    1, 70, 8, 46, 7, 76, 4, 50, 3, 11, 0, 36, 2, 63, 5, 59, 6, 85, 
    5, 71, 1, 26, 8,  9, 6, 35, 0, 47, 2, 28, 3, 11, 7, 73, 4, 58, 
    5, 95, 6, 42, 0, 85, 8, 53, 2, 63, 4, 61, 3, 58, 1, 47, 7, 12, 
    0, 98, 2, 27, 4, 54, 3, 18, 8, 41, 7, 14, 5, 33, 6, 16, 1, 86, 
    0, 97, 1, 18, 2, 49, 7, 46, 5, 78, 4, 49, 6, 60, 8, 73, 3, 17
  };
  const int q1755[] = {
    9, 9, // Number of jobs and machines
    4, 23, 8,  6, 5,  1, 2, 79, 0, 31, 6, 91, 3, 82, 7, 89, 1, 13, 
    8, 82, 4, 25, 3,  2, 5, 64, 6, 41, 0, 68, 2, 98, 1, 76, 7,  7, 
    6, 67, 5, 71, 1, 87, 8, 94, 2, 48, 7, 35, 4, 72, 0,  6, 3, 25, 
    4, 46, 7, 91, 6, 52, 3, 22, 8,  8, 1, 93, 5, 81, 0, 15, 2, 96, 
    4, 63, 6, 61, 3,  1, 8, 89, 7, 82, 2,  8, 0, 32, 1, 50, 5, 67, 
    6, 85, 0, 68, 8, 34, 3, 95, 1, 42, 2,  6, 5, 14, 4, 66, 7,  3, 
    0,  7, 1, 66, 5, 13, 2, 26, 4, 31, 7, 31, 3,  6, 6, 99, 8, 91, 
    4, 36, 1, 21, 7, 13, 0, 82, 6, 98, 5, 51, 3, 10, 2, 16, 8, 57, 
    8, 61, 3, 73, 1,  5, 2, 86, 7, 42, 0,  1, 6, 80, 4,  7, 5, 53
  };
  const int q1756[] = {
    9, 9, // Number of jobs and machines
    8, 82, 0, 52, 6, 70, 2, 99, 4, 24, 1, 16, 3, 64, 5, 84, 7,  8, 
    0, 42, 2, 53, 1, 65, 4, 38, 3, 12, 7, 63, 5, 28, 6, 27, 8, 29, 
    3, 53, 8,  7, 1, 43, 4, 38, 6, 76, 2, 90, 7, 53, 0, 52, 5, 20, 
    3, 83, 7, 14, 2, 10, 5, 79, 0, 70, 8, 42, 6, 19, 4, 21, 1, 78, 
    2, 47, 3, 34, 5,  9, 8, 14, 7, 14, 0, 93, 1, 52, 6, 68, 4, 14, 
    3, 69, 7,  6, 0, 71, 5, 55, 6, 15, 1, 21, 4, 26, 2,  4, 8, 82, 
    6, 69, 5, 40, 8, 90, 1, 21, 3, 26, 2, 43, 7, 37, 0, 33, 4, 83, 
    4,  7, 1, 40, 8, 72, 2, 33, 6, 98, 3, 39, 5, 66, 7, 70, 0, 13, 
    0, 81, 4, 96, 2, 40, 6, 72, 1, 20, 7, 16, 8, 91, 5, 89, 3, 91
  };
  const int q1757[] = {
    9, 9, // Number of jobs and machines
    0, 23, 8, 17, 6, 94, 2, 71, 1, 98, 7, 16, 5, 43, 3, 88, 4,  8, 
    0, 41, 3, 76, 6, 20, 4,  7, 7, 16, 2, 62, 1, 26, 8, 58, 5,  9, 
    4, 22, 2, 97, 0, 40, 5, 78, 1, 89, 3, 21, 7, 89, 8, 86, 6, 14, 
    7, 98, 8, 35, 6, 15, 0, 66, 5,  7, 2, 56, 1, 24, 3, 13, 4,  7, 
    6, 72, 5, 44, 0, 38, 8, 55, 2,  7, 4, 75, 7, 45, 1, 20, 3, 70, 
    8, 99, 4, 29, 5, 66, 1, 43, 2, 28, 6, 87, 0, 56, 7, 79, 3, 65, 
    1, 67, 4, 79, 6, 69, 7, 33, 0,  3, 5,  2, 2, 47, 3, 31, 8, 36, 
    3, 22, 4, 16, 6, 35, 1, 44, 5, 96, 0, 90, 8, 97, 2, 18, 7, 18, 
    0, 46, 6,  8, 7, 20, 5, 77, 4, 54, 8,  9, 1, 80, 3, 85, 2, 31
  };
  const int q1758[] = {
    9, 9, // Number of jobs and machines
    7, 33, 8, 46, 4, 85, 2, 84, 1, 97, 0, 75, 5, 65, 6, 65, 3, 61, 
    7,  5, 3, 72, 1, 35, 8, 19, 0, 70, 6, 75, 4, 39, 5, 10, 2, 14, 
    2, 15, 7,  5, 8, 69, 4, 36, 6, 90, 0, 54, 3,  6, 5, 83, 1, 73, 
    2, 30, 1, 85, 8, 27, 3, 30, 5, 19, 4, 47, 6, 62, 0, 58, 7, 24, 
    0, 90, 6, 54, 2, 27, 8, 47, 7, 76, 3, 19, 5, 95, 1, 62, 4, 94, 
    7, 81, 1, 98, 3, 37, 2, 38, 4, 83, 5, 44, 6, 12, 8, 20, 0, 67, 
    6, 20, 7, 68, 0, 19, 4, 59, 8, 95, 5, 96, 2, 93, 1, 92, 3, 15, 
    4, 62, 8, 78, 7, 75, 3, 18, 0, 62, 5, 19, 2, 88, 1, 32, 6, 53, 
    8, 94, 1, 92, 3, 80, 4, 69, 7, 32, 0, 28, 6, 26, 2, 27, 5, 85
  };
  const int q1759[] = {
    9, 9, // Number of jobs and machines
    2, 89, 3, 81, 5, 20, 4, 83, 1, 46, 8, 76, 0,  7, 7, 20, 6, 56, 
    2, 19, 1, 10, 6, 32, 0, 72, 3, 51, 5, 85, 4, 36, 8, 71, 7, 11, 
    8, 60, 2, 75, 4, 90, 0, 91, 6, 61, 5, 66, 1, 28, 7, 27, 3, 39, 
    3, 31, 5, 86, 8, 51, 1, 43, 6, 18, 7, 56, 0, 44, 2, 44, 4,  7, 
    4, 83, 8, 61, 7, 43, 3, 76, 1,  8, 5, 60, 2, 63, 0,  4, 6, 24, 
    1, 90, 2, 48, 4, 62, 3, 56, 5, 25, 6, 95, 8, 37, 0, 95, 7, 92, 
    4, 33, 6, 33, 5, 77, 2, 10, 7, 13, 0, 28, 8, 95, 1, 92, 3,  5, 
    0,  4, 6, 64, 3, 58, 4, 44, 8, 17, 1, 90, 5, 48, 7, 88, 2, 56, 
    7, 59, 2,  4, 3, 86, 4, 36, 1, 47, 8, 42, 6, 85, 0, 29, 5, 63
  };
  const int q1760[] = {
    9, 9, // Number of jobs and machines
    0, 87, 5, 94, 6, 98, 4, 58, 7, 99, 8, 39, 1, 56, 3,  4, 2, 27, 
    7, 21, 5, 74, 6, 87, 0, 41, 8, 51, 1, 55, 2, 88, 4, 44, 3, 25, 
    0, 25, 2, 54, 1, 84, 4, 43, 7, 29, 3, 47, 5,  1, 8, 60, 6, 36, 
    8, 44, 6, 37, 4, 56, 3, 84, 0, 57, 2, 43, 5, 39, 7, 39, 1,  9, 
    6, 53, 0, 83, 3, 78, 7, 74, 4, 81, 8,  3, 1, 23, 5, 97, 2, 78, 
    7, 37, 0, 65, 2, 99, 3, 14, 4, 37, 8, 34, 1, 19, 6, 97, 5, 94, 
    7, 29, 5, 73, 1, 66, 6, 56, 2, 68, 3, 38, 0, 94, 8, 21, 4, 95, 
    8, 35, 4, 33, 2, 48, 6, 13, 1, 16, 5, 34, 7, 98, 3, 89, 0, 35, 
    3, 10, 5, 70, 7,  6, 0, 69, 8, 40, 4, 30, 6, 14, 1, 17, 2, 24
  };
  const int q1761[] = {
    9, 9, // Number of jobs and machines
    4, 95, 3, 75, 0, 53, 1, 27, 8, 17, 6, 82, 7, 67, 5, 56, 2, 41, 
    6, 12, 5, 78, 0, 37, 8, 80, 4, 24, 2,  3, 7, 12, 1, 85, 3, 12, 
    5, 26, 1, 21, 4, 65, 2, 15, 0, 91, 8, 79, 3, 28, 7,  4, 6, 79, 
    1, 82, 4, 85, 3, 22, 5, 92, 0,  4, 8, 86, 7, 77, 2, 98, 6, 70, 
    1, 65, 2,  2, 5, 91, 4, 77, 0, 88, 7, 61, 3, 98, 8, 63, 6,  2, 
    6, 81, 0, 75, 4, 59, 7, 57, 8, 89, 3, 97, 5, 59, 1, 10, 2, 28, 
    2, 49, 6, 89, 4, 68, 1, 43, 5, 62, 8,  1, 7, 65, 0, 64, 3, 76, 
    5, 18, 6, 53, 0, 17, 3, 50, 2, 31, 7, 51, 1, 23, 8, 84, 4, 50, 
    5, 76, 1, 84, 4, 71, 8, 29, 0, 53, 6, 22, 2, 76, 3, 88, 7, 83
  };
  const int q1762[] = {
    9, 9, // Number of jobs and machines
    4, 89, 0, 97, 8, 18, 1, 10, 7, 12, 6, 70, 5, 36, 3, 36, 2, 49, 
    8, 77, 7, 54, 4, 76, 2, 68, 0, 28, 6, 68, 1, 55, 3, 19, 5, 61, 
    1,  4, 3, 63, 5, 31, 2, 70, 4, 25, 7,  3, 6, 95, 8, 73, 0, 64, 
    7, 96, 3, 87, 6, 73, 4,  5, 0, 59, 8, 45, 1, 88, 2, 41, 5, 10, 
    6, 69, 3,  1, 4, 27, 0, 18, 2,  5, 5,  7, 1, 70, 8, 62, 7, 29, 
    0, 29, 6,  3, 1, 39, 5, 46, 8, 26, 7, 51, 4, 63, 2, 99, 3, 22, 
    7, 14, 6, 26, 8, 52, 0, 79, 4, 29, 5, 83, 1, 80, 3, 91, 2, 18, 
    4, 23, 2, 54, 3, 55, 7, 57, 0, 86, 8, 99, 1, 71, 5,  3, 6, 11, 
    7, 90, 5, 15, 0, 17, 2, 63, 6, 27, 8, 14, 1,  3, 3, 31, 4, 39
  };
  const int q1763[] = {
    9, 9, // Number of jobs and machines
    7, 67, 0, 41, 8, 67, 1, 77, 3, 36, 5, 98, 2, 57, 4, 22, 6, 53, 
    0, 88, 1, 60, 5, 32, 2, 42, 7, 29, 8, 99, 3, 36, 4,  7, 6, 40, 
    8, 68, 7, 93, 2, 45, 1, 36, 0, 82, 4, 72, 6, 56, 5, 70, 3, 77, 
    6, 72, 2,  7, 4, 45, 0, 86, 1, 92, 5,  3, 8, 23, 7, 46, 3, 73, 
    2, 54, 1, 47, 4, 55, 3, 88, 6, 29, 0, 50, 7, 86, 5, 90, 8, 69, 
    8, 40, 6, 87, 5, 19, 2, 39, 4, 56, 0, 14, 3, 15, 7, 36, 1, 98, 
    6, 32, 2, 47, 0,  5, 5, 37, 1, 54, 3, 81, 8, 66, 7, 83, 4, 27, 
    6, 71, 5, 78, 3, 56, 2, 60, 1, 84, 7, 66, 0, 54, 4, 86, 8, 63, 
    7, 53, 6, 87, 4, 54, 5, 23, 8, 56, 3, 32, 1,  7, 2,  8, 0, 76
  };
  const int q1764[] = {
    9, 9, // Number of jobs and machines
    1, 52, 6, 68, 0, 49, 3, 21, 5, 49, 4, 60, 7,  1, 2, 21, 8, 17, 
    5, 38, 4, 66, 7, 72, 1, 63, 6, 99, 2, 19, 0, 30, 3, 56, 8, 77, 
    3, 31, 4, 31, 1,  9, 5, 35, 8, 48, 2, 66, 0, 46, 6,  9, 7,  9, 
    1, 39, 6, 35, 5, 51, 8, 69, 0, 43, 7, 97, 4, 32, 2, 70, 3, 19, 
    6, 92, 5, 74, 2, 61, 0, 56, 3, 61, 1, 72, 4, 12, 8, 77, 7, 68, 
    1, 49, 4, 73, 7, 15, 6, 95, 5, 38, 2,  4, 8, 47, 3, 98, 0, 81, 
    5, 41, 2, 43, 0, 28, 8, 40, 3, 54, 7, 35, 1,  6, 6, 17, 4, 86, 
    6, 84, 5, 36, 0, 10, 8, 37, 2, 72, 4, 10, 3, 53, 7, 75, 1, 78, 
    4, 65, 6, 31, 5, 20, 0,  3, 2,  2, 8, 95, 7, 68, 3, 81, 1, 54
  };
  const int q1765[] = {
    9, 9, // Number of jobs and machines
    0, 71, 2, 68, 8, 89, 7, 26, 4, 99, 3,  1, 1, 45, 5,  9, 6, 23, 
    6, 74, 0, 55, 5, 46, 3, 91, 1, 34, 7, 39, 8, 24, 2, 80, 4, 74, 
    5, 53, 7, 45, 8, 34, 2, 46, 3, 26, 6, 89, 1, 38, 0, 72, 4, 85, 
    2,  4, 8, 26, 1, 22, 5, 27, 4, 87, 3, 52, 7, 88, 6, 47, 0, 42, 
    2, 84, 5, 28, 8, 34, 6, 20, 0, 94, 3, 81, 7, 31, 4, 69, 1, 29, 
    2, 67, 8, 59, 1, 14, 5, 58, 4, 16, 7, 78, 0,  3, 3, 73, 6, 88, 
    0, 49, 7, 30, 5, 92, 1, 29, 6, 46, 8, 34, 2, 88, 3, 69, 4, 22, 
    4, 31, 2, 23, 6, 61, 7, 23, 5, 65, 8, 48, 1, 70, 0, 68, 3, 84, 
    4, 71, 6, 36, 5, 99, 3,  4, 2, 21, 1, 92, 0, 62, 7, 67, 8, 32
  };
  const int q1766[] = {
    9, 9, // Number of jobs and machines
    5, 59, 6, 86, 0, 11, 3, 12, 4, 48, 7, 82, 8, 32, 1, 31, 2, 75, 
    5, 55, 8, 68, 0, 18, 6, 34, 3, 80, 7,  6, 2, 70, 1, 80, 4, 18, 
    0, 51, 5, 33, 1, 10, 2, 63, 7, 75, 8, 56, 3, 15, 6, 68, 4, 24, 
    5, 99, 1, 75, 6, 51, 4, 18, 3, 58, 0, 47, 8, 70, 2, 97, 7, 44, 
    5, 71, 1, 21, 8, 16, 6, 49, 7, 23, 2, 33, 4, 53, 0, 53, 3, 81, 
    3, 19, 4, 26, 0, 45, 8, 44, 5, 52, 7, 36, 6, 87, 1, 10, 2, 50, 
    2, 86, 0,  2, 7, 40, 3, 37, 1, 19, 4, 44, 6, 60, 5, 83, 8, 14, 
    8, 54, 3, 11, 0, 51, 7, 29, 5, 41, 2, 30, 1,  9, 6,  6, 4, 57, 
    5, 75, 2, 19, 1, 23, 7, 32, 8, 56, 6, 70, 4, 14, 3, 61, 0, 86
  };
  const int q1767[] = {
    9, 9, // Number of jobs and machines
    2, 65, 4, 83, 6, 76, 7, 61, 3, 91, 0, 72, 8, 47, 5, 41, 1, 27, 
    3, 61, 1, 13, 0, 72, 6, 23, 2,  5, 4,  5, 5, 96, 7, 17, 8, 58, 
    5, 29, 0, 65, 1,  6, 7, 73, 6, 12, 4, 83, 3, 24, 8,  9, 2, 34, 
    5, 78, 7, 66, 8, 33, 1, 83, 4, 11, 6,  4, 3,  8, 2,  7, 0, 19, 
    7, 63, 2,  8, 5, 17, 0, 54, 1, 72, 8,  4, 6,  3, 3, 16, 4, 35, 
    1, 29, 4, 79, 2, 78, 8, 79, 3, 88, 0, 31, 5,  8, 6, 14, 7, 51, 
    4, 58, 6,  5, 1, 84, 2, 30, 5, 12, 0, 12, 7, 17, 3, 19, 8, 47, 
    7, 35, 5, 59, 2, 17, 0, 59, 1, 93, 3, 90, 6, 51, 8, 17, 4, 70, 
    2,  1, 7, 67, 3, 28, 8, 84, 5,  7, 1, 88, 6, 58, 4, 57, 0,  6
  };
  const int q1768[] = {
    9, 9, // Number of jobs and machines
    2, 17, 7, 96, 5, 35, 8, 19, 0, 21, 3, 36, 1, 50, 6, 72, 4, 96, 
    2, 59, 1, 65, 0, 51, 5, 14, 4,  1, 6, 82, 8, 85, 7, 24, 3, 14, 
    2, 34, 7, 95, 0, 16, 4, 49, 6, 94, 3, 40, 1, 24, 5, 48, 8, 74, 
    6,  8, 1,  1, 5, 60, 3, 68, 2,  9, 0, 79, 4, 48, 8, 39, 7, 34, 
    8, 89, 7,  2, 5, 20, 2, 77, 3,  4, 4,  5, 6, 91, 1, 13, 0, 85, 
    3, 44, 0, 46, 1, 53, 4, 13, 6, 91, 8, 13, 7, 15, 5, 59, 2, 97, 
    1, 39, 0, 20, 6, 72, 7, 73, 3, 81, 4, 60, 8, 89, 2, 52, 5, 76, 
    4, 60, 2, 53, 7, 25, 8, 54, 3, 41, 0, 58, 5, 90, 6, 92, 1, 77, 
    5, 61, 2, 35, 0, 24, 4, 49, 3, 53, 8, 18, 1, 49, 7, 74, 6, 60
  };
  const int q1769[] = {
    9, 9, // Number of jobs and machines
    2, 91, 3, 84, 0, 23, 8, 92, 7, 69, 4, 78, 5, 54, 6,  6, 1, 41, 
    0, 56, 2, 56, 7, 86, 5, 38, 4, 77, 6, 66, 1, 67, 8,  6, 3,  3, 
    6, 70, 4, 19, 5, 13, 3, 61, 1, 86, 8, 72, 0, 55, 7, 16, 2, 83, 
    6, 52, 8, 52, 0, 77, 7, 37, 4, 89, 2, 25, 1, 27, 3, 80, 5, 97, 
    2, 15, 6, 37, 7, 81, 4, 61, 3, 12, 8, 12, 0, 70, 1, 45, 5, 89, 
    2, 36, 4,  1, 3, 89, 5, 53, 1, 32, 8, 98, 0, 37, 7,  5, 6,  6, 
    7, 80, 2, 73, 8, 60, 3, 52, 1, 30, 6, 22, 4,  6, 0, 69, 5,  7, 
    1, 94, 7, 17, 8, 27, 5, 51, 6, 29, 4, 18, 2, 51, 0, 65, 3, 31, 
    6,  8, 0, 94, 8, 45, 2, 85, 5, 98, 3, 20, 7, 24, 1, 54, 4, 59
  };
  const int q1770[] = {
    9, 9, // Number of jobs and machines
    2, 84, 4, 99, 6, 73, 1, 17, 3, 68, 7, 75, 5, 30, 0, 55, 8, 13, 
    5, 82, 8, 70, 2, 87, 4, 28, 0, 41, 1, 67, 7, 30, 3, 49, 6, 47, 
    2, 97, 3, 77, 8, 22, 4, 60, 0, 31, 5, 23, 7, 53, 6, 77, 1,  5, 
    6, 51, 1, 15, 3, 37, 5, 77, 4, 26, 2, 47, 7, 25, 0, 61, 8,  2, 
    5, 80, 2, 45, 0, 40, 3, 28, 7, 63, 8, 49, 1, 42, 6, 73, 4, 43, 
    7, 83, 6, 63, 1, 39, 5, 85, 2, 96, 3, 72, 4, 91, 0, 95, 8, 76, 
    3,  5, 6, 94, 0, 85, 7, 34, 1, 29, 2, 44, 5, 87, 4,  4, 8, 64, 
    4, 55, 2, 34, 6, 72, 7, 86, 3, 62, 0, 11, 8, 18, 1, 91, 5, 70, 
    5, 34, 7, 36, 4, 43, 2, 93, 6, 90, 0, 82, 1, 77, 8, 43, 3, 68
  };
  const int q1771[] = {
    9, 9, // Number of jobs and machines
    5, 11, 7, 47, 8, 33, 0, 44, 6, 76, 3, 13, 2, 69, 4, 32, 1, 29, 
    4, 50, 1, 20, 8, 88, 7,  7, 0, 26, 5, 27, 3,  9, 6, 13, 2, 53, 
    8, 59, 0, 79, 1, 37, 6, 61, 5, 13, 2, 95, 4, 68, 3, 41, 7, 47, 
    7, 52, 2, 55, 0, 43, 6, 45, 3, 49, 1, 13, 4, 90, 8, 91, 5, 59, 
    8, 90, 3, 88, 7, 43, 4, 82, 1, 22, 2, 54, 5, 64, 6, 11, 0, 29, 
    0,  8, 2, 73, 6, 51, 3, 27, 8, 13, 1, 22, 4, 28, 5, 31, 7, 76, 
    4, 36, 2, 17, 3, 81, 7, 20, 1,  3, 0, 74, 6, 96, 5, 65, 8, 36, 
    8, 36, 4, 73, 3, 12, 0, 55, 6, 26, 1, 40, 2, 33, 7, 90, 5,  5, 
    0, 58, 2, 55, 3,  4, 1, 32, 5, 14, 6, 73, 7, 31, 4, 94, 8, 78
  };
  const int q1772[] = {
    9, 9, // Number of jobs and machines
    5, 94, 2, 53, 8, 95, 1, 66, 0, 77, 4, 20, 3, 82, 6, 83, 7,  2, 
    2, 49, 8, 93, 4, 99, 1, 58, 7, 75, 0, 64, 5, 36, 6,  2, 3, 88, 
    0, 36, 5, 33, 6, 25, 7, 61, 3, 83, 2,  6, 8, 74, 1, 99, 4, 88, 
    2,  7, 6, 69, 1, 33, 3, 59, 0, 82, 4, 69, 8,  9, 7, 54, 5, 22, 
    5, 39, 4, 92, 1, 22, 2, 88, 8, 48, 6, 96, 0, 61, 7,  5, 3, 60, 
    7, 41, 1,  5, 2,  4, 6, 24, 4, 46, 8, 77, 0, 88, 5, 75, 3, 49, 
    0, 59, 5, 57, 2, 54, 6, 29, 8, 73, 7, 20, 3, 37, 4, 43, 1, 22, 
    6, 39, 5, 42, 2, 81, 4, 50, 1, 55, 3, 86, 0, 51, 8, 86, 7, 20, 
    3, 54, 6,  1, 2, 52, 5, 78, 8, 53, 4,  4, 0, 52, 7, 72, 1, 58
  };
  const int q1773[] = {
    9, 9, // Number of jobs and machines
    8, 96, 1, 56, 6, 78, 3, 86, 4, 68, 5, 38, 7, 74, 0, 14, 2, 72, 
    6, 37, 5, 38, 8, 72, 0, 27, 1, 75, 7, 74, 3,  9, 4, 77, 2, 67, 
    4, 63, 6, 92, 7,  4, 3, 67, 2, 64, 0, 24, 8, 78, 1, 11, 5, 16, 
    8, 38, 0, 60, 3, 49, 1, 96, 7, 41, 5, 99, 4, 46, 2, 50, 6, 39, 
    0, 36, 5,  3, 1, 15, 3, 94, 6, 70, 8, 38, 2, 53, 4, 26, 7, 58, 
    2,  8, 4, 28, 0, 23, 1, 55, 3, 84, 6, 57, 7, 44, 8, 79, 5, 58, 
    8, 36, 1, 80, 2, 33, 0, 20, 3, 57, 5, 62, 6, 56, 4, 17, 7,  4, 
    1, 98, 5, 54, 2, 20, 7, 14, 4, 14, 6, 20, 3, 21, 8, 47, 0, 98, 
    0, 17, 3, 15, 1, 85, 5, 92, 4, 77, 2, 40, 7, 55, 6, 67, 8, 41
  };
  const int q1774[] = {
    9, 9, // Number of jobs and machines
    7, 99, 2, 54, 1, 23, 0, 17, 3, 52, 6, 71, 4, 26, 5, 11, 8, 46, 
    0, 32, 7, 90, 3, 29, 2, 22, 8,  5, 4, 53, 1, 49, 6, 64, 5, 76, 
    2, 95, 5, 33, 6, 73, 4, 25, 0, 22, 3, 62, 1, 38, 8, 14, 7, 82, 
    2, 56, 4, 67, 8, 88, 5,  6, 0, 28, 3, 82, 7, 54, 1, 95, 6, 61, 
    0, 60, 4, 84, 7, 46, 2, 58, 6, 94, 3, 93, 5, 69, 8, 79, 1, 81, 
    6, 96, 4, 80, 7, 51, 2, 96, 8, 65, 0, 36, 1, 76, 3, 12, 5, 21, 
    3, 20, 8, 42, 4, 15, 1,  2, 7,  4, 2, 29, 6, 60, 0, 11, 5, 69, 
    8, 17, 1, 10, 2, 80, 5, 54, 3, 91, 0, 12, 4, 97, 7, 76, 6, 42, 
    5, 75, 6, 56, 1, 99, 3,  4, 2, 87, 8, 83, 4, 33, 0, 29, 7, 18
  };
  const int q1775[] = {
    9, 9, // Number of jobs and machines
    1, 94, 6, 74, 5, 76, 4,  4, 3, 47, 8, 67, 2, 29, 0, 49, 7, 91, 
    8, 36, 7, 65, 1, 48, 6, 66, 4, 17, 0,  4, 5, 11, 2, 38, 3, 80, 
    8, 58, 7, 75, 4,  6, 5, 18, 6, 27, 0, 63, 3, 11, 2, 11, 1, 10, 
    7, 18, 3, 27, 5, 84, 4, 25, 2, 82, 6, 16, 8, 23, 0, 21, 1, 29, 
    8, 44, 5,  6, 1, 27, 4, 89, 0, 30, 3, 45, 6, 42, 2, 61, 7, 37, 
    7, 97, 0, 57, 8, 77, 6, 37, 1, 40, 4, 71, 5, 14, 3, 59, 2, 26, 
    2, 93, 8, 84, 1, 51, 4, 18, 3, 11, 5, 92, 6, 26, 7, 12, 0, 98, 
    2, 25, 0, 70, 7, 81, 5, 81, 4, 64, 8, 61, 1, 53, 6, 28, 3, 84, 
    3, 27, 8,  9, 6, 71, 1, 49, 7, 26, 5,  8, 2, 57, 0, 32, 4, 54
  };
  const int q1776[] = {
    9, 9, // Number of jobs and machines
    6, 53, 4,  1, 7, 44, 1, 53, 2, 41, 8, 57, 5, 90, 0, 13, 3, 94, 
    0, 81, 2, 94, 6, 26, 3, 65, 1, 96, 5, 54, 7,  5, 8, 70, 4,  9, 
    5, 36, 1, 36, 6,  2, 4, 52, 2, 81, 8, 64, 3, 29, 7, 65, 0, 18, 
    5, 73, 3, 11, 7, 23, 6, 99, 2, 42, 8, 85, 1, 43, 0, 26, 4, 63, 
    7, 48, 8, 36, 2, 70, 4, 85, 1, 71, 0, 83, 5, 17, 3, 37, 6, 64, 
    6, 45, 0, 15, 5, 72, 1, 90, 2, 48, 4, 33, 7, 64, 3, 71, 8,  6, 
    7, 90, 3, 38, 6, 41, 0,  7, 2, 41, 4, 12, 5, 34, 8, 19, 1, 68, 
    1, 12, 5, 10, 7, 83, 2, 92, 0,  5, 4, 82, 3, 30, 8, 96, 6,  4, 
    7, 35, 6, 48, 5, 26, 0, 87, 2, 48, 3, 15, 1, 19, 8, 58, 4,  6
  };
  const int q1777[] = {
    9, 9, // Number of jobs and machines
    3, 48, 4, 90, 0, 23, 7, 98, 1, 67, 6, 19, 8, 90, 2,  4, 5, 14, 
    4, 38, 7, 66, 8, 11, 1, 45, 0, 50, 3, 71, 2, 14, 6, 60, 5, 51, 
    1,  3, 3, 80, 4,  8, 5, 41, 7,  2, 8, 15, 0, 31, 6, 61, 2, 30, 
    1, 20, 5,  7, 4, 82, 6, 89, 8,  1, 7,  7, 3, 66, 2, 43, 0, 42, 
    6, 47, 2, 46, 1, 93, 4, 65, 8, 80, 5, 18, 3, 96, 7, 48, 0, 17, 
    3, 37, 1, 84, 8,  3, 0, 13, 2, 27, 5, 13, 7, 26, 4, 84, 6, 73, 
    1, 18, 5, 32, 4, 68, 2, 22, 8, 82, 3, 45, 6, 53, 0, 36, 7, 74, 
    1, 67, 4, 16, 8, 24, 0, 51, 6, 91, 5, 67, 2, 39, 7, 76, 3, 20, 
    7, 33, 2, 81, 3, 98, 6, 65, 5, 52, 4, 70, 8,  3, 1, 81, 0, 96
  };
  const int q1778[] = {
    9, 9, // Number of jobs and machines
    5, 76, 1, 12, 8, 55, 3, 30, 7, 76, 4, 48, 6, 61, 0,  3, 2, 12, 
    0, 64, 3, 52, 7, 57, 8, 32, 5,  7, 6, 44, 2, 97, 1, 28, 4, 16, 
    5, 59, 6, 78, 2, 45, 1, 74, 7, 96, 0, 48, 4, 25, 8, 93, 3, 31, 
    2,  5, 0, 31, 5, 10, 6, 35, 7, 47, 8, 81, 3, 82, 4, 42, 1, 12, 
    8, 40, 6, 69, 0, 60, 7, 81, 4, 88, 2, 23, 3, 41, 5, 43, 1,  6, 
    3, 68, 7, 16, 1, 89, 0, 44, 4, 73, 2, 19, 5, 82, 6, 31, 8, 42, 
    7, 86, 0,  8, 1, 96, 4, 34, 2, 63, 6, 24, 3, 93, 5, 79, 8, 44, 
    8, 45, 3,  8, 7, 15, 1, 19, 6,  9, 2, 75, 5, 64, 4, 62, 0, 80, 
    3, 64, 6,  3, 1, 56, 4, 24, 8, 34, 5, 22, 0, 83, 7,  7, 2, 17
  };
  const int q1779[] = {
    9, 9, // Number of jobs and machines
    2, 34, 4, 90, 1, 43, 8, 18, 3, 70, 7, 76, 0, 49, 6, 36, 5, 70, 
    5, 75, 2, 68, 1, 73, 3, 84, 6, 86, 8, 98, 7, 26, 4, 61, 0, 46, 
    2, 73, 0, 50, 6, 50, 4,  1, 3, 47, 7, 65, 8, 10, 1, 12, 5, 75, 
    7, 25, 3,  2, 1, 77, 6, 96, 0, 83, 5, 56, 2, 12, 8, 16, 4, 92, 
    6, 12, 8, 78, 0,  2, 3, 38, 7, 25, 1, 15, 4, 70, 5, 68, 2, 74, 
    2, 52, 8,  4, 1, 41, 4, 79, 5, 69, 0, 38, 3, 13, 7, 51, 6, 96, 
    3, 46, 8,  3, 7, 45, 2, 60, 6, 77, 5, 69, 1, 90, 4, 73, 0, 57, 
    3, 66, 6, 77, 1, 18, 4, 27, 8, 44, 0,  3, 7, 93, 2, 30, 5, 36, 
    7, 31, 2,  8, 4, 26, 6, 27, 5, 19, 3, 97, 8, 54, 1,  7, 0, 59
  };
  const int q1780[] = {
    9, 9, // Number of jobs and machines
    1, 63, 6, 47, 7, 86, 0, 22, 4, 34, 2, 50, 3,  4, 5, 26, 8, 16, 
    6,  4, 8, 23, 5,  7, 7, 70, 4, 79, 0, 92, 3, 71, 1, 72, 2, 52, 
    6, 86, 3, 17, 1,  6, 2, 13, 7, 26, 5, 82, 4, 76, 8, 71, 0, 34, 
    6, 23, 4, 63, 7, 32, 0, 42, 1,  9, 2, 19, 8, 81, 5, 81, 3, 51, 
    7, 59, 6, 85, 5, 68, 4, 33, 1, 40, 3, 59, 2, 52, 8, 58, 0, 99, 
    2, 32, 3,  6, 7, 43, 0, 69, 4, 48, 6, 35, 5,  6, 1, 59, 8, 65, 
    2, 26, 4, 48, 1, 89, 7, 30, 0,  5, 6,  5, 3, 57, 5, 32, 8, 71, 
    4, 91, 2, 24, 6, 67, 8, 75, 3, 67, 1, 96, 0, 77, 7, 87, 5,  1, 
    8, 52, 2, 55, 5, 64, 7,  2, 4, 96, 0, 37, 3, 94, 1,  6, 6, 39
  };
  const int q1781[] = {
    9, 9, // Number of jobs and machines
    0, 84, 6, 75, 8, 54, 7, 64, 2, 38, 5, 14, 4, 13, 3, 43, 1, 91, 
    2, 93, 3, 70, 8,  5, 5, 36, 6, 26, 1, 56, 7, 60, 0, 91, 4, 72, 
    0, 34, 1, 58, 3, 10, 7, 77, 6, 51, 8, 92, 2, 70, 5, 78, 4,  2, 
    5, 16, 6, 51, 4,  7, 2, 20, 1, 87, 7, 33, 8, 30, 0, 44, 3, 86, 
    8, 69, 2, 49, 5, 80, 3, 79, 0, 16, 7, 75, 1, 59, 6, 18, 4, 83, 
    0, 18, 8, 15, 7, 73, 5, 75, 1, 65, 6, 46, 3, 10, 4, 21, 2, 96, 
    3, 56, 6, 88, 7, 16, 8,  9, 2, 44, 1, 41, 0, 13, 4, 76, 5, 55, 
    4, 33, 8,  9, 6, 18, 7, 85, 2, 25, 3, 78, 1, 80, 5, 99, 0, 97, 
    1, 19, 0, 24, 8, 73, 7, 56, 5, 80, 4, 73, 2, 32, 3, 91, 6, 66
  };
  const int q1782[] = {
    9, 9, // Number of jobs and machines
    8, 49, 0, 36, 7, 68, 2, 80, 1, 49, 6, 96, 4, 54, 5, 87, 3, 11, 
    7, 98, 8, 70, 5, 55, 3, 49, 4, 95, 1, 58, 0, 99, 6, 77, 2, 99, 
    6, 69, 5, 29, 4,  3, 2, 77, 8, 39, 3, 90, 0, 69, 1, 99, 7, 56, 
    5,  4, 1, 56, 2, 96, 4, 28, 6, 81, 7, 36, 0, 50, 8, 92, 3, 56, 
    3, 15, 4, 68, 5, 51, 6, 70, 0, 53, 1, 75, 2, 18, 7, 76, 8, 82, 
    1, 31, 8,  1, 5,  3, 2, 90, 0, 97, 4, 14, 6, 55, 7, 17, 3, 61, 
    3, 48, 7,  8, 2, 38, 6, 98, 0, 34, 8, 43, 4,  2, 5, 20, 1,  5, 
    8, 16, 2, 11, 6, 71, 1, 95, 4, 23, 0, 63, 7, 56, 3, 77, 5, 97, 
    6, 47, 2, 58, 3, 96, 1, 96, 0, 98, 7, 15, 8, 42, 4, 21, 5, 67
  };
  const int q1783[] = {
    9, 9, // Number of jobs and machines
    2, 67, 7, 25, 5,  1, 4, 84, 3, 43, 6, 54, 0, 24, 1, 77, 8, 61, 
    7, 21, 1, 98, 3, 87, 5, 79, 2, 82, 6, 63, 0, 55, 8,  1, 4, 33, 
    1, 41, 8, 94, 4, 33, 2, 41, 3, 34, 0, 98, 7, 16, 6, 79, 5, 75, 
    1, 50, 4, 37, 3, 89, 8,  6, 5,  1, 7, 80, 0, 69, 2, 53, 6, 20, 
    5, 57, 1, 22, 3,  1, 8, 26, 0,  7, 7,  4, 2, 25, 6, 43, 4,  7, 
    6, 35, 7,  5, 3, 86, 8, 81, 5, 33, 0, 18, 1,  4, 2, 75, 4, 55, 
    1, 20, 2, 37, 5, 28, 3, 92, 6, 44, 4, 51, 8,  1, 0, 46, 7,  8, 
    5, 50, 3, 28, 7, 23, 4, 39, 8, 68, 0, 30, 2, 74, 1, 57, 6, 90, 
    6, 92, 8,  8, 0, 39, 7,  4, 3, 15, 5, 17, 2, 48, 4, 80, 1, 43
  };
  const int q1784[] = {
    9, 9, // Number of jobs and machines
    8, 92, 5, 41, 4, 83, 1, 29, 6, 11, 2, 61, 3, 20, 0, 44, 7, 50, 
    6, 49, 1, 87, 3, 67, 5, 84, 4, 52, 2, 91, 0, 52, 7, 87, 8, 99, 
    8, 58, 4, 48, 3, 24, 2, 13, 7, 83, 1, 29, 0, 51, 5, 10, 6, 63, 
    2, 31, 6,  6, 4, 31, 7, 15, 5, 89, 3, 22, 8, 10, 1, 44, 0, 32, 
    8, 68, 0, 58, 3, 81, 7, 96, 5, 20, 4, 40, 6, 33, 1, 32, 2, 86, 
    0, 35, 3, 80, 8, 76, 7, 51, 1, 86, 6, 21, 4, 72, 5, 49, 2, 35, 
    5, 16, 3, 94, 6,  6, 1, 57, 0, 76, 2, 65, 4, 41, 8, 62, 7,  5, 
    8, 38, 0, 81, 7, 22, 6, 28, 4, 33, 2, 59, 1,  2, 3, 32, 5, 92, 
    6, 17, 7, 47, 1, 14, 5, 88, 4, 22, 8, 48, 2, 38, 0, 95, 3, 87
  };
  const int q1785[] = {
    9, 9, // Number of jobs and machines
    5, 16, 1, 62, 8, 79, 0, 13, 4, 99, 6, 56, 3, 41, 7, 37, 2, 34, 
    6, 47, 8, 19, 2,  7, 1, 31, 5, 72, 3, 46, 0, 76, 4, 63, 7, 88, 
    4, 88, 2,  3, 3,  6, 8, 40, 1, 81, 5, 19, 7, 50, 0, 67, 6, 28, 
    6, 65, 8,  5, 3, 88, 2,  5, 4, 81, 1, 93, 0, 16, 5, 56, 7, 93, 
    4, 84, 8, 45, 7, 74, 5, 42, 6, 77, 1, 22, 3,  4, 0, 15, 2, 16, 
    0, 27, 5, 39, 4, 75, 2, 25, 6, 80, 3, 79, 7, 59, 8, 15, 1, 49, 
    4, 64, 8, 18, 5, 98, 3,  7, 0, 30, 7, 67, 6, 82, 2, 58, 1, 35, 
    5, 38, 1, 39, 3, 80, 4, 58, 6, 73, 8, 55, 0, 28, 7,  8, 2,  2, 
    6, 28, 4, 96, 0, 49, 3, 17, 7, 68, 1, 40, 8, 57, 2, 35, 5, 25
  };
  const int q1786[] = {
    9, 9, // Number of jobs and machines
    2, 49, 3, 76, 7, 84, 4, 50, 5, 54, 0, 26, 8, 94, 6, 38, 1, 44, 
    6, 19, 7, 98, 8, 59, 3, 48, 5, 92, 2, 46, 0, 59, 1,  4, 4, 55, 
    3, 68, 5,  6, 7, 67, 0,  1, 2, 56, 8, 12, 1, 37, 4, 36, 6, 95, 
    1, 13, 6, 86, 4, 98, 2, 65, 8, 87, 7, 49, 5, 69, 0, 52, 3, 78, 
    3, 84, 2,  7, 0, 31, 5, 37, 1, 79, 8, 83, 7, 84, 4, 78, 6, 81, 
    4, 80, 6, 86, 0, 91, 8, 26, 5, 42, 2, 96, 3, 81, 1, 92, 7, 12, 
    2, 78, 5, 89, 1, 80, 8, 94, 3, 93, 0, 78, 4, 57, 7, 34, 6, 48, 
    3, 25, 0, 36, 5, 58, 4, 82, 2, 49, 8, 41, 6, 22, 7,  2, 1, 15, 
    6, 42, 4, 32, 8, 95, 7, 25, 2, 65, 5, 40, 0, 63, 1,  9, 3, 67
  };
  const int q1787[] = {
    9, 9, // Number of jobs and machines
    8, 62, 0, 80, 1, 94, 5, 16, 4, 21, 3, 97, 2, 30, 6, 85, 7, 27, 
    3,  3, 0,  3, 4, 48, 8, 93, 7,  9, 5, 62, 1, 50, 6, 86, 2, 16, 
    2, 30, 7, 85, 4, 12, 5, 54, 3, 98, 6, 84, 1, 33, 8, 50, 0, 62, 
    8, 69, 1, 77, 5, 57, 0,  2, 3, 17, 4, 58, 6, 77, 2, 57, 7, 85, 
    3,  3, 2, 24, 4, 11, 8, 25, 7, 19, 1, 23, 0, 58, 5, 41, 6, 86, 
    0,  6, 6,  5, 5,  5, 7, 73, 8, 19, 3, 73, 2, 43, 1, 78, 4, 73, 
    5,  9, 0, 65, 3, 39, 1,  4, 8, 29, 2, 43, 7, 90, 6, 92, 4, 33, 
    6, 11, 3, 74, 7, 46, 5, 34, 1,  5, 8, 80, 2, 70, 0, 64, 4, 10, 
    3, 45, 0, 97, 5, 29, 1, 36, 2, 73, 8, 31, 7, 52, 6, 21, 4, 48
  };
  const int q1788[] = {
    9, 9, // Number of jobs and machines
    3, 91, 1,  7, 8, 67, 6, 93, 7, 45, 2, 53, 4, 19, 0, 43, 5, 48, 
    5, 91, 6, 21, 3, 34, 1,  7, 8, 18, 0, 30, 4, 79, 7, 88, 2, 86, 
    0, 62, 4,  4, 6, 66, 1, 54, 2, 24, 3, 24, 7,  2, 8, 65, 5, 42, 
    2, 12, 0, 78, 6, 46, 3, 86, 5, 58, 1, 56, 7, 85, 8, 28, 4,  9, 
    1, 56, 4, 95, 2, 92, 5, 50, 0, 21, 6, 20, 3, 24, 8, 67, 7, 95, 
    8, 49, 5, 93, 4,  5, 3, 35, 2, 76, 6, 36, 0, 10, 7,  7, 1, 83, 
    4, 93, 2, 81, 8, 75, 0, 19, 7, 77, 5, 63, 3, 20, 6, 96, 1, 35, 
    5, 48, 4, 19, 7, 73, 2, 18, 3, 76, 0, 87, 1, 16, 6, 58, 8,  1, 
    5, 64, 3, 22, 4, 89, 2,  2, 6, 96, 8, 96, 1, 25, 0, 34, 7, 18
  };
  const int q1789[] = {
    9, 9, // Number of jobs and machines
    0, 44, 2, 19, 6, 95, 1, 24, 7, 62, 3, 37, 4, 57, 5, 49, 8, 12, 
    2, 35, 6, 69, 8, 84, 4, 79, 0,  8, 7, 17, 1, 30, 5, 46, 3, 64, 
    2, 59, 7, 94, 6, 16, 3, 36, 8, 72, 0, 78, 5, 28, 4, 78, 1, 21, 
    6, 62, 1, 57, 4, 75, 5, 69, 3, 48, 0, 20, 8, 98, 7, 96, 2, 26, 
    8, 62, 6, 18, 3, 24, 5, 69, 1, 81, 4,  8, 7, 72, 0, 84, 2, 51, 
    8, 59, 3, 71, 6, 19, 7,  9, 5,  1, 0, 60, 4, 27, 1, 41, 2, 21, 
    8, 72, 1, 75, 4, 20, 5, 73, 7, 92, 2, 94, 6, 86, 3, 66, 0, 54, 
    8, 93, 2, 13, 5,  4, 1, 24, 4, 62, 0, 42, 7, 27, 6, 34, 3, 54, 
    7, 61, 2, 49, 0, 59, 1, 34, 8, 83, 3, 19, 4, 45, 5, 58, 6,  8
  };
  const int q1790[] = {
    9, 9, // Number of jobs and machines
    8, 82, 4, 66, 7, 13, 0, 55, 3,  7, 2, 34, 1, 52, 5, 72, 6,  1, 
    0, 99, 1, 30, 3, 24, 6, 96, 7, 97, 4, 67, 2, 43, 8, 58, 5, 98, 
    6, 21, 7, 87, 5, 87, 3, 98, 8, 44, 4, 56, 2, 52, 0, 42, 1, 76, 
    7, 49, 2, 18, 0, 13, 5, 66, 8, 48, 6, 37, 3, 44, 1, 10, 4, 80, 
    8, 73, 0, 93, 4, 52, 1, 22, 5, 42, 3, 82, 6, 86, 7, 52, 2, 52, 
    8, 89, 7, 96, 2, 65, 6, 22, 5, 58, 1, 77, 3, 53, 0, 70, 4, 26, 
    0, 12, 6, 62, 7, 60, 2, 73, 5, 25, 1, 44, 4,  5, 3, 21, 8, 82, 
    1, 48, 3, 36, 0, 68, 8, 93, 4, 86, 7, 36, 2, 21, 5, 51, 6, 97, 
    4, 62, 5, 83, 8, 91, 2, 52, 1, 81, 7, 21, 3, 97, 0, 67, 6, 28
  };
  const int q1791[] = {
    9, 9, // Number of jobs and machines
    2, 79, 3, 53, 6, 43, 4, 32, 1, 33, 0,  7, 7, 47, 5, 94, 8, 32, 
    7, 72, 5, 44, 3, 24, 0, 73, 1, 85, 4, 56, 2, 70, 6, 91, 8, 56, 
    3, 87, 4, 97, 0, 85, 7,  7, 8, 62, 6, 53, 1, 81, 5, 59, 2, 16, 
    4, 79, 7, 90, 2, 40, 8, 21, 1, 97, 0,  9, 6, 46, 5, 13, 3, 33, 
    1, 17, 8, 41, 7, 69, 2, 55, 4, 73, 0, 46, 5, 55, 6, 51, 3, 21, 
    4, 70, 1, 42, 2, 63, 8, 12, 5, 69, 7, 76, 0,  1, 3, 81, 6, 90, 
    8, 86, 2, 82, 7, 47, 0, 90, 3, 76, 4, 81, 5, 35, 6, 54, 1,  9, 
    8, 82, 3, 65, 2,  1, 4, 93, 0, 16, 6, 38, 5, 26, 1, 63, 7, 10, 
    8, 52, 2, 42, 0, 99, 6, 59, 7, 18, 4, 86, 3, 87, 5, 58, 1, 63
  };
  const int q1792[] = {
    9, 9, // Number of jobs and machines
    1, 26, 3, 56, 0, 94, 6, 23, 2, 41, 5, 10, 8,  3, 7, 46, 4, 72, 
    0,  5, 6, 31, 2, 78, 8,  2, 3,  8, 1, 26, 4, 88, 7, 20, 5, 16, 
    6, 97, 7, 49, 1, 35, 4, 46, 0, 34, 5, 29, 3, 25, 8, 35, 2, 15, 
    4, 34, 5, 43, 1, 85, 8, 92, 6, 86, 3,  2, 7, 80, 2, 80, 0, 52, 
    6, 85, 8, 28, 3, 53, 5, 47, 2, 66, 1, 79, 0, 75, 4, 82, 7, 20, 
    0, 86, 1, 46, 5, 12, 2, 54, 3,  7, 4,  4, 6, 52, 8, 72, 7, 23, 
    0, 39, 5, 73, 4, 36, 3, 78, 7, 25, 8,  2, 2, 80, 6, 42, 1, 57, 
    4,  6, 3, 30, 6, 36, 1, 93, 7, 33, 8, 92, 2, 31, 5,  3, 0, 80, 
    3, 16, 7, 42, 4, 95, 2, 14, 0, 15, 5, 89, 6, 16, 1, 44, 8, 22
  };
  const int q1793[] = {
    9, 9, // Number of jobs and machines
    6, 95, 3, 48, 2, 13, 8, 92, 4, 50, 1, 48, 0, 82, 7, 75, 5, 25, 
    0, 52, 2, 44, 6, 68, 4,  5, 1, 83, 3, 10, 5, 74, 8, 28, 7, 57, 
    8, 27, 4, 33, 2, 66, 0, 48, 1, 10, 7, 27, 3, 93, 5, 26, 6, 21, 
    8, 23, 5, 74, 3, 92, 1, 29, 7, 71, 2, 64, 0, 34, 4, 78, 6, 56, 
    5, 11, 7, 86, 1, 43, 0, 13, 6,  3, 2, 30, 4,  3, 3, 52, 8, 75, 
    4, 63, 1, 11, 5,  3, 7, 59, 8, 38, 2, 82, 0, 28, 3, 77, 6, 48, 
    3, 40, 1, 90, 0, 11, 6, 16, 2, 18, 4, 38, 8, 85, 7, 37, 5, 38, 
    7, 44, 6, 12, 1, 26, 5, 22, 2,  1, 3, 70, 8, 85, 4,  7, 0,  4, 
    8,  5, 5, 66, 2, 28, 6, 89, 0, 12, 3, 86, 4, 98, 7, 97, 1, 76
  };
  const int q1794[] = {
    9, 9, // Number of jobs and machines
    5, 18, 8, 73, 0, 41, 7, 85, 3, 61, 4, 76, 6, 23, 1, 40, 2, 77, 
    2,  4, 6, 27, 1,  5, 3,  6, 5, 19, 8, 86, 7, 93, 0, 68, 4, 96, 
    6, 66, 7, 46, 3, 59, 0, 30, 8, 44, 1, 45, 4, 26, 2, 47, 5, 13, 
    5, 98, 2, 41, 0, 39, 1, 76, 4, 20, 6, 66, 3, 69, 8, 38, 7, 11, 
    4, 77, 0,  6, 6, 53, 3, 46, 8, 95, 5, 71, 2, 89, 1, 96, 7, 10, 
    0, 14, 7, 51, 2, 88, 6, 80, 8, 40, 5,  9, 3, 20, 1, 86, 4, 51, 
    6, 74, 3, 57, 5, 73, 2, 90, 4, 20, 0, 38, 7, 22, 8, 20, 1, 72, 
    2, 52, 8, 64, 5, 96, 0, 54, 1, 95, 7,  9, 3,  2, 6, 14, 4, 64, 
    3, 22, 2, 54, 7, 64, 6, 29, 8,  4, 5, 44, 0, 49, 1,  9, 4, 58
  };
  const int q1795[] = {
    9, 9, // Number of jobs and machines
    5, 92, 2, 26, 6, 81, 4, 65, 1, 22, 0, 85, 3, 32, 7, 82, 8, 49, 
    5,  1, 7, 22, 6, 69, 0, 52, 8, 78, 3, 58, 1, 40, 4, 77, 2,  8, 
    6, 20, 8, 77, 5, 49, 1, 55, 4, 14, 7, 39, 3, 98, 2, 27, 0, 82, 
    8, 71, 1,  7, 7, 55, 5, 32, 0, 38, 3, 15, 6, 56, 2, 22, 4, 12, 
    2, 70, 7, 67, 0, 97, 4, 42, 5, 70, 8, 23, 6, 37, 1, 94, 3, 28, 
    1, 73, 2, 24, 7, 89, 3, 86, 5, 55, 4, 19, 8, 45, 6, 41, 0, 64, 
    0, 89, 4,  4, 1, 56, 7, 98, 6, 43, 3, 76, 2, 58, 8, 46, 5, 27, 
    1, 44, 7, 38, 6, 21, 3, 81, 5, 90, 2, 71, 0, 39, 4, 89, 8, 64, 
    1, 63, 0, 78, 3, 14, 6, 70, 4, 89, 2, 62, 8, 34, 5, 50, 7, 46
  };
  const int q1796[] = {
    9, 9, // Number of jobs and machines
    7, 88, 2, 31, 6, 34, 1,  9, 3, 77, 8, 10, 0, 38, 4, 13, 5,  7, 
    0, 11, 2, 78, 1, 97, 5, 60, 4, 79, 3, 89, 7, 73, 8, 90, 6, 93, 
    0, 69, 4, 31, 1, 53, 7, 22, 2, 11, 3, 31, 6, 41, 8, 91, 5, 85, 
    0,  4, 8, 34, 6, 81, 4, 88, 5,  5, 3, 39, 1, 81, 2, 79, 7, 62, 
    0, 99, 5, 32, 8,  8, 4,  3, 2, 74, 3, 52, 1, 45, 6, 52, 7, 27, 
    7, 73, 5,  3, 3, 79, 2, 10, 4, 45, 8, 54, 6, 78, 1, 99, 0, 17, 
    5, 99, 0, 77, 2, 95, 3,  2, 1, 63, 4, 39, 6, 19, 8, 95, 7, 18, 
    0, 56, 6, 56, 4, 80, 2, 89, 3, 41, 5, 19, 8, 47, 7, 64, 1, 65, 
    0, 66, 6,  5, 1, 24, 2, 26, 7, 48, 4, 22, 5, 66, 8, 88, 3, 77
  };
  const int q1797[] = {
    9, 9, // Number of jobs and machines
    0, 66, 4, 98, 2, 20, 6, 47, 1, 21, 8, 60, 5, 54, 3, 77, 7,  8, 
    5, 77, 1, 19, 6, 61, 7, 34, 3, 69, 2, 73, 0, 45, 8, 57, 4, 18, 
    7, 29, 1, 90, 4, 92, 6, 92, 0, 42, 8, 73, 5,  7, 3, 45, 2, 42, 
    7, 40, 3, 62, 1, 61, 6, 72, 4, 72, 8, 81, 0, 63, 2,  2, 5, 53, 
    6, 26, 2, 25, 8, 90, 7, 67, 5, 14, 4, 59, 1, 87, 0, 43, 3, 75, 
    4,  3, 2, 61, 3, 69, 6, 42, 0, 18, 1, 35, 7, 24, 8, 37, 5,  9, 
    4, 17, 1, 96, 3, 35, 0, 19, 8, 28, 5, 44, 6, 43, 2, 80, 7, 41, 
    7, 77, 1, 40, 4, 55, 5, 27, 2, 91, 6, 84, 3, 43, 8, 85, 0, 18, 
    5, 44, 0, 52, 4, 82, 6, 38, 3, 92, 8, 45, 2, 45, 7, 91, 1, 42
  };
  const int q1798[] = {
    9, 9, // Number of jobs and machines
    1, 36, 2, 72, 0, 54, 4, 51, 8, 81, 7, 57, 6, 29, 5, 27, 3, 28, 
    4, 13, 7, 54, 8, 58, 6, 64, 0, 38, 3, 25, 5, 74, 2, 96, 1, 29, 
    6, 43, 3, 43, 4, 66, 0, 22, 5,  3, 8, 40, 2, 46, 7, 15, 1, 90, 
    5,  3, 2, 13, 8, 54, 1, 86, 6, 72, 7, 53, 3, 44, 0, 66, 4, 17, 
    7, 20, 6, 95, 1, 21, 2, 98, 3, 43, 5, 52, 4, 15, 8, 48, 0, 68, 
    4,  8, 5,  6, 3, 91, 0, 10, 8,  6, 1, 77, 2, 81, 6, 31, 7, 49, 
    8, 97, 6, 40, 0, 67, 5, 11, 7, 77, 2, 97, 1, 67, 4, 50, 3, 99, 
    5,  7, 3, 51, 6,  8, 7, 18, 8, 21, 4, 63, 1, 58, 0,  2, 2, 29, 
    1, 93, 2, 82, 6, 93, 3, 68, 4, 10, 0, 35, 8, 68, 5, 10, 7, 53
  };
  const int q1799[] = {
    9, 9, // Number of jobs and machines
    1, 90, 2, 94, 0,  5, 5, 13, 8, 60, 7, 33, 3, 82, 6, 46, 4, 10, 
    1, 89, 8, 58, 2, 85, 7, 71, 3, 45, 4, 54, 6, 64, 5, 69, 0,  8, 
    1, 17, 3, 34, 7, 85, 5, 34, 6, 95, 0, 36, 4, 56, 2, 31, 8, 37, 
    1, 24, 7, 50, 8, 43, 4, 84, 6, 77, 3, 16, 0, 47, 5,  2, 2, 21, 
    6, 70, 2, 50, 8, 86, 3, 83, 1, 78, 0, 44, 5, 74, 7, 29, 4, 18, 
    5, 83, 3, 36, 6, 79, 1, 66, 7, 16, 0, 50, 4, 31, 2, 72, 8, 87, 
    6, 25, 0, 15, 5, 13, 1, 47, 8, 72, 3, 32, 2, 83, 7, 93, 4, 86, 
    1, 78, 7, 41, 3, 48, 5, 10, 4, 71, 8,  3, 0, 79, 6, 98, 2, 33, 
    8, 44, 3,  2, 0, 37, 4, 34, 6, 86, 5, 21, 1, 76, 7, 47, 2, 29
  };
  const int q1800[] = {
    9, 9, // Number of jobs and machines
    3, 77, 5, 81, 2, 79, 1,  7, 8, 75, 7, 90, 0, 29, 4, 72, 6, 65, 
    4, 31, 0, 32, 8, 39, 3, 32, 6, 56, 5, 26, 1, 68, 7, 57, 2, 43, 
    5, 20, 3, 92, 4, 58, 0, 63, 1, 59, 7, 76, 8, 76, 2, 15, 6, 66, 
    6, 22, 0, 59, 4, 16, 8, 11, 7, 97, 3, 13, 2, 35, 5, 17, 1, 76, 
    2, 96, 6, 24, 3, 29, 8, 51, 0, 49, 7, 77, 5, 37, 1, 94, 4, 28, 
    2, 45, 6, 34, 0, 67, 1, 42, 4, 22, 7, 87, 8,  6, 3, 78, 5, 58, 
    1, 26, 6, 88, 4, 49, 3, 67, 2, 43, 7, 13, 0, 25, 5, 89, 8,  1, 
    6, 76, 3, 84, 0,  3, 7,  1, 4, 66, 1,  7, 8, 84, 5, 21, 2, 73, 
    2, 18, 5,  2, 0, 26, 1, 13, 4, 70, 7, 33, 3, 49, 6, 12, 8, 16
  };
  const int q1801[] = {
    9, 9, // Number of jobs and machines
    5, 38, 3, 35, 4, 24, 2, 98, 6,  2, 7, 49, 0, 46, 1, 47, 8, 61, 
    8, 32, 7, 93, 5, 87, 4, 35, 6, 54, 3, 48, 1, 67, 0, 60, 2, 25, 
    7, 57, 8, 26, 0, 20, 2, 15, 5, 66, 1, 27, 6, 51, 4, 86, 3, 37, 
    7, 35, 1, 94, 3, 38, 0, 58, 5, 18, 4, 56, 6, 55, 2, 39, 8, 97, 
    3, 44, 4,  6, 8, 80, 5, 12, 0, 65, 7, 89, 6, 82, 1, 41, 2,  7, 
    3, 80, 7, 11, 1, 20, 4,  3, 8, 63, 6, 23, 5, 27, 0, 99, 2, 48, 
    4, 10, 8, 45, 3, 43, 2,  8, 5,  3, 1, 66, 6, 21, 7, 13, 0, 99, 
    6, 57, 0, 52, 8, 63, 1, 10, 2, 13, 4, 87, 5, 24, 3, 65, 7, 86, 
    6, 43, 5, 57, 7, 58, 2, 58, 8, 26, 3, 88, 1, 23, 4, 73, 0, 66
  };
  const int q1802[] = {
    9, 9, // Number of jobs and machines
    6, 44, 2, 78, 4, 50, 3, 58, 8, 21, 7, 25, 5, 29, 0,  8, 1, 40, 
    1, 32, 4, 38, 8, 87, 7, 58, 0, 27, 2, 35, 3, 78, 5, 43, 6, 18, 
    2,  8, 7, 16, 1,  7, 6,  6, 8, 70, 4, 74, 3, 20, 5, 64, 0, 10, 
    8, 65, 2, 25, 6, 53, 5, 66, 4, 83, 3, 85, 0, 92, 7,  7, 1, 35, 
    4, 18, 6, 19, 2, 41, 7, 88, 1, 44, 8, 35, 5,  7, 0, 42, 3, 95, 
    8,  7, 6,  5, 5, 69, 7, 52, 4, 48, 2, 39, 0, 18, 1, 99, 3, 50, 
    5, 67, 8, 65, 6, 27, 3,  9, 7, 29, 4, 20, 0, 96, 2, 87, 1, 39, 
    1, 73, 6, 92, 8, 38, 2, 80, 5, 58, 0, 92, 4, 33, 7, 51, 3, 92, 
    7, 29, 3, 28, 5, 39, 6, 38, 2, 85, 0, 27, 4, 76, 8, 82, 1, 89
  };
  const int q1803[] = {
    9, 9, // Number of jobs and machines
    1,  5, 0, 24, 8, 56, 6, 87, 4, 18, 7, 34, 2, 38, 5, 13, 3, 16, 
    6, 11, 2, 35, 8, 47, 3, 26, 1, 90, 7, 79, 4, 71, 0, 70, 5, 15, 
    0, 73, 7, 97, 6, 39, 8, 30, 3, 18, 5,  6, 1,  1, 4, 82, 2, 41, 
    5, 18, 6,  8, 7, 25, 8, 72, 4, 40, 2, 35, 0, 98, 3, 52, 1, 79, 
    5, 23, 3, 14, 7, 64, 0, 16, 8, 50, 1,  1, 6, 13, 4, 95, 2, 13, 
    3, 90, 0, 60, 5, 23, 7, 42, 2, 58, 6, 60, 8, 32, 1, 93, 4, 44, 
    0,  8, 1, 86, 6, 18, 3, 91, 8, 95, 7, 67, 4, 34, 2, 17, 5, 59, 
    2, 95, 3, 33, 0, 38, 6, 70, 8, 31, 1, 87, 7, 52, 4, 26, 5, 88, 
    3, 52, 1, 11, 7, 81, 6, 77, 4, 53, 5, 12, 0, 92, 8, 32, 2, 74
  };
  const int q1804[] = {
    9, 9, // Number of jobs and machines
    6, 84, 2, 18, 1, 20, 7, 30, 8,  8, 4, 16, 5, 83, 3, 23, 0, 86, 
    1, 92, 2, 83, 6, 63, 7, 73, 8,  3, 3, 41, 5, 60, 4, 56, 0, 70, 
    5, 52, 2, 31, 0, 91, 4, 67, 6, 14, 8, 70, 1, 60, 3, 41, 7, 67, 
    5, 81, 2, 84, 6, 94, 8, 12, 4, 65, 0, 86, 7,  3, 1, 52, 3, 46, 
    1,  5, 3, 55, 0, 98, 2, 24, 7, 88, 5, 91, 6, 22, 8, 23, 4, 12, 
    6, 96, 2, 12, 5, 75, 3, 70, 1, 60, 4, 35, 7, 83, 8, 35, 0, 31, 
    6, 12, 0, 91, 3, 11, 8, 12, 2, 72, 4, 36, 1, 43, 7, 33, 5, 12, 
    5, 23, 7, 91, 2, 53, 6, 81, 4, 40, 8, 87, 0, 54, 1, 21, 3, 15, 
    2, 84, 6, 27, 0, 38, 3,  5, 7, 95, 8,  1, 5, 37, 4, 46, 1,  6
  };
  const int q1805[] = {
    9, 9, // Number of jobs and machines
    4, 57, 2, 28, 0, 18, 7, 61, 1, 26, 6, 37, 8,  1, 3,  6, 5, 52, 
    3, 33, 8, 71, 0, 38, 7, 82, 5, 54, 2, 45, 4, 33, 6, 84, 1, 20, 
    6, 50, 7, 91, 2, 25, 3, 37, 0, 43, 5, 11, 1, 41, 8, 27, 4, 75, 
    5, 63, 6, 75, 4, 32, 1, 90, 2, 66, 8, 54, 0, 56, 7, 85, 3, 67, 
    3, 76, 5, 60, 1, 85, 2, 72, 0,  1, 7, 74, 6, 55, 8, 84, 4, 51, 
    5,  3, 1, 14, 6, 92, 4, 19, 0, 92, 8, 98, 2, 62, 7, 71, 3, 97, 
    3, 61, 0, 26, 1, 34, 8, 23, 5, 43, 2, 62, 4, 95, 6, 88, 7, 16, 
    7, 58, 2, 30, 1, 54, 6, 18, 5, 23, 3, 13, 4, 78, 0, 79, 8, 46, 
    2, 73, 3, 25, 8, 28, 5, 57, 6, 67, 4, 70, 1, 66, 0, 86, 7, 78
  };
  const int q1806[] = {
    9, 9, // Number of jobs and machines
    4, 31, 1, 68, 3, 54, 0, 30, 5, 24, 8, 91, 7, 59, 6, 49, 2, 77, 
    2, 88, 7, 75, 0, 37, 6, 36, 3, 53, 4, 40, 8, 32, 1, 96, 5, 86, 
    1, 91, 0,  9, 4,  2, 8, 82, 6, 87, 2, 22, 3, 68, 5, 32, 7, 85, 
    0, 35, 8, 89, 1,  1, 7, 78, 6, 78, 5, 85, 2, 40, 4, 72, 3, 79, 
    3, 46, 1, 26, 7, 92, 2, 11, 8, 48, 4, 15, 0, 48, 6, 18, 5, 53, 
    0, 25, 4, 15, 1, 38, 6,  9, 5, 98, 2, 69, 8, 54, 3, 43, 7, 98, 
    4, 87, 6, 18, 2, 56, 8, 23, 0,  8, 7, 25, 5, 53, 1, 30, 3, 34, 
    7, 31, 8, 32, 1, 44, 3, 95, 2, 22, 4,  6, 6, 94, 5, 84, 0, 37, 
    0, 54, 5,  9, 4, 57, 6, 23, 8, 75, 3,  7, 7, 38, 1, 86, 2, 73
  };
  const int q1807[] = {
    9, 9, // Number of jobs and machines
    8, 28, 5, 87, 2, 40, 1, 81, 6,  7, 7, 96, 4, 20, 3, 58, 0, 78, 
    4, 56, 5, 85, 0, 71, 7, 13, 8, 53, 6, 86, 3,  3, 2, 84, 1, 76, 
    2, 67, 1, 86, 7, 38, 0, 18, 8, 86, 4, 28, 5, 90, 3, 30, 6, 50, 
    2, 37, 6, 40, 3, 77, 1, 75, 5,  2, 4,  4, 7, 53, 8, 68, 0,  1, 
    0, 95, 6, 82, 4, 28, 8, 13, 2, 91, 3, 11, 7, 79, 5, 68, 1, 30, 
    5, 87, 8, 84, 4, 97, 1,  7, 7, 48, 2, 31, 3, 63, 0, 61, 6, 46, 
    1, 77, 3, 85, 0, 17, 5, 53, 2, 39, 7, 58, 4, 37, 8,  4, 6, 37, 
    4, 11, 6, 74, 1, 21, 3, 61, 0, 54, 8,  7, 7, 69, 5, 77, 2,  9, 
    5, 92, 7, 95, 1, 58, 2, 39, 4, 51, 6, 69, 0, 58, 8, 59, 3, 49
  };
  const int q1808[] = {
    9, 9, // Number of jobs and machines
    5, 81, 3, 34, 0, 13, 2, 89, 8, 33, 6, 96, 4, 18, 7, 87, 1, 88, 
    8, 47, 0, 43, 7, 16, 4, 13, 1, 40, 5, 53, 2, 34, 6, 49, 3, 48, 
    3, 33, 8, 69, 7, 68, 4, 40, 0, 22, 5, 46, 1, 63, 6, 43, 2, 10, 
    0, 64, 3, 17, 6, 98, 5, 74, 1, 56, 7,  7, 2, 67, 4, 41, 8, 58, 
    2, 96, 4,  6, 3, 98, 7, 69, 0, 96, 5, 65, 6, 80, 8, 14, 1, 73, 
    2, 23, 6,  1, 3, 70, 4, 35, 8, 40, 1, 14, 5, 42, 0, 72, 7, 61, 
    2, 28, 1, 69, 6,  9, 3, 22, 7, 50, 5, 71, 4, 39, 8, 74, 0, 50, 
    6, 55, 4, 82, 5,  4, 8, 34, 0, 22, 2, 92, 3, 91, 7, 30, 1, 33, 
    6, 55, 8, 78, 5, 61, 2, 33, 0, 91, 3, 55, 7, 97, 1, 57, 4, 26
  };
  const int q1809[] = {
    9, 9, // Number of jobs and machines
    1, 62, 8, 38, 2, 13, 6, 19, 4, 76, 0,  6, 5, 65, 3, 81, 7, 79, 
    5, 61, 3, 54, 1, 85, 6, 11, 8, 93, 7, 98, 0, 21, 4, 43, 2, 35, 
    3,  7, 6, 73, 8, 11, 4,  6, 2, 68, 7, 95, 1, 86, 0, 76, 5, 42, 
    2, 94, 7, 52, 1,  2, 3, 62, 8, 22, 5, 62, 0, 98, 4, 65, 6, 97, 
    0, 28, 5, 84, 7, 92, 6, 22, 4, 81, 2, 33, 3, 61, 1, 67, 8, 24, 
    4, 58, 5, 74, 6, 32, 8, 88, 0,  6, 2, 42, 7, 52, 1, 38, 3, 80, 
    2, 25, 7, 38, 8, 64, 1,  6, 6, 19, 3, 44, 0, 45, 5, 40, 4, 64, 
    4, 94, 8, 46, 6, 69, 1, 89, 0, 99, 2, 76, 3,  8, 7,  9, 5, 67, 
    0, 69, 7, 40, 2, 31, 6, 43, 5, 90, 1, 17, 4, 58, 3, 67, 8, 51
  };
  const int q1810[] = {
    9, 9, // Number of jobs and machines
    6, 23, 4, 47, 1, 13, 8, 95, 3, 83, 7, 27, 0, 13, 5, 30, 2, 28, 
    5, 27, 6,  2, 7, 18, 2, 71, 1, 26, 0, 37, 8, 76, 4, 61, 3, 56, 
    1, 99, 3, 81, 0,  3, 7, 60, 6, 67, 4, 48, 5, 33, 8, 92, 2, 13, 
    7, 51, 4, 79, 6, 69, 1, 70, 8, 23, 2, 45, 3,  6, 0, 92, 5, 23, 
    5, 81, 4, 22, 0, 58, 2, 74, 7, 48, 1, 20, 3, 76, 6, 85, 8, 63, 
    0, 74, 1,  6, 2, 29, 6, 78, 3, 55, 4, 89, 5,  2, 8, 20, 7,  5, 
    5, 28, 6, 11, 8, 96, 7,  5, 2, 27, 4, 81, 3, 74, 1, 83, 0, 46, 
    1, 68, 0, 91, 2, 85, 7, 75, 4, 51, 5, 97, 3, 31, 8, 23, 6, 18, 
    5, 25, 2,  2, 6, 62, 0,  2, 7, 61, 4, 37, 3, 56, 8, 12, 1, 32
  };
  const int q1811[] = {
    9, 9, // Number of jobs and machines
    1,  7, 7, 36, 0, 29, 4, 72, 2, 40, 3, 93, 5, 65, 6, 90, 8, 82, 
    5, 46, 8, 20, 4,  1, 6, 41, 3,  5, 2,  9, 7, 61, 1, 92, 0, 38, 
    8, 79, 6, 52, 5, 94, 0, 41, 4, 75, 3, 26, 1, 46, 2, 99, 7, 47, 
    8, 79, 3, 29, 1, 27, 5, 55, 4, 92, 6, 16, 2, 63, 0, 34, 7, 60, 
    1, 32, 0, 72, 2, 82, 7, 58, 5, 37, 6, 83, 4, 88, 8, 27, 3, 98, 
    4, 59, 3, 97, 6, 27, 1, 80, 2, 62, 7, 10, 8, 91, 5,  2, 0, 41, 
    5, 23, 4, 36, 8, 73, 6,  3, 3, 83, 0, 49, 7, 28, 1, 44, 2, 72, 
    2, 43, 8, 54, 4, 35, 6, 44, 5, 24, 1, 91, 0, 47, 3, 60, 7, 65, 
    1, 81, 3, 34, 4,  1, 2,  9, 8, 79, 6, 23, 0, 77, 5, 72, 7, 92
  };
  const int q1812[] = {
    9, 9, // Number of jobs and machines
    2, 33, 4, 26, 8, 12, 0, 84, 6, 84, 7, 46, 1, 29, 5, 85, 3, 66, 
    3,  6, 7, 10, 6,  8, 0, 66, 5,  7, 1,  9, 2, 13, 8, 71, 4, 71, 
    7, 66, 4, 82, 8, 72, 1, 98, 6, 36, 2, 20, 0, 36, 5, 28, 3, 81, 
    4, 23, 0, 99, 3, 13, 7, 72, 1, 14, 6, 11, 2, 68, 5,  8, 8, 64, 
    6, 37, 1, 55, 4, 99, 8, 28, 3,  8, 7, 44, 2, 21, 5, 28, 0, 30, 
    8, 39, 5, 74, 2, 60, 4, 66, 3, 20, 0, 52, 6, 95, 7, 63, 1, 70, 
    7, 50, 3, 62, 4, 91, 1, 58, 8, 77, 6, 25, 5, 39, 0, 35, 2,  4, 
    4, 67, 1, 41, 0, 27, 5,  5, 7, 87, 8, 65, 6, 85, 3, 56, 2, 28, 
    8, 16, 1, 60, 0, 20, 4,  1, 7, 84, 6, 89, 3, 40, 2, 52, 5, 84
  };
  const int q1813[] = {
    9, 9, // Number of jobs and machines
    4, 54, 3,  3, 7, 13, 2, 80, 5, 31, 8, 20, 6, 66, 1, 81, 0, 85, 
    6,  5, 5, 93, 1, 21, 8, 74, 7, 51, 4, 28, 2, 34, 0, 15, 3, 73, 
    2, 92, 7, 18, 1, 34, 3, 59, 8, 74, 5, 23, 4, 73, 6, 17, 0, 41, 
    6, 62, 4, 80, 7, 83, 2, 85, 8, 91, 1, 39, 5, 29, 0, 66, 3, 55, 
    3,  1, 0,  4, 8, 68, 5, 47, 7, 19, 1, 78, 4,  3, 6, 44, 2, 23, 
    2, 67, 3, 63, 7, 44, 0, 19, 4, 41, 6, 37, 1,  7, 5,  9, 8, 21, 
    4, 49, 1, 76, 8, 52, 0, 93, 7, 56, 2, 15, 6, 32, 5, 37, 3, 19, 
    7, 56, 6, 34, 4, 32, 8, 18, 2, 62, 3, 10, 5, 27, 0, 63, 1, 83, 
    3, 91, 2, 80, 0, 73, 7, 24, 6, 28, 5, 76, 4, 50, 1, 28, 8,  1
  };
  const int q1814[] = {
    9, 9, // Number of jobs and machines
    3, 80, 0, 25, 2, 62, 5, 38, 6, 69, 7, 89, 1, 14, 8, 78, 4, 28, 
    4, 11, 6, 35, 1, 13, 3, 70, 2, 92, 0, 45, 7, 28, 8, 10, 5, 66, 
    0, 43, 6, 55, 2, 94, 8, 53, 4, 21, 1, 61, 3, 81, 5, 77, 7, 49, 
    3, 88, 2, 47, 6,  2, 4, 82, 8, 77, 0, 86, 7, 99, 1, 64, 5,  1, 
    7, 26, 3,  2, 0, 56, 4, 43, 1, 51, 8, 52, 5, 28, 2, 26, 6, 23, 
    6, 67, 4, 71, 5, 42, 0, 12, 7,  4, 8, 79, 3, 90, 1, 84, 2,  3, 
    7, 13, 6, 45, 0,  1, 4, 66, 2, 41, 8, 75, 3, 75, 5, 47, 1, 95, 
    1, 40, 6, 36, 8, 67, 5, 10, 0, 99, 2, 65, 7, 36, 3, 38, 4, 36, 
    0, 44, 3, 95, 6,  5, 4, 46, 5, 88, 7, 20, 2, 89, 8, 27, 1, 16
  };
  const int q1815[] = {
    9, 9, // Number of jobs and machines
    1,  4, 4, 65, 0,  6, 7, 13, 6, 20, 5, 75, 2, 80, 8, 69, 3, 53, 
    5, 23, 2, 54, 7, 70, 1, 63, 3, 26, 0, 67, 8, 62, 4, 73, 6, 76, 
    7, 83, 1, 41, 6, 58, 3, 75, 2, 12, 5, 46, 4, 63, 0, 25, 8, 85, 
    0, 42, 7, 19, 5, 63, 6, 16, 1, 56, 3, 68, 4, 38, 8, 97, 2, 13, 
    5, 53, 4, 11, 7, 73, 2, 91, 6,  7, 3, 77, 8, 69, 1,  1, 0, 78, 
    4, 47, 7, 35, 3, 38, 0, 68, 2, 29, 5, 85, 8, 36, 1, 42, 6, 25, 
    7, 13, 4, 25, 1, 45, 6, 24, 0, 68, 5, 27, 8, 42, 3, 13, 2, 84, 
    0, 76, 6, 25, 1, 31, 3, 25, 4,  6, 7, 93, 8, 69, 2, 93, 5, 79, 
    8, 80, 3, 14, 4, 67, 6, 74, 5, 92, 7,  8, 0, 10, 1, 51, 2, 26
  };
  const int q1816[] = {
    9, 9, // Number of jobs and machines
    5, 36, 8, 56, 4, 22, 3, 43, 0, 78, 2, 80, 1, 49, 7, 86, 6, 42, 
    7, 71, 1, 61, 2, 54, 8, 94, 5, 88, 0, 51, 4, 59, 6, 92, 3, 99, 
    7, 18, 5, 91, 4, 62, 0, 77, 1, 25, 6, 76, 2, 30, 3, 42, 8, 56, 
    0, 88, 6, 28, 2, 27, 1, 38, 8, 60, 5, 24, 4, 12, 3, 30, 7, 90, 
    3, 61, 4,  4, 8, 87, 2, 60, 6, 27, 1,  6, 5, 88, 7, 63, 0,  1, 
    1, 97, 2, 48, 4, 48, 8, 18, 7, 16, 3, 44, 5, 92, 6,  6, 0, 52, 
    4, 85, 0, 92, 8, 49, 2, 93, 6, 38, 1, 18, 5, 72, 3, 60, 7, 93, 
    8, 27, 5, 57, 4, 76, 6, 78, 3, 40, 1, 22, 7, 43, 2, 17, 0, 24, 
    8, 86, 7, 41, 0, 96, 2,  3, 6, 45, 5, 28, 4, 42, 1, 26, 3, 75
  };
  const int q1817[] = {
    9, 9, // Number of jobs and machines
    1, 71, 8, 40, 4, 20, 0, 35, 3,  8, 2, 77, 5, 66, 6, 43, 7, 56, 
    7, 72, 8, 26, 0, 75, 2, 70, 4, 45, 3, 67, 5, 62, 1, 88, 6, 33, 
    0,  8, 6, 73, 2, 79, 5,  6, 7, 38, 1, 82, 8, 39, 4, 25, 3, 77, 
    7, 14, 4, 88, 3, 33, 1, 87, 6, 81, 0, 99, 5, 26, 2, 51, 8, 46, 
    5, 39, 2, 44, 6, 35, 3, 20, 4, 96, 7, 39, 0,  1, 8, 10, 1, 26, 
    8, 10, 3, 39, 0, 58, 2, 30, 4, 97, 1, 46, 6, 92, 5, 71, 7, 16, 
    3,  1, 6, 87, 1, 78, 7, 86, 0, 91, 8, 24, 5, 97, 4, 31, 2, 30, 
    4, 51, 1, 86, 5, 56, 3, 20, 7, 17, 2, 88, 6, 33, 8, 36, 0, 26, 
    4, 68, 3, 13, 7, 47, 6, 25, 8, 21, 1, 90, 5, 18, 2, 66, 0, 79
  };
  const int q1818[] = {
    9, 9, // Number of jobs and machines
    2, 29, 6, 67, 8, 60, 3, 15, 0, 48, 4, 91, 5, 67, 1, 29, 7, 83, 
    5, 31, 1, 10, 2, 43, 6, 43, 7, 44, 4, 46, 3, 70, 0, 52, 8, 42, 
    1, 11, 8, 54, 3, 38, 4, 37, 6, 35, 5, 49, 2, 30, 0, 72, 7, 37, 
    7, 21, 4, 42, 8, 65, 1, 51, 6, 96, 2, 60, 3, 57, 0, 70, 5, 95, 
    8, 39, 6, 35, 2, 33, 7, 38, 5, 70, 0, 87, 3, 71, 4, 16, 1, 60, 
    8, 68, 2, 85, 7, 59, 1, 75, 4, 34, 6, 50, 5, 96, 3,  5, 0, 78, 
    0, 21, 7, 61, 6, 22, 4, 95, 5,  2, 1, 21, 2, 40, 8, 41, 3, 64, 
    7, 64, 3, 87, 1, 80, 0, 66, 5, 73, 2, 41, 4, 94, 6, 36, 8, 92, 
    1, 96, 0, 70, 8, 88, 6, 85, 2, 96, 3, 22, 4, 47, 5, 77, 7, 87
  };
  const int q1819[] = {
    9, 9, // Number of jobs and machines
    0, 38, 4,  6, 6, 50, 5, 68, 2, 90, 7, 62, 3, 34, 8, 89, 1, 21, 
    5, 20, 6, 33, 4, 56, 3, 79, 8, 21, 1, 55, 7,  4, 2, 27, 0, 55, 
    1, 73, 7, 47, 0, 11, 2, 92, 6, 64, 5, 65, 4, 43, 8, 17, 3,  7, 
    5, 45, 4, 96, 3, 32, 0,  3, 7, 44, 1, 31, 8, 66, 6, 22, 2, 52, 
    5, 59, 6, 44, 3, 12, 0, 88, 7, 23, 8, 72, 4, 96, 2, 49, 1, 94, 
    8, 75, 3, 18, 7, 20, 5, 93, 2, 72, 6, 94, 0, 46, 4, 32, 1, 94, 
    7, 15, 4, 65, 2, 97, 5, 17, 6, 27, 1, 86, 0, 60, 8, 33, 3, 49, 
    4, 28, 5, 77, 1, 13, 0, 24, 6, 28, 7, 20, 2, 98, 3, 79, 8, 54, 
    1, 73, 2, 37, 4, 47, 7,  1, 0, 73, 8, 32, 5, 24, 6, 55, 3, 80
  };
  const int q1820[] = {
    9, 9, // Number of jobs and machines
    8, 13, 2, 39, 1, 93, 4, 58, 0, 63, 3, 25, 5, 30, 6, 89, 7, 99, 
    0, 87, 7, 21, 2, 63, 5, 90, 3, 71, 6, 64, 8, 50, 4, 89, 1, 69, 
    2, 55, 8, 78, 0, 82, 1, 94, 3, 31, 6, 47, 7, 88, 4, 96, 5, 44, 
    8, 28, 0, 36, 7, 41, 2,  3, 5, 27, 6, 46, 3, 44, 4,  3, 1, 93, 
    8, 82, 4, 85, 0, 95, 3, 36, 2, 27, 1, 12, 5, 28, 7, 68, 6, 52, 
    2, 63, 7, 46, 3, 65, 0, 76, 6, 82, 5, 66, 4,  1, 1, 63, 8, 70, 
    5, 31, 7, 19, 2, 38, 6, 95, 0, 45, 1, 68, 4, 50, 8, 18, 3, 52, 
    8, 59, 2, 46, 1, 86, 5, 78, 4, 74, 6, 92, 7, 74, 3, 58, 0, 43, 
    5, 99, 1, 58, 4, 82, 2, 81, 0,  7, 7, 69, 8, 83, 6, 96, 3, 41
  };
  const int q1821[] = {
    9, 9, // Number of jobs and machines
    4, 85, 0, 80, 5, 25, 1, 29, 7, 23, 3, 62, 6, 93, 8, 92, 2, 64, 
    8, 72, 2, 50, 6, 30, 3, 61, 5, 29, 0, 23, 4,  9, 7, 84, 1, 11, 
    4, 52, 6, 61, 2, 21, 5, 78, 0, 73, 3, 73, 1, 88, 7, 97, 8, 36, 
    1, 33, 6, 52, 2, 56, 4,  9, 8, 58, 0, 67, 3, 97, 7,  8, 5, 76, 
    1, 80, 3, 58, 5, 52, 4, 47, 0, 28, 7, 15, 2, 80, 8,  7, 6, 71, 
    7, 64, 5, 31, 2, 98, 8,  4, 6,  3, 4, 29, 3,  3, 1, 35, 0, 60, 
    0, 77, 6, 22, 4, 85, 7,  8, 5, 94, 1, 81, 3, 81, 2, 80, 8, 24, 
    1, 47, 2,  5, 3, 99, 8, 78, 6, 51, 0, 56, 5, 48, 7, 65, 4, 69, 
    7, 45, 2, 47, 5,  8, 6, 87, 4, 56, 3, 55, 1, 33, 0, 33, 8, 13
  };
  const int q1822[] = {
    9, 9, // Number of jobs and machines
    2, 31, 0, 79, 4, 57, 5,  1, 7,  7, 3, 42, 8, 13, 1, 47, 6, 43, 
    5, 78, 3, 75, 4, 94, 0, 88, 2,  2, 6,  1, 7, 93, 8, 48, 1, 49, 
    6, 43, 4, 61, 3, 92, 8, 56, 2, 27, 0, 45, 1, 98, 7, 99, 5, 43, 
    2, 80, 6,  5, 4, 49, 8, 79, 7, 49, 1, 46, 0, 46, 5, 13, 3, 63, 
    8, 64, 6, 61, 5, 78, 7, 19, 4, 97, 2, 79, 1, 14, 0, 12, 3, 88, 
    5, 27, 8,  6, 3, 15, 2, 30, 7, 37, 1, 30, 0, 86, 6, 29, 4, 60, 
    2, 26, 8, 18, 1, 88, 7, 80, 6, 75, 5, 70, 4, 57, 3, 52, 0, 82, 
    5, 79, 7, 82, 2, 74, 4, 73, 6, 68, 1, 16, 8, 76, 3, 68, 0, 91, 
    7, 16, 8, 12, 1, 63, 6,  5, 0, 12, 2,  3, 3, 19, 4, 49, 5, 49
  };
  const int q1823[] = {
    9, 9, // Number of jobs and machines
    8, 50, 3, 53, 2, 74, 4, 26, 7, 28, 0, 10, 5, 17, 6,  4, 1, 81, 
    4, 24, 5, 81, 2, 48, 1, 29, 6, 83, 8, 70, 3,  2, 0, 99, 7, 86, 
    6, 57, 4, 45, 1, 20, 8, 75, 3, 32, 7, 53, 5, 37, 2, 55, 0, 57, 
    3, 71, 1, 67, 6, 77, 5, 91, 4, 50, 7, 19, 8, 58, 2, 92, 0, 37, 
    0, 58, 4, 81, 8, 65, 6, 96, 5, 94, 3, 28, 7, 73, 2,  2, 1, 89, 
    6, 86, 8, 62, 3, 82, 7, 30, 2, 32, 1, 15, 4, 39, 5, 51, 0, 54, 
    2, 75, 4, 60, 5, 67, 3, 96, 0, 80, 6, 32, 8, 39, 7, 78, 1, 36, 
    7,  4, 1, 45, 6, 75, 4, 51, 0, 77, 2, 99, 5, 36, 8, 61, 3, 77, 
    5, 40, 7, 45, 3, 51, 4, 70, 8, 69, 2, 83, 0, 96, 1, 24, 6, 34
  };
  const int q1824[] = {
    9, 9, // Number of jobs and machines
    5, 82, 0, 72, 8, 98, 7, 77, 6, 13, 4, 29, 1, 48, 3, 87, 2, 26, 
    7, 59, 6,  3, 4, 97, 8, 11, 5, 13, 3, 59, 1, 89, 2, 90, 0, 41, 
    3,  7, 2, 98, 0, 20, 6, 15, 5, 14, 8,  2, 7, 20, 4, 30, 1, 22, 
    5, 44, 4,  6, 0, 13, 3, 91, 2, 81, 7, 60, 1, 53, 6, 37, 8, 92, 
    0, 24, 6, 46, 8, 12, 2, 90, 5, 62, 3, 20, 4, 54, 7, 49, 1, 20, 
    2, 47, 4, 75, 8, 30, 0,  3, 6, 21, 7, 43, 5, 95, 1, 35, 3, 86, 
    4, 98, 3, 89, 8, 13, 1,  5, 0, 80, 2, 27, 6, 87, 7, 60, 5, 70, 
    0, 53, 4, 23, 8,  6, 6, 93, 3, 16, 2, 21, 1, 37, 5, 15, 7, 55, 
    3, 23, 8, 42, 5, 80, 1, 22, 6,  3, 7, 39, 4, 46, 0, 39, 2, 95
  };
  const int q1825[] = {
    9, 9, // Number of jobs and machines
    3, 77, 0, 84, 6, 98, 4,  3, 5, 20, 7, 41, 8, 97, 2, 71, 1, 48, 
    2, 92, 8, 94, 6, 63, 3, 55, 1, 89, 7, 42, 0, 34, 4, 88, 5, 33, 
    4, 54, 0,  1, 7,  8, 1, 57, 6, 26, 5, 26, 8, 18, 3, 69, 2, 98, 
    0, 79, 2,  2, 7, 77, 3, 36, 5, 40, 6, 98, 8, 37, 4, 91, 1, 74, 
    8, 86, 6, 36, 5, 10, 4, 93, 0,  6, 3, 35, 7, 66, 1, 61, 2, 77, 
    1, 45, 6, 52, 7, 96, 4, 95, 3, 46, 8, 46, 0,  1, 5, 58, 2, 39, 
    4, 36, 1, 91, 5, 51, 8, 51, 6, 50, 3, 97, 0, 11, 2, 92, 7, 18, 
    0, 37, 3, 94, 1, 46, 5,  5, 7, 88, 4, 42, 2, 31, 6, 44, 8, 64, 
    5, 60, 7,  2, 8, 11, 6, 53, 1, 47, 2, 42, 4, 40, 3,  3, 0, 95
  };
  const int q1826[] = {
    9, 9, // Number of jobs and machines
    7, 42, 1, 53, 0,  9, 5,  1, 8, 64, 2, 80, 3, 25, 6, 42, 4, 25, 
    1, 37, 6,  4, 7, 95, 2, 62, 0, 23, 4, 91, 8, 97, 5,  7, 3, 79, 
    2, 48, 4, 43, 3, 84, 7, 52, 8, 43, 6, 30, 0, 67, 1, 40, 5, 34, 
    5, 75, 7, 51, 4, 86, 3, 84, 2, 78, 8, 14, 6, 30, 1, 39, 0, 30, 
    0, 82, 1, 71, 4, 89, 6, 32, 2, 23, 3,  4, 5, 24, 7, 38, 8, 70, 
    5, 71, 6, 33, 0, 29, 4, 98, 8, 44, 2,  9, 1,  3, 7,  5, 3, 56, 
    8, 80, 0, 22, 1, 62, 2, 74, 6,  9, 4, 61, 3, 16, 7, 51, 5,  4, 
    6, 47, 8, 40, 5, 28, 1, 19, 4, 43, 3, 99, 2, 86, 7, 60, 0, 91, 
    2, 23, 6, 46, 8, 58, 5, 41, 4, 63, 0, 77, 1, 85, 3, 78, 7, 58
  };
  const int q1827[] = {
    9, 9, // Number of jobs and machines
    0, 96, 8, 70, 2, 17, 3, 98, 1, 92, 6,  6, 5, 28, 7, 89, 4, 60, 
    3,  8, 7, 41, 0,  8, 5, 98, 4,  2, 2, 29, 6, 71, 1, 88, 8, 12, 
    5, 79, 3, 51, 6, 60, 8,  9, 1, 93, 2, 32, 4,  3, 7, 41, 0,  7, 
    8, 85, 7, 33, 5, 40, 4, 55, 2, 19, 1, 82, 6, 66, 3, 19, 0, 14, 
    1, 18, 3, 49, 4, 48, 0, 71, 2,  1, 5, 19, 8, 19, 6, 70, 7, 38, 
    2, 26, 4, 67, 1, 28, 8, 15, 5, 10, 3, 83, 0, 50, 6, 59, 7,  4, 
    6, 17, 0, 51, 8,  6, 5, 18, 4, 91, 2, 44, 3, 65, 7, 73, 1,  1, 
    6, 13, 2, 66, 3, 96, 0, 45, 1, 98, 7, 21, 8, 61, 5, 40, 4, 67, 
    1, 90, 6, 15, 0,  6, 5, 94, 8, 90, 2, 44, 4, 93, 7, 87, 3, 15
  };
  const int q1828[] = {
    9, 9, // Number of jobs and machines
    3,  7, 2, 59, 4,  4, 8, 95, 6, 26, 1,  9, 7, 39, 5, 41, 0, 82, 
    4, 76, 2, 85, 8, 63, 1, 77, 6, 32, 0,  6, 3, 54, 5, 48, 7, 97, 
    2, 73, 7, 43, 1, 70, 3, 44, 8, 32, 0, 62, 4, 74, 6, 54, 5, 58, 
    5, 29, 1, 76, 8, 56, 3, 69, 7, 41, 0, 47, 2, 53, 4, 16, 6, 72, 
    8, 87, 6, 50, 5, 24, 3, 69, 2, 12, 0, 93, 1, 57, 7, 76, 4, 65, 
    2, 63, 4, 84, 7, 51, 5, 60, 6, 58, 0, 94, 3, 63, 8, 15, 1, 18, 
    7, 50, 0, 33, 1, 49, 3, 10, 6, 10, 4, 40, 8, 96, 2, 87, 5, 75, 
    8, 43, 5, 29, 6, 96, 1, 49, 2, 72, 0, 98, 3,  8, 4, 10, 7, 88, 
    6, 56, 0, 15, 7, 16, 2, 56, 3,  9, 8, 11, 4, 47, 1, 65, 5, 87
  };
  const int q1829[] = {
    9, 9, // Number of jobs and machines
    1, 17, 3, 65, 0, 55, 7, 56, 8, 76, 5, 79, 4, 74, 2, 66, 6, 50, 
    1, 90, 6,  8, 4, 83, 2, 38, 0, 88, 8, 78, 3, 24, 5, 30, 7,  7, 
    8, 46, 6,  7, 4, 15, 5, 66, 2, 47, 7,  3, 1, 64, 3, 43, 0, 91, 
    5, 12, 4, 28, 7,  3, 6, 12, 0, 46, 3, 77, 1, 56, 8, 57, 2, 17, 
    1, 53, 2, 75, 8, 48, 0, 89, 7, 26, 4,  9, 6, 55, 5, 30, 3, 27, 
    6, 68, 7, 12, 4, 88, 3,  8, 1, 31, 5, 29, 0, 50, 2, 11, 8, 76, 
    1, 84, 0, 96, 3,  2, 2,  4, 8,  8, 4,  8, 5, 97, 7, 18, 6, 36, 
    8, 11, 3, 98, 4, 16, 5, 31, 1, 94, 0, 19, 7, 76, 2, 60, 6, 54, 
    0, 61, 7,  3, 4, 51, 6, 40, 5, 43, 3, 37, 1,  6, 2, 54, 8, 76
  };
  const int q1830[] = {
    9, 9, // Number of jobs and machines
    3, 86, 6, 18, 5, 68, 8, 70, 2, 70, 7, 72, 4, 26, 1, 37, 0, 13, 
    5, 75, 1, 32, 7, 51, 2, 59, 0, 74, 3, 80, 6,  9, 8, 49, 4, 52, 
    3, 11, 4, 26, 7, 39, 6, 43, 2, 94, 8, 29, 1, 55, 0, 61, 5, 41, 
    5, 67, 7,  1, 1,  7, 4, 83, 6, 11, 8, 42, 2, 51, 0, 65, 3, 45, 
    5, 98, 7, 58, 6, 54, 2,  3, 3, 19, 8, 34, 0, 40, 4, 77, 1, 90, 
    8,  7, 4, 80, 1, 27, 7, 24, 0, 31, 6, 16, 2, 18, 3, 54, 5, 88, 
    6, 68, 7, 55, 5, 23, 2, 79, 8, 73, 1, 49, 3, 87, 0, 90, 4, 66, 
    2, 41, 7, 29, 1, 70, 4, 87, 5, 30, 6, 12, 0, 77, 3, 71, 8, 36, 
    0, 76, 2, 91, 5,  6, 3, 31, 7,  7, 1, 14, 4, 88, 8, 23, 6,  9
  };
  const int q1831[] = {
    9, 9, // Number of jobs and machines
    1, 69, 2, 19, 3, 92, 5, 59, 8, 83, 6, 69, 0, 49, 4, 71, 7, 80, 
    1, 70, 0, 22, 6, 10, 5, 48, 2, 39, 4, 47, 3, 19, 8, 27, 7, 26, 
    6, 80, 3, 48, 4, 72, 8, 49, 5, 14, 7, 30, 0, 43, 1, 44, 2, 27, 
    8, 37, 2, 64, 4, 15, 1, 54, 3, 43, 0, 84, 7, 92, 6, 31, 5,  9, 
    6,  5, 3, 26, 5, 28, 7, 47, 0,  5, 2, 96, 1, 72, 8, 62, 4, 17, 
    7, 94, 4, 33, 3, 78, 8, 48, 6, 25, 0, 33, 2, 57, 5, 17, 1,  8, 
    1, 39, 8, 56, 0, 49, 3, 80, 6, 59, 5, 68, 2, 75, 4,  6, 7, 75, 
    6, 14, 4, 10, 8, 28, 3, 83, 1, 76, 7, 87, 5, 97, 0, 22, 2,  9, 
    0,  8, 6, 18, 5, 20, 7, 41, 3, 94, 8, 42, 1, 58, 4, 12, 2, 20
  };
  const int q1832[] = {
    9, 9, // Number of jobs and machines
    0, 34, 2, 12, 4, 67, 8, 90, 7, 90, 3, 49, 6, 94, 1, 37, 5, 23, 
    2, 42, 6, 83, 0, 19, 7,  4, 1, 72, 8, 56, 5, 87, 4, 23, 3, 51, 
    1, 67, 0, 84, 6, 58, 2, 77, 5, 54, 3, 83, 8, 97, 4, 92, 7, 91, 
    6, 31, 3, 22, 4, 57, 2, 22, 0, 23, 8, 19, 7, 25, 1, 80, 5, 49, 
    2, 67, 0, 68, 8, 40, 6, 42, 7, 57, 4, 85, 1, 86, 5, 31, 3, 51, 
    7, 45, 2, 60, 0, 90, 4, 37, 8, 52, 3, 40, 1, 98, 5, 13, 6, 23, 
    0, 39, 2, 30, 4, 30, 5, 72, 6, 34, 7, 68, 1, 58, 8, 89, 3, 27, 
    0, 96, 4, 11, 2, 72, 5, 97, 3, 12, 6, 12, 7,  3, 1, 54, 8, 40, 
    2, 18, 6, 70, 3, 88, 5, 94, 0, 74, 1, 15, 7, 85, 4, 67, 8, 91
  };
  const int q1833[] = {
    9, 9, // Number of jobs and machines
    2, 63, 1,  2, 7, 78, 6, 98, 4, 14, 3, 73, 8, 56, 0, 99, 5, 17, 
    3, 77, 7,  8, 6, 43, 0,  6, 1, 23, 8, 29, 2, 82, 5, 44, 4, 10, 
    2, 80, 1, 19, 4,  4, 6, 41, 7, 30, 5, 15, 3, 11, 8, 20, 0, 98, 
    5, 15, 8, 47, 2, 46, 6, 68, 1, 67, 0, 82, 7, 52, 3, 77, 4, 44, 
    4, 54, 6, 85, 1,  9, 2, 56, 0, 61, 5, 87, 7, 69, 8, 42, 3, 94, 
    3, 43, 4, 40, 8, 36, 0,  2, 2, 70, 1, 73, 6,  6, 7,  7, 5, 69, 
    2, 57, 4,  7, 8, 19, 1, 93, 3, 79, 6, 63, 7, 67, 0, 30, 5,  1, 
    0, 77, 2, 76, 6, 12, 1, 43, 4, 69, 8, 15, 3, 82, 5, 10, 7,  1, 
    3,  1, 6, 13, 1, 77, 2, 19, 8, 44, 0, 80, 7, 66, 5,  3, 4, 70
  };
  const int q1834[] = {
    9, 9, // Number of jobs and machines
    0, 57, 3,  9, 6, 10, 1, 68, 7, 14, 2, 73, 8, 12, 4, 33, 5, 10, 
    7, 81, 2, 46, 8, 55, 4, 49, 3, 53, 1, 91, 0, 22, 5,  5, 6,  7, 
    2, 16, 7, 13, 5, 35, 8, 93, 3, 75, 0, 66, 6, 83, 4, 79, 1, 44, 
    4, 89, 7, 83, 8, 80, 1, 91, 2, 65, 5, 72, 3, 52, 6, 94, 0, 62, 
    3, 83, 2, 48, 6, 74, 0, 47, 7, 88, 4, 47, 5, 38, 8, 10, 1, 88, 
    3, 62, 4, 84, 5, 92, 6, 56, 8, 89, 7, 61, 2, 31, 0, 33, 1, 41, 
    4, 97, 5, 51, 1, 74, 0, 46, 8, 74, 7, 33, 2, 72, 6, 66, 3, 14, 
    7, 41, 3, 76, 4, 71, 0, 10, 6, 60, 5, 81, 8, 94, 2, 57, 1, 42, 
    0, 25, 6, 70, 7, 43, 3, 67, 1, 37, 4, 27, 8, 81, 2, 36, 5, 54
  };
  const int q1835[] = {
    9, 9, // Number of jobs and machines
    7, 83, 3, 24, 1, 20, 5, 16, 6, 47, 8, 44, 2, 64, 0, 33, 4, 96, 
    6, 88, 5, 89, 0, 94, 8, 36, 4, 65, 2, 58, 7, 33, 1, 96, 3, 10, 
    0, 57, 7, 89, 2, 56, 1, 31, 6, 78, 5, 83, 4, 89, 8, 93, 3, 80, 
    2, 70, 1, 70, 4, 63, 0, 49, 3, 13, 8, 56, 5,  6, 6, 13, 7, 37, 
    1, 92, 7, 97, 0, 17, 5, 59, 6, 76, 2, 35, 4, 20, 8, 44, 3, 74, 
    7, 97, 6,  8, 2, 51, 0, 55, 1, 10, 8, 81, 4, 96, 5, 58, 3, 42, 
    0, 55, 8, 25, 4, 74, 3,  6, 2, 27, 5, 50, 6, 31, 7, 15, 1, 29, 
    3, 89, 1, 83, 2, 22, 6, 93, 4, 88, 0, 56, 5, 93, 8, 81, 7, 54, 
    7, 58, 1, 38, 6, 33, 2, 64, 4, 14, 8, 58, 0, 79, 5,  3, 3, 71
  };
  const int q1836[] = {
    9, 9, // Number of jobs and machines
    4, 68, 1, 40, 2, 75, 3, 34, 0, 75, 7, 13, 8, 39, 5, 11, 6, 30, 
    1, 12, 3, 78, 6, 86, 4, 74, 8, 38, 7, 29, 5, 59, 2, 83, 0, 74, 
    7, 11, 2, 61, 3,  3, 0, 34, 4,  7, 6, 34, 8,  8, 5, 60, 1, 12, 
    4, 73, 6, 63, 0, 73, 8, 30, 2, 55, 7, 16, 5,  7, 3, 20, 1, 74, 
    8, 14, 3, 71, 0, 11, 2,  7, 1, 27, 6, 23, 5, 63, 4, 96, 7, 35, 
    4, 60, 3, 76, 0, 75, 5, 52, 6, 82, 2, 14, 7,  8, 1, 28, 8, 49, 
    6, 83, 3, 82, 0, 19, 7, 51, 8, 57, 1, 23, 2, 12, 5,  8, 4, 20, 
    3, 92, 6, 43, 2, 67, 8, 17, 7,  1, 0, 22, 1, 86, 5, 89, 4, 71, 
    2, 24, 1, 12, 4, 46, 8, 64, 5, 75, 0, 86, 6, 64, 3, 54, 7, 57
  };
  const int q1837[] = {
    9, 9, // Number of jobs and machines
    5, 53, 8, 82, 0, 59, 1, 14, 2, 25, 4, 80, 3, 17, 7, 91, 6, 28, 
    2, 77, 4, 54, 6, 94, 7, 93, 3, 68, 0, 62, 1, 28, 8, 57, 5, 61, 
    7, 63, 1, 19, 3, 69, 4, 24, 5, 52, 8, 96, 6, 56, 0, 77, 2, 20, 
    3, 36, 7, 22, 4, 72, 2, 97, 8, 57, 5, 43, 1,  9, 6, 54, 0, 65, 
    6, 66, 2, 83, 7, 21, 5, 30, 8, 35, 3, 94, 4, 39, 1, 17, 0, 49, 
    2, 97, 7, 18, 1, 18, 6,  2, 4, 91, 8, 20, 0, 18, 5, 88, 3, 39, 
    3, 97, 8, 28, 2, 64, 1,  3, 0, 33, 6, 90, 5, 66, 7, 25, 4, 61, 
    1,  8, 0, 94, 3, 79, 8, 37, 5, 23, 2, 81, 4, 86, 7, 48, 6, 74, 
    7, 28, 8, 73, 5, 33, 1, 79, 4, 98, 2, 41, 3, 71, 6,  2, 0, 81
  };
  const int q1838[] = {
    9, 9, // Number of jobs and machines
    7, 31, 8, 16, 1, 28, 2, 19, 5, 94, 4, 28, 0, 78, 6, 56, 3, 74, 
    7, 57, 6, 86, 3, 95, 0, 23, 5,  5, 1, 46, 4, 36, 2, 97, 8, 77, 
    1, 92, 7, 61, 0, 23, 6, 91, 8, 50, 5, 66, 3, 81, 4, 48, 2, 47, 
    4, 68, 3, 46, 0, 53, 6,  1, 2, 97, 1, 91, 8, 62, 5,  7, 7,  1, 
    7, 48, 1, 99, 4,  8, 2, 31, 0, 69, 3, 77, 6, 90, 5, 82, 8, 21, 
    3, 36, 2, 63, 8, 76, 6, 77, 1, 92, 0, 20, 7, 23, 4, 51, 5, 89, 
    5, 40, 6, 89, 8, 43, 3, 47, 1, 95, 0, 42, 2, 87, 7, 67, 4, 25, 
    6, 87, 7, 81, 4, 13, 5, 88, 0, 36, 3, 45, 1, 44, 8, 35, 2, 99, 
    3, 75, 6, 66, 7, 45, 4, 62, 5, 75, 8, 15, 1, 90, 2, 30, 0, 83
  };
  const int q1839[] = {
    9, 9, // Number of jobs and machines
    7, 26, 5, 23, 1, 25, 8, 25, 0,  8, 3, 31, 6, 44, 4, 38, 2, 84, 
    0, 35, 4, 60, 8,  4, 5, 26, 2, 52, 1, 74, 7,  2, 6, 48, 3, 77, 
    1, 59, 8,  9, 0, 55, 6, 32, 3, 41, 5,  8, 7,  3, 4, 30, 2, 20, 
    7, 92, 3, 31, 5, 56, 0,  7, 6, 85, 4, 76, 1, 58, 8,  6, 2, 66, 
    1, 57, 3, 80, 8, 38, 7, 42, 2, 30, 6, 40, 0, 27, 5, 11, 4, 76, 
    7, 89, 3, 82, 4, 76, 1, 66, 2, 26, 0, 35, 6,  8, 8, 99, 5, 13, 
    1, 16, 5, 56, 4,  4, 7, 23, 2, 11, 8,  1, 0, 40, 6, 28, 3, 83, 
    7, 33, 1, 48, 2, 68, 4, 20, 0, 21, 8, 94, 6, 94, 5, 32, 3, 50, 
    6, 51, 4, 25, 2, 44, 8, 83, 3, 28, 0, 89, 7, 99, 1, 95, 5,  6
  };
  const int q1840[] = {
    9, 9, // Number of jobs and machines
    0, 69, 2,  9, 3, 38, 1, 32, 5, 97, 8,  7, 6, 63, 4, 51, 7, 37, 
    2, 71, 7, 30, 8, 30, 5,  5, 0, 53, 4, 55, 6, 69, 1, 33, 3, 63, 
    4, 51, 5, 14, 8, 41, 1, 94, 6,  9, 7, 52, 2, 40, 3, 11, 0, 46, 
    5, 56, 6, 48, 2, 67, 3,  6, 0,  1, 7, 54, 8, 59, 1, 17, 4, 50, 
    8, 32, 5, 94, 2,  3, 1, 27, 6, 62, 0,  8, 7, 98, 3, 80, 4, 44, 
    5, 17, 0, 67, 4, 80, 7, 19, 6, 53, 2, 75, 3, 67, 1,  9, 8,  2, 
    4, 11, 3, 93, 2, 41, 1, 26, 7, 67, 6, 28, 0, 30, 8, 91, 5, 31, 
    3,  9, 2,  8, 6, 87, 4, 30, 5, 98, 7, 68, 0, 49, 8, 17, 1,  4, 
    3, 34, 2, 32, 5, 80, 4, 50, 7, 53, 8, 36, 1, 68, 0, 68, 6, 24
  };
  const int q1841[] = {
    9, 9, // Number of jobs and machines
    8, 76, 4, 50, 5, 93, 0,  7, 6, 59, 3,  8, 7, 88, 1, 29, 2, 83, 
    6, 71, 3, 39, 8, 19, 1, 91, 2, 83, 0, 21, 4, 68, 5, 27, 7,  8, 
    2, 95, 4, 87, 1, 16, 8, 20, 0, 89, 6, 43, 3, 71, 5, 60, 7, 11, 
    4, 21, 6, 87, 8, 13, 0, 64, 7, 67, 2, 83, 1,  1, 3,  3, 5, 58, 
    4, 60, 6, 55, 8, 36, 5,  4, 3,  4, 2, 97, 1, 12, 0, 22, 7,  6, 
    0, 35, 3, 59, 8, 24, 2, 57, 5, 66, 6, 11, 1, 95, 7, 98, 4, 28, 
    6, 22, 3, 78, 0, 38, 5, 41, 8, 21, 2, 91, 7, 26, 1, 31, 4, 90, 
    2, 73, 0, 92, 3, 29, 7, 20, 4, 79, 6, 84, 8, 92, 5, 86, 1, 77, 
    5, 83, 1, 84, 7, 20, 0, 70, 4, 39, 6, 44, 8, 93, 3, 77, 2, 21
  };
  const int q1842[] = {
    9, 9, // Number of jobs and machines
    1, 93, 4, 10, 2, 81, 3, 73, 7, 63, 5, 78, 8, 41, 0,  8, 6, 58, 
    2, 43, 6, 50, 5, 62, 1, 37, 7, 65, 4, 54, 8, 39, 0, 81, 3, 81, 
    5, 95, 1, 88, 3, 90, 0, 30, 7, 14, 8, 93, 2,  2, 4, 38, 6, 37, 
    0, 77, 1, 48, 7, 36, 8,  9, 3, 20, 4, 51, 6, 51, 2, 13, 5, 44, 
    8, 20, 1, 28, 6, 78, 7, 33, 2, 66, 3, 60, 0, 10, 4, 43, 5, 70, 
    3, 32, 7, 10, 2, 90, 0, 10, 6, 97, 8, 35, 4, 24, 5, 86, 1, 34, 
    4,  9, 6, 61, 1, 49, 8, 21, 2, 25, 5, 93, 0, 86, 3, 73, 7, 12, 
    2, 47, 4, 73, 1, 44, 8, 89, 7,  6, 3, 94, 5, 24, 0, 41, 6, 76, 
    1, 59, 8, 61, 2, 50, 6,  2, 5, 97, 4,  9, 7, 78, 0, 52, 3, 70
  };
  const int q1843[] = {
    9, 9, // Number of jobs and machines
    5, 47, 3, 36, 7, 96, 8, 39, 2, 69, 6, 21, 1, 36, 4,  8, 0, 41, 
    8, 26, 0, 60, 7, 56, 5, 85, 6, 97, 4, 21, 1, 16, 2, 20, 3, 92, 
    5, 24, 3, 43, 0, 74, 7, 70, 8, 24, 2, 82, 4, 79, 6, 50, 1,  1, 
    0, 65, 2, 33, 7, 20, 8, 53, 6, 73, 3, 32, 4, 51, 1, 99, 5, 34, 
    1, 42, 3, 11, 8, 93, 5, 16, 2, 61, 0,  7, 7, 51, 4, 71, 6, 35, 
    2, 74, 0, 45, 5, 87, 3, 87, 7, 48, 6, 57, 8, 93, 1, 19, 4, 10, 
    5, 58, 6, 95, 2, 38, 0, 48, 1, 57, 3, 66, 4, 40, 7, 58, 8, 87, 
    4, 46, 5, 13, 8, 47, 1,  5, 2, 96, 6, 10, 7,  5, 0,  4, 3, 78, 
    0, 20, 7, 35, 3, 80, 8, 43, 4, 50, 1, 14, 5, 39, 2, 84, 6, 22
  };
  const int q1844[] = {
    9, 9, // Number of jobs and machines
    0, 10, 7, 83, 6, 68, 2, 78, 8,  6, 3, 30, 5, 25, 1, 54, 4,  2, 
    3, 25, 6, 12, 2, 61, 8, 91, 0, 88, 5, 83, 7, 98, 4,  9, 1, 62, 
    6, 80, 0, 90, 2, 67, 4, 97, 3, 63, 8, 62, 7, 21, 5, 48, 1, 44, 
    5, 61, 3, 46, 0, 50, 7, 76, 2, 91, 6, 81, 1, 99, 8,  6, 4, 20, 
    6, 48, 8, 56, 3, 58, 2, 91, 4, 33, 5, 40, 7, 58, 1, 98, 0, 84, 
    5, 85, 1, 16, 7,  3, 8, 85, 3,  1, 2, 46, 4, 22, 6, 45, 0, 83, 
    3,  5, 2, 57, 6,  2, 5,  7, 8, 36, 4, 72, 1, 10, 0, 44, 7, 36, 
    1, 82, 3, 28, 2, 85, 5, 47, 4, 86, 0,  4, 6, 43, 8, 80, 7, 17, 
    5, 88, 6, 67, 0, 76, 4, 76, 7,  1, 2, 38, 8,  9, 3, 81, 1, 45
  };
  const int q1845[] = {
    9, 9, // Number of jobs and machines
    6, 69, 0, 23, 3,  1, 1, 80, 2,  3, 4, 20, 5,  7, 8, 85, 7,  3, 
    6, 36, 8, 72, 7, 81, 4, 42, 1, 40, 2, 31, 3, 16, 5, 36, 0, 26, 
    7, 64, 4, 43, 6, 10, 8, 82, 2, 44, 1, 10, 3, 36, 0, 14, 5, 38, 
    3, 46, 6,  6, 0, 98, 4, 79, 5, 34, 1, 42, 2, 55, 8,  9, 7, 86, 
    2, 43, 8, 56, 4, 52, 0, 65, 5, 58, 6, 73, 7, 33, 1, 85, 3, 70, 
    3, 99, 5,  9, 2, 93, 7, 87, 6,  1, 8, 40, 1, 22, 0, 63, 4, 92, 
    6, 69, 5, 82, 4, 86, 7, 13, 8, 79, 1, 15, 2, 29, 3, 88, 0, 71, 
    1, 59, 3, 90, 5, 83, 0,  2, 2, 58, 7, 97, 6, 79, 8, 99, 4, 35, 
    4, 98, 7, 84, 0,  4, 8,  7, 6, 55, 3, 32, 5, 34, 2, 21, 1, 54
  };
  const int q1846[] = {
    9, 9, // Number of jobs and machines
    3, 50, 2, 92, 4, 68, 0, 21, 1, 31, 5, 29, 8, 71, 7, 49, 6, 84, 
    8, 22, 1, 13, 3, 99, 2, 12, 0,  7, 5, 38, 6, 10, 4, 90, 7, 42, 
    7, 16, 8, 96, 6,  8, 2, 49, 3,  3, 5, 56, 1, 96, 4, 85, 0, 44, 
    4,  5, 5, 99, 7, 64, 6, 57, 8, 24, 1, 24, 2, 32, 3, 96, 0, 85, 
    4, 90, 5, 35, 1, 93, 2, 60, 8, 89, 0, 31, 3, 17, 7, 25, 6, 81, 
    0, 64, 7, 52, 4, 68, 6, 13, 3, 74, 1, 45, 2, 67, 5, 26, 8, 91, 
    8, 65, 4, 25, 3, 57, 1, 12, 5, 65, 2, 43, 6,  9, 0, 97, 7, 76, 
    6, 33, 7, 57, 1, 75, 3, 82, 4, 62, 8,  4, 2, 14, 0, 29, 5, 25, 
    3, 63, 2, 60, 7, 22, 5, 17, 4, 27, 0, 19, 8, 49, 6, 89, 1, 92
  };
  const int q1847[] = {
    9, 9, // Number of jobs and machines
    1, 83, 2, 72, 7, 14, 3, 48, 6, 89, 4,  3, 5, 57, 0, 63, 8, 17, 
    7, 79, 2, 82, 4, 32, 5, 81, 0, 71, 1, 81, 8, 45, 3, 52, 6, 89, 
    6, 51, 7, 40, 5, 77, 4, 91, 8, 88, 2, 23, 3, 10, 1, 10, 0, 54, 
    6, 35, 7, 46, 5, 12, 2, 99, 8, 37, 3, 70, 0, 41, 4, 42, 1, 32, 
    0, 83, 5, 74, 6, 83, 7, 51, 4, 94, 3, 94, 1, 95, 2, 87, 8, 38, 
    0, 39, 6, 55, 1,  8, 4, 26, 8, 44, 5, 18, 7, 23, 3, 13, 2, 84, 
    6, 45, 8, 73, 3, 80, 4, 44, 2, 43, 0, 94, 5, 48, 7, 48, 1, 83, 
    8, 14, 0, 43, 7, 13, 4, 74, 3, 95, 5,  2, 2, 47, 6, 93, 1, 93, 
    8,  1, 2, 86, 3, 14, 6, 30, 1,  1, 0, 85, 7, 14, 5, 60, 4,  2
  };
  const int q1848[] = {
    9, 9, // Number of jobs and machines
    1, 33, 7, 22, 2, 51, 5, 33, 0, 61, 6, 23, 4, 45, 8, 21, 3, 34, 
    5, 95, 2, 67, 4, 32, 3, 39, 0, 13, 7, 34, 6, 14, 1, 28, 8, 64, 
    3, 89, 1, 52, 7, 78, 8, 91, 5, 77, 0, 77, 2, 71, 4, 81, 6, 43, 
    5, 32, 0, 62, 1, 56, 7, 16, 4, 45, 3, 34, 2, 93, 8, 58, 6, 68, 
    3, 73, 1, 52, 2, 87, 7, 50, 5, 51, 6, 39, 0, 69, 4, 60, 8, 20, 
    8, 42, 7, 80, 2, 53, 4, 35, 1, 68, 6,  5, 5, 55, 3, 32, 0, 98, 
    4, 98, 2, 35, 1, 45, 7, 69, 5, 49, 3, 28, 0, 94, 8,  3, 6, 10, 
    3, 26, 8, 92, 6, 28, 7, 96, 0, 43, 2, 24, 4, 24, 1, 86, 5, 37, 
    8, 24, 7, 41, 2, 68, 6, 97, 1, 73, 3, 74, 0, 54, 5, 22, 4, 48
  };
  const int q1849[] = {
    9, 9, // Number of jobs and machines
    3, 23, 7, 16, 1, 17, 0, 65, 4, 43, 6, 18, 5, 94, 8,  2, 2, 95, 
    6, 93, 1, 41, 5, 88, 3, 53, 7, 75, 8, 95, 0, 63, 4, 76, 2, 97, 
    5, 72, 0, 75, 4, 49, 7,  5, 2, 44, 8, 67, 1, 61, 3, 73, 6, 70, 
    1, 84, 4, 19, 0, 58, 2,  4, 8, 74, 6, 60, 5, 41, 3, 39, 7, 87, 
    1, 26, 2, 65, 4, 30, 6, 97, 8, 41, 3, 86, 5, 44, 0, 85, 7, 96, 
    4, 71, 8, 30, 6, 34, 2, 62, 5, 78, 0, 80, 7,  4, 1, 86, 3, 54, 
    7,  1, 2, 12, 8, 59, 0, 40, 1, 74, 3, 46, 4, 72, 6, 60, 5,  6, 
    0, 67, 5, 93, 4, 90, 1, 35, 3, 75, 2, 60, 8, 76, 7, 74, 6, 74, 
    1, 14, 3, 84, 0, 63, 2, 26, 5, 91, 7, 14, 6,  5, 8, 39, 4,  6
  };
  const int q1850[] = {
    9, 9, // Number of jobs and machines
    3, 41, 4, 58, 8, 38, 0, 93, 6, 58, 2, 31, 7, 83, 1, 13, 5, 41, 
    8, 28, 0, 28, 4, 16, 3,  9, 2, 50, 7, 76, 1, 20, 6, 38, 5, 99, 
    4, 29, 8, 73, 2, 78, 0, 99, 3, 22, 6, 79, 7,  5, 1, 67, 5, 84, 
    8, 29, 0, 89, 7, 13, 4, 42, 6, 74, 3, 35, 5, 68, 1, 27, 2, 43, 
    3, 99, 7,  9, 6, 50, 1, 95, 5,  4, 2, 74, 4, 72, 8, 80, 0, 12, 
    2, 15, 6, 22, 1, 26, 8, 62, 4, 65, 7, 22, 5, 58, 0, 45, 3, 61, 
    5, 30, 1, 83, 3, 80, 8, 85, 4, 42, 0, 77, 2, 12, 7, 58, 6, 16, 
    3,  9, 2, 64, 4, 31, 8, 42, 7, 61, 6, 89, 5, 80, 1,  2, 0, 24, 
    1, 29, 8, 51, 5, 58, 3, 12, 2, 57, 7, 63, 4,  2, 0, 20, 6, 86
  };
  const int q1851[] = {
    9, 9, // Number of jobs and machines
    1, 10, 2, 93, 3, 11, 6, 26, 5, 94, 7, 66, 8,  2, 0, 49, 4, 86, 
    0, 42, 4, 94, 7, 74, 5, 96, 6, 18, 3, 38, 1, 10, 2, 35, 8, 60, 
    4, 15, 7, 57, 2, 16, 3, 52, 8, 37, 0,  4, 6, 99, 1,  7, 5, 18, 
    7, 24, 0, 25, 2, 42, 4, 25, 6, 62, 3, 75, 1, 71, 8, 46, 5, 37, 
    2, 69, 3, 32, 0,  9, 8, 32, 7, 99, 4, 50, 6, 67, 5, 34, 1, 63, 
    0, 29, 4, 76, 3, 16, 8, 81, 7, 66, 5, 89, 2,  1, 1, 43, 6, 51, 
    8, 82, 7, 20, 1, 72, 3,  4, 6, 95, 4, 80, 2, 31, 0, 34, 5, 34, 
    6, 23, 7, 45, 3, 75, 8, 91, 2, 42, 4, 93, 1,  3, 0, 29, 5, 86, 
    7, 77, 0, 40, 8, 22, 5, 80, 2, 55, 3, 64, 6, 87, 1, 75, 4, 12
  };
  const int q1852[] = {
    9, 9, // Number of jobs and machines
    5, 81, 6, 94, 0, 81, 2, 23, 7, 42, 3, 49, 1, 34, 8, 65, 4, 22, 
    3,  2, 0, 67, 7, 59, 6, 41, 4, 29, 1, 94, 8, 97, 2, 15, 5, 43, 
    5, 62, 8,  4, 6, 42, 1, 60, 2, 28, 3, 46, 7, 41, 0, 47, 4,  1, 
    7, 23, 2, 50, 4, 79, 6, 45, 8, 85, 5, 46, 3, 66, 1, 60, 0, 59, 
    0, 18, 1, 59, 5, 35, 4, 38, 7, 36, 6, 38, 3,  5, 2, 88, 8, 88, 
    2, 49, 4, 10, 1, 68, 5, 79, 6, 81, 8, 91, 0, 57, 3, 86, 7, 34, 
    7, 89, 3, 41, 0, 25, 2,  5, 5, 99, 6, 26, 1, 42, 4, 36, 8, 45, 
    0, 36, 4, 66, 8,  4, 5, 19, 2, 71, 7, 35, 1, 18, 3, 41, 6,  2, 
    6, 27, 4, 97, 1, 21, 2, 51, 7, 42, 5, 94, 0, 15, 8, 28, 3,  7
  };
  const int q1853[] = {
    9, 9, // Number of jobs and machines
    3, 33, 6, 72, 1, 53, 0, 30, 5, 22, 2, 70, 4, 74, 8, 94, 7, 10, 
    3, 37, 0, 38, 6, 94, 4, 71, 1, 86, 8,  2, 5, 99, 7, 51, 2,  9, 
    3, 74, 2, 16, 5, 40, 0, 33, 6, 44, 1, 98, 8, 14, 4, 75, 7, 87, 
    6, 84, 5, 85, 8, 61, 4, 38, 7, 17, 2, 12, 1,  2, 0, 87, 3, 64, 
    1, 54, 7, 84, 2,  1, 6, 88, 8, 45, 4,  8, 0, 71, 5, 92, 3, 64, 
    2,  6, 3, 76, 4, 57, 6, 36, 8, 75, 7, 23, 1, 94, 0, 27, 5, 32, 
    0, 92, 1, 83, 5, 65, 6, 20, 4, 47, 3, 20, 8, 61, 7, 13, 2, 59, 
    4, 11, 3, 23, 5, 66, 1, 10, 2, 38, 0, 25, 6, 42, 7, 87, 8, 78, 
    4, 45, 3,  6, 5, 81, 8, 23, 2, 26, 7,  8, 0, 57, 1, 19, 6, 61
  };
  const int q1854[] = {
    9, 9, // Number of jobs and machines
    0, 74, 8, 25, 2, 57, 6, 57, 4, 96, 1, 31, 5, 13, 7, 87, 3, 16, 
    8, 69, 0, 23, 1, 95, 4, 27, 3, 84, 7, 38, 5, 16, 6, 60, 2, 81, 
    7, 58, 3, 42, 4, 95, 6, 27, 2, 11, 0, 45, 5, 75, 8, 16, 1, 63, 
    0, 33, 8, 85, 7, 92, 5, 30, 6, 95, 2, 12, 4, 71, 3, 80, 1, 44, 
    3,  3, 8,  8, 1, 85, 2, 26, 5, 26, 7, 39, 4, 42, 0, 28, 6, 44, 
    4, 42, 3, 87, 0, 71, 5, 96, 7,  7, 1,  1, 6, 77, 8, 42, 2,  5, 
    7, 77, 4, 83, 1, 69, 3, 83, 6,  6, 2, 48, 8, 23, 0, 47, 5, 55, 
    0, 99, 8, 32, 5, 52, 1, 56, 6, 62, 4, 27, 2, 15, 3, 34, 7,  8, 
    3, 44, 8, 18, 5, 54, 7, 65, 6, 43, 4, 13, 0, 46, 1, 76, 2, 19
  };
  const int q1855[] = {
    9, 9, // Number of jobs and machines
    7,  4, 3, 19, 2, 57, 6, 54, 0, 24, 4, 49, 1, 70, 5, 75, 8, 12, 
    0, 57, 4, 29, 1, 82, 5, 20, 7, 83, 8, 45, 3, 14, 6, 82, 2, 98, 
    2, 24, 8, 28, 7, 82, 3, 76, 6, 79, 0, 85, 5, 44, 4, 35, 1, 28, 
    8, 81, 4,  7, 6, 81, 7, 38, 3, 53, 1, 29, 5, 28, 2, 89, 0, 12, 
    7, 63, 0, 31, 4,  7, 8, 72, 5, 70, 1, 24, 2, 84, 6, 96, 3, 25, 
    1, 98, 6,  3, 3, 24, 7, 98, 4, 41, 8, 48, 2, 62, 0, 88, 5, 86, 
    4, 24, 8, 50, 5, 16, 0, 32, 3, 24, 6, 50, 2, 68, 7, 39, 1, 43, 
    2, 47, 8, 63, 1, 77, 6, 49, 3, 24, 0, 70, 4, 42, 7, 19, 5, 50, 
    8, 75, 5, 10, 1, 62, 4, 98, 0, 67, 3, 36, 6, 81, 7, 93, 2, 70
  };
  const int q1856[] = {
    9, 9, // Number of jobs and machines
    2,  9, 1, 54, 8, 86, 5, 57, 7,  6, 3, 30, 0, 88, 6, 40, 4, 66, 
    5, 57, 2, 69, 8, 62, 3, 80, 7, 85, 0, 66, 1, 86, 4, 65, 6,  5, 
    3, 29, 4,  2, 0,  4, 7, 59, 2, 50, 6, 38, 1,  2, 5, 65, 8, 25, 
    8, 72, 6,  2, 4, 34, 0, 82, 3, 35, 2, 41, 1, 63, 7, 24, 5, 37, 
    8, 60, 6, 69, 4, 65, 2, 14, 3, 64, 7, 64, 0, 65, 5, 24, 1, 62, 
    5, 41, 4, 83, 0,  3, 1,  6, 8, 11, 3,  5, 6, 40, 7, 24, 2, 65, 
    6, 79, 0, 16, 3, 22, 7, 33, 4, 25, 2,  9, 8, 86, 1, 23, 5, 11, 
    6, 75, 0, 20, 3, 31, 5, 48, 4, 71, 8, 46, 2, 68, 7, 89, 1, 75, 
    1, 13, 6, 37, 4, 97, 5, 29, 3, 31, 7, 52, 0, 88, 2, 92, 8, 48
  };
  const int q1857[] = {
    9, 9, // Number of jobs and machines
    0,  2, 7, 27, 2, 75, 8, 22, 6, 44, 5, 67, 1, 25, 4, 68, 3, 54, 
    6, 21, 0, 54, 2, 61, 8,  5, 3, 66, 4, 14, 5, 67, 1, 26, 7, 91, 
    1, 50, 5, 61, 0, 64, 3, 94, 8, 54, 7, 30, 2,  1, 6, 16, 4, 51, 
    8, 36, 7, 92, 3, 25, 2, 45, 6, 89, 5, 72, 0, 78, 4, 47, 1, 91, 
    2, 65, 4, 29, 6, 39, 8, 65, 0, 76, 3, 97, 5, 47, 1, 50, 7, 94, 
    0,  5, 8, 27, 4, 17, 2, 75, 7,  9, 3, 12, 1, 84, 6, 54, 5, 69, 
    8, 24, 1, 33, 4, 88, 5, 35, 7, 31, 6,  5, 2, 13, 0, 12, 3, 21, 
    6, 13, 2, 52, 7, 65, 1, 49, 0, 52, 4, 69, 3, 93, 8, 28, 5, 66, 
    6, 16, 2, 41, 4,  3, 1, 58, 3, 31, 5, 99, 7, 49, 0, 52, 8, 45
  };
  const int q1858[] = {
    9, 9, // Number of jobs and machines
    3, 42, 6, 43, 7, 36, 8, 60, 2,  7, 5, 66, 0, 47, 4, 66, 1, 69, 
    6, 16, 3, 49, 8, 15, 0, 90, 5,  8, 7, 76, 1, 11, 2, 83, 4, 65, 
    8, 96, 0, 30, 7,  7, 6, 17, 4,  2, 5, 87, 2, 26, 3, 31, 1, 22, 
    6, 29, 1, 43, 3, 56, 4,  2, 0, 80, 5, 59, 2, 28, 7, 95, 8, 15, 
    5, 57, 6, 65, 3, 89, 8, 27, 2, 46, 7, 61, 1, 77, 0, 45, 4,  1, 
    6, 26, 8, 11, 3, 44, 7,  7, 0, 44, 5, 43, 1, 39, 4, 69, 2, 48, 
    4, 54, 7, 41, 6, 40, 0, 43, 5, 33, 2, 23, 3, 66, 8, 30, 1, 15, 
    0, 47, 7, 30, 3, 86, 8,  5, 1, 19, 6, 15, 5, 67, 2, 56, 4, 80, 
    1,  3, 8, 26, 5, 92, 3, 61, 4, 29, 2, 21, 6, 52, 7,  4, 0, 16
  };
  const int q1859[] = {
    9, 9, // Number of jobs and machines
    6, 78, 3, 23, 8, 35, 4, 57, 7, 94, 1, 38, 2, 45, 0, 76, 5, 49, 
    7, 54, 4, 85, 1, 27, 2, 21, 5, 67, 3, 44, 0, 67, 6, 77, 8,  1, 
    4, 77, 8, 88, 3, 44, 1, 61, 6, 36, 5, 85, 0, 28, 7, 96, 2, 71, 
    2, 82, 8, 16, 4, 95, 1, 37, 5, 70, 7, 45, 6, 74, 0, 21, 3, 50, 
    3, 69, 7, 25, 6, 57, 5,  1, 0, 70, 2, 73, 1, 92, 8, 77, 4, 38, 
    3, 60, 2, 14, 8, 16, 1, 22, 5,  3, 4, 48, 7, 86, 6, 85, 0, 85, 
    8, 99, 3, 94, 5, 84, 6, 15, 2, 73, 4, 75, 0, 41, 1, 19, 7, 68, 
    7, 52, 5, 24, 3, 52, 4,  8, 2, 54, 1, 83, 0, 87, 6, 52, 8, 17, 
    4, 50, 3, 95, 1, 86, 6, 45, 8, 15, 7, 80, 2, 43, 0,  3, 5, 52
  };
  const int q1860[] = {
    9, 9, // Number of jobs and machines
    6, 46, 1, 69, 7, 76, 3, 91, 4, 27, 8, 19, 2,  8, 5, 43, 0, 83, 
    0, 79, 5, 59, 8,  5, 1, 22, 6, 99, 3, 65, 2, 72, 4, 77, 7, 73, 
    0, 49, 6, 84, 7, 29, 5, 86, 4, 50, 1, 67, 8, 12, 3, 17, 2, 65, 
    5, 46, 7, 67, 8, 78, 6, 65, 4, 88, 0, 10, 3, 75, 2, 80, 1, 48, 
    8, 48, 6, 64, 3, 95, 2, 65, 0, 19, 1, 69, 7, 76, 4, 28, 5, 53, 
    2, 44, 7, 96, 3, 60, 6, 66, 4, 31, 1, 99, 5, 58, 8, 21, 0, 11, 
    7, 35, 2, 52, 6, 42, 1, 90, 8, 85, 4, 45, 0, 46, 5, 83, 3, 69, 
    8,  1, 2, 52, 3, 60, 1, 21, 4,  2, 5,  6, 0, 61, 7, 49, 6, 31, 
    7, 83, 4, 17, 1, 99, 2, 50, 0, 20, 5, 12, 6, 16, 3, 29, 8, 80
  };
  const int q1861[] = {
    9, 9, // Number of jobs and machines
    8, 97, 1, 37, 0, 67, 2, 57, 5, 50, 3, 66, 6, 44, 7,  7, 4,  9, 
    2, 66, 3, 16, 0, 85, 1, 36, 6, 72, 4, 99, 7, 77, 8, 43, 5, 89, 
    0, 31, 3, 94, 7, 15, 6, 99, 2, 71, 4, 45, 8, 16, 1, 85, 5, 24, 
    6, 79, 7, 14, 3, 17, 0, 93, 4, 47, 1, 97, 8, 33, 2, 18, 5, 45, 
    8, 36, 3, 20, 5, 85, 7, 78, 0, 75, 1, 85, 6, 53, 4, 59, 2, 37, 
    6, 78, 5, 66, 0, 71, 1, 11, 8, 75, 4, 55, 3,  7, 2, 84, 7, 49, 
    3, 96, 4, 43, 2, 64, 7, 25, 5,  7, 6, 99, 0, 91, 8, 65, 1, 47, 
    7, 40, 4, 97, 3, 53, 0, 34, 6, 75, 2, 49, 5,  2, 8, 74, 1, 81, 
    2, 11, 8, 99, 3,  6, 4, 30, 1, 52, 5, 47, 7, 69, 6, 35, 0, 29
  };
  const int q1862[] = {
    9, 9, // Number of jobs and machines
    1, 48, 4, 95, 8,  3, 7, 73, 5, 27, 3, 12, 0, 72, 2, 38, 6, 91, 
    6, 46, 3, 90, 7, 56, 1, 16, 5, 12, 0, 47, 4, 82, 2, 92, 8,  5, 
    6, 59, 0, 35, 8, 79, 3, 84, 4, 25, 1, 85, 5,  4, 2, 10, 7, 21, 
    2, 85, 0, 80, 3, 43, 1, 47, 7,  7, 6, 22, 5, 86, 8, 41, 4, 75, 
    1, 14, 0, 96, 4, 28, 8, 43, 7, 76, 2, 31, 6, 52, 5, 91, 3, 13, 
    0, 10, 8, 22, 3, 30, 2, 57, 5,  4, 4, 69, 1, 24, 6, 15, 7, 28, 
    7, 62, 8, 50, 1, 90, 3, 88, 2,  5, 6, 15, 4, 37, 5, 42, 0, 76, 
    2, 13, 8, 88, 3, 86, 4, 49, 7, 52, 6, 41, 0,  6, 1, 26, 5, 10, 
    7, 25, 1, 87, 6, 40, 5, 83, 0, 42, 3, 31, 4, 97, 8, 84, 2,  7
  };
  const int q1863[] = {
    9, 9, // Number of jobs and machines
    4, 68, 1, 71, 7, 63, 0, 76, 6, 43, 2, 39, 8,  2, 5, 69, 3, 44, 
    1, 17, 7, 52, 4, 34, 5,  6, 2, 44, 6,  6, 3, 86, 8, 73, 0, 54, 
    3, 44, 4, 15, 0, 77, 5, 62, 2, 37, 6, 16, 7, 97, 1, 50, 8, 79, 
    1, 32, 6, 36, 4, 77, 3,  9, 8, 26, 5, 30, 2, 36, 0, 63, 7, 62, 
    2, 20, 0, 49, 8, 13, 3, 67, 6, 86, 4, 44, 7, 30, 5, 69, 1, 68, 
    8, 68, 6, 50, 4, 27, 0, 63, 7, 82, 1, 11, 2, 25, 3, 22, 5, 15, 
    4, 56, 7, 33, 1, 72, 6, 82, 0, 48, 2, 33, 3,  1, 8, 90, 5, 15, 
    7, 81, 8,  5, 2,  5, 1, 63, 5, 46, 3, 91, 4, 53, 0, 72, 6, 39, 
    3, 28, 1, 77, 5, 69, 8, 13, 2, 34, 7, 82, 6, 21, 4,  8, 0, 27
  };
  const int q1864[] = {
    9, 9, // Number of jobs and machines
    8, 73, 1, 91, 0, 30, 4, 87, 7,  8, 5, 69, 2, 89, 3, 86, 6, 45, 
    1, 93, 2, 21, 4, 38, 6, 76, 3, 37, 5, 34, 7, 75, 0, 54, 8, 86, 
    4, 64, 8, 37, 1, 13, 0,  9, 6,  2, 2, 27, 3, 13, 5, 89, 7,  9, 
    4, 88, 0, 44, 2, 27, 6, 47, 7, 43, 5, 55, 8, 52, 3,  6, 1, 59, 
    8, 36, 5, 79, 2, 52, 7, 14, 6, 25, 3, 74, 1, 32, 4, 34, 0, 86, 
    8, 26, 0, 75, 3, 24, 2, 43, 4, 66, 7, 28, 6, 77, 1, 46, 5, 23, 
    8, 79, 2, 53, 0, 36, 7, 17, 1, 52, 6, 36, 3, 54, 4, 88, 5, 92, 
    2, 20, 0, 66, 4, 86, 3, 18, 6, 33, 5, 73, 8, 11, 1, 77, 7, 64, 
    3, 84, 7, 30, 2, 76, 0, 57, 6, 56, 1, 52, 8,  6, 5, 11, 4, 67
  };
  const int q1865[] = {
    9, 9, // Number of jobs and machines
    2, 11, 3, 71, 1, 66, 4, 26, 5, 55, 0, 37, 7, 25, 8, 43, 6, 81, 
    2, 51, 4,  3, 1, 69, 0, 33, 7,  3, 8, 48, 6, 17, 5, 46, 3, 36, 
    1, 48, 3, 49, 4, 69, 8, 84, 2, 38, 5, 46, 6, 29, 0, 74, 7, 71, 
    3, 66, 2, 25, 6, 30, 8, 85, 1, 19, 5, 81, 4, 38, 0, 56, 7, 65, 
    3, 34, 6,  8, 0, 27, 8, 35, 4, 88, 7, 78, 5, 59, 2, 90, 1, 95, 
    6,  5, 2, 31, 7, 44, 4, 94, 0, 47, 5, 47, 3, 68, 8, 28, 1, 96, 
    3,  3, 2, 37, 4, 46, 0, 20, 7, 16, 8, 54, 1, 39, 6, 19, 5, 85, 
    0, 85, 1, 23, 3, 93, 8,  9, 6, 29, 4, 59, 5, 23, 2, 27, 7, 13, 
    3, 43, 5, 45, 1, 17, 8, 51, 6, 33, 4, 34, 0, 52, 2, 52, 7, 90
  };
  const int q1866[] = {
    9, 9, // Number of jobs and machines
    0, 44, 5, 23, 7, 98, 1, 56, 6, 50, 8, 76, 2, 41, 4, 70, 3, 90, 
    4,  2, 7,  7, 0,  6, 6, 35, 8, 63, 3, 91, 2, 81, 1, 30, 5, 45, 
    4, 37, 6,  9, 8, 98, 0, 29, 2, 77, 7, 42, 3, 86, 5, 56, 1, 51, 
    5, 50, 4, 59, 2, 96, 6, 66, 7, 77, 1, 61, 0, 43, 8, 89, 3,  6, 
    7, 86, 3, 23, 8, 98, 1, 69, 6, 44, 2,  7, 4, 44, 5, 14, 0, 29, 
    1, 41, 0, 69, 8, 84, 2, 39, 4, 22, 7, 44, 6, 90, 3, 91, 5,  7, 
    7, 40, 8, 23, 2, 79, 6, 78, 5, 24, 4, 26, 1, 65, 3, 92, 0, 60, 
    3, 65, 2, 23, 6, 77, 1, 52, 0, 17, 5, 49, 8, 53, 7, 39, 4,  1, 
    7, 47, 1, 76, 4, 59, 5, 88, 3, 45, 6, 64, 0, 25, 2, 50, 8, 93
  };
  const int q1867[] = {
    9, 9, // Number of jobs and machines
    1, 68, 7, 33, 0, 50, 8, 92, 2, 60, 4, 25, 3,  2, 5, 34, 6, 15, 
    8, 28, 5, 11, 7, 25, 1, 24, 2, 22, 6, 17, 3, 12, 0, 28, 4, 72, 
    0, 73, 4, 89, 3, 39, 7, 56, 8, 56, 2, 37, 6, 16, 1, 56, 5,  1, 
    0, 75, 8, 70, 1, 34, 5, 21, 3,  3, 2, 24, 6, 30, 4, 68, 7, 80, 
    0,  1, 1, 57, 7, 85, 6, 97, 4,  3, 2, 73, 8, 88, 5, 66, 3, 63, 
    4, 90, 6,  3, 5, 67, 1, 90, 7, 83, 2, 49, 8, 52, 0, 59, 3, 56, 
    2, 53, 4, 87, 1, 24, 8, 30, 7, 68, 5, 16, 0, 92, 3, 52, 6, 20, 
    8, 96, 6, 86, 3, 43, 2, 18, 0, 77, 7, 33, 4, 45, 1, 39, 5, 99, 
    1, 42, 5, 12, 6, 82, 0,  5, 3, 78, 2, 68, 8, 32, 4, 60, 7, 29
  };
  const int q1868[] = {
    9, 9, // Number of jobs and machines
    3, 99, 0, 26, 6, 10, 4, 24, 2, 26, 8, 75, 5, 19, 1, 66, 7, 21, 
    1, 93, 4, 98, 2, 18, 6, 69, 5, 32, 8, 36, 3, 31, 0, 49, 7, 19, 
    8, 33, 6, 74, 3, 78, 5,  8, 4, 12, 0, 82, 7, 10, 2, 90, 1, 61, 
    4, 20, 1, 42, 7, 90, 6, 37, 3, 81, 0,  2, 8, 47, 5, 72, 2, 12, 
    7, 82, 1, 61, 3, 40, 5, 47, 0, 70, 6, 40, 8,  5, 2, 91, 4, 11, 
    3, 27, 8, 96, 5, 15, 4, 95, 2, 76, 1, 33, 0, 47, 6, 55, 7, 76, 
    0, 45, 1, 51, 5, 26, 4, 79, 7, 44, 6, 73, 8, 49, 2, 90, 3, 28, 
    7, 54, 5, 55, 1, 39, 8,  7, 3, 20, 4, 63, 6, 62, 2, 26, 0, 91, 
    5, 87, 0, 46, 7, 90, 4, 66, 2, 26, 1, 62, 6,  8, 3,  3, 8, 63
  };
  const int q1869[] = {
    9, 9, // Number of jobs and machines
    3, 35, 7,  8, 2, 79, 4, 26, 6, 40, 1, 78, 8, 11, 5,  3, 0, 21, 
    0, 71, 6, 41, 4, 64, 8, 11, 5, 52, 7, 58, 2, 69, 3, 28, 1, 55, 
    2, 59, 3, 48, 7,  9, 6, 74, 1, 22, 4, 70, 5,  3, 0, 68, 8, 43, 
    4, 85, 1, 73, 3, 40, 0, 48, 5, 53, 7, 51, 8, 61, 6, 14, 2, 84, 
    2,  5, 7,  7, 3, 54, 8, 39, 6, 20, 5, 12, 4, 41, 1, 97, 0, 60, 
    1, 90, 2, 20, 6, 99, 7, 94, 4, 60, 3, 67, 8, 42, 5, 60, 0, 66, 
    0, 16, 4,  8, 1, 54, 3, 27, 8,  3, 7, 63, 6, 20, 2, 16, 5, 23, 
    1, 64, 3, 38, 4, 31, 0, 73, 5, 78, 2, 18, 6, 14, 7,  3, 8, 82, 
    7, 98, 2, 92, 6, 87, 1, 85, 4, 95, 0, 82, 8, 71, 3, 61, 5, 78
  };
  const int q1870[] = {
    9, 9, // Number of jobs and machines
    7, 90, 0, 38, 2, 69, 3, 41, 6,  9, 4, 97, 1, 40, 5, 36, 8, 32, 
    7, 52, 6, 29, 8, 68, 1, 66, 5, 43, 3, 10, 0, 36, 4, 63, 2, 31, 
    6, 81, 8,  2, 1, 36, 7, 16, 2, 27, 3, 94, 4, 34, 0, 65, 5, 88, 
    1, 46, 3, 81, 0, 30, 7, 21, 6,  5, 2, 48, 4,  9, 8, 71, 5, 87, 
    6, 24, 1, 59, 2, 53, 0, 76, 4, 84, 3, 15, 7, 79, 5, 61, 8, 36, 
    6, 47, 3, 73, 0, 69, 2, 76, 8, 10, 5,  4, 4, 97, 7, 69, 1, 46, 
    6, 11, 5, 63, 3, 52, 7, 75, 0, 46, 2, 30, 1, 46, 8, 61, 4,  1, 
    7, 11, 8, 91, 2, 11, 3, 75, 4, 13, 6, 77, 5, 40, 1, 16, 0, 62, 
    6, 64, 0,  7, 2, 57, 7, 12, 3, 75, 4, 70, 5, 92, 8, 25, 1, 49
  };
  const int q1871[] = {
    9, 9, // Number of jobs and machines
    6, 37, 7, 60, 0, 35, 3, 93, 4, 83, 2, 19, 8, 25, 1,  7, 5,  3, 
    2,  9, 7, 44, 5, 30, 8,  9, 3, 64, 1, 40, 4, 28, 6, 62, 0, 18, 
    2, 60, 6, 12, 8, 17, 5, 16, 1, 20, 4,  4, 0, 54, 7,  1, 3, 20, 
    4, 46, 2, 28, 1, 44, 5, 50, 0, 12, 8, 30, 3, 57, 6,  1, 7, 12, 
    1, 44, 0,  3, 5, 14, 4,  1, 3, 94, 6, 43, 2, 99, 8, 45, 7, 56, 
    5, 68, 4, 14, 0, 47, 1, 68, 2, 91, 7, 85, 6,  9, 3, 18, 8, 31, 
    5, 68, 3, 68, 4, 36, 2, 25, 6, 76, 0, 61, 7, 83, 8,  7, 1, 94, 
    3, 33, 6, 12, 4, 97, 5, 58, 1, 65, 8, 73, 2, 44, 0, 30, 7,  3, 
    7, 57, 2, 49, 6, 75, 5, 85, 8,  8, 1, 29, 4, 44, 0, 25, 3,  2
  };
  const int q1872[] = {
    9, 9, // Number of jobs and machines
    2, 34, 6, 68, 4, 65, 1,  6, 8, 25, 3, 60, 7, 57, 5, 70, 0, 48, 
    7, 38, 0, 70, 4, 24, 1,  7, 2, 53, 8, 88, 5, 48, 3,  4, 6, 11, 
    7, 62, 8, 17, 5, 87, 0, 44, 3, 10, 4, 17, 2, 72, 1, 47, 6, 87, 
    2,  5, 0, 22, 5, 63, 1, 85, 4, 92, 7, 56, 6, 77, 8, 60, 3, 37, 
    5,  5, 7, 38, 3, 44, 2, 61, 1, 16, 0,  9, 6, 30, 4, 44, 8, 67, 
    4, 12, 2, 29, 0, 87, 7, 74, 8, 64, 5, 99, 3, 82, 1, 34, 6, 26, 
    2, 70, 8, 44, 3,  4, 7, 48, 1, 47, 6, 80, 4, 32, 0, 51, 5, 11, 
    7, 35, 8, 90, 1,  9, 4, 15, 0, 96, 5,  5, 3, 18, 6, 61, 2, 90, 
    0,  8, 2, 13, 6, 46, 5, 12, 8,  6, 1,  5, 7, 39, 4, 55, 3, 53
  };
  const int q1873[] = {
    9, 9, // Number of jobs and machines
    0, 29, 8, 87, 7, 47, 6, 89, 1, 47, 3, 55, 4, 13, 5, 32, 2, 48, 
    7, 55, 6, 18, 0,  8, 4, 13, 2, 31, 3, 18, 8, 13, 1, 31, 5,  8, 
    4,  3, 2, 37, 7, 14, 1, 26, 5, 31, 8, 45, 0, 44, 6, 13, 3, 53, 
    0, 42, 4, 43, 7, 32, 6, 21, 3, 27, 2, 38, 5, 93, 8, 45, 1, 66, 
    6, 93, 1, 32, 4, 90, 7, 63, 3, 98, 8, 96, 0, 92, 5, 99, 2, 57, 
    5, 15, 7, 84, 3, 94, 2, 30, 1, 88, 6, 27, 8, 65, 4, 32, 0, 15, 
    0, 89, 3, 90, 7, 78, 1, 94, 4, 64, 5, 32, 8, 66, 2, 10, 6,  3, 
    4, 85, 5, 93, 0, 82, 6, 13, 3, 23, 8, 69, 1, 38, 7, 61, 2, 32, 
    5, 57, 4, 94, 1, 57, 8, 93, 3, 31, 6, 79, 7, 69, 0, 38, 2, 90
  };
  const int q1874[] = {
    9, 9, // Number of jobs and machines
    5,  8, 6, 87, 1, 28, 0, 10, 8, 83, 4, 90, 3, 91, 7, 81, 2,  5, 
    8,  9, 0, 69, 6, 79, 5, 78, 3, 18, 2, 48, 1, 94, 7, 44, 4, 88, 
    3, 54, 4, 62, 8,  9, 7, 60, 0, 21, 1, 28, 5, 38, 6,  2, 2, 87, 
    5, 25, 6, 84, 1,  3, 3, 28, 7, 45, 8, 57, 2, 60, 4, 28, 0, 23, 
    4, 19, 7, 91, 1, 23, 3, 45, 6, 98, 8, 83, 0, 65, 2, 95, 5, 77, 
    2, 70, 5, 13, 4,  7, 8, 64, 1, 71, 3, 85, 0, 11, 7, 60, 6, 83, 
    8, 69, 1, 82, 3,  6, 4, 46, 0, 23, 6, 15, 5, 13, 2, 42, 7, 33, 
    1, 44, 3, 10, 6, 12, 2, 20, 5, 90, 4, 62, 0, 69, 7, 22, 8, 87, 
    7, 18, 4, 56, 6, 37, 8, 62, 0, 42, 2, 17, 3, 64, 1, 16, 5, 94
  };
  const int q1875[] = {
    9, 9, // Number of jobs and machines
    7, 79, 0, 31, 5, 50, 4, 67, 3, 23, 2, 89, 1,  4, 8,  4, 6, 52, 
    2, 29, 7, 56, 4, 55, 3, 99, 6, 44, 8, 71, 1, 94, 0, 51, 5, 63, 
    3, 62, 0, 94, 7, 35, 2, 75, 1, 74, 4, 81, 8, 36, 6, 62, 5, 42, 
    5, 27, 6, 80, 7, 60, 0, 84, 2,  7, 8, 86, 3, 82, 1, 47, 4, 77, 
    4, 84, 7,  2, 5,  1, 0, 87, 8, 33, 1, 92, 6, 31, 3, 34, 2, 37, 
    6, 52, 5, 63, 2, 11, 1, 75, 3, 68, 8, 77, 4, 42, 0, 24, 7,  6, 
    3, 24, 4, 85, 1, 14, 6, 45, 2, 44, 7, 41, 0, 66, 5, 27, 8, 84, 
    6, 68, 1, 29, 8, 14, 2, 63, 0, 24, 5, 34, 4, 17, 7,  2, 3, 77, 
    6, 55, 1, 79, 7, 54, 3, 78, 5, 82, 0,  3, 8, 92, 2, 78, 4, 66
  };
  const int q1876[] = {
    9, 9, // Number of jobs and machines
    5, 35, 6,  5, 1, 46, 0, 35, 4, 63, 7, 85, 3, 10, 8, 55, 2, 37, 
    2, 23, 0, 75, 6, 52, 1, 31, 5, 91, 8, 30, 3, 46, 4, 86, 7, 67, 
    0, 74, 7, 53, 6, 75, 1, 14, 2, 68, 8, 18, 5, 27, 4, 42, 3, 47, 
    1, 54, 0, 89, 4, 45, 8, 43, 6, 83, 3, 22, 2,  4, 5, 98, 7, 62, 
    8, 81, 4, 41, 6, 68, 0, 24, 3, 29, 2, 46, 7, 28, 1, 16, 5, 37, 
    4, 66, 3,  2, 2, 42, 1, 76, 6, 46, 0, 75, 8, 91, 5, 62, 7, 33, 
    2, 97, 4, 15, 0, 66, 1, 18, 5, 56, 3, 58, 7, 44, 8, 80, 6, 34, 
    7, 61, 3, 36, 2, 84, 1, 56, 5, 61, 8, 41, 4, 98, 6, 35, 0, 88, 
    3, 76, 6, 66, 1, 47, 4,  8, 7, 11, 0, 30, 5, 32, 8, 42, 2, 19
  };
  const int q1877[] = {
    9, 9, // Number of jobs and machines
    6, 15, 5, 59, 0, 56, 7,  8, 1, 32, 4, 71, 8, 94, 2, 46, 3, 39, 
    8, 48, 3, 29, 5, 51, 0, 30, 6, 15, 1, 17, 4, 13, 2, 68, 7, 58, 
    2, 99, 8,  5, 7, 91, 3, 33, 5, 55, 6, 30, 4, 57, 1,  5, 0,  6, 
    8, 31, 7, 87, 1, 72, 4, 80, 3, 66, 6, 73, 5, 89, 2,  5, 0, 67, 
    7, 50, 3, 84, 4, 29, 8, 14, 1, 54, 6, 25, 0, 22, 2,  4, 5, 23, 
    1, 10, 5, 63, 8, 51, 4,  3, 3, 45, 7, 34, 0, 41, 2, 33, 6, 43, 
    2, 72, 1, 92, 0,  1, 4, 25, 5, 33, 3, 59, 8, 10, 6, 22, 7, 31, 
    4, 95, 6,  2, 3, 32, 0, 35, 7, 93, 1, 10, 8, 84, 5, 17, 2, 68, 
    7, 42, 0, 55, 2, 44, 3, 55, 4, 69, 8,  5, 1, 41, 6,  6, 5, 10
  };
  const int q1878[] = {
    9, 9, // Number of jobs and machines
    6, 55, 7, 41, 0, 44, 4, 70, 2, 59, 5, 17, 1, 28, 3, 95, 8, 85, 
    1, 18, 0, 79, 2, 96, 5, 95, 3, 19, 4, 15, 8, 39, 6, 14, 7, 98, 
    2, 20, 8, 89, 4, 77, 0, 15, 7, 16, 6, 96, 5, 99, 1, 39, 3, 77, 
    8, 81, 1, 30, 4, 36, 3, 11, 0,  6, 6, 23, 7, 45, 2, 35, 5,  8, 
    2, 52, 4, 43, 1, 26, 8,  3, 3, 72, 5, 73, 7, 61, 6, 35, 0, 57, 
    3, 36, 7, 46, 4, 72, 6, 19, 1, 41, 5, 59, 8, 59, 2, 97, 0, 56, 
    5, 17, 6, 35, 7, 65, 8, 43, 3, 62, 0, 26, 2, 42, 1, 11, 4, 73, 
    8, 36, 4, 93, 7, 91, 0, 30, 5, 15, 1, 32, 3, 20, 6, 96, 2, 67, 
    1, 95, 0, 46, 6, 56, 8, 78, 2, 28, 5, 10, 4, 44, 7, 69, 3, 92
  };
  const int q1879[] = {
    9, 9, // Number of jobs and machines
    0, 51, 7,  4, 3, 21, 8, 46, 1, 91, 5, 97, 6, 84, 2,  3, 4, 87, 
    1, 50, 4, 58, 3, 48, 2, 95, 6, 19, 8, 35, 7, 12, 5, 78, 0, 35, 
    7, 55, 3,  4, 0, 15, 1, 97, 4, 70, 2, 68, 6, 94, 8, 52, 5, 98, 
    7, 81, 0, 50, 6, 44, 4, 30, 3, 73, 1, 97, 8, 52, 2,  2, 5, 20, 
    8, 79, 7, 38, 3, 79, 6, 85, 2,  3, 0, 23, 5, 82, 1, 18, 4, 92, 
    7, 87, 2, 33, 1, 67, 8,  5, 6, 17, 4, 83, 5, 15, 3, 55, 0, 35, 
    7,  8, 2, 91, 4, 13, 6, 13, 5, 88, 8, 18, 1, 17, 0, 18, 3, 96, 
    5, 46, 6, 47, 8, 18, 7, 76, 3, 82, 1,  3, 0, 58, 4, 69, 2, 67, 
    5, 79, 6, 67, 1, 70, 4, 77, 0, 97, 3, 14, 7, 67, 2, 80, 8, 12
  };
  const int q1880[] = {
    9, 9, // Number of jobs and machines
    4, 75, 6, 19, 3, 98, 1, 78, 7, 71, 0, 34, 2, 52, 8,  5, 5, 79, 
    1, 50, 8, 12, 3, 18, 5, 88, 4, 44, 7, 11, 6, 55, 0, 75, 2, 48, 
    0, 66, 4, 79, 5, 58, 8, 69, 7, 42, 3, 87, 2, 39, 6, 65, 1, 54, 
    4, 13, 3, 34, 1, 92, 2, 21, 7, 85, 0, 69, 6, 12, 5, 81, 8, 50, 
    3, 12, 6, 32, 8, 66, 1, 19, 5, 85, 7, 29, 0, 51, 2, 46, 4, 62, 
    6, 98, 7, 15, 1, 63, 8, 29, 4, 68, 3, 38, 0, 37, 5, 28, 2, 39, 
    6, 47, 1, 52, 4, 10, 3, 87, 5,  2, 7, 15, 8, 21, 0, 84, 2, 91, 
    6, 24, 0, 51, 7, 21, 4, 40, 1, 72, 8, 74, 2, 69, 3, 92, 5, 23, 
    7, 47, 2, 28, 1, 50, 3, 29, 8, 28, 6, 86, 5, 18, 0, 23, 4, 35
  };
  const int q1881[] = {
    9, 9, // Number of jobs and machines
    0, 32, 1, 81, 2, 41, 7, 86, 3, 46, 5, 65, 8, 89, 6, 19, 4, 77, 
    8, 76, 3, 56, 5, 14, 7, 94, 4, 97, 0, 73, 2, 18, 6, 80, 1, 64, 
    2, 78, 8, 86, 5, 89, 3, 72, 4, 75, 6, 14, 0, 60, 7, 43, 1, 61, 
    2, 80, 6, 14, 4, 50, 3, 34, 1,  3, 8, 50, 0, 11, 7, 79, 5, 17, 
    0, 40, 1, 44, 6, 46, 5, 64, 2, 94, 3, 56, 8, 89, 4, 30, 7, 33, 
    6, 27, 3, 57, 2, 29, 1, 65, 5, 31, 0,  3, 8, 72, 4, 87, 7, 64, 
    6, 18, 2,  8, 0,  4, 8,  8, 1, 24, 4, 22, 7, 61, 5, 63, 3, 19, 
    2, 36, 5, 25, 6, 42, 4, 55, 0, 47, 3, 25, 1, 74, 8, 61, 7, 32, 
    7, 13, 0, 77, 8, 68, 4, 34, 1, 11, 2, 97, 5, 71, 3, 56, 6, 90
  };
  const int q1882[] = {
    9, 9, // Number of jobs and machines
    7, 73, 6, 96, 5, 64, 8, 78, 4, 45, 2, 34, 3, 59, 1, 65, 0, 94, 
    7,  2, 4,  8, 0,  9, 5, 43, 3, 74, 6, 24, 1, 44, 8, 26, 2, 75, 
    6, 64, 3, 49, 2, 32, 4, 61, 5, 23, 1, 95, 8, 24, 7, 17, 0, 88, 
    8, 68, 7,  1, 5, 27, 3, 77, 2, 21, 1, 67, 4, 90, 0, 11, 6, 59, 
    6, 61, 7, 72, 8, 55, 3, 25, 4,  3, 0, 78, 2, 67, 1, 52, 5, 86, 
    2, 91, 4, 80, 6, 20, 0, 83, 1,  6, 8, 23, 3, 89, 7, 93, 5, 68, 
    3, 86, 7, 75, 8, 97, 2, 72, 4, 86, 0, 46, 1, 85, 6, 49, 5, 29, 
    5, 16, 8, 51, 4,  4, 0, 59, 2, 56, 7,  5, 3, 50, 1, 18, 6, 71, 
    1, 27, 5,  7, 0, 52, 7, 93, 8, 67, 6, 48, 4, 44, 2, 52, 3, 80
  };
  const int q1883[] = {
    9, 9, // Number of jobs and machines
    3, 74, 5, 47, 2, 11, 8, 20, 0, 43, 4, 16, 6, 37, 7, 97, 1, 38, 
    6, 74, 3, 90, 7, 40, 0, 73, 2, 91, 4,  2, 5, 54, 1,  2, 8, 60, 
    2, 82, 6, 69, 1, 13, 7, 66, 5, 49, 0,  6, 4, 26, 3,  8, 8, 59, 
    1,  9, 3, 78, 2, 20, 5, 76, 0,  9, 7,  4, 8,  9, 4, 88, 6, 93, 
    0, 24, 8, 40, 2, 36, 6, 43, 1, 24, 4, 59, 7, 15, 5,  9, 3, 18, 
    1, 14, 3, 11, 8, 77, 5, 17, 6, 15, 0, 30, 7,  1, 2, 21, 4, 44, 
    4, 52, 2, 58, 7, 38, 1, 62, 8, 46, 3, 50, 6, 19, 0, 95, 5, 78, 
    6, 25, 8, 64, 1, 92, 2, 45, 7,  9, 4, 59, 3,  6, 5, 17, 0, 24, 
    6, 80, 3, 26, 5, 33, 1, 36, 4, 93, 8, 28, 0, 70, 7, 37, 2, 99
  };
  const int q1884[] = {
    9, 9, // Number of jobs and machines
    4, 13, 7, 33, 2, 63, 1, 78, 3, 95, 0, 53, 5, 73, 6,  4, 8, 42, 
    8, 46, 2, 87, 6, 38, 0, 50, 7, 37, 4, 40, 3, 66, 5, 41, 1, 36, 
    7, 64, 8, 64, 5, 22, 3, 78, 0, 84, 2,  2, 4, 38, 1, 70, 6, 54, 
    7, 89, 0, 92, 8, 67, 4, 44, 5, 99, 2, 75, 3, 83, 6, 68, 1, 53, 
    1, 50, 7, 96, 6, 53, 3, 69, 0, 82, 4, 57, 8, 92, 5,  1, 2, 36, 
    4, 83, 8, 58, 3, 82, 0, 88, 1, 64, 2,  4, 7, 77, 5, 10, 6, 66, 
    4, 86, 2, 85, 8,  5, 0, 98, 3, 75, 7, 96, 1, 74, 5, 32, 6, 20, 
    1, 66, 7, 99, 5, 58, 4, 24, 3, 34, 6, 95, 0, 52, 8, 21, 2, 19, 
    8, 89, 5, 15, 1, 92, 6, 71, 0, 25, 3, 19, 4, 54, 7, 15, 2, 60
  };
  const int q1885[] = {
    9, 9, // Number of jobs and machines
    6, 97, 3, 19, 1, 55, 8, 12, 5, 17, 7, 38, 2, 53, 4, 88, 0, 66, 
    7, 65, 1, 41, 6, 98, 0, 46, 5, 68, 3, 32, 8, 79, 2, 19, 4, 93, 
    1, 75, 0, 19, 5, 68, 4, 72, 6,  2, 8, 20, 2, 65, 3, 82, 7, 56, 
    3, 38, 0, 13, 2, 89, 6,  7, 5, 26, 1, 53, 7, 22, 8, 87, 4, 83, 
    8, 78, 0, 82, 1, 43, 6, 75, 3, 13, 4,  3, 2, 58, 7, 38, 5, 60, 
    2, 67, 1, 66, 3, 24, 4, 11, 6, 53, 7, 15, 0, 69, 5, 71, 8, 75, 
    0, 68, 5, 69, 1, 69, 4, 63, 3, 28, 8, 79, 2, 60, 7, 46, 6,  5, 
    8, 34, 7, 55, 1, 47, 3,  1, 0, 22, 4, 58, 2, 69, 5, 72, 6,  4, 
    1, 36, 8, 14, 6, 94, 2, 69, 3,  7, 4, 15, 0, 15, 7, 72, 5, 59
  };
  const int q1886[] = {
    9, 9, // Number of jobs and machines
    3, 18, 2, 24, 7, 95, 6, 39, 1, 45, 0, 92, 5, 18, 8, 76, 4,  7, 
    5, 84, 2, 20, 4, 46, 7, 44, 0, 78, 8, 86, 6, 22, 1, 36, 3, 90, 
    1, 90, 6, 94, 2, 90, 3, 47, 4, 67, 8, 48, 7, 37, 0, 99, 5, 87, 
    5, 77, 2, 75, 8, 13, 0, 24, 3,  6, 4, 51, 6, 22, 7, 16, 1, 66, 
    6, 34, 2, 62, 5,  9, 4, 63, 3, 88, 1,  2, 0, 74, 7,  8, 8, 93, 
    7,  5, 8, 98, 0, 81, 6, 49, 1, 16, 3, 41, 2, 85, 4, 54, 5, 97, 
    7, 74, 2, 22, 0, 75, 5,  6, 3, 79, 4, 48, 1, 33, 8,  7, 6, 19, 
    6, 62, 1, 41, 7, 93, 2, 64, 3, 17, 5, 10, 8, 18, 4, 75, 0, 92, 
    3, 92, 4, 82, 0, 71, 1, 39, 5, 24, 7, 38, 2, 85, 6, 52, 8, 28
  };
  const int q1887[] = {
    9, 9, // Number of jobs and machines
    6, 97, 0, 57, 3, 83, 2, 29, 4, 43, 7, 37, 5, 26, 8, 71, 1, 12, 
    4, 59, 6, 14, 2, 36, 0, 45, 3, 90, 5, 38, 7, 12, 8, 29, 1,  4, 
    8, 23, 3, 22, 7, 83, 0, 44, 1, 19, 5,  4, 2, 19, 6, 20, 4, 95, 
    6, 70, 7, 95, 5, 13, 0, 51, 4, 40, 2, 48, 3, 18, 1, 82, 8, 87, 
    0, 88, 5, 12, 7, 24, 6, 25, 1, 36, 8, 94, 3, 77, 4, 34, 2, 62, 
    6,  1, 7, 42, 4,  7, 8, 60, 2, 94, 0, 21, 1, 19, 5, 22, 3, 58, 
    3, 30, 0, 57, 5, 78, 1, 94, 7, 53, 6, 13, 2, 51, 4, 42, 8, 84, 
    0, 23, 7, 71, 3, 15, 5, 11, 8, 15, 1, 84, 6, 35, 4, 69, 2, 62, 
    1, 17, 5, 30, 4, 29, 8, 40, 0, 12, 7, 77, 6, 52, 2, 63, 3, 66
  };
  const int q1888[] = {
    9, 9, // Number of jobs and machines
    8, 15, 4, 55, 3,  6, 7, 66, 0, 40, 2, 85, 1, 93, 6, 40, 5, 19, 
    6, 21, 3, 88, 5, 61, 0, 99, 2, 77, 1, 77, 7, 36, 4, 24, 8,  4, 
    3, 77, 2,  6, 0, 20, 6, 13, 7, 75, 8, 91, 5, 83, 4, 71, 1, 48, 
    1, 53, 6, 91, 0, 90, 2, 95, 4, 20, 5, 87, 3, 80, 8, 54, 7, 62, 
    5, 30, 0, 30, 6, 77, 8,  7, 4, 96, 7,  7, 2, 21, 3, 38, 1, 63, 
    7, 90, 0, 76, 3,  8, 2, 69, 6, 41, 1, 93, 4, 89, 8, 62, 5, 70, 
    0, 74, 6, 70, 8,  8, 1,  8, 2, 34, 7, 32, 4, 20, 5, 80, 3, 21, 
    5, 10, 8, 64, 3, 71, 6, 57, 0, 93, 7, 47, 4, 68, 2, 13, 1,  3, 
    8, 12, 3, 29, 7, 29, 2, 83, 1, 11, 5, 40, 6, 70, 0, 70, 4, 17
  };
  const int q1889[] = {
    9, 9, // Number of jobs and machines
    5, 61, 6, 10, 3, 61, 7, 36, 0, 37, 8, 54, 1, 92, 2, 41, 4,  7, 
    7, 36, 6, 26, 5, 30, 8, 59, 2, 52, 1, 58, 3, 13, 0, 66, 4,  7, 
    7, 14, 5, 78, 4, 89, 0, 56, 1, 72, 3, 43, 8, 57, 2, 80, 6, 60, 
    8,  5, 7, 26, 4, 22, 2, 33, 5, 58, 6, 53, 1, 40, 3,  7, 0, 15, 
    5, 72, 1, 15, 6, 33, 0, 21, 7, 42, 3,  8, 4, 77, 8, 83, 2, 83, 
    2, 49, 5, 36, 8, 94, 7, 71, 4, 13, 6, 54, 0, 42, 1, 84, 3, 38, 
    2, 23, 7, 57, 8, 73, 5, 50, 1, 26, 4, 72, 0, 48, 6, 30, 3, 82, 
    1, 99, 3, 25, 5, 12, 7, 83, 0, 89, 2, 26, 4, 23, 8,  9, 6, 60, 
    4, 41, 0, 47, 1, 14, 3,  8, 8, 74, 7, 10, 5, 45, 6, 27, 2, 66
  };
  const int q1890[] = {
    9, 9, // Number of jobs and machines
    7, 70, 8, 30, 3, 74, 2, 43, 0, 73, 6, 11, 5, 26, 1, 20, 4, 28, 
    4,  6, 5, 29, 8, 40, 3, 37, 1, 42, 6, 48, 7, 68, 0, 64, 2, 26, 
    0, 51, 4, 79, 8, 72, 3, 84, 1, 18, 5, 19, 7, 55, 2,  5, 6, 71, 
    2, 31, 0, 69, 4, 43, 1,  3, 6, 21, 5, 75, 8,  8, 7, 80, 3, 60, 
    3, 20, 5, 42, 8, 16, 7, 63, 4, 56, 2, 83, 6, 13, 0, 41, 1, 68, 
    6, 96, 5, 73, 7, 53, 1, 26, 2, 60, 3, 52, 0, 45, 8, 98, 4, 16, 
    8, 80, 5, 15, 0,  2, 4, 83, 6, 66, 2, 69, 1, 73, 7, 16, 3, 44, 
    0, 82, 6, 92, 5, 56, 8, 72, 1, 63, 3, 18, 2, 61, 7, 82, 4, 19, 
    8, 40, 3, 55, 1, 69, 4, 41, 5, 22, 0, 51, 7, 19, 2, 15, 6, 53
  };
  const int q1891[] = {
    9, 9, // Number of jobs and machines
    2, 25, 3, 27, 4, 39, 7, 25, 0, 27, 6,  7, 8, 73, 5, 72, 1, 61, 
    1, 56, 6, 16, 8, 37, 3, 12, 5, 67, 4, 10, 7, 59, 2, 69, 0, 90, 
    5, 56, 6, 64, 2,  7, 7, 19, 4, 60, 1, 19, 0, 40, 3, 28, 8, 54, 
    5, 38, 4, 38, 3, 42, 8, 77, 6, 25, 1, 12, 0, 33, 7, 13, 2,  6, 
    0, 63, 1, 72, 8, 26, 6, 45, 5, 35, 7, 10, 3, 45, 4, 97, 2, 35, 
    3,  1, 5, 11, 1, 62, 8, 76, 6, 87, 7, 12, 4, 66, 2, 37, 0, 31, 
    1, 57, 0, 82, 3, 87, 6, 30, 5, 14, 4, 31, 2, 61, 7, 20, 8, 47, 
    4, 56, 5,  3, 1, 12, 2, 90, 0, 23, 6, 24, 8, 10, 3, 59, 7, 58, 
    0, 76, 4, 29, 2, 98, 3, 12, 6, 33, 8, 65, 7, 30, 5, 91, 1, 47
  };
  const int q1892[] = {
    9, 9, // Number of jobs and machines
    2, 43, 7, 71, 5, 16, 1, 64, 0, 51, 8, 80, 4, 76, 6,  2, 3, 54, 
    3,  7, 0,  3, 5, 91, 1, 59, 4, 51, 2, 96, 7, 82, 8, 34, 6, 42, 
    6, 70, 3, 71, 8, 58, 4, 46, 7, 37, 5, 22, 2, 12, 1, 50, 0, 19, 
    3, 28, 8, 41, 1, 28, 4, 76, 2, 19, 5,  7, 6, 20, 0, 73, 7, 87, 
    5,  6, 7, 51, 3, 45, 6, 79, 1, 90, 8, 20, 2, 56, 0, 91, 4, 96, 
    8,  5, 3, 45, 1, 77, 5, 74, 4, 43, 7, 56, 0,  9, 6, 40, 2, 91, 
    6, 92, 2, 72, 5, 52, 1, 69, 7, 41, 3, 75, 4, 33, 0, 80, 8, 55, 
    3, 70, 4, 79, 6, 13, 8, 59, 0, 13, 2, 33, 5,  7, 1, 68, 7,  4, 
    2, 63, 5, 10, 4, 77, 8, 58, 1, 16, 3,  3, 7, 48, 6, 16, 0, 29
  };
  const int q1893[] = {
    9, 9, // Number of jobs and machines
    5, 96, 6, 82, 7, 83, 0, 23, 4, 35, 2, 80, 1, 17, 8, 32, 3, 92, 
    5, 96, 4, 10, 2, 10, 0, 35, 1, 47, 3, 57, 8, 45, 7, 83, 6, 68, 
    4, 22, 2, 98, 0, 16, 8, 29, 5, 66, 1, 19, 3, 64, 7, 20, 6, 77, 
    8, 48, 5, 64, 2, 86, 3, 69, 7, 46, 0, 99, 6, 65, 4, 31, 1, 23, 
    4, 28, 6, 13, 8, 82, 0, 86, 7, 73, 1, 40, 3, 26, 5, 63, 2, 29, 
    5, 50, 0, 87, 8, 56, 2, 51, 6, 19, 1, 57, 4, 62, 3,  8, 7, 15, 
    1, 45, 0, 84, 4, 23, 6, 65, 3,  4, 5, 53, 8, 49, 2, 41, 7,  7, 
    2, 62, 8, 54, 1, 39, 7, 18, 3, 94, 6, 91, 4, 55, 5, 60, 0, 10, 
    4, 59, 7, 90, 8, 79, 1, 43, 6, 35, 3, 39, 2, 92, 0, 25, 5, 69
  };
  const int q1894[] = {
    9, 9, // Number of jobs and machines
    1, 15, 5, 11, 2, 86, 8, 94, 0, 52, 6, 12, 3, 24, 4, 66, 7, 92, 
    5,  2, 3, 62, 4, 84, 1, 86, 7, 46, 8, 74, 0, 20, 6, 36, 2, 23, 
    2, 49, 0, 50, 6, 34, 1, 71, 5, 13, 8, 86, 3, 31, 4, 85, 7,  6, 
    7, 58, 1, 10, 4, 43, 5, 28, 3, 85, 8, 66, 2, 11, 6, 36, 0, 19, 
    0, 50, 2, 96, 1, 10, 4, 39, 8, 45, 7, 70, 5, 95, 6, 76, 3, 48, 
    6, 61, 8, 55, 5, 43, 2, 23, 4, 29, 1, 29, 0, 11, 7, 98, 3, 23, 
    6, 95, 8, 13, 0, 67, 2, 24, 3,  7, 5, 27, 4, 24, 1, 56, 7, 50, 
    6, 74, 0, 43, 7, 26, 3, 83, 1, 14, 2,  5, 5, 45, 8, 70, 4, 83, 
    5, 49, 7, 67, 2, 35, 8, 31, 0, 12, 6, 34, 1, 21, 4, 18, 3, 76
  };
  const int q1895[] = {
    9, 9, // Number of jobs and machines
    1, 85, 5, 96, 7, 65, 8, 29, 6, 57, 3, 11, 2, 83, 4, 43, 0, 82, 
    0, 73, 5, 88, 6, 60, 3, 79, 7, 89, 4, 78, 8, 62, 1, 42, 2, 33, 
    3, 81, 1, 18, 7, 54, 4, 48, 6, 32, 5, 83, 2, 60, 0, 86, 8, 10, 
    8, 52, 7, 10, 1, 66, 6, 97, 3, 25, 2, 78, 0, 57, 5, 52, 4, 86, 
    6, 53, 0, 76, 1, 57, 8, 82, 3, 22, 2, 26, 7,  5, 4, 40, 5, 31, 
    2, 87, 7, 73, 8, 17, 5, 62, 3, 58, 1, 97, 4, 50, 6, 56, 0, 19, 
    3, 83, 4, 17, 5, 59, 2, 28, 1, 60, 6, 69, 7, 31, 8, 74, 0, 89, 
    2, 49, 7, 45, 0,  9, 8, 68, 3, 16, 4, 17, 1,  1, 6, 67, 5, 25, 
    7, 71, 0, 29, 4, 96, 2, 16, 1, 20, 6, 52, 8,  8, 5, 21, 3, 12
  };
  const int q1896[] = {
    9, 9, // Number of jobs and machines
    7, 93, 1, 33, 6, 67, 4, 83, 5,  5, 8, 68, 2, 18, 0, 57, 3, 37, 
    0, 82, 7, 60, 3, 13, 2, 71, 6, 58, 1, 90, 8, 50, 4, 23, 5, 20, 
    3, 65, 0, 28, 2, 33, 7, 82, 5, 76, 1, 99, 8, 90, 4, 32, 6, 16, 
    8,  6, 4, 57, 6, 80, 5, 69, 3, 49, 0, 86, 2, 17, 1,  1, 7, 66, 
    8, 83, 1, 27, 0, 98, 6, 73, 4,  9, 2, 99, 7, 93, 3, 69, 5, 58, 
    3, 41, 6, 82, 4, 35, 1, 58, 2, 19, 5, 91, 8, 40, 0, 10, 7, 45, 
    0, 86, 7,  4, 1, 68, 5, 95, 8, 58, 6, 44, 2, 71, 4, 26, 3, 39, 
    6, 36, 1, 84, 8, 65, 3, 35, 4, 19, 7, 47, 0, 51, 2, 70, 5,  9, 
    5, 17, 7, 23, 1, 41, 6, 88, 2, 49, 3,  6, 4, 65, 0, 62, 8, 80
  };
  const int q1897[] = {
    9, 9, // Number of jobs and machines
    0, 71, 6,  8, 2, 56, 4, 54, 3, 19, 8, 87, 1, 25, 5, 84, 7, 62, 
    8, 71, 1, 56, 2, 59, 6, 81, 3, 40, 4, 39, 7, 19, 5, 77, 0, 14, 
    2, 63, 4, 18, 5, 36, 8, 39, 7,  2, 1, 50, 6, 97, 0, 47, 3, 31, 
    0, 48, 5, 71, 4, 70, 3, 27, 7, 69, 6, 81, 8, 34, 2,  4, 1, 41, 
    5, 31, 2, 22, 0, 96, 8, 91, 3, 74, 6, 36, 1, 17, 4, 98, 7, 33, 
    4, 44, 7, 33, 1, 11, 5,  1, 2,  4, 8, 41, 0, 42, 3, 71, 6, 30, 
    5, 54, 4, 47, 0,  9, 7, 79, 8, 32, 1, 37, 6, 94, 3, 70, 2, 22, 
    1, 52, 8, 30, 6, 76, 0, 18, 5, 71, 2, 32, 7, 62, 4, 96, 3, 12, 
    2, 11, 0, 24, 7, 48, 1, 98, 8, 46, 5, 15, 4, 87, 3, 97, 6, 48
  };
  const int q1898[] = {
    9, 9, // Number of jobs and machines
    3,  9, 5,  6, 4, 72, 8,  6, 1, 19, 0,  9, 2, 95, 7, 45, 6, 40, 
    6, 87, 4, 47, 2, 51, 7,  6, 0, 16, 3, 14, 5, 93, 8, 97, 1, 19, 
    6, 73, 5, 93, 8,  2, 1, 41, 2, 51, 7, 33, 0, 10, 3, 44, 4, 49, 
    3, 65, 7, 71, 6, 70, 4, 82, 0, 57, 8, 43, 5, 56, 1, 53, 2, 80, 
    4, 14, 5, 67, 2, 68, 7,  2, 3, 77, 0,  1, 1, 70, 6, 63, 8, 11, 
    0, 11, 1, 71, 5, 84, 3, 55, 7, 48, 8, 24, 2, 19, 6, 29, 4, 59, 
    3, 30, 8,  4, 6, 66, 1, 95, 5, 17, 4, 56, 7, 16, 2, 10, 0, 33, 
    2, 55, 7, 89, 5,  4, 8, 24, 3, 86, 6, 19, 1, 38, 0,  6, 4, 28, 
    4, 37, 3, 37, 1, 61, 8, 98, 2, 95, 7, 74, 0,  3, 5, 26, 6, 47
  };
  const int q1899[] = {
    9, 9, // Number of jobs and machines
    1, 43, 3, 55, 4, 44, 2, 64, 5, 95, 7, 40, 6, 58, 0, 87, 8, 11, 
    7, 45, 8,  5, 0, 89, 2, 81, 4,  2, 6, 53, 3, 81, 1, 78, 5, 82, 
    1, 31, 3, 62, 0, 84, 5, 60, 4,  5, 7, 61, 8, 75, 6, 16, 2, 87, 
    3, 90, 7, 88, 2, 83, 8,  7, 0, 32, 1, 69, 5, 24, 4,  5, 6, 65, 
    8, 68, 1, 38, 7, 90, 3, 23, 0, 29, 4, 77, 6, 16, 2, 58, 5,  8, 
    1, 99, 7, 87, 5, 57, 3, 24, 8, 45, 0, 29, 6,  2, 4, 93, 2, 99, 
    6, 15, 3, 24, 8, 50, 2, 36, 0, 58, 4, 74, 5, 64, 7, 65, 1, 72, 
    5, 60, 0, 82, 8, 56, 2, 29, 4, 14, 7, 20, 3, 55, 6, 32, 1, 89, 
    7, 19, 1, 57, 6, 33, 8, 72, 5, 36, 0,  8, 2, 50, 3, 22, 4, 23
  };
  const int q1900[] = {
    9, 9, // Number of jobs and machines
    4, 69, 1, 61, 8, 49, 6,  3, 7, 67, 3, 19, 0, 60, 5, 91, 2, 48, 
    4, 70, 0, 69, 8, 42, 6, 65, 7, 36, 5,  2, 2, 86, 3, 59, 1, 60, 
    0, 92, 5, 94, 1, 76, 4, 87, 3, 46, 7, 10, 2, 99, 6, 43, 8, 39, 
    5, 61, 2,  9, 0, 82, 1,  3, 8, 72, 6,  5, 7, 10, 3, 74, 4, 78, 
    6, 48, 4, 26, 3, 12, 8, 51, 2, 35, 5, 93, 7, 18, 1, 14, 0, 35, 
    2, 72, 4, 72, 7, 20, 0, 34, 6, 39, 8, 63, 1, 48, 5, 45, 3, 98, 
    7, 58, 6, 27, 5, 19, 3, 30, 1,  3, 8, 98, 2, 81, 0, 66, 4, 14, 
    7, 86, 1, 59, 5,  8, 8,  7, 3,  7, 4, 71, 2, 63, 0, 92, 6, 89, 
    8, 97, 3, 98, 4, 61, 1, 24, 6, 61, 0, 90, 7, 86, 5, 38, 2, 84
  };
  const int q1901[] = {
    9, 9, // Number of jobs and machines
    7, 99, 6, 86, 1,  4, 0, 16, 3, 90, 2, 80, 8, 67, 5, 29, 4, 73, 
    1, 31, 8, 74, 5, 74, 4, 12, 3, 95, 0, 44, 2, 73, 7, 76, 6, 13, 
    8, 80, 1,  1, 2, 74, 3, 94, 0, 35, 6, 40, 5, 55, 4, 25, 7, 10, 
    0, 28, 8, 67, 5, 86, 3, 64, 1,  7, 7, 49, 2, 13, 4, 60, 6, 94, 
    5, 59, 2, 91, 0, 84, 7, 43, 3, 31, 4, 19, 8, 51, 6,  8, 1, 70, 
    0, 36, 3, 92, 2, 37, 6, 45, 1, 62, 8, 80, 7,  7, 5, 77, 4, 18, 
    4,  4, 5, 83, 2, 20, 7, 38, 1, 72, 8, 78, 0,  8, 6, 69, 3, 35, 
    7, 28, 1, 54, 4,  2, 5,  7, 3, 33, 6, 92, 2, 41, 8, 62, 0, 15, 
    6, 78, 3, 60, 2, 36, 5, 91, 4, 29, 7, 32, 8, 37, 1, 67, 0, 26
  };
  const int q1902[] = {
    9, 9, // Number of jobs and machines
    1,  4, 8, 95, 6, 94, 3, 78, 4, 46, 0, 68, 5, 59, 7, 98, 2, 75, 
    3, 69, 0, 55, 8, 39, 1, 49, 4,  4, 5, 28, 7, 69, 6,  2, 2, 59, 
    2, 58, 0, 34, 5, 60, 3, 56, 6, 87, 7, 60, 1, 47, 4,  8, 8, 26, 
    2, 11, 8, 98, 1, 13, 5, 87, 3, 70, 7,  2, 6, 20, 0, 94, 4, 60, 
    4, 76, 7, 74, 6, 31, 5, 93, 3, 68, 0, 58, 1, 36, 8, 85, 2, 31, 
    0,  5, 5, 37, 7, 88, 6, 23, 8, 65, 1, 10, 3, 59, 2, 32, 4, 34, 
    2, 95, 6, 79, 1, 79, 8, 26, 0, 56, 7, 64, 4, 42, 3,  8, 5, 29, 
    4, 99, 1, 11, 2, 57, 6, 52, 8, 25, 7, 39, 3, 30, 5, 71, 0, 48, 
    0,  7, 5, 35, 4, 50, 8, 78, 3, 59, 6, 30, 7, 13, 1,  7, 2, 38
  };
  const int q1903[] = {
    9, 9, // Number of jobs and machines
    5, 86, 3, 63, 7, 44, 8, 51, 1, 97, 6, 50, 0, 72, 4, 80, 2, 66, 
    3,  7, 6, 75, 8, 77, 7, 27, 4,  6, 1, 54, 5, 42, 0, 26, 2, 15, 
    1, 14, 8,  9, 4, 46, 0, 24, 6, 14, 7, 32, 2, 47, 5, 31, 3, 18, 
    0, 13, 6, 36, 5, 47, 4, 25, 1, 31, 2, 49, 8, 25, 7, 42, 3, 79, 
    8, 19, 6, 10, 7, 85, 0, 12, 4, 13, 5, 69, 3, 88, 2, 92, 1, 46, 
    4, 74, 0, 49, 1, 14, 2, 41, 6, 61, 7, 89, 3, 43, 5, 91, 8, 46, 
    2,  7, 8, 89, 4, 58, 6, 11, 5, 43, 7, 35, 0, 58, 3, 57, 1, 38, 
    2, 70, 0, 88, 6,  6, 1, 71, 7, 35, 8, 50, 3, 81, 5, 26, 4, 82, 
    0, 77, 2, 86, 5,  6, 1, 15, 8, 78, 6, 76, 4, 11, 7, 64, 3, 25
  };
  const int q1904[] = {
    9, 9, // Number of jobs and machines
    6, 52, 1, 56, 3, 43, 8, 77, 5, 96, 0, 86, 7, 58, 2, 34, 4, 53, 
    5, 84, 7, 51, 0, 97, 8, 51, 3, 99, 1, 32, 2, 63, 4, 80, 6,  8, 
    0, 28, 5, 28, 2,  9, 7, 95, 1, 42, 6, 58, 4, 13, 8, 76, 3, 82, 
    8, 77, 5, 26, 6, 65, 7, 82, 1, 13, 2, 87, 3, 18, 4, 22, 0, 26, 
    4, 50, 3, 93, 6, 49, 8, 47, 1, 70, 0, 56, 2, 79, 7, 67, 5, 89, 
    3, 37, 1,  5, 6, 50, 8, 48, 2, 79, 0, 10, 7, 91, 4, 14, 5, 82, 
    6, 89, 2, 17, 0, 82, 5, 47, 4, 57, 7, 35, 8, 35, 3, 22, 1, 33, 
    4, 32, 2, 66, 3, 96, 5, 90, 8,  7, 6, 19, 7, 27, 1, 34, 0, 77, 
    1,  1, 3, 82, 2, 16, 6, 95, 0, 84, 4, 79, 7, 60, 8, 53, 5,  7
  };
  const int q1905[] = {
    9, 9, // Number of jobs and machines
    3, 19, 2, 89, 6, 36, 4, 47, 0, 68, 7, 66, 8,  7, 5, 87, 1, 44, 
    2, 73, 6, 43, 3, 62, 8, 61, 4, 70, 1, 13, 7, 92, 0, 95, 5, 45, 
    5, 88, 8, 13, 0, 96, 4, 24, 3, 52, 7, 67, 2, 77, 1, 46, 6, 66, 
    3, 24, 0, 95, 7, 23, 8, 50, 1, 17, 6, 40, 4, 99, 5, 17, 2,  8, 
    8, 66, 0, 57, 7, 80, 5, 90, 6, 92, 1, 57, 4, 33, 3,  1, 2, 85, 
    5, 38, 2, 93, 7, 18, 1, 41, 4,  5, 0, 77, 8, 94, 3, 41, 6, 17, 
    5, 37, 0, 38, 7, 83, 6, 15, 2, 39, 1, 77, 3, 29, 4, 20, 8, 56, 
    2, 77, 6,  2, 8, 84, 5, 73, 1, 81, 7, 15, 4, 88, 0, 42, 3, 13, 
    0, 97, 5, 99, 7, 29, 4, 64, 2, 25, 1, 16, 3, 41, 8, 53, 6, 16
  };
  const int q1906[] = {
    9, 9, // Number of jobs and machines
    8, 86, 6, 91, 1,  7, 2, 68, 7, 25, 3, 98, 5, 56, 4, 33, 0, 89, 
    1, 88, 7, 86, 4, 31, 5, 61, 8, 94, 6,  4, 0, 16, 2, 48, 3, 19, 
    0, 55, 2, 67, 1, 99, 4, 69, 7, 72, 8, 31, 6, 56, 5, 28, 3, 10, 
    6, 18, 2, 19, 0, 38, 1, 11, 8, 49, 3, 46, 4, 64, 5, 99, 7, 31, 
    2, 22, 1,  3, 8, 32, 3, 27, 0, 36, 6, 85, 7,  1, 4, 25, 5, 78, 
    7, 21, 6, 51, 3, 48, 5, 73, 0, 67, 8, 44, 1, 15, 2, 42, 4, 48, 
    0, 60, 5, 80, 4, 28, 7,  4, 6, 11, 3, 32, 1, 56, 8, 54, 2,  2, 
    8, 63, 5, 21, 4, 66, 0, 29, 1, 13, 7, 59, 6, 76, 2, 31, 3, 63, 
    5, 60, 1, 88, 2, 44, 3, 47, 0,  2, 7,  7, 4, 29, 8, 86, 6, 80
  };
  const int q1907[] = {
    9, 9, // Number of jobs and machines
    0, 90, 6, 31, 7, 91, 2, 89, 1, 38, 5, 44, 8, 84, 4, 16, 3, 27, 
    4, 65, 5, 28, 3, 34, 8, 94, 7, 24, 1, 78, 6, 37, 0, 64, 2, 59, 
    7, 48, 4,  5, 1, 16, 2, 94, 5, 65, 0,  6, 6, 35, 8, 21, 3, 38, 
    4, 60, 2, 50, 6, 83, 8, 35, 3, 84, 5, 87, 0, 85, 1, 73, 7, 95, 
    8, 36, 7,  9, 1, 36, 0, 24, 3, 57, 6, 46, 4, 77, 2,  4, 5, 82, 
    5, 25, 4, 22, 3, 60, 8, 36, 0, 81, 6, 43, 7, 12, 2, 12, 1, 49, 
    0, 50, 5, 64, 1, 23, 2, 92, 7, 89, 6, 35, 4, 18, 3, 51, 8, 31, 
    7, 69, 6, 66, 2, 20, 8, 69, 4, 92, 5, 99, 1, 30, 3, 24, 0, 46, 
    1, 89, 8, 50, 6, 93, 7, 97, 3, 63, 2, 19, 0,  6, 4, 17, 5, 39
  };
  const int q1908[] = {
    9, 9, // Number of jobs and machines
    3, 20, 0, 13, 1, 99, 8, 48, 7, 93, 5, 50, 6, 78, 2, 62, 4, 96, 
    7, 89, 1, 77, 5, 40, 2, 97, 8, 22, 4, 28, 6,  7, 3, 13, 0, 92, 
    0, 71, 6, 68, 3, 40, 8, 88, 2, 98, 7, 20, 1, 34, 5, 77, 4, 49, 
    4, 14, 2, 44, 1, 21, 3, 43, 6, 46, 0,  1, 7, 25, 8, 10, 5, 81, 
    2, 71, 0, 37, 1, 54, 7, 49, 4, 89, 8, 12, 3, 68, 6, 64, 5, 11, 
    3, 41, 8, 96, 5, 39, 2, 19, 4, 92, 1,  3, 6, 20, 0,  5, 7,  7, 
    1, 16, 5, 75, 7,  4, 3, 52, 0, 29, 2, 94, 8, 75, 4, 95, 6, 14, 
    6, 83, 0, 56, 3, 66, 5, 45, 1, 61, 8, 57, 7, 85, 4, 92, 2, 13, 
    3, 53, 4, 24, 7, 25, 6, 32, 2, 29, 1, 64, 5, 65, 8, 88, 0, 32
  };
  const int q1909[] = {
    9, 9, // Number of jobs and machines
    7, 42, 1, 91, 2, 34, 0, 40, 4, 63, 8, 81, 6, 79, 3, 35, 5,  3, 
    8, 73, 2, 44, 4,  6, 6, 15, 7, 42, 3, 66, 5, 72, 1,  7, 0, 24, 
    3, 60, 7, 40, 5, 88, 6, 85, 2, 42, 1,  2, 4, 15, 0, 44, 8,  2, 
    2, 81, 4, 79, 8, 79, 1, 59, 5,  5, 0, 86, 6, 40, 3, 69, 7, 56, 
    8, 51, 7, 49, 2, 71, 1, 65, 5, 54, 3,  8, 0, 68, 6,  9, 4, 25, 
    3, 42, 8, 75, 0, 19, 7, 20, 2,  2, 6, 95, 4, 94, 5, 50, 1, 11, 
    3, 98, 4, 63, 1, 84, 5, 37, 8, 15, 2, 61, 7, 20, 6, 49, 0, 92, 
    4, 21, 7, 82, 3, 10, 8, 75, 5, 80, 0, 58, 2, 98, 1, 45, 6,  3, 
    5,  7, 8, 27, 0, 62, 6, 20, 2, 37, 3, 52, 4, 13, 1, 21, 7, 56
  };
  const int q1910[] = {
    9, 9, // Number of jobs and machines
    3, 83, 6, 97, 0,  8, 7, 55, 4, 37, 2, 71, 8, 95, 1, 36, 5, 11, 
    0, 39, 3, 40, 5, 52, 7, 16, 1, 14, 4, 66, 2, 18, 6, 42, 8, 67, 
    5, 76, 7, 51, 1, 19, 4, 98, 2, 34, 0, 10, 6, 49, 8, 45, 3, 24, 
    7, 59, 6, 11, 1, 75, 2, 17, 8, 56, 0, 63, 4, 86, 3, 43, 5, 50, 
    8, 82, 0, 64, 1, 78, 2, 41, 3, 21, 7, 49, 6, 11, 4, 92, 5, 71, 
    0, 81, 8, 80, 6, 33, 4, 46, 5,  8, 7, 79, 3, 76, 1, 16, 2, 50, 
    4, 12, 6, 77, 3, 11, 2, 96, 8, 66, 0, 25, 5, 12, 1, 43, 7, 29, 
    7, 29, 6, 84, 5, 77, 3,  6, 1, 97, 4, 99, 0, 54, 2, 14, 8, 58, 
    8,  6, 6, 25, 7, 54, 5, 48, 2, 62, 3, 64, 4, 22, 0, 93, 1, 44
  };
  const int q1911[] = {
    9, 9, // Number of jobs and machines
    1, 29, 5, 32, 0, 58, 7, 31, 2, 48, 8, 13, 3, 21, 6, 83, 4, 89, 
    7, 19, 3, 50, 5, 25, 8, 46, 1, 87, 2, 25, 4, 99, 0, 96, 6, 88, 
    8, 30, 5, 67, 2, 95, 0, 23, 1, 87, 3, 30, 7, 66, 6, 17, 4, 94, 
    4, 33, 8, 48, 2, 68, 6, 82, 0, 13, 3, 70, 5, 38, 1, 16, 7, 89, 
    7, 63, 0, 95, 4, 54, 2,  5, 1, 16, 5,  9, 6, 66, 8,  1, 3, 13, 
    7, 89, 1, 70, 4, 29, 8, 21, 0, 13, 6, 93, 5, 10, 2, 47, 3, 63, 
    5, 96, 7, 70, 2, 91, 4, 24, 1, 48, 0, 91, 3, 59, 8,  5, 6, 85, 
    8, 19, 3, 84, 1, 68, 0, 91, 7, 61, 2, 17, 4, 73, 6, 49, 5, 97, 
    5, 96, 4,  6, 3, 56, 0, 10, 6, 53, 2, 65, 8, 21, 7, 79, 1, 28
  };
  const int q1912[] = {
    9, 9, // Number of jobs and machines
    1,  4, 5, 37, 3, 43, 0, 26, 8, 32, 2, 68, 6, 14, 7, 31, 4, 29, 
    1, 82, 8, 87, 6, 43, 2, 46, 0, 22, 3,  1, 5, 78, 4,  2, 7, 10, 
    6, 32, 0,  8, 8, 72, 2, 65, 3,  9, 5, 62, 7, 41, 4, 23, 1, 59, 
    0, 21, 5, 69, 8, 68, 4, 90, 6, 32, 1,  1, 3, 12, 2, 33, 7, 72, 
    5, 74, 7, 12, 2, 17, 6, 35, 0, 28, 4, 84, 8, 43, 3, 23, 1, 88, 
    7, 47, 5, 44, 2, 74, 3, 51, 0,  2, 1, 42, 4, 52, 8, 99, 6, 93, 
    6, 45, 4, 83, 8, 39, 3, 71, 1, 96, 0, 35, 5, 47, 7, 34, 2, 39, 
    6, 30, 1, 42, 8, 67, 3, 78, 0, 35, 7, 96, 4, 39, 2, 35, 5, 23, 
    7, 93, 2, 80, 6, 85, 4,  4, 3, 67, 8, 71, 5, 82, 1, 85, 0, 77
  };
  const int q1913[] = {
    9, 9, // Number of jobs and machines
    0, 62, 8, 62, 3, 46, 5,  4, 7, 97, 4, 76, 2, 66, 1, 72, 6, 25, 
    1, 79, 3, 31, 8,  4, 7, 13, 4, 55, 5, 32, 0, 31, 2, 47, 6, 67, 
    4, 31, 0, 79, 1, 54, 8, 86, 7, 74, 5, 89, 3,  1, 2, 65, 6, 29, 
    0, 35, 7, 50, 3, 89, 5, 25, 2, 98, 6,  2, 1, 66, 8, 64, 4, 76, 
    0, 53, 5, 54, 3, 29, 1, 65, 8, 65, 6, 10, 2, 81, 7, 62, 4, 81, 
    2, 26, 5, 65, 3, 18, 6, 57, 4,  5, 8, 72, 1, 76, 0, 57, 7, 36, 
    8, 29, 7, 51, 0,  6, 6, 88, 1, 65, 3, 77, 4, 19, 5, 17, 2, 27, 
    6, 71, 7, 80, 0, 65, 8,  4, 1, 81, 5, 90, 2, 20, 3, 55, 4,  5, 
    2,  4, 1, 48, 8, 98, 3, 78, 5, 59, 4, 41, 0, 68, 6, 81, 7, 77
  };
  const int q1914[] = {
    9, 9, // Number of jobs and machines
    1, 14, 2, 44, 0, 58, 3, 29, 4, 81, 8, 91, 7, 55, 6, 29, 5, 64, 
    0, 21, 3, 73, 8, 57, 4, 72, 6, 88, 7, 87, 5,  3, 2, 11, 1, 85, 
    3, 77, 0, 42, 8, 33, 5, 96, 4, 63, 6,  6, 7, 41, 2, 94, 1, 82, 
    8, 15, 4,  5, 1, 17, 2, 38, 7, 79, 0, 28, 3, 45, 6, 64, 5, 73, 
    6, 49, 3, 98, 5, 75, 8, 50, 4, 45, 2, 53, 1,  1, 0, 55, 7, 77, 
    1, 21, 4, 98, 5, 44, 7, 31, 2, 29, 8, 51, 0, 53, 6, 46, 3, 48, 
    1, 33, 4, 83, 7, 59, 2, 81, 8, 63, 5, 31, 3, 49, 0, 43, 6, 79, 
    0, 76, 6, 94, 8, 44, 1, 28, 7, 60, 4, 16, 5,  1, 2, 71, 3, 48, 
    6, 65, 8, 61, 0, 50, 4, 11, 3, 72, 1, 12, 2, 24, 5, 68, 7, 58
  };
  const int q1915[] = {
    9, 9, // Number of jobs and machines
    8, 31, 4, 89, 7, 30, 3, 20, 5,  6, 0, 44, 6, 26, 2, 73, 1,  9, 
    7, 11, 0, 14, 3, 31, 4, 50, 1, 49, 8, 54, 5, 22, 2, 58, 6, 65, 
    6, 62, 5,  8, 1, 75, 0, 15, 3, 22, 2, 66, 7, 80, 8,  2, 4, 93, 
    7, 70, 1,  9, 3,  2, 6, 26, 4, 68, 5,  2, 2, 99, 8, 34, 0, 91, 
    2, 23, 1, 59, 5, 34, 6, 76, 0, 46, 8, 22, 4,  8, 3, 33, 7, 57, 
    8, 25, 2, 12, 7, 24, 5, 83, 3, 57, 1, 10, 6, 30, 0, 40, 4, 87, 
    2, 13, 3, 27, 8, 33, 1, 61, 5, 30, 6, 96, 0, 92, 7, 23, 4, 69, 
    4, 69, 2, 89, 8, 27, 3, 84, 0, 14, 1, 83, 6, 21, 5, 82, 7, 45, 
    6,  9, 3, 16, 8, 99, 0, 71, 1, 72, 2, 46, 4, 62, 5, 39, 7,  1
  };
  const int q1916[] = {
    9, 9, // Number of jobs and machines
    4,  3, 8, 21, 3, 15, 6, 67, 1, 64, 7, 31, 0, 76, 2, 67, 5, 85, 
    3, 21, 2, 78, 6, 14, 5, 38, 4, 91, 7, 63, 0, 92, 1, 12, 8, 73, 
    3, 83, 4, 89, 0, 51, 7, 43, 6, 46, 8, 88, 1, 14, 2, 49, 5, 63, 
    0, 23, 1, 37, 3, 25, 7, 37, 6, 44, 8, 27, 5, 90, 2, 68, 4, 74, 
    6, 99, 0, 36, 7, 41, 1,  6, 3, 84, 4, 86, 5, 59, 2, 53, 8,  8, 
    6, 29, 1, 87, 5, 18, 2, 70, 7, 76, 0, 64, 3, 69, 4,  1, 8, 39, 
    0, 71, 6, 25, 4, 10, 2, 51, 1, 58, 7, 39, 5, 27, 3, 92, 8, 54, 
    7, 23, 4, 79, 2, 66, 6, 48, 5, 12, 3, 46, 1, 20, 0, 17, 8,  7, 
    6, 13, 8, 43, 5, 84, 3, 58, 2, 70, 1, 65, 7, 36, 4,  9, 0, 71
  };
  const int q1917[] = {
    9, 9, // Number of jobs and machines
    0, 92, 5, 22, 7, 72, 2, 68, 8,  2, 1, 93, 3,  5, 4,  2, 6, 20, 
    1, 10, 8, 52, 4,  4, 0,  3, 3, 28, 5, 99, 6, 64, 2, 54, 7, 78, 
    5, 42, 2, 50, 1, 83, 4, 15, 0, 64, 8, 78, 3, 22, 6, 37, 7, 37, 
    7, 36, 0, 63, 5, 63, 4, 40, 2, 43, 8, 49, 6, 39, 1, 50, 3, 81, 
    1,  7, 4, 37, 5, 83, 3, 60, 7, 27, 2, 84, 6, 31, 8, 13, 0, 44, 
    0, 91, 4, 58, 5, 34, 7, 54, 8, 34, 6, 32, 1, 88, 3, 12, 2, 65, 
    4, 78, 1, 23, 8, 92, 6,  9, 7, 20, 2,  9, 0, 62, 3, 81, 5, 22, 
    5, 71, 4, 13, 6, 19, 7, 28, 2, 69, 1, 11, 3, 24, 8, 38, 0, 56, 
    5, 91, 0, 55, 6, 99, 8, 90, 2, 89, 3, 40, 1, 11, 4, 19, 7, 15
  };
  const int q1918[] = {
    9, 9, // Number of jobs and machines
    6, 92, 4, 41, 1,  3, 8, 98, 3, 72, 0, 48, 2, 18, 7, 46, 5, 72, 
    2,  3, 3, 83, 5, 89, 8, 46, 4, 65, 1, 35, 0, 44, 7, 63, 6, 31, 
    7, 97, 0, 76, 2, 79, 6,  5, 4, 55, 1, 85, 8, 82, 3, 63, 5, 65, 
    8, 25, 6, 11, 7, 87, 0,  4, 1,  6, 2, 46, 4, 33, 3, 70, 5, 97, 
    5, 86, 3, 16, 2, 81, 4, 44, 1, 73, 8, 60, 7, 86, 0, 73, 6, 56, 
    1, 87, 5, 76, 8, 21, 2, 10, 6, 33, 4, 60, 0, 40, 7, 52, 3, 15, 
    8, 28, 3, 96, 0, 32, 4, 40, 7,  4, 5, 87, 2, 16, 1, 82, 6, 41, 
    8,  2, 5, 43, 0, 59, 7, 86, 3, 23, 4, 82, 6, 38, 1, 70, 2, 59, 
    8, 95, 4, 19, 5, 42, 6, 52, 2, 89, 1, 28, 7, 61, 3, 23, 0, 46
  };
  const int q1919[] = {
    9, 9, // Number of jobs and machines
    2, 90, 5, 84, 8, 59, 1, 96, 3, 77, 0, 63, 4, 90, 7, 79, 6, 57, 
    7, 72, 8, 75, 1, 18, 4, 48, 6, 43, 2, 16, 0, 35, 3, 95, 5, 43, 
    3, 72, 2, 56, 6, 99, 5, 90, 7, 10, 0, 19, 8, 66, 1, 60, 4, 45, 
    0, 87, 5, 11, 3, 61, 8, 10, 7, 15, 1, 98, 2, 93, 4, 29, 6, 27, 
    5, 45, 1, 70, 6, 89, 0, 62, 3, 17, 4, 68, 7, 19, 2, 93, 8, 66, 
    7, 94, 0, 91, 5, 17, 1,  2, 3, 16, 4, 47, 6, 96, 8, 33, 2,  1, 
    3, 34, 7, 30, 8, 41, 6, 92, 1, 59, 5, 53, 4, 80, 2, 89, 0, 37, 
    7, 36, 5, 22, 2, 38, 8, 65, 0,  1, 3, 99, 1, 88, 6, 28, 4,  6, 
    8, 35, 2,  6, 5,  5, 0, 95, 4, 66, 6, 29, 1, 89, 7, 20, 3, 33
  };
  const int q1920[] = {
    9, 9, // Number of jobs and machines
    0, 95, 5, 75, 3, 99, 4, 84, 1, 72, 8, 66, 6, 26, 7, 52, 2, 32, 
    5, 72, 7, 95, 1, 19, 8, 68, 6, 35, 2,  4, 3, 21, 4, 85, 0, 46, 
    1, 24, 3, 29, 0, 68, 7, 77, 5,  2, 8, 52, 4, 52, 2, 41, 6, 10, 
    5, 40, 2,  6, 7, 44, 0, 55, 6, 73, 8, 84, 3, 95, 4, 76, 1, 16, 
    2, 85, 6, 80, 0, 87, 8, 45, 7, 21, 1, 55, 5, 30, 3, 78, 4, 39, 
    5, 12, 4, 48, 0, 99, 8, 15, 3, 23, 7, 55, 1, 67, 2, 84, 6, 33, 
    4, 81, 8, 91, 7, 45, 2, 67, 1, 40, 5, 52, 3, 71, 6, 17, 0, 47, 
    2, 99, 1, 35, 3, 95, 8, 58, 0, 91, 7, 90, 4, 95, 6, 55, 5, 93, 
    2, 46, 6, 22, 0, 83, 8, 14, 4, 85, 7, 56, 1, 16, 5, 48, 3, 63
  };
  const int q1921[] = {
    9, 9, // Number of jobs and machines
    3, 26, 4, 23, 8, 75, 1,  1, 0, 70, 6,  1, 2, 54, 5, 70, 7,  9, 
    3,  6, 2, 23, 1, 10, 7, 17, 5, 42, 8, 31, 6, 27, 0, 95, 4, 51, 
    0, 59, 2, 65, 4, 92, 1, 51, 6, 15, 5, 16, 8, 24, 7, 34, 3, 99, 
    4,  3, 3, 92, 2,  4, 6, 63, 5, 16, 1, 68, 8, 12, 0, 97, 7, 83, 
    3, 19, 8, 52, 4, 26, 0,  5, 2, 57, 1, 22, 5, 95, 7, 62, 6, 31, 
    3, 52, 7, 28, 2, 65, 0, 39, 1, 30, 4,  4, 6, 96, 5, 37, 8, 31, 
    8, 37, 4,  1, 2, 87, 0, 44, 6, 60, 1,  1, 3, 90, 7, 82, 5, 46, 
    4, 70, 0, 90, 2, 77, 5, 18, 7, 23, 3, 28, 8, 24, 1, 48, 6, 95, 
    6, 78, 1, 53, 2, 31, 7, 93, 0, 83, 3, 13, 5,  7, 8, 15, 4, 73
  };
  const int q1922[] = {
    9, 9, // Number of jobs and machines
    3, 76, 4, 67, 5, 75, 0, 77, 2, 62, 6, 71, 1, 66, 8, 81, 7, 64, 
    3, 36, 4, 20, 8, 35, 7, 33, 5, 84, 1, 40, 6, 65, 0,  7, 2, 71, 
    7, 71, 6, 48, 0, 76, 4, 65, 1, 55, 2,  5, 3, 90, 5, 62, 8, 96, 
    4, 19, 6, 46, 3, 60, 8,  5, 0, 47, 2, 77, 1, 93, 7, 34, 5, 43, 
    0, 29, 2, 41, 5,  1, 4, 76, 3, 77, 1, 25, 7, 59, 8, 32, 6, 51, 
    0, 33, 4, 65, 6, 23, 3, 81, 7, 73, 5, 73, 1, 43, 2, 62, 8, 45, 
    3, 75, 0, 80, 4, 41, 8, 55, 2, 81, 7, 57, 1, 91, 6, 65, 5,  3, 
    6, 89, 4, 34, 3,  8, 1,  5, 5, 40, 7, 86, 0, 10, 2, 97, 8, 70, 
    7, 96, 2, 53, 3, 98, 8, 34, 5, 14, 4, 94, 0, 48, 6, 18, 1, 36
  };
  const int q1923[] = {
    9, 9, // Number of jobs and machines
    1,  9, 2, 89, 5, 56, 0,  7, 6, 33, 8, 89, 3, 25, 4, 12, 7,  7, 
    8, 74, 3, 36, 6, 31, 5, 53, 7, 58, 2, 45, 4, 86, 1, 85, 0, 21, 
    7, 73, 5, 31, 1, 43, 0, 71, 2, 60, 8, 43, 4, 67, 6, 33, 3, 90, 
    3, 57, 5, 15, 7, 68, 0, 12, 4, 88, 1, 71, 2, 74, 8, 50, 6, 57, 
    6, 81, 2, 44, 5, 12, 3, 58, 0, 51, 1, 57, 8, 92, 4, 71, 7, 40, 
    3, 34, 1, 70, 8, 54, 2, 76, 7, 84, 5,  4, 4, 73, 6, 13, 0,  9, 
    6, 78, 2, 89, 3, 99, 5,  7, 4, 79, 8, 33, 1, 15, 7, 25, 0, 24, 
    8, 35, 7,  2, 4, 11, 3, 99, 5, 18, 1, 44, 0, 22, 6, 73, 2, 97, 
    3,  4, 6, 23, 5, 56, 8, 25, 7, 62, 4, 62, 0, 43, 1, 24, 2,  9
  };
  const int q1924[] = {
    9, 9, // Number of jobs and machines
    1, 33, 4, 82, 2, 85, 3, 87, 8, 40, 6,  7, 0, 88, 5, 61, 7, 94, 
    5, 71, 8, 56, 4,  5, 3, 15, 6, 32, 2, 13, 0, 66, 7, 60, 1, 56, 
    6, 47, 4, 19, 8, 32, 0, 70, 3, 92, 7, 48, 5, 65, 2, 51, 1, 73, 
    1, 77, 8, 95, 0, 96, 3, 19, 7, 87, 5, 27, 6, 11, 2, 84, 4, 11, 
    2, 47, 4, 31, 8, 26, 5,  5, 6, 42, 7, 44, 1, 58, 3, 97, 0, 28, 
    3, 93, 5, 84, 4, 25, 1, 29, 6, 58, 2, 19, 0,  5, 8, 51, 7, 72, 
    7, 26, 5, 59, 3, 78, 0, 69, 6, 64, 4, 53, 1,  8, 2,  4, 8, 19, 
    1, 57, 0, 68, 6, 95, 7, 97, 3, 25, 8, 22, 2, 62, 4,  9, 5, 79, 
    5, 67, 8, 98, 2, 86, 3, 36, 4, 26, 1, 15, 0,  3, 6,  7, 7, 53
  };
  const int q1925[] = {
    9, 9, // Number of jobs and machines
    0, 12, 6,  5, 2, 66, 1, 96, 4,  9, 8, 96, 3, 29, 5, 24, 7, 40, 
    1, 65, 5, 65, 0, 16, 4, 42, 7, 50, 2, 57, 3,  6, 6, 85, 8, 11, 
    3, 67, 6, 27, 7, 51, 8, 39, 2, 24, 0, 60, 4,  3, 5, 18, 1, 24, 
    3,  8, 4, 36, 1, 69, 6, 83, 2, 73, 0, 60, 5, 13, 8, 67, 7, 78, 
    4, 59, 6, 63, 2, 45, 8, 37, 1, 23, 0, 31, 3,  2, 7, 40, 5, 98, 
    7, 85, 6, 98, 0, 39, 4, 56, 2, 14, 5, 87, 8, 39, 1, 26, 3, 19, 
    8, 65, 5, 37, 0, 46, 6, 98, 7, 56, 2, 40, 1, 50, 3, 14, 4, 70, 
    1, 80, 6, 62, 0, 55, 5, 18, 4, 91, 3, 19, 7, 30, 2, 78, 8, 65, 
    8, 67, 1, 37, 7, 33, 2, 18, 3, 42, 6, 94, 0, 76, 5, 32, 4, 54
  };
  const int q1926[] = {
    9, 9, // Number of jobs and machines
    3, 52, 6,  6, 5, 22, 8, 64, 0, 73, 4, 39, 7, 63, 1,  1, 2, 42, 
    6, 83, 2, 45, 7,  7, 4, 79, 8, 63, 5, 87, 3, 41, 0, 26, 1, 54, 
    4, 15, 8, 73, 3, 81, 7, 99, 2, 17, 0,  6, 5, 21, 6, 87, 1, 64, 
    3, 45, 1,  2, 8, 47, 5, 65, 2, 34, 7, 83, 4, 10, 0, 46, 6, 57, 
    8, 56, 4, 22, 6, 69, 1, 63, 0, 61, 7, 67, 3, 91, 2,  6, 5, 16, 
    5, 94, 6, 55, 2, 75, 1, 49, 7, 45, 3, 12, 0, 40, 8, 25, 4, 24, 
    1, 47, 8, 25, 0, 66, 5, 55, 6, 20, 2, 78, 3,  3, 4, 76, 7, 70, 
    3, 15, 4,  7, 7, 99, 0, 51, 5, 37, 6,  4, 2, 89, 8, 53, 1, 41, 
    7,  2, 6, 47, 3, 45, 5, 98, 4, 30, 1, 70, 0, 36, 8, 83, 2, 28
  };
  const int q1927[] = {
    9, 9, // Number of jobs and machines
    0, 16, 2, 14, 1,  4, 7, 54, 8, 52, 4, 54, 6,  4, 5, 22, 3, 64, 
    0, 64, 7, 21, 5, 34, 8,  1, 4, 22, 1, 65, 6, 68, 2, 59, 3, 66, 
    0, 26, 4, 95, 6,  6, 5, 43, 1, 53, 3, 13, 7, 85, 8, 65, 2, 21, 
    8, 94, 4, 23, 0, 31, 3, 17, 7, 70, 1, 42, 6, 53, 2, 28, 5, 92, 
    1,  6, 2,  8, 5,  5, 0, 79, 6, 32, 8, 93, 4,  3, 7, 64, 3, 21, 
    1, 38, 8, 95, 3, 32, 2, 98, 6, 53, 4, 20, 7, 72, 5,  8, 0, 13, 
    0, 99, 5, 36, 7, 12, 6, 42, 8, 97, 4, 24, 2, 48, 1, 86, 3, 81, 
    5, 97, 4, 63, 6, 95, 0, 80, 8, 68, 2, 81, 7, 94, 3, 40, 1, 27, 
    2, 80, 6,  7, 8, 56, 0, 63, 5, 99, 1,  1, 7, 68, 3, 10, 4, 63
  };
  const int q1928[] = {
    9, 9, // Number of jobs and machines
    5, 19, 3, 86, 2, 70, 1, 61, 0, 96, 8, 80, 4,  5, 6, 32, 7, 26, 
    7, 85, 8,  9, 6, 21, 5, 84, 2, 47, 1, 81, 0, 94, 4, 47, 3, 78, 
    2, 75, 0, 10, 4, 44, 1, 43, 8,  7, 3, 48, 5, 38, 6, 39, 7, 51, 
    2,  7, 8, 79, 4, 90, 0, 51, 7, 35, 1, 64, 3, 92, 5, 28, 6, 45, 
    6, 21, 0, 96, 1, 14, 2,  6, 4, 44, 7, 68, 8, 71, 5, 39, 3, 55, 
    2, 75, 6, 89, 4, 38, 8, 82, 0, 55, 5, 45, 3, 57, 1, 43, 7,  1, 
    4, 84, 0, 70, 6, 41, 5, 75, 2, 38, 3, 98, 8, 37, 7, 81, 1, 78, 
    7,  3, 8, 56, 4, 88, 1,  9, 3, 36, 0, 25, 2, 75, 6, 55, 5, 23, 
    6, 90, 4, 82, 1, 31, 8,  2, 7, 93, 0, 97, 5, 10, 2, 68, 3, 59
  };
  const int q1929[] = {
    9, 9, // Number of jobs and machines
    8, 69, 6, 12, 4, 84, 0, 82, 1, 94, 7, 76, 5, 47, 3, 68, 2, 50, 
    2, 46, 5, 97, 7, 63, 1, 91, 0, 73, 6, 68, 3, 78, 8, 85, 4, 62, 
    5, 81, 3, 81, 8, 50, 2, 36, 1,  5, 6, 77, 0, 71, 7, 66, 4, 83, 
    0, 31, 3, 11, 8, 20, 4, 89, 5, 55, 1, 99, 6, 24, 7, 56, 2, 35, 
    3, 33, 0, 40, 1, 80, 5, 96, 6, 19, 2, 57, 7, 68, 4, 81, 8, 82, 
    6, 73, 5, 65, 0, 33, 7, 12, 8, 27, 3, 36, 2, 90, 1, 24, 4, 64, 
    4,  9, 0, 73, 7, 71, 2, 73, 8, 25, 5,  5, 3, 44, 6, 41, 1, 57, 
    2, 16, 4, 91, 6, 39, 7, 61, 3, 12, 8, 26, 0, 83, 1, 25, 5, 39, 
    8,  4, 7, 31, 4, 25, 3, 40, 6,  4, 2,  4, 0, 65, 1, 77, 5, 84
  };
  const int q1930[] = {
    9, 9, // Number of jobs and machines
    4, 86, 5, 53, 7, 17, 1, 80, 6, 25, 8, 66, 2, 73, 0, 84, 3, 58, 
    0, 78, 1,  3, 5, 70, 8, 59, 4, 13, 3, 33, 2, 66, 6, 74, 7, 54, 
    0, 79, 6, 20, 7, 29, 8, 23, 5, 71, 3, 97, 1, 84, 2, 92, 4, 87, 
    5, 87, 7, 99, 2,  3, 8,  6, 0, 21, 6, 71, 1, 71, 3, 51, 4, 77, 
    4, 95, 6, 50, 8, 17, 0, 58, 3, 33, 5, 40, 7, 55, 1,  4, 2, 80, 
    2, 54, 8, 74, 3, 25, 4, 36, 0, 57, 7, 76, 1, 98, 6, 55, 5, 93, 
    4, 69, 2, 22, 7, 68, 5, 27, 6, 61, 3, 90, 1, 18, 8, 82, 0, 82, 
    5, 48, 0, 56, 6, 34, 2, 16, 8, 97, 4, 83, 3, 51, 7,  6, 1, 23, 
    1, 99, 7, 13, 0, 51, 5, 83, 4, 24, 6, 46, 8, 29, 2,  8, 3, 64
  };
  const int q1931[] = {
    9, 9, // Number of jobs and machines
    1, 19, 0, 16, 5, 31, 8, 66, 7, 78, 4,  7, 3, 75, 2, 71, 6, 46, 
    1, 33, 6, 72, 2,  3, 5, 56, 7, 72, 4, 58, 3, 63, 0, 22, 8, 99, 
    7, 26, 8, 78, 0, 70, 1, 59, 4, 14, 2, 21, 5, 65, 6, 44, 3, 68, 
    3, 24, 1, 74, 5, 24, 2, 44, 7, 76, 8, 32, 0, 13, 6, 38, 4, 14, 
    8, 55, 3, 99, 2, 79, 4, 78, 0, 14, 7, 37, 6, 30, 1, 97, 5, 59, 
    8, 48, 4, 74, 2, 21, 1, 13, 5, 64, 0, 90, 3, 99, 6, 23, 7, 96, 
    3,  7, 6, 34, 8, 45, 1, 53, 7, 77, 0, 89, 4, 97, 5, 62, 2,  9, 
    8, 27, 4, 76, 1, 87, 3, 67, 5, 63, 6, 19, 7, 71, 0, 89, 2, 82, 
    3, 97, 6, 84, 8, 45, 7,  2, 0, 76, 2, 93, 4,  1, 5, 53, 1, 30
  };
  const int q1932[] = {
    9, 9, // Number of jobs and machines
    7, 37, 1, 86, 8, 95, 4, 27, 0, 57, 6, 43, 2, 86, 3, 41, 5, 43, 
    7, 77, 1, 59, 0, 21, 6, 51, 2, 99, 8,  4, 5, 28, 4, 46, 3, 28, 
    1,  2, 4, 41, 7, 46, 6, 78, 3, 66, 0,  2, 8, 82, 2, 89, 5, 22, 
    6, 22, 5, 89, 3, 82, 8, 77, 1, 84, 2, 37, 0, 44, 7, 67, 4, 57, 
    1, 53, 6, 14, 2, 89, 7,  5, 5, 96, 0, 23, 8, 84, 4, 42, 3, 81, 
    3, 47, 2, 64, 5, 88, 4,  9, 6, 64, 0, 20, 7, 45, 8,  8, 1, 33, 
    1, 70, 6, 49, 2, 17, 3, 60, 4, 23, 7, 62, 8, 38, 5, 20, 0, 11, 
    5, 98, 0, 23, 7, 40, 2, 64, 1, 93, 8, 39, 3, 98, 6, 52, 4, 78, 
    4, 67, 6, 17, 8, 19, 5, 85, 3, 64, 7, 83, 1, 74, 0, 73, 2,  6
  };
  const int q1933[] = {
    9, 9, // Number of jobs and machines
    1, 44, 8, 29, 5, 27, 2, 35, 4, 34, 3, 28, 0, 76, 7, 84, 6, 96, 
    6, 26, 0, 60, 4, 60, 1, 73, 8,  8, 2, 39, 7, 27, 3, 25, 5, 71, 
    2, 85, 7, 20, 3, 26, 1, 32, 8, 82, 5, 11, 4, 25, 6, 73, 0, 10, 
    0,  7, 7, 78, 3, 39, 5, 15, 8, 61, 6, 99, 4, 87, 2, 23, 1, 65, 
    1, 29, 5, 90, 6, 54, 3, 51, 0,  4, 8, 57, 7, 73, 4, 64, 2, 18, 
    4, 36, 8, 75, 5, 65, 1, 83, 7, 68, 0, 38, 3, 36, 2,  9, 6, 86, 
    6, 51, 3, 99, 1, 36, 2, 72, 0, 74, 7, 30, 5, 96, 4, 42, 8, 11, 
    7, 53, 0, 15, 3, 60, 8, 54, 2, 13, 5, 14, 4, 27, 1, 80, 6, 10, 
    7, 99, 0, 30, 6, 14, 8, 35, 2, 67, 5, 28, 3, 80, 1, 42, 4, 89
  };
  const int q1934[] = {
    9, 9, // Number of jobs and machines
    8, 42, 3, 61, 1, 23, 0, 54, 2, 25, 4, 76, 6,  5, 5, 20, 7, 31, 
    8,  3, 3, 95, 7, 43, 6, 51, 1, 72, 4, 33, 5, 44, 0, 39, 2, 86, 
    2, 21, 1, 47, 3, 50, 0, 11, 8, 71, 5, 12, 6, 17, 7, 24, 4, 43, 
    3, 27, 2, 33, 6, 68, 7, 92, 5, 27, 0, 14, 4, 56, 8, 38, 1, 48, 
    5, 15, 0, 68, 6, 85, 4, 50, 8, 83, 3, 92, 7, 37, 1, 37, 2, 69, 
    0, 83, 2, 77, 7, 46, 8, 32, 1, 39, 5, 72, 4, 53, 3, 77, 6, 65, 
    7, 10, 1, 65, 0, 34, 5, 65, 8, 41, 3, 40, 4, 45, 2, 12, 6, 35, 
    2, 47, 5, 91, 1,  5, 8, 10, 0, 30, 7, 30, 6, 58, 3, 23, 4, 58, 
    1, 21, 3, 13, 2,  4, 8, 64, 5, 80, 4, 60, 0, 85, 7, 89, 6, 74
  };
  const int q1935[] = {
    9, 9, // Number of jobs and machines
    5, 56, 1,  3, 3, 30, 8, 76, 4, 11, 0, 51, 7, 21, 6,  3, 2, 10, 
    7, 76, 2, 67, 3, 13, 0,  1, 1, 37, 6, 64, 5, 50, 4, 80, 8, 14, 
    3, 93, 6,  8, 0, 49, 2, 19, 5, 62, 4, 32, 8, 52, 1, 19, 7, 18, 
    5, 85, 3, 42, 0, 17, 2, 81, 4, 46, 7, 87, 8, 43, 1, 95, 6, 29, 
    8, 38, 6,  9, 2, 71, 7, 40, 3, 53, 5, 87, 4, 98, 0, 50, 1, 78, 
    0, 75, 8, 75, 4, 64, 6, 47, 5, 80, 7,  2, 2, 87, 3, 73, 1,  6, 
    8, 35, 1, 88, 2, 30, 4, 36, 3, 17, 6, 63, 7, 15, 5, 93, 0, 50, 
    1, 13, 4, 60, 8, 16, 7, 42, 0, 87, 3, 37, 6, 36, 5, 89, 2, 59, 
    0, 65, 8, 29, 2, 84, 6, 34, 5, 85, 1, 18, 7, 72, 4, 62, 3, 81
  };
  const int q1936[] = {
    9, 9, // Number of jobs and machines
    1, 99, 6,  4, 7, 64, 2, 36, 5, 65, 4,  4, 0,  3, 8, 67, 3,  8, 
    5, 83, 8, 84, 3,  2, 2, 18, 4, 81, 1, 42, 6, 97, 7, 50, 0, 34, 
    5, 99, 1, 94, 0, 19, 8, 22, 3, 46, 2, 63, 7, 98, 6, 62, 4, 10, 
    4, 80, 6, 91, 0, 20, 8, 87, 1, 62, 7, 35, 3, 19, 5, 86, 2, 54, 
    0, 77, 3, 86, 6, 19, 2, 69, 7, 92, 4,  6, 8, 64, 1, 31, 5, 29, 
    5, 93, 6, 44, 8, 31, 3, 91, 0, 78, 1, 97, 2, 48, 7, 62, 4, 27, 
    7, 54, 6, 24, 1, 99, 2, 56, 0,  8, 8, 60, 4, 30, 3,  9, 5, 73, 
    3, 61, 6, 29, 5, 56, 8, 74, 4, 33, 7, 21, 2, 94, 1, 58, 0, 99, 
    2, 84, 7, 94, 4, 71, 3,  6, 1, 85, 6, 76, 0, 75, 8, 45, 5, 22
  };
  const int q1937[] = {
    9, 9, // Number of jobs and machines
    4, 77, 2, 62, 0, 20, 5, 72, 1, 33, 7, 21, 6, 99, 3, 79, 8, 30, 
    4, 34, 1, 20, 0, 64, 2, 77, 5,  9, 8, 14, 6, 51, 3, 21, 7, 97, 
    5, 67, 0, 48, 8, 41, 3, 25, 4,  7, 2,  4, 7, 37, 6, 60, 1, 14, 
    3, 29, 8, 32, 7,  8, 0, 18, 4, 79, 6, 96, 2, 70, 1, 83, 5, 73, 
    3, 61, 1, 61, 2, 84, 7, 14, 6, 56, 8, 98, 4, 13, 5, 13, 0, 45, 
    6, 15, 8, 43, 1, 81, 7, 98, 5, 42, 0, 53, 2, 26, 3, 62, 4, 92, 
    5, 34, 4, 37, 2, 55, 3, 13, 8, 69, 0, 27, 6, 43, 1, 17, 7, 71, 
    0, 10, 4, 34, 8, 55, 5, 55, 7, 18, 3, 93, 1, 15, 2, 36, 6, 93, 
    2, 32, 0, 41, 7, 93, 1,  5, 3, 36, 5, 95, 8, 93, 4, 93, 6, 64
  };
  const int q1938[] = {
    9, 9, // Number of jobs and machines
    0,  9, 1, 84, 7, 57, 3, 27, 6, 68, 5, 85, 4, 73, 2, 53, 8, 49, 
    1, 29, 5, 93, 6, 32, 7, 20, 0, 13, 4, 40, 2, 36, 8, 89, 3, 25, 
    4, 37, 6, 36, 3, 65, 5, 61, 7,  9, 0, 16, 1,  3, 2, 96, 8, 68, 
    0,  6, 2, 62, 8, 25, 6, 65, 1, 85, 5, 77, 4, 25, 3, 93, 7, 31, 
    2,  9, 6, 14, 5, 21, 8, 52, 0, 18, 4, 67, 7, 49, 3, 96, 1, 60, 
    7, 56, 6, 78, 3, 25, 2, 35, 0, 61, 4, 21, 5, 33, 1, 38, 8, 32, 
    2, 69, 7, 21, 1, 32, 3, 36, 5, 32, 6, 36, 8, 30, 0, 46, 4, 44, 
    2, 21, 3, 93, 1, 63, 0, 63, 4, 48, 7, 66, 5, 96, 6, 82, 8, 95, 
    7, 64, 4, 95, 2, 93, 0, 29, 8, 70, 1, 41, 5, 32, 3, 69, 6, 51
  };
  const int q1939[] = {
    9, 9, // Number of jobs and machines
    8, 35, 3, 27, 5, 26, 4, 41, 1, 30, 2, 17, 7, 74, 6, 79, 0, 15, 
    4, 56, 6, 55, 2, 44, 1, 66, 7, 71, 3, 90, 8, 28, 0, 42, 5, 45, 
    8, 51, 3, 34, 1, 86, 6, 90, 4,  9, 7, 76, 5, 86, 0, 68, 2, 92, 
    0, 48, 1, 67, 4, 79, 3, 28, 8, 42, 2, 17, 7,  6, 5, 51, 6, 98, 
    7, 72, 6, 18, 1, 65, 5, 30, 0, 27, 8, 85, 3, 29, 2, 35, 4,  3, 
    4, 65, 2, 76, 5, 42, 8, 36, 3, 76, 1, 27, 6, 61, 0, 48, 7, 29, 
    2, 74, 1, 70, 6, 31, 5, 77, 4, 37, 0, 10, 3, 19, 7, 25, 8, 49, 
    1, 42, 3, 74, 8, 48, 6, 79, 7, 99, 0, 77, 2, 12, 5, 35, 4, 40, 
    3, 31, 7, 85, 6, 73, 4,  4, 5, 67, 2, 33, 8,  4, 0, 89, 1, 50
  };
  const int q1940[] = {
    9, 9, // Number of jobs and machines
    8, 81, 1, 36, 0, 55, 7, 35, 3, 61, 5, 16, 2, 75, 6, 32, 4,  4, 
    4, 91, 2, 91, 5, 79, 6, 11, 8,  1, 0, 22, 7, 90, 1, 40, 3, 18, 
    3, 78, 6, 77, 5, 55, 2, 64, 4, 38, 1,  6, 7,  4, 0, 11, 8, 86, 
    5, 79, 8, 62, 7, 24, 1, 53, 2, 25, 0, 17, 4, 36, 3, 64, 6, 41, 
    0, 88, 8, 53, 2, 19, 1, 47, 7, 47, 4, 38, 5, 11, 3, 52, 6, 60, 
    1, 55, 2, 43, 3, 40, 8, 44, 4, 85, 5, 40, 0, 49, 7, 85, 6, 25, 
    5, 77, 6, 49, 0, 95, 8, 28, 2, 77, 3, 42, 1, 61, 4, 85, 7,  3, 
    8, 43, 0, 90, 1, 41, 4, 46, 7, 72, 6, 29, 3,  5, 5, 67, 2, 70, 
    8, 21, 1, 84, 0, 73, 2, 34, 3, 93, 5, 24, 4, 59, 6, 60, 7, 86
  };
  const int q1941[] = {
    9, 9, // Number of jobs and machines
    6, 86, 8, 44, 4, 94, 1,  6, 0, 74, 2, 64, 7, 48, 3, 62, 5, 62, 
    2, 20, 1, 33, 4, 57, 0, 99, 6, 58, 8, 56, 3, 56, 5, 70, 7, 79, 
    7, 75, 4, 46, 5,  5, 8, 41, 6, 46, 3, 31, 2, 66, 1, 28, 0, 54, 
    0, 93, 5, 99, 1, 79, 4, 92, 2, 98, 3, 39, 7,  7, 8,  8, 6, 35, 
    7, 85, 0, 21, 8, 91, 6,  1, 4, 74, 1, 12, 3, 58, 5, 52, 2, 10, 
    0, 63, 4, 49, 3, 26, 5, 21, 7, 50, 8, 15, 6, 59, 1, 90, 2, 68, 
    1, 26, 5, 71, 6,  2, 0, 27, 3, 84, 4, 72, 8,  6, 7, 96, 2, 97, 
    8, 71, 7, 59, 6, 23, 4, 76, 3, 25, 0, 37, 1, 63, 5,  9, 2, 26, 
    2, 13, 0, 52, 5, 29, 7, 90, 3, 57, 4, 70, 1, 57, 6, 93, 8, 60
  };
  const int q1942[] = {
    9, 9, // Number of jobs and machines
    8, 83, 4, 78, 0, 29, 5, 73, 3, 17, 2, 94, 1, 94, 7, 47, 6, 19, 
    7, 56, 3, 33, 2, 88, 8, 81, 6,  6, 4, 63, 1,  8, 0, 20, 5, 96, 
    0, 64, 8, 69, 5, 73, 2, 45, 6,  7, 4,  1, 3, 83, 1, 79, 7, 13, 
    0, 27, 3, 27, 7, 59, 5, 86, 4, 75, 2, 78, 8, 33, 6,  6, 1, 21, 
    3, 69, 4, 21, 8, 91, 1, 18, 2, 37, 0, 99, 7, 38, 6, 19, 5, 91, 
    6, 70, 4, 78, 7, 17, 0, 68, 1, 52, 3, 40, 8, 90, 5, 90, 2, 75, 
    3,  6, 0, 87, 6, 92, 4, 23, 2,  5, 1,  1, 5, 92, 8, 36, 7, 84, 
    2, 36, 5, 74, 6, 69, 3, 27, 4, 51, 8, 40, 1, 55, 7, 80, 0, 80, 
    3, 32, 5, 40, 0, 92, 2, 48, 6, 18, 8, 54, 7, 53, 4, 27, 1, 85
  };
  const int q1943[] = {
    9, 9, // Number of jobs and machines
    5, 35, 8, 81, 4, 19, 0, 79, 1, 52, 6, 95, 7, 32, 2, 61, 3, 39, 
    6, 85, 4, 64, 1, 32, 2, 28, 0, 10, 5, 10, 7, 67, 8, 75, 3, 91, 
    3, 82, 2, 78, 6, 18, 7,  5, 5, 56, 0, 50, 1, 15, 4, 32, 8, 57, 
    6, 14, 2, 41, 0, 13, 1, 52, 4,  3, 8, 78, 7, 73, 5, 24, 3, 86, 
    6, 93, 8, 16, 0, 94, 2, 13, 3, 22, 1, 72, 4, 96, 5, 49, 7, 20, 
    1, 72, 4, 30, 7, 50, 3, 18, 6, 90, 5, 37, 0, 69, 2, 72, 8, 38, 
    0, 31, 7, 87, 2, 44, 8, 95, 6, 24, 3, 86, 5, 63, 4, 27, 1, 66, 
    6, 30, 3, 79, 4, 66, 5, 30, 2, 75, 0, 69, 7, 71, 8, 20, 1, 40, 
    2, 78, 6, 59, 5, 86, 3, 60, 1, 93, 4, 86, 8, 88, 7, 27, 0,  5
  };
  const int q1944[] = {
    9, 9, // Number of jobs and machines
    2, 68, 6, 77, 1, 71, 7, 90, 0, 13, 5, 92, 4, 96, 3, 48, 8,  4, 
    6, 69, 2, 94, 0, 62, 8, 53, 5, 42, 4,  1, 7, 77, 1, 96, 3, 65, 
    2, 56, 3,  2, 4, 19, 0, 49, 1, 67, 5, 58, 7, 52, 6, 15, 8, 91, 
    4, 98, 3, 41, 6, 19, 7, 68, 0, 84, 5, 59, 2, 32, 8, 99, 1, 45, 
    8, 12, 6, 75, 1, 26, 3, 62, 2, 41, 7, 90, 5, 43, 4, 56, 0, 93, 
    7, 91, 8, 51, 6, 89, 3, 88, 4, 40, 5, 78, 1, 39, 2, 61, 0, 63, 
    3,  7, 4, 92, 6, 43, 5, 94, 1, 12, 7,  7, 0, 24, 2, 26, 8, 70, 
    1, 48, 8, 17, 6, 92, 2, 74, 3, 43, 0, 45, 7, 97, 4, 82, 5, 12, 
    2, 71, 5, 15, 7, 19, 3,  4, 8, 45, 1, 50, 4, 44, 6, 88, 0, 60
  };
  const int q1945[] = {
    9, 9, // Number of jobs and machines
    0, 89, 2, 46, 3, 19, 7, 32, 8, 54, 6,  9, 5,  4, 4, 32, 1, 93, 
    8, 79, 0, 38, 5, 22, 1, 63, 4, 64, 3, 89, 7, 27, 2,  6, 6, 74, 
    3,  6, 2, 30, 0, 48, 1, 88, 4, 88, 5, 14, 6, 69, 8, 80, 7, 34, 
    2, 33, 7, 43, 4, 86, 0, 95, 1, 29, 5, 69, 6, 96, 8, 20, 3, 23, 
    0, 20, 8, 69, 3, 52, 1, 82, 7, 18, 6, 44, 5, 40, 4, 75, 2, 51, 
    5, 74, 7, 37, 0, 22, 6, 48, 4, 41, 2,  4, 3, 78, 8, 12, 1, 66, 
    6,  9, 5,  5, 0, 31, 8, 58, 4, 81, 1, 38, 2, 72, 3, 46, 7, 21, 
    4, 20, 0, 86, 8, 34, 6, 92, 3, 73, 7, 63, 1, 44, 5, 95, 2,  8, 
    0, 56, 1, 24, 4, 24, 5, 97, 6, 72, 7, 72, 2, 80, 8, 50, 3, 14
  };
  const int q1946[] = {
    9, 9, // Number of jobs and machines
    4, 97, 8, 73, 1, 23, 0, 76, 2, 97, 3, 14, 5, 18, 6, 43, 7, 63, 
    8,  3, 2, 45, 5, 69, 4, 40, 1, 95, 6, 23, 7,  1, 3, 21, 0,  7, 
    4, 82, 6, 64, 7, 85, 1, 39, 5, 83, 0, 27, 3, 70, 2, 67, 8, 86, 
    4, 12, 3, 74, 8, 56, 6, 73, 5, 15, 7, 98, 0, 19, 1, 31, 2,  6, 
    5, 40, 7, 79, 4, 31, 1, 10, 6, 35, 8, 78, 2, 63, 0, 74, 3, 23, 
    4, 24, 3, 73, 8, 95, 5, 75, 1, 78, 0, 31, 7, 82, 6,  7, 2, 63, 
    1, 75, 4,  1, 5, 84, 2, 22, 7, 50, 3, 40, 8, 16, 6, 28, 0, 45, 
    4, 49, 3, 66, 2, 16, 8, 53, 0,  2, 6, 89, 1, 32, 7, 20, 5, 63, 
    4, 97, 7, 76, 2, 68, 8, 37, 1, 81, 5,  7, 6, 12, 3,  5, 0, 32
  };
  const int q1947[] = {
    9, 9, // Number of jobs and machines
    7, 33, 5,  6, 8, 12, 1, 73, 2,  3, 6,  3, 3, 52, 4, 58, 0, 84, 
    6, 65, 7,  2, 2, 30, 3, 67, 4, 87, 8, 73, 5, 54, 0, 19, 1, 37, 
    8, 71, 1, 20, 6, 49, 7, 11, 4, 96, 2, 41, 0, 18, 5, 60, 3, 67, 
    2, 24, 6, 75, 1, 97, 0,  9, 3, 52, 5, 59, 4, 55, 8, 87, 7, 75, 
    3, 43, 4,  3, 5, 83, 0, 11, 6, 76, 2, 59, 8,  2, 1, 44, 7, 31, 
    6, 62, 8, 36, 5, 35, 4, 80, 7, 33, 0, 66, 1, 93, 2,  5, 3, 33, 
    3,  4, 7, 26, 5, 33, 1, 22, 0, 55, 4, 43, 6, 47, 8, 62, 2,  4, 
    6,  5, 4, 40, 5, 65, 1, 30, 0, 69, 2, 84, 3, 13, 8, 14, 7, 35, 
    0, 28, 6, 14, 4, 33, 1, 91, 8, 54, 2, 45, 5, 76, 7, 34, 3, 87
  };
  const int q1948[] = {
    9, 9, // Number of jobs and machines
    8, 32, 3, 83, 6, 19, 5,  3, 0, 58, 1,  8, 4, 78, 7,  9, 2, 63, 
    5, 59, 6, 85, 8, 75, 3,  4, 7, 90, 1, 31, 0, 69, 4, 60, 2, 49, 
    2, 71, 3,  6, 4, 64, 8, 16, 7, 29, 6, 67, 0, 52, 1, 45, 5, 25, 
    1, 80, 6,  3, 8, 80, 3, 15, 5, 66, 7, 69, 0,  5, 4, 10, 2, 59, 
    0, 75, 2, 10, 3, 95, 7, 42, 6, 53, 5, 26, 1, 37, 8, 39, 4, 98, 
    4, 57, 2, 95, 8, 22, 0, 42, 7,  3, 5, 12, 6, 67, 1, 58, 3, 12, 
    2, 84, 7, 98, 3,  8, 1, 98, 0, 69, 5, 72, 6, 72, 4, 12, 8, 18, 
    8, 21, 2, 10, 7, 20, 5, 23, 1, 92, 0, 30, 3, 11, 6, 97, 4, 41, 
    4, 71, 7, 71, 6, 10, 2, 67, 0, 51, 1, 69, 5,  2, 8, 85, 3, 12
  };
  const int q1949[] = {
    9, 9, // Number of jobs and machines
    6, 79, 5, 45, 7, 21, 8, 96, 3, 97, 2, 44, 0, 85, 1, 72, 4, 46, 
    3, 20, 4, 31, 8,  1, 5, 56, 0,  8, 2,  5, 7, 68, 6,  9, 1, 98, 
    1,  8, 0, 97, 7, 21, 8, 83, 3, 59, 6, 12, 2, 76, 5, 59, 4, 35, 
    4, 91, 0, 54, 6, 44, 7, 42, 5, 29, 3, 76, 2, 67, 1, 84, 8, 22, 
    6, 29, 1, 91, 5, 97, 2, 60, 3, 75, 4, 83, 0, 73, 7, 12, 8, 68, 
    6, 63, 7, 17, 2, 73, 1, 70, 4, 35, 5, 94, 0, 16, 8, 18, 3, 42, 
    6, 50, 2, 68, 0, 79, 8, 59, 4, 35, 1, 83, 7, 13, 3, 53, 5, 74, 
    7, 16, 4, 41, 8, 56, 3, 68, 0, 55, 1, 60, 6, 63, 5, 15, 2, 89, 
    1, 68, 7, 63, 4, 26, 3, 31, 6, 33, 5, 63, 0, 11, 8, 57, 2, 19
  };
  const int q1950[] = {
    9, 9, // Number of jobs and machines
    1, 96, 8, 96, 0, 86, 2, 43, 4, 94, 7, 35, 6, 62, 5, 84, 3, 66, 
    6, 76, 8, 16, 1, 39, 0, 35, 7, 79, 4, 79, 5, 72, 3, 78, 2,  5, 
    8, 49, 0, 99, 6, 93, 5,  4, 2, 21, 3, 52, 7, 40, 4,  9, 1, 75, 
    0, 99, 6, 20, 3, 11, 4, 44, 1, 97, 2, 18, 5, 56, 7, 88, 8, 48, 
    8, 67, 5, 73, 6, 40, 2, 80, 1, 51, 4, 76, 3, 62, 0, 86, 7, 39, 
    5, 76, 0,  1, 3,  6, 7, 40, 8, 27, 1, 39, 6, 61, 4, 96, 2,  3, 
    4, 18, 3, 75, 7, 27, 0, 70, 6, 60, 5, 37, 1, 84, 2, 77, 8, 65, 
    3, 44, 2, 97, 0, 64, 1, 14, 8, 60, 6, 28, 5, 67, 4, 60, 7, 72, 
    0, 46, 6, 57, 4, 13, 1, 12, 5, 89, 8, 14, 2, 67, 7,  7, 3, 86
  };
  const int q1951[] = {
    9, 9, // Number of jobs and machines
    4, 43, 1, 40, 3, 87, 8, 29, 0, 10, 7, 85, 6, 59, 2, 98, 5, 62, 
    4, 47, 1, 64, 7, 54, 8, 91, 6, 30, 5, 28, 0, 13, 3, 80, 2, 15, 
    2, 37, 5, 12, 8, 68, 4, 57, 3, 25, 0, 30, 1, 90, 6,  2, 7, 63, 
    5, 13, 2, 18, 3, 24, 8, 10, 6,  1, 7, 95, 4, 88, 0, 14, 1, 53, 
    8, 87, 5, 52, 6, 40, 1, 96, 4,  1, 7, 86, 2, 20, 0, 59, 3, 45, 
    7, 42, 1, 57, 6, 87, 3, 37, 8, 86, 0, 93, 5, 34, 4, 34, 2, 85, 
    8, 95, 5, 27, 4, 19, 2, 59, 0, 69, 1, 97, 6,  9, 7, 67, 3, 53, 
    8, 13, 2, 91, 5,  7, 1, 76, 6, 35, 3, 49, 7, 38, 0, 17, 4, 29, 
    4, 83, 1, 17, 0, 98, 7, 10, 2, 53, 6, 77, 8, 57, 5, 80, 3, 38
  };
  const int q1952[] = {
    9, 9, // Number of jobs and machines
    2, 40, 0, 93, 8, 54, 4, 31, 5, 70, 6, 56, 7,  4, 3, 37, 1, 66, 
    1, 72, 8, 14, 5, 97, 6, 42, 4, 42, 7, 49, 2, 15, 3, 20, 0, 86, 
    5, 73, 8,  4, 7, 40, 0, 48, 3, 24, 1, 97, 2, 50, 6, 80, 4, 29, 
    0, 37, 4, 69, 7,  7, 3, 49, 5, 51, 1, 67, 8, 69, 6, 21, 2, 52, 
    0, 48, 2, 94, 1, 27, 5,  5, 3, 54, 6,  6, 8, 60, 7, 12, 4, 82, 
    1, 38, 6, 43, 8, 60, 3, 94, 2, 43, 4, 23, 7, 25, 0, 12, 5, 37, 
    1, 31, 8,  1, 2, 89, 5,  2, 7, 36, 0, 95, 6, 97, 3, 21, 4, 82, 
    0, 82, 8, 27, 7, 19, 3, 20, 1, 51, 5, 28, 4, 87, 6, 54, 2, 58, 
    3, 22, 1, 38, 5, 36, 0, 96, 8, 86, 6,  3, 7, 54, 4, 51, 2, 24
  };
  const int q1953[] = {
    9, 9, // Number of jobs and machines
    3, 23, 5, 73, 0, 67, 7, 96, 1, 72, 6, 36, 8, 95, 4, 92, 2,  5, 
    4, 18, 0, 25, 5, 17, 7, 95, 8,  4, 1, 27, 3, 59, 2, 42, 6, 70, 
    6, 47, 4, 14, 5, 76, 1, 62, 2,  5, 3,  4, 8, 25, 7, 54, 0, 86, 
    5, 69, 0, 89, 1, 82, 6, 24, 7, 60, 8, 23, 4, 82, 2, 91, 3, 20, 
    6, 56, 1, 53, 2,  4, 0, 86, 8,  9, 7, 41, 3, 57, 5, 65, 4, 63, 
    1, 54, 3, 66, 7, 51, 5, 29, 0, 45, 6, 99, 2, 92, 4, 26, 8, 30, 
    0,  7, 2, 55, 1,  1, 8, 57, 7, 35, 3, 69, 6, 95, 4, 45, 5, 91, 
    3,  5, 8, 60, 0, 37, 6, 38, 5, 64, 2, 70, 4, 55, 7,  8, 1, 97, 
    4, 83, 6, 66, 7, 20, 1, 15, 8, 19, 5, 59, 0,  4, 2, 77, 3, 16
  };
  const int q1954[] = {
    9, 9, // Number of jobs and machines
    6, 54, 8, 46, 2, 51, 1, 98, 0, 58, 7, 17, 3, 60, 4, 79, 5, 36, 
    0, 28, 1, 28, 8, 66, 3, 73, 6, 75, 5, 52, 2, 14, 4, 62, 7, 38, 
    6, 37, 7, 97, 2, 12, 4, 70, 3,  2, 0, 25, 1, 85, 5, 25, 8, 64, 
    2, 51, 1, 96, 5, 22, 7, 23, 6, 53, 8, 57, 0, 76, 3, 74, 4, 61, 
    5, 41, 2, 46, 1, 59, 0, 22, 3, 66, 7, 36, 4, 26, 6, 64, 8,  8, 
    8, 24, 5, 70, 0,  7, 6, 16, 2, 41, 4, 47, 3, 54, 7, 81, 1, 20, 
    4, 60, 0,  3, 6, 26, 5, 11, 7, 75, 8, 31, 3, 51, 1, 17, 2,  1, 
    4, 75, 7, 80, 1, 57, 8, 92, 6, 67, 0, 93, 2,  5, 3, 59, 5, 72, 
    3, 67, 4, 87, 2, 26, 5, 91, 0, 84, 6, 13, 1, 44, 7, 94, 8, 55
  };
  const int q1955[] = {
    9, 9, // Number of jobs and machines
    1, 43, 2, 72, 4, 34, 7, 19, 8, 65, 5, 79, 3, 71, 0,  5, 6, 48, 
    1, 27, 3, 47, 0, 24, 2,  2, 4, 95, 8, 54, 6, 59, 5, 46, 7, 96, 
    2, 90, 8, 51, 5, 23, 4, 78, 1, 76, 0, 61, 7, 17, 3,  7, 6, 97, 
    2, 97, 7, 94, 5, 90, 0, 47, 1, 87, 6, 54, 8, 62, 3, 76, 4,  3, 
    7, 13, 4, 43, 5, 55, 2, 78, 1,  6, 0, 21, 3, 83, 8, 89, 6, 92, 
    0, 36, 6, 35, 1, 96, 3,  5, 7, 67, 5,  5, 2, 39, 8, 25, 4, 67, 
    1, 10, 2, 95, 0,  4, 7, 23, 5, 72, 8, 97, 6, 84, 4, 29, 3, 69, 
    2, 21, 6,  3, 4, 58, 5,  9, 7, 48, 3,  6, 1, 56, 8, 44, 0, 17, 
    6, 34, 8, 63, 5, 77, 4, 67, 0, 11, 7, 64, 1, 55, 3, 42, 2, 58
  };
  const int q1956[] = {
    9, 9, // Number of jobs and machines
    8, 46, 1, 97, 6, 44, 7, 90, 3, 80, 4, 53, 2, 43, 5, 92, 0, 87, 
    3, 13, 2, 95, 5, 35, 7, 53, 6, 92, 4,  1, 8, 40, 1, 38, 0,  9, 
    5,  5, 3, 95, 7, 25, 2, 86, 0, 21, 4, 99, 8, 67, 6, 67, 1, 88, 
    5, 68, 2, 64, 4, 99, 0, 36, 1, 74, 8, 61, 3, 57, 7, 78, 6, 48, 
    2, 42, 8, 71, 6, 29, 7, 95, 5, 40, 1, 76, 3, 74, 0, 33, 4,  1, 
    0, 48, 2, 10, 3, 22, 4, 65, 6, 70, 8, 44, 5, 40, 7, 88, 1,  6, 
    5, 62, 1, 68, 8, 70, 6, 43, 0, 45, 2, 73, 4, 93, 3,  6, 7, 34, 
    3,  6, 7, 11, 1, 72, 2, 50, 4, 24, 8, 73, 0, 15, 5, 34, 6, 16, 
    8, 91, 4, 77, 5, 26, 3, 10, 1, 58, 2, 90, 0, 49, 7, 28, 6, 91
  };
  const int q1957[] = {
    9, 9, // Number of jobs and machines
    8, 45, 6, 84, 5, 87, 1, 55, 2, 29, 3, 11, 4, 70, 7, 91, 0, 20, 
    7, 97, 1,  5, 4, 88, 2, 71, 0, 69, 8, 32, 6, 49, 5, 69, 3, 88, 
    0, 28, 1, 90, 7, 48, 3, 86, 2,  4, 5, 71, 8, 85, 6, 15, 4, 76, 
    7, 69, 1, 68, 6, 84, 4, 27, 3, 39, 8, 54, 2, 47, 0, 22, 5, 24, 
    4, 68, 8, 11, 2, 57, 5, 46, 7, 83, 1, 52, 6, 76, 0, 61, 3, 56, 
    0, 20, 8, 78, 2, 43, 4, 38, 5, 44, 3, 45, 1, 96, 6, 69, 7, 81, 
    1, 43, 4, 55, 6,  7, 3, 99, 7, 13, 0,  4, 2, 18, 8, 95, 5, 30, 
    6, 15, 5, 45, 3, 47, 7, 49, 2, 90, 4,  5, 1, 48, 0, 89, 8, 22, 
    3, 98, 5, 52, 0,  4, 1, 90, 4, 80, 6, 32, 2, 38, 7, 92, 8, 28
  };
  const int q1958[] = {
    9, 9, // Number of jobs and machines
    0, 55, 7, 56, 2,  5, 6, 69, 4, 99, 3, 80, 5, 29, 8, 17, 1, 29, 
    7, 76, 5, 90, 6, 36, 4, 18, 1, 27, 2, 44, 3, 19, 0, 76, 8, 78, 
    6, 54, 7, 48, 3, 89, 8, 67, 4,  7, 1, 80, 2, 85, 5, 81, 0, 35, 
    6, 67, 0, 85, 3,  2, 8, 57, 2, 11, 5, 66, 1, 69, 7, 67, 4, 53, 
    4, 67, 6, 40, 8, 56, 0, 64, 3, 98, 2, 65, 7, 84, 1,  6, 5, 50, 
    0, 12, 3, 65, 5, 72, 4, 80, 2, 88, 8, 85, 6, 56, 7, 73, 1, 52, 
    5, 42, 7, 33, 2, 21, 1, 47, 4, 20, 8, 66, 3, 20, 6, 72, 0, 24, 
    6, 70, 0, 23, 1, 74, 4, 66, 5, 96, 3, 87, 7, 89, 8, 57, 2, 58, 
    7, 31, 2, 51, 6, 48, 4, 91, 0, 85, 3, 12, 5,  9, 8, 79, 1,  7
  };
  const int q1959[] = {
    9, 9, // Number of jobs and machines
    7, 53, 3, 20, 6, 79, 2, 32, 5, 60, 1, 95, 4, 10, 0, 16, 8, 89, 
    3, 61, 4, 13, 5, 84, 7, 19, 2,  3, 6, 35, 8, 99, 1, 13, 0, 99, 
    0, 51, 4, 24, 7, 49, 3, 40, 6, 70, 5, 85, 1, 35, 8, 38, 2, 98, 
    0, 43, 2, 88, 1, 95, 6, 37, 5, 86, 8, 12, 4, 89, 3, 96, 7, 38, 
    4, 40, 6, 53, 8, 64, 5, 98, 2, 97, 1, 72, 3, 44, 0, 59, 7, 75, 
    7, 30, 2, 38, 0, 36, 4, 74, 3, 98, 8, 49, 5, 18, 1, 46, 6, 99, 
    5, 29, 0, 45, 3, 38, 2, 36, 4, 98, 6, 49, 8, 34, 7, 58, 1, 67, 
    5, 69, 6, 83, 8, 23, 7, 20, 4, 62, 0, 35, 3, 27, 2, 25, 1, 53, 
    1, 85, 3, 68, 6, 95, 5, 47, 8, 26, 7, 10, 4, 48, 0, 63, 2, 44
  };
  const int q1960[] = {
    9, 9, // Number of jobs and machines
    0, 10, 7, 83, 8, 35, 3, 57, 6, 66, 1,  1, 2, 14, 4, 94, 5, 97, 
    6, 17, 2, 79, 7, 78, 0, 12, 3, 34, 8, 31, 1, 83, 5, 71, 4, 90, 
    1, 65, 7, 45, 5, 94, 2, 66, 0, 48, 3, 49, 6, 53, 8,  6, 4, 19, 
    0, 16, 5, 27, 8, 27, 2, 59, 1, 52, 3, 63, 7, 70, 6, 68, 4, 29, 
    3, 19, 1, 41, 7, 81, 8, 70, 2, 32, 0,  1, 4, 67, 5,  4, 6, 25, 
    1, 93, 4, 59, 2, 47, 3, 60, 8, 25, 6, 69, 0, 14, 7, 40, 5, 69, 
    2, 91, 6, 91, 4, 75, 7, 62, 3, 72, 5, 52, 8, 67, 1, 70, 0,  5, 
    5, 82, 8,  6, 1, 91, 4, 85, 0, 38, 3, 43, 6, 34, 2, 32, 7, 50, 
    8, 72, 6, 73, 7, 96, 5, 44, 4, 87, 2, 93, 1, 88, 0,  5, 3, 97
  };
  const int q1961[] = {
    9, 9, // Number of jobs and machines
    3, 64, 8, 55, 7, 64, 4, 27, 5, 12, 2, 58, 1, 75, 0, 72, 6, 15, 
    6, 17, 1, 33, 3, 39, 2, 26, 7, 41, 8, 44, 0, 95, 4, 62, 5, 64, 
    7, 82, 4, 82, 3,  7, 5, 25, 1, 75, 6, 97, 2, 88, 0, 56, 8, 82, 
    7, 90, 2,  8, 3, 61, 4, 45, 5, 60, 0, 43, 1, 56, 8, 52, 6,  9, 
    4, 84, 7, 40, 3, 17, 1, 19, 8, 88, 0, 31, 5,  3, 6, 27, 2, 42, 
    6, 80, 3,  8, 1, 79, 0, 36, 2, 59, 4, 90, 5, 38, 8, 50, 7, 97, 
    8, 50, 2, 15, 6, 15, 1,  5, 5, 48, 4, 78, 7, 73, 0, 54, 3, 12, 
    3, 88, 4, 74, 7,  2, 1, 82, 6, 97, 2, 76, 0, 63, 5, 81, 8, 85, 
    3, 14, 7, 45, 5, 55, 2, 23, 1, 56, 6, 27, 4, 79, 8, 16, 0, 45
  };
  const int q1962[] = {
    9, 9, // Number of jobs and machines
    0, 94, 3, 36, 8, 61, 6, 37, 1, 26, 4, 20, 5, 76, 7,  9, 2, 57, 
    0, 99, 6, 94, 4,  8, 8, 63, 3, 34, 7, 52, 5, 33, 1, 87, 2,  4, 
    4, 31, 2,  5, 1, 50, 3, 62, 0, 21, 6,  4, 5, 70, 7, 29, 8, 58, 
    2, 43, 4, 23, 6, 46, 3, 96, 0, 62, 1,  1, 8, 37, 5, 55, 7, 98, 
    3,  8, 2,  4, 6, 49, 4, 80, 7, 53, 5,  8, 0, 66, 1, 93, 8, 24, 
    5, 12, 3, 36, 2, 96, 1, 12, 0, 68, 4,  3, 6, 76, 7, 72, 8, 12, 
    5, 79, 2, 91, 8, 41, 4, 16, 6, 75, 7, 86, 3, 39, 1, 27, 0, 59, 
    5, 22, 7, 32, 6, 19, 2, 50, 4,  5, 8, 19, 3, 86, 1, 38, 0, 94, 
    8, 94, 2, 50, 3,  2, 1,  3, 6, 99, 4, 86, 7, 23, 0, 51, 5, 38
  };
  const int q1963[] = {
    9, 9, // Number of jobs and machines
    3, 84, 1, 58, 7, 73, 4, 83, 8, 15, 0, 25, 5, 30, 2, 60, 6, 56, 
    7, 85, 3, 28, 6, 30, 5, 51, 8, 15, 2, 41, 0, 42, 1, 15, 4, 25, 
    4, 42, 3, 41, 6, 89, 8, 40, 7,  6, 2, 85, 1, 98, 5, 62, 0, 20, 
    2, 19, 6, 84, 8, 75, 1, 15, 5, 23, 7, 78, 3, 95, 0, 44, 4, 97, 
    4, 41, 8, 63, 5, 83, 6, 36, 7, 28, 3, 98, 0, 41, 2, 77, 1, 76, 
    4, 75, 3, 61, 2,  1, 1, 59, 5,  2, 8, 47, 0, 93, 6, 32, 7, 63, 
    6, 37, 0, 14, 4, 80, 8, 43, 1, 99, 5, 48, 7, 56, 2, 43, 3, 75, 
    6, 23, 1, 19, 0, 31, 3, 39, 4, 19, 8, 60, 7, 46, 2, 95, 5, 14, 
    7, 54, 2, 18, 8, 20, 0, 69, 5, 93, 4, 95, 3, 12, 6, 77, 1, 33
  };
  const int q1964[] = {
    9, 9, // Number of jobs and machines
    1, 69, 2, 38, 4, 38, 6, 76, 0, 71, 7, 95, 3, 63, 5,  4, 8, 67, 
    8, 82, 5, 48, 0, 85, 3, 93, 4, 85, 2, 98, 1,  9, 6, 90, 7, 29, 
    7, 83, 0, 15, 3, 80, 4, 54, 8, 51, 1, 54, 6, 17, 2, 82, 5,  1, 
    5, 45, 2, 16, 6, 17, 7, 15, 0, 19, 1, 24, 8,  1, 3,  8, 4, 41, 
    1,  4, 7,  2, 8, 47, 6,  3, 0, 82, 4, 62, 3, 64, 5, 39, 2, 24, 
    1, 42, 0, 52, 7, 63, 8, 28, 3, 95, 5, 93, 6, 14, 4, 60, 2, 67, 
    8, 38, 3,  1, 6, 94, 2,  9, 1, 39, 4, 24, 0, 62, 5,  2, 7,  4, 
    3, 38, 1, 29, 5, 49, 6, 83, 4, 23, 7, 99, 8, 37, 0, 48, 2, 34, 
    2, 56, 6, 15, 1, 47, 5, 23, 8, 45, 3, 61, 7, 67, 4, 22, 0, 34
  };
  const int q1965[] = {
    9, 9, // Number of jobs and machines
    5, 19, 4, 12, 7, 69, 3, 27, 6, 69, 2, 63, 0, 13, 8, 78, 1, 83, 
    1, 27, 8, 32, 4, 71, 3, 78, 6, 16, 2, 57, 5, 19, 7, 57, 0, 55, 
    4, 92, 8, 19, 3, 27, 5, 14, 6, 93, 7, 45, 0,  2, 2, 31, 1, 52, 
    3, 72, 1, 96, 5, 22, 0, 45, 7, 22, 2, 43, 8,  6, 6, 46, 4, 53, 
    8, 47, 3, 49, 2, 67, 0, 40, 7, 31, 4, 79, 6, 68, 1, 52, 5, 82, 
    7, 27, 3, 72, 0, 75, 8, 70, 4, 21, 6, 51, 2, 98, 5, 79, 1, 67, 
    0, 62, 1, 60, 3, 45, 7, 38, 4, 28, 2, 56, 5, 27, 6, 15, 8, 42, 
    5, 85, 8, 16, 7, 20, 0, 44, 6, 66, 1, 23, 2, 98, 4, 47, 3, 48, 
    6, 36, 0, 37, 5, 12, 1, 62, 2,  6, 3, 41, 4, 85, 8, 77, 7, 90
  };
  const int q1966[] = {
    9, 9, // Number of jobs and machines
    2, 27, 7, 84, 3, 91, 5, 82, 1, 51, 4, 56, 0, 45, 8, 28, 6, 28, 
    7, 14, 1,  1, 2, 36, 4, 44, 0, 12, 6, 61, 5, 52, 8, 51, 3,  6, 
    7, 30, 1, 60, 5, 47, 0, 83, 2, 85, 6, 66, 8, 82, 3, 88, 4, 54, 
    1, 40, 0, 14, 3,  8, 7, 77, 2, 70, 5, 97, 8, 62, 6, 97, 4, 67, 
    4, 91, 1, 79, 8, 16, 7, 48, 5,  3, 6, 45, 2,  3, 3, 59, 0, 66, 
    5, 85, 2, 63, 7, 28, 0, 91, 3, 30, 6, 98, 8, 99, 4, 97, 1, 28, 
    1, 59, 0, 72, 2, 10, 4, 98, 3, 97, 6, 79, 7, 18, 5, 79, 8, 27, 
    7,  7, 6, 41, 1, 51, 3, 49, 5, 43, 4, 61, 0, 47, 8, 67, 2, 96, 
    2, 45, 1, 92, 6, 80, 0, 43, 4, 33, 5, 11, 8, 28, 7, 40, 3, 31
  };
  const int q1967[] = {
    9, 9, // Number of jobs and machines
    2, 35, 6, 31, 4, 84, 3, 59, 7, 61, 8, 32, 1, 37, 5, 71, 0, 97, 
    8, 92, 6,  3, 3, 16, 4, 61, 0, 84, 1, 23, 2, 42, 7, 35, 5, 21, 
    2, 56, 0, 43, 7, 93, 3, 85, 5, 29, 1, 45, 4, 60, 6, 84, 8, 98, 
    1, 43, 3, 98, 2,  4, 6, 53, 0, 74, 4, 96, 8, 95, 7, 57, 5, 87, 
    0, 88, 3, 37, 8, 97, 1,  1, 7, 11, 6, 95, 4, 48, 5, 18, 2, 28, 
    5, 94, 4,  4, 6, 62, 7, 82, 1, 85, 2, 21, 8, 54, 0, 32, 3, 18, 
    5, 22, 4, 41, 7, 99, 6, 71, 0, 67, 3, 42, 1, 56, 8, 24, 2, 95, 
    4, 32, 6, 85, 2, 25, 0, 14, 3, 72, 7, 82, 1, 39, 8, 90, 5, 51, 
    8, 95, 2, 87, 4, 42, 0, 40, 1, 22, 3, 83, 6, 20, 5, 36, 7, 56
  };
  const int q1968[] = {
    9, 9, // Number of jobs and machines
    4, 16, 8, 90, 7, 76, 5, 89, 2, 23, 6, 15, 1,  8, 0, 54, 3, 20, 
    1, 71, 3, 53, 8,  1, 7, 81, 6,  7, 4, 59, 5, 31, 2, 62, 0, 97, 
    6,  5, 3, 39, 0, 75, 5, 79, 8, 39, 4, 54, 1, 71, 7, 63, 2, 42, 
    8, 17, 6, 62, 2, 99, 4, 88, 7, 42, 1, 60, 3,  8, 0, 16, 5, 99, 
    4, 18, 7,  4, 0, 48, 1, 57, 8, 73, 3, 18, 2, 21, 6,  6, 5, 74, 
    4, 27, 2, 98, 0, 55, 7,  5, 1, 56, 3, 27, 6, 36, 5, 60, 8, 84, 
    3, 25, 4, 77, 6, 98, 5, 79, 7,  9, 8, 93, 1, 58, 0, 84, 2,  2, 
    5, 30, 6, 44, 8, 72, 4, 13, 1, 61, 0, 59, 2, 72, 3,  6, 7, 67, 
    4, 37, 5,  9, 3, 77, 7, 62, 0, 99, 6, 95, 8, 44, 1, 91, 2, 50
  };
  const int q1969[] = {
    9, 9, // Number of jobs and machines
    2, 62, 1, 93, 6, 10, 0, 75, 4, 57, 3, 43, 5, 97, 7, 55, 8, 43, 
    6, 24, 0, 19, 2, 82, 8, 92, 4,  2, 7, 27, 1, 35, 5, 55, 3, 84, 
    8, 65, 2, 97, 4,  1, 1,  5, 5, 79, 6, 84, 3, 45, 7, 17, 0,  6, 
    3, 33, 6,  9, 8, 86, 1, 34, 0, 10, 5, 22, 2, 26, 4, 21, 7, 77, 
    3, 13, 7, 68, 6, 71, 2, 89, 0, 94, 8, 91, 5, 35, 4, 70, 1, 66, 
    4, 19, 5, 49, 3, 41, 8, 51, 2, 42, 1, 91, 0, 96, 7, 55, 6,  6, 
    2, 57, 7, 45, 5, 12, 1, 39, 3, 13, 4, 66, 6, 85, 8, 33, 0, 65, 
    1, 63, 7, 47, 5, 34, 6, 10, 0, 67, 3, 15, 4, 31, 2, 39, 8,  1, 
    5, 83, 7, 69, 4, 65, 8, 80, 0, 78, 1, 45, 6, 89, 2, 92, 3,  8
  };
  const int q1970[] = {
    9, 9, // Number of jobs and machines
    0, 13, 2, 94, 6, 45, 7, 55, 1,  3, 8, 87, 5,  1, 3, 39, 4, 68, 
    0, 91, 2, 85, 3, 16, 6, 50, 5,  6, 8,  8, 7, 74, 1, 67, 4, 54, 
    2, 41, 8,  4, 5,  7, 4, 66, 1, 74, 0, 55, 3, 20, 7, 44, 6, 55, 
    1, 65, 6, 40, 2,  6, 0,  1, 5, 15, 3, 54, 8, 48, 4, 41, 7, 82, 
    4, 89, 5, 68, 7, 99, 3, 13, 1,  2, 0, 35, 2, 75, 6, 49, 8, 32, 
    3, 17, 4,  1, 7, 34, 1, 38, 0,  2, 8, 19, 6, 79, 2, 89, 5, 23, 
    8, 75, 7, 80, 1, 73, 2, 49, 4, 13, 3, 17, 6,  4, 0, 63, 5, 13, 
    0, 98, 8,  6, 3, 65, 5, 25, 1, 59, 7, 72, 2, 87, 4, 35, 6, 51, 
    2, 76, 7, 47, 1, 45, 3, 18, 6, 53, 4, 73, 8, 24, 5, 56, 0,  1
  };
  const int q1971[] = {
    9, 9, // Number of jobs and machines
    1, 65, 4, 88, 3, 15, 2, 51, 5, 86, 0, 91, 8, 81, 7, 90, 6, 85, 
    2, 19, 1, 37, 4, 12, 7, 27, 5, 10, 6, 50, 8, 54, 3, 92, 0, 68, 
    3, 83, 6, 35, 4, 73, 2, 32, 0, 87, 8, 65, 7,  2, 1, 78, 5, 68, 
    2, 76, 8, 85, 4, 78, 5, 72, 3, 97, 7, 36, 0, 55, 6, 32, 1, 79, 
    5, 69, 7,  8, 4, 29, 2, 93, 3, 85, 6, 45, 0, 49, 1, 89, 8, 91, 
    3,  2, 5, 85, 7, 84, 0,  9, 4,  9, 1, 82, 6, 87, 8, 48, 2, 91, 
    8, 79, 1,  8, 0, 94, 3, 78, 5, 63, 7, 69, 4, 16, 2, 64, 6, 50, 
    8, 41, 1, 42, 0, 33, 2, 33, 5, 27, 6, 70, 3,  6, 4, 50, 7, 42, 
    3, 53, 4, 87, 5, 66, 8, 25, 6, 27, 7, 35, 2, 35, 0, 73, 1, 58
  };
  const int q1972[] = {
    9, 9, // Number of jobs and machines
    1, 97, 8, 28, 5, 62, 2, 61, 6, 16, 7, 76, 0, 29, 3, 21, 4, 86, 
    2,  2, 0, 44, 5, 35, 1, 19, 7, 92, 3, 84, 8, 55, 4, 25, 6, 93, 
    4, 76, 0,  1, 5, 25, 1,  2, 7, 94, 6, 70, 8, 57, 3,  6, 2, 51, 
    8, 49, 3, 85, 4, 79, 5,  9, 6, 27, 0, 32, 2, 31, 1, 10, 7, 12, 
    6, 81, 2, 64, 8, 38, 4, 21, 3, 53, 7, 78, 5, 63, 1, 95, 0, 56, 
    5, 28, 4, 53, 6, 45, 1, 66, 7, 74, 2, 69, 0, 65, 8, 52, 3, 15, 
    5, 49, 2, 60, 4, 23, 3, 24, 1, 45, 7, 41, 6, 40, 8, 96, 0, 49, 
    4, 93, 2, 29, 7, 92, 0, 72, 6, 10, 3, 81, 5, 63, 1, 63, 8, 27, 
    7, 50, 0, 13, 5, 40, 3,  8, 1, 96, 8, 10, 2, 46, 4, 43, 6, 74
  };
  const int q1973[] = {
    9, 9, // Number of jobs and machines
    7, 85, 0, 26, 4,  6, 5, 50, 8, 21, 6,  1, 2, 10, 3, 39, 1, 63, 
    8,  2, 2, 56, 7, 11, 1, 23, 5, 39, 6, 13, 0, 41, 4, 15, 3, 53, 
    3, 33, 8, 58, 6, 30, 1, 86, 5, 52, 7, 40, 2, 51, 0, 75, 4, 58, 
    6, 84, 1, 71, 8, 32, 5, 27, 7,  8, 0, 86, 4, 78, 3, 20, 2, 93, 
    0, 71, 8, 43, 2, 74, 3, 90, 1, 61, 7, 37, 4, 15, 6, 83, 5, 52, 
    1,  3, 4, 61, 5, 66, 3, 72, 7, 19, 6, 23, 2, 53, 8, 73, 0, 20, 
    1, 53, 4, 21, 3, 55, 7, 59, 8, 49, 6, 36, 5, 63, 2,  4, 0,  7, 
    4, 96, 0, 55, 7, 23, 1,  5, 3, 37, 2, 37, 8, 29, 5, 99, 6, 91, 
    5, 36, 1, 81, 4, 80, 8, 84, 3, 45, 7, 59, 0, 46, 2, 30, 6, 35
  };
  const int q1974[] = {
    9, 9, // Number of jobs and machines
    8, 27, 5, 51, 3, 92, 0, 75, 4, 89, 1, 12, 7, 68, 6, 72, 2, 97, 
    3, 62, 1, 79, 4, 10, 6, 29, 8, 87, 5, 16, 0, 22, 7, 89, 2, 86, 
    5, 94, 8, 89, 3, 19, 2,  2, 7, 30, 0, 39, 1, 54, 6, 70, 4, 26, 
    7, 60, 3, 19, 5, 44, 0, 84, 4, 56, 8, 22, 2, 29, 1, 29, 6, 58, 
    0, 77, 5, 90, 1, 35, 2, 64, 8, 87, 6, 99, 3, 26, 4, 20, 7, 37, 
    3, 34, 1, 16, 7,  1, 5, 51, 6, 24, 0, 42, 4, 92, 2, 98, 8, 23, 
    1, 98, 4, 14, 7, 42, 0, 86, 6, 31, 2, 28, 8, 45, 5, 27, 3, 42, 
    5,  1, 0, 25, 8, 43, 1, 92, 3, 52, 2, 76, 7, 28, 4, 20, 6, 41, 
    2, 53, 3,  6, 1, 57, 8, 70, 4, 78, 7, 16, 0, 95, 6, 53, 5, 15
  };
  const int q1975[] = {
    9, 9, // Number of jobs and machines
    6, 53, 2, 89, 5, 20, 4, 26, 8, 98, 0, 53, 3, 79, 7, 20, 1, 74, 
    2, 17, 4, 13, 0, 82, 8, 28, 5, 46, 3, 82, 7, 23, 6, 92, 1, 52, 
    0, 60, 2, 37, 1, 64, 6, 58, 7,  1, 3, 84, 5, 53, 4, 89, 8, 15, 
    4, 40, 2, 47, 7, 89, 3, 62, 8, 58, 1,  3, 6, 98, 5, 62, 0, 67, 
    8, 63, 7, 24, 2, 71, 3, 83, 4, 79, 6, 27, 1, 80, 5,  1, 0, 43, 
    7, 25, 6, 24, 2, 67, 5,  5, 3, 57, 1, 96, 8, 17, 4, 83, 0, 25, 
    3, 10, 0, 56, 2, 35, 6, 60, 7, 15, 4, 59, 5,  3, 1, 79, 8, 93, 
    3, 18, 8, 92, 7, 28, 1, 83, 0, 41, 4, 71, 6, 84, 5, 83, 2, 25, 
    8, 35, 0, 91, 6, 72, 7, 59, 5, 57, 3, 91, 1, 93, 4, 54, 2, 49
  };
  const int q1976[] = {
    9, 9, // Number of jobs and machines
    6, 20, 2, 57, 5, 52, 7, 27, 0, 56, 1, 16, 4, 62, 8, 79, 3, 25, 
    7, 36, 0, 41, 3, 46, 8, 77, 5, 51, 6, 34, 2, 26, 1, 20, 4, 33, 
    4, 18, 7, 34, 2, 68, 0, 27, 5, 31, 1, 94, 6, 35, 8, 50, 3, 13, 
    0, 96, 2, 98, 3, 12, 8,  7, 6, 29, 1, 55, 5, 15, 4, 87, 7, 25, 
    1, 66, 4, 14, 5, 52, 2, 86, 6, 91, 8, 47, 7, 46, 0, 87, 3, 58, 
    1,  1, 3, 80, 6, 62, 2, 48, 0, 54, 4, 75, 8, 20, 7, 47, 5, 85, 
    8, 56, 2, 14, 4, 54, 7, 64, 3, 88, 0, 59, 1, 62, 6, 63, 5, 78, 
    5, 15, 2, 66, 3, 44, 6, 36, 4, 27, 1, 30, 7, 73, 8, 41, 0, 34, 
    5, 58, 4, 72, 3, 22, 1, 34, 0, 43, 8, 36, 6, 60, 7, 16, 2, 47
  };
  const int q1977[] = {
    9, 9, // Number of jobs and machines
    6, 82, 8, 59, 3, 67, 2, 74, 7, 76, 1, 75, 4, 36, 5, 42, 0, 87, 
    0, 75, 8, 26, 1, 15, 5, 25, 3, 58, 7, 54, 2, 31, 6, 24, 4, 89, 
    8, 26, 6, 85, 0, 60, 7, 86, 2, 79, 5, 92, 4, 44, 1, 41, 3, 89, 
    8, 23, 7, 70, 0, 19, 6, 93, 4, 55, 1, 97, 2, 72, 3, 66, 5, 59, 
    0, 64, 1, 61, 4, 82, 3, 62, 2,  2, 5, 61, 7, 22, 8, 46, 6,  1, 
    4, 56, 1, 42, 0,  7, 3, 51, 6, 40, 2, 96, 8, 69, 7, 77, 5,  8, 
    1, 74, 7,  4, 6, 28, 4, 55, 3, 63, 5, 64, 2, 16, 8, 77, 0, 69, 
    8,  2, 2, 69, 7,  5, 1, 38, 5, 50, 0, 91, 4, 74, 3,  7, 6, 42, 
    1, 60, 2, 49, 5, 14, 7, 10, 4, 89, 3, 95, 6, 74, 8, 51, 0, 67
  };
  const int q1978[] = {
    9, 9, // Number of jobs and machines
    1, 18, 6, 98, 3, 86, 2, 33, 7, 59, 5, 26, 8, 53, 4, 43, 0, 30, 
    4, 47, 7, 71, 0, 56, 3, 41, 8, 53, 6, 18, 1,  5, 2, 39, 5, 77, 
    2, 16, 8, 23, 5, 13, 6, 36, 3,  3, 4, 91, 0, 97, 7, 16, 1,  1, 
    2, 97, 1, 18, 7, 61, 5, 67, 0, 41, 3, 24, 6, 67, 8, 88, 4, 72, 
    7, 94, 6, 74, 3, 16, 0, 56, 5, 81, 1, 18, 2,  6, 4, 32, 8, 89, 
    8, 40, 7, 94, 1, 75, 4, 52, 0,  4, 2, 58, 5, 10, 3,  7, 6, 64, 
    3, 61, 4, 52, 5, 38, 8, 98, 2, 27, 6,  2, 0,  7, 7, 82, 1,  7, 
    6, 22, 3, 70, 8, 65, 2, 59, 7, 32, 5, 73, 1, 96, 0, 55, 4, 36, 
    2, 85, 8, 72, 3, 42, 0, 57, 1, 70, 5, 88, 7,  4, 6, 22, 4, 27
  };
  const int q1979[] = {
    9, 9, // Number of jobs and machines
    1, 66, 6, 91, 5, 21, 4,  9, 2, 47, 7, 21, 3,  9, 8, 52, 0, 81, 
    0, 24, 4, 47, 5, 85, 6, 47, 8, 41, 2, 80, 1, 54, 3, 49, 7, 91, 
    4, 59, 6,  3, 1, 32, 3, 91, 8, 55, 2, 44, 0, 91, 7, 75, 5, 85, 
    0, 46, 6, 17, 1, 31, 8, 93, 5, 71, 3, 91, 4,  3, 7, 39, 2, 85, 
    2, 65, 5, 24, 4,  5, 1,  6, 0, 55, 3, 76, 7, 24, 8, 65, 6, 64, 
    6, 98, 3, 26, 2, 34, 4, 50, 1, 22, 0, 17, 8, 25, 5, 22, 7, 78, 
    6, 42, 0,  2, 1, 41, 7, 64, 3, 34, 5, 68, 2, 42, 4, 17, 8, 19, 
    0, 79, 4, 21, 7, 94, 1, 86, 6, 30, 2, 59, 5, 26, 8, 68, 3, 54, 
    7, 11, 2, 88, 5, 18, 6, 43, 0,  4, 8, 27, 1, 49, 3,  8, 4, 25
  };
  const int q1980[] = {
    9, 9, // Number of jobs and machines
    7, 42, 0, 53, 1, 51, 6, 20, 3, 23, 2, 71, 5, 71, 4, 81, 8, 91, 
    6, 39, 1, 81, 8, 55, 4, 67, 5, 58, 3, 21, 2, 75, 7, 19, 0, 81, 
    6, 71, 4, 54, 5, 60, 7, 39, 1, 71, 2, 35, 3, 77, 8, 45, 0, 78, 
    1, 68, 3, 61, 2, 96, 0,  4, 5, 70, 4,  9, 6, 82, 8, 90, 7, 14, 
    7, 53, 6,  6, 1, 34, 5, 17, 8, 26, 3, 58, 4, 96, 0, 49, 2, 93, 
    6, 10, 0, 12, 5, 43, 2, 45, 7, 59, 3, 22, 1, 50, 8,  1, 4, 37, 
    8,  1, 3, 92, 4, 94, 2,  5, 0, 86, 6, 85, 7, 60, 1, 10, 5, 54, 
    0, 80, 4, 62, 3, 41, 7, 46, 5, 33, 8, 35, 1, 66, 6, 80, 2, 31, 
    8, 41, 4, 41, 2, 35, 1, 82, 5, 70, 7, 46, 0, 95, 6,  3, 3, 84
  };
  const int q1981[] = {
    9, 9, // Number of jobs and machines
    3, 85, 6, 38, 8, 29, 0, 34, 1, 36, 5, 51, 4, 93, 7, 17, 2, 29, 
    3, 50, 8, 56, 2, 72, 6, 82, 5, 29, 7, 58, 0, 97, 4, 85, 1, 79, 
    0,  1, 5, 88, 7, 59, 2, 68, 6, 95, 4, 29, 1,  4, 3, 64, 8, 92, 
    2, 92, 1, 64, 0, 62, 8, 42, 3, 55, 4, 44, 6, 77, 5, 54, 7, 88, 
    3, 27, 7, 54, 0, 94, 8, 45, 1, 42, 5, 50, 6, 61, 4, 25, 2, 54, 
    7, 45, 3, 24, 4, 36, 2, 80, 6, 75, 1, 83, 8, 53, 5, 35, 0, 51, 
    7, 69, 2, 75, 8, 35, 6, 85, 3, 63, 5, 50, 0,  2, 1, 20, 4, 90, 
    4, 16, 1, 78, 8, 60, 3, 80, 5, 91, 2, 71, 7, 94, 6,  8, 0, 86, 
    8,  7, 5, 15, 0, 82, 1, 57, 6,  3, 4, 57, 3, 54, 2, 92, 7, 35
  };
  const int q1982[] = {
    9, 9, // Number of jobs and machines
    8, 93, 6, 58, 4, 99, 5, 40, 2, 60, 7, 96, 1, 12, 0, 37, 3, 46, 
    4, 21, 7, 77, 1, 36, 2, 50, 3, 57, 6, 80, 8, 48, 5, 15, 0, 40, 
    4,  8, 3, 68, 2, 40, 0, 80, 5, 44, 6, 94, 1, 83, 8, 57, 7, 20, 
    4, 78, 7, 43, 2, 17, 0, 26, 8,  3, 5, 22, 3, 70, 1, 91, 6, 76, 
    4, 35, 7, 70, 5, 11, 8, 20, 2, 77, 3, 37, 6, 65, 1, 39, 0, 93, 
    6, 75, 1, 20, 0, 56, 4, 70, 3, 86, 7, 30, 8, 94, 5, 84, 2, 76, 
    0, 83, 2, 69, 8, 42, 7, 19, 6, 82, 4, 28, 3, 47, 1, 56, 5, 94, 
    5, 78, 2, 42, 1, 85, 7,  8, 4, 55, 6, 21, 0, 56, 3, 27, 8, 62, 
    5,  5, 2, 83, 7, 22, 0, 53, 4, 81, 1, 51, 3, 34, 6,  7, 8,  9
  };
  const int q1983[] = {
    9, 9, // Number of jobs and machines
    4, 60, 2, 87, 5, 91, 8, 93, 6, 53, 0, 23, 7, 25, 1,  3, 3, 68, 
    2, 35, 1, 15, 0, 48, 4, 69, 3, 34, 6, 31, 7, 97, 8, 97, 5,  8, 
    2, 94, 6, 70, 0, 11, 5, 38, 3, 47, 1, 86, 7, 42, 8, 98, 4, 48, 
    0,  9, 6, 73, 3, 72, 5, 66, 1, 49, 2, 25, 7, 78, 4, 15, 8, 23, 
    5, 56, 2, 11, 3, 18, 0, 29, 8, 49, 7, 16, 6, 15, 4, 14, 1, 68, 
    6, 38, 4, 54, 7, 73, 1, 48, 3, 74, 8, 59, 0, 89, 2, 77, 5, 81, 
    4, 15, 7, 94, 6, 78, 5, 78, 2, 63, 0, 27, 8, 22, 3, 88, 1, 68, 
    1, 97, 6, 64, 5, 61, 2, 62, 7,  8, 8, 90, 4, 80, 0, 88, 3, 88, 
    2, 84, 4, 88, 7,  6, 3, 87, 1, 75, 5, 32, 0, 56, 8, 94, 6, 59
  };
  const int q1984[] = {
    9, 9, // Number of jobs and machines
    4, 65, 8, 35, 2,  5, 3, 90, 5, 65, 0, 14, 1, 42, 6, 32, 7, 26, 
    2, 26, 1, 12, 7, 72, 6, 49, 5, 84, 3, 40, 0, 22, 4, 18, 8, 41, 
    8, 36, 5, 89, 0, 39, 4, 79, 7, 67, 6, 49, 2, 85, 1, 54, 3, 16, 
    8, 60, 1, 31, 4, 58, 6, 40, 7, 11, 0,  8, 3, 50, 2, 44, 5, 22, 
    0, 25, 5, 92, 4,  4, 2, 66, 3, 99, 7, 17, 6, 69, 1, 26, 8, 52, 
    8, 61, 4, 11, 2, 67, 3, 96, 6,  1, 0, 12, 1, 36, 7, 70, 5, 53, 
    7, 54, 3,  1, 5, 31, 0, 37, 8, 19, 4, 15, 6, 69, 2, 60, 1, 87, 
    4, 97, 8, 65, 0, 61, 1,  6, 7, 89, 2, 74, 5, 56, 6, 59, 3, 81, 
    0, 88, 6, 16, 4, 50, 2, 12, 5, 62, 7, 56, 3, 81, 8, 60, 1, 56
  };
  const int q1985[] = {
    9, 9, // Number of jobs and machines
    3, 78, 1, 45, 2, 88, 8, 77, 6, 95, 4, 69, 7, 30, 0, 15, 5, 57, 
    6, 27, 3, 52, 2, 67, 8, 95, 7, 60, 4, 76, 5, 42, 1, 68, 0, 12, 
    3, 55, 0, 55, 2, 23, 4, 91, 7, 42, 6, 23, 1, 22, 5, 11, 8,  7, 
    3, 80, 1, 76, 8, 58, 0, 48, 7, 52, 2, 32, 4, 90, 5, 97, 6,  4, 
    7, 22, 8, 63, 6, 45, 1,  9, 4, 41, 2, 50, 5, 19, 0, 94, 3, 72, 
    0, 23, 4, 14, 2, 32, 3, 36, 5, 11, 1, 53, 7, 11, 6, 78, 8,  1, 
    3, 40, 1, 37, 2, 31, 0, 42, 6, 76, 7, 33, 8, 53, 5, 75, 4, 57, 
    4, 47, 0, 53, 8, 62, 5, 61, 1, 47, 2, 23, 6, 96, 3, 69, 7, 89, 
    8, 96, 1, 69, 0, 38, 4, 54, 2, 82, 5, 95, 7,  3, 6, 69, 3, 69
  };
  const int q1986[] = {
    9, 9, // Number of jobs and machines
    7,  8, 4, 17, 2,  2, 1, 33, 8, 10, 0, 52, 5, 90, 6, 64, 3, 45, 
    3, 12, 6, 18, 4, 86, 2, 79, 7, 44, 5, 96, 8, 51, 0, 63, 1,  6, 
    7, 13, 3, 58, 0, 62, 1, 92, 6,  5, 8, 33, 5, 59, 4, 85, 2, 53, 
    1, 44, 7,  8, 8, 82, 4, 64, 0, 23, 6, 12, 5, 90, 2, 25, 3, 90, 
    3, 19, 1, 18, 7, 91, 2, 59, 6, 15, 4, 29, 8, 32, 0, 29, 5, 60, 
    4, 74, 3, 79, 1, 25, 6, 51, 5, 19, 0, 89, 7, 32, 8, 41, 2, 25, 
    1, 20, 3, 85, 2, 44, 7, 36, 0, 72, 6, 81, 5, 42, 4, 79, 8, 68, 
    6, 39, 1, 62, 8, 96, 3, 29, 0, 58, 4, 64, 5, 19, 2, 34, 7, 99, 
    1, 78, 2, 69, 6, 95, 3, 81, 8, 55, 4, 77, 7, 29, 0, 76, 5, 53
  };
  const int q1987[] = {
    9, 9, // Number of jobs and machines
    8, 90, 6, 35, 5, 47, 1, 73, 2,  4, 7, 81, 0, 90, 3, 76, 4, 77, 
    5, 47, 6, 73, 0, 92, 7, 85, 4, 79, 8, 61, 2,  6, 1, 13, 3, 15, 
    0,  1, 2, 59, 8, 97, 7, 87, 1,  3, 5, 82, 3, 24, 4, 48, 6, 61, 
    0, 57, 8, 98, 2, 14, 3, 24, 5, 12, 4, 69, 6, 53, 1, 56, 7, 34, 
    3, 74, 5, 61, 7, 34, 6, 10, 2, 19, 4, 48, 8, 22, 0, 22, 1, 56, 
    4, 72, 7, 59, 3, 83, 2, 20, 0, 73, 5, 70, 8, 92, 1, 59, 6, 23, 
    3, 34, 1, 50, 5, 62, 4, 49, 0, 22, 7, 98, 8, 40, 2, 81, 6, 48, 
    7, 58, 2, 70, 5, 52, 6, 78, 8, 42, 3, 32, 1, 90, 4, 62, 0, 76, 
    5, 71, 0, 72, 7, 10, 1, 59, 8, 23, 2, 58, 6, 73, 3, 73, 4, 33
  };
  const int q1988[] = {
    9, 9, // Number of jobs and machines
    0, 78, 3, 86, 8, 99, 5, 79, 6, 29, 4, 42, 1, 27, 2, 21, 7, 89, 
    0, 94, 5, 83, 8,  4, 3, 94, 1, 81, 4, 72, 7, 37, 6, 11, 2, 81, 
    4, 54, 7,  2, 5, 77, 2, 92, 3, 37, 6,  6, 0, 84, 8, 22, 1, 58, 
    5, 59, 1,  3, 4, 72, 2, 20, 0, 80, 8, 79, 6, 96, 3, 86, 7, 86, 
    0, 71, 1,  5, 5, 47, 7, 52, 2, 14, 8, 45, 6, 59, 3, 81, 4, 75, 
    5, 16, 3, 71, 1, 83, 8, 86, 4, 70, 2, 77, 6, 75, 7, 68, 0,  3, 
    8, 89, 1, 43, 4, 51, 0, 41, 5, 26, 3, 28, 2, 77, 7, 95, 6, 39, 
    8, 71, 3, 25, 7, 83, 0, 66, 4, 93, 6, 75, 5, 86, 1, 43, 2, 69, 
    3, 42, 0, 61, 4, 40, 7, 21, 5, 30, 8,  2, 6,  9, 1,  7, 2, 94
  };
  const int q1989[] = {
    9, 9, // Number of jobs and machines
    3, 47, 2, 46, 8,  5, 5,  8, 1, 92, 0, 49, 6, 63, 7, 90, 4, 26, 
    4,  6, 7, 53, 1, 51, 2, 62, 0, 29, 8, 73, 6, 87, 3, 83, 5, 28, 
    0, 37, 4, 86, 7, 82, 5, 99, 6, 24, 2, 37, 3, 80, 1, 98, 8, 78, 
    7, 34, 8, 89, 5, 47, 2, 83, 6, 57, 3, 27, 1, 42, 4, 95, 0, 85, 
    3, 51, 0, 39, 8, 26, 1, 91, 6, 24, 2, 97, 7, 26, 4, 63, 5, 76, 
    6, 36, 4, 24, 5, 55, 0, 83, 3, 95, 1, 15, 7, 33, 8, 49, 2, 10, 
    8, 27, 5, 96, 6, 76, 4, 50, 3, 54, 0, 35, 1, 48, 7, 18, 2,  2, 
    4, 43, 5, 67, 7, 66, 6, 18, 3,  9, 0, 65, 2, 66, 8, 69, 1, 53, 
    6, 91, 0, 20, 1, 51, 2, 87, 8, 54, 7,  7, 4, 91, 5, 79, 3, 54
  };
  const int q1990[] = {
    9, 9, // Number of jobs and machines
    6, 70, 3, 49, 0, 97, 8, 59, 5, 69, 1, 99, 2, 53, 7, 72, 4, 85, 
    4, 75, 5, 27, 2, 92, 3, 58, 0, 29, 6, 29, 7, 96, 1, 78, 8, 84, 
    6, 39, 1, 65, 5, 40, 8, 61, 7, 81, 4, 98, 2, 61, 3, 35, 0, 85, 
    8, 15, 4, 90, 0,  2, 6, 92, 2, 59, 3,  3, 7, 61, 1, 43, 5, 75, 
    8, 87, 7,  6, 4, 20, 6, 51, 3,  3, 1, 18, 2, 29, 0, 41, 5, 37, 
    8, 49, 1, 13, 7, 64, 3, 99, 0, 25, 6, 22, 4,  9, 2, 77, 5, 37, 
    6, 73, 8, 16, 1, 46, 4, 45, 3,  9, 0,  7, 2, 73, 7, 58, 5, 44, 
    8, 59, 6, 89, 4, 13, 3, 69, 2, 18, 7, 28, 1, 33, 0, 77, 5, 32, 
    6, 13, 5, 53, 2, 28, 3, 67, 0, 42, 1, 50, 4,  8, 7, 96, 8, 50
  };
  const int q1991[] = {
    9, 9, // Number of jobs and machines
    5,  5, 1, 35, 3, 96, 6, 48, 0, 27, 7,  9, 2, 62, 8, 97, 4, 36, 
    3,  1, 5, 11, 1, 22, 6, 30, 2, 81, 4, 68, 8, 50, 0, 21, 7,  2, 
    5, 83, 8,  5, 1, 73, 3, 18, 6, 13, 4, 54, 0, 65, 7, 67, 2, 23, 
    2, 20, 4, 13, 1, 49, 7, 54, 0, 53, 3, 54, 8, 39, 6, 70, 5, 16, 
    1, 22, 8, 27, 4, 58, 6, 38, 3, 96, 7,  1, 5, 48, 0, 35, 2, 45, 
    8, 87, 0, 98, 7, 25, 5,  9, 6, 54, 2, 54, 1,  4, 4, 57, 3, 45, 
    8, 21, 3, 31, 5, 36, 1, 71, 0, 16, 4,  3, 6, 32, 7, 51, 2, 27, 
    1, 12, 2, 93, 5, 30, 4, 40, 6, 65, 8,  9, 7, 50, 0, 96, 3,  9, 
    8, 53, 2, 50, 4, 88, 0, 53, 5, 81, 7, 97, 3, 51, 6, 52, 1, 79
  };
  const int q1992[] = {
    9, 9, // Number of jobs and machines
    6, 21, 1, 98, 2,  5, 0, 58, 8, 67, 4, 25, 3, 48, 7, 44, 5, 78, 
    6, 98, 0, 20, 4, 50, 8,  2, 3, 14, 5, 66, 1, 76, 7, 16, 2, 17, 
    6, 28, 8, 21, 3, 84, 4, 18, 2, 20, 5, 16, 0,  4, 1, 84, 7, 47, 
    2, 60, 7, 93, 8, 47, 3, 60, 0, 16, 1, 17, 4, 39, 6, 22, 5, 33, 
    7,  7, 8, 22, 0, 10, 1, 12, 5, 45, 4, 82, 3, 46, 2, 41, 6, 87, 
    1, 11, 8, 61, 7, 24, 3, 29, 0, 22, 6, 58, 4, 48, 5, 22, 2, 14, 
    4,  3, 5, 62, 8, 23, 1,  1, 0, 10, 3, 59, 6, 56, 2, 57, 7, 71, 
    7, 24, 2, 62, 6, 10, 3, 65, 4, 70, 1, 64, 0, 13, 5, 68, 8, 98, 
    5, 61, 3, 77, 6, 37, 1, 52, 0,  9, 8, 84, 2, 43, 7, 27, 4, 64
  };
  const int q1993[] = {
    9, 9, // Number of jobs and machines
    6, 95, 7, 25, 8, 85, 5, 77, 4, 88, 3, 42, 1, 65, 2, 14, 0, 79, 
    5, 47, 2, 25, 4,  2, 6, 65, 0, 29, 1,  8, 8, 55, 3,  8, 7, 44, 
    4, 52, 2, 25, 3, 33, 0, 19, 8, 18, 1, 51, 7, 29, 5, 52, 6, 23, 
    8, 48, 7, 48, 1,  6, 2, 64, 0, 29, 4,  3, 6,  7, 3, 90, 5, 71, 
    5, 78, 3, 99, 8, 45, 4, 21, 0, 41, 2, 38, 7, 30, 1, 49, 6, 99, 
    7, 91, 3, 88, 5, 98, 0, 86, 1, 77, 4, 79, 6, 80, 8, 52, 2, 98, 
    3, 82, 0, 86, 1, 12, 5, 98, 6, 80, 7, 66, 8,  5, 4, 53, 2, 66, 
    7, 43, 8, 50, 4, 38, 1, 60, 3, 65, 6, 81, 0, 57, 5, 14, 2, 56, 
    1, 92, 5, 35, 4,  6, 8, 57, 2, 32, 3, 27, 6, 66, 0, 52, 7, 94
  };
  const int q1994[] = {
    9, 9, // Number of jobs and machines
    2, 41, 7, 87, 8, 76, 4, 91, 1,  7, 3, 38, 5, 12, 0, 43, 6, 17, 
    1, 80, 3, 40, 5, 78, 0,  4, 7, 85, 4, 45, 6,  8, 2, 80, 8, 10, 
    0, 63, 2, 44, 5,  9, 8, 22, 3, 70, 1, 56, 7, 72, 6, 46, 4, 32, 
    7, 42, 2, 22, 3, 11, 1, 31, 0, 96, 6, 14, 8,  1, 4, 94, 5, 92, 
    4, 23, 0, 60, 1, 81, 5, 66, 7, 70, 3, 56, 6, 75, 2, 80, 8, 55, 
    8, 70, 5,  6, 7, 25, 6, 34, 3, 37, 4, 74, 2, 83, 1, 55, 0, 44, 
    6, 96, 0,  7, 5, 98, 2, 27, 7, 15, 8, 42, 4, 87, 1, 69, 3, 72, 
    2, 37, 4, 30, 1, 30, 6,  7, 5, 79, 0,  5, 7, 74, 3,  1, 8, 44, 
    1, 50, 6, 35, 5, 18, 4, 44, 7, 75, 8, 93, 2,  8, 3, 31, 0, 39
  };
  const int q1995[] = {
    9, 9, // Number of jobs and machines
    4, 13, 1, 41, 5, 62, 3, 96, 2, 19, 6, 11, 8, 46, 0, 76, 7, 44, 
    4, 26, 6, 87, 8, 57, 7,  5, 5, 10, 3, 88, 1, 91, 2, 34, 0,  8, 
    7, 94, 8,  5, 5, 50, 2, 17, 6, 12, 4, 19, 0, 59, 1, 14, 3, 12, 
    4, 73, 0, 73, 3, 53, 6, 86, 1, 48, 8, 67, 7, 97, 2, 15, 5, 59, 
    0, 34, 5, 48, 4, 37, 8, 98, 3, 65, 7, 86, 2, 91, 1, 73, 6, 99, 
    0, 94, 2, 40, 1, 83, 7, 12, 4, 68, 8, 23, 5, 67, 6, 82, 3, 74, 
    0, 94, 5, 87, 2, 93, 1,  8, 3, 59, 7, 65, 4, 12, 8, 47, 6, 77, 
    7, 17, 1, 69, 2, 81, 8, 68, 3, 37, 6, 89, 4, 84, 0,  3, 5, 92, 
    4, 84, 3, 25, 8, 32, 5, 40, 6, 91, 0, 68, 2, 47, 7, 29, 1, 26
  };
  const int q1996[] = {
    9, 9, // Number of jobs and machines
    5, 40, 4, 94, 2, 32, 0, 59, 8, 94, 6, 34, 7, 85, 3, 39, 1, 76, 
    5, 59, 1, 82, 8, 81, 7, 43, 4, 18, 6, 37, 0, 92, 2, 82, 3, 78, 
    8, 50, 0, 76, 3, 33, 1, 47, 5, 78, 4, 96, 7, 85, 2, 10, 6, 68, 
    2, 75, 7, 61, 4, 56, 8, 61, 0, 88, 6, 24, 5, 51, 3, 93, 1, 49, 
    1, 61, 6, 45, 8,  5, 3,  2, 2, 13, 4, 27, 7, 15, 0, 99, 5, 90, 
    1, 12, 2, 61, 7, 73, 8, 11, 4, 48, 6, 56, 5, 26, 0, 27, 3, 25, 
    5,  5, 4, 75, 6, 71, 8, 58, 2, 20, 0, 91, 3, 17, 7, 90, 1, 29, 
    8, 24, 4, 47, 7, 56, 5, 68, 6, 28, 0, 15, 3, 43, 1, 63, 2, 27, 
    7, 22, 5, 11, 4, 47, 2, 39, 8, 20, 0, 17, 1, 45, 6, 85, 3, 23
  };
  const int q1997[] = {
    9, 9, // Number of jobs and machines
    3, 91, 4, 88, 8, 99, 1, 23, 7,  2, 0, 91, 2,  1, 6, 48, 5,  9, 
    3, 74, 5, 37, 0, 62, 8, 81, 1, 28, 7, 81, 6, 66, 4, 65, 2, 85, 
    5, 57, 2, 94, 7, 68, 3, 65, 8,  5, 1, 29, 6, 16, 0, 25, 4, 28, 
    4, 33, 3, 30, 5, 14, 1, 64, 2, 15, 6, 84, 7, 58, 0, 91, 8, 68, 
    6, 51, 8, 54, 3, 72, 5, 94, 2, 64, 1,  6, 4, 38, 7, 22, 0, 18, 
    1, 62, 0, 37, 7, 87, 8, 11, 6, 74, 4, 18, 2, 41, 3, 48, 5, 67, 
    7, 23, 3, 29, 2, 54, 1, 69, 5, 95, 6,  8, 8, 51, 4, 84, 0, 69, 
    8, 24, 4, 70, 6, 53, 3, 42, 2, 59, 1, 68, 7, 50, 5, 42, 0, 66, 
    8, 34, 3, 73, 7,  6, 2, 61, 6, 82, 5, 35, 4, 88, 0, 44, 1, 15
  };
  const int q1998[] = {
    9, 9, // Number of jobs and machines
    7, 71, 5, 54, 3, 31, 2, 40, 0, 66, 6, 71, 8, 25, 4, 24, 1, 63, 
    3,  3, 0, 37, 1, 89, 6, 44, 4, 57, 2, 18, 8, 92, 5, 17, 7, 68, 
    4, 31, 3, 17, 6, 35, 2,  6, 5, 71, 8, 64, 0, 86, 1, 59, 7,  7, 
    0, 19, 1, 94, 6, 10, 4, 71, 3, 91, 7, 17, 8, 52, 2, 82, 5, 18, 
    4, 35, 0, 67, 5, 40, 1, 72, 8, 77, 7, 62, 6, 39, 2, 55, 3, 98, 
    3, 35, 5, 67, 7, 90, 2, 84, 4, 17, 6, 74, 1, 76, 8, 68, 0, 40, 
    8,  2, 5, 53, 1, 94, 7, 17, 0, 88, 6, 29, 3, 71, 4, 20, 2, 40, 
    7, 35, 1, 12, 2, 66, 3, 37, 0, 17, 4, 84, 5, 57, 6, 23, 8,  6, 
    6, 76, 8, 20, 0, 65, 2, 99, 5, 49, 3, 52, 4, 18, 1, 15, 7, 62
  };
  const int q1999[] = {
    9, 9, // Number of jobs and machines
    8, 74, 2, 11, 1, 32, 4, 89, 5, 83, 7, 66, 0, 63, 3, 72, 6, 13, 
    4, 71, 7, 78, 3, 38, 2, 54, 8, 14, 5,  8, 0, 17, 1, 59, 6, 46, 
    8, 22, 5, 29, 4, 94, 2, 46, 0, 49, 1, 53, 6, 44, 7, 84, 3, 30, 
    0, 85, 5, 83, 4, 35, 6, 47, 8, 99, 3, 47, 7, 27, 2, 69, 1, 37, 
    6, 47, 0, 48, 2, 53, 1, 14, 3, 23, 8, 11, 4, 74, 5, 39, 7, 52, 
    0, 34, 4, 30, 3, 59, 5, 93, 7, 28, 8, 49, 1, 24, 6, 76, 2, 36, 
    8, 33, 4, 68, 6, 90, 3, 63, 0, 75, 2, 77, 7, 71, 1, 43, 5, 71, 
    8,  9, 3, 71, 6, 26, 0, 29, 2, 99, 7, 62, 4, 90, 1, 63, 5, 42, 
    1, 77, 3, 70, 8, 65, 6, 66, 4, 86, 7, 76, 5, 59, 2, 30, 0, 56
  };
  const int q2000[] = {
    9, 9, // Number of jobs and machines
    7, 79, 3, 90, 5, 93, 8, 30, 2, 11, 1, 89, 6, 86, 4, 67, 0, 52, 
    3, 68, 7, 76, 0, 40, 5, 97, 1, 48, 8, 52, 6, 86, 4, 82, 2, 90, 
    8, 20, 1,  6, 0,  4, 5, 63, 2, 28, 3, 12, 7, 46, 6, 53, 4, 81, 
    5, 34, 2,  5, 4, 95, 1,  5, 6, 65, 7, 53, 8, 71, 0, 78, 3, 91, 
    1, 21, 7, 44, 5, 87, 2, 71, 6, 97, 4, 90, 0, 61, 8, 85, 3, 98, 
    5,  6, 3, 85, 7, 97, 1, 52, 6, 57, 2, 91, 8, 17, 4, 32, 0, 59, 
    8,  1, 6, 97, 7, 19, 5, 47, 4, 16, 0, 59, 2,  7, 3, 21, 1, 88, 
    7, 71, 0, 98, 3, 43, 1, 86, 4, 88, 5, 63, 8, 45, 2, 92, 6, 56, 
    6, 19, 4, 62, 7,  3, 1, 62, 8, 97, 5, 23, 3, 81, 0, 60, 2, 57
  };
  const int q2001[] = {
    9, 9, // Number of jobs and machines
    0, 26, 8, 52, 4, 69, 7, 70, 5, 16, 1, 94, 2, 42, 3, 63, 6, 51, 
    8, 72, 6, 17, 1, 81, 0, 45, 2, 56, 5, 73, 7, 54, 4, 53, 3, 34, 
    8, 34, 1, 33, 7, 66, 4, 36, 0, 77, 3, 32, 6, 16, 5, 30, 2, 85, 
    8,  2, 0, 43, 7,  7, 1, 22, 4, 35, 5, 44, 2, 89, 3,  6, 6,  6, 
    3, 27, 5, 34, 7,  8, 4, 45, 1, 28, 0, 19, 6, 12, 8,  7, 2, 36, 
    6, 68, 7, 63, 4, 69, 8, 50, 1,  1, 2, 39, 0, 65, 5, 47, 3, 99, 
    5, 95, 7, 74, 4, 79, 0, 82, 2, 23, 6, 77, 3, 13, 8, 30, 1, 69, 
    4, 81, 0, 57, 7, 78, 8, 44, 1, 56, 5, 23, 6, 57, 2, 92, 3,  5, 
    3, 95, 2, 11, 7, 86, 1, 26, 6,  2, 5, 98, 4, 21, 8, 62, 0, 24
  };
  const int q2002[] = {
    9, 9, // Number of jobs and machines
    6, 98, 2,  3, 8, 72, 7,  3, 3, 12, 1,  3, 5, 57, 4,  4, 0, 95, 
    5, 78, 0,  6, 8, 14, 7, 83, 1, 66, 4, 46, 6, 96, 3, 81, 2, 98, 
    1,  4, 0, 60, 5, 20, 2, 10, 7, 10, 3, 33, 6, 96, 8, 86, 4, 96, 
    5, 39, 8, 23, 2, 52, 6, 95, 0, 78, 1, 26, 4, 45, 3, 51, 7, 17, 
    1, 54, 0, 20, 4, 77, 8, 43, 2, 32, 5, 14, 3, 63, 6, 49, 7, 34, 
    5, 45, 6, 50, 7, 98, 3, 10, 1, 35, 2,  7, 8, 50, 4,  8, 0, 47, 
    0, 75, 1, 47, 3, 19, 7, 93, 2, 89, 4, 21, 8, 21, 5, 75, 6,  9, 
    0, 86, 7,  6, 3, 45, 6, 72, 1, 34, 8, 22, 4, 13, 2, 72, 5, 74, 
    1, 60, 8, 11, 2,  1, 4, 67, 5,  1, 7, 21, 6, 25, 0, 89, 3, 85
  };
  const int q2003[] = {
    9, 9, // Number of jobs and machines
    3, 82, 1, 89, 6, 47, 0, 56, 8, 90, 2, 74, 4, 93, 7, 19, 5, 13, 
    4, 85, 7,  1, 3, 91, 1, 14, 0, 41, 5, 51, 2, 28, 8, 41, 6, 97, 
    1, 86, 4, 98, 7, 42, 5, 39, 6, 57, 3, 51, 2, 44, 8, 39, 0, 79, 
    4,  3, 7, 80, 0, 97, 5, 36, 3, 17, 1, 79, 6, 10, 8, 70, 2, 71, 
    6, 36, 0, 84, 3, 46, 8, 66, 2, 73, 5, 72, 7, 65, 4, 51, 1, 82, 
    1, 27, 8, 83, 0, 61, 7, 31, 2, 41, 3, 12, 6, 46, 4, 40, 5,  5, 
    1, 62, 8,  7, 2, 97, 4, 49, 7, 54, 6, 56, 5, 28, 3, 41, 0, 35, 
    2, 33, 3, 21, 0, 96, 5, 86, 4, 84, 6, 14, 1, 16, 8, 27, 7, 58, 
    1, 68, 4, 44, 7,  5, 2, 84, 8, 31, 5,  6, 3, 76, 6, 64, 0,  2
  };
  const int q2004[] = {
    9, 9, // Number of jobs and machines
    3, 22, 7, 46, 4, 15, 0, 74, 2, 67, 6, 65, 1, 44, 8, 88, 5, 95, 
    0, 80, 3, 64, 7, 58, 1, 24, 5, 79, 2, 59, 4, 30, 6, 19, 8, 98, 
    1, 46, 3, 78, 4, 28, 8,  2, 5, 42, 7, 81, 2, 84, 6, 81, 0,  8, 
    4,  3, 6, 91, 2, 28, 8, 29, 5,  5, 7, 44, 3, 21, 1, 48, 0, 78, 
    1, 23, 3,  9, 7, 85, 8, 38, 0, 62, 5, 76, 4, 44, 2, 16, 6, 87, 
    4, 78, 7, 34, 8, 60, 5, 94, 2, 73, 0, 11, 1, 31, 3, 34, 6, 55, 
    3, 61, 7, 92, 0, 67, 8, 53, 1,  1, 4, 43, 6, 99, 5, 33, 2, 60, 
    5, 15, 1, 85, 4, 64, 7, 86, 6, 42, 2, 71, 8, 82, 0, 66, 3, 50, 
    6, 34, 3,  4, 4, 70, 7, 71, 1, 32, 0, 37, 5, 64, 8, 20, 2, 30
  };
  const int q2005[] = {
    9, 9, // Number of jobs and machines
    5, 99, 6, 76, 2, 66, 8,  2, 1, 39, 3, 53, 4, 21, 7, 52, 0, 63, 
    4, 46, 8, 93, 7, 35, 3, 23, 5, 67, 2, 17, 1, 35, 6, 52, 0, 92, 
    0, 62, 8, 10, 2, 97, 6, 97, 7, 78, 3, 83, 4, 95, 5, 95, 1,  3, 
    1, 70, 4, 98, 6, 66, 7, 83, 5, 97, 3, 54, 0, 28, 8, 28, 2, 19, 
    4, 32, 0, 72, 5, 33, 8, 72, 6, 33, 2, 54, 1, 36, 7, 31, 3, 63, 
    6, 37, 5, 40, 2, 16, 8, 66, 7, 63, 1, 44, 3, 28, 4, 74, 0, 31, 
    0, 24, 6, 35, 1, 28, 5, 62, 2, 62, 7, 96, 3, 76, 8, 35, 4, 21, 
    2, 97, 4, 69, 8, 76, 6, 61, 1, 76, 5, 98, 7,  8, 3, 70, 0, 36, 
    4, 22, 7,  5, 3, 31, 8,  5, 1, 59, 5, 39, 6, 18, 2, 30, 0, 10
  };
  const int q2006[] = {
    9, 9, // Number of jobs and machines
    3, 59, 1, 12, 5, 85, 0,  5, 6, 36, 8, 78, 4, 74, 2, 96, 7, 87, 
    2, 29, 6, 41, 4, 23, 7, 69, 8, 12, 3, 85, 5,  9, 0, 36, 1, 46, 
    4, 54, 1, 54, 3, 12, 5,  5, 8, 70, 2, 54, 6, 30, 0,  9, 7,  1, 
    1, 91, 5, 51, 2, 20, 7, 49, 3, 34, 4, 14, 0, 31, 8, 75, 6,  3, 
    0, 63, 7, 52, 5, 31, 2, 38, 4, 62, 6, 69, 8, 17, 1, 98, 3, 83, 
    1, 43, 7, 65, 4, 56, 2, 18, 3, 22, 0,  8, 8, 23, 5, 37, 6, 36, 
    7, 17, 4, 55, 0, 82, 6, 77, 2, 49, 8, 37, 5, 34, 1, 14, 3, 65, 
    3, 17, 6, 21, 0, 46, 5, 57, 7, 50, 4,  2, 1, 42, 8, 68, 2, 50, 
    4, 14, 5, 47, 2, 44, 1, 53, 6, 48, 0, 16, 7, 30, 8, 21, 3, 10
  };
  const int q2007[] = {
    9, 9, // Number of jobs and machines
    8, 38, 6, 58, 1, 41, 0, 15, 3, 77, 2,  1, 4, 58, 7, 10, 5,  9, 
    6, 83, 0, 72, 1, 21, 8,  3, 3, 20, 4, 76, 7,  3, 5, 78, 2, 51, 
    2, 24, 0, 65, 3, 29, 7, 23, 1, 20, 4, 21, 6, 98, 8, 36, 5,  5, 
    6, 37, 1, 89, 7, 25, 5, 44, 2, 66, 3, 15, 4, 86, 8, 83, 0, 21, 
    2, 67, 1, 42, 4, 18, 8, 70, 0, 10, 7, 64, 3, 31, 5, 78, 6, 37, 
    5, 94, 7, 70, 3, 12, 4,  6, 2, 55, 8, 28, 0, 52, 1, 77, 6, 28, 
    7, 29, 5,  3, 8, 73, 0, 60, 1, 59, 2, 77, 4, 95, 3, 15, 6, 31, 
    4, 66, 0, 17, 7, 29, 6, 24, 3, 92, 8, 97, 5, 19, 2, 25, 1, 94, 
    1, 77, 3, 73, 0, 34, 2, 45, 4, 82, 6, 43, 5, 65, 7,  5, 8, 55
  };
  const int q2008[] = {
    9, 9, // Number of jobs and machines
    3, 22, 1, 25, 5, 49, 8, 47, 6, 32, 4,  5, 7, 21, 0, 19, 2, 21, 
    2, 33, 8, 89, 1, 43, 5, 20, 3, 20, 6, 32, 7, 52, 0, 31, 4,  5, 
    8, 24, 2, 40, 5, 31, 1, 94, 3, 15, 6, 87, 4, 81, 7, 65, 0, 82, 
    5, 48, 2, 90, 7, 25, 6, 43, 4, 95, 0, 73, 3,  6, 1, 44, 8, 18, 
    6, 27, 0, 97, 5, 26, 1, 12, 8, 30, 4, 38, 7, 51, 2, 96, 3, 42, 
    2, 42, 7,  5, 6, 81, 8, 41, 1, 34, 0, 88, 3, 37, 5, 14, 4, 49, 
    5, 36, 2, 87, 7, 43, 8, 34, 3, 51, 0, 64, 1, 67, 4, 56, 6, 64, 
    4, 59, 7, 71, 6, 78, 3, 47, 1, 35, 5, 27, 2, 44, 8, 80, 0, 44, 
    5,  6, 3,  5, 6, 18, 4, 61, 0, 21, 1, 28, 2, 75, 7, 52, 8, 53
  };
  const int q2009[] = {
    9, 9, // Number of jobs and machines
    8, 62, 3, 73, 0, 59, 1, 38, 2, 54, 4, 36, 5, 57, 7, 21, 6, 82, 
    2, 57, 5, 94, 6, 76, 8, 98, 3, 59, 4, 33, 1, 28, 0, 65, 7, 25, 
    3,  7, 5, 32, 1,  6, 2, 22, 6, 13, 8,  5, 4, 72, 0, 65, 7, 86, 
    0, 27, 4, 85, 5, 25, 6, 36, 2, 87, 3, 71, 1, 75, 7, 36, 8, 87, 
    8, 84, 1, 63, 4, 72, 5, 39, 7, 13, 0, 21, 3, 60, 2,  7, 6, 90, 
    5, 67, 1, 49, 0, 84, 7, 13, 4, 71, 6, 15, 8, 17, 3, 41, 2, 14, 
    1, 97, 4, 93, 7, 89, 0, 58, 6, 31, 2, 61, 5, 89, 8, 83, 3, 74, 
    5, 42, 6, 19, 8, 29, 1, 32, 2, 29, 7, 41, 0, 25, 4, 22, 3, 12, 
    8, 67, 0, 92, 4, 58, 6, 39, 2, 15, 3, 73, 1, 57, 7, 92, 5, 42
  };
  const int q2010[] = {
    9, 9, // Number of jobs and machines
    1, 69, 2, 53, 8, 63, 7, 43, 0, 20, 5, 89, 4, 10, 6, 27, 3, 27, 
    7, 21, 3, 55, 4, 44, 0, 66, 6, 82, 8, 96, 1,  5, 2, 30, 5, 87, 
    6, 68, 5, 61, 1, 39, 4, 94, 2, 14, 3, 15, 7, 12, 8, 25, 0, 62, 
    3, 31, 7, 60, 4, 63, 0,  7, 5, 30, 2, 23, 1, 34, 8, 24, 6, 56, 
    4, 78, 0, 50, 8, 77, 2, 89, 1, 84, 6,  1, 5, 28, 3, 21, 7, 85, 
    0, 52, 1, 62, 3, 43, 4, 82, 7, 30, 5, 92, 6, 72, 8, 46, 2, 58, 
    8, 88, 4, 92, 2, 88, 0, 14, 6, 75, 5, 80, 3, 10, 7, 13, 1, 64, 
    6,  3, 4, 35, 1, 83, 2, 27, 0, 60, 8, 51, 3, 84, 5, 25, 7, 62, 
    1, 96, 4, 36, 5, 22, 3, 12, 7, 64, 2, 99, 8, 54, 0,  2, 6, 65
  };
  const int q2011[] = {
    9, 9, // Number of jobs and machines
    6, 89, 7, 62, 3, 56, 5, 19, 1, 33, 4, 90, 0, 66, 2, 63, 8, 67, 
    6, 48, 2, 34, 4, 27, 0, 26, 8, 67, 7, 72, 1, 78, 3, 54, 5, 35, 
    6, 99, 3,  6, 8, 43, 7, 91, 2, 72, 1, 95, 4, 41, 0, 92, 5, 79, 
    3, 70, 7, 43, 8, 26, 1, 88, 2,  8, 0, 17, 5,  8, 6, 57, 4, 26, 
    0, 48, 7, 14, 3, 63, 6,  2, 2, 30, 8, 23, 4, 53, 5, 71, 1, 99, 
    1, 41, 5, 80, 6, 33, 2, 43, 3, 43, 0, 45, 7, 24, 8, 79, 4, 73, 
    8, 22, 3, 67, 5, 84, 2, 55, 1, 74, 6, 17, 0, 20, 4, 31, 7, 30, 
    4, 80, 3, 26, 6, 66, 7, 61, 1,  2, 8,  4, 2, 34, 0, 67, 5, 60, 
    0, 90, 8, 13, 7, 91, 3, 62, 6, 96, 1, 62, 5, 33, 2, 50, 4, 12
  };
  const int q2012[] = {
    9, 9, // Number of jobs and machines
    5, 13, 1, 20, 8, 61, 0, 68, 2, 79, 3, 88, 7,  3, 6, 94, 4, 53, 
    2, 99, 4, 51, 6, 72, 7,  6, 1,  1, 5, 64, 3, 27, 8, 75, 0, 20, 
    6, 21, 5, 33, 8, 25, 7, 46, 4,  2, 2, 49, 0, 83, 1, 92, 3, 82, 
    8, 32, 6, 93, 2, 35, 5, 46, 3, 53, 4, 63, 1,  9, 7,  4, 0, 98, 
    5,  1, 8, 25, 3, 80, 2,  9, 7, 49, 4, 36, 0, 32, 1, 22, 6, 64, 
    8, 62, 3, 13, 1, 11, 5, 21, 7, 23, 0, 49, 2, 33, 6, 95, 4, 88, 
    3, 69, 2, 48, 0, 76, 7, 89, 1, 22, 5, 24, 4, 10, 8, 17, 6,  5, 
    5, 43, 7,  2, 0, 19, 2, 46, 8, 42, 3, 34, 6, 95, 4, 16, 1, 60, 
    5, 44, 2, 56, 3, 89, 6, 84, 0, 28, 7, 47, 4, 33, 1, 59, 8, 78
  };
  const int q2013[] = {
    9, 9, // Number of jobs and machines
    4, 15, 8, 91, 6, 34, 0, 41, 7, 44, 3, 11, 2, 43, 5, 33, 1, 27, 
    6, 85, 0, 77, 2, 10, 7, 81, 5, 71, 4, 69, 3, 62, 8, 94, 1, 85, 
    3, 85, 4, 59, 5, 56, 1, 40, 7, 67, 0, 52, 2,  6, 8, 36, 6, 54, 
    4,  2, 0, 13, 5, 79, 8, 46, 3, 80, 2, 94, 1, 80, 7, 93, 6, 38, 
    8, 56, 6, 13, 4, 75, 3, 95, 0, 68, 5, 74, 2, 76, 7,  6, 1,  7, 
    7,  3, 5, 33, 6, 69, 4, 89, 1, 91, 3, 63, 8, 58, 2, 28, 0, 29, 
    2, 24, 0, 57, 1, 85, 7, 58, 6, 28, 3, 48, 5, 97, 4, 50, 8, 60, 
    5, 99, 2, 45, 8,  4, 6, 53, 4, 50, 3, 69, 0, 32, 1, 97, 7, 30, 
    5, 87, 0, 51, 1, 24, 8, 94, 2, 33, 6, 50, 3, 74, 7, 19, 4, 69
  };
  const int q2014[] = {
    9, 9, // Number of jobs and machines
    3, 25, 0, 89, 7, 23, 8, 77, 2, 14, 5, 97, 4, 86, 6, 61, 1, 68, 
    1, 88, 0, 75, 5, 36, 6, 99, 2, 81, 8, 29, 4,  5, 7, 91, 3, 86, 
    6, 27, 0, 77, 1, 73, 2, 29, 7, 49, 4, 18, 5, 79, 8, 44, 3, 77, 
    0, 15, 8, 24, 5, 33, 6, 15, 1, 51, 4, 29, 7, 90, 3, 38, 2, 68, 
    2, 49, 1,  2, 4, 65, 3, 19, 7, 44, 6, 18, 8, 67, 5, 98, 0, 72, 
    0, 89, 1, 73, 5, 35, 8, 92, 3, 12, 2, 45, 6, 46, 4, 68, 7, 24, 
    1, 63, 0, 67, 6, 25, 4, 33, 3, 30, 8, 10, 5, 41, 7, 31, 2, 84, 
    4, 69, 1, 84, 5, 60, 7, 79, 8, 49, 3, 49, 0, 79, 2, 71, 6, 57, 
    7, 51, 1, 70, 8,  2, 2, 15, 5, 66, 3, 50, 0, 91, 4, 81, 6, 43
  };
  const int q2015[] = {
    9, 9, // Number of jobs and machines
    1, 23, 0, 16, 3, 33, 6, 53, 7, 69, 2, 24, 4, 62, 8, 86, 5, 19, 
    6, 59, 1, 25, 7, 82, 0, 57, 5, 41, 8, 25, 3, 76, 2, 37, 4, 13, 
    6, 23, 4, 14, 5, 25, 1, 72, 2, 61, 7, 62, 0, 92, 8, 68, 3, 39, 
    3, 33, 7, 77, 1,  6, 6, 28, 0, 53, 8, 96, 4, 91, 5, 14, 2, 15, 
    3, 52, 0, 19, 6, 24, 7, 73, 4, 52, 5, 39, 1, 89, 8,  3, 2, 51, 
    0, 15, 1, 45, 6, 78, 5, 66, 8, 69, 4, 33, 2, 29, 7, 84, 3, 23, 
    0, 90, 6, 57, 4, 11, 2, 29, 5, 42, 7, 15, 1, 64, 3, 76, 8, 56, 
    1, 42, 6,  9, 8, 50, 0, 87, 5, 80, 4, 83, 2, 72, 3, 11, 7, 16, 
    5,  2, 8, 60, 2, 15, 1, 73, 0, 73, 7, 55, 4, 29, 6, 62, 3, 16
  };
  const int q2016[] = {
    9, 9, // Number of jobs and machines
    8, 52, 2, 66, 4,  5, 0, 64, 3, 11, 6, 78, 7, 51, 1, 82, 5, 69, 
    5,  8, 2, 25, 1, 55, 7, 85, 8, 60, 0,  2, 6, 80, 3, 90, 4, 41, 
    3,  9, 7, 23, 8, 37, 0, 39, 1, 22, 6, 81, 4, 95, 2,  9, 5, 96, 
    4, 61, 0, 61, 5,  9, 1, 94, 6, 62, 2, 25, 7,  6, 3, 72, 8, 76, 
    3, 37, 7, 97, 5, 51, 4, 18, 6,  2, 2, 84, 1, 16, 0, 51, 8, 74, 
    2, 35, 3, 50, 4, 39, 5, 85, 1, 10, 7, 93, 6, 85, 0, 62, 8, 66, 
    1, 20, 0, 46, 6, 74, 7,  2, 8, 70, 4, 58, 5, 85, 2, 62, 3, 36, 
    6, 19, 3, 55, 8, 99, 5, 79, 1, 50, 0, 25, 4, 21, 7, 34, 2, 49, 
    7, 26, 1, 53, 6, 21, 3, 84, 0, 24, 4,  7, 8, 15, 5, 76, 2, 24
  };
  const int q2017[] = {
    9, 9, // Number of jobs and machines
    0, 79, 5, 59, 7, 52, 2, 11, 1, 10, 3, 83, 4, 34, 6, 64, 8, 17, 
    7, 57, 4, 10, 3, 87, 5, 62, 6, 45, 1,  7, 8, 28, 0, 14, 2, 42, 
    7, 22, 0, 54, 3, 28, 1, 19, 5, 92, 4, 71, 6, 55, 8, 13, 2, 22, 
    5,  9, 3, 40, 4, 83, 8, 77, 2, 19, 0, 28, 7, 90, 1, 30, 6, 27, 
    5, 96, 3, 87, 8, 49, 2, 56, 4, 75, 7, 60, 0, 64, 6, 42, 1, 18, 
    8, 62, 2, 54, 5,  9, 7, 24, 0, 12, 1, 84, 3, 35, 6, 57, 4, 23, 
    7, 59, 3, 88, 0, 86, 4, 77, 6, 63, 1, 77, 8, 15, 5, 23, 2, 84, 
    0, 17, 6,  6, 8, 16, 3, 47, 5, 23, 4, 58, 2, 68, 7, 61, 1, 94, 
    8, 93, 6, 81, 0, 81, 1, 16, 4, 33, 7, 91, 2,  7, 3, 51, 5, 26
  };
  const int q2018[] = {
    9, 9, // Number of jobs and machines
    5, 22, 0, 88, 4, 80, 3, 26, 1, 65, 2, 66, 6, 45, 7, 42, 8, 62, 
    4, 89, 8, 44, 5, 94, 6, 57, 0, 93, 2, 14, 3, 35, 1, 33, 7, 69, 
    2, 85, 1, 37, 3, 91, 4, 79, 7, 42, 0, 57, 5, 11, 6, 49, 8, 54, 
    1, 61, 7, 64, 6, 94, 8, 91, 0, 49, 4, 40, 2, 24, 3, 56, 5, 32, 
    5, 60, 0, 49, 4, 72, 2, 84, 3, 61, 8, 21, 7,  7, 1, 91, 6, 48, 
    6, 84, 4, 16, 2,  3, 7,  3, 1, 40, 0,  1, 8, 54, 3, 66, 5, 65, 
    1, 72, 6, 25, 2, 13, 3, 56, 7, 84, 0, 63, 5, 69, 4, 35, 8, 31, 
    7, 66, 5, 42, 4, 13, 6, 18, 8, 43, 1, 60, 2, 86, 3, 14, 0, 58, 
    5, 85, 7, 32, 4, 14, 3, 81, 6, 59, 2, 85, 8, 88, 0, 28, 1, 39
  };
  const int q2019[] = {
    9, 9, // Number of jobs and machines
    8, 82, 1, 62, 5, 48, 7, 49, 0, 95, 4, 61, 2, 88, 6, 37, 3, 37, 
    1, 68, 8, 79, 4, 29, 5, 31, 0, 26, 2, 59, 3, 71, 7, 94, 6, 80, 
    7, 64, 4, 74, 1, 63, 2, 47, 5, 16, 8, 59, 0,  8, 3, 24, 6, 77, 
    3, 47, 0, 82, 6, 37, 1, 50, 8, 58, 5, 96, 4,  4, 7, 79, 2, 71, 
    8, 35, 5, 98, 1, 27, 0, 10, 7, 35, 6, 51, 4, 75, 2, 38, 3, 80, 
    1, 42, 2, 80, 0, 78, 5, 75, 4, 31, 3,  4, 6, 99, 7, 75, 8, 52, 
    6, 43, 8, 89, 5, 81, 2, 17, 1, 78, 0, 50, 3, 37, 7,  7, 4, 22, 
    1, 57, 5, 33, 7,  6, 8, 89, 3, 35, 2, 49, 4, 87, 6, 17, 0, 97, 
    5, 73, 2, 24, 4, 37, 1, 42, 8, 67, 6,  9, 0, 65, 3, 54, 7, 58
  };
  const int q2020[] = {
    9, 9, // Number of jobs and machines
    1, 37, 0, 13, 5, 63, 6, 66, 8, 62, 7, 95, 2, 70, 4, 98, 3, 58, 
    7, 78, 3, 63, 0, 31, 4, 79, 5, 15, 1, 50, 2, 60, 8, 96, 6, 26, 
    6, 73, 1, 22, 5, 94, 8, 78, 4,  9, 3, 80, 7,  5, 2, 38, 0, 74, 
    2, 79, 5, 45, 6, 19, 4, 73, 8, 75, 3, 88, 0,  9, 7, 16, 1, 75, 
    5, 35, 7, 96, 4, 32, 0, 83, 1, 50, 3, 84, 6, 31, 8, 42, 2, 34, 
    1, 53, 7, 73, 6, 74, 4,  5, 0, 40, 8, 67, 5,  6, 3, 93, 2, 74, 
    0, 86, 7,  5, 1, 42, 2, 27, 5,  8, 3, 45, 6,  5, 8, 18, 4, 97, 
    4, 70, 0, 57, 7, 63, 3, 48, 8,  3, 5, 32, 1, 99, 6,  2, 2, 25, 
    2, 14, 6, 67, 3, 14, 0, 94, 8, 47, 4, 85, 1, 84, 5, 15, 7, 95
  };
  const int q2021[] = {
    9, 9, // Number of jobs and machines
    7, 50, 0, 43, 4, 72, 3,  8, 8, 45, 1, 44, 5, 14, 2,  4, 6, 77, 
    0, 81, 7, 92, 6, 85, 5,  4, 1, 13, 2, 71, 3, 66, 4, 99, 8, 42, 
    4, 78, 2, 24, 3, 27, 5, 41, 1, 80, 6, 10, 8, 42, 0, 58, 7, 75, 
    3, 33, 8, 83, 4, 40, 1,  4, 6, 57, 0, 14, 2, 60, 7,  2, 5, 98, 
    3,  4, 1, 81, 2, 93, 6, 63, 4, 79, 7, 72, 0, 32, 5, 96, 8, 29, 
    8, 95, 7,  3, 3, 15, 4, 97, 6, 41, 2, 76, 0, 34, 1, 97, 5, 26, 
    3, 59, 2, 87, 0, 72, 7, 27, 6, 77, 4,  6, 8, 60, 5,  5, 1, 67, 
    7, 65, 5, 31, 6, 19, 2, 10, 1, 38, 3, 46, 4,  3, 8, 89, 0, 99, 
    6, 42, 7, 32, 8,  3, 3, 85, 0, 71, 2, 38, 4, 30, 1, 44, 5, 87
  };
  const int q2022[] = {
    9, 9, // Number of jobs and machines
    5, 19, 3, 73, 8, 88, 1, 53, 0, 89, 6, 27, 4, 83, 7,  9, 2, 23, 
    2, 51, 6, 20, 7, 48, 4, 87, 0, 93, 1, 45, 3, 24, 5, 88, 8, 22, 
    3, 86, 5, 91, 1, 86, 7,  6, 8, 91, 6, 37, 4, 93, 0, 21, 2, 36, 
    0, 90, 1, 77, 2, 23, 5, 12, 6, 98, 8, 31, 7, 67, 4, 23, 3, 57, 
    7, 67, 4,  5, 2, 95, 5, 15, 6, 39, 8, 14, 0, 25, 3, 22, 1, 17, 
    5, 51, 0, 99, 6, 81, 4,  2, 1, 97, 8, 15, 7, 15, 3, 82, 2, 66, 
    3, 17, 7, 31, 8, 53, 4, 58, 6, 51, 5, 13, 0, 56, 1, 38, 2, 91, 
    8, 65, 6, 75, 7, 90, 1, 21, 5, 16, 4, 48, 0, 27, 3, 75, 2, 20, 
    3, 88, 7, 63, 2, 81, 8, 10, 5, 49, 1, 34, 6, 71, 0, 56, 4, 20
  };
  const int q2023[] = {
    9, 9, // Number of jobs and machines
    6, 68, 1, 43, 8, 67, 4, 24, 0, 35, 3, 27, 2, 29, 5, 65, 7, 79, 
    2, 19, 5, 20, 0, 28, 6, 77, 7, 17, 4, 92, 1, 29, 3, 88, 8, 89, 
    8, 35, 7, 28, 5, 53, 1, 26, 6, 80, 0, 31, 3, 80, 4, 40, 2,  4, 
    0, 12, 5, 86, 3, 37, 1, 61, 6, 87, 4, 20, 7, 14, 2, 14, 8, 31, 
    0, 86, 5, 67, 2, 10, 8, 74, 1, 18, 7, 47, 3, 53, 4, 23, 6, 56, 
    7, 14, 0, 20, 5, 16, 3, 86, 4, 32, 8, 35, 6, 63, 2, 84, 1,  9, 
    4, 75, 5, 62, 0, 24, 2, 61, 7, 54, 6, 43, 1, 48, 8, 88, 3, 93, 
    2, 38, 3, 47, 5, 30, 1, 24, 8, 26, 4, 83, 6, 61, 0, 57, 7, 15, 
    8, 99, 1, 99, 0, 72, 6, 30, 7, 45, 2, 56, 3,  9, 4, 41, 5, 51
  };
  const int q2024[] = {
    9, 9, // Number of jobs and machines
    8, 26, 1, 40, 6, 17, 5, 89, 0,  3, 3, 61, 4, 34, 2, 14, 7, 28, 
    0, 67, 3, 52, 6, 45, 5,  8, 4, 22, 1,  4, 7, 89, 8, 58, 2, 17, 
    5, 77, 4, 29, 0, 76, 1, 58, 6, 44, 7, 14, 8,  6, 2, 41, 3, 47, 
    3, 44, 6, 23, 2,  9, 5, 22, 7, 56, 1, 63, 4, 80, 8, 10, 0, 10, 
    8,  4, 2, 93, 3, 45, 0, 34, 6, 77, 5, 92, 1, 65, 7, 47, 4, 78, 
    7, 43, 3,  5, 6, 67, 4, 98, 8, 68, 0,  3, 5, 29, 1, 62, 2, 26, 
    0, 68, 8, 27, 2, 14, 5, 15, 3, 21, 6, 95, 1,  2, 7, 12, 4, 89, 
    4, 70, 3, 45, 0, 36, 7, 98, 8, 38, 5, 20, 1, 69, 2, 73, 6,  2, 
    8, 41, 1, 29, 5, 19, 3, 54, 2, 10, 0, 44, 6, 82, 4, 47, 7,  1
  };
  const int q2025[] = {
    9, 9, // Number of jobs and machines
    3, 79, 1, 72, 5, 30, 8, 85, 6, 77, 2, 29, 7, 91, 4, 16, 0, 64, 
    8, 73, 5, 19, 2, 79, 4, 49, 1, 90, 0, 70, 7, 25, 6, 54, 3, 59, 
    7, 95, 6, 10, 8,  7, 3, 19, 2, 98, 0, 76, 4, 25, 5, 37, 1, 62, 
    7, 26, 2, 67, 1,  4, 8, 86, 5, 85, 0, 82, 3, 29, 4, 34, 6,  7, 
    0, 45, 2, 50, 6, 46, 8, 53, 3, 11, 7, 90, 4, 62, 5, 76, 1, 86, 
    5, 52, 6, 43, 3, 77, 7, 94, 2, 23, 1,  3, 0, 45, 8, 97, 4, 31, 
    4, 56, 6, 25, 3, 18, 2, 37, 8, 74, 1, 37, 5, 94, 0, 40, 7, 19, 
    3, 75, 1, 70, 7, 56, 5, 73, 0, 30, 8, 78, 4, 98, 6, 81, 2, 19, 
    4, 13, 2, 88, 8, 68, 3, 72, 1, 52, 0, 82, 7, 96, 5,  1, 6, 66
  };
  const int q2026[] = {
    9, 9, // Number of jobs and machines
    1,  9, 2, 77, 0, 82, 5, 72, 4, 78, 6, 98, 3, 76, 7, 66, 8, 63, 
    4, 20, 7, 50, 8, 54, 6, 13, 0, 15, 2, 68, 3, 38, 5, 25, 1, 92, 
    8, 91, 2, 97, 3, 92, 1, 45, 5, 41, 4, 99, 0, 84, 7, 28, 6, 10, 
    6, 78, 0, 68, 7, 11, 8, 80, 4, 57, 3,  5, 5, 46, 2, 30, 1,  6, 
    0, 94, 2, 20, 5, 28, 4, 22, 7, 43, 6, 24, 1, 71, 8, 33, 3, 78, 
    5, 41, 7, 55, 3,  2, 0, 23, 6, 52, 1, 82, 4, 68, 8, 11, 2, 12, 
    5, 15, 2, 92, 0, 40, 8, 20, 7, 47, 4, 77, 1, 96, 6, 56, 3, 82, 
    7, 42, 0, 35, 8, 19, 1, 53, 2, 16, 5, 53, 6, 57, 3, 82, 4, 18, 
    6, 20, 2, 81, 4, 92, 8, 68, 3, 39, 0, 40, 7,  3, 1, 15, 5, 69
  };
  const int q2027[] = {
    9, 9, // Number of jobs and machines
    7, 40, 3, 78, 5, 13, 6, 40, 1,  3, 4, 33, 2, 15, 0, 31, 8, 32, 
    0, 81, 8, 13, 2, 88, 1, 77, 6, 47, 7, 27, 5, 24, 4, 60, 3, 63, 
    4, 77, 8, 11, 6, 56, 3, 83, 0, 81, 5, 47, 7, 95, 2, 18, 1, 28, 
    1, 83, 5, 41, 4, 11, 0, 28, 7, 47, 3, 97, 8, 55, 2, 29, 6, 65, 
    4, 98, 3, 87, 5, 40, 1, 97, 2, 89, 6, 35, 8, 88, 0, 94, 7, 43, 
    4, 27, 6, 43, 2, 24, 5, 30, 1, 53, 8, 28, 3, 16, 7, 38, 0, 57, 
    8, 83, 3, 98, 5, 74, 6, 24, 1, 72, 4, 71, 2, 40, 0, 80, 7, 78, 
    3, 14, 8, 30, 5, 78, 7, 73, 1, 36, 0, 55, 6, 80, 2, 12, 4, 67, 
    5, 16, 1, 44, 7,  5, 8, 84, 0, 57, 4, 43, 3, 64, 6, 92, 2, 92
  };
  const int q2028[] = {
    9, 9, // Number of jobs and machines
    4, 60, 5, 96, 2, 49, 3, 97, 7, 61, 1, 87, 6, 50, 0, 52, 8, 97, 
    6, 85, 5, 40, 8, 26, 2, 39, 3, 54, 4, 17, 1, 74, 7, 20, 0, 43, 
    0, 94, 2, 62, 1, 11, 8, 47, 3, 70, 7, 23, 5, 89, 6, 34, 4, 31, 
    8, 27, 3, 65, 6, 88, 7, 66, 4, 98, 2, 16, 0, 13, 1, 58, 5, 11, 
    4, 51, 7, 94, 6,  9, 5, 52, 3, 82, 8, 43, 2, 49, 0, 76, 1, 16, 
    5, 42, 3, 82, 1, 78, 7, 72, 2, 24, 4, 67, 6, 25, 0, 18, 8, 16, 
    5, 20, 7, 49, 6,  1, 1,  5, 0, 63, 4, 87, 8, 70, 3, 42, 2, 89, 
    6, 18, 0, 55, 4, 63, 3, 65, 8, 84, 7, 31, 1, 51, 2,  3, 5, 23, 
    8, 14, 3, 41, 6, 35, 5,  7, 7, 57, 0, 87, 2,  1, 1, 70, 4,  5
  };
  const int q2029[] = {
    9, 9, // Number of jobs and machines
    3, 40, 2, 50, 0, 62, 7, 92, 4, 84, 5, 89, 8, 73, 1, 75, 6, 59, 
    5, 55, 7, 68, 6, 98, 0, 10, 3, 97, 2,  8, 1, 75, 8, 11, 4, 43, 
    1, 86, 4, 89, 0, 16, 3, 40, 6,  3, 7,  7, 8, 89, 2, 89, 5, 54, 
    8, 52, 0,  9, 2, 87, 4, 48, 6, 56, 5, 62, 1, 71, 3,  5, 7,  7, 
    1, 70, 7, 20, 0, 30, 8,  1, 6, 73, 4, 53, 3, 60, 2,  6, 5, 52, 
    5, 98, 2, 64, 4, 17, 1, 12, 3, 44, 8,  9, 6, 22, 0, 84, 7, 85, 
    7, 66, 4, 62, 5,  6, 1,  1, 0, 54, 8, 32, 6, 45, 2, 38, 3, 34, 
    2, 67, 0, 52, 8, 39, 7, 71, 5, 33, 3, 69, 1, 62, 4, 90, 6, 79, 
    8, 22, 0, 10, 2, 51, 7, 35, 5, 57, 4, 38, 3, 40, 6, 62, 1, 93
  };
  const int q2030[] = {
    9, 9, // Number of jobs and machines
    6, 12, 5, 37, 0, 72, 8, 94, 4, 20, 7, 44, 1, 53, 2, 34, 3, 66, 
    8,  8, 1, 25, 6, 44, 5, 41, 2, 40, 7, 75, 3, 70, 4, 16, 0, 96, 
    6, 52, 7, 22, 5, 50, 4, 38, 1, 50, 8, 32, 2,  6, 0, 15, 3, 61, 
    0, 78, 4, 48, 2, 14, 5, 23, 1, 38, 7,  5, 8, 68, 3, 87, 6, 62, 
    4, 80, 7, 32, 5, 19, 6, 63, 1, 89, 8, 65, 2, 65, 3, 47, 0,  3, 
    4, 35, 1, 51, 0,  8, 5, 92, 2, 78, 7, 54, 6, 61, 8, 71, 3, 93, 
    2,  8, 4, 72, 3, 35, 1, 93, 7, 70, 8, 58, 5, 12, 0, 40, 6, 34, 
    8, 84, 0, 18, 5,  1, 3, 18, 2, 51, 7, 74, 1,  3, 6, 74, 4, 51, 
    3,  4, 4, 45, 6, 13, 7, 17, 5, 12, 8, 78, 0, 11, 1, 93, 2, 51
  };
  const int q2031[] = {
    9, 9, // Number of jobs and machines
    3, 48, 5,  4, 0, 12, 8, 45, 7, 22, 4, 30, 1, 68, 2, 16, 6, 42, 
    7, 80, 0, 14, 3, 50, 4,  4, 1, 89, 8, 54, 5, 19, 2, 36, 6, 75, 
    7, 19, 6,  5, 0, 43, 3, 96, 2, 86, 5, 68, 4, 89, 1, 87, 8, 20, 
    1, 41, 5, 83, 6,  4, 4, 29, 7, 82, 0, 86, 3, 57, 8,  3, 2, 77, 
    2, 56, 5, 48, 8, 57, 3, 66, 1, 29, 7, 51, 0, 42, 6, 24, 4, 15, 
    1,  5, 7, 54, 3, 23, 8, 21, 5, 55, 6, 54, 4,  3, 2, 36, 0, 51, 
    2, 20, 3,  9, 7,  1, 4, 40, 5, 54, 6,  2, 0, 46, 1, 46, 8, 64, 
    8, 61, 2, 35, 5, 35, 4,  8, 7, 38, 6, 86, 0, 62, 3, 66, 1, 97, 
    1, 28, 5, 85, 2, 51, 6, 79, 7, 70, 8, 88, 0,  4, 4, 34, 3, 96
  };
  const int q2032[] = {
    9, 9, // Number of jobs and machines
    0, 70, 6, 98, 4, 46, 7, 13, 2, 47, 5, 21, 3, 65, 8,  6, 1, 97, 
    7, 72, 0, 64, 3, 18, 8, 36, 2, 15, 6, 46, 1, 69, 4,  8, 5, 98, 
    5, 61, 8, 91, 4, 30, 3, 75, 2, 81, 6, 79, 0, 79, 7, 13, 1,  9, 
    4, 21, 3, 62, 1, 14, 6,  5, 8, 55, 2, 60, 7, 13, 0, 31, 5, 64, 
    1, 84, 0,  3, 3, 71, 2,  1, 8, 62, 7, 91, 5, 63, 4, 47, 6, 38, 
    2, 34, 1, 92, 8, 21, 6, 10, 7, 43, 3, 52, 0, 83, 5, 97, 4, 39, 
    0, 54, 2,  1, 4, 64, 6, 97, 7, 45, 8, 58, 1, 33, 5, 71, 3, 91, 
    8, 85, 6, 85, 3, 94, 0, 65, 2, 21, 7, 26, 5, 55, 1, 28, 4, 58, 
    5,  1, 0, 69, 4, 15, 3, 45, 6, 64, 1, 77, 2, 50, 8, 80, 7, 57
  };
  const int q2033[] = {
    9, 9, // Number of jobs and machines
    3, 39, 1, 62, 6, 16, 7, 68, 2, 78, 5, 71, 0, 83, 4, 79, 8, 21, 
    1, 62, 4,  8, 3, 90, 2, 58, 8, 27, 6, 63, 0, 64, 5, 73, 7, 60, 
    3, 70, 5, 72, 4, 28, 1, 78, 7, 68, 2, 84, 0, 74, 8, 83, 6, 54, 
    4, 11, 6, 91, 0, 61, 7, 54, 5, 15, 2, 61, 8, 37, 1, 36, 3, 12, 
    4, 51, 6, 78, 8, 67, 1, 13, 7, 11, 5, 93, 2, 98, 3, 64, 0, 18, 
    4, 21, 2, 85, 3, 47, 7, 16, 8, 56, 0, 34, 5, 64, 6, 16, 1, 39, 
    1, 57, 6, 39, 8, 78, 3,  7, 5,  5, 0, 42, 2, 30, 4, 62, 7, 19, 
    2, 76, 7, 72, 8, 82, 1, 60, 4,  4, 6, 56, 5, 87, 0, 86, 3, 60, 
    4, 66, 8, 79, 0, 38, 3,  6, 5,  9, 2, 31, 1, 56, 6, 35, 7, 98
  };
  const int q2034[] = {
    9, 9, // Number of jobs and machines
    5, 20, 6, 62, 7, 37, 0, 64, 4, 78, 3, 48, 1, 71, 2, 12, 8, 41, 
    5, 35, 7, 20, 0, 87, 2, 56, 4, 62, 3, 38, 8, 54, 1,  2, 6,  9, 
    7, 49, 3, 66, 0, 57, 1, 37, 5, 43, 2, 30, 6, 71, 4, 90, 8, 59, 
    2, 95, 3, 19, 5, 44, 8, 49, 7, 15, 6, 75, 1,  7, 0, 89, 4, 80, 
    4, 65, 3,  4, 6, 36, 1, 36, 8, 13, 2, 11, 0, 62, 5, 86, 7, 31, 
    4, 16, 6,  1, 7, 42, 8, 86, 1, 24, 3,  5, 5, 53, 2, 67, 0, 87, 
    8, 46, 2, 32, 1, 25, 3, 70, 4, 17, 7, 26, 6, 54, 5, 73, 0, 60, 
    8, 75, 5, 32, 0, 73, 3, 61, 6,  1, 2, 20, 7, 65, 4, 78, 1, 76, 
    6, 63, 1, 30, 8, 46, 2, 53, 7, 81, 3, 84, 4, 91, 5, 10, 0, 28
  };
  const int q2035[] = {
    9, 9, // Number of jobs and machines
    8, 36, 0, 28, 4, 11, 5, 83, 2, 86, 6, 27, 1, 22, 7, 68, 3, 89, 
    6, 28, 5, 16, 4, 56, 7, 62, 0, 74, 3, 60, 1, 49, 2, 40, 8, 58, 
    8, 26, 0, 57, 4, 44, 2, 22, 1, 94, 7, 83, 5, 99, 3, 21, 6, 80, 
    0, 33, 6, 51, 3, 93, 1, 92, 2, 62, 7, 35, 4, 58, 8, 79, 5, 42, 
    7, 33, 2, 42, 0, 60, 4, 16, 5, 97, 3, 12, 8, 38, 1, 28, 6, 17, 
    6, 98, 3, 51, 2, 68, 5, 42, 1,  1, 0, 10, 8, 36, 4, 71, 7,  7, 
    7, 54, 2, 90, 5, 10, 4, 64, 3, 72, 0, 16, 6, 23, 1, 12, 8, 63, 
    5, 19, 8, 72, 2, 96, 7, 68, 1, 55, 4, 27, 0, 98, 6, 76, 3, 66, 
    3, 10, 5, 20, 4, 72, 8, 16, 1, 86, 6, 90, 2, 71, 7, 77, 0, 80
  };
  const int q2036[] = {
    9, 9, // Number of jobs and machines
    4, 90, 5, 24, 3, 18, 6, 21, 7, 17, 8, 57, 2, 78, 1, 16, 0, 92, 
    0, 13, 3, 29, 1, 10, 2, 20, 7, 29, 5, 78, 6, 37, 8, 88, 4, 27, 
    4, 43, 1, 72, 8, 22, 6, 25, 0, 84, 3, 41, 5, 61, 7, 70, 2, 85, 
    4, 37, 8, 26, 2, 69, 7, 21, 6, 99, 0, 47, 1,  5, 5,  1, 3, 30, 
    3, 65, 7,  6, 6, 51, 4,  6, 8,  8, 1, 67, 0, 44, 5, 70, 2, 42, 
    5,  4, 0, 24, 7, 78, 1, 36, 8, 39, 3, 98, 6, 73, 4, 83, 2, 78, 
    4, 41, 3, 49, 6,  1, 5, 59, 8, 96, 1, 60, 2, 80, 0, 19, 7, 72, 
    4, 35, 3, 69, 8,  8, 1, 89, 7, 98, 5, 32, 0,  5, 6, 98, 2, 94, 
    5, 36, 4,  4, 7, 92, 3, 11, 2, 23, 6, 29, 8, 94, 1, 41, 0, 75
  };
  const int q2037[] = {
    9, 9, // Number of jobs and machines
    5, 32, 8, 82, 3, 62, 4, 72, 2, 39, 1, 97, 7, 13, 6, 95, 0, 31, 
    4, 67, 5, 23, 7, 35, 3, 39, 6,  2, 2, 53, 0, 17, 1, 38, 8, 16, 
    2, 92, 1, 66, 8, 51, 3, 15, 0, 19, 7, 25, 5, 73, 4, 68, 6, 54, 
    5, 82, 1,  8, 8,  7, 7, 75, 6, 37, 4, 78, 3, 80, 2, 99, 0, 37, 
    1, 81, 0,  6, 6, 17, 7, 30, 2, 17, 8, 13, 3, 23, 5,  4, 4, 21, 
    5, 21, 8, 32, 7, 78, 2, 56, 6, 92, 4, 65, 0, 44, 3, 33, 1,  1, 
    5, 67, 8, 57, 6, 67, 1, 29, 7, 89, 3, 15, 4, 19, 0,  6, 2, 65, 
    5, 26, 6,  6, 8, 21, 7, 21, 1,  1, 2, 43, 4, 50, 0, 58, 3, 69, 
    3, 22, 4,  2, 0, 71, 1, 52, 5, 95, 8, 78, 7, 47, 6, 76, 2, 58
  };
  const int q2038[] = {
    9, 9, // Number of jobs and machines
    8, 31, 1, 26, 0, 47, 6,  5, 2, 34, 3,  3, 7, 54, 4, 23, 5, 95, 
    1, 80, 5, 80, 7, 79, 6, 19, 2, 94, 8, 64, 0, 76, 4, 27, 3,  4, 
    2, 66, 0, 85, 1, 19, 4, 84, 6, 50, 7, 58, 5, 18, 3, 26, 8, 44, 
    1, 46, 4, 19, 6, 63, 5, 78, 3, 75, 8, 44, 2, 27, 7, 86, 0, 30, 
    2, 60, 6, 19, 7, 59, 4, 83, 3, 29, 5, 38, 0, 45, 1, 79, 8, 75, 
    1, 43, 7, 18, 4, 32, 5, 70, 3, 50, 2, 45, 8, 70, 0, 34, 6, 91, 
    2, 99, 6, 10, 8, 50, 7, 14, 4, 78, 5, 47, 0, 47, 1, 25, 3, 42, 
    2, 78, 3, 96, 4, 69, 5, 18, 0, 86, 1, 44, 8,  2, 7, 42, 6, 63, 
    3, 28, 0, 19, 6, 60, 2, 69, 8, 14, 4, 38, 7, 43, 5, 77, 1, 49
  };
  const int q2039[] = {
    9, 9, // Number of jobs and machines
    8,  5, 6, 36, 7,  4, 1, 85, 2, 27, 3, 21, 4, 56, 5, 76, 0, 54, 
    1, 63, 6, 24, 5,  9, 0, 68, 4, 12, 2, 17, 3, 57, 7, 91, 8, 62, 
    8, 38, 4, 97, 5, 80, 3, 16, 6, 75, 1, 12, 7, 14, 2, 62, 0, 54, 
    7, 43, 4, 68, 1, 96, 3, 24, 6, 29, 2,  8, 0, 59, 8, 45, 5, 46, 
    0, 52, 1, 54, 6, 89, 3, 85, 8, 60, 7, 27, 4, 14, 5, 95, 2, 34, 
    3, 27, 6, 76, 0, 95, 7, 33, 4, 96, 1, 10, 2, 31, 5, 11, 8, 59, 
    0,  4, 6, 21, 4, 96, 5, 29, 3, 62, 8, 37, 7, 77, 1, 28, 2, 35, 
    7, 80, 3, 55, 8,  8, 4, 93, 2, 80, 1, 52, 5, 33, 0, 50, 6, 92, 
    1, 10, 6, 88, 3, 90, 8, 39, 2, 13, 5, 13, 0, 62, 4, 89, 7, 55
  };
  const int q2040[] = {
    9, 9, // Number of jobs and machines
    8, 83, 1, 71, 3, 26, 4, 74, 5, 52, 7, 32, 6, 91, 2, 59, 0, 94, 
    1, 58, 5, 36, 0, 14, 4, 67, 3, 91, 7, 22, 2, 51, 6, 93, 8, 18, 
    1, 73, 3, 67, 6, 57, 8, 18, 5,  6, 4, 34, 2, 56, 7, 41, 0, 92, 
    1, 50, 2, 12, 7, 31, 0, 40, 5, 70, 6, 70, 3, 27, 4, 66, 8, 55, 
    8, 44, 0, 20, 6, 22, 7, 26, 2, 64, 3, 97, 1, 24, 4, 91, 5, 96, 
    1, 76, 7, 69, 4, 91, 6, 15, 0, 72, 3, 18, 2, 80, 8, 90, 5, 17, 
    2, 11, 7, 22, 3, 18, 1, 62, 4, 47, 6, 14, 0, 82, 5, 58, 8, 13, 
    7, 94, 0, 59, 1, 18, 4, 31, 8, 72, 5, 70, 6, 62, 2, 53, 3, 46, 
    2, 72, 0, 75, 6, 87, 7, 12, 1, 51, 3, 60, 8, 44, 4, 22, 5, 68
  };
  const int q2041[] = {
    9, 9, // Number of jobs and machines
    0, 63, 3, 85, 5, 12, 7, 32, 8, 99, 4,  6, 2, 70, 1, 85, 6, 32, 
    3, 67, 7, 87, 5, 87, 0, 96, 4, 52, 2, 45, 8, 45, 6,  3, 1, 73, 
    0, 61, 2, 61, 8, 48, 3, 64, 5, 36, 6, 85, 1, 96, 7, 71, 4,  5, 
    6, 52, 8, 12, 1,  9, 0, 92, 5, 90, 3, 51, 7, 87, 4, 58, 2, 34, 
    2,  1, 3, 41, 8, 97, 1, 89, 5, 67, 7, 23, 4, 92, 0, 76, 6, 64, 
    8, 13, 6, 57, 1, 24, 4,  2, 5, 76, 7, 42, 2, 53, 0, 87, 3, 39, 
    6, 75, 5, 97, 1,  8, 7, 11, 8, 76, 2, 10, 4, 43, 3, 80, 0,  4, 
    1, 11, 0, 63, 4, 28, 7, 59, 3, 61, 5, 64, 2, 12, 6, 18, 8, 41, 
    3, 68, 2, 67, 8, 88, 6, 39, 7, 12, 4, 45, 5, 15, 1, 78, 0, 45
  };
  const int q2042[] = {
    9, 9, // Number of jobs and machines
    3, 58, 4, 25, 7, 50, 6, 98, 2, 10, 8, 63, 5, 52, 1, 81, 0, 28, 
    0, 63, 8, 73, 6,  4, 1, 12, 4,  7, 2, 69, 5,  5, 3, 65, 7, 38, 
    3, 31, 7, 38, 6, 67, 0, 37, 2, 38, 4, 34, 5, 40, 1, 74, 8, 54, 
    8, 70, 0, 93, 3, 65, 4, 70, 1, 66, 6, 15, 5, 61, 2, 69, 7, 75, 
    8, 74, 7,  4, 5, 63, 3, 10, 2, 67, 1, 63, 0, 72, 6, 25, 4, 75, 
    0, 13, 1, 72, 4, 80, 7, 58, 2, 35, 6, 63, 8, 96, 5,  6, 3, 60, 
    8, 27, 2, 47, 5, 11, 1, 80, 7, 56, 6, 32, 0, 19, 4, 41, 3, 24, 
    7, 55, 0, 23, 1, 60, 6,  6, 5, 99, 2, 25, 8, 62, 4, 83, 3, 22, 
    3, 29, 7, 86, 4, 32, 8, 67, 2, 96, 0, 82, 6, 16, 5, 65, 1, 79
  };
  const int q2043[] = {
    9, 9, // Number of jobs and machines
    3, 89, 1, 66, 8, 76, 2, 69, 6, 95, 4,  6, 7, 97, 5, 98, 0, 48, 
    1, 43, 6,  4, 5,  3, 4, 60, 2, 52, 3, 86, 0, 92, 7, 62, 8, 75, 
    8, 11, 6, 60, 3, 76, 1, 25, 0, 40, 5, 16, 7, 79, 4, 75, 2, 45, 
    1, 70, 0, 91, 8, 17, 2, 42, 5, 29, 3, 61, 6,  8, 7, 39, 4, 47, 
    1,  3, 4, 24, 6,  8, 0, 26, 3, 33, 8, 51, 5, 63, 7, 47, 2, 80, 
    8, 54, 1, 18, 5, 54, 3, 85, 4, 86, 2, 57, 6, 43, 0, 98, 7, 43, 
    7, 13, 5, 96, 6, 20, 0, 95, 8, 54, 1, 46, 2, 19, 4, 85, 3, 27, 
    8, 29, 6, 31, 5, 11, 4, 90, 2, 13, 3, 68, 1, 67, 7, 77, 0, 67, 
    5, 69, 8, 75, 7, 19, 0, 41, 6, 19, 1, 59, 4, 68, 2, 43, 3, 38
  };
  const int q2044[] = {
    9, 9, // Number of jobs and machines
    6, 82, 1, 68, 5, 91, 4, 95, 8, 75, 7, 20, 0, 47, 2, 39, 3, 43, 
    7, 47, 8, 58, 4, 37, 6, 50, 3,  5, 0, 38, 5, 85, 1, 18, 2, 73, 
    6, 63, 1, 14, 4, 22, 5, 79, 0, 16, 3, 98, 7, 15, 8, 17, 2, 69, 
    0, 38, 7, 50, 5, 37, 4, 46, 3, 32, 2,  3, 8, 49, 1, 47, 6, 57, 
    6, 26, 7, 78, 8,  2, 1,  4, 5, 30, 3, 43, 0, 72, 2,  4, 4, 72, 
    1, 98, 7, 51, 3, 66, 2, 57, 6, 91, 4, 54, 5,  3, 0, 54, 8, 92, 
    4, 12, 3, 50, 0, 15, 1,  8, 6,  9, 5, 26, 2, 48, 8, 17, 7, 56, 
    5,  4, 8, 32, 0, 61, 3, 89, 2, 91, 6, 23, 4, 60, 1, 46, 7, 11, 
    8,  4, 4, 99, 5, 99, 1, 54, 6, 58, 2, 27, 7, 54, 0, 95, 3, 44
  };
  const int q2045[] = {
    9, 9, // Number of jobs and machines
    0, 20, 1, 98, 6, 75, 3, 12, 4, 70, 8, 59, 2, 34, 7, 48, 5,  9, 
    2,  8, 8, 92, 6, 64, 5, 53, 3, 43, 4, 53, 7, 64, 0, 95, 1,  8, 
    5, 48, 1, 94, 8, 11, 6, 25, 3, 62, 4, 79, 2, 25, 0, 67, 7, 89, 
    3,  1, 0, 63, 4, 56, 1, 37, 6, 55, 2,  2, 7, 85, 5, 98, 8, 79, 
    0, 54, 5, 16, 1, 24, 7, 65, 4, 50, 2, 10, 8, 55, 6, 57, 3, 13, 
    0, 72, 4, 95, 6, 53, 1, 67, 5, 99, 2, 85, 7, 76, 3, 73, 8, 17, 
    0, 56, 7, 23, 5, 44, 1, 27, 8, 86, 6, 73, 2, 90, 3, 42, 4, 45, 
    7, 16, 4, 12, 5, 49, 8, 39, 0, 66, 3, 27, 2, 54, 1, 63, 6, 62, 
    1, 81, 3,  1, 5, 36, 0, 74, 6, 47, 8, 73, 7, 96, 4, 60, 2, 82
  };
  const int q2046[] = {
    9, 9, // Number of jobs and machines
    0, 16, 5, 13, 7,  2, 6, 20, 4, 60, 2, 42, 3, 24, 1, 69, 8, 66, 
    0,  8, 1, 83, 4, 72, 3, 72, 6, 71, 2, 41, 8, 99, 7,  5, 5, 13, 
    2, 77, 3, 28, 4, 66, 1, 22, 8, 89, 0, 50, 5, 27, 7, 60, 6, 54, 
    0, 71, 6, 23, 3, 81, 5, 73, 4, 56, 1, 84, 7, 28, 8, 41, 2,  9, 
    6, 93, 3, 90, 8, 24, 7, 25, 5, 12, 2, 86, 4,  4, 1, 26, 0, 41, 
    0, 10, 7, 36, 6, 78, 8, 61, 3, 79, 1, 32, 2, 43, 4, 76, 5, 43, 
    3, 30, 8, 63, 5, 32, 4, 59, 6, 23, 2, 92, 1, 51, 0,  6, 7, 18, 
    4, 78, 6, 77, 0, 93, 8, 29, 1, 14, 5, 21, 7, 15, 2, 32, 3, 87, 
    6, 85, 4, 77, 5, 27, 1, 29, 3, 75, 8, 81, 2, 74, 7, 72, 0, 84
  };
  const int q2047[] = {
    9, 9, // Number of jobs and machines
    1, 97, 8, 29, 0, 74, 5, 88, 3, 89, 4, 15, 7, 78, 2, 49, 6,  7, 
    3, 31, 7, 90, 4,  7, 2, 70, 8, 36, 5, 95, 6, 11, 0, 15, 1, 95, 
    1, 71, 5, 49, 7, 73, 3, 27, 0, 42, 8, 25, 2, 65, 6, 51, 4,  2, 
    8, 40, 0, 57, 3, 97, 5, 93, 4, 25, 7, 15, 6, 24, 2, 86, 1, 39, 
    8, 54, 2, 80, 4, 90, 5, 75, 1,  2, 7, 17, 0, 76, 3, 13, 6, 27, 
    0, 17, 3, 18, 2, 39, 6, 18, 1, 36, 8, 60, 7, 11, 5, 43, 4, 36, 
    1, 71, 0, 65, 6, 12, 4, 22, 5, 41, 3, 45, 2, 71, 8, 98, 7, 58, 
    5, 41, 8, 27, 3, 68, 7, 49, 2, 25, 4, 38, 6, 82, 0, 89, 1, 63, 
    5, 72, 6, 20, 3, 49, 2, 39, 0,  4, 4, 26, 7, 94, 8, 35, 1, 44
  };
  const int q2048[] = {
    9, 9, // Number of jobs and machines
    1, 89, 2,  4, 4, 45, 0, 85, 8, 80, 6, 33, 3, 59, 5, 67, 7, 86, 
    7, 51, 3, 50, 4, 90, 5, 71, 1, 48, 0, 95, 6, 53, 2, 89, 8, 25, 
    2, 92, 1, 32, 4, 41, 0, 69, 7, 22, 5, 74, 6, 41, 3, 71, 8, 28, 
    7, 98, 1, 28, 6, 37, 8, 98, 4, 38, 2, 57, 0, 17, 3, 42, 5, 32, 
    8,  1, 3, 92, 7, 58, 5, 46, 0, 30, 4, 54, 1, 27, 2, 85, 6, 48, 
    5, 83, 2, 16, 7, 55, 0, 68, 8, 34, 1, 12, 3, 72, 4, 37, 6, 89, 
    5, 20, 1, 40, 4, 24, 6, 19, 3, 82, 7, 90, 8, 58, 2, 56, 0, 60, 
    1, 87, 2,  8, 7, 49, 8, 62, 4,  8, 5, 64, 6, 67, 0,  8, 3, 11, 
    7,  2, 3, 46, 5, 27, 6,  6, 0, 70, 2, 99, 8, 83, 1, 30, 4, 95
  };
  const int q2049[] = {
    9, 9, // Number of jobs and machines
    5, 86, 8, 55, 6, 16, 2, 67, 1,  6, 7, 63, 3, 88, 4, 28, 0, 42, 
    6, 87, 1, 13, 0, 84, 8, 63, 5, 67, 3, 55, 2, 62, 4, 78, 7, 64, 
    1,  7, 4, 78, 3, 56, 5, 55, 8, 78, 7, 62, 0,  7, 2, 56, 6, 94, 
    7, 24, 3, 11, 8, 18, 4, 66, 6, 77, 5,  8, 0,  6, 2, 93, 1, 49, 
    2, 31, 6, 88, 3, 21, 5, 74, 0, 37, 1, 55, 7, 22, 4, 54, 8, 24, 
    1, 53, 7, 97, 2, 65, 8, 60, 0, 50, 4,  9, 5,  6, 6, 40, 3, 88, 
    8, 79, 5, 46, 6, 24, 3, 66, 0, 29, 7, 68, 1, 27, 4, 73, 2, 55, 
    8, 40, 1, 13, 6, 55, 0, 66, 5, 97, 7, 67, 3, 86, 4, 83, 2, 80, 
    8, 13, 5, 90, 7,  7, 4, 72, 3, 41, 6, 81, 1, 32, 2, 70, 0, 87
  };
  const int q2050[] = {
    9, 9, // Number of jobs and machines
    4, 48, 8, 19, 5, 61, 2, 27, 0, 36, 3, 93, 6, 26, 7, 41, 1, 73, 
    7, 20, 1,  9, 6, 68, 0, 40, 5, 80, 3, 20, 4, 75, 2,  7, 8, 58, 
    4, 30, 7, 52, 0, 35, 3, 84, 2, 74, 6, 40, 1, 98, 5,  4, 8, 16, 
    6, 10, 2, 10, 3, 12, 4, 76, 1, 93, 0, 25, 8, 22, 5, 45, 7, 12, 
    4, 92, 3,  3, 7, 45, 0, 82, 8, 41, 1, 63, 5, 18, 6, 91, 2, 32, 
    6, 25, 7, 56, 1, 19, 5, 25, 8, 70, 2, 15, 3, 27, 0,  8, 4, 94, 
    7, 84, 5, 84, 8, 52, 0, 29, 1, 66, 3, 51, 2, 46, 6, 89, 4, 46, 
    8, 42, 0, 34, 2, 85, 4, 20, 6, 71, 3, 91, 1, 85, 7, 37, 5, 24, 
    0, 14, 1, 90, 5, 85, 6, 42, 3, 98, 4,  2, 2, 31, 8, 81, 7, 97
  };
  const int q2051[] = {
    9, 9, // Number of jobs and machines
    1, 79, 0, 12, 5, 60, 8, 48, 4, 66, 2, 88, 3, 67, 7, 79, 6, 15, 
    4, 70, 8, 69, 5, 74, 7, 19, 2, 67, 6, 26, 3, 37, 0, 21, 1, 14, 
    6, 35, 3, 85, 0, 69, 4, 52, 2, 38, 5,  5, 7, 59, 1, 52, 8, 51, 
    2, 32, 7, 52, 5, 78, 3,  8, 1, 98, 4, 28, 0, 46, 8, 88, 6, 26, 
    3, 96, 1, 40, 0, 93, 6, 16, 8, 16, 2, 50, 5, 68, 4, 11, 7, 20, 
    4, 86, 3, 35, 8, 90, 7, 43, 2, 77, 5, 88, 1, 25, 6, 32, 0, 99, 
    1, 66, 2,  6, 0, 57, 6, 43, 3, 69, 8, 84, 5, 48, 4, 34, 7, 17, 
    0, 86, 8, 62, 5, 68, 6, 39, 4, 21, 1, 42, 3, 56, 2,  6, 7, 78, 
    0, 10, 4, 12, 8, 39, 3,  6, 1, 87, 2, 33, 6, 98, 5, 40, 7, 15
  };
  const int q2052[] = {
    9, 9, // Number of jobs and machines
    3, 88, 6, 96, 7, 54, 2,  9, 4, 70, 1, 67, 0,  1, 8, 83, 5, 26, 
    0, 12, 5, 77, 8, 83, 6, 15, 2, 66, 3, 22, 1, 32, 4, 79, 7, 78, 
    7, 43, 1,  1, 8, 94, 3,  7, 6, 13, 2, 22, 4, 19, 0, 45, 5, 17, 
    6, 96, 0, 32, 4, 89, 1, 93, 2, 67, 3, 51, 8, 54, 7, 31, 5, 55, 
    2, 85, 4, 30, 6,  5, 0, 99, 5, 58, 8, 56, 1, 84, 3, 35, 7,  7, 
    5, 74, 1, 58, 6, 51, 8, 50, 3, 91, 0, 89, 4, 94, 2, 68, 7, 26, 
    5, 73, 3, 13, 2, 95, 1, 68, 8, 63, 4, 99, 7, 28, 6,  8, 0,  6, 
    0, 92, 8, 77, 4, 91, 1, 66, 6, 18, 7, 63, 5, 41, 2,  3, 3, 11, 
    4, 24, 3, 17, 0, 34, 2, 46, 5, 22, 6, 61, 7, 70, 8, 95, 1, 59
  };
  const int q2053[] = {
    9, 9, // Number of jobs and machines
    4, 61, 2, 13, 6, 86, 8, 59, 5, 11, 7, 85, 0, 89, 1, 71, 3, 62, 
    1, 98, 4, 21, 5,  4, 6, 54, 2, 82, 3, 86, 0, 21, 8, 24, 7, 28, 
    1, 24, 0, 60, 4, 75, 6, 35, 2, 41, 7, 27, 8, 84, 3, 85, 5, 95, 
    0, 33, 2, 77, 6, 69, 5, 71, 3, 21, 4, 38, 1, 70, 7, 62, 8, 37, 
    3, 92, 0, 80, 6, 37, 1, 15, 7, 34, 2, 33, 5, 35, 8, 27, 4, 27, 
    0, 53, 3, 76, 6, 46, 4, 51, 2, 20, 5, 39, 7, 21, 8, 66, 1, 24, 
    4, 54, 1, 49, 7,  2, 5, 59, 8, 95, 6, 73, 0, 17, 3, 24, 2, 18, 
    1, 55, 6, 56, 3, 39, 8, 82, 7, 84, 2, 31, 0, 35, 5, 66, 4, 69, 
    0, 25, 7, 72, 3, 99, 8, 48, 5, 37, 6, 96, 1, 25, 4, 46, 2, 96
  };
  const int q2054[] = {
    9, 9, // Number of jobs and machines
    0, 41, 5, 97, 7, 95, 3, 67, 6, 19, 4, 96, 2, 63, 8, 22, 1, 73, 
    4, 54, 7, 57, 2,  7, 3,  2, 1, 61, 0, 34, 6, 12, 8, 78, 5, 89, 
    7, 81, 8, 49, 3, 34, 5, 45, 1,  1, 6, 79, 2, 19, 4, 59, 0, 75, 
    6,  2, 7, 24, 1, 33, 8, 14, 0, 52, 4, 62, 5, 13, 3, 36, 2,  3, 
    5, 26, 1, 77, 4, 36, 7, 53, 6, 34, 3, 24, 8, 43, 0, 86, 2, 56, 
    5, 48, 3, 35, 1, 58, 8, 52, 2, 52, 6, 64, 0, 50, 7, 52, 4, 41, 
    7, 31, 3, 40, 1, 86, 6, 63, 2,  5, 5, 20, 8, 45, 0, 94, 4, 60, 
    3, 39, 7, 11, 8,  1, 1, 59, 5, 40, 4, 78, 6, 96, 0,  8, 2, 10, 
    4,  3, 7, 23, 3, 30, 1, 54, 6,  3, 0, 39, 2, 82, 5, 71, 8, 71
  };
  const int q2055[] = {
    9, 9, // Number of jobs and machines
    5, 68, 6, 60, 4, 46, 1, 45, 0,  1, 2,  5, 3, 74, 7, 82, 8, 70, 
    5, 52, 1, 95, 3, 65, 4,  9, 0, 46, 8, 29, 6, 20, 2, 36, 7,  2, 
    2, 91, 8, 95, 3, 88, 6, 56, 1, 70, 5, 33, 4, 25, 7, 67, 0, 63, 
    7, 74, 0, 46, 1, 98, 8, 56, 3, 36, 4, 25, 5, 23, 6, 37, 2, 99, 
    4, 78, 0, 50, 1, 79, 6, 13, 8, 26, 2, 54, 5, 23, 7,  8, 3, 22, 
    0, 65, 7, 54, 5, 97, 2,  4, 6, 57, 8, 78, 4,  5, 3, 75, 1, 26, 
    0, 70, 7, 18, 3, 82, 5, 63, 8, 79, 4, 77, 2,  4, 1, 61, 6, 46, 
    7, 96, 5, 38, 0, 25, 3, 24, 8, 75, 1, 21, 4, 88, 6, 49, 2, 89, 
    6, 92, 3, 25, 5, 73, 7,  8, 0, 29, 2, 46, 4, 83, 8, 32, 1, 69
  };
  const int q2056[] = {
    9, 9, // Number of jobs and machines
    5, 41, 7, 38, 4, 20, 6, 12, 2, 44, 1, 18, 3, 27, 8, 96, 0, 44, 
    4, 10, 7,  4, 8, 69, 3, 57, 1, 73, 5, 78, 6, 92, 0, 98, 2, 16, 
    6, 16, 0, 10, 2, 28, 8, 89, 1, 58, 7, 96, 3,  9, 4, 74, 5, 33, 
    7, 57, 0, 35, 4, 42, 1, 63, 6, 73, 3, 89, 2, 62, 5, 92, 8, 50, 
    1, 51, 5, 23, 3, 55, 8, 13, 7,  5, 4, 99, 0, 29, 6, 59, 2, 35, 
    1, 22, 8, 21, 2, 80, 3, 47, 7, 48, 0, 19, 5, 99, 6, 81, 4, 41, 
    7, 76, 4, 67, 0, 71, 8, 34, 5, 31, 2, 98, 3, 84, 6, 79, 1, 83, 
    5, 73, 7, 69, 2, 58, 0, 30, 8, 25, 3,  4, 1, 46, 6, 59, 4, 99, 
    7, 80, 5, 65, 3, 95, 6, 52, 0, 53, 1, 40, 8, 86, 2, 56, 4, 85
  };
  const int q2057[] = {
    9, 9, // Number of jobs and machines
    4, 51, 7, 52, 3, 82, 5, 64, 2,  8, 8, 58, 6, 26, 1, 19, 0, 92, 
    0, 90, 7, 55, 2, 40, 4, 43, 5, 41, 1, 65, 6,  9, 8, 44, 3, 23, 
    1, 80, 8, 88, 5, 10, 2, 56, 6, 82, 0, 62, 3, 51, 7, 28, 4, 92, 
    2,  8, 0, 71, 3, 34, 1,  1, 8, 14, 6, 65, 7,  4, 4, 55, 5, 23, 
    4, 70, 5, 36, 0, 34, 6, 46, 2, 78, 1, 26, 7, 44, 3, 30, 8, 56, 
    1, 83, 8, 26, 3,  7, 7, 83, 5, 68, 2, 63, 6, 17, 0, 98, 4, 71, 
    8,  1, 0,  3, 3,  7, 5, 50, 1, 88, 6, 93, 2, 76, 4, 99, 7, 89, 
    7, 40, 6, 33, 4, 55, 3, 62, 5, 99, 2, 33, 8, 55, 1, 57, 0, 64, 
    4, 88, 1, 38, 6, 41, 8, 93, 5, 67, 2, 69, 0, 96, 7, 82, 3, 33
  };
  const int q2058[] = {
    9, 9, // Number of jobs and machines
    3, 78, 1, 43, 7, 71, 2, 99, 0, 73, 5, 13, 6, 46, 8, 64, 4, 33, 
    4, 27, 8, 52, 6, 46, 2, 52, 0, 72, 1, 85, 7, 86, 3, 61, 5, 90, 
    2, 12, 4, 83, 6, 37, 5, 14, 3, 47, 0, 25, 1, 12, 7, 15, 8, 35, 
    2, 76, 1, 23, 0, 27, 6, 65, 4, 10, 8, 34, 3, 61, 5, 49, 7, 66, 
    2, 92, 6, 40, 4, 90, 3, 65, 7,  9, 8, 74, 5, 33, 1, 10, 0, 91, 
    4, 50, 1, 95, 8, 49, 7, 83, 6, 57, 0, 80, 5, 53, 2, 54, 3, 38, 
    0, 70, 2, 67, 5, 92, 1, 87, 4, 21, 3, 71, 6, 28, 7, 36, 8, 69, 
    6, 37, 5, 44, 2,  4, 7, 90, 4, 66, 1,  9, 8, 34, 0, 99, 3, 82, 
    6, 86, 8, 86, 5, 56, 2, 88, 7, 67, 4, 26, 1, 76, 0, 16, 3, 21
  };
  const int q2059[] = {
    9, 9, // Number of jobs and machines
    5, 74, 2, 93, 6, 59, 1, 84, 8, 23, 0, 76, 7, 89, 4, 83, 3, 49, 
    7, 81, 1, 67, 0,  8, 3, 45, 4, 84, 6, 75, 2, 28, 5, 96, 8, 48, 
    3, 81, 4, 38, 5, 29, 6, 47, 7, 46, 1,  8, 2, 93, 0, 77, 8, 31, 
    7,  7, 5, 10, 6, 12, 4, 73, 1, 64, 3, 35, 2, 61, 0, 39, 8, 48, 
    7, 51, 0, 95, 1, 81, 5, 93, 8, 10, 2,  3, 3, 41, 6, 41, 4, 30, 
    7, 79, 3, 48, 1, 67, 2, 29, 5, 45, 8, 83, 6, 20, 4, 71, 0, 57, 
    5, 45, 3, 44, 6, 33, 7, 33, 1, 95, 0, 24, 4, 49, 8, 19, 2, 57, 
    8,  5, 0, 37, 1, 64, 6, 86, 5, 32, 2,  7, 7, 82, 4, 59, 3, 59, 
    7, 98, 1, 67, 6, 36, 2, 53, 8, 11, 5, 74, 3, 59, 4, 37, 0, 55
  };
  const int q2060[] = {
    9, 9, // Number of jobs and machines
    2, 97, 7, 59, 3, 26, 5, 73, 6, 77, 0, 49, 1, 30, 8, 52, 4, 53, 
    1, 43, 3, 43, 0, 57, 2, 29, 5, 70, 8, 94, 7, 54, 4, 29, 6, 42, 
    0, 48, 6,  5, 3, 97, 2, 93, 8, 61, 4, 41, 7,  1, 1, 85, 5,  4, 
    4, 41, 5, 72, 7, 46, 0,  5, 8, 18, 6, 80, 3, 32, 1, 67, 2, 37, 
    2, 99, 4, 30, 1, 84, 8, 43, 0, 28, 7, 47, 3,  4, 6,  8, 5, 41, 
    4, 93, 1, 28, 5, 50, 2, 49, 6, 33, 0, 64, 3,  3, 8, 43, 7, 86, 
    4, 76, 0, 35, 2, 23, 8, 54, 6, 68, 3, 64, 7, 49, 5, 34, 1, 43, 
    6, 64, 0, 63, 5, 67, 3, 99, 1, 80, 2, 72, 8, 65, 7,  9, 4,  1, 
    0, 83, 3, 26, 2, 22, 1, 96, 8, 83, 6, 86, 5, 59, 7, 44, 4, 57
  };
  const int q2061[] = {
    9, 9, // Number of jobs and machines
    4, 55, 7, 11, 0, 78, 1, 64, 8, 76, 5, 93, 2, 54, 3, 39, 6, 71, 
    1, 51, 6, 40, 0, 93, 3, 87, 8, 46, 2, 48, 7, 41, 4, 88, 5, 20, 
    3, 73, 1, 68, 7, 34, 8, 79, 0, 86, 6, 84, 5, 47, 2, 53, 4, 10, 
    8, 12, 4, 42, 1,  1, 2, 16, 6, 26, 5,  7, 3, 97, 7, 65, 0, 75, 
    3, 38, 2, 36, 1, 50, 0, 78, 5, 36, 8, 48, 7, 86, 6, 55, 4, 31, 
    0, 41, 5, 78, 6, 77, 8, 53, 1,  1, 2, 70, 3, 27, 7, 28, 4, 75, 
    1, 40, 8, 89, 6, 49, 4, 15, 3, 50, 2, 94, 0, 81, 5, 76, 7, 15, 
    7, 19, 6, 45, 0, 56, 8, 53, 3, 30, 4, 40, 5, 59, 2, 70, 1, 52, 
    4, 84, 6, 89, 3, 20, 2, 40, 1, 46, 0, 63, 7, 57, 8, 27, 5, 25
  };
  const int q2062[] = {
    9, 9, // Number of jobs and machines
    5, 43, 3, 23, 2, 17, 1,  6, 7, 89, 6, 93, 4, 32, 8, 11, 0, 65, 
    2,  3, 5, 89, 1, 25, 7, 56, 8, 85, 0, 40, 4, 12, 3, 43, 6, 34, 
    2, 56, 5, 70, 0, 55, 7, 26, 4, 88, 8, 17, 3, 51, 1, 65, 6,  1, 
    1, 34, 8, 81, 2,  6, 7, 35, 6, 58, 3,  6, 4, 38, 0, 59, 5, 31, 
    6, 48, 2,  2, 8, 49, 5, 22, 1, 22, 7, 72, 3, 65, 0, 22, 4, 54, 
    5,  4, 6,  4, 7, 66, 8, 61, 4, 55, 0, 88, 1,  3, 3, 48, 2, 22, 
    8, 93, 0, 34, 4, 72, 5, 47, 2, 46, 1, 55, 6, 34, 3, 21, 7, 76, 
    2, 59, 7, 38, 3, 61, 6,  1, 8, 82, 4, 73, 5, 92, 0, 39, 1,  3, 
    6, 51, 5, 45, 7, 87, 3, 96, 4, 14, 8, 19, 1, 86, 2, 52, 0, 22
  };
  const int q2063[] = {
    9, 9, // Number of jobs and machines
    0,  4, 2, 53, 6, 28, 4, 12, 7, 13, 8, 45, 1, 64, 5, 59, 3, 34, 
    8, 99, 5, 22, 7, 65, 1, 64, 6, 42, 3, 56, 2, 58, 4,  6, 0, 65, 
    2, 71, 1, 30, 6, 84, 4, 55, 5,  1, 8, 45, 3, 61, 0,  4, 7, 84, 
    7,  3, 5,  4, 1, 88, 8, 59, 3, 90, 4, 88, 2, 82, 6,  9, 0, 24, 
    5, 34, 6, 21, 3, 96, 2, 94, 7, 52, 1, 26, 4, 44, 0, 25, 8, 17, 
    3, 52, 4,  4, 1, 81, 8, 35, 6, 90, 5, 35, 0, 66, 2,  8, 7, 55, 
    3, 80, 0, 77, 5,  6, 1, 15, 2, 96, 7, 98, 8, 48, 6, 86, 4, 18, 
    0, 57, 2,  3, 5, 37, 8, 97, 6, 13, 4,  2, 1, 30, 3, 52, 7, 23, 
    4, 87, 6, 86, 7, 23, 0, 62, 3, 61, 5, 56, 2, 50, 8, 78, 1,  5
  };
  const int q2064[] = {
    9, 9, // Number of jobs and machines
    0, 52, 1,  6, 3, 92, 6, 22, 5, 20, 7, 13, 8, 26, 4, 38, 2, 85, 
    3, 73, 2, 37, 0, 57, 4, 19, 1, 51, 5, 49, 6, 29, 7, 54, 8, 21, 
    5, 83, 1,  8, 2, 64, 7, 73, 4, 40, 3, 55, 6, 83, 8, 25, 0, 11, 
    7, 82, 2, 22, 0, 35, 3,  4, 5,  1, 8, 94, 4, 42, 6, 34, 1, 58, 
    4, 86, 1, 18, 2, 72, 6, 39, 8, 82, 5, 39, 3,  8, 7, 58, 0,  8, 
    8, 53, 3, 51, 2, 94, 7, 20, 6, 96, 5, 34, 1, 42, 0, 66, 4, 72, 
    6, 77, 8, 58, 4, 18, 2, 65, 1, 64, 5, 59, 7, 59, 0, 97, 3, 84, 
    6, 57, 4, 36, 3, 12, 2, 57, 7, 88, 5, 85, 8, 78, 0, 18, 1, 83, 
    2, 89, 5, 64, 6, 36, 4, 35, 0, 99, 7, 83, 3, 36, 1, 13, 8,  2
  };
  const int q2065[] = {
    9, 9, // Number of jobs and machines
    8, 18, 7, 70, 6, 68, 3, 66, 1,  5, 2,  3, 0,  9, 5, 64, 4, 87, 
    4, 88, 3, 88, 5, 72, 6, 30, 8, 66, 1,  7, 0,  6, 2, 20, 7, 95, 
    4, 71, 7, 37, 8, 41, 3, 74, 5, 15, 0, 49, 1, 87, 2, 93, 6, 24, 
    8, 69, 3, 93, 1, 72, 7, 47, 6, 22, 5, 19, 4, 31, 0, 59, 2, 69, 
    7, 51, 8, 44, 6, 20, 5,  7, 1, 29, 2, 30, 4, 65, 0, 70, 3,  3, 
    5, 56, 1, 79, 7, 89, 8, 57, 0, 66, 3, 26, 2, 65, 6, 35, 4, 90, 
    7, 21, 8, 41, 1, 34, 5, 36, 4, 65, 2, 67, 3,  7, 6,  6, 0, 43, 
    1, 74, 7, 92, 3, 19, 5, 57, 0, 86, 8, 62, 6, 53, 2, 99, 4, 22, 
    4, 19, 8, 50, 6, 54, 0, 83, 2, 86, 3, 49, 5, 36, 1, 51, 7, 65
  };
  const int q2066[] = {
    9, 9, // Number of jobs and machines
    7, 59, 6, 55, 0,  6, 4, 64, 1, 71, 5, 21, 8, 42, 2, 63, 3, 19, 
    5, 30, 0, 97, 7, 10, 8, 86, 6, 57, 1, 72, 4, 16, 2, 92, 3, 12, 
    8, 42, 0, 77, 6, 30, 4, 67, 1, 71, 3, 62, 5, 78, 7, 23, 2,  1, 
    0, 79, 1, 37, 2,  8, 4, 80, 6, 60, 7, 87, 3, 49, 8,  2, 5, 37, 
    7,  9, 8, 36, 5,  8, 2, 41, 6, 11, 1,  6, 4, 85, 0, 18, 3,  4, 
    5, 37, 4, 74, 3, 44, 2, 85, 7, 63, 0, 62, 1, 85, 8, 98, 6, 55, 
    1, 49, 8, 10, 3, 44, 5, 26, 6, 49, 4, 29, 7, 81, 0, 18, 2, 24, 
    2, 76, 5, 80, 1, 95, 0, 21, 3, 14, 4, 89, 7, 21, 8, 79, 6, 41, 
    0, 75, 1, 29, 7, 77, 4, 78, 3, 72, 2, 34, 6, 59, 5, 44, 8, 16
  };
  const int q2067[] = {
    9, 9, // Number of jobs and machines
    7, 31, 1, 96, 6, 19, 8, 22, 0,  3, 3,  3, 4, 12, 2, 88, 5, 58, 
    8, 74, 3, 73, 6, 91, 7,  9, 0, 63, 4,  4, 1, 23, 5, 31, 2,  9, 
    7, 90, 2, 65, 6, 34, 1, 48, 5, 59, 4, 58, 8, 32, 3,  2, 0, 80, 
    0, 25, 5, 11, 8, 64, 3, 63, 4, 34, 2, 27, 6, 87, 1, 67, 7, 92, 
    4, 75, 1, 35, 8, 39, 6, 16, 7, 94, 0,  2, 5, 81, 3, 49, 2, 79, 
    5, 39, 0, 51, 1, 43, 2, 23, 7,  2, 6, 31, 4, 26, 3, 79, 8, 79, 
    2, 94, 7, 54, 4,  4, 8, 14, 0, 78, 5, 28, 1, 82, 3, 63, 6, 83, 
    8, 24, 2, 12, 0, 50, 3, 84, 5, 37, 1, 19, 7, 97, 4, 73, 6, 46, 
    5, 37, 1, 87, 3, 96, 4, 94, 0, 59, 8, 84, 6, 48, 7, 20, 2, 32
  };
  const int q2068[] = {
    9, 9, // Number of jobs and machines
    3, 22, 8, 89, 0, 72, 4, 47, 1, 24, 2, 71, 6, 19, 5,  7, 7, 20, 
    1, 13, 4, 24, 0, 93, 8, 50, 6, 99, 2, 96, 5, 90, 7, 34, 3, 59, 
    1, 77, 8, 23, 7, 34, 5, 44, 0, 59, 2, 23, 6,  6, 3, 93, 4, 38, 
    2, 99, 3, 58, 4, 51, 6, 47, 8, 10, 5, 56, 1, 25, 7, 52, 0, 40, 
    7, 20, 0, 36, 2, 69, 1, 17, 6,  8, 3, 21, 4, 26, 5,  1, 8, 14, 
    3, 35, 6, 31, 0, 38, 2, 53, 4, 26, 1, 69, 5, 55, 7,  4, 8, 39, 
    3, 53, 6, 35, 4, 48, 5, 27, 1, 48, 2, 87, 7, 81, 8, 13, 0, 30, 
    0, 25, 8, 98, 3, 29, 1, 59, 4, 47, 7, 83, 6,  5, 2,  2, 5, 71, 
    8, 65, 2, 35, 6, 14, 1, 94, 3,  5, 5, 32, 4, 67, 0, 39, 7, 92
  };
  const int q2069[] = {
    9, 9, // Number of jobs and machines
    2, 94, 1, 56, 3, 28, 8, 73, 0, 83, 6, 55, 7, 51, 4, 30, 5, 72, 
    8, 71, 7, 97, 4, 48, 1, 59, 0, 79, 3, 52, 5, 67, 2, 89, 6, 22, 
    5, 75, 1, 25, 6, 98, 0, 98, 8, 11, 2, 55, 4, 24, 3, 70, 7, 87, 
    7,  4, 8, 61, 3, 69, 0,  3, 6, 39, 1, 66, 2, 27, 5, 41, 4, 44, 
    3, 77, 1, 96, 2, 81, 5, 14, 0, 47, 6, 42, 4, 16, 8, 59, 7, 97, 
    0, 88, 5, 73, 2, 36, 6,  4, 3, 84, 7, 41, 1, 73, 4,  3, 8, 10, 
    8, 36, 7, 53, 6, 24, 0, 38, 5, 68, 3, 74, 4, 95, 2, 60, 1, 47, 
    0, 56, 7, 77, 3, 13, 4, 44, 6, 88, 2, 36, 1, 12, 5,  6, 8, 71, 
    8, 32, 1, 19, 3,  9, 4,  3, 5, 84, 0, 15, 6, 59, 2, 35, 7,  3
  };
  const int q2070[] = {
    9, 9, // Number of jobs and machines
    0, 22, 3,  3, 1, 96, 2, 14, 6, 80, 7,  7, 4,  6, 5, 30, 8, 98, 
    7, 26, 1, 91, 6, 21, 0, 41, 4, 95, 2, 94, 8, 20, 5, 11, 3,  4, 
    1, 12, 6, 78, 2, 99, 4, 41, 3,  4, 5, 73, 7, 64, 8, 27, 0, 18, 
    7, 25, 2, 61, 3, 28, 1, 77, 8, 75, 5, 49, 6, 66, 0, 62, 4, 60, 
    4, 17, 1,  4, 0, 88, 5, 28, 6, 82, 3, 15, 2, 84, 7, 40, 8, 89, 
    6, 59, 2, 20, 0, 67, 4, 37, 5, 61, 3, 73, 8, 88, 1, 43, 7, 10, 
    5, 93, 0, 99, 7,  3, 8,  9, 2, 10, 3, 19, 4, 59, 6, 69, 1, 48, 
    2, 51, 4, 35, 8, 18, 6,  9, 5, 70, 7, 90, 0, 30, 3, 92, 1, 27, 
    8, 51, 7, 14, 3, 59, 2, 44, 0, 99, 4, 90, 5, 63, 1, 58, 6, 54
  };
  const int q2071[] = {
    9, 9, // Number of jobs and machines
    0, 85, 4, 17, 7, 45, 5, 21, 2,  4, 3, 34, 6, 99, 1, 64, 8, 19, 
    8, 85, 3, 48, 1, 92, 2, 24, 5, 62, 6, 29, 4, 56, 0, 74, 7, 12, 
    5, 78, 2, 28, 7, 48, 0, 61, 3, 66, 8, 92, 4, 90, 1, 48, 6, 44, 
    7, 38, 4, 36, 2, 21, 5, 42, 8, 52, 1, 45, 6,  6, 0, 32, 3, 90, 
    5, 64, 2, 94, 0, 33, 4, 83, 1, 94, 6, 15, 3, 72, 7,  9, 8, 86, 
    8, 22, 2, 43, 6,  7, 5, 87, 3, 24, 1, 75, 7, 35, 0, 22, 4, 85, 
    1, 53, 8, 39, 2, 81, 3, 81, 4, 94, 7, 86, 5, 13, 0, 59, 6, 88, 
    8, 76, 0, 64, 3, 61, 2, 73, 1, 32, 4, 71, 5, 29, 6, 32, 7,  8, 
    6, 42, 3,  1, 1, 88, 0, 85, 7, 39, 2, 24, 8, 29, 4, 60, 5, 62
  };
  const int q2072[] = {
    9, 9, // Number of jobs and machines
    6,  5, 7, 21, 5,  6, 4, 69, 1,  4, 0, 54, 2, 49, 3, 61, 8, 15, 
    4, 19, 6, 77, 5, 12, 1, 15, 7, 44, 8,  6, 3, 36, 0, 57, 2,  3, 
    1, 33, 8, 64, 6, 75, 2, 32, 7,  9, 0, 29, 4, 19, 3, 98, 5, 39, 
    6, 83, 5, 15, 2, 34, 0, 84, 3, 49, 7,  8, 8, 74, 4, 18, 1, 12, 
    3, 81, 8, 82, 2, 53, 5,  6, 7, 53, 6, 69, 0, 63, 1, 46, 4, 50, 
    2, 56, 6, 99, 0, 51, 7, 97, 8, 78, 3, 93, 5, 88, 1, 86, 4, 35, 
    3, 23, 2, 65, 8, 95, 4, 33, 6, 75, 5, 67, 0, 89, 7, 13, 1, 76, 
    3, 29, 1, 70, 8, 78, 6, 75, 5, 61, 4, 65, 2, 80, 0, 58, 7, 14, 
    6, 31, 3, 87, 7, 78, 8, 37, 1, 18, 0, 18, 2,  2, 4, 90, 5, 51
  };
  const int q2073[] = {
    9, 9, // Number of jobs and machines
    5, 13, 0, 25, 2, 93, 3, 97, 4,  2, 7, 89, 8, 38, 1, 40, 6, 64, 
    0, 88, 5, 54, 1, 41, 2, 48, 7, 64, 3, 12, 8, 53, 4, 64, 6, 69, 
    2, 24, 1, 92, 5, 20, 3,  5, 4, 82, 8, 76, 0, 25, 7, 76, 6, 85, 
    5, 82, 3, 94, 6,  6, 4,  1, 0, 71, 7, 88, 1, 99, 2, 31, 8,  7, 
    5, 24, 4, 50, 1, 96, 8, 21, 6, 47, 2, 96, 7, 71, 0,  4, 3, 32, 
    1, 10, 4,  5, 0, 33, 6, 46, 7, 47, 3, 67, 5, 57, 2, 68, 8, 77, 
    7, 97, 4,  9, 1, 51, 6, 12, 3, 80, 8, 62, 2, 23, 0, 26, 5, 31, 
    3, 37, 8, 54, 1, 22, 5, 41, 0, 99, 4, 10, 7, 98, 6, 70, 2, 28, 
    3,  1, 7, 70, 6, 42, 5, 55, 8,  5, 4, 44, 0, 12, 2, 98, 1,  6
  };
  const int q2074[] = {
    9, 9, // Number of jobs and machines
    1, 47, 2, 72, 3, 83, 5, 77, 6, 26, 4, 36, 7, 63, 8, 19, 0, 53, 
    5, 18, 0, 53, 6, 71, 8, 81, 2, 11, 1, 76, 7, 51, 4,  1, 3, 52, 
    1, 54, 4, 60, 0, 99, 8, 89, 7, 37, 6, 28, 3,  1, 2, 31, 5, 36, 
    6, 75, 1, 20, 0,  4, 3, 14, 7,  8, 2, 71, 8,  2, 4, 82, 5, 54, 
    4, 17, 8, 28, 3, 32, 2, 43, 6, 99, 7, 38, 1, 97, 0, 68, 5, 73, 
    1, 61, 7, 34, 2, 36, 0,  9, 5, 90, 4, 44, 8,  9, 3, 11, 6, 84, 
    8, 92, 7, 45, 2, 93, 5, 78, 4, 19, 0, 98, 3, 82, 1, 79, 6, 57, 
    7, 87, 8, 62, 3, 40, 2, 12, 5, 56, 1, 78, 0, 92, 4, 70, 6,  1, 
    5, 62, 6, 39, 2, 95, 7, 84, 1, 19, 0,  1, 4, 42, 8, 88, 3, 68
  };
  const int q2075[] = {
    9, 9, // Number of jobs and machines
    4, 84, 3, 55, 8, 39, 5, 27, 7, 51, 6, 24, 2, 69, 0, 94, 1, 97, 
    0, 57, 2, 83, 3, 20, 7, 55, 8, 39, 1, 17, 5, 11, 4,  1, 6, 82, 
    5, 66, 3, 62, 1, 20, 6, 29, 2, 97, 7, 61, 4, 46, 8,  4, 0, 17, 
    6, 39, 5, 17, 1, 98, 8, 91, 3, 24, 4, 34, 7, 72, 2, 55, 0, 25, 
    1, 14, 0, 34, 7, 47, 2, 58, 8, 90, 6, 13, 4, 65, 3, 46, 5,  3, 
    7, 17, 1, 13, 8, 68, 2, 78, 4, 44, 6, 17, 0, 17, 5, 70, 3,  2, 
    6, 41, 7, 12, 3, 55, 5, 70, 2, 89, 0, 77, 1, 41, 4, 48, 8,  4, 
    0, 20, 4, 70, 8, 69, 2, 50, 1, 79, 3, 57, 7, 68, 6, 14, 5,  1, 
    4, 80, 7, 97, 1, 39, 6, 53, 0, 80, 5, 40, 8, 18, 2, 51, 3, 48
  };
  const int q2076[] = {
    9, 9, // Number of jobs and machines
    2, 33, 6, 46, 7, 29, 0, 91, 8, 87, 4, 58, 5, 29, 1, 48, 3, 19, 
    3, 18, 1, 24, 7, 42, 6, 82, 4, 32, 0, 27, 5, 81, 2, 92, 8, 62, 
    4, 40, 1, 96, 0, 75, 7, 75, 3, 66, 8, 14, 5, 28, 2, 67, 6, 63, 
    0, 12, 6,  3, 5, 44, 2, 78, 8, 27, 4, 96, 3, 75, 1, 52, 7, 41, 
    5, 38, 3, 32, 1, 42, 0, 66, 6, 33, 8, 32, 4, 60, 2, 65, 7, 49, 
    0, 19, 2, 27, 4, 34, 6, 41, 1, 75, 3, 59, 7, 19, 8, 62, 5, 77, 
    0, 40, 2, 92, 5,  7, 3, 62, 6, 75, 4, 16, 8, 89, 1, 10, 7, 69, 
    3, 83, 8, 50, 4, 10, 0, 44, 7, 87, 6, 81, 1, 65, 5, 86, 2, 76, 
    8, 27, 3, 92, 1, 10, 5, 36, 6, 70, 7, 24, 0,  8, 4, 63, 2, 83
  };
  const int q2077[] = {
    9, 9, // Number of jobs and machines
    4, 11, 5, 22, 7, 24, 8, 27, 2, 50, 0, 39, 1, 69, 3, 71, 6, 77, 
    7, 73, 3, 88, 4, 48, 5, 89, 6, 81, 0, 44, 2, 81, 8, 58, 1, 80, 
    3,  8, 2, 20, 4, 45, 8, 92, 7, 25, 1,  8, 0, 36, 5, 27, 6,  4, 
    1, 99, 7, 84, 4, 20, 2, 68, 5, 80, 8, 86, 6, 67, 0, 41, 3, 55, 
    5, 52, 8, 90, 1, 52, 7, 90, 2, 45, 4, 23, 3, 11, 0, 96, 6, 31, 
    5, 18, 6, 22, 1, 27, 3, 73, 7, 97, 0, 14, 2, 98, 8, 54, 4, 65, 
    7, 91, 4, 12, 8, 45, 1,  7, 3, 23, 2, 64, 0, 27, 5, 40, 6, 75, 
    4, 62, 8, 22, 6,  3, 3, 62, 2, 21, 1, 78, 7, 60, 0, 33, 5, 45, 
    3, 49, 5, 80, 0, 57, 7, 30, 8, 17, 2, 22, 1, 10, 6, 82, 4, 13
  };
  const int q2078[] = {
    9, 9, // Number of jobs and machines
    3, 96, 2, 88, 1, 60, 0, 32, 8, 14, 6, 17, 7, 62, 5, 46, 4, 50, 
    2, 12, 7,  2, 6, 59, 1, 13, 8, 35, 5, 44, 4, 42, 3, 41, 0, 13, 
    5, 96, 2, 95, 1, 43, 7, 46, 4, 80, 0, 64, 8, 89, 6, 35, 3,  3, 
    8,  4, 4, 82, 1, 81, 0, 76, 7, 98, 5, 24, 3, 54, 6, 58, 2, 34, 
    4,  4, 5, 95, 1, 23, 3, 91, 7, 86, 0, 51, 6, 81, 2, 15, 8,  4, 
    1,  9, 0, 39, 4, 66, 8, 28, 7, 95, 5, 32, 6, 16, 3, 42, 2, 16, 
    7, 28, 4, 99, 2, 95, 3, 90, 5, 13, 8, 67, 6, 15, 1, 82, 0, 32, 
    7, 16, 3, 89, 1, 26, 0, 19, 8, 87, 4, 64, 2, 80, 5, 33, 6, 91, 
    4, 46, 8, 26, 5, 38, 0, 78, 7, 99, 1, 23, 3, 22, 2, 33, 6, 65
  };
  const int q2079[] = {
    9, 9, // Number of jobs and machines
    5, 19, 8, 58, 6, 83, 4,  6, 2, 91, 0,  8, 7, 38, 1, 15, 3, 40, 
    4, 35, 5, 85, 7, 60, 0, 36, 6, 31, 2, 55, 1,  3, 8, 47, 3, 78, 
    0, 11, 7, 12, 5, 36, 4,  2, 2, 29, 8, 97, 6, 66, 3, 67, 1,  7, 
    7, 75, 8, 59, 6, 73, 1, 80, 4, 63, 3, 71, 2, 40, 5, 88, 0, 69, 
    1, 97, 5, 47, 7, 34, 6, 21, 2, 91, 4, 45, 3, 20, 8, 35, 0, 34, 
    7, 14, 3, 59, 2, 55, 6, 29, 0, 37, 4, 12, 8, 23, 5, 28, 1, 88, 
    0, 17, 8,  9, 5, 66, 1, 85, 4, 55, 2, 97, 7, 84, 6,  2, 3, 76, 
    4, 25, 5, 31, 0, 83, 2, 11, 8, 94, 6, 90, 7, 41, 1,  5, 3, 54, 
    0, 22, 1,  3, 6, 24, 4, 39, 8, 59, 7, 93, 5, 44, 3, 76, 2,  1
  };
  const int q2080[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 74, 0, 80, 1, 74, 7,  8, 3, 31, 6, 93, 5, 55, 8, 92, 
    1, 31, 7, 94, 6, 55, 3, 83, 4, 23, 2, 84, 0, 80, 5, 25, 8, 28, 
    2, 73, 7, 60, 6, 80, 3, 10, 8,  5, 5, 10, 0, 57, 1, 28, 4, 48, 
    6, 28, 3, 31, 1, 22, 0, 62, 5, 97, 7, 47, 4, 75, 2, 73, 8, 66, 
    2, 75, 6, 38, 5, 92, 7, 49, 8, 89, 1, 50, 0, 64, 4, 44, 3, 28, 
    8, 50, 1, 89, 7,  9, 4, 89, 5, 47, 3, 18, 2, 56, 0, 10, 6, 60, 
    0, 73, 3, 28, 7, 58, 8, 47, 1, 62, 2,  2, 4, 90, 5,  8, 6, 22, 
    5, 24, 4, 46, 3, 62, 7, 50, 1, 73, 8, 74, 2, 27, 0,  2, 6, 84, 
    0, 71, 8, 91, 2, 44, 6, 36, 3, 65, 5, 28, 4, 18, 1,  2, 7, 59
  };
  const int q2081[] = {
    9, 9, // Number of jobs and machines
    1, 70, 2, 38, 7, 51, 5, 49, 3, 99, 8,  3, 6, 10, 4, 88, 0, 79, 
    1, 67, 5, 49, 4, 55, 2, 28, 7, 31, 8, 19, 6, 86, 3, 41, 0, 44, 
    6, 80, 2, 84, 3, 69, 4, 54, 5, 46, 7, 98, 8, 97, 0, 83, 1, 50, 
    8, 35, 6, 89, 1, 24, 2, 79, 3, 90, 0, 78, 4, 52, 5, 14, 7, 11, 
    6, 24, 5, 21, 8, 59, 0, 48, 2,  6, 7, 13, 3, 90, 4, 51, 1, 87, 
    0,  6, 6, 27, 2, 62, 8,  2, 7, 39, 4, 32, 1, 14, 3, 38, 5, 10, 
    8, 65, 2, 50, 0,  9, 5, 71, 3, 62, 6, 17, 4, 80, 1, 43, 7, 64, 
    0, 11, 2, 23, 7, 27, 1, 90, 6, 39, 5, 65, 3, 20, 8, 57, 4, 41, 
    6, 72, 3, 79, 8, 87, 2, 92, 7, 88, 1, 43, 0, 52, 5, 95, 4, 43
  };
  const int q2082[] = {
    9, 9, // Number of jobs and machines
    4, 37, 1, 61, 8, 49, 7, 24, 2, 33, 5, 51, 6, 51, 0, 26, 3, 89, 
    3, 90, 7,  7, 1, 89, 2, 28, 0, 65, 5, 32, 4, 48, 8, 52, 6, 11, 
    3, 99, 7, 54, 5, 11, 1, 88, 8, 41, 0, 30, 2, 98, 4, 37, 6, 92, 
    8, 46, 2, 53, 4, 19, 7, 81, 3, 84, 5, 59, 6, 87, 0, 43, 1, 19, 
    3, 87, 1, 87, 6, 18, 5,  3, 8, 23, 4, 31, 0, 98, 7, 33, 2, 40, 
    3, 31, 4, 25, 6, 10, 1, 72, 7, 72, 2, 89, 0, 31, 5, 29, 8, 16, 
    5, 55, 2, 54, 1, 77, 0, 60, 7, 70, 4, 50, 3, 79, 8, 38, 6, 63, 
    1, 56, 7, 79, 3, 61, 8, 83, 5, 73, 4, 61, 2, 87, 6, 65, 0, 98, 
    6, 84, 3, 61, 7, 55, 1, 64, 2, 55, 8, 10, 4, 78, 5, 45, 0, 53
  };
  const int q2083[] = {
    9, 9, // Number of jobs and machines
    7, 78, 8, 62, 5,  4, 2, 38, 1, 55, 4, 35, 0, 51, 6, 68, 3, 99, 
    7, 30, 8, 41, 5,  9, 3, 22, 4, 27, 1, 72, 2, 39, 0, 91, 6, 57, 
    5, 18, 4, 21, 7, 93, 0, 17, 1, 19, 6, 19, 8, 80, 2, 38, 3, 66, 
    1, 18, 7,  4, 6, 51, 8,  7, 0, 20, 4, 37, 2, 36, 3, 60, 5, 21, 
    1, 80, 7, 33, 6, 32, 2, 56, 4, 60, 3,  1, 0, 52, 5, 71, 8, 22, 
    5, 94, 7, 16, 8,  8, 4, 57, 6, 59, 0, 84, 2, 91, 3, 34, 1, 32, 
    1, 67, 2, 47, 7, 64, 5, 40, 4, 57, 3, 33, 6, 91, 0, 11, 8, 98, 
    5, 34, 7, 25, 2, 25, 8, 68, 6, 97, 4, 89, 0, 19, 1,  4, 3, 61, 
    6, 61, 7, 80, 8, 78, 5, 97, 3, 33, 1, 49, 4, 37, 0, 83, 2, 88
  };
  const int q2084[] = {
    9, 9, // Number of jobs and machines
    6, 80, 8, 53, 3,  6, 0, 62, 1, 66, 2, 13, 5, 54, 4, 88, 7,  5, 
    8, 85, 0, 54, 4, 47, 2,  5, 7, 45, 1, 73, 3, 49, 5, 72, 6, 36, 
    3, 14, 8, 31, 5, 86, 1, 29, 0, 40, 6, 36, 7, 48, 4, 44, 2, 91, 
    1, 98, 2, 72, 5, 77, 8, 84, 6, 26, 0, 64, 3, 62, 4, 91, 7, 63, 
    5, 91, 7, 26, 1, 87, 2, 40, 8, 69, 6,  3, 0, 70, 3,  2, 4, 48, 
    1, 79, 6, 95, 4, 84, 0, 91, 8, 83, 3, 24, 5, 29, 2, 67, 7, 68, 
    0, 75, 3, 77, 6, 10, 2, 49, 5, 11, 1, 62, 8, 53, 7, 11, 4, 87, 
    8, 98, 7, 94, 2, 41, 4, 73, 3, 39, 0, 74, 6, 96, 1, 21, 5, 85, 
    7, 96, 2, 74, 0, 79, 8, 53, 3, 46, 1, 62, 6, 79, 4, 94, 5, 96
  };
  const int q2085[] = {
    9, 9, // Number of jobs and machines
    5, 34, 1, 68, 0, 91, 3, 92, 2, 64, 6, 36, 8, 52, 4, 79, 7, 38, 
    4, 51, 7, 81, 0, 64, 3, 45, 6, 83, 1, 38, 5, 50, 2, 72, 8, 83, 
    0, 36, 2, 35, 7,  4, 8, 46, 4, 91, 5,  2, 3, 91, 1, 92, 6, 21, 
    6, 16, 5, 89, 0, 48, 7, 12, 8, 30, 4, 95, 3,  5, 1, 23, 2, 32, 
    8, 25, 7, 83, 5, 76, 4, 15, 3, 15, 0, 99, 2, 32, 6, 56, 1,  4, 
    4,  5, 8, 51, 1, 62, 2, 64, 0, 20, 6, 24, 5,  7, 3, 73, 7, 29, 
    4, 65, 8,  1, 0, 88, 2, 45, 7,  4, 5, 49, 1, 24, 3,  3, 6, 39, 
    1, 45, 8,  1, 5, 20, 3,  4, 7, 82, 0, 24, 4, 45, 2, 10, 6, 30, 
    8, 64, 4, 26, 0,  1, 2, 39, 5, 65, 7, 48, 1, 54, 3, 68, 6, 85
  };
  const int q2086[] = {
    9, 9, // Number of jobs and machines
    4,  8, 3,  7, 7, 48, 8, 17, 1, 98, 6, 58, 2, 57, 5, 41, 0, 68, 
    5, 94, 2, 29, 8, 74, 7, 83, 6, 55, 0, 82, 4, 76, 1, 52, 3, 58, 
    4, 40, 5, 27, 3, 82, 1, 43, 0, 58, 6, 25, 7, 10, 8, 29, 2,  1, 
    5, 85, 1, 65, 0, 19, 2, 61, 7, 94, 8, 64, 6, 35, 3, 27, 4, 30, 
    3, 41, 1,  9, 0, 60, 7, 66, 8, 77, 4,  8, 6, 44, 5, 78, 2, 48, 
    6, 20, 8, 97, 3, 32, 7, 44, 5, 91, 1, 88, 4, 45, 0, 83, 2, 69, 
    6, 65, 2, 80, 0, 60, 4, 59, 5, 80, 1, 53, 7, 47, 3, 41, 8, 55, 
    2, 93, 1, 32, 7, 83, 5, 37, 6, 33, 3,  8, 0, 24, 4, 27, 8,  6, 
    7,  8, 1, 94, 6, 62, 3, 87, 0, 33, 5,  8, 4, 51, 8, 78, 2, 69
  };
  const int q2087[] = {
    9, 9, // Number of jobs and machines
    3, 42, 1, 26, 0, 38, 8, 26, 2,  9, 6, 90, 4, 86, 5, 16, 7,  9, 
    1, 58, 3,  3, 2, 22, 5, 42, 6,  1, 7, 21, 0, 99, 8, 47, 4, 68, 
    2, 17, 0,  1, 3, 16, 1, 72, 5, 13, 4, 42, 7, 96, 8, 32, 6, 38, 
    1, 33, 5, 37, 7, 11, 2, 46, 4, 77, 8, 27, 6, 18, 0, 76, 3, 96, 
    3, 77, 4,  2, 7, 29, 8, 47, 0, 65, 1, 31, 6, 69, 5,  8, 2, 62, 
    7,  7, 0, 97, 8, 73, 3, 42, 4, 33, 5,  3, 6, 45, 2, 45, 1, 74, 
    4, 60, 6, 13, 2, 80, 8, 34, 5, 90, 3, 17, 7, 45, 1, 79, 0, 90, 
    6, 35, 5, 25, 1, 85, 2,  6, 3, 44, 8, 50, 0, 26, 7, 27, 4, 90, 
    3, 77, 2, 67, 0, 98, 1,  5, 6, 95, 7, 82, 4, 21, 5, 65, 8, 61
  };
  const int q2088[] = {
    9, 9, // Number of jobs and machines
    7, 39, 6, 28, 3, 37, 4, 40, 8, 85, 0, 84, 2, 91, 1,  6, 5,  7, 
    7, 52, 5, 95, 3, 62, 0, 35, 2, 69, 6, 76, 8,  2, 4, 75, 1, 59, 
    7, 75, 5, 52, 8,  4, 3, 66, 4, 15, 1, 31, 6, 12, 0, 29, 2, 53, 
    1, 61, 7, 38, 6, 30, 3, 53, 4, 27, 2,  8, 0, 37, 5,  7, 8, 46, 
    3, 65, 1, 38, 7, 94, 4, 16, 6, 12, 0, 14, 5, 16, 2, 13, 8, 36, 
    8, 37, 1, 15, 5,  9, 6, 46, 0, 61, 3, 36, 4, 91, 2, 35, 7, 27, 
    5, 46, 8, 21, 6, 14, 1, 99, 7, 53, 0, 12, 2, 11, 4, 82, 3, 47, 
    1,  8, 6, 24, 8, 60, 2, 52, 5, 11, 3, 46, 0,  3, 7, 65, 4, 53, 
    8, 86, 7, 74, 3, 90, 6, 70, 2, 88, 0, 33, 4, 33, 5, 12, 1, 88
  };
  const int q2089[] = {
    9, 9, // Number of jobs and machines
    1, 91, 3, 36, 7, 33, 8, 63, 6, 17, 5, 88, 0, 26, 4, 56, 2, 81, 
    2, 34, 4, 50, 3, 39, 6, 13, 1, 47, 5, 55, 7,  3, 8, 41, 0, 15, 
    0, 62, 8, 33, 2,  5, 4, 78, 3, 51, 5, 90, 1, 32, 6, 20, 7, 45, 
    1,  6, 2, 35, 4, 67, 6, 64, 3,  5, 0, 85, 8, 14, 7, 95, 5,  5, 
    6, 91, 2, 10, 5, 17, 8, 82, 7,  3, 4, 96, 3, 80, 1, 89, 0, 15, 
    5, 58, 4, 10, 6, 22, 3, 67, 2, 77, 7,  8, 1, 39, 8, 62, 0, 21, 
    1, 26, 3, 59, 2, 76, 5, 76, 6, 89, 7, 38, 4, 74, 8, 29, 0, 72, 
    6, 55, 4, 15, 7, 97, 8, 22, 1, 92, 0, 56, 2, 91, 3, 30, 5, 16, 
    3, 55, 5, 39, 7, 99, 2, 89, 1, 60, 0, 18, 6, 22, 4, 96, 8, 83
  };
  const int q2090[] = {
    9, 9, // Number of jobs and machines
    4, 41, 1, 94, 8, 81, 2, 50, 6,  5, 7, 89, 0, 74, 5, 49, 3, 91, 
    6, 80, 1, 89, 8, 57, 0, 28, 5, 28, 3, 97, 2, 28, 4, 82, 7, 70, 
    3, 38, 6,  6, 0, 84, 5, 16, 8, 68, 2, 16, 1, 43, 7, 63, 4, 18, 
    7, 69, 3, 61, 1, 93, 2, 34, 0, 78, 5, 61, 8, 27, 6, 87, 4, 18, 
    6, 71, 3, 95, 4, 69, 2, 30, 5, 63, 7, 72, 1, 46, 8, 58, 0, 82, 
    0, 73, 2, 49, 7,  6, 5, 11, 8, 76, 6, 38, 1, 68, 4, 59, 3, 59, 
    3, 40, 2, 96, 4, 89, 0, 83, 5, 99, 7, 66, 8, 47, 1, 23, 6, 75, 
    8, 33, 4, 96, 5, 56, 7, 70, 2, 12, 6, 33, 0, 67, 3, 15, 1, 46, 
    5, 86, 4, 18, 6, 51, 7,  1, 1, 50, 3, 39, 2, 93, 8, 99, 0,  1
  };
  const int q2091[] = {
    9, 9, // Number of jobs and machines
    6, 40, 8, 34, 4, 84, 5, 83, 1, 48, 3, 65, 2, 89, 7, 91, 0, 46, 
    0, 77, 6, 25, 5, 70, 4, 19, 7, 47, 3, 27, 1, 40, 8, 46, 2, 41, 
    1, 36, 5, 60, 7, 93, 8, 68, 2, 67, 3, 61, 0, 20, 4, 20, 6, 50, 
    3, 48, 7, 85, 5, 79, 2, 10, 1, 98, 0, 48, 4, 33, 6, 68, 8, 61, 
    4, 62, 8, 58, 0, 22, 3, 54, 6, 56, 2, 94, 7, 70, 1, 76, 5, 61, 
    4, 45, 5, 44, 2, 84, 1, 56, 3, 93, 8, 32, 0, 71, 7, 55, 6, 25, 
    6, 88, 4, 69, 5, 86, 1, 16, 3, 43, 7, 64, 2, 23, 8, 61, 0, 25, 
    7, 44, 2, 69, 0, 42, 1, 38, 4, 40, 5, 95, 8, 47, 6, 10, 3, 79, 
    6, 94, 8, 10, 0, 87, 7, 21, 5, 75, 1, 91, 3, 21, 2, 26, 4, 33
  };
  const int q2092[] = {
    9, 9, // Number of jobs and machines
    8,  6, 3, 52, 2,  5, 7, 54, 5, 61, 6, 29, 4, 18, 1, 35, 0, 25, 
    8,  6, 7, 92, 4, 94, 1, 19, 5, 95, 3, 30, 2, 47, 6, 61, 0, 57, 
    1, 18, 2,  2, 5, 92, 0, 33, 3, 50, 4,  2, 6, 15, 8, 74, 7, 11, 
    7, 30, 5, 75, 2, 83, 1, 84, 6, 70, 0, 48, 4, 71, 8, 40, 3, 81, 
    4, 91, 1, 87, 0, 47, 5, 92, 7, 59, 2, 40, 6, 52, 8,  5, 3, 74, 
    3, 87, 2, 87, 1, 26, 8, 10, 4,  5, 0, 75, 6, 80, 5, 92, 7, 38, 
    8, 92, 7, 72, 6, 51, 5, 38, 4, 70, 2, 57, 3, 30, 0, 72, 1,  1, 
    4, 79, 1, 73, 7, 40, 8, 67, 2, 24, 6,  1, 0, 63, 5, 27, 3, 91, 
    2, 53, 0, 36, 6, 14, 1, 84, 8, 75, 7,  6, 4, 74, 5, 26, 3, 24
  };
  const int q2093[] = {
    9, 9, // Number of jobs and machines
    8, 99, 1, 73, 4, 88, 3, 11, 6, 51, 5, 41, 7, 53, 0, 45, 2, 32, 
    4, 38, 1, 35, 7, 22, 8, 23, 5, 54, 6, 53, 2, 25, 3,  4, 0, 68, 
    4, 14, 8, 83, 1, 57, 7, 44, 3, 32, 0, 21, 2, 14, 6, 17, 5, 65, 
    0, 86, 8, 28, 2, 19, 1, 34, 3, 70, 7, 62, 6,  8, 4, 51, 5, 65, 
    2, 52, 7,  3, 4, 90, 5, 70, 6, 15, 0, 31, 8, 65, 1, 29, 3, 15, 
    1, 76, 8, 61, 3, 93, 2, 69, 6, 88, 7, 87, 5, 89, 4, 98, 0, 74, 
    8, 28, 2, 16, 0,  7, 3, 14, 6,  7, 7, 49, 1, 90, 5, 69, 4, 47, 
    4, 60, 6, 26, 5,  4, 1, 32, 3, 35, 2, 83, 0, 73, 7, 76, 8, 15, 
    0, 40, 1, 80, 7, 56, 4, 72, 8, 26, 2, 86, 5, 72, 3,  1, 6, 97
  };
  const int q2094[] = {
    9, 9, // Number of jobs and machines
    8, 78, 6, 67, 2, 31, 1, 14, 0, 68, 7, 57, 5, 72, 4,  3, 3, 12, 
    3, 23, 2, 51, 0, 95, 6, 53, 8, 89, 7,  7, 1, 55, 5,  8, 4, 15, 
    3, 10, 4, 67, 2, 21, 1, 51, 5, 14, 0, 92, 6,  9, 8, 65, 7, 54, 
    5, 75, 6, 57, 1, 16, 3, 88, 0, 57, 2, 19, 8, 29, 4, 21, 7, 65, 
    5, 13, 8,  6, 3, 82, 2, 44, 7, 62, 4, 78, 6, 26, 0, 97, 1, 89, 
    7, 87, 1, 36, 3, 67, 2,  3, 6, 96, 5, 36, 8, 78, 4, 31, 0, 74, 
    2,  8, 6, 36, 3, 95, 5, 65, 4, 94, 0,  3, 7, 60, 8, 82, 1, 10, 
    3, 85, 0, 86, 1, 35, 5, 97, 8, 60, 4, 98, 2, 26, 7, 36, 6, 45, 
    5, 21, 3, 67, 6, 11, 4, 24, 2, 79, 1, 62, 8, 69, 7, 68, 0, 24
  };
  const int q2095[] = {
    9, 9, // Number of jobs and machines
    6, 98, 1, 67, 8, 31, 0, 34, 7, 88, 3, 19, 4, 28, 5, 40, 2, 22, 
    4, 52, 8, 81, 3, 70, 2, 69, 7, 25, 6, 91, 5, 14, 1, 85, 0, 31, 
    7,  1, 0, 50, 8, 24, 1,  5, 5, 65, 6,  3, 3, 46, 2, 57, 4, 44, 
    6, 10, 0, 82, 5, 44, 8, 25, 1, 92, 3, 23, 2, 32, 4, 24, 7,  4, 
    8, 62, 4, 19, 6, 55, 7, 36, 0, 15, 1, 93, 5, 52, 2, 83, 3, 77, 
    2, 95, 7, 21, 6,  4, 0,  1, 3, 81, 4, 80, 5, 47, 8, 36, 1,  9, 
    6, 61, 0, 49, 3, 96, 5, 74, 1, 24, 4, 63, 7, 16, 2, 42, 8, 75, 
    5, 79, 7, 41, 2, 13, 0, 38, 1, 57, 6, 98, 8, 36, 4, 75, 3, 27, 
    6, 75, 3, 43, 8, 56, 0,  3, 5, 28, 1, 75, 4, 25, 7,  5, 2, 65
  };
  const int q2096[] = {
    9, 9, // Number of jobs and machines
    6, 76, 4, 80, 7, 85, 3, 35, 5, 31, 0, 60, 8, 41, 2, 85, 1, 37, 
    3, 23, 2,  1, 8, 90, 7, 19, 1, 62, 6, 94, 4, 37, 0, 58, 5, 70, 
    8, 34, 7, 23, 6,  5, 0, 46, 2, 82, 1, 65, 4, 17, 3, 59, 5, 39, 
    4, 33, 2, 34, 5, 94, 1, 32, 6, 20, 3, 28, 7, 59, 8, 54, 0, 76, 
    2,  9, 0, 21, 6, 93, 4,  7, 7, 24, 5,  9, 3, 97, 1, 25, 8, 23, 
    3, 97, 1, 73, 6, 18, 2,  6, 4, 32, 0, 26, 8,  9, 5, 97, 7, 89, 
    3, 49, 6, 77, 0, 77, 4, 21, 7, 86, 5, 98, 8, 98, 2, 75, 1, 24, 
    7,  8, 4, 23, 6, 53, 5, 33, 0, 25, 8, 39, 3, 35, 1, 98, 2, 38, 
    8, 88, 6, 80, 7, 39, 2, 91, 4, 66, 5, 84, 1, 70, 0, 85, 3, 91
  };
  const int q2097[] = {
    9, 9, // Number of jobs and machines
    5, 83, 0, 98, 2, 52, 4, 68, 3,  6, 1, 27, 7,  9, 6, 49, 8, 82, 
    6, 96, 1, 10, 8, 59, 2,  7, 0, 68, 3, 29, 4,  8, 5, 20, 7, 87, 
    0,  8, 6, 90, 7, 37, 4, 52, 3, 82, 8, 61, 2, 86, 5, 61, 1, 97, 
    5, 98, 4, 72, 2, 17, 7, 41, 0, 68, 6, 30, 8, 70, 3,  9, 1, 17, 
    2, 26, 7, 64, 5, 16, 3,  3, 6, 36, 8, 16, 0, 36, 1, 27, 4, 56, 
    5, 14, 8, 36, 4, 77, 7, 55, 6, 56, 0,  1, 2, 31, 3, 31, 1, 95, 
    5, 85, 7, 15, 8, 18, 0, 81, 4,  3, 1, 38, 6, 27, 2, 39, 3, 10, 
    8, 33, 7, 57, 5, 73, 0, 86, 1,  3, 2, 82, 6, 50, 4, 38, 3, 60, 
    0, 81, 2, 30, 1, 59, 5, 21, 4, 93, 7, 12, 8,  3, 3, 42, 6, 17
  };
  const int q2098[] = {
    9, 9, // Number of jobs and machines
    7, 12, 2, 24, 0, 15, 3, 97, 6, 45, 1, 47, 8, 68, 5,  9, 4, 68, 
    2,  7, 0, 15, 5, 10, 4, 82, 6, 24, 1,  8, 8, 26, 7, 45, 3, 83, 
    0, 24, 1, 13, 4, 93, 3, 67, 7,  1, 8, 60, 5, 64, 6, 33, 2, 42, 
    5, 78, 8, 83, 0, 22, 7, 39, 2, 65, 6, 72, 4, 31, 3, 64, 1, 64, 
    2, 60, 3, 66, 8, 29, 5, 27, 4,  1, 0,  9, 7, 77, 6, 26, 1, 50, 
    8, 54, 4, 49, 0, 11, 2,  2, 5, 14, 3,  3, 7, 85, 1, 81, 6, 12, 
    4, 22, 0, 20, 5, 88, 8, 37, 7,  8, 6, 70, 1, 30, 2, 65, 3, 62, 
    0, 50, 6, 28, 2, 92, 8, 66, 7, 51, 4, 95, 3, 97, 1, 75, 5, 61, 
    2, 19, 6, 32, 4, 15, 1, 59, 0, 75, 8, 39, 5, 10, 3, 68, 7, 80
  };
  const int q2099[] = {
    9, 9, // Number of jobs and machines
    3,  1, 7, 18, 2, 86, 0, 41, 4, 36, 8, 49, 5, 21, 6, 77, 1, 92, 
    7, 80, 8, 27, 4, 19, 1, 49, 5, 83, 6, 66, 0, 26, 2, 37, 3, 91, 
    5, 27, 8, 10, 1, 24, 7, 21, 3, 70, 2, 83, 4, 70, 6,  5, 0, 10, 
    8, 38, 5, 91, 1,  4, 4, 46, 2, 79, 7, 62, 6, 90, 3, 86, 0, 20, 
    5, 33, 7, 75, 8, 17, 0, 27, 4, 32, 1, 82, 6, 30, 3, 28, 2,  7, 
    4, 68, 7, 36, 3, 43, 2, 73, 8, 26, 6, 67, 0, 80, 5, 82, 1, 15, 
    1, 83, 3, 16, 5, 33, 4, 51, 2, 92, 7, 75, 8, 92, 6, 21, 0, 11, 
    7, 11, 2, 17, 8, 11, 1, 86, 4, 80, 5, 35, 0, 10, 3, 22, 6, 65, 
    4, 62, 2, 72, 3,  9, 6, 80, 7, 87, 0,  8, 8, 46, 5, 72, 1, 94
  };
  const int q2100[] = {
    9, 9, // Number of jobs and machines
    4, 73, 1,  5, 2, 92, 3,  6, 6, 51, 7, 12, 0,  9, 5, 73, 8, 29, 
    2, 11, 7, 63, 0, 39, 1, 56, 8, 10, 6, 14, 5, 68, 4, 65, 3, 21, 
    8, 86, 0, 67, 3, 46, 6, 94, 4,  5, 5, 97, 7, 33, 2, 45, 1, 74, 
    2, 55, 1, 64, 0, 73, 3, 20, 5, 88, 7, 73, 4, 97, 6, 43, 8, 98, 
    8, 59, 0, 10, 4, 88, 7, 28, 1, 24, 2, 81, 5, 12, 3, 58, 6,  3, 
    4, 80, 3, 11, 7, 41, 8, 18, 0,  4, 2, 46, 1, 98, 6, 98, 5, 98, 
    8, 12, 0, 57, 2, 16, 6, 50, 3, 11, 4, 54, 1, 58, 5, 82, 7, 43, 
    4, 64, 7, 59, 6, 35, 8, 27, 0, 29, 3, 74, 1, 26, 2, 84, 5, 56, 
    8, 45, 2, 50, 3, 92, 6, 90, 0, 32, 5, 49, 1, 80, 4, 79, 7, 20
  };
  const int q2101[] = {
    9, 9, // Number of jobs and machines
    8, 10, 1, 71, 4, 23, 0, 54, 7, 51, 6, 18, 3, 62, 5,  4, 2, 60, 
    3, 63, 6, 11, 8, 71, 1, 40, 7,  7, 5, 97, 0, 53, 2, 99, 4, 72, 
    8, 29, 2, 78, 7, 40, 3, 21, 0, 24, 1, 77, 6, 75, 5, 53, 4, 50, 
    5, 56, 3, 65, 6,  4, 1, 71, 7, 96, 4,  2, 8, 45, 0, 12, 2, 98, 
    2, 23, 6, 54, 5, 81, 8, 37, 7,  5, 1,  8, 3, 21, 4, 64, 0, 69, 
    3, 50, 8,  3, 0, 72, 2, 43, 6, 66, 5, 19, 4, 46, 1, 57, 7,  6, 
    2, 94, 8, 23, 6, 89, 4, 34, 5, 13, 3, 99, 7, 69, 0, 42, 1, 69, 
    0, 87, 1, 99, 6, 43, 2,  3, 7,  3, 5, 72, 8,  5, 4, 22, 3, 91, 
    3, 74, 0, 98, 4, 24, 7, 96, 2, 13, 1, 21, 5, 76, 8, 17, 6, 39
  };
  const int q2102[] = {
    9, 9, // Number of jobs and machines
    1, 92, 8, 83, 5, 78, 6, 80, 2, 97, 3, 35, 0, 61, 7, 69, 4, 14, 
    5, 10, 8, 14, 4, 58, 1, 22, 6, 44, 3, 72, 7, 32, 2, 36, 0,  3, 
    1, 64, 3, 96, 5, 79, 2, 39, 8,  1, 6, 10, 0, 55, 7, 51, 4,  7, 
    4, 35, 0, 61, 6, 48, 1, 41, 7, 12, 3, 56, 2, 90, 5,  2, 8, 60, 
    0, 85, 4, 11, 6, 54, 1, 88, 2, 75, 3, 84, 5, 46, 8, 18, 7, 15, 
    8, 29, 5, 67, 1, 80, 7, 68, 3, 79, 4, 33, 0, 96, 6, 21, 2, 17, 
    2, 69, 5,  5, 0, 59, 7, 26, 8, 62, 1, 93, 6, 70, 3, 46, 4,  6, 
    2, 13, 0, 76, 7, 61, 8, 64, 6, 63, 4, 51, 3, 89, 5, 83, 1, 97, 
    1, 32, 5,  8, 4, 26, 3, 56, 2, 24, 0, 50, 6,  8, 8, 99, 7, 59
  };
  const int q2103[] = {
    9, 9, // Number of jobs and machines
    3,  7, 1, 54, 8,  6, 4, 70, 6, 62, 2, 46, 7,  2, 5, 49, 0, 52, 
    1, 20, 5, 79, 4, 36, 2, 29, 6, 19, 3, 21, 0, 36, 8, 73, 7, 43, 
    2, 28, 0, 26, 1, 44, 7, 89, 4, 44, 3, 71, 6,  5, 8, 70, 5, 96, 
    6, 32, 8, 73, 4, 39, 7, 41, 5, 82, 3, 93, 1, 90, 2, 29, 0, 52, 
    7, 67, 3, 37, 8, 90, 2, 72, 4, 74, 5, 52, 6,  5, 0, 99, 1, 69, 
    6,  5, 7, 44, 5, 84, 2, 62, 1, 92, 4,  7, 0, 77, 8, 71, 3, 17, 
    3, 40, 0, 67, 8, 49, 2, 89, 7,  1, 4, 87, 5, 13, 6, 94, 1, 20, 
    8, 58, 1, 69, 6, 48, 5, 67, 3, 69, 0, 52, 4, 35, 7, 70, 2, 39, 
    3, 78, 5, 44, 2, 66, 6, 24, 7, 57, 0,  2, 8, 70, 1, 48, 4,  6
  };
  const int q2104[] = {
    9, 9, // Number of jobs and machines
    3, 47, 4, 66, 6, 16, 7, 47, 5, 54, 1, 62, 0, 44, 8, 32, 2, 28, 
    2, 36, 4, 91, 7, 96, 5, 17, 0, 43, 6, 46, 3, 11, 8, 16, 1, 52, 
    2, 52, 4, 62, 5, 18, 8, 15, 1, 84, 0, 56, 3, 44, 6,  8, 7, 80, 
    8, 93, 3, 80, 0, 77, 6, 22, 2, 17, 7, 66, 1, 71, 5, 19, 4, 48, 
    8,  2, 1, 16, 6, 25, 0,  7, 3,  9, 2, 53, 5, 19, 4, 61, 7, 51, 
    3, 98, 4, 65, 7, 10, 5, 26, 6, 43, 2, 97, 1, 89, 8, 74, 0, 60, 
    6, 79, 3, 37, 4,  2, 2, 61, 1, 30, 0, 87, 8, 30, 5, 10, 7, 15, 
    1,  2, 0,  1, 8, 73, 2, 22, 3, 37, 5, 27, 7, 66, 6, 21, 4, 98, 
    4, 13, 8, 16, 6, 66, 0,  8, 1, 64, 7, 57, 2, 98, 3, 78, 5, 37
  };
  const int q2105[] = {
    9, 9, // Number of jobs and machines
    6, 38, 2, 65, 5, 49, 3, 50, 0, 79, 1, 26, 4, 54, 8, 30, 7,  7, 
    1, 53, 7, 92, 5, 93, 3, 92, 6, 87, 0, 82, 2, 61, 4, 95, 8, 82, 
    6, 86, 1, 19, 3, 12, 5, 63, 4, 20, 2, 19, 0, 93, 7, 25, 8, 43, 
    6, 31, 4, 44, 0, 12, 8,  3, 5, 99, 7, 41, 1, 32, 2, 44, 3,  1, 
    2, 80, 8, 89, 0, 89, 5, 49, 6, 49, 3, 49, 7, 62, 1,  4, 4, 27, 
    2, 87, 3, 41, 6, 67, 5, 66, 4, 48, 7, 30, 8,  5, 1, 46, 0, 69, 
    6, 58, 0,  5, 2, 80, 1, 73, 8,  9, 7, 84, 4, 10, 3, 37, 5, 13, 
    4, 99, 1, 52, 8, 47, 7, 41, 2, 26, 0, 55, 5, 34, 6, 84, 3, 19, 
    6, 60, 1, 68, 5, 17, 8, 40, 0, 84, 4, 93, 2, 64, 3, 16, 7, 11
  };
  const int q2106[] = {
    9, 9, // Number of jobs and machines
    0, 98, 8, 54, 4, 28, 3, 23, 6, 77, 2, 81, 1,  1, 5, 65, 7, 71, 
    7, 33, 8, 87, 3, 29, 5, 70, 2, 27, 0, 68, 1, 18, 6, 28, 4, 50, 
    7, 81, 2, 35, 0, 48, 8, 38, 1, 41, 4, 16, 3, 24, 5, 63, 6, 17, 
    8, 20, 2, 81, 5, 78, 1,  6, 0, 46, 6, 29, 7, 45, 4, 68, 3, 58, 
    7, 33, 3, 43, 5, 71, 2, 92, 4, 50, 6, 71, 1, 27, 8, 36, 0, 34, 
    3, 96, 7,  7, 0,  3, 8, 41, 5, 53, 6, 20, 2,  4, 1, 92, 4, 21, 
    3,  6, 8, 66, 0, 91, 5, 40, 4, 38, 2, 59, 6, 68, 1, 27, 7,  6, 
    0, 25, 3, 55, 2, 15, 7, 35, 5, 28, 1, 93, 4, 51, 6, 93, 8, 29, 
    8, 26, 6, 90, 7, 58, 3, 30, 4, 95, 2, 29, 0, 70, 1, 47, 5, 97
  };
  const int q2107[] = {
    9, 9, // Number of jobs and machines
    1, 71, 7, 51, 3,  8, 8, 28, 0, 75, 5, 42, 4, 94, 2,  8, 6, 18, 
    5, 89, 3, 51, 2, 63, 1, 96, 8,  8, 0, 22, 7, 74, 4, 45, 6, 36, 
    7, 40, 3, 24, 2, 43, 8,  5, 4, 53, 0, 80, 6, 37, 5, 57, 1, 27, 
    6, 47, 1, 53, 8, 21, 5, 40, 3, 35, 2, 65, 0, 77, 4, 15, 7, 54, 
    5, 54, 7, 49, 0, 94, 4, 65, 8, 21, 2, 19, 6, 43, 3, 85, 1, 29, 
    0, 62, 4, 52, 2, 81, 1, 13, 7, 12, 5, 80, 3, 41, 6, 60, 8, 11, 
    7, 46, 4, 58, 5, 74, 1, 26, 8, 46, 3, 38, 0,  6, 6, 30, 2,  8, 
    7, 87, 3, 35, 4, 79, 6, 40, 1, 92, 0,  5, 8, 47, 5, 60, 2, 80, 
    2, 51, 6, 94, 1, 63, 7, 91, 4, 18, 8, 48, 0, 42, 5, 13, 3, 59
  };
  const int q2108[] = {
    9, 9, // Number of jobs and machines
    5, 55, 7, 25, 4, 41, 2, 30, 6, 82, 0, 63, 8, 35, 3, 32, 1,  2, 
    5, 14, 6, 24, 2, 69, 4, 34, 0, 64, 7, 21, 1, 42, 3, 46, 8, 62, 
    1, 15, 2, 57, 3, 68, 5, 19, 0, 91, 6, 98, 4, 40, 8, 84, 7, 82, 
    7, 79, 6, 26, 4, 78, 8, 61, 3, 49, 2, 45, 0, 48, 5, 80, 1,  5, 
    2, 65, 3,  5, 0, 61, 1, 70, 4, 34, 6, 53, 7, 38, 5, 20, 8, 79, 
    2, 45, 8,  4, 0, 47, 1, 42, 7, 85, 6,  3, 5, 16, 4, 70, 3, 30, 
    6, 64, 1, 38, 8, 70, 4, 77, 5, 85, 2, 37, 7, 54, 3, 28, 0, 11, 
    6, 41, 2, 40, 7, 91, 5, 58, 1, 17, 0, 60, 3,  3, 8, 91, 4, 32, 
    3, 46, 6, 30, 5, 72, 0, 49, 1, 74, 8,  9, 4, 82, 2, 19, 7, 82
  };
  const int q2109[] = {
    9, 9, // Number of jobs and machines
    5, 77, 7, 84, 6, 91, 8, 63, 4, 18, 0, 12, 1,  3, 3, 53, 2,  2, 
    4, 63, 3, 51, 5, 99, 6, 38, 7, 47, 1, 27, 0, 24, 8, 90, 2, 55, 
    5, 79, 2, 20, 0, 97, 6, 55, 7, 20, 8, 13, 4, 27, 1, 66, 3, 54, 
    3, 22, 6, 49, 8, 15, 7, 32, 2, 10, 0, 77, 5, 14, 4, 31, 1, 88, 
    2, 85, 8, 94, 3, 36, 0, 63, 1, 75, 4, 82, 6, 54, 7, 19, 5, 93, 
    8,  1, 4, 53, 7, 13, 0, 10, 5, 76, 6, 12, 1, 59, 2, 21, 3, 65, 
    1, 91, 8, 68, 4, 74, 6, 96, 0, 16, 3, 56, 7, 24, 5, 99, 2, 28, 
    8, 34, 3, 74, 5, 72, 2, 38, 1, 86, 4, 27, 6, 86, 0, 50, 7, 37, 
    6, 43, 1, 87, 2, 74, 5, 34, 4, 42, 7, 73, 3,  2, 8, 72, 0, 98
  };
  const int q2110[] = {
    9, 9, // Number of jobs and machines
    3, 22, 1, 37, 0,  3, 7,  3, 4, 53, 2,  6, 8, 55, 6, 34, 5, 72, 
    7,  9, 1, 91, 0, 61, 4,  6, 3, 51, 2, 32, 5, 35, 6, 13, 8, 22, 
    5, 29, 3, 22, 0, 78, 7, 20, 1, 56, 4, 36, 2, 25, 8, 95, 6, 68, 
    8, 38, 1, 65, 5, 71, 0, 66, 7, 79, 3, 55, 2, 49, 4,  1, 6, 96, 
    8, 43, 4, 58, 5, 78, 2, 56, 6, 89, 3, 49, 0, 23, 7, 92, 1, 34, 
    8, 11, 3, 91, 1, 45, 7, 77, 4, 20, 2, 46, 5, 78, 6, 30, 0, 41, 
    7, 10, 6, 52, 5, 58, 8, 59, 4, 59, 2, 97, 0, 64, 1, 72, 3, 45, 
    3,  3, 8, 93, 0, 71, 5, 27, 6, 97, 1, 74, 7, 72, 4, 92, 2, 35, 
    5,  2, 0, 68, 1, 78, 6, 11, 2, 93, 7, 82, 4, 49, 3, 40, 8, 40
  };
  const int q2111[] = {
    9, 9, // Number of jobs and machines
    5, 38, 1, 98, 8, 59, 0, 61, 6, 43, 3, 76, 2,  5, 4, 90, 7, 16, 
    6, 76, 5, 39, 4, 18, 7, 88, 1, 62, 0, 42, 2, 58, 3, 25, 8, 49, 
    2, 64, 4, 79, 0, 60, 1, 73, 3, 50, 7, 30, 6, 17, 8,  9, 5, 91, 
    7, 82, 1, 85, 8, 57, 6, 13, 4, 70, 0, 16, 3, 16, 2, 33, 5,  7, 
    3, 80, 0, 85, 5, 29, 6, 93, 8, 63, 7, 53, 4, 10, 1, 19, 2, 91, 
    4, 63, 8, 98, 3, 47, 7, 71, 2, 10, 6, 32, 5, 78, 0, 55, 1, 93, 
    4, 84, 6, 94, 5, 17, 0, 99, 7, 85, 2, 56, 1, 64, 8, 56, 3,  3, 
    1, 96, 8, 53, 2, 34, 0, 60, 3, 87, 5, 62, 4, 76, 6, 68, 7, 95, 
    6, 56, 2, 68, 5, 79, 4, 84, 1,  4, 7, 34, 3,  1, 8, 26, 0, 62
  };
  const int q2112[] = {
    9, 9, // Number of jobs and machines
    7, 32, 0, 34, 2, 64, 3, 52, 5, 81, 6,  4, 1, 80, 4, 55, 8, 94, 
    7, 42, 5, 76, 2, 51, 8, 79, 0, 38, 3, 50, 1, 77, 4, 72, 6, 72, 
    8, 17, 2, 52, 5, 18, 0, 26, 4, 65, 7, 58, 6, 43, 3, 21, 1, 86, 
    6, 41, 5, 62, 4, 45, 0, 35, 3, 57, 8, 55, 2, 52, 1, 42, 7, 12, 
    5, 49, 2, 16, 3, 88, 7, 88, 8, 50, 0, 78, 6, 13, 1, 99, 4, 88, 
    2,  7, 5, 24, 8, 76, 4, 63, 3, 53, 0, 31, 7, 20, 1, 61, 6, 33, 
    2, 88, 0, 31, 8, 42, 4, 74, 6, 60, 5,  1, 1, 54, 7, 11, 3, 68, 
    2, 86, 5, 63, 8,  5, 4, 84, 6, 41, 3, 97, 1, 62, 0, 54, 7, 99, 
    0, 97, 6, 70, 2, 42, 5, 74, 1, 55, 7, 82, 3, 64, 8, 18, 4, 71
  };
  const int q2113[] = {
    9, 9, // Number of jobs and machines
    3, 38, 6, 44, 7,  9, 0,  9, 5, 21, 2, 27, 4,  5, 1, 35, 8, 11, 
    0, 56, 8, 71, 6, 38, 4, 68, 1, 55, 7, 30, 3, 92, 2, 74, 5, 19, 
    8, 10, 0, 59, 7, 62, 2, 57, 4, 40, 3, 19, 6, 34, 5, 81, 1, 11, 
    3, 39, 0, 75, 1, 88, 4, 55, 8, 60, 6,  1, 5, 68, 7, 96, 2,  6, 
    8, 23, 5, 94, 3, 75, 2, 34, 4, 32, 6,  4, 0, 80, 1, 76, 7,  7, 
    0, 65, 3, 89, 4, 68, 8, 62, 1, 55, 6, 91, 2, 77, 7, 38, 5, 46, 
    7, 71, 3, 40, 4, 51, 8, 76, 5, 29, 0, 83, 1, 86, 6, 32, 2, 24, 
    1, 62, 4,  5, 7, 96, 2, 86, 0, 55, 8, 86, 5, 20, 6,  9, 3, 14, 
    3, 70, 1, 99, 7, 94, 5, 43, 2, 73, 0, 39, 8, 98, 4, 23, 6, 42
  };
  const int q2114[] = {
    9, 9, // Number of jobs and machines
    0, 81, 4, 27, 8,  6, 3, 99, 7, 69, 5, 12, 1, 10, 6, 60, 2, 52, 
    3, 25, 6, 21, 2, 73, 8, 77, 1, 43, 0, 34, 5, 80, 7, 24, 4, 74, 
    7, 56, 3, 71, 8, 16, 2, 10, 4, 88, 0,  8, 6, 70, 5, 70, 1, 12, 
    6, 84, 3,  1, 2, 91, 8, 47, 7, 24, 4, 20, 1, 38, 5, 24, 0, 17, 
    2,  5, 6, 78, 1, 82, 8, 99, 0, 37, 4, 71, 7, 90, 5, 18, 3, 15, 
    6, 95, 2, 94, 4, 19, 5, 40, 7, 64, 1, 80, 8, 37, 0,  3, 3, 35, 
    6,  8, 4, 90, 2, 61, 8, 27, 7, 21, 5, 96, 0, 26, 3,  7, 1, 59, 
    1, 73, 6, 38, 3, 53, 2, 99, 5, 66, 7,  9, 4, 10, 0, 96, 8, 49, 
    4, 93, 6, 15, 5, 65, 2, 50, 3, 64, 8, 97, 1, 19, 7, 32, 0,  9
  };
  const int q2115[] = {
    9, 9, // Number of jobs and machines
    0, 23, 7, 14, 8, 39, 6, 96, 4, 33, 1, 49, 2, 55, 5, 79, 3, 80, 
    7, 50, 8, 37, 6, 49, 5, 30, 0, 77, 3, 55, 4,  2, 1, 52, 2, 18, 
    5,  2, 7, 24, 3, 84, 2, 84, 6, 37, 4, 23, 1, 94, 0, 42, 8, 33, 
    0, 59, 7, 37, 3, 95, 2, 78, 6,  5, 4, 20, 1, 99, 5, 89, 8, 51, 
    7, 55, 0, 56, 2, 33, 4,  6, 3, 31, 6, 25, 8, 83, 5, 47, 1, 48, 
    7,  2, 2, 36, 8, 10, 3, 53, 6,  7, 4, 23, 1, 64, 5, 21, 0, 80, 
    8, 58, 7, 49, 3, 90, 5, 70, 2, 20, 1, 76, 4, 10, 6, 13, 0, 52, 
    1, 59, 8, 14, 6, 61, 2, 58, 0, 24, 5, 79, 4, 42, 7, 64, 3, 46, 
    1, 31, 3, 81, 7, 49, 5, 26, 2, 84, 6, 25, 0,  1, 4, 77, 8, 23
  };
  const int q2116[] = {
    9, 9, // Number of jobs and machines
    1, 16, 2, 98, 4, 41, 0,  5, 7, 36, 3, 70, 5, 83, 8, 79, 6, 32, 
    8, 37, 3, 52, 5, 87, 6, 34, 1, 66, 0, 71, 2, 53, 7, 29, 4, 68, 
    2, 55, 8, 77, 3, 75, 7, 75, 6, 89, 4, 97, 5, 59, 1, 17, 0, 73, 
    6, 80, 2, 24, 0, 31, 3,  8, 1, 40, 5, 67, 8, 17, 4, 39, 7, 35, 
    6, 33, 1, 12, 8, 72, 3, 80, 5, 38, 7, 14, 2, 79, 4, 55, 0,  5, 
    0, 66, 2,  3, 1,  9, 5, 46, 4, 72, 3, 47, 6, 58, 8, 24, 7, 75, 
    8, 62, 2,  5, 3, 71, 5, 62, 7, 90, 1,  7, 0, 16, 4, 31, 6, 80, 
    0, 58, 2, 20, 5,  7, 7, 93, 6, 29, 4, 18, 3, 87, 1, 71, 8, 42, 
    5,  7, 1, 89, 4, 60, 6, 53, 2, 96, 8, 15, 7, 27, 3, 97, 0, 95
  };
  const int q2117[] = {
    9, 9, // Number of jobs and machines
    2, 17, 8, 93, 1,  2, 6, 29, 7, 66, 5, 60, 3, 52, 0, 81, 4,  8, 
    0, 56, 6,  9, 8,  5, 7, 67, 1, 33, 5, 13, 4, 90, 2, 98, 3, 75, 
    3, 74, 8, 47, 1, 98, 0, 36, 4,  8, 6, 92, 7, 95, 5, 80, 2, 91, 
    4,  2, 1, 66, 6, 46, 7, 11, 8, 42, 5,  5, 3, 36, 2, 78, 0, 62, 
    3,  2, 5, 46, 6, 43, 2, 37, 1, 50, 0, 12, 8, 68, 4, 26, 7, 99, 
    1, 54, 3, 10, 6,  5, 0, 30, 8, 48, 5, 22, 4, 13, 2, 92, 7, 81, 
    2, 11, 4,  5, 3, 18, 5, 37, 6, 98, 7, 66, 1, 69, 8,  2, 0, 46, 
    0, 57, 8, 39, 4, 49, 2,  9, 6, 23, 1, 47, 3, 56, 5, 47, 7, 54, 
    2, 84, 5, 23, 7, 82, 8, 22, 6,  2, 1, 27, 3, 29, 4, 25, 0, 30
  };
  const int q2118[] = {
    9, 9, // Number of jobs and machines
    5, 16, 0, 69, 7, 88, 4, 90, 3, 29, 6, 90, 2, 36, 8, 91, 1, 21, 
    4, 92, 3, 24, 8,  6, 7, 37, 1, 34, 0,  2, 2, 77, 5, 95, 6, 32, 
    7, 75, 1, 99, 3,  4, 6, 25, 2, 66, 8, 28, 0, 29, 5, 22, 4, 54, 
    2, 47, 7, 37, 3, 77, 4, 18, 6, 15, 0, 97, 1, 18, 5, 36, 8, 82, 
    2, 21, 5, 81, 8, 33, 3,  8, 4, 24, 7, 79, 6, 30, 1, 36, 0, 85, 
    2, 84, 6, 61, 1, 10, 5, 78, 0, 42, 3, 33, 8, 34, 7, 13, 4, 93, 
    2, 86, 6, 13, 8, 10, 3, 29, 4, 19, 0, 73, 5,  4, 7, 63, 1, 77, 
    3, 39, 2,  7, 6, 32, 0, 32, 7, 15, 4, 25, 8, 74, 1, 27, 5, 94, 
    8, 74, 3, 36, 2, 80, 0, 56, 5, 85, 6, 80, 1, 37, 4,  9, 7, 54
  };
  const int q2119[] = {
    9, 9, // Number of jobs and machines
    1, 89, 2, 82, 0, 59, 3, 82, 6, 77, 7, 28, 8, 96, 5, 34, 4, 33, 
    7,  9, 5, 27, 3, 33, 1, 33, 0, 92, 6,  2, 4, 80, 8, 25, 2, 25, 
    1, 90, 3, 55, 4, 65, 0, 60, 7, 60, 2,  5, 5, 87, 8, 39, 6,  4, 
    8, 51, 7, 39, 4, 66, 1, 21, 6, 67, 5, 66, 2, 63, 3, 81, 0, 80, 
    8,  9, 4, 34, 3, 98, 1, 46, 2, 83, 5,  5, 6, 66, 0, 35, 7, 77, 
    7, 58, 4, 55, 8, 37, 2, 40, 3, 38, 1, 42, 5, 12, 6, 64, 0, 43, 
    7, 59, 0,  7, 5, 99, 4, 67, 1, 36, 3, 64, 6, 62, 8,  7, 2, 44, 
    0, 74, 6, 38, 8, 80, 2, 74, 4, 66, 5, 52, 7, 11, 3, 11, 1, 48, 
    8, 19, 1, 35, 4, 95, 7, 40, 6, 31, 0, 70, 2, 67, 5, 29, 3, 66
  };
  const int q2120[] = {
    9, 9, // Number of jobs and machines
    3, 59, 0, 45, 6, 77, 4,  2, 7, 59, 5,  4, 2, 95, 1, 29, 8, 64, 
    1, 70, 3, 38, 7, 19, 2, 35, 8, 61, 6, 21, 4, 17, 0, 96, 5, 56, 
    4, 97, 2, 74, 1,  9, 0, 82, 7, 73, 5, 37, 3, 57, 6, 91, 8, 70, 
    0, 65, 8, 82, 5, 86, 1, 62, 4, 21, 6, 88, 3, 10, 2, 84, 7, 11, 
    1, 18, 8, 18, 7, 11, 3,  6, 0, 54, 2, 96, 4, 62, 6, 72, 5, 41, 
    2,  3, 5, 70, 8, 68, 0, 50, 4, 47, 1, 50, 6, 32, 7, 16, 3, 51, 
    1, 13, 2, 37, 8, 27, 4, 20, 3, 44, 0, 28, 5, 93, 6, 42, 7,  4, 
    3,  2, 4, 15, 8, 29, 0,  8, 7, 16, 5, 95, 1, 82, 2, 66, 6, 38, 
    7, 80, 6, 42, 3, 59, 5, 42, 1, 25, 0, 45, 8, 84, 4, 83, 2, 30
  };
  const int q2121[] = {
    9, 9, // Number of jobs and machines
    7,  8, 0,  9, 1, 27, 4, 50, 3, 55, 5,  3, 8, 92, 6, 39, 2, 47, 
    2, 80, 1, 60, 3, 71, 0, 55, 7, 29, 4, 62, 6, 85, 8, 55, 5, 65, 
    2, 24, 5, 42, 4, 21, 0, 89, 6, 76, 3, 68, 1, 43, 8,  7, 7, 30, 
    1,  1, 0, 32, 5, 47, 7, 91, 2,  2, 4, 48, 6, 19, 3, 66, 8, 78, 
    5, 96, 0, 12, 1, 46, 7, 16, 3, 57, 6, 80, 4, 99, 8, 56, 2, 77, 
    3, 19, 2, 29, 7, 75, 8, 69, 4, 21, 6, 79, 5, 15, 1, 83, 0, 98, 
    0, 37, 4, 52, 5, 60, 1, 60, 8, 66, 2, 99, 7, 59, 3, 94, 6,  3, 
    1,  2, 7, 16, 8, 89, 4, 54, 0, 29, 6, 65, 5, 88, 3, 46, 2, 50, 
    8, 77, 3, 29, 2, 36, 0, 37, 6, 38, 4, 32, 1, 62, 5,  8, 7, 62
  };
  const int q2122[] = {
    9, 9, // Number of jobs and machines
    2, 79, 8, 45, 7, 89, 5, 73, 1, 61, 0, 44, 6, 29, 3, 19, 4, 89, 
    4, 28, 5, 57, 6, 77, 1, 75, 3,  8, 2, 69, 7, 96, 8, 32, 0,  2, 
    3, 40, 6, 79, 8, 46, 0, 41, 5, 35, 2, 84, 7, 73, 1, 50, 4, 71, 
    1, 15, 6, 99, 2, 65, 5, 80, 7, 26, 8, 48, 3, 12, 0, 32, 4,  2, 
    4, 90, 2, 50, 3, 24, 8, 91, 0, 10, 7, 35, 5,  2, 1, 56, 6, 13, 
    8, 35, 0, 17, 5, 39, 7, 98, 1, 13, 3, 65, 4, 32, 6, 43, 2, 89, 
    6, 41, 0, 70, 3, 26, 7, 43, 5, 67, 2, 10, 4, 11, 1, 93, 8, 97, 
    7, 99, 0, 61, 1, 56, 3, 19, 2, 60, 8, 89, 4, 84, 6, 62, 5, 17, 
    8, 54, 4, 45, 7, 27, 3, 23, 1, 18, 2, 19, 6, 31, 0, 31, 5, 44
  };
  const int q2123[] = {
    9, 9, // Number of jobs and machines
    6, 63, 0, 58, 4,  5, 2, 79, 3, 32, 1,  6, 5, 43, 8, 13, 7, 30, 
    1, 34, 3, 96, 2, 26, 0,  7, 6, 13, 4, 22, 7, 45, 5, 20, 8, 33, 
    7,  1, 5,  7, 2, 77, 4, 16, 1, 83, 0, 10, 3, 86, 6, 50, 8,  8, 
    3, 51, 8, 62, 6, 53, 5, 10, 2,  8, 1, 98, 4, 89, 0, 85, 7, 75, 
    4, 87, 6, 43, 0, 70, 3,  5, 7, 13, 2, 94, 8, 76, 1, 28, 5, 83, 
    7, 71, 1, 44, 6, 30, 5, 37, 3, 36, 8, 83, 2, 66, 0, 80, 4,  6, 
    7, 48, 4,  8, 8, 19, 6, 36, 2, 17, 1, 95, 3, 29, 5,  1, 0, 71, 
    1, 48, 6, 62, 4, 32, 2, 45, 8, 47, 5,  6, 7, 62, 0, 43, 3, 98, 
    2, 54, 4, 36, 3, 46, 0, 98, 6, 42, 5, 69, 1, 13, 7, 47, 8, 72
  };
  const int q2124[] = {
    9, 9, // Number of jobs and machines
    0, 60, 7, 29, 4, 45, 3, 51, 1, 50, 5, 10, 6, 45, 2, 44, 8, 24, 
    5, 51, 1, 61, 0, 71, 3, 56, 6, 41, 2, 33, 8, 52, 7,  1, 4, 66, 
    8, 44, 2, 73, 4, 89, 3, 89, 6, 61, 5,  4, 1, 99, 0, 75, 7, 98, 
    7, 74, 6, 31, 4, 94, 8, 66, 5, 17, 2, 39, 0, 70, 3, 36, 1, 58, 
    3, 33, 2, 76, 5, 61, 4, 48, 6, 40, 0, 42, 7, 70, 1,  5, 8, 85, 
    1, 20, 4, 45, 3, 65, 7, 38, 2, 12, 0, 42, 8, 91, 6, 98, 5, 96, 
    2, 85, 0, 49, 4, 76, 8, 95, 7, 35, 5, 64, 6, 31, 1, 62, 3, 61, 
    2, 41, 3, 71, 5, 99, 4, 33, 8, 15, 6, 40, 0, 47, 1, 56, 7, 30, 
    2, 53, 5, 57, 1, 38, 7, 70, 3, 19, 8,  7, 6, 14, 0, 81, 4, 40
  };
  const int q2125[] = {
    9, 9, // Number of jobs and machines
    0, 30, 6, 20, 4, 28, 7, 34, 8, 10, 2, 61, 3,  4, 5, 97, 1, 78, 
    3, 36, 7, 92, 0, 36, 8, 34, 4, 30, 2, 63, 5, 46, 6, 13, 1, 95, 
    3, 45, 8, 83, 7, 15, 2, 63, 5, 89, 0, 62, 6, 19, 1, 77, 4, 51, 
    8, 82, 1, 25, 3, 39, 7, 79, 0, 73, 2, 40, 5, 96, 6, 39, 4, 50, 
    7, 65, 6, 48, 5, 14, 4, 62, 1, 31, 0,  1, 2, 82, 8, 36, 3, 70, 
    7, 20, 2, 76, 1, 97, 8, 20, 3, 64, 4, 91, 0, 72, 6, 81, 5, 23, 
    7, 57, 8, 57, 2, 55, 3, 73, 0, 10, 6, 23, 1, 99, 5, 46, 4, 71, 
    6, 46, 4, 71, 5, 45, 2,  5, 3,  5, 0, 65, 7, 59, 8, 97, 1, 44, 
    0, 81, 1, 39, 6, 93, 7,  2, 2, 21, 4, 79, 8, 79, 5, 73, 3, 27
  };
  const int q2126[] = {
    9, 9, // Number of jobs and machines
    2, 36, 6, 34, 8, 19, 4, 39, 7, 30, 0, 95, 3,  1, 5,  3, 1, 31, 
    6, 10, 0, 16, 2, 15, 1, 62, 5, 93, 4, 26, 8, 88, 3, 91, 7, 62, 
    8, 13, 2, 56, 5, 48, 3, 60, 4, 56, 7, 68, 6,  8, 0,  1, 1, 29, 
    0, 92, 3, 55, 2, 97, 6, 64, 4, 46, 1, 98, 7, 54, 5, 36, 8, 73, 
    1, 94, 6, 28, 8,  9, 7, 20, 3, 91, 2, 93, 4, 67, 5, 34, 0, 51, 
    7, 43, 2, 11, 5, 23, 1,  7, 0, 84, 3, 77, 6, 63, 4, 60, 8, 59, 
    0, 79, 2,  4, 3, 52, 4, 60, 1, 56, 6, 42, 8, 25, 5, 67, 7, 19, 
    0, 30, 5, 21, 1, 40, 6, 35, 8, 78, 7, 66, 4, 75, 3, 89, 2, 62, 
    6, 55, 8, 54, 2, 39, 1, 42, 0, 25, 4, 49, 7, 78, 5, 34, 3, 67
  };
  const int q2127[] = {
    9, 9, // Number of jobs and machines
    8, 25, 3, 57, 5, 71, 6, 70, 0, 60, 7, 27, 4, 92, 2, 29, 1, 23, 
    0, 26, 6, 67, 2, 51, 8,  4, 5, 67, 1, 60, 3, 21, 4, 97, 7, 53, 
    8,  3, 5, 89, 2,  9, 6, 79, 7, 53, 3, 61, 4, 65, 0,  9, 1, 28, 
    3, 65, 0, 81, 4, 49, 7, 13, 6, 40, 2, 99, 5,  6, 1, 78, 8, 91, 
    5, 48, 0, 64, 6, 24, 4, 22, 1, 46, 2, 42, 3, 55, 7, 46, 8,  1, 
    0, 91, 8, 81, 4, 88, 6, 45, 7, 27, 1, 29, 5, 14, 3, 87, 2, 36, 
    1, 79, 5, 64, 0, 35, 4, 12, 8, 57, 2, 28, 6, 67, 3, 57, 7, 34, 
    8,  2, 1, 91, 3, 83, 6, 61, 5, 49, 4, 36, 0,  2, 7, 68, 2, 12, 
    7, 60, 3,  7, 5, 80, 4, 55, 8, 63, 2, 10, 6, 69, 1, 75, 0, 87
  };
  const int q2128[] = {
    9, 9, // Number of jobs and machines
    6, 36, 5, 59, 1, 16, 2, 53, 7, 98, 0, 60, 8, 25, 3,  1, 4, 13, 
    6, 63, 3,  8, 4, 79, 1, 27, 0, 49, 5, 60, 2, 94, 8, 61, 7, 34, 
    5,  4, 7, 42, 1, 64, 4, 54, 8, 22, 6, 41, 0, 37, 3, 40, 2, 97, 
    8,  3, 1, 49, 5, 41, 0, 71, 2, 12, 3, 21, 4,  4, 6, 73, 7, 30, 
    4, 43, 3, 60, 2, 32, 8, 82, 0, 64, 5, 98, 1,  5, 6, 47, 7, 32, 
    3, 52, 7, 63, 5,  4, 1, 32, 0, 11, 2, 55, 6, 10, 4,  7, 8, 56, 
    6, 95, 4, 78, 5, 41, 0, 28, 2, 74, 7, 84, 3, 51, 8, 38, 1, 72, 
    4, 15, 8, 67, 3, 53, 5, 52, 2, 25, 7, 94, 6, 42, 0, 18, 1, 48, 
    5, 83, 6, 65, 8, 38, 7, 39, 0, 11, 4, 59, 3, 70, 1, 61, 2, 19
  };
  const int q2129[] = {
    9, 9, // Number of jobs and machines
    4, 22, 2, 27, 0,  5, 7,  2, 1, 39, 3, 71, 6, 92, 5, 62, 8, 47, 
    6, 47, 0, 36, 3, 85, 1, 93, 2, 29, 5, 29, 8, 45, 7, 70, 4,  3, 
    1, 98, 0, 96, 4, 31, 5, 72, 7, 56, 8, 17, 2, 39, 6,  2, 3, 58, 
    4,  9, 2, 80, 5,  1, 8, 98, 7, 79, 3, 83, 1, 40, 6, 24, 0, 16, 
    5, 90, 0, 61, 7, 47, 2, 24, 6, 23, 3, 43, 4, 67, 1, 21, 8, 38, 
    8, 37, 4,  6, 2, 49, 7, 38, 3, 25, 6, 23, 0, 72, 5, 61, 1, 76, 
    8, 55, 1, 25, 5, 75, 4, 92, 3, 44, 6, 77, 2, 89, 0, 60, 7, 99, 
    8, 60, 0, 66, 4, 71, 3, 67, 2, 81, 6, 62, 5, 18, 1, 18, 7, 14, 
    4, 14, 2, 21, 8, 88, 1, 44, 3, 60, 0, 55, 7, 20, 6, 81, 5, 53
  };
  const int q2130[] = {
    9, 9, // Number of jobs and machines
    4,  9, 1, 37, 5, 80, 7, 25, 2, 15, 0, 93, 3, 20, 8, 49, 6, 33, 
    2, 56, 8, 66, 3, 73, 4, 24, 5,  3, 0, 24, 1, 91, 7, 63, 6, 87, 
    5, 61, 2, 73, 6, 86, 3, 63, 8, 61, 4, 87, 7, 39, 0, 59, 1, 42, 
    6, 68, 0, 40, 1,  1, 5, 85, 8, 30, 7, 17, 3, 71, 2,  3, 4, 23, 
    1, 91, 7, 10, 5, 86, 0, 36, 2, 85, 6, 72, 3, 17, 8, 42, 4, 50, 
    7, 73, 0, 34, 5, 36, 8, 66, 2,  8, 6, 36, 1, 90, 4, 69, 3, 49, 
    3, 95, 1, 24, 8, 22, 5, 37, 7, 91, 2, 20, 4, 77, 0, 65, 6, 22, 
    1, 46, 7, 62, 2, 86, 0, 25, 8, 57, 3, 18, 6, 87, 5, 39, 4, 38, 
    6, 39, 3, 41, 2, 14, 7, 23, 0,  5, 1,  9, 5, 60, 4,  4, 8, 34
  };
  const int q2131[] = {
    9, 9, // Number of jobs and machines
    8,  5, 1, 44, 7, 94, 4, 46, 3, 83, 6, 77, 5, 47, 2, 32, 0, 38, 
    2, 71, 3, 11, 5, 99, 7, 75, 6, 92, 4, 51, 8,  8, 0, 35, 1, 65, 
    5, 61, 8, 47, 6, 25, 0, 95, 7, 13, 3, 29, 2, 97, 1, 90, 4, 11, 
    1, 39, 6, 44, 0, 21, 8, 76, 4, 87, 2, 59, 3, 80, 5, 66, 7, 31, 
    7, 51, 1, 97, 5, 61, 4, 51, 0,  8, 2, 35, 3, 57, 8, 51, 6, 88, 
    2, 29, 0, 40, 8, 42, 5, 16, 3,  4, 6, 39, 4, 46, 1, 72, 7,  7, 
    1,  5, 6, 45, 8, 58, 0, 30, 4, 29, 7, 17, 3,  9, 5, 92, 2, 27, 
    5, 15, 0, 93, 8, 58, 2, 55, 7, 34, 1, 24, 6, 23, 3, 39, 4, 41, 
    7, 87, 0, 46, 6, 67, 1, 25, 4, 58, 3, 85, 5, 92, 8, 43, 2, 66
  };
  const int q2132[] = {
    9, 9, // Number of jobs and machines
    5, 44, 4, 27, 8, 92, 6, 85, 1, 84, 0, 65, 7, 90, 3, 92, 2, 82, 
    6,  1, 4,  4, 2,  5, 3, 40, 0, 37, 1, 12, 7, 63, 5,  6, 8, 13, 
    0, 25, 3, 82, 1, 89, 8, 73, 6, 62, 2, 84, 7, 13, 4, 12, 5, 87, 
    0, 50, 8, 34, 6,  7, 5, 43, 3, 75, 7,  9, 2, 68, 1, 66, 4, 46, 
    5, 13, 2, 47, 0, 88, 6, 30, 1, 87, 3, 85, 8, 27, 7, 34, 4, 20, 
    6,  1, 1, 79, 8, 58, 4, 28, 3, 40, 0, 58, 5, 85, 7, 61, 2, 57, 
    4, 66, 5, 68, 2, 39, 6, 37, 7, 18, 8,  9, 3, 49, 0, 81, 1, 10, 
    6, 85, 4, 71, 5,  7, 1, 63, 0, 43, 8, 76, 2, 37, 7, 32, 3,  2, 
    4, 86, 2, 82, 8, 60, 3,  2, 6, 89, 5, 30, 0, 59, 1, 64, 7, 58
  };
  const int q2133[] = {
    9, 9, // Number of jobs and machines
    5, 97, 1, 91, 4, 87, 7, 46, 2, 54, 3, 27, 0, 46, 8, 85, 6, 46, 
    4, 47, 8, 55, 5, 69, 1, 31, 3, 15, 6, 44, 7, 69, 2, 46, 0, 63, 
    7, 31, 8, 29, 2, 61, 4, 53, 6, 25, 5, 12, 3, 30, 1, 91, 0, 96, 
    5, 68, 6, 27, 1,  5, 0, 76, 2, 39, 3, 64, 8, 73, 4, 28, 7, 33, 
    8, 82, 5, 93, 1, 94, 6, 12, 4, 68, 2, 37, 0, 76, 7, 12, 3, 49, 
    3,  9, 7, 59, 5, 30, 2,  6, 1, 42, 6, 98, 4, 44, 8,  9, 0, 99, 
    3, 25, 0, 73, 2, 27, 6, 91, 1, 20, 7, 69, 5, 48, 4, 62, 8, 38, 
    2, 28, 1, 38, 7, 39, 6, 52, 4, 74, 0, 47, 5, 34, 3, 86, 8, 32, 
    5,  6, 1, 80, 8, 50, 7,  9, 2, 21, 3, 30, 6, 98, 0, 72, 4, 32
  };
  const int q2134[] = {
    9, 9, // Number of jobs and machines
    5, 61, 4, 95, 6, 22, 7, 98, 2, 93, 0, 37, 8, 67, 1, 69, 3, 77, 
    4, 85, 1,  7, 7, 11, 8, 36, 3, 23, 6, 36, 2, 77, 0, 41, 5,  4, 
    1, 65, 0, 43, 5, 73, 8, 38, 7, 14, 3, 23, 4, 47, 6,  9, 2, 92, 
    1, 21, 7, 73, 5, 45, 2, 44, 4, 83, 6, 85, 3, 43, 8, 58, 0, 61, 
    1,  4, 5, 29, 4,  5, 0,  1, 3, 81, 8, 14, 6, 37, 2, 44, 7, 48, 
    8, 82, 5, 16, 0, 25, 1, 99, 7, 32, 3, 11, 2, 85, 4, 76, 6, 59, 
    3, 88, 7, 24, 8, 39, 6, 15, 4, 75, 1, 63, 2, 45, 5, 43, 0, 89, 
    2, 91, 4, 19, 7, 13, 5, 82, 3, 85, 1, 71, 8, 93, 6, 23, 0, 10, 
    1, 45, 0,  7, 2, 15, 4, 54, 5, 77, 7, 44, 6, 43, 8, 17, 3, 32
  };
  const int q2135[] = {
    9, 9, // Number of jobs and machines
    1, 34, 4, 41, 2, 55, 8, 75, 0, 90, 7, 68, 6, 44, 3, 78, 5, 34, 
    6, 75, 3, 11, 8, 92, 2, 75, 5, 33, 0, 72, 7, 61, 1, 12, 4, 30, 
    0, 29, 3, 60, 2, 69, 1, 94, 6, 10, 4, 62, 8, 16, 5, 26, 7, 99, 
    8, 20, 3,  4, 7, 43, 0, 48, 5, 70, 2, 49, 6, 85, 1, 48, 4, 61, 
    5, 63, 1, 14, 3, 78, 8, 77, 4, 26, 6, 47, 7, 15, 2,  4, 0, 58, 
    5, 44, 3, 93, 6, 83, 0, 97, 1, 35, 8,  6, 4, 36, 7, 16, 2, 34, 
    2, 28, 4, 76, 7,  4, 3, 41, 0, 75, 6, 51, 1, 46, 5, 13, 8,  9, 
    7, 66, 2, 45, 1,  9, 0, 28, 5, 50, 6, 71, 8, 68, 4,  8, 3, 15, 
    7, 18, 4, 33, 8, 63, 3, 44, 0, 84, 1, 76, 5, 91, 2, 40, 6, 33
  };
  const int q2136[] = {
    9, 9, // Number of jobs and machines
    3, 56, 0, 74, 5, 52, 2, 94, 4, 39, 1, 61, 6, 73, 8, 78, 7, 98, 
    6, 71, 5, 72, 3, 48, 0, 72, 8, 20, 1,  3, 2, 68, 4, 93, 7, 19, 
    8, 81, 6, 74, 3, 39, 0, 87, 7, 34, 5, 76, 1,  2, 4, 63, 2, 52, 
    6, 34, 0, 69, 5, 90, 4, 59, 2, 36, 7, 14, 1, 92, 8, 59, 3, 22, 
    6, 37, 3, 68, 7, 57, 8, 87, 0, 93, 5, 93, 4, 62, 1, 29, 2, 90, 
    5, 43, 8, 72, 2, 53, 1, 99, 3, 72, 0, 62, 4, 22, 7, 63, 6, 80, 
    6, 67, 4, 44, 0, 47, 8, 17, 2, 11, 7, 25, 3, 56, 5, 46, 1, 44, 
    2, 14, 0, 37, 3, 15, 7, 74, 8, 59, 4, 86, 6, 58, 5, 29, 1, 87, 
    2, 38, 3, 92, 5,  9, 4, 91, 0, 98, 1, 30, 8, 12, 6,  7, 7, 41
  };
  const int q2137[] = {
    9, 9, // Number of jobs and machines
    3, 80, 2, 86, 6, 37, 8, 13, 0, 16, 5, 94, 1, 76, 4, 33, 7, 53, 
    1, 91, 5, 48, 6, 49, 4, 65, 3, 76, 0, 50, 7, 64, 8, 57, 2, 68, 
    2, 15, 0, 35, 8, 15, 6, 68, 5, 12, 4, 39, 1, 11, 7, 80, 3,  8, 
    1, 77, 2,  4, 8, 91, 0, 81, 6, 68, 4, 51, 5, 38, 3, 51, 7, 94, 
    4,  2, 1, 40, 7, 18, 0,  5, 2, 46, 3, 83, 8, 41, 5, 70, 6, 79, 
    5, 19, 3, 14, 6, 12, 8, 55, 1, 26, 7, 67, 0, 66, 4, 76, 2, 26, 
    3, 91, 0, 23, 4, 30, 7, 10, 5, 16, 8, 43, 2, 83, 6, 93, 1, 80, 
    8, 46, 3, 58, 0, 41, 6, 90, 1, 13, 2, 88, 5, 22, 7, 26, 4, 22, 
    3, 55, 5, 77, 1,  6, 8, 90, 7, 29, 2, 71, 6, 81, 4, 54, 0, 80
  };
  const int q2138[] = {
    9, 9, // Number of jobs and machines
    6, 18, 3, 45, 8, 56, 0, 82, 7, 70, 5, 15, 2, 49, 1, 74, 4, 48, 
    1, 37, 2, 66, 8, 54, 7, 13, 6, 36, 0, 71, 4, 66, 3, 83, 5, 34, 
    2, 80, 5, 17, 3, 65, 4,  5, 0, 26, 8, 66, 6, 52, 7, 11, 1, 37, 
    6, 31, 8, 25, 5, 42, 4, 53, 0, 32, 7, 69, 3, 67, 1, 44, 2, 90, 
    6,  1, 5, 24, 7,  6, 3, 59, 8, 56, 4,  8, 1, 17, 2, 95, 0, 66, 
    2, 66, 7, 78, 5, 12, 3, 67, 4, 86, 8, 71, 6, 43, 0, 15, 1, 97, 
    0, 98, 2, 14, 4, 57, 6,  1, 7, 41, 1,  2, 8, 61, 5, 48, 3, 21, 
    2, 28, 1, 51, 8, 18, 6, 39, 0, 36, 3,  7, 4, 70, 5, 54, 7, 14, 
    5, 58, 7, 25, 4, 29, 3, 43, 6, 57, 8,  8, 1, 56, 0, 54, 2, 18
  };
  const int q2139[] = {
    9, 9, // Number of jobs and machines
    5, 61, 2,  6, 6, 10, 8, 37, 3, 32, 1, 71, 7,  7, 4, 44, 0,  8, 
    4, 35, 8, 67, 5, 14, 6, 86, 0, 52, 2, 20, 3, 18, 7, 31, 1, 59, 
    1,  8, 5,  1, 7, 98, 0, 72, 8, 52, 4, 11, 2, 77, 6, 75, 3, 99, 
    3, 31, 0, 62, 1, 34, 8, 34, 4, 53, 2, 56, 6, 89, 5, 92, 7,  1, 
    6, 56, 1, 94, 3, 14, 8, 36, 7, 72, 2, 64, 5, 33, 0,  1, 4, 73, 
    8, 23, 2, 30, 4, 36, 1, 90, 5, 16, 7,  9, 3, 44, 6, 28, 0, 58, 
    2, 39, 1, 80, 6, 85, 5, 84, 8, 72, 4,  4, 7, 31, 3, 85, 0, 56, 
    1, 19, 0, 10, 5, 74, 2, 43, 4, 34, 6, 50, 7, 35, 3, 75, 8, 68, 
    2, 54, 0, 69, 6, 64, 7, 52, 4, 53, 1, 14, 5, 87, 3, 15, 8, 10
  };
  const int q2140[] = {
    9, 9, // Number of jobs and machines
    4, 69, 0, 17, 6, 54, 1, 12, 8, 67, 3, 95, 2, 16, 7, 20, 5, 42, 
    6, 33, 8, 79, 1, 66, 3, 28, 7, 50, 4, 68, 5, 65, 0, 25, 2, 75, 
    0, 58, 5, 73, 2, 76, 1, 59, 6, 55, 7, 58, 3, 36, 4, 64, 8,  8, 
    1, 63, 6, 84, 3, 87, 8,  8, 7, 87, 0, 71, 5, 30, 2, 27, 4, 31, 
    5, 39, 3, 36, 8, 28, 4, 28, 0, 94, 6, 15, 2, 43, 1, 90, 7, 66, 
    1, 30, 3, 17, 4, 66, 6, 31, 7, 15, 2, 44, 0,  9, 8, 97, 5, 74, 
    6, 30, 1, 50, 4, 99, 7, 43, 8, 11, 0, 80, 2, 35, 5, 67, 3, 17, 
    0, 84, 6, 96, 5, 28, 8, 20, 3, 13, 2, 38, 1, 44, 7, 89, 4,  6, 
    4, 58, 8, 66, 6, 35, 1, 94, 3, 33, 7, 60, 0, 63, 5, 11, 2, 62
  };
  const int q2141[] = {
    9, 9, // Number of jobs and machines
    1, 51, 4, 88, 6, 36, 3,  2, 8, 25, 7, 28, 0, 70, 5, 56, 2, 76, 
    4, 89, 5, 95, 3, 49, 6, 93, 7, 52, 2, 24, 0, 24, 8, 36, 1, 54, 
    8, 91, 5, 56, 7, 46, 4, 75, 2, 76, 3, 77, 1, 46, 6, 76, 0, 32, 
    3, 34, 4, 33, 5, 42, 1, 39, 7, 14, 6, 49, 8, 14, 2, 69, 0, 24, 
    0, 67, 4, 20, 7, 71, 6, 97, 2, 60, 5, 23, 3, 18, 8,  5, 1, 18, 
    3, 78, 5, 21, 1, 68, 7, 28, 8,  9, 2, 39, 0, 93, 4, 97, 6,  9, 
    5, 93, 3, 25, 0, 82, 4, 98, 2, 87, 6, 12, 1,  5, 8, 30, 7, 83, 
    7, 66, 0, 88, 3, 22, 4,  9, 8, 59, 1, 70, 6,  8, 5, 91, 2, 61, 
    7,  8, 2, 85, 8, 31, 1,  2, 3, 71, 4, 33, 5, 53, 0, 60, 6, 59
  };
  const int q2142[] = {
    9, 9, // Number of jobs and machines
    5, 86, 8, 38, 3, 75, 2, 16, 1, 17, 7, 66, 0,  4, 4, 99, 6, 70, 
    3, 22, 6, 84, 5, 50, 4, 71, 7, 20, 8,  4, 1, 91, 2, 57, 0, 16, 
    2, 32, 4, 27, 8, 80, 6, 66, 3, 23, 1, 37, 0, 44, 5, 70, 7, 72, 
    2, 33, 5, 77, 3, 71, 8, 46, 4, 17, 1, 57, 7, 48, 6, 11, 0, 17, 
    8,  5, 1, 76, 3, 46, 7, 45, 2, 86, 4, 71, 0, 65, 5, 31, 6, 47, 
    8,  9, 1, 51, 5, 86, 4, 36, 7, 61, 3, 42, 6,  2, 0, 35, 2, 41, 
    6, 99, 0, 21, 7,  1, 1, 44, 8, 30, 2, 23, 5, 50, 4,  5, 3, 46, 
    4, 76, 6, 97, 0, 30, 2, 46, 5, 64, 3, 38, 1, 85, 8,  3, 7, 59, 
    7,  1, 2, 80, 5, 78, 6, 17, 3, 43, 8, 66, 0, 31, 4, 62, 1, 64
  };
  const int q2143[] = {
    9, 9, // Number of jobs and machines
    8, 57, 4, 88, 2, 60, 1, 70, 7, 30, 3, 87, 0, 70, 5,  6, 6, 53, 
    3, 61, 7, 30, 2, 96, 6, 33, 5, 82, 8, 47, 1, 74, 4,  8, 0, 14, 
    6, 94, 8, 79, 1, 13, 4, 99, 3, 51, 0, 31, 5, 22, 7, 81, 2, 33, 
    1,  9, 5, 20, 8, 80, 7,  8, 2, 67, 6, 17, 4, 26, 0, 45, 3, 79, 
    2, 34, 1, 92, 0, 71, 8, 73, 4, 93, 7, 58, 3, 89, 5, 84, 6, 54, 
    5, 38, 6, 29, 0, 39, 7, 23, 1, 17, 3, 40, 2,  1, 4, 70, 8, 14, 
    6, 73, 5, 86, 3, 30, 8, 30, 2, 13, 4, 87, 1, 50, 0, 61, 7, 56, 
    2, 44, 1, 11, 6, 82, 4, 53, 5, 86, 8, 49, 0, 70, 7, 76, 3, 48, 
    7, 60, 1, 45, 0, 77, 5, 58, 4, 86, 2, 68, 3, 92, 8, 87, 6, 59
  };
  const int q2144[] = {
    9, 9, // Number of jobs and machines
    0, 44, 6, 25, 3, 68, 1,  1, 4, 37, 8, 36, 2, 47, 7, 70, 5, 55, 
    0, 78, 4, 96, 7, 78, 2, 11, 6, 44, 5, 69, 8, 73, 3, 61, 1, 97, 
    4, 37, 6, 34, 8, 33, 2, 81, 0,  2, 3, 53, 1, 38, 5, 70, 7, 58, 
    3, 98, 8,  7, 4, 12, 1, 18, 6, 89, 2, 23, 5,  8, 0, 25, 7, 95, 
    0, 22, 7, 49, 5, 88, 1, 19, 4, 79, 6, 27, 3, 92, 2, 54, 8,  2, 
    2, 82, 5, 59, 1, 59, 6, 13, 8, 16, 4, 81, 7, 80, 0, 11, 3, 82, 
    3, 75, 5, 38, 2, 13, 7, 81, 1, 65, 0, 51, 6,  6, 4, 30, 8, 47, 
    5,  9, 8, 94, 1, 40, 0, 82, 7, 53, 3, 89, 2, 41, 6, 58, 4, 90, 
    6, 23, 3,  7, 1, 66, 7, 29, 2, 35, 8, 90, 5, 61, 4,  2, 0, 43
  };
  const int q2145[] = {
    9, 9, // Number of jobs and machines
    4, 12, 7, 19, 0,  7, 2, 71, 1, 42, 5, 81, 3,  6, 8, 68, 6, 50, 
    7,  8, 4, 25, 0, 49, 1, 11, 2,  2, 6, 78, 3, 46, 5, 15, 8, 56, 
    4, 90, 2, 85, 6, 52, 5, 86, 7, 34, 0, 85, 8, 18, 3, 26, 1, 25, 
    2, 20, 6, 78, 3, 45, 7,  5, 8, 89, 4, 20, 0, 25, 1, 36, 5, 71, 
    5, 13, 6, 63, 1, 39, 0, 22, 2, 73, 8, 82, 7, 24, 4, 16, 3, 33, 
    6, 68, 2, 99, 7, 33, 1, 93, 8, 99, 0, 88, 5, 21, 4, 94, 3, 39, 
    6, 16, 7,  8, 2, 83, 3, 56, 4, 38, 8, 29, 0, 66, 5, 73, 1, 89, 
    8, 75, 7, 99, 4, 96, 0, 99, 6,  8, 5, 60, 1, 87, 3, 13, 2, 19, 
    0, 34, 7, 30, 8, 39, 5, 17, 6, 66, 3,  2, 1, 48, 2, 82, 4, 94
  };
  const int q2146[] = {
    9, 9, // Number of jobs and machines
    0, 68, 3, 98, 7, 27, 4, 57, 5, 75, 2, 95, 1, 23, 6, 14, 8, 61, 
    2, 76, 5, 33, 1, 32, 3, 62, 8, 69, 4, 65, 7, 45, 0, 79, 6, 53, 
    4, 97, 2, 11, 1, 53, 0, 36, 5, 58, 7,  8, 3, 35, 6, 29, 8, 71, 
    1, 14, 5, 60, 7, 61, 4, 71, 0,  1, 3,  4, 2, 16, 8, 56, 6, 12, 
    1, 51, 8, 23, 6, 73, 4, 53, 3, 45, 0, 57, 2, 62, 7, 54, 5, 55, 
    1,  1, 4, 40, 7, 22, 8, 55, 5, 97, 0, 74, 2, 93, 3, 55, 6, 71, 
    3, 19, 4, 77, 8, 30, 0, 72, 1, 18, 5, 98, 6, 57, 7, 74, 2, 45, 
    0,  2, 6, 55, 1, 23, 4, 47, 7, 18, 3, 67, 5, 55, 2, 99, 8, 91, 
    3,  3, 7, 14, 6, 27, 2, 75, 0,  8, 5, 41, 1, 32, 4,  1, 8, 36
  };
  const int q2147[] = {
    9, 9, // Number of jobs and machines
    2, 43, 3, 70, 5,  1, 4, 53, 1, 89, 8, 35, 0, 90, 6, 48, 7, 98, 
    4, 21, 1, 84, 3, 38, 8, 90, 5, 61, 6, 14, 0, 22, 7, 82, 2, 50, 
    4, 11, 2, 52, 8, 25, 7, 44, 3, 72, 1, 36, 6, 59, 0, 15, 5, 46, 
    1, 75, 5,  7, 0,  5, 6, 70, 2,  9, 3, 56, 8, 26, 7,  2, 4, 43, 
    6, 66, 2, 21, 4, 62, 3, 75, 1, 41, 8, 44, 7, 80, 5, 81, 0,  4, 
    2, 29, 4, 79, 3, 99, 6, 31, 8, 68, 0, 79, 7, 30, 5, 84, 1, 71, 
    0, 25, 5, 75, 7,  1, 1, 97, 4, 67, 2, 14, 6, 27, 8, 97, 3,  2, 
    7, 63, 3, 31, 6, 77, 0, 76, 1, 28, 4, 61, 8, 29, 2, 94, 5, 85, 
    8, 93, 7, 25, 1, 30, 3, 16, 2, 40, 4, 64, 6, 21, 0, 83, 5, 62
  };
  const int q2148[] = {
    9, 9, // Number of jobs and machines
    2, 89, 0, 81, 8, 47, 7,  7, 1, 77, 3, 14, 5, 83, 4, 95, 6, 38, 
    0,  3, 4, 91, 1,  2, 3,  7, 5, 14, 2, 39, 7,  3, 8, 15, 6, 57, 
    4, 21, 2, 88, 0, 85, 5, 52, 1, 56, 7, 37, 3, 74, 8, 77, 6, 62, 
    5, 70, 1, 31, 0, 48, 8, 17, 7, 65, 3, 38, 2, 86, 6,  8, 4, 86, 
    7, 95, 5, 81, 2, 88, 8, 60, 0, 94, 4, 89, 6, 81, 1, 67, 3, 37, 
    0, 30, 3, 44, 6, 41, 7, 37, 5, 86, 4, 38, 8,  3, 1, 81, 2, 72, 
    1, 56, 4, 14, 7,  6, 6, 85, 8, 69, 2, 65, 0, 78, 3, 91, 5, 54, 
    7, 68, 4, 80, 2,  2, 6, 24, 3,  8, 8, 96, 1,  9, 5, 82, 0, 42, 
    6, 74, 5, 50, 4,  5, 1, 75, 8, 84, 2, 84, 7, 95, 0, 90, 3, 75
  };
  const int q2149[] = {
    9, 9, // Number of jobs and machines
    3, 56, 4, 68, 2, 77, 1, 31, 5, 75, 6, 35, 0, 11, 8, 82, 7, 69, 
    8, 45, 6, 51, 0, 15, 3, 23, 1, 93, 4, 45, 2, 23, 7, 63, 5, 27, 
    0, 38, 4, 92, 1, 37, 7, 61, 3, 15, 8, 19, 2, 54, 5, 13, 6, 87, 
    3, 67, 5, 34, 4, 89, 6, 98, 0, 65, 1, 85, 7, 25, 8, 50, 2, 18, 
    1, 44, 6, 20, 2,  7, 0, 67, 7, 95, 5, 83, 3, 94, 4, 42, 8, 64, 
    8, 55, 3, 73, 1, 33, 4, 31, 7, 20, 5, 97, 6, 33, 0, 42, 2, 10, 
    0, 77, 6, 83, 1, 22, 7, 41, 5, 15, 2, 87, 4, 26, 3, 15, 8, 75, 
    7, 26, 3, 20, 2,  8, 5, 36, 1, 46, 0, 17, 6, 57, 4, 42, 8, 55, 
    4, 51, 8, 86, 1, 12, 7, 76, 3, 32, 6, 57, 5, 49, 0, 75, 2, 65
  };
  const int q2150[] = {
    9, 9, // Number of jobs and machines
    5, 22, 2, 70, 7, 23, 6, 76, 0, 32, 3, 82, 8, 39, 1, 80, 4, 38, 
    1, 61, 3, 71, 7,  3, 5, 17, 4, 63, 6, 20, 0, 10, 2, 36, 8, 35, 
    3,  3, 2, 15, 0, 35, 6, 95, 4, 69, 7, 97, 5, 80, 1, 61, 8, 89, 
    5, 71, 8, 95, 1, 10, 3, 16, 2, 91, 4, 54, 7, 88, 6, 38, 0, 63, 
    1, 21, 7, 10, 8, 74, 3, 66, 0, 56, 2, 62, 5, 49, 4, 55, 6, 78, 
    6, 44, 4, 15, 0, 93, 8, 23, 3, 11, 7, 35, 2, 84, 5, 69, 1,  3, 
    4, 92, 3, 92, 7, 53, 0, 91, 1, 27, 6, 40, 5, 65, 8, 74, 2,  2, 
    3, 72, 6, 90, 8, 54, 1, 57, 4, 61, 0, 33, 2, 38, 5, 53, 7, 65, 
    7, 31, 0, 88, 5, 16, 1, 56, 3,  9, 4, 15, 2, 85, 8, 27, 6,  3
  };
  const int q2151[] = {
    9, 9, // Number of jobs and machines
    0, 90, 5,  2, 3, 32, 8, 96, 2, 89, 1, 27, 4, 99, 6, 21, 7, 39, 
    3, 81, 2, 70, 5, 28, 8, 47, 7, 90, 4, 44, 1, 87, 6, 58, 0, 28, 
    2, 88, 7, 88, 5, 28, 1, 34, 8, 27, 6, 39, 3, 33, 4, 58, 0, 13, 
    5, 87, 8, 72, 0, 29, 6, 56, 2, 51, 4, 27, 3, 85, 1, 76, 7, 59, 
    7, 61, 2, 49, 5, 50, 8, 83, 0, 10, 6,  2, 1,  8, 4, 72, 3, 27, 
    1, 64, 6, 82, 5, 88, 2, 12, 8, 68, 4,  3, 3, 66, 7, 34, 0, 40, 
    8, 78, 2,  5, 5, 29, 6, 11, 4, 31, 7, 32, 3,  8, 1, 73, 0, 11, 
    4,  7, 1, 87, 0, 76, 5, 85, 3, 29, 2, 85, 7, 13, 6, 63, 8, 32, 
    5, 24, 6, 14, 7, 26, 3, 38, 1, 18, 2, 10, 8, 24, 0, 15, 4,  7
  };
  const int q2152[] = {
    9, 9, // Number of jobs and machines
    0, 38, 5, 23, 1, 26, 7, 85, 6, 84, 8, 34, 2, 21, 4, 59, 3, 97, 
    3, 37, 1, 10, 2, 14, 5, 43, 4, 50, 6,  9, 7,  9, 0, 26, 8,  2, 
    5,  2, 4, 85, 3, 43, 2, 60, 0, 28, 7, 46, 1, 66, 6, 81, 8, 15, 
    3, 17, 0, 29, 1, 47, 6, 39, 7, 47, 4, 29, 2, 20, 5,  6, 8, 27, 
    7, 98, 1, 56, 6, 25, 5,  3, 4, 10, 0, 70, 8, 39, 3, 89, 2, 41, 
    2, 52, 5, 40, 8, 29, 7, 48, 4, 91, 1, 37, 3, 67, 0, 72, 6, 82, 
    7, 84, 6, 77, 1, 76, 0, 16, 2, 77, 4, 44, 5, 17, 3, 14, 8, 37, 
    2, 36, 1, 58, 5, 60, 6, 24, 0, 36, 7, 14, 3, 14, 8, 42, 4, 93, 
    4, 15, 8, 58, 3, 82, 0, 11, 5, 20, 1, 38, 2, 31, 6, 85, 7, 80
  };
  const int q2153[] = {
    9, 9, // Number of jobs and machines
    0, 63, 7, 61, 3, 27, 4, 40, 1, 56, 2, 10, 6, 98, 5, 15, 8, 97, 
    8, 20, 2, 95, 0, 12, 7, 41, 4, 27, 3, 36, 1, 17, 5, 37, 6, 98, 
    8, 86, 5, 35, 0, 88, 4, 99, 2, 54, 1, 82, 7, 52, 3,  1, 6, 32, 
    4,  9, 7, 50, 6, 67, 2, 70, 8, 57, 5, 54, 1,  9, 0, 66, 3, 38, 
    4, 50, 7, 34, 0, 55, 1, 10, 8, 87, 2, 48, 3, 56, 5, 72, 6, 32, 
    7, 92, 6, 92, 8, 70, 2, 81, 1, 47, 3,  2, 5,  3, 0, 91, 4, 66, 
    2, 84, 8, 86, 4, 73, 6, 81, 3, 56, 0,  5, 1, 41, 7, 50, 5,  6, 
    2, 27, 5, 73, 0, 85, 4, 88, 3, 32, 6,  1, 8, 24, 1, 36, 7, 87, 
    1, 44, 2, 27, 0,  4, 8, 70, 6, 77, 5, 50, 4, 13, 3, 42, 7, 32
  };
  const int q2154[] = {
    9, 9, // Number of jobs and machines
    6, 26, 3, 34, 8, 25, 2, 20, 7, 35, 4, 90, 0, 86, 1, 48, 5, 28, 
    3, 77, 2,  7, 0, 76, 8,  3, 1, 68, 6, 53, 4, 70, 7,  5, 5, 16, 
    8, 80, 0,  5, 3, 56, 5, 62, 1, 36, 7, 98, 6, 24, 2, 41, 4, 42, 
    1, 36, 7,  8, 2,  4, 4, 65, 8, 84, 5,  2, 3,  2, 0, 24, 6, 73, 
    8, 47, 6, 41, 7, 73, 5, 49, 1, 30, 0,  7, 3, 17, 4, 53, 2, 70, 
    4, 89, 5, 92, 3, 15, 7, 16, 1, 12, 0,  8, 2, 37, 6, 40, 8, 83, 
    5,  6, 6, 34, 8, 60, 3, 21, 2, 65, 0, 62, 4, 16, 7, 28, 1, 49, 
    0, 54, 5, 50, 7, 43, 8, 77, 1, 55, 6, 19, 3, 91, 4, 79, 2, 41, 
    3, 21, 8, 94, 0, 69, 5, 34, 2, 11, 4, 68, 1, 12, 6, 36, 7, 12
  };
  const int q2155[] = {
    9, 9, // Number of jobs and machines
    5, 91, 7, 56, 1, 81, 4,  6, 6, 82, 3, 51, 8, 17, 0, 56, 2, 62, 
    1, 85, 6,  8, 3, 53, 4, 41, 2, 70, 8, 20, 5, 42, 0, 73, 7, 96, 
    8, 89, 6, 68, 4, 11, 7, 17, 1, 85, 0, 35, 3, 67, 5, 83, 2, 56, 
    8, 27, 0, 42, 3, 12, 4, 18, 7, 71, 1, 49, 2, 73, 5, 70, 6, 98, 
    6, 71, 0, 77, 8, 24, 7, 66, 3, 64, 1, 73, 5, 17, 2, 18, 4,  2, 
    2,  3, 5, 58, 6, 69, 3, 69, 7, 59, 0, 60, 4, 56, 8, 23, 1, 14, 
    0, 35, 7, 31, 6, 31, 3, 57, 2, 20, 4, 45, 8, 10, 5,  5, 1, 86, 
    8, 40, 2, 10, 7,  5, 4, 30, 0, 20, 6, 88, 3, 33, 1,  5, 5, 21, 
    6, 58, 7, 80, 8, 36, 0, 53, 4, 51, 2, 60, 1, 94, 3, 47, 5, 68
  };
  const int q2156[] = {
    9, 9, // Number of jobs and machines
    8, 48, 7, 37, 2, 82, 0, 70, 1, 74, 4, 98, 6, 53, 3, 65, 5, 98, 
    0, 91, 7, 52, 6, 80, 1, 92, 8, 20, 5, 13, 3,  3, 2,  9, 4, 64, 
    7, 49, 3, 96, 8, 15, 2, 49, 5, 98, 1, 45, 0, 44, 4, 60, 6, 92, 
    1, 96, 4, 51, 6, 33, 8, 38, 7, 23, 5, 64, 3, 12, 2, 35, 0, 57, 
    8, 76, 2, 66, 7,  1, 1, 17, 6, 85, 4, 38, 3, 42, 5, 96, 0, 68, 
    1, 30, 6, 18, 2, 95, 4, 52, 0, 51, 8, 11, 5, 13, 7,  7, 3, 84, 
    5, 93, 0, 57, 3,  1, 4, 23, 8, 17, 7,  3, 1, 41, 6, 35, 2, 80, 
    3, 86, 1, 72, 0, 36, 7, 38, 5, 25, 6, 13, 4, 82, 8, 65, 2, 64, 
    4,  6, 7, 41, 0, 41, 8, 17, 6, 36, 3, 92, 2, 32, 5, 60, 1, 77
  };
  const int q2157[] = {
    9, 9, // Number of jobs and machines
    5,  1, 0, 48, 7, 75, 4,  9, 2, 23, 8, 10, 6, 61, 3, 53, 1, 47, 
    4, 65, 0, 63, 5, 24, 7, 92, 8, 87, 2,  6, 6, 44, 1, 57, 3, 37, 
    2, 79, 4,  4, 7, 84, 1, 59, 6, 98, 0, 21, 5, 64, 3, 29, 8, 80, 
    3, 53, 1,  8, 2, 20, 4, 93, 7, 50, 5,  6, 8, 68, 6, 19, 0,  8, 
    8, 70, 2,  8, 5, 82, 7, 35, 1, 62, 3, 29, 4,  4, 0,  8, 6, 99, 
    8, 83, 7, 29, 4, 25, 2, 48, 3, 65, 6, 93, 5, 16, 0, 64, 1, 85, 
    2, 83, 4, 23, 1, 64, 6, 99, 7, 51, 0, 79, 8,  8, 3,  5, 5,  5, 
    1, 57, 5, 90, 0, 47, 6, 39, 7, 42, 3, 44, 2, 99, 8, 23, 4, 94, 
    0, 22, 2,  2, 4, 53, 1, 38, 7, 86, 5, 43, 3, 95, 8, 78, 6, 79
  };
  const int q2158[] = {
    9, 9, // Number of jobs and machines
    5, 50, 8, 60, 7, 65, 4, 14, 1, 71, 3,  4, 2,  8, 0, 16, 6,  4, 
    2, 63, 8, 94, 7, 19, 4, 93, 3, 52, 6, 74, 1, 84, 0, 64, 5, 64, 
    4, 49, 5, 57, 1, 83, 8, 78, 0, 21, 3, 66, 2, 73, 6, 16, 7, 23, 
    4, 91, 3, 37, 1, 92, 7, 13, 5, 19, 8,  6, 6, 71, 0, 58, 2, 93, 
    6, 79, 5, 98, 2, 46, 0, 40, 8, 92, 1, 13, 4, 33, 3, 81, 7, 12, 
    6, 75, 3, 73, 4, 76, 8, 93, 5, 38, 0, 83, 1,  5, 7, 76, 2, 26, 
    4, 20, 8,  8, 2, 51, 5,  5, 0, 40, 1, 57, 3, 55, 6, 68, 7, 72, 
    5, 94, 8, 31, 6, 28, 2, 28, 3, 10, 1, 96, 4, 81, 7,  7, 0,  5, 
    5, 40, 3,  4, 7, 25, 0, 81, 4, 60, 1, 55, 8, 78, 6, 84, 2, 84
  };
  const int q2159[] = {
    9, 9, // Number of jobs and machines
    4, 11, 8, 45, 0, 35, 7, 43, 1, 73, 5, 52, 3, 18, 6, 40, 2, 12, 
    8, 27, 6, 36, 4, 88, 5, 38, 1, 50, 2, 64, 0, 84, 3, 35, 7, 55, 
    7, 21, 3, 48, 0, 54, 6, 30, 2, 27, 1, 14, 4, 67, 8, 36, 5, 95, 
    8, 10, 7,  5, 2, 38, 3, 30, 0, 48, 6, 94, 4, 54, 1, 97, 5, 76, 
    0, 79, 5, 42, 4, 21, 1, 72, 2, 57, 6, 14, 3,  1, 7,  1, 8, 73, 
    4, 54, 1, 25, 6,  7, 7, 91, 8, 85, 0, 62, 3, 36, 2, 13, 5, 78, 
    0, 84, 5, 63, 2,  5, 8, 38, 6, 58, 1, 83, 3, 15, 7, 75, 4, 65, 
    3, 59, 7, 67, 8, 92, 0, 73, 1, 26, 5, 36, 4, 83, 2, 31, 6, 22, 
    2, 77, 3, 76, 8, 78, 7, 80, 6,  6, 0, 27, 4, 72, 1, 18, 5, 75
  };
  const int q2160[] = {
    9, 9, // Number of jobs and machines
    8,  4, 3, 57, 0, 29, 6, 33, 4, 23, 1, 73, 7, 51, 5, 81, 2, 11, 
    3,  6, 8, 65, 6, 24, 5, 13, 2, 17, 0, 93, 1, 63, 7, 13, 4, 68, 
    6, 67, 4,  9, 2, 93, 1, 25, 5, 17, 3, 17, 0, 71, 7,  3, 8,  2, 
    3, 90, 0, 38, 5, 18, 7, 20, 8, 73, 4,  3, 2, 50, 6, 93, 1, 20, 
    3, 63, 8, 30, 7, 38, 1, 23, 0, 31, 5, 54, 6, 73, 4, 19, 2, 19, 
    5, 17, 2, 19, 3, 26, 4, 31, 0, 76, 1, 57, 8, 99, 6, 77, 7, 38, 
    2, 57, 1, 68, 7, 18, 3, 28, 8, 86, 5, 23, 4, 88, 6, 27, 0, 90, 
    6, 82, 8, 94, 3, 44, 1, 38, 0, 12, 2, 21, 4, 20, 7, 17, 5, 22, 
    3, 42, 5, 58, 8,  5, 2, 74, 0,  2, 1, 42, 4, 23, 6, 76, 7, 74
  };
  const int q2161[] = {
    9, 9, // Number of jobs and machines
    4, 51, 2, 61, 6, 98, 3, 58, 5, 78, 7, 38, 0, 70, 8, 89, 1, 63, 
    1,  3, 5, 44, 8, 71, 7, 57, 6,  7, 2, 30, 4, 48, 3, 20, 0, 70, 
    1, 97, 4, 61, 7, 51, 0, 34, 2, 72, 5,  2, 6, 59, 8, 69, 3, 60, 
    8, 27, 0, 87, 7,  5, 3, 17, 6, 92, 2,  2, 4, 17, 5, 57, 1, 20, 
    2, 76, 0, 39, 3, 42, 5, 32, 8, 73, 1, 50, 7, 36, 4,  9, 6, 64, 
    4, 77, 3,  7, 2, 10, 6, 45, 1, 19, 8, 67, 5, 16, 0,  7, 7, 85, 
    6, 47, 7, 28, 1, 73, 2, 43, 5, 95, 0, 40, 4, 36, 3,  4, 8, 25, 
    3, 63, 1, 33, 5, 54, 7, 57, 0,  2, 4, 94, 2, 77, 6,  7, 8, 93, 
    0, 27, 4, 44, 8, 70, 6, 56, 3, 46, 7, 69, 1, 25, 5, 94, 2,  2
  };
  const int q2162[] = {
    9, 9, // Number of jobs and machines
    5, 21, 6,  6, 2,  3, 4,  4, 0, 84, 8, 21, 1, 65, 7, 39, 3, 32, 
    4, 78, 0, 64, 6, 85, 5, 54, 7,  6, 2, 36, 8, 27, 1, 33, 3, 38, 
    4,  7, 1, 41, 5, 18, 6, 89, 8, 83, 2, 88, 3, 19, 7, 28, 0, 76, 
    7, 75, 3, 47, 0, 63, 8, 33, 2, 46, 1, 22, 4, 43, 5, 31, 6, 37, 
    7, 46, 1, 14, 6, 93, 4, 46, 8, 94, 0, 60, 3, 73, 2, 64, 5,  1, 
    7, 37, 6, 97, 2, 86, 3, 85, 8, 34, 4, 56, 1, 88, 0, 35, 5, 61, 
    6, 81, 5, 87, 3, 45, 0, 76, 7, 64, 8, 43, 4, 77, 1, 23, 2, 50, 
    4,  3, 6, 61, 1, 92, 7, 33, 3,  5, 0, 92, 2, 42, 5,  6, 8, 85, 
    6,  5, 7, 52, 4, 57, 5, 43, 8, 44, 1, 46, 0,  7, 2, 50, 3, 11
  };
  const int q2163[] = {
    9, 9, // Number of jobs and machines
    0, 79, 8, 45, 4, 92, 2, 11, 7, 49, 5, 71, 1, 54, 6, 34, 3,  7, 
    1, 11, 0, 24, 5, 28, 6, 29, 7, 48, 8, 39, 3, 64, 2, 22, 4, 65, 
    6, 79, 4, 86, 7, 42, 3, 48, 2, 89, 1, 93, 8, 86, 5, 87, 0, 53, 
    3, 40, 2, 89, 4, 15, 1, 94, 0, 85, 6, 84, 5, 24, 7, 94, 8, 69, 
    2, 79, 5, 11, 0, 14, 3, 57, 1, 65, 7, 34, 6, 39, 4, 81, 8, 30, 
    3, 84, 0,  4, 6, 45, 7, 59, 2, 85, 1, 17, 8, 84, 5, 97, 4, 92, 
    0, 28, 6, 55, 3, 35, 1, 85, 5, 34, 2, 53, 7, 78, 8, 29, 4, 38, 
    0, 37, 4, 28, 5, 75, 3, 36, 2, 16, 6, 78, 7, 79, 1, 90, 8, 18, 
    6, 55, 3, 30, 4, 87, 2, 16, 7, 97, 8, 51, 5, 91, 0, 75, 1, 93
  };
  const int q2164[] = {
    9, 9, // Number of jobs and machines
    3, 20, 6, 86, 2, 98, 0, 18, 1, 49, 4, 76, 7, 51, 8, 83, 5, 32, 
    7, 98, 0, 23, 6, 54, 4, 13, 5, 50, 8, 31, 3, 42, 1, 67, 2, 69, 
    4, 89, 3, 94, 6,  7, 0, 23, 1, 78, 8, 28, 7, 98, 2, 60, 5, 61, 
    3, 19, 8, 31, 6, 81, 4, 10, 2, 97, 5, 92, 0, 98, 7, 74, 1, 49, 
    6, 54, 8, 20, 7, 57, 1, 54, 2, 83, 0, 73, 3, 74, 5, 80, 4,  1, 
    2, 66, 3, 43, 7, 43, 4, 97, 8, 24, 1, 20, 5, 16, 0, 11, 6, 49, 
    6, 54, 0, 67, 7, 73, 4, 61, 5,  2, 1, 13, 2, 78, 3, 24, 8,  2, 
    2, 13, 7, 87, 1, 64, 8, 72, 6, 58, 5, 49, 3, 73, 4, 76, 0, 83, 
    4, 36, 5, 94, 6, 52, 1, 99, 2, 44, 0, 22, 8, 47, 7, 97, 3, 65
  };
  const int q2165[] = {
    9, 9, // Number of jobs and machines
    6, 13, 8, 91, 5, 62, 2, 82, 1, 21, 0, 52, 4, 20, 7, 34, 3,  4, 
    1, 97, 4, 39, 3, 90, 6, 25, 2, 91, 5, 13, 8,  9, 0,  7, 7, 62, 
    4, 87, 2, 51, 1, 95, 8, 70, 3, 39, 6, 49, 5, 24, 7, 44, 0, 79, 
    3,  9, 4, 53, 0, 85, 6, 45, 8, 27, 2, 35, 1, 39, 5,  1, 7,  8, 
    3,  1, 0, 15, 8, 64, 5, 62, 7, 22, 1, 58, 6, 32, 4, 38, 2,  8, 
    7,  1, 2, 33, 3, 87, 0, 91, 5, 62, 4, 67, 6, 58, 1, 54, 8, 71, 
    0,  5, 3,  8, 5, 43, 4, 65, 7,  8, 1, 19, 2, 24, 6, 39, 8, 64, 
    7, 91, 8, 48, 2,  8, 5, 14, 3, 98, 1,  6, 0, 52, 6,  9, 4, 93, 
    4, 71, 6, 26, 8, 52, 7, 14, 1, 41, 5, 64, 2, 95, 3, 24, 0, 96
  };
  const int q2166[] = {
    9, 9, // Number of jobs and machines
    8, 55, 2, 18, 7, 84, 4, 54, 3,  8, 1, 72, 6, 71, 5,  7, 0, 35, 
    4, 97, 8, 18, 0, 98, 3, 45, 7, 95, 1, 29, 6, 78, 2, 69, 5,  8, 
    1, 70, 6, 96, 0, 89, 5, 19, 2, 83, 4, 41, 7, 51, 8,  5, 3, 48, 
    8, 48, 6, 42, 5,  5, 4, 45, 7,  8, 2, 74, 1,  4, 0, 53, 3, 39, 
    4, 96, 8, 23, 5, 85, 3, 92, 7,  9, 6, 19, 1, 64, 0, 92, 2, 90, 
    6, 70, 0, 43, 1, 65, 7, 23, 4, 49, 8, 54, 3, 13, 5, 76, 2, 50, 
    3,  2, 2, 27, 4, 71, 0, 97, 1, 20, 8, 97, 7, 18, 6, 24, 5, 65, 
    4, 37, 6,  6, 7, 33, 3, 54, 8, 46, 2, 58, 1, 52, 5, 85, 0, 71, 
    6, 15, 2, 53, 8, 35, 1, 99, 7,  3, 4, 83, 5, 85, 0, 13, 3, 27
  };
  const int q2167[] = {
    9, 9, // Number of jobs and machines
    2, 37, 1,  5, 4, 65, 3, 59, 8, 23, 5, 55, 7, 28, 0, 22, 6, 40, 
    7, 45, 1, 17, 4, 61, 6, 66, 8, 47, 3, 53, 0, 40, 5, 59, 2, 72, 
    3, 24, 8, 70, 0, 34, 2, 89, 4, 58, 1, 92, 7, 19, 5, 58, 6, 15, 
    5, 97, 0,  7, 1, 84, 2, 65, 6, 66, 7, 66, 4, 55, 3, 32, 8, 62, 
    5, 84, 2, 57, 0, 80, 4, 56, 8, 96, 7, 42, 3, 83, 6, 55, 1, 46, 
    8,  7, 7, 61, 1, 47, 2, 11, 4, 57, 5, 30, 3, 51, 0, 70, 6, 45, 
    0, 69, 6, 76, 7, 75, 3, 94, 1,  8, 2, 39, 4, 46, 5, 74, 8, 38, 
    1,  4, 2,  7, 6, 43, 8, 13, 5,  2, 0, 79, 3, 60, 7, 98, 4, 63, 
    6, 68, 8, 47, 5, 47, 0, 34, 2, 15, 4, 66, 3, 98, 7, 11, 1, 40
  };
  const int q2168[] = {
    9, 9, // Number of jobs and machines
    8, 68, 7, 82, 3,  6, 0, 71, 5, 25, 6, 57, 4, 65, 1, 15, 2, 60, 
    3, 43, 4, 49, 5, 24, 1, 98, 8, 73, 7, 89, 6, 94, 2, 42, 0, 98, 
    0, 71, 2, 35, 7, 43, 1, 92, 5, 39, 8, 44, 6, 95, 3, 56, 4, 28, 
    4, 85, 8, 99, 2, 37, 7, 30, 1, 19, 0, 42, 5, 78, 6, 62, 3, 85, 
    7, 96, 4, 53, 8, 54, 1, 68, 0, 66, 6, 11, 5, 32, 3, 18, 2, 88, 
    2, 25, 0, 74, 4, 92, 6, 49, 3,  6, 5, 77, 7, 84, 1, 98, 8, 14, 
    2, 38, 4, 50, 8, 26, 6, 93, 3, 86, 7, 28, 5, 55, 0, 69, 1,  7, 
    3, 70, 1, 73, 4, 74, 7, 85, 8, 70, 0, 21, 2, 73, 5, 77, 6, 19, 
    6, 31, 4, 45, 1, 51, 3, 84, 2, 11, 0, 84, 5,  2, 8, 42, 7,  7
  };
  const int q2169[] = {
    9, 9, // Number of jobs and machines
    1, 30, 5,  1, 3, 19, 6, 25, 4, 72, 7, 56, 0, 12, 2,  8, 8, 24, 
    5, 58, 0, 98, 3, 64, 6, 42, 1, 82, 7,  6, 2, 46, 8,  1, 4, 55, 
    1, 65, 7, 73, 4, 32, 8, 26, 6, 32, 0, 47, 3, 34, 2, 86, 5, 91, 
    1, 90, 7, 71, 4, 65, 8, 23, 6, 99, 2, 26, 0, 82, 5, 22, 3, 90, 
    0, 92, 4, 15, 5, 23, 1, 10, 3, 38, 7, 84, 8, 55, 2, 72, 6, 67, 
    0, 63, 7,  7, 8, 97, 6,  1, 5, 41, 4, 21, 3, 81, 2, 69, 1, 72, 
    1, 88, 8, 33, 7,  3, 3, 40, 2, 51, 5, 71, 4, 92, 0, 15, 6, 93, 
    7, 51, 3, 15, 4, 86, 5, 97, 1, 32, 8, 74, 6, 93, 0, 30, 2, 35, 
    1, 71, 0, 56, 5, 71, 7, 52, 3, 30, 8, 98, 2, 97, 4, 15, 6, 19
  };
  const int q2170[] = {
    9, 9, // Number of jobs and machines
    2, 84, 7, 78, 3, 39, 8, 75, 0, 95, 5, 53, 4, 60, 1, 62, 6, 54, 
    2, 85, 8, 82, 4, 95, 6, 38, 7, 49, 0, 58, 1, 50, 5, 66, 3, 99, 
    8, 53, 3, 56, 4, 38, 7, 70, 0, 16, 1, 43, 5, 72, 6, 80, 2, 24, 
    5, 57, 1, 71, 0,  3, 7, 78, 4, 14, 8,  4, 2, 71, 3, 59, 6, 22, 
    0, 78, 3, 53, 6, 70, 5,  1, 2, 48, 7, 36, 1, 52, 4,  5, 8, 10, 
    8, 20, 7, 31, 1, 59, 4, 75, 6, 31, 2, 88, 3, 96, 0, 72, 5, 34, 
    2, 60, 7, 33, 8, 89, 1, 68, 4,  8, 5, 68, 3, 44, 6, 16, 0,  2, 
    1, 74, 4, 62, 8, 83, 3, 48, 2, 24, 7, 93, 0, 50, 6, 94, 5, 99, 
    0, 16, 2, 32, 5, 39, 4, 62, 7, 76, 8, 44, 6, 23, 3, 94, 1, 46
  };
  const int q2171[] = {
    9, 9, // Number of jobs and machines
    0, 59, 1, 20, 3,  2, 6, 85, 7, 58, 5, 36, 4, 85, 2, 53, 8,  8, 
    2, 61, 7, 31, 6, 57, 0, 46, 1,  9, 8, 51, 3, 50, 4, 67, 5, 53, 
    6, 53, 5, 64, 3, 74, 8,  9, 0, 81, 1, 78, 7, 37, 4,  5, 2, 48, 
    8, 90, 0, 70, 4, 65, 1, 20, 2, 44, 3, 55, 5, 58, 6, 20, 7, 68, 
    0, 52, 5, 55, 8, 99, 4, 75, 3, 80, 1, 55, 7,  4, 6, 97, 2, 51, 
    7, 23, 0, 29, 3,  8, 2, 82, 6, 38, 1, 11, 4, 41, 8, 96, 5, 85, 
    6, 80, 7, 85, 2, 61, 5, 43, 1, 94, 8, 30, 4, 92, 0, 12, 3, 25, 
    8, 44, 4,  4, 3, 20, 0, 38, 6, 27, 1, 23, 2, 40, 7, 83, 5, 46, 
    6, 27, 1, 88, 5, 43, 2, 23, 7, 51, 3,  3, 0, 78, 8, 98, 4, 13
  };
  const int q2172[] = {
    9, 9, // Number of jobs and machines
    1, 68, 0, 75, 3, 36, 6, 29, 7, 62, 8, 97, 5, 27, 4, 82, 2, 25, 
    7, 85, 8, 99, 5, 61, 4, 20, 0, 98, 1, 93, 3, 77, 6, 48, 2, 25, 
    6, 78, 7, 33, 4, 16, 5, 83, 1, 50, 2, 99, 8, 14, 3, 58, 0, 47, 
    5, 77, 4, 63, 0, 24, 8, 30, 3, 86, 1, 61, 2, 15, 6, 47, 7, 52, 
    4, 52, 7, 66, 5, 39, 1, 91, 2, 18, 8, 89, 0, 46, 3, 12, 6, 18, 
    5, 50, 4, 67, 6,  2, 2, 46, 0, 70, 3, 38, 7, 66, 1, 86, 8, 63, 
    5, 32, 7, 11, 6, 43, 3, 35, 8, 82, 4, 93, 0, 32, 1, 85, 2, 33, 
    7, 54, 0, 73, 6, 55, 1, 82, 3, 61, 5,  9, 8, 63, 4, 99, 2, 42, 
    5,  7, 7, 42, 0, 56, 3, 25, 8, 17, 1, 59, 6, 29, 4, 31, 2, 15
  };
  const int q2173[] = {
    9, 9, // Number of jobs and machines
    3, 64, 1, 26, 2, 61, 5, 11, 6, 86, 4, 65, 7, 24, 8, 98, 0, 93, 
    2, 13, 4, 61, 8, 40, 3, 15, 7, 81, 5, 25, 0, 40, 1, 59, 6, 22, 
    3, 80, 0, 30, 6, 34, 1, 24, 2, 45, 4, 64, 5, 24, 8, 67, 7, 51, 
    3, 31, 7, 77, 8, 79, 2, 16, 1, 79, 0,  7, 5,  4, 6, 67, 4, 26, 
    6, 41, 4, 36, 3,  8, 2, 60, 0, 26, 5, 91, 7,  6, 8, 93, 1, 23, 
    2, 45, 4, 91, 7, 29, 3,  5, 6, 39, 8, 56, 5, 46, 1, 91, 0, 51, 
    2, 14, 8, 33, 1, 60, 7, 40, 6, 59, 5, 72, 4, 86, 0, 62, 3, 59, 
    1, 65, 2, 96, 5, 77, 8, 69, 7, 17, 4, 36, 3, 62, 0, 80, 6, 10, 
    6, 50, 5, 63, 0, 61, 2, 36, 8, 12, 4,  1, 7, 92, 1, 60, 3, 31
  };
  const int q2174[] = {
    9, 9, // Number of jobs and machines
    7, 76, 6, 68, 3, 73, 4, 48, 8, 53, 0, 68, 2, 33, 1, 48, 5, 72, 
    8, 22, 5,  5, 4, 52, 7, 52, 1, 31, 0, 66, 6, 62, 3, 45, 2, 61, 
    7, 58, 4, 94, 3, 87, 5, 20, 2, 51, 6, 76, 0, 79, 1, 23, 8, 99, 
    1,  5, 6, 42, 0, 88, 5, 48, 7, 53, 8, 81, 3, 21, 4, 56, 2, 48, 
    2, 61, 5, 83, 7, 36, 8, 11, 1, 70, 3, 63, 6, 66, 0, 67, 4, 50, 
    8, 47, 3, 99, 4, 56, 2, 78, 7, 39, 0, 50, 6, 50, 5, 97, 1, 63, 
    0, 77, 1, 80, 4, 40, 5, 96, 3, 49, 7, 99, 8, 70, 6, 66, 2,  3, 
    4, 93, 3, 22, 1, 61, 2, 48, 0, 80, 8,  3, 6, 23, 5, 53, 7, 19, 
    7, 52, 0, 30, 3, 62, 5, 21, 1, 83, 2, 46, 6, 22, 8,  9, 4, 76
  };
  const int q2175[] = {
    9, 9, // Number of jobs and machines
    1,  3, 0, 28, 2, 15, 6, 81, 4, 65, 3, 97, 8, 94, 7, 41, 5, 64, 
    7, 42, 6, 73, 5, 76, 1, 55, 3, 53, 4, 23, 8, 73, 2, 73, 0, 90, 
    7, 60, 2, 97, 8, 77, 0, 77, 4, 69, 1, 51, 5, 86, 6,  5, 3, 20, 
    2, 31, 6, 89, 8, 78, 7, 47, 3, 96, 4, 81, 5, 81, 0, 12, 1,  2, 
    3, 93, 0, 63, 1, 88, 6, 16, 2, 72, 7,  8, 5, 63, 8, 32, 4, 29, 
    6, 52, 1, 82, 4, 19, 2, 87, 3, 92, 0, 33, 5, 25, 8, 81, 7, 52, 
    2, 46, 6, 54, 0, 21, 1, 55, 5, 56, 8,  2, 7, 45, 4, 23, 3, 77, 
    3, 34, 0, 20, 2, 16, 6, 25, 8, 72, 5, 31, 7, 33, 4, 41, 1, 72, 
    3, 42, 8, 19, 6, 40, 4, 30, 5, 64, 1, 19, 7, 74, 2, 94, 0, 33
  };
  const int q2176[] = {
    9, 9, // Number of jobs and machines
    6, 48, 8, 51, 1, 54, 0, 10, 4, 57, 7, 28, 5, 22, 2, 74, 3, 78, 
    1, 46, 5, 28, 7, 83, 3, 28, 0, 56, 8,  7, 4, 76, 2, 66, 6, 56, 
    2, 17, 5, 48, 3, 86, 4, 66, 0, 29, 8, 54, 6, 23, 7, 17, 1, 12, 
    4, 25, 7, 45, 2, 80, 0, 71, 1, 63, 6, 93, 5, 56, 3, 83, 8, 27, 
    4, 53, 2, 67, 6, 46, 1, 64, 7, 51, 5, 61, 0,  6, 8, 24, 3, 57, 
    2, 39, 7, 18, 0, 21, 4, 49, 3, 55, 5, 85, 8, 51, 6, 62, 1, 98, 
    8, 79, 7, 18, 6, 20, 4,  7, 2, 75, 1, 92, 3,  2, 0, 75, 5, 24, 
    7, 16, 1, 43, 4,  7, 5, 99, 8, 79, 6, 73, 2, 79, 0, 31, 3,  6, 
    5, 77, 4, 18, 1, 81, 3, 80, 0, 31, 8, 60, 6, 68, 7, 55, 2, 92
  };
  const int q2177[] = {
    9, 9, // Number of jobs and machines
    1, 54, 6, 33, 3, 46, 5,  4, 7, 94, 0, 87, 2, 27, 4, 95, 8, 73, 
    2, 50, 8, 45, 7, 16, 1, 49, 5, 36, 3, 59, 6, 91, 0, 97, 4, 57, 
    5,  8, 3, 10, 4, 75, 0, 86, 6, 86, 7, 32, 1, 64, 8, 31, 2, 90, 
    8, 55, 7, 78, 5, 52, 2, 85, 0,  7, 1, 44, 4, 86, 3, 94, 6, 58, 
    1, 78, 3, 83, 5, 43, 4, 40, 0, 87, 2, 70, 8, 23, 6, 79, 7, 21, 
    2, 56, 0, 99, 4, 16, 7, 36, 3, 43, 8, 95, 5, 31, 6, 91, 1, 14, 
    3,  6, 8, 82, 1, 77, 6,  8, 0, 88, 2, 47, 4, 45, 7, 24, 5, 90, 
    5, 45, 2, 21, 7, 96, 0, 88, 3, 86, 1, 82, 4, 67, 6, 65, 8, 97, 
    4, 13, 1, 30, 3, 97, 0, 30, 8, 49, 5, 15, 7, 33, 2, 61, 6, 27
  };
  const int q2178[] = {
    9, 9, // Number of jobs and machines
    8, 67, 1, 63, 3, 44, 0, 46, 4, 64, 2,  9, 7, 66, 6,  9, 5, 95, 
    3, 43, 5, 24, 2, 80, 8, 45, 7, 41, 6, 58, 4, 81, 1, 64, 0, 59, 
    0, 47, 7, 28, 1, 21, 6, 80, 5, 78, 3, 25, 2, 70, 8, 65, 4, 26, 
    1, 51, 4, 28, 5,  2, 8, 19, 2, 83, 6, 24, 3,  3, 7, 61, 0, 87, 
    8, 44, 0, 85, 5, 52, 2, 41, 3,  1, 6, 18, 4, 95, 1, 68, 7, 59, 
    1, 65, 8, 22, 7, 47, 4, 35, 6,  8, 3, 77, 2, 38, 0, 45, 5, 74, 
    1, 79, 3, 55, 0,  7, 4, 83, 2, 86, 6, 61, 7, 86, 5, 84, 8, 72, 
    3, 61, 1, 10, 6, 27, 8, 56, 2, 31, 5, 26, 7, 85, 0, 98, 4, 94, 
    5, 62, 0, 51, 8, 91, 3, 44, 6, 95, 1, 13, 4, 66, 2, 73, 7, 19
  };
  const int q2179[] = {
    9, 9, // Number of jobs and machines
    8, 98, 6, 90, 2, 37, 0,  9, 5, 40, 1, 50, 4, 32, 7, 42, 3, 37, 
    0, 33, 5, 18, 8,  5, 2, 67, 7, 53, 6, 21, 3, 86, 1, 60, 4, 42, 
    8, 65, 3, 76, 6, 81, 4, 57, 2, 69, 1, 34, 0, 48, 7, 53, 5, 33, 
    4, 41, 8, 84, 6, 20, 3, 13, 2, 38, 0,  5, 5, 10, 1, 87, 7, 76, 
    7, 78, 8, 30, 4, 97, 1, 99, 6, 70, 3, 61, 5, 53, 0, 94, 2, 67, 
    6, 48, 7, 48, 3, 10, 8, 47, 4, 75, 5, 61, 1, 64, 2, 96, 0, 83, 
    1, 75, 4, 55, 0, 36, 8, 28, 7, 56, 6, 14, 3, 89, 2, 46, 5, 24, 
    7, 34, 2, 16, 4, 36, 1, 62, 0, 69, 8, 37, 6, 84, 5, 30, 3, 93, 
    8, 57, 1, 75, 4, 27, 5, 75, 7, 75, 0, 22, 3, 34, 2, 21, 6, 24
  };
  const int q2180[] = {
    9, 9, // Number of jobs and machines
    3, 29, 4, 27, 2, 98, 5, 67, 1, 31, 8, 31, 7, 24, 0, 16, 6, 53, 
    1, 51, 5, 35, 3, 55, 4, 85, 7, 59, 2, 43, 0, 38, 6,  1, 8, 22, 
    0,  3, 3, 94, 6, 13, 8, 82, 5, 89, 2, 22, 7, 65, 1, 85, 4, 52, 
    8, 55, 1, 96, 3, 36, 0, 24, 2, 39, 7, 96, 5, 98, 4, 64, 6, 50, 
    1, 25, 3, 49, 6, 54, 5, 15, 7, 80, 2, 54, 4, 91, 8, 19, 0, 30, 
    4, 20, 0, 75, 2, 35, 5, 59, 8, 84, 7, 78, 3, 28, 1, 84, 6, 87, 
    3, 20, 6, 34, 8, 48, 7, 97, 2, 22, 5, 71, 1, 26, 4, 67, 0, 59, 
    6, 41, 0, 87, 5, 47, 7, 89, 1, 56, 3, 73, 4, 68, 8, 14, 2, 13, 
    3, 83, 2, 28, 4, 55, 5, 92, 7, 26, 0, 21, 1, 98, 6, 23, 8, 54
  };
  const int q2181[] = {
    9, 9, // Number of jobs and machines
    3, 96, 1, 52, 8, 71, 5, 57, 0, 61, 2, 16, 4, 11, 7, 73, 6,  6, 
    3, 24, 0,  1, 8, 24, 6, 24, 7, 96, 4, 91, 1, 73, 2, 38, 5, 93, 
    6, 23, 3, 83, 8, 95, 1, 62, 4,  7, 2,  6, 5, 91, 0, 87, 7, 23, 
    5, 47, 2,  6, 3, 38, 1, 24, 7, 34, 6, 29, 4, 91, 8, 55, 0, 99, 
    2, 58, 3, 91, 0, 96, 7, 61, 6, 71, 1, 90, 8, 22, 4, 50, 5, 34, 
    8, 96, 7, 57, 6,  5, 5, 91, 3, 50, 0, 18, 1, 51, 4, 27, 2, 39, 
    3, 52, 1, 55, 8, 31, 4, 97, 6, 95, 0, 31, 2, 23, 7, 33, 5, 79, 
    8, 12, 3, 70, 5,  9, 7, 60, 2, 89, 1, 28, 6, 35, 4, 13, 0, 49, 
    1, 14, 0, 92, 4, 71, 5, 80, 2, 52, 8, 73, 7, 29, 6, 85, 3, 93
  };
  const int q2182[] = {
    9, 9, // Number of jobs and machines
    8, 96, 0,  3, 1, 46, 5, 46, 4,  5, 3, 10, 6, 37, 2, 21, 7, 35, 
    2, 45, 3, 18, 8, 81, 4, 24, 0, 61, 7, 33, 5, 63, 1, 72, 6, 34, 
    2,  2, 7, 61, 3, 73, 6, 15, 4, 82, 0, 35, 8, 87, 5, 39, 1, 34, 
    2, 41, 8, 15, 5, 95, 3, 55, 6, 74, 1, 75, 7, 74, 4, 51, 0, 46, 
    8, 59, 4, 62, 3, 58, 0, 91, 7, 38, 6, 20, 5, 75, 2, 23, 1, 85, 
    2, 68, 7,  1, 0, 50, 3, 74, 6, 91, 5, 33, 4,  3, 1, 22, 8, 62, 
    5, 73, 1, 45, 7, 92, 4, 10, 6, 33, 3, 36, 0, 64, 2, 20, 8, 27, 
    8, 58, 7, 75, 2, 45, 6, 99, 1, 55, 4, 95, 5, 91, 0, 56, 3, 32, 
    5, 83, 3, 54, 7, 68, 1, 45, 0, 69, 4,  2, 2,  8, 6, 98, 8, 27
  };
  const int q2183[] = {
    9, 9, // Number of jobs and machines
    8, 38, 5, 87, 0, 35, 1, 62, 3, 58, 4,  8, 2, 87, 6, 81, 7, 10, 
    0, 70, 8, 77, 5,  8, 1, 45, 2, 15, 7, 43, 3,  8, 4, 24, 6,  7, 
    4, 23, 5, 89, 3, 59, 6, 35, 1, 77, 8, 27, 2, 54, 0, 65, 7, 91, 
    1, 60, 5, 66, 3, 12, 7, 80, 2,  6, 0, 17, 8, 61, 4, 90, 6, 12, 
    1, 16, 0, 42, 4, 51, 6, 33, 3, 25, 2, 87, 8, 65, 7, 93, 5, 55, 
    5, 42, 6, 83, 0, 40, 2, 93, 1, 28, 4, 16, 3, 29, 7, 15, 8, 35, 
    3,  9, 2, 20, 7, 32, 5,  9, 4, 84, 8, 75, 1, 27, 6, 87, 0, 45, 
    5, 36, 0,  8, 4, 68, 7, 66, 8, 87, 6, 13, 1, 80, 3,  3, 2, 29, 
    1, 93, 4, 87, 6, 38, 2, 95, 3, 39, 5, 69, 7, 35, 0, 21, 8, 38
  };
  const int q2184[] = {
    9, 9, // Number of jobs and machines
    1, 36, 6, 77, 4, 61, 0, 30, 2, 36, 3, 23, 7,  1, 5, 56, 8, 60, 
    1, 61, 3, 45, 0, 39, 6, 98, 8, 17, 4, 26, 2, 88, 5,  5, 7, 59, 
    0,  5, 3, 14, 7, 41, 5, 36, 2, 69, 4, 83, 1, 68, 6, 41, 8, 50, 
    3, 42, 8, 76, 2, 55, 5, 64, 7,  1, 1, 36, 6, 61, 0, 57, 4, 86, 
    2, 98, 4,  2, 7, 38, 3, 83, 0, 74, 6, 13, 5, 71, 8, 97, 1, 96, 
    4, 65, 3, 54, 1, 38, 5, 99, 6, 10, 0, 80, 2, 65, 8, 97, 7, 52, 
    3, 58, 0,  4, 2, 16, 7, 40, 1, 12, 4, 94, 6, 87, 8, 18, 5, 30, 
    6,  2, 0, 15, 4, 59, 7, 28, 5, 17, 2, 74, 8, 63, 3, 80, 1, 27, 
    6, 25, 5, 44, 0, 26, 8, 50, 7, 55, 4, 48, 1, 69, 2, 34, 3, 48
  };
  const int q2185[] = {
    9, 9, // Number of jobs and machines
    7, 59, 8, 72, 0, 35, 6, 56, 3, 46, 1, 86, 2, 92, 4, 26, 5, 30, 
    0, 74, 1, 31, 8, 26, 3, 76, 7, 12, 4, 27, 5, 10, 2,  2, 6, 11, 
    4, 11, 6,  3, 5, 70, 3, 79, 7, 74, 8, 35, 2,  4, 1, 15, 0, 45, 
    7, 26, 0, 91, 3, 49, 8, 19, 2, 94, 1, 15, 5, 65, 4, 90, 6, 72, 
    7, 38, 3, 47, 1, 81, 8, 74, 2, 47, 6, 37, 5, 39, 0, 80, 4, 10, 
    5, 49, 7, 93, 2, 57, 4,  4, 0, 20, 8,  4, 1, 19, 6, 89, 3, 63, 
    3, 50, 4, 96, 1, 38, 8, 33, 2, 89, 6, 17, 0, 89, 5, 28, 7,  6, 
    1, 19, 5, 89, 7, 96, 0, 34, 3, 58, 6, 11, 2, 94, 8, 52, 4, 89, 
    2, 52, 7, 57, 6,  2, 1, 35, 8, 68, 3, 26, 4, 40, 5, 43, 0, 30
  };
  const int q2186[] = {
    9, 9, // Number of jobs and machines
    2, 71, 5, 80, 0, 21, 8,  5, 4, 55, 7, 77, 1, 37, 6, 97, 3, 61, 
    3, 35, 0, 94, 4, 60, 5, 14, 7, 92, 6, 52, 2, 45, 1, 14, 8, 55, 
    5, 58, 2, 32, 6, 34, 4, 33, 8, 51, 1, 19, 7, 30, 3, 73, 0, 19, 
    4, 97, 5, 60, 0, 83, 6, 42, 7, 91, 8, 48, 3, 30, 1, 64, 2, 41, 
    6, 14, 2, 62, 3, 36, 7, 29, 0, 89, 8, 92, 4, 34, 5, 39, 1, 72, 
    7, 39, 6, 12, 0, 55, 5,  8, 8, 73, 2,  1, 4, 26, 1, 24, 3,  8, 
    1, 28, 3, 61, 2, 83, 5,  7, 7, 79, 8, 18, 0, 33, 4, 84, 6,  9, 
    1, 82, 0, 87, 7, 77, 3, 62, 2, 44, 6, 95, 8,  6, 4, 28, 5, 84, 
    3, 52, 6, 23, 0, 20, 7, 53, 1, 43, 2, 97, 8, 79, 4, 39, 5, 76
  };
  const int q2187[] = {
    9, 9, // Number of jobs and machines
    5, 19, 8, 45, 2, 29, 1, 50, 0, 79, 3, 40, 7, 86, 4, 47, 6, 43, 
    2, 48, 7, 96, 8, 57, 6, 68, 1,  3, 3, 42, 4, 37, 5,  5, 0, 96, 
    8, 72, 6, 54, 2, 98, 0, 88, 3, 49, 1, 73, 7, 58, 4, 49, 5, 38, 
    7, 76, 5, 72, 6, 49, 2, 75, 3, 73, 0, 42, 4, 12, 1, 46, 8, 18, 
    6, 30, 7, 94, 3, 78, 4, 93, 0, 36, 8,  8, 2, 64, 5,  2, 1,  6, 
    3, 44, 8, 30, 7, 32, 5, 84, 6, 13, 2, 74, 0, 98, 4, 96, 1, 64, 
    5, 12, 4, 72, 2, 47, 3,  1, 8, 61, 7, 13, 6, 34, 0,  3, 1, 92, 
    4, 23, 7, 11, 1, 48, 8, 19, 0, 12, 2, 16, 5, 63, 6, 71, 3, 61, 
    3, 83, 8, 80, 2, 12, 5, 49, 4, 52, 1, 60, 0, 70, 7, 75, 6, 78
  };
  const int q2188[] = {
    9, 9, // Number of jobs and machines
    6, 39, 7,  1, 2, 12, 8, 54, 4, 74, 1, 69, 0, 99, 3, 27, 5, 88, 
    5, 13, 7,  8, 1, 94, 2, 23, 4, 27, 3, 28, 0, 59, 6, 85, 8, 73, 
    1,  8, 8, 21, 5, 23, 7, 35, 2, 79, 0, 89, 4, 12, 3, 62, 6, 95, 
    4, 15, 0, 32, 1, 18, 7, 78, 8, 19, 6, 73, 3, 58, 2, 69, 5,  2, 
    6, 75, 3, 83, 7, 10, 2, 44, 5, 42, 4, 44, 1, 90, 8, 68, 0, 41, 
    2, 88, 3, 23, 1, 48, 7, 82, 6, 85, 0, 52, 5, 40, 8, 58, 4, 81, 
    0, 31, 4, 82, 1, 94, 6, 30, 2, 82, 8,  3, 5, 24, 7, 78, 3, 57, 
    0, 25, 4, 22, 5, 74, 8, 92, 2,  1, 3, 24, 6, 59, 1, 39, 7, 52, 
    6, 95, 0, 98, 2, 13, 5, 16, 4, 86, 3, 24, 1, 15, 7, 62, 8, 49
  };
  const int q2189[] = {
    9, 9, // Number of jobs and machines
    1, 90, 2, 54, 4, 12, 0, 27, 3, 65, 5, 37, 6, 93, 8, 28, 7, 24, 
    8, 55, 3, 12, 0,  5, 6, 46, 1, 31, 7, 67, 5, 50, 2, 91, 4, 62, 
    3, 88, 0, 63, 1, 19, 4, 24, 2, 19, 8, 83, 5, 91, 7,  3, 6, 49, 
    1, 38, 0, 32, 8, 32, 6, 43, 5, 22, 7, 77, 4, 25, 2, 60, 3, 76, 
    7, 76, 5, 89, 2, 44, 6, 89, 0,  9, 1, 21, 4, 70, 3, 38, 8, 80, 
    8, 69, 3, 37, 5, 75, 4,  3, 1, 84, 7, 89, 6, 20, 2, 75, 0, 86, 
    1, 47, 4, 44, 2, 24, 3, 65, 0, 80, 6, 98, 5, 87, 7, 57, 8, 24, 
    4, 42, 7, 27, 0, 75, 3, 17, 5, 30, 8, 21, 1, 60, 2, 38, 6, 70, 
    6, 87, 7, 35, 2, 75, 5, 44, 0, 93, 3, 51, 8, 97, 4, 42, 1, 63
  };
  const int q2190[] = {
    9, 9, // Number of jobs and machines
    4, 38, 2,  4, 1, 47, 0, 53, 3,  6, 6,  3, 8, 44, 7,  8, 5, 92, 
    4, 71, 8, 55, 5, 39, 2, 35, 1, 10, 0, 81, 3, 73, 7, 62, 6,  5, 
    7, 38, 5, 80, 2, 98, 3, 46, 0, 36, 8, 64, 1, 30, 6, 67, 4, 27, 
    7, 56, 2, 45, 1, 22, 5, 80, 4, 49, 6, 22, 3, 63, 0, 56, 8, 81, 
    1, 21, 7, 13, 8, 58, 0, 87, 3, 32, 4, 56, 5, 29, 6, 31, 2, 92, 
    7, 42, 3, 66, 6, 12, 2, 55, 1, 57, 8, 43, 5, 56, 0, 53, 4, 84, 
    5, 47, 0, 41, 2, 35, 4, 57, 6, 36, 1, 23, 8, 53, 3, 23, 7, 86, 
    0, 59, 8,  9, 5, 20, 2, 27, 4, 72, 3, 70, 7, 73, 1, 91, 6, 80, 
    7, 85, 4, 73, 2, 64, 5, 37, 3, 50, 6, 64, 8, 15, 0, 92, 1, 90
  };
  const int q2191[] = {
    9, 9, // Number of jobs and machines
    1, 16, 8, 98, 2, 91, 7, 78, 3,  6, 4, 46, 5, 23, 0, 83, 6, 17, 
    5,  6, 4,  6, 0, 77, 1, 25, 3, 50, 8, 84, 6, 66, 2, 56, 7, 65, 
    4,  3, 6, 12, 7,  9, 2, 58, 0, 18, 3, 23, 5, 11, 8, 30, 1, 94, 
    3, 88, 1, 38, 2, 93, 7, 30, 0, 51, 5, 34, 4, 39, 8,  8, 6,  7, 
    1, 33, 8,  1, 3, 19, 7, 71, 6, 84, 4, 90, 0, 85, 5, 14, 2, 29, 
    2, 64, 6, 12, 8, 86, 0, 49, 7, 83, 4, 35, 3, 70, 1, 95, 5, 84, 
    8,  1, 3, 13, 0, 58, 2, 83, 4, 45, 1, 42, 7, 63, 6, 43, 5, 33, 
    2, 30, 8, 87, 1, 50, 5, 43, 6, 37, 4, 95, 0, 64, 7, 51, 3, 16, 
    3, 87, 2, 85, 1, 65, 6, 44, 5, 67, 7, 56, 4, 78, 8, 30, 0, 27
  };
  const int q2192[] = {
    9, 9, // Number of jobs and machines
    7,  4, 8, 80, 1, 21, 0, 86, 6, 33, 3, 83, 5, 48, 2, 22, 4, 50, 
    5, 31, 8, 18, 0, 85, 3,  2, 4, 73, 2,  6, 1, 29, 6, 11, 7, 84, 
    6, 61, 2, 66, 8, 15, 5, 82, 4, 50, 0, 63, 3, 96, 1, 19, 7, 44, 
    8, 25, 0, 79, 2, 28, 5, 24, 6, 59, 3, 79, 7,  4, 1, 32, 4, 13, 
    3, 38, 4, 92, 0,  9, 1, 44, 7, 72, 8,  1, 2, 43, 6, 60, 5, 15, 
    7, 29, 0, 74, 3, 13, 8, 38, 4, 37, 6,  9, 2, 37, 1, 87, 5, 79, 
    2, 71, 3, 16, 7, 30, 8, 17, 4, 92, 5, 82, 1, 29, 6, 78, 0, 64, 
    3, 30, 8,  3, 5,  5, 4, 12, 0, 16, 1, 13, 6, 87, 7, 67, 2, 39, 
    0, 25, 8, 71, 2, 38, 1,  8, 3, 60, 5, 54, 4, 47, 6, 43, 7, 69
  };
  const int q2193[] = {
    9, 9, // Number of jobs and machines
    1, 10, 2, 93, 6, 35, 8, 66, 0, 29, 3, 82, 4, 26, 5, 51, 7, 64, 
    0,  4, 4, 83, 6, 63, 7, 38, 2, 87, 8, 26, 1, 51, 5, 23, 3, 43, 
    6, 42, 2, 29, 3, 58, 5, 75, 8, 62, 7, 24, 0, 11, 4,  6, 1, 93, 
    4, 62, 8, 80, 2, 25, 3, 80, 7, 56, 6, 37, 5,  4, 1, 67, 0,  6, 
    7, 51, 4, 73, 3, 92, 6, 76, 8, 70, 1,  8, 0, 61, 2, 53, 5, 53, 
    5, 48, 3, 52, 8, 85, 2, 88, 0, 20, 6, 37, 1, 49, 7, 72, 4, 76, 
    3, 79, 5, 84, 1, 78, 7, 16, 4, 50, 8,  6, 2, 36, 0, 53, 6, 23, 
    4, 40, 3, 99, 5, 43, 8, 74, 2, 37, 0, 30, 6, 24, 7, 89, 1, 21, 
    1, 69, 8, 98, 6, 42, 2, 17, 3, 12, 5, 60, 0, 96, 7, 63, 4, 68
  };
  const int q2194[] = {
    9, 9, // Number of jobs and machines
    7, 43, 8,  1, 4, 57, 6, 30, 2, 65, 1, 96, 3, 93, 0, 28, 5,  7, 
    5, 13, 8, 32, 6, 54, 1, 35, 7, 94, 2, 12, 3, 45, 0, 11, 4, 20, 
    4, 21, 0, 45, 7, 76, 2,  4, 5, 66, 8, 47, 1, 89, 3, 10, 6, 74, 
    5,  2, 8, 13, 1, 28, 0, 68, 7, 69, 4, 69, 2, 28, 6, 11, 3, 48, 
    6, 83, 2, 79, 1, 72, 5, 61, 4, 37, 3, 10, 7, 64, 0, 70, 8, 33, 
    5, 80, 3, 29, 6, 26, 7, 49, 2, 26, 0,  5, 4, 61, 8,  4, 1, 20, 
    4, 74, 3, 76, 2,  9, 0, 34, 7, 43, 6, 63, 1, 72, 5, 88, 8, 26, 
    7,  9, 2, 44, 8, 48, 6, 95, 1, 40, 4,  8, 3, 89, 0, 10, 5, 27, 
    7, 45, 8, 56, 0, 27, 6, 23, 3, 85, 5, 89, 4, 39, 2,  2, 1, 21
  };
  const int q2195[] = {
    9, 9, // Number of jobs and machines
    3, 53, 5, 29, 4, 85, 2, 14, 1, 69, 6, 18, 0, 51, 8, 41, 7, 86, 
    8, 95, 1, 91, 4, 16, 7, 67, 2, 26, 3, 51, 6, 81, 0, 92, 5, 13, 
    4, 91, 2, 34, 1, 88, 5, 37, 8, 89, 0, 41, 3, 76, 7, 32, 6, 56, 
    3, 64, 2, 83, 5, 18, 0, 87, 6, 20, 1, 88, 4, 98, 7, 96, 8, 89, 
    2, 41, 0, 69, 3, 73, 6, 29, 7, 82, 5, 20, 4, 97, 1, 30, 8, 40, 
    5, 74, 6, 37, 2, 19, 7, 40, 8, 51, 0, 40, 4, 99, 1, 42, 3, 34, 
    3, 33, 8, 20, 0, 56, 4, 81, 6, 19, 7, 83, 5,  2, 2,  1, 1, 58, 
    3, 36, 8, 32, 4, 57, 7, 42, 2, 89, 1, 80, 5, 38, 6, 79, 0, 61, 
    4, 55, 2, 13, 3, 67, 5, 96, 6, 40, 0, 49, 7, 36, 1, 86, 8, 11
  };
  const int q2196[] = {
    9, 9, // Number of jobs and machines
    3, 73, 5,  5, 6, 34, 2, 15, 7, 73, 4, 33, 1, 84, 0, 86, 8, 68, 
    3, 76, 7, 31, 4,  3, 6, 84, 8, 84, 1, 75, 5, 31, 2, 55, 0,  2, 
    5, 86, 2, 66, 4, 76, 6, 67, 1, 18, 0, 17, 3, 70, 7, 10, 8, 91, 
    3, 11, 1, 57, 8, 29, 0, 41, 6, 95, 5, 74, 7, 42, 4, 97, 2, 96, 
    3, 80, 7, 12, 8, 95, 4, 56, 6, 44, 5,  4, 1, 93, 0, 24, 2, 97, 
    2, 18, 5, 89, 4, 19, 3, 65, 0, 64, 8,  7, 6, 86, 1, 62, 7,  7, 
    6, 85, 3,  1, 5, 37, 1, 50, 2, 73, 7, 37, 0, 68, 8, 99, 4, 80, 
    0, 89, 2, 92, 5, 36, 3, 70, 4, 33, 8, 97, 1, 32, 7, 25, 6, 28, 
    6, 22, 5, 64, 2, 73, 3, 37, 7,  9, 1, 62, 0, 23, 4, 33, 8, 94
  };
  const int q2197[] = {
    9, 9, // Number of jobs and machines
    5, 94, 0, 72, 1,  2, 4, 47, 2,  1, 7,  5, 6, 16, 8, 74, 3, 81, 
    6,  8, 4, 42, 7, 24, 5, 90, 0, 71, 8, 57, 1, 11, 2, 22, 3, 28, 
    0, 10, 4, 42, 7, 37, 5, 56, 1, 66, 6, 14, 8, 75, 2, 48, 3, 96, 
    2, 27, 0,  9, 4, 13, 6, 94, 5, 85, 1, 34, 8, 79, 3, 45, 7,  9, 
    2, 51, 4, 18, 3, 47, 8, 75, 0,  3, 1, 73, 6, 23, 5, 72, 7, 35, 
    5, 46, 4, 73, 0, 24, 7, 47, 6, 34, 8, 36, 2, 76, 3, 66, 1, 76, 
    7, 51, 5,  5, 1, 44, 6, 88, 3, 60, 2, 19, 8, 71, 4, 72, 0, 46, 
    0, 63, 4, 30, 5, 49, 8, 26, 2, 15, 6, 36, 7, 71, 3, 98, 1, 15, 
    7, 74, 2, 30, 1, 44, 3, 62, 8, 43, 5, 45, 0, 92, 6, 14, 4, 12
  };
  const int q2198[] = {
    9, 9, // Number of jobs and machines
    8, 23, 3, 68, 4, 82, 1, 34, 6,  5, 0, 50, 5, 86, 7,  9, 2,  1, 
    0, 21, 6, 20, 2,  9, 1, 32, 5, 97, 3, 23, 7, 38, 8, 94, 4, 36, 
    3,  4, 8, 76, 0, 77, 1, 52, 2,  1, 5, 75, 6, 95, 4, 47, 7, 90, 
    2, 44, 4, 35, 6, 32, 3,  6, 7,  8, 1, 85, 8, 73, 5, 13, 0,  9, 
    4,  5, 8, 50, 7, 69, 1, 40, 3, 78, 6, 51, 5, 34, 0, 76, 2, 36, 
    4, 56, 8, 54, 6, 73, 0, 49, 2, 40, 7, 32, 5, 67, 1, 82, 3, 12, 
    8, 54, 4, 50, 0, 41, 1, 72, 6, 47, 3, 14, 2, 33, 5, 79, 7, 44, 
    4, 36, 1, 86, 2, 88, 6, 93, 0, 27, 3, 17, 5, 62, 8, 72, 7, 41, 
    8, 66, 2, 70, 4, 87, 1, 94, 7, 16, 6, 44, 0, 26, 3, 39, 5, 51
  };
  const int q2199[] = {
    9, 9, // Number of jobs and machines
    8, 10, 0, 15, 4, 41, 1, 88, 7, 84, 3, 55, 6, 16, 2, 93, 5, 75, 
    5, 62, 3, 77, 8,  9, 6, 99, 7, 71, 1,  6, 2, 86, 0, 69, 4, 52, 
    4, 40, 8, 64, 3, 56, 1, 70, 6, 81, 2, 55, 7, 70, 0, 81, 5, 50, 
    5, 91, 8, 47, 6, 74, 0, 72, 4, 34, 7, 25, 2, 96, 3, 69, 1, 49, 
    4, 24, 0,  5, 2, 42, 1, 35, 8, 57, 6, 20, 7, 59, 5, 12, 3, 55, 
    7, 19, 3,  4, 6, 12, 5, 81, 2, 97, 1, 30, 8, 33, 0, 45, 4, 62, 
    2, 58, 6, 70, 4, 96, 3, 81, 0, 91, 8, 52, 5, 21, 1, 34, 7, 32, 
    3, 96, 5, 54, 0, 21, 6, 51, 7, 65, 4, 81, 2, 34, 8, 76, 1, 10, 
    5, 40, 1, 92, 7, 32, 4, 59, 0, 29, 8, 10, 3,  5, 2, 47, 6, 93
  };
  const int q2200[] = {
    9, 9, // Number of jobs and machines
    2, 93, 6, 25, 0, 80, 3, 67, 5, 23, 8, 90, 4, 32, 1, 98, 7, 80, 
    1, 35, 0, 24, 8, 77, 2, 70, 6, 70, 5, 35, 7, 35, 4, 91, 3,  8, 
    7, 69, 1, 78, 6, 60, 2, 34, 3, 85, 4, 58, 8, 85, 5, 44, 0, 42, 
    2, 37, 4, 47, 5, 95, 1, 41, 8, 19, 6, 72, 0, 11, 3, 78, 7, 65, 
    2, 93, 5, 20, 4, 95, 7, 19, 1, 79, 3, 76, 8, 46, 0, 62, 6,  8, 
    7, 49, 5, 67, 0,  5, 8, 85, 1, 56, 2, 53, 4, 63, 3, 47, 6, 37, 
    6, 75, 2, 59, 1, 36, 4, 59, 0, 46, 7,  7, 3, 62, 8, 93, 5, 53, 
    3, 81, 2, 62, 6, 40, 0, 26, 8, 73, 4,  1, 7, 21, 5, 72, 1, 58, 
    6, 44, 2, 45, 5, 48, 4, 36, 3, 80, 8, 85, 7, 21, 1, 26, 0,  6
  };
  const int q2201[] = {
    9, 9, // Number of jobs and machines
    8, 62, 1, 96, 6, 57, 5, 23, 2, 54, 3, 79, 7, 33, 0, 69, 4,  6, 
    0, 85, 1, 79, 2,  8, 3, 92, 6, 51, 4, 68, 5, 24, 8,  2, 7, 95, 
    0, 17, 6, 63, 3, 64, 2, 43, 5, 11, 1, 70, 4, 37, 7, 70, 8, 62, 
    6, 31, 3, 70, 0, 38, 4, 75, 2, 20, 8, 12, 1, 98, 7, 53, 5, 44, 
    1, 90, 4, 10, 5, 90, 8, 30, 2, 20, 3, 57, 7, 91, 0, 95, 6, 47, 
    6,  9, 4, 94, 1, 58, 2, 44, 7, 86, 5, 11, 3, 90, 0, 12, 8, 81, 
    3, 22, 4, 40, 0, 19, 2, 70, 5,  3, 7, 77, 1, 44, 8, 92, 6, 53, 
    4, 98, 8, 10, 7, 82, 1, 31, 6,  7, 3, 62, 5, 16, 0, 22, 2, 70, 
    8,  8, 0, 71, 2, 87, 1, 10, 5,  4, 4, 86, 7, 52, 3, 34, 6, 82
  };
  const int q2202[] = {
    9, 9, // Number of jobs and machines
    8, 54, 2,  5, 4, 18, 5, 63, 0, 32, 6, 43, 3, 20, 1, 54, 7, 11, 
    8, 58, 3, 36, 4, 59, 1, 31, 5,  7, 7, 58, 0, 68, 2, 65, 6, 20, 
    8,  8, 0,  2, 1, 52, 7, 54, 3, 92, 4, 60, 2, 94, 6, 81, 5,  3, 
    6, 50, 4, 17, 1, 51, 8, 67, 5, 49, 0, 15, 2, 91, 3, 14, 7, 55, 
    8,  1, 0, 21, 6, 49, 3, 95, 5, 87, 7, 73, 1,  2, 4, 30, 2, 50, 
    4,  3, 1, 14, 5, 88, 6, 45, 2, 88, 3, 67, 0, 25, 8, 65, 7, 26, 
    4, 57, 8, 21, 3, 16, 6, 70, 1, 21, 5, 20, 0, 46, 2, 24, 7, 23, 
    2,  6, 5, 87, 4, 37, 6, 65, 1, 65, 8, 36, 3, 76, 0, 85, 7, 27, 
    1, 34, 0, 57, 7, 27, 6, 39, 2, 68, 4, 21, 5, 27, 8, 92, 3, 89
  };
  const int q2203[] = {
    9, 9, // Number of jobs and machines
    7, 87, 5, 48, 6, 29, 0, 90, 4, 50, 2, 13, 1, 38, 3, 55, 8, 36, 
    8, 94, 1, 66, 6, 46, 3, 68, 2, 10, 5, 43, 7, 75, 4, 59, 0, 77, 
    0, 66, 4, 23, 5,  3, 1, 57, 3, 92, 7, 95, 8, 58, 2, 47, 6, 15, 
    3,  7, 7, 16, 5, 79, 2, 26, 4, 67, 1, 91, 8, 97, 6, 68, 0, 42, 
    2, 72, 7, 19, 4, 23, 0, 62, 3, 33, 8, 33, 1, 59, 6, 80, 5, 32, 
    1, 49, 2, 81, 0, 32, 7, 26, 8, 50, 4, 14, 6, 36, 5, 45, 3, 15, 
    3, 94, 2, 65, 6, 70, 0, 90, 8, 10, 7, 34, 4,  5, 5, 38, 1, 99, 
    0, 46, 7, 73, 2,  5, 4, 29, 3, 42, 8, 29, 6, 62, 5, 26, 1,  5, 
    8, 43, 5, 51, 6, 90, 1, 71, 0, 95, 7, 61, 4, 30, 3, 64, 2, 48
  };
  const int q2204[] = {
    9, 9, // Number of jobs and machines
    1, 70, 2, 64, 7, 99, 0,  8, 4, 83, 3, 44, 8, 76, 5, 41, 6, 61, 
    6, 97, 7, 69, 2, 80, 8, 34, 3, 59, 1, 33, 5, 35, 0,  7, 4, 84, 
    6, 84, 1, 30, 5, 24, 2, 81, 7,  4, 0, 43, 8, 84, 3, 31, 4, 56, 
    8, 66, 1, 51, 0, 96, 7,  7, 4, 39, 3, 86, 2, 58, 6, 64, 5, 41, 
    4, 33, 2,  9, 1, 25, 7, 14, 0, 47, 3, 50, 8, 39, 6, 43, 5, 97, 
    3, 64, 4, 62, 8, 87, 1, 45, 6, 90, 0, 17, 5, 92, 2, 94, 7, 27, 
    3, 38, 0, 22, 7, 59, 4, 45, 8, 48, 1, 47, 2, 15, 5, 13, 6, 84, 
    1, 64, 0, 64, 3, 73, 8, 46, 6, 26, 2,  1, 7, 75, 5, 19, 4, 44, 
    6, 25, 2, 17, 5, 80, 4, 78, 1, 29, 3, 37, 0, 96, 7, 32, 8, 23
  };
  const int q2205[] = {
    9, 9, // Number of jobs and machines
    3, 81, 8, 90, 0,  4, 5,  1, 1, 89, 4, 32, 6, 86, 7, 64, 2, 96, 
    7, 42, 2, 22, 8, 88, 6, 14, 0, 92, 4, 13, 5, 50, 3, 10, 1, 70, 
    6, 47, 7, 90, 3, 39, 1, 40, 5, 26, 0, 60, 8, 81, 4, 48, 2, 41, 
    6, 72, 1, 21, 4, 79, 0, 81, 3, 94, 2,  2, 7,  1, 5, 77, 8, 69, 
    5, 69, 1,  1, 4, 38, 3, 60, 2, 34, 7, 97, 8, 94, 6, 18, 0, 15, 
    2, 72, 8, 97, 1, 51, 4, 27, 3, 74, 6, 62, 7, 65, 5, 17, 0, 40, 
    6, 30, 7, 48, 3, 52, 8, 57, 0, 80, 1, 49, 4, 56, 2, 53, 5, 19, 
    3, 83, 1, 79, 2, 73, 5, 44, 4, 66, 0, 68, 6, 78, 8, 61, 7, 98, 
    2, 79, 1, 27, 3, 19, 4, 98, 6,  2, 5, 26, 7, 41, 0, 67, 8,  5
  };
  const int q2206[] = {
    9, 9, // Number of jobs and machines
    8, 29, 6, 72, 3, 42, 5, 32, 0, 60, 2, 43, 4, 88, 7, 65, 1, 51, 
    2, 20, 0, 34, 8, 44, 3, 94, 4, 88, 5, 30, 1, 30, 6, 68, 7, 45, 
    5, 79, 1, 80, 2, 82, 0, 57, 3, 94, 8, 36, 4, 76, 7, 61, 6, 98, 
    5, 20, 7, 57, 8, 91, 6, 36, 4, 80, 3,  3, 0, 99, 2, 32, 1, 63, 
    5, 76, 3, 47, 6, 32, 8, 61, 2, 39, 1, 96, 7,  1, 4, 33, 0, 18, 
    0, 97, 4, 10, 5, 63, 3, 55, 8, 41, 6, 90, 1, 99, 7, 59, 2, 75, 
    8, 47, 4, 38, 2, 97, 1, 63, 3, 52, 0, 92, 5, 75, 6, 70, 7, 58, 
    4, 61, 5, 77, 7, 81, 0, 66, 3, 73, 8, 15, 1, 19, 2, 72, 6, 99, 
    7, 35, 8, 24, 0, 74, 2, 96, 4, 52, 5, 58, 1, 58, 3, 70, 6, 60
  };
  const int q2207[] = {
    9, 9, // Number of jobs and machines
    4,  9, 1, 63, 6, 79, 5, 96, 2, 64, 8, 91, 0, 63, 3, 17, 7, 86, 
    6, 27, 3, 30, 0, 81, 4, 55, 8, 31, 7, 45, 2, 45, 5, 22, 1, 93, 
    5, 81, 0, 93, 8, 35, 3, 23, 7, 25, 1, 81, 4, 80, 6, 80, 2, 46, 
    0, 47, 4, 53, 8, 11, 7, 72, 6, 25, 3, 58, 1, 70, 2, 65, 5, 66, 
    5, 24, 7, 42, 3, 99, 6, 11, 2,  2, 8, 33, 0, 73, 4, 95, 1, 21, 
    6, 35, 1, 28, 4, 21, 8, 33, 2, 34, 3, 48, 0, 87, 7, 35, 5, 17, 
    4, 25, 3, 94, 8, 89, 2, 91, 0, 50, 1, 87, 7, 14, 6, 15, 5,  9, 
    3, 24, 4,  7, 8, 92, 2, 71, 7, 20, 6, 18, 5, 57, 0, 10, 1, 99, 
    7, 30, 1, 36, 2, 68, 4, 92, 8, 77, 3, 91, 6, 10, 5, 63, 0, 75
  };
  const int q2208[] = {
    9, 9, // Number of jobs and machines
    1, 50, 0,  1, 5, 95, 2, 32, 4, 70, 3, 30, 7, 36, 8, 33, 6, 94, 
    2, 75, 0, 82, 6, 69, 8,  4, 1, 63, 4, 50, 3, 12, 5, 13, 7, 40, 
    2, 29, 3, 74, 8, 27, 1, 25, 4,  7, 7, 97, 5, 95, 0, 55, 6,  9, 
    4, 35, 8, 95, 2, 52, 3, 47, 0, 72, 5, 14, 6, 79, 1, 66, 7, 88, 
    5, 19, 6, 64, 7, 58, 8, 19, 0, 70, 2, 78, 1, 28, 3,  3, 4, 93, 
    6, 77, 7, 42, 0, 51, 5, 60, 8, 40, 3, 99, 2, 44, 1, 44, 4, 64, 
    0, 13, 4,  7, 6, 95, 3, 87, 5, 26, 8, 30, 1, 79, 2, 33, 7, 59, 
    5, 46, 4, 82, 8,  8, 3, 22, 1, 33, 6, 75, 0, 92, 7, 88, 2, 56, 
    2, 66, 5, 88, 1, 84, 4, 57, 8, 20, 6, 75, 7, 30, 0, 71, 3, 57
  };
  const int q2209[] = {
    9, 9, // Number of jobs and machines
    0, 54, 6, 35, 4, 72, 7, 88, 1, 51, 2, 86, 3, 35, 8, 37, 5, 49, 
    8, 94, 1, 74, 2, 69, 0, 57, 6, 10, 7, 65, 5, 99, 4, 59, 3, 64, 
    6,  7, 7,  4, 8, 48, 5, 70, 4, 53, 2, 53, 0, 21, 3, 77, 1, 11, 
    6, 57, 5, 76, 8,  2, 0, 88, 7, 58, 3,  8, 2, 30, 1, 82, 4, 52, 
    2, 77, 7, 72, 0, 59, 5, 92, 1, 91, 4, 59, 3, 59, 6, 44, 8, 11, 
    0, 88, 4, 43, 5,  1, 6, 77, 3, 64, 1, 65, 2, 58, 8, 74, 7,  2, 
    6, 99, 0, 60, 5, 99, 3, 22, 1, 64, 2, 32, 7, 23, 4, 82, 8, 27, 
    4, 28, 1, 23, 8, 13, 0, 79, 6, 68, 7, 52, 3, 60, 2, 24, 5, 92, 
    0, 61, 2, 95, 7, 43, 5, 63, 4, 96, 1, 45, 3, 38, 6, 63, 8, 64
  };
  const int q2210[] = {
    9, 9, // Number of jobs and machines
    0, 93, 7, 36, 8, 44, 4, 78, 2, 96, 5, 66, 1,  1, 6, 66, 3, 17, 
    7, 15, 3, 93, 6, 11, 0, 30, 8, 90, 2, 19, 5, 24, 4, 21, 1, 85, 
    2, 29, 4,  7, 6, 58, 7, 61, 3, 27, 1, 70, 0, 79, 5, 25, 8,  3, 
    5, 88, 6, 55, 8, 73, 1, 34, 3, 88, 0, 16, 7, 75, 2, 59, 4, 22, 
    1, 47, 4, 71, 0, 44, 7, 24, 2, 25, 8, 68, 6, 91, 5, 65, 3, 45, 
    2, 62, 3, 71, 5, 74, 0, 45, 1, 25, 7, 87, 4, 71, 6, 21, 8,  8, 
    3,  5, 1, 64, 8, 93, 7,  8, 5, 14, 2, 30, 4, 49, 0,  6, 6, 93, 
    5, 37, 1,  9, 4, 48, 2, 51, 0, 25, 6, 74, 8, 71, 7, 97, 3, 98, 
    0, 86, 7, 63, 6, 87, 1, 52, 3, 88, 8, 68, 4, 40, 2, 18, 5, 23
  };
  const int q2211[] = {
    9, 9, // Number of jobs and machines
    1, 96, 0, 25, 8, 80, 4,  9, 6, 66, 2,  8, 7, 85, 5, 68, 3, 30, 
    2, 81, 7, 74, 4, 97, 3, 80, 0, 94, 8, 50, 1, 22, 5, 48, 6, 45, 
    1, 72, 6, 33, 2, 86, 8, 67, 4, 20, 0, 32, 7, 44, 3, 34, 5,  3, 
    4, 61, 0, 82, 8, 18, 5, 98, 1, 26, 2, 73, 6, 17, 7, 22, 3, 26, 
    5, 24, 7, 49, 4, 25, 0, 58, 8, 83, 3, 18, 2, 49, 1, 68, 6, 52, 
    2, 90, 3, 33, 8, 46, 6, 54, 0, 46, 1, 16, 4, 64, 5, 18, 7,  2, 
    8, 13, 0, 17, 3, 65, 6, 38, 4, 57, 5, 98, 7, 31, 1, 63, 2, 79, 
    8, 15, 1, 58, 0, 45, 7, 13, 4, 13, 2,  6, 5, 81, 3, 92, 6,  6, 
    1, 84, 5, 97, 7, 23, 3, 70, 6, 25, 4, 66, 2, 22, 0, 58, 8, 24
  };
  const int q2212[] = {
    9, 9, // Number of jobs and machines
    6, 50, 1, 24, 3, 31, 5, 29, 8, 63, 4, 24, 7, 20, 2, 78, 0, 52, 
    0,  9, 6, 10, 4, 39, 7, 24, 1,  2, 3, 84, 5, 13, 8, 53, 2, 38, 
    2, 69, 0, 23, 6, 44, 8, 37, 5, 31, 1, 73, 4, 94, 7, 10, 3, 65, 
    4, 34, 0, 35, 7, 73, 6, 92, 1, 67, 8, 92, 2, 61, 3, 11, 5, 56, 
    6, 95, 5, 47, 7, 66, 0, 25, 4, 42, 2, 92, 3, 54, 8, 34, 1, 33, 
    4, 63, 7, 82, 3, 56, 2, 82, 1,  6, 6, 36, 5, 75, 8, 39, 0, 95, 
    4, 88, 2, 94, 7, 43, 1, 72, 0, 34, 3, 42, 6, 30, 5,  3, 8, 60, 
    4, 15, 0, 32, 5,  9, 8, 53, 1, 28, 3, 42, 6, 38, 7, 21, 2, 69, 
    3, 27, 8, 50, 7, 42, 2, 61, 0, 73, 5, 40, 1, 45, 4, 30, 6, 93
  };
  const int q2213[] = {
    9, 9, // Number of jobs and machines
    3, 40, 4, 95, 6, 34, 5,  8, 8, 27, 1, 95, 7,  4, 2, 93, 0, 60, 
    1, 23, 6, 91, 0, 67, 5, 68, 8, 39, 3, 40, 7, 12, 4, 96, 2, 53, 
    5,  5, 0, 50, 1, 72, 6, 90, 2, 31, 3, 89, 7, 52, 8, 32, 4, 28, 
    8, 82, 4, 26, 6, 66, 1, 59, 7, 63, 5, 29, 2, 24, 0, 37, 3, 75, 
    6, 89, 4, 84, 1, 77, 2, 17, 0, 13, 7, 31, 8, 83, 5, 86, 3, 53, 
    7, 46, 2, 32, 6, 47, 0, 49, 1, 90, 8, 60, 5, 47, 4,  8, 3, 45, 
    0, 39, 2, 41, 5, 18, 1, 87, 7, 78, 4, 20, 6, 30, 8, 14, 3, 41, 
    3, 46, 0, 14, 6, 26, 5,  9, 1, 29, 4,  3, 8, 55, 7, 38, 2, 35, 
    0, 11, 6, 61, 5, 62, 2, 19, 7, 35, 8,  3, 3,  5, 4, 89, 1, 42
  };
  const int q2214[] = {
    9, 9, // Number of jobs and machines
    0, 71, 1, 36, 6, 46, 5, 66, 3, 82, 2, 41, 8, 16, 7, 61, 4, 54, 
    6, 85, 0, 38, 4, 45, 1, 42, 2, 96, 3, 56, 7, 32, 8, 42, 5, 51, 
    2,  1, 0, 94, 3, 90, 7, 99, 4, 72, 8, 51, 1, 26, 5, 54, 6, 99, 
    1, 24, 5, 85, 4, 16, 0, 94, 7, 85, 8, 95, 3, 61, 2, 56, 6, 52, 
    0, 94, 5,  3, 7, 18, 6, 80, 8, 41, 1, 20, 2, 88, 4, 29, 3, 29, 
    2, 39, 1, 58, 6, 89, 0, 86, 8, 99, 4, 69, 5, 83, 3,  4, 7, 74, 
    4, 66, 0, 22, 2, 29, 3, 74, 8, 16, 1, 92, 5, 48, 6, 72, 7,  8, 
    8, 99, 2, 56, 7, 12, 6, 11, 0, 65, 1, 49, 5, 96, 4, 11, 3, 81, 
    3, 23, 0, 95, 4, 41, 2, 71, 8, 32, 5, 45, 7, 93, 1, 70, 6, 75
  };
  const int q2215[] = {
    9, 9, // Number of jobs and machines
    2,  8, 5, 30, 1,  9, 0, 66, 8, 65, 7, 94, 4, 19, 3, 40, 6, 60, 
    0, 22, 5, 82, 4, 79, 7, 45, 1, 93, 6, 74, 3, 77, 2, 81, 8, 29, 
    5, 49, 7, 18, 4,  6, 6, 67, 8, 60, 0, 82, 3, 83, 2, 50, 1,  1, 
    2, 28, 1, 98, 3, 46, 0, 83, 8, 30, 4, 89, 5, 36, 6, 79, 7, 27, 
    1, 54, 7, 57, 3, 56, 2, 64, 8, 71, 4, 42, 0, 96, 5, 27, 6,  2, 
    6, 59, 1, 40, 3, 95, 4, 97, 5, 10, 2, 87, 7, 50, 8, 40, 0, 66, 
    8,  9, 0, 42, 7, 40, 2, 34, 6, 61, 5, 20, 3, 92, 1, 52, 4,  2, 
    5, 86, 7, 13, 4, 82, 0, 86, 6, 53, 2, 93, 1, 24, 8, 41, 3, 68, 
    3, 37, 0, 17, 7, 83, 8, 45, 4, 88, 5, 98, 6, 77, 2, 76, 1, 41
  };
  const int q2216[] = {
    9, 9, // Number of jobs and machines
    5, 65, 7, 54, 8, 13, 6, 83, 2,  1, 3, 45, 4, 87, 1, 94, 0, 32, 
    6, 55, 0, 39, 8, 69, 5, 92, 4, 90, 3, 20, 1, 46, 2, 46, 7, 57, 
    6, 18, 0, 80, 2, 80, 1, 51, 8, 79, 4, 33, 3, 28, 5,  4, 7, 85, 
    1,  6, 2, 15, 0, 95, 7, 31, 5, 76, 8, 11, 6, 36, 4, 24, 3, 99, 
    3, 33, 1, 12, 5, 64, 8, 75, 6, 89, 0, 85, 7, 80, 4, 65, 2, 79, 
    2, 33, 5, 96, 0, 36, 4, 81, 7, 75, 8, 76, 1, 86, 3, 76, 6, 18, 
    0, 37, 2, 62, 6, 71, 8, 76, 7,  3, 4, 86, 5, 66, 1,  1, 3, 55, 
    6, 75, 4, 49, 0, 29, 2, 84, 3, 59, 1, 98, 5, 15, 7, 82, 8, 89, 
    1, 35, 7, 43, 4, 43, 8, 26, 6,  4, 5, 25, 3, 34, 0, 46, 2, 29
  };
  const int q2217[] = {
    9, 9, // Number of jobs and machines
    0, 87, 1, 55, 7, 67, 2, 19, 8, 66, 4, 95, 5, 22, 3, 75, 6, 86, 
    5, 13, 3,  6, 2, 25, 0, 69, 7,  1, 6, 78, 8, 31, 1, 66, 4, 23, 
    3, 33, 4, 91, 2,  5, 5, 66, 6, 15, 7, 52, 0, 64, 8, 77, 1, 91, 
    2,  2, 6, 59, 7, 29, 3, 17, 8, 11, 4, 41, 1, 56, 5, 24, 0, 49, 
    5, 91, 1,  9, 8,  6, 4, 98, 6, 61, 3,  1, 2, 58, 0, 65, 7, 49, 
    3, 56, 5, 88, 7, 21, 1, 15, 4, 99, 8, 53, 2, 95, 6, 62, 0, 53, 
    8, 54, 0,  1, 4, 18, 5, 51, 3, 84, 6,  1, 1, 60, 2,  6, 7, 50, 
    4, 54, 8, 97, 1,  7, 6, 37, 5, 98, 7, 49, 2, 23, 0, 30, 3, 38, 
    5,  6, 6, 67, 4, 72, 7, 91, 0,  1, 3, 24, 2, 55, 1, 98, 8, 32
  };
  const int q2218[] = {
    9, 9, // Number of jobs and machines
    2, 38, 3, 93, 5, 26, 6,  3, 7, 97, 4, 34, 0, 37, 8,  5, 1, 25, 
    0, 53, 3, 45, 1, 89, 6, 82, 7, 19, 4, 72, 5, 97, 8, 31, 2, 86, 
    5, 45, 3, 66, 4, 85, 0, 78, 6, 11, 1, 79, 8, 31, 7,  2, 2, 44, 
    4, 37, 3, 53, 5, 34, 6, 68, 0, 60, 2, 14, 1, 85, 8, 93, 7, 10, 
    1, 18, 6, 56, 3, 72, 8, 28, 4, 22, 2, 31, 5, 24, 0, 64, 7, 44, 
    5, 13, 1, 85, 4,  3, 7, 72, 2, 97, 3, 97, 8, 12, 0,  7, 6, 41, 
    6, 81, 8,  9, 0, 45, 5, 52, 2, 25, 4, 17, 1, 78, 7, 31, 3, 36, 
    8, 94, 4, 80, 1, 31, 3, 86, 7, 57, 6, 13, 2, 85, 0, 40, 5, 24, 
    0, 89, 4, 52, 8, 81, 7, 92, 1, 85, 5, 68, 2, 71, 6, 63, 3, 92
  };
  const int q2219[] = {
    9, 9, // Number of jobs and machines
    2, 55, 0, 12, 7, 85, 6, 16, 3, 85, 1, 60, 8, 24, 4,  4, 5, 65, 
    2, 87, 8, 38, 3, 78, 5, 25, 7, 73, 6, 10, 0,  8, 1, 55, 4, 42, 
    8, 50, 3, 12, 0, 66, 6, 46, 7, 17, 5,  1, 2, 23, 1, 52, 4, 25, 
    4, 53, 0, 72, 1, 75, 8, 56, 6, 24, 2, 30, 7, 31, 5, 59, 3, 45, 
    5, 66, 8, 49, 0, 97, 6, 73, 7, 10, 4,  5, 3, 65, 1, 55, 2, 36, 
    2, 32, 4, 67, 8,  7, 7, 25, 5, 93, 6,  9, 0, 27, 1, 86, 3, 95, 
    4, 48, 1, 72, 3, 57, 5, 67, 0, 26, 7, 13, 2, 31, 6, 35, 8, 20, 
    3, 99, 2, 30, 0, 55, 5,  6, 7, 15, 6, 27, 8, 28, 4, 28, 1, 46, 
    1, 83, 4, 68, 7, 13, 6, 42, 5, 81, 0, 26, 8, 38, 2, 88, 3, 48
  };
  const int q2220[] = {
    9, 9, // Number of jobs and machines
    3, 35, 7, 10, 5, 97, 8, 46, 2, 92, 4, 98, 1, 42, 0, 56, 6, 53, 
    6, 34, 3, 61, 2, 42, 5, 82, 8, 60, 4, 59, 0, 56, 7, 41, 1, 41, 
    0, 71, 4, 58, 8, 90, 7, 56, 2, 51, 3, 74, 6, 86, 1, 21, 5, 98, 
    5, 56, 2, 89, 8, 61, 4, 22, 0, 65, 7, 75, 3, 65, 6, 37, 1, 74, 
    0, 60, 3, 36, 4, 53, 1, 48, 2, 58, 8, 45, 5, 47, 7, 81, 6,  5, 
    7, 25, 4,  7, 1, 67, 0, 10, 3, 36, 5, 52, 6, 43, 8, 61, 2, 58, 
    1, 60, 0, 91, 2,  7, 6, 84, 5, 97, 3, 74, 8, 70, 7, 44, 4, 92, 
    1, 21, 5, 33, 2, 54, 7,  5, 8, 27, 6, 57, 4, 93, 0, 10, 3, 19, 
    5, 72, 3, 80, 1, 83, 0, 68, 8, 76, 4, 33, 7,  1, 6, 34, 2, 54
  };
  const int q2221[] = {
    9, 9, // Number of jobs and machines
    8,  1, 4, 42, 3, 84, 5, 60, 6, 63, 2, 50, 0, 39, 7,  3, 1,  1, 
    4, 30, 0, 13, 6, 82, 1, 93, 5, 56, 2, 46, 8, 32, 7, 38, 3, 44, 
    7, 56, 0, 18, 2, 64, 1, 77, 3,  9, 5, 49, 8,  6, 6, 29, 4, 60, 
    1, 71, 2, 99, 3, 21, 0, 35, 6, 36, 7, 13, 8, 37, 5, 42, 4, 15, 
    4, 33, 8,  6, 7, 23, 3,  5, 0, 68, 1, 82, 6, 97, 2, 69, 5, 84, 
    0, 45, 2, 74, 7, 61, 6, 77, 5, 58, 4, 83, 1, 54, 8, 33, 3, 53, 
    0, 86, 6, 44, 1, 41, 8, 96, 4, 16, 3, 51, 2, 17, 5, 21, 7, 91, 
    3, 37, 1, 63, 2, 52, 8, 37, 4, 84, 0,  7, 7, 34, 6, 38, 5, 31, 
    2, 98, 0, 40, 8, 29, 5, 79, 7, 28, 3, 45, 6, 92, 1, 25, 4, 64
  };
  const int q2222[] = {
    9, 9, // Number of jobs and machines
    0, 66, 3, 65, 1, 75, 4, 21, 5, 83, 7, 44, 2, 27, 6, 13, 8, 30, 
    2, 23, 4, 48, 8, 55, 0, 19, 7, 80, 6, 54, 1, 49, 3, 23, 5, 27, 
    4, 96, 1, 32, 3, 45, 7, 15, 8,  5, 0, 62, 2, 46, 6, 27, 5, 56, 
    6, 88, 5, 35, 3, 77, 7, 22, 8,  3, 4, 11, 2, 43, 1,  6, 0, 39, 
    4, 72, 6, 26, 8, 87, 1, 78, 3, 10, 7, 48, 2, 73, 5, 59, 0, 17, 
    5, 43, 3, 23, 2, 57, 1, 67, 0, 70, 4, 27, 6, 95, 7, 76, 8, 86, 
    8, 81, 7, 28, 1,  2, 6, 40, 4, 15, 3, 69, 0,  9, 2,  9, 5, 30, 
    4, 53, 8, 86, 5, 11, 0, 72, 3, 52, 6, 55, 7, 48, 2, 38, 1,  9, 
    1, 58, 5, 86, 6, 39, 7, 78, 4, 58, 3, 21, 8, 89, 0, 81, 2, 33
  };
  const int q2223[] = {
    9, 9, // Number of jobs and machines
    3, 11, 7,  2, 8, 19, 6, 12, 2, 83, 1, 42, 4, 74, 0, 50, 5, 84, 
    7, 76, 8, 43, 5, 40, 2, 85, 1, 59, 6, 53, 3, 32, 4, 45, 0, 13, 
    7, 47, 4, 42, 2, 14, 1, 72, 0, 85, 3, 64, 5, 44, 6, 16, 8, 63, 
    4, 62, 3, 87, 5, 12, 6, 52, 7, 58, 0, 52, 2, 74, 1, 63, 8, 58, 
    2, 86, 1, 74, 6, 86, 5, 29, 0,  1, 8, 26, 4, 86, 7, 32, 3, 98, 
    4, 51, 5, 51, 3, 36, 8, 69, 7, 68, 2, 25, 6,  1, 1, 60, 0, 98, 
    1, 22, 0, 73, 2, 95, 6,  3, 7, 88, 8, 24, 3, 62, 5, 24, 4, 75, 
    2, 12, 7,  3, 0, 99, 8, 99, 1, 20, 5, 41, 4, 10, 6, 36, 3, 78, 
    0,  7, 5, 27, 3, 58, 8, 33, 2, 43, 7, 84, 6, 24, 1, 16, 4, 71
  };
  const int q2224[] = {
    9, 9, // Number of jobs and machines
    8, 30, 2, 60, 7,  8, 3, 83, 6, 50, 1, 30, 0, 37, 5, 11, 4, 43, 
    2, 75, 0, 86, 1, 22, 7, 33, 8, 47, 5, 97, 3, 47, 4, 47, 6, 29, 
    6, 91, 1, 25, 2, 64, 7, 71, 0, 66, 4, 24, 8, 17, 5, 53, 3, 90, 
    4,  2, 5, 37, 2, 97, 0, 98, 7, 54, 3, 29, 1, 88, 8, 36, 6, 91, 
    1,  8, 7, 46, 0, 52, 2, 16, 5, 63, 8, 19, 3,  7, 4, 46, 6, 18, 
    4, 34, 5, 31, 0, 73, 6, 14, 7, 92, 3, 98, 8, 40, 2, 90, 1, 57, 
    5, 75, 7, 64, 1, 84, 8,  2, 3, 21, 6,  1, 2, 72, 4, 77, 0, 49, 
    3, 59, 7, 87, 6,  6, 5, 24, 8, 72, 2, 55, 0, 67, 1, 74, 4, 43, 
    8, 30, 4, 84, 7, 41, 5, 59, 6, 31, 0, 85, 1, 26, 3, 76, 2, 39
  };
  const int q2225[] = {
    9, 9, // Number of jobs and machines
    7, 17, 6,  9, 0, 81, 3, 87, 5, 46, 1, 16, 2, 21, 4, 92, 8, 51, 
    3, 59, 7, 96, 4, 56, 1, 41, 2, 14, 0, 91, 6, 43, 8, 82, 5, 90, 
    7, 15, 2, 80, 4, 29, 8, 30, 1,  1, 3, 10, 6, 50, 0, 50, 5, 56, 
    0, 59, 5, 13, 4, 47, 3, 64, 2, 96, 1, 60, 7, 38, 6, 18, 8, 72, 
    1, 99, 8, 43, 2,  6, 5,  8, 6, 33, 3, 42, 4, 88, 0, 70, 7, 18, 
    0, 63, 1, 59, 3, 56, 7, 33, 8, 77, 5, 67, 6, 72, 4, 67, 2, 94, 
    5, 72, 2, 56, 7, 28, 8, 86, 0, 70, 4,  3, 3,  2, 1, 72, 6,  9, 
    7, 37, 4, 13, 3, 90, 2, 71, 0, 22, 1, 58, 8, 45, 5, 80, 6, 15, 
    6, 43, 1, 10, 4, 61, 3, 83, 2, 81, 5, 96, 8, 88, 7,  2, 0, 43
  };
  const int q2226[] = {
    9, 9, // Number of jobs and machines
    3, 86, 8, 41, 1, 61, 4, 85, 2, 97, 0, 45, 5, 81, 6, 84, 7, 70, 
    6, 62, 1, 20, 7, 39, 0, 64, 2, 44, 5, 37, 4, 41, 3, 64, 8, 52, 
    2, 56, 3, 41, 1,  6, 6, 33, 5, 72, 7,  7, 0, 75, 4,  5, 8, 40, 
    4, 37, 1,  7, 3, 44, 5, 55, 7,  2, 0,  5, 6, 49, 2, 77, 8, 43, 
    1, 25, 6, 61, 2, 36, 4, 14, 3, 67, 5, 46, 0, 67, 8, 55, 7, 75, 
    2, 25, 0, 94, 7, 31, 4, 25, 5,  4, 1,  8, 8, 33, 3, 89, 6, 64, 
    7, 14, 6, 90, 4, 18, 3, 81, 5, 86, 2, 34, 8, 98, 0, 53, 1, 95, 
    5, 93, 3, 95, 2, 62, 0, 21, 4, 67, 8, 46, 6, 44, 7, 87, 1, 29, 
    6, 57, 1, 95, 2, 55, 8, 66, 4, 37, 7, 93, 3, 34, 0, 10, 5, 64
  };
  const int q2227[] = {
    9, 9, // Number of jobs and machines
    2,  5, 3, 71, 5, 88, 0, 67, 6, 63, 4, 51, 7, 25, 1, 18, 8, 51, 
    0, 64, 4, 15, 7, 21, 6, 48, 8, 38, 3, 51, 2, 64, 5, 86, 1, 65, 
    8, 42, 4, 63, 2, 95, 3, 84, 6, 72, 1, 57, 0, 19, 5, 35, 7, 10, 
    2, 53, 0, 11, 3, 60, 8, 78, 1, 35, 6, 10, 4, 46, 7, 43, 5, 77, 
    0, 33, 1, 23, 7, 55, 8,  6, 2, 94, 4, 49, 3, 11, 5, 34, 6, 52, 
    6, 46, 7, 83, 1, 40, 5, 97, 4, 67, 2, 27, 8, 86, 3, 66, 0, 77, 
    2, 14, 3, 87, 6, 63, 8, 81, 0, 88, 7, 64, 4, 77, 5, 65, 1, 46, 
    1, 30, 4, 81, 7,  8, 0, 16, 2, 90, 5, 69, 8, 51, 6, 16, 3, 77, 
    1, 83, 6,  4, 2, 83, 8, 87, 3, 31, 4, 91, 5, 49, 7, 67, 0, 59
  };
  const int q2228[] = {
    9, 9, // Number of jobs and machines
    3, 39, 4,  5, 6, 41, 0, 26, 5,  5, 1, 31, 8, 98, 2, 66, 7, 31, 
    2, 24, 5, 72, 6, 97, 1, 96, 3, 63, 0, 13, 8, 16, 7, 38, 4, 36, 
    6, 35, 8, 59, 7, 58, 3, 86, 1, 52, 4, 79, 5, 17, 2, 48, 0, 87, 
    1, 59, 6, 63, 0, 91, 5, 83, 4, 89, 3, 75, 7, 16, 2, 27, 8, 83, 
    3, 45, 2, 11, 8, 83, 4, 51, 6, 95, 5, 25, 1, 72, 0, 30, 7, 35, 
    6, 12, 1,  7, 8, 88, 2, 44, 5, 84, 3, 62, 0, 47, 4,  4, 7, 85, 
    8, 34, 6, 68, 5, 28, 1, 15, 7,  3, 4, 35, 3, 98, 2, 45, 0, 96, 
    7, 66, 6, 63, 1, 85, 4, 21, 2, 34, 5, 64, 0, 39, 8, 80, 3, 79, 
    3, 25, 6, 30, 1, 64, 0, 72, 4, 48, 7, 38, 2, 22, 5, 81, 8, 59
  };
  const int q2229[] = {
    9, 9, // Number of jobs and machines
    8, 35, 5, 57, 4, 72, 7, 14, 1, 59, 6, 39, 0, 12, 2, 86, 3, 29, 
    6, 97, 5,  1, 7, 86, 4, 35, 8, 91, 0, 15, 2, 81, 3, 58, 1, 68, 
    4, 51, 2, 11, 1, 10, 8, 99, 0, 14, 5, 37, 6,  4, 3, 75, 7, 17, 
    0,  6, 5, 53, 8, 84, 7, 74, 6, 94, 1, 57, 3, 38, 2, 13, 4, 62, 
    0, 19, 6, 41, 7, 34, 5, 26, 2, 13, 4, 61, 8, 95, 1, 88, 3, 32, 
    8, 55, 7, 62, 2, 59, 4, 96, 1, 16, 5, 86, 6,  6, 3,  7, 0, 94, 
    4, 14, 5,  3, 6, 19, 1, 27, 8, 80, 7, 57, 3, 16, 2, 43, 0, 46, 
    4, 91, 1, 47, 7, 87, 5, 73, 8, 63, 2,  9, 0, 93, 3, 21, 6, 30, 
    6, 38, 8, 16, 5, 40, 1, 49, 4,  2, 0, 46, 7, 72, 3, 69, 2, 39
  };
  const int q2230[] = {
    9, 9, // Number of jobs and machines
    4, 87, 3, 43, 8, 88, 5, 22, 0, 48, 7, 44, 6, 17, 2, 26, 1, 19, 
    2, 42, 8, 72, 7, 10, 5,  2, 6, 10, 4, 19, 1, 45, 3, 13, 0, 54, 
    3, 77, 7, 87, 6, 50, 4, 57, 5, 82, 1, 74, 2, 80, 0, 41, 8, 28, 
    4, 92, 3, 13, 6, 42, 0, 18, 1, 80, 5, 79, 7, 49, 8,  3, 2, 79, 
    6,  3, 0, 29, 8, 80, 3,  5, 1, 50, 5, 15, 2, 47, 4, 60, 7, 48, 
    1, 10, 0, 97, 7, 41, 2, 70, 5,  3, 8, 36, 4, 73, 3, 28, 6, 41, 
    1, 52, 6, 77, 3, 49, 7, 56, 0, 24, 2, 73, 5, 41, 4, 41, 8, 76, 
    5, 54, 3, 50, 6, 22, 8, 94, 7, 66, 4, 50, 2, 55, 1, 84, 0, 56, 
    0, 84, 6, 41, 3, 93, 2, 40, 7, 59, 4, 14, 1, 20, 5, 95, 8, 15
  };
  const int q2231[] = {
    9, 9, // Number of jobs and machines
    8, 71, 2, 29, 4, 19, 3, 78, 5,  7, 7, 78, 6, 61, 1, 16, 0, 76, 
    8, 57, 3, 58, 7, 25, 6, 18, 4, 26, 0, 84, 2, 89, 1, 69, 5, 82, 
    3, 51, 7, 20, 5, 47, 2, 20, 0, 88, 6, 23, 8, 83, 1, 32, 4,  5, 
    2, 47, 7, 15, 5, 83, 8, 87, 0,  1, 4, 42, 6, 57, 1, 28, 3, 23, 
    4,  9, 6, 95, 2, 70, 8, 79, 3, 38, 5, 97, 0, 90, 7,  4, 1, 55, 
    7, 71, 6, 43, 2, 88, 4, 78, 3, 35, 1, 91, 0, 19, 8, 42, 5, 36, 
    5, 54, 8, 63, 1, 24, 0, 57, 7, 81, 4, 11, 3, 14, 2, 97, 6, 40, 
    3, 61, 1, 36, 6, 53, 4, 94, 0, 90, 2, 44, 8,  2, 7, 10, 5, 14, 
    3, 86, 6,  3, 2, 19, 4, 44, 1, 45, 0, 48, 8, 37, 5, 75, 7, 78
  };
  const int q2232[] = {
    9, 9, // Number of jobs and machines
    0, 34, 7,  9, 6, 17, 5, 78, 4,  4, 3, 15, 8, 59, 2, 11, 1, 41, 
    0, 91, 7, 23, 2,  7, 3, 11, 5, 88, 1, 73, 8, 85, 6, 89, 4,  4, 
    3, 61, 4, 38, 1, 58, 7,  6, 2, 82, 5, 74, 6, 49, 8, 16, 0, 76, 
    0, 96, 1, 41, 5, 58, 4, 61, 3, 33, 2, 67, 8, 28, 7, 14, 6, 21, 
    1, 73, 6, 88, 8, 32, 4, 31, 0, 41, 7, 79, 5, 47, 2, 55, 3, 98, 
    4, 25, 2, 86, 8, 77, 7, 99, 3, 86, 6, 85, 0, 90, 1, 84, 5, 34, 
    1, 69, 3, 29, 8, 94, 4, 64, 5, 60, 0, 55, 6, 82, 2, 75, 7,  4, 
    1, 36, 2, 46, 4, 27, 7, 60, 8, 84, 6, 64, 5, 73, 0, 74, 3,  8, 
    1, 55, 3, 61, 0, 64, 7, 38, 8, 25, 5, 33, 4, 39, 2, 60, 6, 29
  };
  const int q2233[] = {
    9, 9, // Number of jobs and machines
    2, 41, 8, 47, 6, 28, 1, 53, 4, 62, 7, 69, 3, 60, 5, 34, 0, 34, 
    5, 59, 8,  4, 6, 79, 2, 14, 0, 66, 3,  9, 1, 79, 7, 37, 4, 90, 
    7, 73, 4, 86, 1, 77, 2, 70, 3, 91, 6, 43, 5, 92, 8, 42, 0, 35, 
    6, 81, 8, 35, 1, 37, 4, 96, 3, 46, 0, 75, 5, 95, 7,  2, 2, 87, 
    1, 98, 0, 32, 5, 13, 7, 54, 2, 12, 4, 62, 6, 39, 3, 21, 8, 70, 
    4, 61, 0, 75, 1,  3, 7, 12, 2, 74, 6, 49, 5, 78, 3, 70, 8, 80, 
    0, 13, 6, 80, 2, 97, 3, 99, 5,  2, 8, 11, 7, 25, 1, 15, 4, 48, 
    2, 48, 7, 69, 3, 52, 1, 36, 5, 67, 4, 96, 0, 73, 6, 89, 8, 37, 
    7, 88, 0, 76, 3, 72, 8, 47, 6, 72, 4, 38, 2, 25, 1, 22, 5, 90
  };
  const int q2234[] = {
    9, 9, // Number of jobs and machines
    8, 48, 1, 70, 3, 60, 0,  1, 7, 47, 4, 49, 6,  5, 5, 23, 2, 74, 
    1, 79, 7, 49, 4, 91, 0, 51, 6, 62, 2, 10, 8, 91, 3, 38, 5, 43, 
    6, 63, 0, 41, 4, 85, 3, 69, 7, 42, 2, 54, 1, 18, 8, 40, 5, 77, 
    5, 36, 6, 59, 4, 21, 2, 67, 7, 78, 8, 18, 3, 75, 0,  6, 1, 51, 
    7, 28, 2, 38, 6, 10, 8, 89, 3,  5, 4, 29, 5, 15, 1, 28, 0, 65, 
    8, 77, 2, 33, 7, 58, 5, 31, 1, 60, 3, 75, 0, 59, 6, 69, 4, 52, 
    2, 15, 3, 13, 7, 70, 4, 65, 1, 66, 0, 34, 6, 92, 5, 63, 8, 68, 
    3, 76, 1, 81, 5, 52, 8, 15, 4, 56, 0, 90, 6, 23, 7, 95, 2, 15, 
    2, 77, 8, 51, 0, 31, 6, 82, 1, 63, 4, 12, 5, 20, 7, 69, 3, 65
  };
  const int q2235[] = {
    9, 9, // Number of jobs and machines
    7, 44, 6, 99, 2, 98, 4, 69, 5, 59, 8, 26, 3, 91, 0, 88, 1, 37, 
    6, 92, 2, 94, 7, 55, 5, 62, 3, 52, 8, 71, 1, 84, 0, 99, 4, 95, 
    7, 18, 3, 76, 8, 43, 6, 83, 4, 18, 2, 76, 5, 56, 1, 33, 0, 45, 
    3, 12, 5, 57, 8, 66, 1, 88, 2,  9, 0,  6, 7, 46, 4, 39, 6, 85, 
    4, 41, 0, 28, 5, 88, 2, 39, 6, 94, 7, 63, 8, 78, 1, 42, 3, 47, 
    7, 55, 2, 98, 1, 47, 6, 26, 4, 35, 0, 92, 3, 96, 5, 10, 8, 99, 
    6, 73, 2, 10, 3,  4, 0, 60, 4, 92, 5, 19, 7, 98, 8, 67, 1, 80, 
    7, 82, 3, 86, 8, 17, 5,  5, 4, 57, 0, 79, 2, 38, 1, 41, 6, 95, 
    5, 94, 0, 27, 2, 28, 8, 91, 6, 50, 4, 84, 3, 20, 1, 31, 7, 35
  };
  const int q2236[] = {
    9, 9, // Number of jobs and machines
    2,  5, 5, 96, 3, 46, 0, 44, 1, 26, 4, 11, 6, 18, 7, 25, 8, 93, 
    4, 83, 7, 82, 8, 53, 6, 71, 3, 54, 0, 72, 1, 82, 5, 50, 2, 87, 
    8, 16, 4,  1, 6, 17, 0, 98, 2, 89, 3, 43, 1, 98, 7, 74, 5, 19, 
    5, 75, 4, 28, 2, 53, 7, 63, 3, 20, 0, 60, 1, 44, 8, 46, 6, 45, 
    8, 92, 7, 15, 3, 41, 1, 77, 2, 98, 4, 15, 5, 29, 0, 89, 6, 53, 
    3, 20, 2, 81, 0, 90, 5, 93, 1, 28, 4, 79, 6, 97, 8,  7, 7, 74, 
    5, 51, 1, 27, 2, 38, 6, 19, 3, 62, 8, 14, 7, 33, 4,  5, 0, 22, 
    8, 52, 2, 97, 5, 47, 1, 17, 7, 79, 6,  9, 3, 56, 4, 52, 0,  5, 
    6,  1, 0, 39, 5, 93, 1, 92, 8, 29, 7, 46, 3, 74, 4, 78, 2,  6
  };
  const int q2237[] = {
    9, 9, // Number of jobs and machines
    5, 40, 7, 51, 0, 12, 6, 98, 4, 70, 8, 70, 3,  8, 1, 74, 2, 14, 
    5,  9, 7, 47, 2,  4, 6, 18, 0, 84, 4, 23, 3, 59, 1, 63, 8, 34, 
    7, 62, 8,  9, 6, 57, 3,  9, 1, 70, 5, 21, 4, 61, 0, 56, 2, 28, 
    4, 33, 6, 39, 8, 33, 3, 43, 1, 26, 2, 58, 0, 69, 5, 98, 7, 21, 
    2, 87, 5, 52, 1,  7, 7, 85, 3, 81, 6, 81, 8, 56, 0, 61, 4, 93, 
    1, 30, 6, 48, 5, 69, 0, 62, 3, 48, 8, 77, 4, 75, 7, 68, 2, 52, 
    1, 67, 7, 64, 4, 38, 3, 87, 5, 19, 8,  4, 0, 79, 6, 61, 2, 91, 
    3, 36, 7, 25, 5, 36, 6, 87, 1, 58, 4, 55, 8, 90, 2, 56, 0, 57, 
    2, 83, 4, 42, 5, 42, 1, 78, 8, 31, 6, 70, 7, 91, 0, 23, 3, 91
  };
  const int q2238[] = {
    9, 9, // Number of jobs and machines
    1, 90, 8, 24, 6, 85, 2, 16, 3, 92, 7, 63, 5, 60, 0, 42, 4, 69, 
    1, 83, 0, 13, 2, 62, 7, 96, 3, 27, 8, 15, 6, 72, 5, 48, 4, 87, 
    6, 89, 1, 82, 2, 24, 5, 48, 7, 15, 0, 24, 8, 93, 4, 80, 3, 93, 
    3, 17, 1, 91, 0, 54, 4, 81, 5, 17, 7, 64, 2, 70, 8, 64, 6, 78, 
    1, 46, 8, 64, 4, 39, 6, 21, 7, 24, 2, 53, 0, 94, 5, 73, 3, 46, 
    2, 85, 5, 23, 8, 84, 0, 42, 6, 12, 4, 86, 7, 21, 1, 16, 3, 43, 
    3, 84, 2, 41, 7, 75, 6, 67, 1, 42, 0, 50, 5, 92, 8, 38, 4, 59, 
    0, 49, 3,  4, 6, 29, 5, 90, 2, 48, 7, 33, 1, 31, 4, 20, 8, 29, 
    3, 49, 1, 58, 0, 26, 2, 11, 6, 41, 5, 54, 8, 90, 4, 67, 7, 32
  };
  const int q2239[] = {
    9, 9, // Number of jobs and machines
    5, 53, 2, 87, 4, 26, 8,  2, 1, 71, 7, 66, 6, 20, 0, 37, 3, 19, 
    8, 92, 1, 41, 7, 70, 0, 85, 5, 78, 3, 57, 6, 51, 2, 46, 4, 73, 
    4, 72, 8, 23, 7, 44, 0, 19, 6, 40, 5, 45, 3, 26, 1, 68, 2, 88, 
    1, 48, 6, 77, 3, 86, 5, 78, 2, 64, 7, 19, 4, 41, 0,  5, 8, 55, 
    3, 30, 6, 72, 5, 30, 1, 65, 7,  2, 8, 11, 0, 15, 2, 80, 4, 90, 
    1, 44, 0, 88, 4, 41, 8, 25, 2, 26, 5,  1, 3, 18, 7, 31, 6, 34, 
    3, 72, 2, 57, 1, 91, 6, 20, 8, 95, 5, 18, 4, 32, 7, 26, 0, 60, 
    0, 63, 2, 19, 5, 20, 7, 33, 3, 34, 1, 96, 4, 64, 6, 63, 8, 43, 
    8, 13, 6, 17, 3, 56, 7, 10, 1, 36, 4, 10, 0, 33, 5, 30, 2, 18
  };
  const int q2240[] = {
    9, 9, // Number of jobs and machines
    5, 33, 7, 32, 4, 15, 3, 80, 6, 53, 8, 18, 0, 71, 2, 71, 1, 34, 
    6, 61, 8, 60, 1, 81, 2, 70, 4, 78, 0, 86, 7, 81, 3, 19, 5, 76, 
    0, 89, 4,  1, 2, 18, 3, 67, 8, 50, 1, 85, 5, 41, 7, 18, 6, 43, 
    0, 16, 1, 51, 4, 33, 8, 32, 3, 83, 6, 76, 7, 35, 2, 63, 5, 85, 
    6, 16, 1, 45, 4, 36, 7, 20, 0, 66, 8, 13, 3, 40, 5, 60, 2, 12, 
    7, 50, 2, 11, 8, 86, 3, 65, 5, 27, 1,  6, 4, 53, 6, 61, 0, 73, 
    8, 99, 0, 76, 5, 72, 7,  3, 3, 27, 6, 22, 1,  8, 2, 58, 4, 75, 
    0, 96, 4, 81, 7, 69, 6, 60, 1,  3, 2, 58, 3, 76, 8, 82, 5, 46, 
    5, 58, 1, 49, 4,  4, 3, 27, 7, 65, 8, 99, 0,  5, 6,  3, 2, 51
  };
  const int q2241[] = {
    9, 9, // Number of jobs and machines
    4, 46, 5, 20, 0, 30, 6, 15, 3, 89, 2, 44, 8, 56, 7, 11, 1, 56, 
    0, 25, 6, 23, 1,  5, 3, 16, 7, 20, 2, 60, 8, 92, 4, 43, 5, 14, 
    3,  4, 1, 87, 8, 71, 6, 61, 4, 17, 5, 56, 7, 60, 0, 27, 2, 92, 
    2, 40, 8, 50, 6, 64, 7, 95, 3, 66, 0, 10, 4, 54, 5,  8, 1, 66, 
    6, 44, 3,  6, 7, 37, 1, 86, 0, 56, 5, 35, 2, 82, 4, 92, 8, 98, 
    0, 56, 1, 32, 7,  5, 4,  5, 6, 64, 5, 16, 3, 55, 2, 55, 8,  3, 
    8, 77, 6, 22, 5, 85, 4, 12, 7, 56, 1, 52, 0, 44, 2, 28, 3, 11, 
    2, 82, 7, 12, 0, 69, 4, 59, 1, 35, 6, 84, 5, 45, 3,  5, 8, 56, 
    6, 68, 1, 88, 5, 37, 4, 90, 2, 72, 3, 22, 8, 14, 7, 41, 0, 12
  };
  const int q2242[] = {
    9, 9, // Number of jobs and machines
    5,  8, 0, 10, 6, 82, 7, 70, 3, 64, 8, 74, 1, 39, 4, 27, 2,  7, 
    3, 23, 2, 73, 1, 24, 8, 66, 7, 21, 6, 88, 0, 32, 4, 57, 5, 66, 
    0, 38, 3, 92, 6, 38, 5, 54, 2, 67, 1, 77, 4, 70, 8, 73, 7, 40, 
    6, 92, 7, 55, 0, 24, 8, 68, 3, 49, 5, 31, 2, 97, 1, 96, 4, 56, 
    8, 60, 1, 43, 2, 23, 3, 53, 5,  9, 7, 65, 4, 93, 6, 87, 0, 47, 
    7, 77, 3, 74, 1, 74, 8, 14, 4, 59, 0,  9, 2, 89, 6,  9, 5, 93, 
    6, 64, 3, 92, 4, 86, 8,  3, 2, 72, 5, 97, 0, 65, 7, 46, 1, 21, 
    3, 87, 1, 74, 4, 36, 5, 43, 7, 86, 6, 82, 2, 44, 0,  7, 8, 65, 
    4, 22, 7, 26, 8, 56, 0, 86, 1, 46, 3, 26, 5, 37, 6, 38, 2, 12
  };
  const int q2243[] = {
    9, 9, // Number of jobs and machines
    2, 45, 7, 24, 3, 87, 5, 54, 6, 62, 4, 29, 0, 77, 8, 76, 1, 38, 
    3, 65, 6, 39, 5, 71, 8, 76, 1,  6, 7, 54, 0, 57, 2, 90, 4, 40, 
    5, 49, 1, 99, 3, 22, 7, 98, 0,  9, 4, 85, 2, 23, 8, 75, 6, 55, 
    1, 31, 7, 49, 3, 22, 0, 99, 2, 17, 5, 42, 8, 53, 6, 56, 4, 28, 
    4, 77, 7,  9, 6,  3, 2, 99, 0, 89, 3, 66, 8, 13, 1, 89, 5, 73, 
    2, 96, 7, 38, 1, 95, 3, 61, 0, 77, 5, 85, 4, 28, 8, 76, 6, 88, 
    2,  7, 4,  6, 5, 62, 7,  9, 3, 26, 1,  6, 0, 49, 6, 98, 8, 48, 
    1, 84, 7, 21, 3, 99, 8, 44, 6, 57, 4, 40, 0, 38, 5, 79, 2, 51, 
    0, 73, 2, 15, 6, 24, 1, 30, 8, 72, 7, 67, 3, 83, 4, 42, 5, 29
  };
  const int q2244[] = {
    9, 9, // Number of jobs and machines
    5, 97, 3, 68, 0, 88, 8, 28, 2,  7, 1, 80, 4, 92, 7, 22, 6, 73, 
    3, 72, 5,  1, 0, 35, 6, 87, 4, 68, 1, 14, 7, 21, 2, 56, 8, 23, 
    3, 19, 8, 38, 1, 18, 7, 67, 4, 25, 2, 16, 5, 37, 6, 20, 0, 52, 
    6,  3, 0, 28, 3, 23, 4, 14, 2, 52, 5, 59, 1,  1, 7, 27, 8, 24, 
    8, 33, 2, 79, 3, 74, 5, 34, 7,  2, 4, 59, 6,  5, 0, 79, 1, 33, 
    4, 28, 0, 28, 2, 30, 6, 84, 3, 37, 7, 64, 8, 94, 5, 46, 1, 40, 
    8, 62, 4, 92, 7, 29, 0, 69, 3,  1, 5, 95, 6, 19, 1,  6, 2, 27, 
    0, 72, 4, 75, 6, 29, 8, 23, 2, 91, 7,  8, 3, 66, 5,  8, 1, 10, 
    2, 68, 7, 23, 5, 96, 6, 92, 8, 99, 1, 54, 3, 28, 0, 51, 4, 21
  };
  const int q2245[] = {
    9, 9, // Number of jobs and machines
    4, 30, 1, 78, 2, 94, 7, 23, 3, 82, 0, 38, 6, 98, 5, 20, 8, 65, 
    5,  1, 7, 59, 2, 35, 4, 80, 3, 11, 1, 92, 6, 38, 8, 24, 0, 57, 
    0, 47, 1, 76, 3, 24, 6, 21, 8, 30, 5, 26, 7, 15, 4, 67, 2, 53, 
    4, 20, 1, 73, 2, 88, 8, 56, 3, 30, 5, 12, 0, 92, 7, 26, 6, 34, 
    2, 55, 8, 81, 0, 64, 3, 52, 5, 39, 4, 57, 1, 41, 7, 26, 6, 85, 
    6, 83, 7, 72, 0, 72, 5,  3, 4, 78, 8, 14, 3, 85, 1, 86, 2, 28, 
    4, 51, 0, 14, 5, 40, 2,  4, 7, 71, 3, 40, 8, 61, 6, 63, 1, 90, 
    0, 25, 4, 47, 6, 71, 8, 10, 1, 39, 2, 61, 3, 78, 7, 40, 5, 42, 
    7, 51, 2, 11, 4, 24, 8, 29, 3, 30, 1, 21, 5, 75, 6, 18, 0, 31
  };
  const int q2246[] = {
    9, 9, // Number of jobs and machines
    1, 27, 5, 43, 0, 33, 6, 60, 3, 12, 7, 25, 4, 44, 8, 11, 2, 45, 
    1, 51, 8, 15, 2, 83, 6, 49, 7, 56, 5, 10, 3, 52, 0, 45, 4, 71, 
    6, 74, 1, 66, 8, 35, 3, 90, 0, 19, 5,  1, 4, 29, 7, 59, 2, 41, 
    1, 62, 4, 65, 3,  8, 6, 30, 8, 79, 7, 55, 2, 20, 0, 92, 5, 63, 
    7, 51, 3, 76, 5, 64, 2, 38, 1, 72, 8, 93, 6, 71, 4, 70, 0, 47, 
    5, 22, 0, 74, 2, 57, 7, 74, 8, 82, 1, 40, 4, 75, 6, 45, 3, 17, 
    5, 14, 7, 80, 3, 65, 6, 24, 4, 71, 0, 81, 8, 80, 1, 88, 2, 28, 
    0, 14, 6, 89, 2, 39, 4, 27, 1,  7, 7, 85, 5, 10, 3, 90, 8, 56, 
    6, 50, 8, 73, 4, 43, 7, 77, 5, 37, 3, 65, 0, 86, 1, 36, 2, 68
  };
  const int q2247[] = {
    9, 9, // Number of jobs and machines
    5, 94, 6, 29, 7, 65, 3, 18, 1, 63, 4, 79, 0, 31, 8,  6, 2, 44, 
    1, 47, 5, 95, 6, 98, 0,  4, 2, 61, 8, 73, 4, 81, 3, 30, 7, 49, 
    5, 92, 0, 85, 3, 31, 4, 98, 1, 89, 2, 82, 7, 40, 8, 83, 6, 99, 
    8, 97, 0, 16, 4, 73, 3, 10, 7, 95, 5, 12, 6, 16, 1, 16, 2, 49, 
    2, 23, 5, 22, 7, 93, 6, 53, 4, 87, 0, 77, 1, 86, 8, 20, 3, 13, 
    1, 24, 7,  5, 5, 99, 0, 99, 3, 37, 8,  4, 4, 23, 2, 97, 6, 68, 
    0, 59, 6, 47, 2, 94, 8, 46, 4, 94, 5, 90, 7, 25, 3,  4, 1, 26, 
    4, 12, 8, 90, 7,  1, 5, 93, 2, 24, 1, 98, 0, 40, 6, 92, 3, 60, 
    1, 62, 7, 77, 2, 64, 0, 72, 3, 50, 6, 75, 5, 63, 4, 25, 8, 84
  };
  const int q2248[] = {
    9, 9, // Number of jobs and machines
    1, 90, 8, 24, 2, 65, 5, 71, 0,  7, 4, 74, 7, 63, 3, 64, 6, 39, 
    7, 59, 5, 50, 1, 20, 8, 25, 4, 27, 6, 72, 3, 30, 0,  7, 2, 90, 
    0,  6, 5, 70, 6, 37, 2, 71, 8, 96, 4, 84, 3, 41, 7, 16, 1, 69, 
    5,  6, 0, 73, 1, 86, 6, 68, 2, 45, 8,  7, 4, 34, 7,  8, 3, 47, 
    0, 50, 4, 91, 7, 74, 8, 53, 6, 51, 3, 29, 2, 40, 1, 34, 5, 63, 
    5,  8, 2, 31, 4, 98, 0, 39, 6, 21, 3, 64, 1, 55, 8, 43, 7, 84, 
    2, 12, 8, 76, 0, 64, 6, 46, 4, 42, 5, 22, 7, 96, 3, 27, 1, 82, 
    1, 87, 4, 86, 6,  3, 7, 89, 2, 51, 5, 75, 8, 46, 0, 36, 3, 71, 
    6, 67, 8,  7, 2, 44, 1, 30, 3, 32, 7, 62, 5, 57, 4, 23, 0, 25
  };
  const int q2249[] = {
    9, 9, // Number of jobs and machines
    6, 49, 8, 52, 7, 58, 0, 90, 1, 51, 5, 11, 2, 57, 3, 70, 4, 44, 
    3, 24, 2, 36, 8, 78, 0, 88, 6, 37, 5, 84, 1, 31, 7, 44, 4, 46, 
    3, 27, 0,  5, 4, 41, 8, 97, 1, 90, 6, 70, 2, 37, 5, 34, 7, 20, 
    0, 10, 7, 83, 2, 33, 6, 33, 1, 96, 3,  7, 4, 35, 8, 76, 5, 40, 
    7, 83, 1, 96, 6, 93, 5, 86, 0, 49, 3, 83, 4, 64, 2, 81, 8, 77, 
    6, 61, 3, 11, 2, 51, 5, 43, 8, 71, 0, 62, 4,  5, 7, 89, 1, 83, 
    2, 72, 7, 54, 6,  2, 1, 60, 5, 12, 0, 73, 4, 25, 3, 55, 8, 41, 
    7, 90, 6, 44, 3, 83, 1, 88, 8, 95, 5,  2, 2, 41, 0, 22, 4, 47, 
    6, 56, 7, 27, 8, 31, 1, 60, 4, 79, 3, 74, 2, 78, 5, 61, 0, 86
  };
  const int q2250[] = {
    9, 9, // Number of jobs and machines
    5, 82, 4, 33, 8, 53, 1, 45, 3, 96, 7, 39, 0, 60, 2, 31, 6, 46, 
    0, 30, 8, 34, 3, 26, 2, 57, 4, 59, 5, 23, 6, 61, 1, 96, 7, 21, 
    6, 53, 5, 50, 0, 98, 4, 53, 3, 96, 8, 33, 2, 73, 7,  6, 1, 15, 
    7, 46, 0, 36, 8, 19, 4, 42, 1, 18, 5, 59, 2, 18, 3, 84, 6, 67, 
    3,  9, 5, 56, 1, 18, 6, 43, 7, 46, 4, 46, 2, 93, 8, 20, 0, 95, 
    5, 90, 1, 91, 6, 98, 3, 57, 8, 68, 2, 89, 7, 76, 0, 91, 4, 65, 
    5, 10, 7, 46, 8, 24, 3,  5, 1, 83, 4, 74, 0, 47, 2,  9, 6, 59, 
    3,  7, 6, 84, 8, 47, 7, 11, 1, 86, 5, 19, 4, 80, 0, 82, 2, 30, 
    4, 59, 5, 73, 7, 79, 0, 50, 1, 54, 8, 68, 6, 67, 3, 27, 2, 50
  };
  const int q2251[] = {
    9, 9, // Number of jobs and machines
    0,  5, 8, 14, 6, 23, 2, 71, 3, 85, 5, 29, 7, 31, 4, 86, 1,  9, 
    2, 35, 7, 33, 0, 88, 3, 56, 4, 73, 1, 45, 8, 24, 5, 99, 6, 35, 
    2, 86, 1, 24, 7, 59, 6, 20, 3, 87, 5, 93, 4, 87, 0, 16, 8, 84, 
    5, 31, 8, 67, 4, 48, 3, 31, 1, 13, 0, 20, 6,  1, 2, 46, 7, 25, 
    0, 36, 1, 94, 8,  7, 2, 86, 4, 71, 3,  6, 7, 71, 5, 47, 6, 25, 
    0, 11, 6, 94, 8, 76, 7, 88, 5, 20, 2, 96, 4, 44, 3, 85, 1, 70, 
    6, 86, 5, 53, 0, 27, 2,  6, 7, 72, 8, 83, 1, 71, 3, 38, 4, 31, 
    8, 26, 0, 79, 7, 34, 6, 22, 4,  5, 5, 56, 2,  5, 3, 82, 1,  4, 
    7, 97, 4, 79, 5, 25, 8, 99, 0, 86, 6, 38, 1, 98, 2, 70, 3, 73
  };
  const int q2252[] = {
    9, 9, // Number of jobs and machines
    5, 45, 8, 40, 4, 72, 6, 29, 7,  7, 2, 19, 3, 65, 0, 65, 1, 42, 
    3, 20, 4, 88, 2, 96, 8, 23, 6, 65, 0, 40, 5, 41, 7, 66, 1, 51, 
    2, 48, 7, 16, 4, 21, 0, 73, 3, 62, 5, 71, 8, 33, 1, 30, 6, 14, 
    1, 27, 3, 35, 2, 35, 6, 97, 4,  3, 7, 38, 5, 89, 0, 61, 8, 32, 
    1, 73, 4, 23, 8, 48, 7, 49, 6, 59, 3, 45, 5, 31, 2, 41, 0, 30, 
    2, 67, 7, 94, 5, 43, 6, 93, 1, 82, 3, 95, 4, 24, 0, 82, 8, 41, 
    6, 21, 1, 41, 4, 53, 5, 53, 0, 56, 7, 34, 3, 76, 2, 78, 8, 57, 
    4, 38, 5, 86, 2, 83, 3,  4, 1, 35, 7, 55, 8, 91, 6, 30, 0, 29, 
    8, 81, 7, 24, 4, 24, 5, 44, 1, 63, 3, 39, 0, 83, 6, 88, 2, 56
  };
  const int q2253[] = {
    9, 9, // Number of jobs and machines
    4, 19, 7, 89, 5,  2, 6, 11, 0, 64, 8, 69, 3, 57, 2, 73, 1, 29, 
    1, 78, 7,  1, 5, 12, 3, 24, 4, 61, 0, 44, 8, 64, 2, 82, 6, 61, 
    3, 63, 7, 99, 2, 10, 1, 57, 4, 26, 5,  7, 6,  2, 8, 32, 0, 46, 
    0, 69, 6,  9, 5, 61, 3, 30, 1,  6, 2, 63, 7, 95, 8, 44, 4, 30, 
    4,  6, 8, 74, 3, 16, 7, 96, 0, 61, 5, 57, 1, 13, 6, 48, 2, 80, 
    5, 79, 7, 14, 4, 25, 6, 24, 0, 35, 3, 77, 2, 77, 8, 71, 1, 73, 
    3, 86, 2, 65, 4, 59, 8, 51, 5, 94, 6, 72, 1, 10, 7, 23, 0, 31, 
    6, 79, 1, 30, 7, 73, 4, 79, 0, 57, 8, 11, 2, 30, 3, 98, 5, 73, 
    2, 47, 6,  6, 5, 49, 7, 89, 4, 66, 0, 70, 8, 16, 3, 50, 1, 95
  };
  const int q2254[] = {
    9, 9, // Number of jobs and machines
    5, 11, 0, 37, 7, 78, 4, 50, 3, 40, 1,  6, 2, 50, 8, 82, 6,  6, 
    4, 35, 8, 45, 7, 70, 2, 49, 5, 80, 6, 98, 1, 22, 0, 22, 3, 34, 
    5, 10, 0, 16, 2, 65, 6, 94, 4, 19, 1, 83, 8, 76, 3, 15, 7, 79, 
    7, 17, 1, 88, 8, 98, 5, 89, 0, 97, 3, 13, 2, 37, 4, 50, 6, 35, 
    3, 52, 2, 80, 0, 79, 1,  8, 7, 34, 5,  9, 8,  6, 4, 24, 6, 93, 
    4, 52, 7, 29, 6, 88, 0, 13, 2, 27, 5, 50, 8,  2, 1, 28, 3, 94, 
    8, 43, 0, 10, 2, 74, 7,  5, 5, 64, 6, 12, 1, 84, 4, 36, 3, 76, 
    5, 12, 7, 10, 1, 44, 2,  5, 4, 53, 0, 26, 3, 66, 6, 11, 8, 40, 
    7,  5, 4,  7, 3, 33, 6,  3, 1, 55, 5, 15, 8, 25, 2, 26, 0, 85
  };
  const int q2255[] = {
    9, 9, // Number of jobs and machines
    0, 23, 6, 89, 3, 77, 1, 10, 8,  8, 4, 19, 7, 15, 2,  9, 5,  4, 
    6,  7, 2, 74, 7, 43, 5, 35, 4, 72, 0, 34, 8, 63, 1,  5, 3,  6, 
    4, 45, 5, 67, 8, 49, 7, 36, 0, 39, 2,  8, 3, 98, 1, 75, 6, 74, 
    7, 45, 4, 64, 1, 25, 0, 31, 5, 30, 3, 72, 6, 21, 2, 33, 8, 59, 
    4, 54, 7, 60, 6,  7, 1, 28, 8,  4, 0, 71, 3, 10, 2, 36, 5, 45, 
    7, 84, 6, 70, 5, 45, 2, 30, 3, 20, 0, 72, 8, 94, 4, 22, 1, 25, 
    0, 34, 3, 40, 5, 87, 8, 30, 7, 85, 4, 78, 2,  3, 1, 54, 6, 30, 
    5, 38, 4, 48, 3, 71, 1, 31, 2, 10, 0, 81, 7, 89, 6, 97, 8, 65, 
    8, 46, 2, 70, 0, 67, 7,  3, 5, 28, 6, 53, 3, 22, 4, 47, 1, 16
  };
  const int q2256[] = {
    9, 9, // Number of jobs and machines
    0, 43, 4, 56, 1, 99, 2,  5, 5, 17, 8, 96, 6, 94, 7, 91, 3, 98, 
    3, 65, 2, 55, 4, 61, 1, 72, 8, 80, 5, 26, 7, 51, 0, 26, 6, 91, 
    7, 59, 6, 58, 2, 53, 3, 78, 8, 67, 1, 54, 5, 15, 0, 92, 4, 58, 
    3, 72, 8, 64, 5, 92, 6, 99, 4, 22, 0, 73, 1, 50, 2, 71, 7, 45, 
    0, 75, 1, 25, 3, 76, 5, 77, 2, 14, 8, 23, 7, 37, 4, 59, 6, 59, 
    2, 61, 0, 18, 3, 33, 6, 73, 7,  7, 1, 23, 8, 98, 4, 60, 5, 25, 
    2, 63, 5, 24, 4, 30, 3, 81, 6, 51, 1, 20, 7, 15, 0, 27, 8, 11, 
    3,  6, 4, 56, 0, 91, 8, 43, 5, 30, 1, 15, 6, 36, 2, 51, 7, 80, 
    1,  7, 8, 72, 3, 72, 0, 34, 4, 11, 2, 35, 6, 36, 5, 48, 7, 15
  };
  const int q2257[] = {
    9, 9, // Number of jobs and machines
    4, 35, 6, 64, 7, 31, 1, 48, 8,  6, 5, 73, 2, 72, 3, 73, 0, 40, 
    4, 42, 1, 99, 3, 71, 2, 73, 0, 44, 6, 35, 5, 43, 8, 67, 7,  8, 
    4,  2, 2, 14, 1, 39, 6, 59, 5, 73, 7, 38, 0, 62, 3, 20, 8, 71, 
    0, 68, 4,  3, 8, 41, 6, 29, 1, 16, 3, 83, 5, 18, 2, 61, 7, 97, 
    1,  8, 6, 84, 2, 88, 5, 37, 0, 61, 4, 84, 8,  9, 3, 24, 7, 30, 
    3, 65, 1, 43, 6, 49, 2,  7, 7, 36, 8, 71, 4, 17, 5, 30, 0, 27, 
    0,  6, 1, 47, 5, 32, 2, 95, 3, 95, 4, 58, 6, 71, 7,  1, 8,  6, 
    5, 50, 1,  8, 3, 22, 2,  7, 4, 48, 6, 86, 0, 85, 8, 31, 7,  1, 
    0, 19, 1, 63, 5, 79, 3, 15, 2, 55, 8, 99, 7, 48, 6, 52, 4, 22
  };
  const int q2258[] = {
    9, 9, // Number of jobs and machines
    1, 32, 7, 21, 3, 53, 5, 12, 8, 53, 2, 71, 6, 42, 4, 29, 0, 69, 
    3, 56, 6, 93, 7, 87, 5, 73, 2, 83, 4, 96, 1, 91, 0, 93, 8, 12, 
    1, 62, 5, 21, 2, 61, 6, 85, 4,  4, 7, 99, 8, 36, 0, 60, 3, 99, 
    3, 26, 0, 93, 2, 68, 4, 36, 5,  2, 6, 65, 7, 51, 1, 78, 8, 95, 
    6,  4, 5, 64, 7, 21, 8, 24, 0, 41, 4, 29, 3, 35, 1,  9, 2, 26, 
    4, 21, 6, 68, 8, 87, 7, 19, 5, 27, 0, 29, 1, 99, 3, 65, 2, 69, 
    8, 59, 4, 91, 5, 43, 1, 40, 6, 13, 0, 70, 3, 55, 2, 85, 7, 61, 
    1, 50, 6, 46, 0, 98, 4, 57, 7, 99, 8, 46, 3,  9, 5,  8, 2, 88, 
    4, 19, 6, 14, 2, 60, 1, 82, 7, 52, 8, 72, 5, 90, 3, 78, 0, 79
  };
  const int q2259[] = {
    9, 9, // Number of jobs and machines
    4, 94, 1, 13, 7, 17, 0, 25, 3, 53, 5, 92, 8,  6, 2, 66, 6, 87, 
    7, 17, 6, 89, 5, 48, 3, 61, 4, 79, 8, 96, 1,  2, 2, 54, 0, 79, 
    8, 83, 4, 34, 6, 26, 1, 42, 3, 80, 2, 57, 0, 35, 5, 40, 7, 65, 
    2, 86, 6, 58, 3, 54, 1, 16, 4, 52, 0, 54, 8, 59, 5, 46, 7, 53, 
    8, 28, 3, 52, 5, 95, 4, 12, 1, 37, 6, 81, 7, 80, 0, 98, 2, 61, 
    4, 66, 0, 18, 8, 22, 2,  8, 1, 75, 5, 23, 7, 67, 6, 14, 3, 49, 
    7,  1, 2, 27, 0, 82, 6, 33, 8, 36, 1, 94, 5, 34, 3, 54, 4, 40, 
    1, 78, 5, 59, 0, 93, 2, 22, 6, 40, 7, 16, 3, 50, 4, 60, 8, 42, 
    5, 86, 4, 90, 8, 75, 7, 83, 6, 50, 0, 53, 2, 91, 3, 70, 1,  5
  };
  const int q2260[] = {
    9, 9, // Number of jobs and machines
    2, 57, 4,  8, 0, 24, 7, 75, 1, 95, 5, 82, 3, 84, 8, 68, 6, 37, 
    0, 31, 8, 61, 4, 19, 5, 34, 2, 58, 7,  8, 1, 60, 6, 41, 3, 26, 
    3, 70, 1, 54, 0, 81, 8, 55, 6, 27, 5, 55, 7, 11, 4,  8, 2, 81, 
    5, 24, 1, 43, 3, 88, 2, 43, 6, 33, 0, 59, 7, 88, 8, 33, 4, 72, 
    8, 65, 2, 90, 5,  8, 1, 30, 6, 70, 7, 89, 3, 96, 4, 56, 0, 49, 
    8, 25, 5,  5, 4, 37, 7, 50, 3, 30, 2, 22, 6, 90, 1, 26, 0, 33, 
    5, 59, 6, 54, 1, 77, 8, 88, 7, 29, 0, 80, 2, 60, 3, 25, 4, 75, 
    2, 14, 3, 61, 7, 77, 0, 41, 6, 35, 5, 20, 4, 10, 1, 79, 8, 70, 
    8, 77, 1,  2, 7, 90, 2, 88, 5, 46, 3, 29, 0,  9, 6, 91, 4, 37
  };
  const int q2261[] = {
    9, 9, // Number of jobs and machines
    0, 42, 5, 57, 4, 10, 3, 65, 8, 76, 6, 63, 2, 45, 7, 97, 1, 71, 
    1, 59, 5, 39, 3, 62, 0, 52, 4, 15, 8, 55, 7, 66, 2, 28, 6, 47, 
    4, 66, 3, 85, 8, 84, 0,  6, 2, 67, 5, 72, 7, 13, 6, 92, 1, 67, 
    6, 73, 4, 79, 5, 60, 8, 13, 7, 30, 2, 40, 3, 16, 1, 71, 0, 84, 
    6, 48, 0,  8, 3, 87, 5, 78, 7, 63, 1, 44, 8, 68, 2, 44, 4,  1, 
    7, 67, 2, 54, 1, 24, 4, 58, 5,  4, 0, 25, 8, 92, 3, 92, 6, 73, 
    8, 41, 0,  3, 6, 35, 3,  8, 1,  8, 5, 66, 7, 13, 4, 46, 2, 52, 
    8, 31, 5, 33, 0, 65, 3, 16, 6, 25, 7, 39, 1, 55, 4, 49, 2, 48, 
    2, 76, 1, 29, 6, 75, 3, 51, 5, 84, 7, 48, 8, 71, 4, 16, 0, 81
  };
  const int q2262[] = {
    9, 9, // Number of jobs and machines
    2, 99, 4, 20, 5, 98, 7, 55, 1,  6, 0, 96, 6, 50, 3, 61, 8, 53, 
    0, 41, 7, 26, 3, 72, 8, 59, 1, 69, 6, 25, 4, 34, 5, 63, 2, 79, 
    3, 17, 2,  4, 1,  7, 4, 88, 7, 36, 8, 65, 0, 45, 5, 98, 6, 13, 
    7, 46, 3, 23, 0, 23, 8, 83, 2, 13, 4, 20, 5, 99, 1, 26, 6, 97, 
    1, 56, 0, 30, 3, 91, 4, 32, 2, 93, 7, 29, 6, 89, 8, 77, 5, 52, 
    5, 52, 3, 94, 6, 74, 8, 42, 1, 23, 4, 11, 0, 63, 7, 96, 2, 24, 
    5, 24, 3, 96, 6, 87, 7,  5, 1,  9, 8, 95, 0, 11, 4, 12, 2, 98, 
    0, 40, 1, 59, 5, 43, 3, 40, 6, 33, 4,  4, 7,  7, 8, 62, 2, 56, 
    1, 84, 6, 94, 2,  6, 7, 74, 0, 85, 5, 59, 8, 97, 4, 29, 3,  2
  };
  const int q2263[] = {
    9, 9, // Number of jobs and machines
    6, 29, 5, 60, 7,  5, 8, 50, 2, 48, 4, 10, 1, 77, 0, 96, 3, 22, 
    2, 99, 4,  5, 7, 44, 1, 69, 3, 30, 5, 73, 0, 83, 8, 62, 6, 88, 
    5, 67, 3, 76, 4, 62, 6, 77, 0, 14, 2, 24, 1, 87, 8, 11, 7, 90, 
    3, 91, 7, 11, 2, 43, 4, 19, 6, 32, 5, 41, 1,  9, 8, 64, 0, 37, 
    6, 27, 8,  4, 2, 31, 3, 28, 1, 90, 0, 34, 4, 67, 7, 57, 5, 98, 
    5,  7, 1, 69, 2,  4, 6, 70, 4,  3, 8, 81, 0, 66, 3, 34, 7, 72, 
    5, 44, 4, 55, 3,  5, 8, 75, 1, 18, 6, 84, 0, 83, 7, 90, 2, 24, 
    5, 66, 3, 36, 7, 91, 8, 62, 0, 83, 4, 34, 1, 89, 2, 39, 6, 50, 
    1, 56, 7, 98, 4, 36, 2, 72, 0, 71, 8, 80, 5, 14, 6, 89, 3, 53
  };
  const int q2264[] = {
    9, 9, // Number of jobs and machines
    6,  7, 3, 21, 5, 23, 0, 79, 4, 19, 8, 93, 2, 64, 7, 55, 1, 78, 
    3, 62, 1, 66, 4, 43, 6, 19, 0, 61, 8, 56, 7, 67, 5, 79, 2, 86, 
    7, 54, 4,  6, 3, 81, 0, 52, 1, 88, 2, 90, 5, 36, 6, 73, 8, 42, 
    0, 97, 1, 33, 6,  4, 8, 51, 2, 53, 5, 47, 4, 91, 7, 23, 3, 99, 
    0, 14, 3,  9, 2, 25, 7,  7, 8, 75, 6, 32, 4, 57, 1, 77, 5, 28, 
    3,  1, 6, 94, 2, 48, 7, 98, 0, 34, 8, 54, 1, 90, 5, 24, 4, 76, 
    1, 62, 2, 22, 7, 70, 6,  6, 8,  6, 5, 67, 0,  9, 4, 51, 3, 32, 
    8, 80, 5, 33, 3, 17, 2, 94, 6, 66, 1, 74, 0, 25, 4, 48, 7, 31, 
    2, 57, 1, 97, 0, 97, 4, 36, 3, 52, 6, 86, 7, 74, 8, 32, 5, 49
  };
  const int q2265[] = {
    9, 9, // Number of jobs and machines
    2, 50, 4, 80, 5, 38, 6, 33, 7, 91, 8, 28, 1, 40, 0, 78, 3, 30, 
    1, 64, 4, 25, 6, 92, 7, 41, 3, 96, 2, 26, 8, 75, 0, 83, 5, 56, 
    3, 28, 5, 94, 1, 39, 6, 16, 4, 45, 8, 18, 0, 68, 7, 93, 2, 34, 
    5,  7, 2, 12, 4, 60, 1, 37, 6, 46, 8, 80, 7, 47, 0, 45, 3, 35, 
    4, 79, 0, 73, 5, 21, 2, 53, 1, 83, 8, 35, 6, 39, 7, 12, 3, 38, 
    4, 41, 2, 12, 7,  1, 0, 54, 8, 27, 5, 95, 1, 59, 3, 46, 6,  7, 
    0, 56, 4, 61, 3, 62, 1, 45, 8, 58, 5, 19, 2,  6, 7,  9, 6, 86, 
    4, 96, 0, 23, 7, 79, 6, 54, 2, 93, 5, 34, 8, 79, 3, 71, 1,  6, 
    7, 28, 5, 88, 3, 33, 8,  8, 1, 71, 0, 30, 6, 20, 4, 56, 2, 12
  };
  const int q2266[] = {
    9, 9, // Number of jobs and machines
    3, 33, 5, 97, 6, 58, 1, 82, 7, 17, 2, 52, 0, 15, 4, 98, 8, 94, 
    0, 21, 6,  3, 7, 12, 3,  8, 2,  6, 8, 27, 4, 38, 5, 90, 1, 15, 
    3, 84, 8,  8, 7, 73, 5, 12, 0, 71, 2, 45, 1, 70, 6, 10, 4, 65, 
    1, 85, 5, 38, 2, 44, 6, 39, 8, 38, 3,  5, 0, 68, 7, 62, 4,  9, 
    6, 83, 4, 18, 2, 63, 3, 13, 1, 43, 0, 94, 5, 12, 8, 48, 7, 71, 
    0, 69, 4,  8, 7, 41, 5, 78, 8, 98, 3, 35, 6, 75, 1, 13, 2, 60, 
    8, 10, 5, 77, 6, 42, 4, 14, 2, 63, 1, 97, 0, 50, 3, 22, 7, 43, 
    6, 22, 2, 76, 0, 26, 4, 50, 8, 47, 7, 27, 1, 21, 3, 66, 5, 15, 
    4, 22, 0, 84, 7, 77, 2, 86, 8,  5, 1, 67, 3,  7, 5, 98, 6, 14
  };
  const int q2267[] = {
    9, 9, // Number of jobs and machines
    5,  1, 7, 52, 4, 13, 0, 54, 1,  2, 6, 74, 3, 49, 8, 38, 2, 90, 
    1, 80, 5, 20, 3, 90, 6, 64, 2, 37, 7, 20, 8, 25, 4, 19, 0, 61, 
    4,  4, 5, 22, 1, 91, 0, 45, 8, 55, 6, 72, 2, 55, 3, 15, 7, 20, 
    1, 76, 5, 57, 8, 20, 6, 71, 0, 73, 7, 73, 3, 75, 2, 22, 4, 63, 
    3, 15, 5, 68, 1, 53, 6, 19, 2, 85, 0, 65, 7, 23, 8,  5, 4, 43, 
    1, 42, 2, 78, 8, 93, 5, 11, 6,  1, 3, 54, 7, 25, 0, 57, 4, 93, 
    4, 75, 2, 19, 0, 11, 1, 29, 3,  8, 8, 77, 7, 60, 5, 95, 6, 54, 
    1, 70, 8, 38, 4, 19, 6, 27, 5, 61, 7, 77, 3,  2, 0, 76, 2,  4, 
    6,  7, 1,  8, 7, 61, 3, 22, 8, 21, 4, 68, 2, 65, 5, 64, 0, 82
  };
  const int q2268[] = {
    9, 9, // Number of jobs and machines
    8, 87, 5, 89, 4, 91, 2, 10, 0, 58, 1, 97, 6, 33, 7, 55, 3, 33, 
    0, 26, 7, 58, 8, 26, 4, 46, 2, 76, 1, 89, 6, 61, 5, 49, 3, 99, 
    6, 48, 5, 19, 2, 59, 1, 40, 8,  8, 7, 19, 0, 17, 3, 67, 4, 19, 
    2, 81, 1, 87, 5, 12, 7,  3, 4, 16, 6, 15, 3, 17, 8, 59, 0, 43, 
    7, 99, 1, 92, 2, 29, 3, 36, 8, 78, 0, 54, 4, 74, 6, 26, 5,  3, 
    3, 74, 2, 44, 8, 46, 6, 64, 0, 96, 5, 84, 1,  5, 4, 17, 7, 76, 
    0, 28, 6, 48, 8,  6, 3, 57, 7, 57, 1, 65, 4,  8, 5, 56, 2, 22, 
    5, 90, 0, 68, 7, 48, 2, 42, 8, 62, 6, 13, 1, 11, 3,  3, 4, 35, 
    5, 11, 3, 69, 8, 77, 4, 94, 7, 41, 1, 82, 2,  7, 6, 17, 0, 97
  };
  const int q2269[] = {
    9, 9, // Number of jobs and machines
    7,  7, 6,  1, 8, 43, 0, 46, 2, 50, 5, 65, 4, 32, 3, 40, 1, 87, 
    2, 76, 6,  4, 7, 63, 1,  2, 5, 14, 3, 33, 4, 52, 8, 22, 0, 33, 
    8, 31, 2, 43, 4,  9, 0, 10, 5, 49, 6, 21, 1, 19, 3, 21, 7, 27, 
    2, 99, 6, 98, 4, 32, 1, 67, 5, 31, 0, 89, 8, 32, 3, 48, 7, 89, 
    0, 38, 2, 29, 8, 96, 5, 17, 6, 19, 4, 44, 1, 44, 7, 21, 3, 27, 
    4, 33, 5, 37, 2, 75, 6, 92, 3, 69, 8, 40, 7, 14, 0, 75, 1, 75, 
    1, 98, 4, 95, 6, 48, 0,  4, 3, 69, 8, 36, 2, 90, 7, 97, 5, 21, 
    5, 46, 6, 46, 8, 10, 1, 78, 3, 84, 0, 36, 7, 51, 2, 60, 4, 95, 
    1, 35, 3, 13, 7, 90, 8, 56, 2, 21, 0, 56, 4, 48, 5, 96, 6, 33
  };
  const int q2270[] = {
    9, 9, // Number of jobs and machines
    7,  5, 6, 11, 3, 23, 5,  5, 1, 26, 0, 77, 2, 65, 8, 67, 4, 92, 
    7, 85, 2, 48, 6, 13, 8, 86, 5, 32, 3, 91, 0, 63, 4, 93, 1, 90, 
    0, 77, 1, 70, 2, 69, 5, 74, 8, 92, 4, 23, 3, 41, 6, 73, 7, 47, 
    4, 76, 2, 50, 8, 83, 3, 76, 6, 96, 5,  3, 7, 74, 0,  1, 1, 32, 
    6, 81, 0, 27, 8, 35, 1, 12, 7, 40, 5, 62, 2, 80, 3, 79, 4, 25, 
    6, 32, 4, 35, 3, 60, 7,  4, 8,  3, 2, 97, 0, 27, 5, 79, 1, 15, 
    8, 18, 6, 17, 3, 15, 0, 20, 7, 11, 2, 45, 5, 74, 4, 65, 1, 73, 
    7, 57, 6, 27, 5, 27, 2, 73, 3, 95, 8, 93, 1, 54, 0, 67, 4, 68, 
    8, 54, 5, 38, 2, 95, 7, 23, 4, 90, 6, 23, 3, 57, 1, 89, 0, 95
  };
  const int q2271[] = {
    9, 9, // Number of jobs and machines
    7, 35, 3, 29, 2, 76, 1, 27, 6, 45, 4, 27, 8, 85, 0, 97, 5, 75, 
    2, 40, 7, 39, 3, 95, 8, 24, 4, 17, 0, 73, 5, 52, 1,  8, 6, 83, 
    4, 83, 3, 39, 6, 45, 1, 16, 2, 84, 5, 43, 7, 61, 8, 80, 0, 82, 
    3, 52, 8, 55, 5, 89, 0, 40, 4, 75, 1, 13, 2, 24, 7, 74, 6,  6, 
    0, 43, 2, 28, 3, 23, 1,  7, 5, 22, 8, 15, 4, 98, 7, 47, 6, 76, 
    1,  6, 5, 38, 7, 49, 3, 63, 0, 69, 2, 26, 6, 82, 4, 28, 8, 93, 
    3, 39, 7, 99, 5,  7, 2, 40, 4, 48, 8, 92, 6,  9, 1, 26, 0, 45, 
    0,  6, 2, 81, 1, 10, 5, 76, 4, 96, 3, 82, 8, 81, 7, 76, 6, 31, 
    3, 73, 8, 72, 2, 58, 5, 53, 1, 10, 6, 75, 7, 39, 0,  8, 4,  2
  };
  const int q2272[] = {
    9, 9, // Number of jobs and machines
    0, 79, 1,  5, 7, 78, 3, 87, 2, 56, 5, 81, 4, 14, 8, 17, 6, 89, 
    8, 77, 6, 74, 4, 24, 1, 36, 2, 24, 0, 96, 3, 32, 7, 11, 5, 76, 
    5, 62, 3, 82, 7, 31, 4, 65, 6, 35, 0, 21, 8, 42, 1, 81, 2, 88, 
    2, 14, 8, 97, 0, 99, 5, 52, 6, 88, 7, 93, 1, 17, 3, 90, 4, 63, 
    8, 77, 3, 61, 4, 12, 5, 27, 6, 89, 1, 10, 2,  1, 7, 23, 0, 87, 
    4, 55, 5, 88, 0, 24, 6,  7, 8, 82, 3, 80, 2, 18, 7,  7, 1, 22, 
    7, 59, 1, 30, 3, 90, 2, 61, 5, 94, 4, 93, 0,  4, 8, 73, 6, 82, 
    0, 41, 6, 10, 3, 68, 8,  9, 1, 97, 5, 53, 7, 90, 2, 24, 4, 71, 
    2, 86, 5, 66, 0, 44, 1, 30, 4, 15, 7, 38, 6, 48, 8, 30, 3, 88
  };
  const int q2273[] = {
    9, 9, // Number of jobs and machines
    2, 86, 0, 57, 3, 18, 5, 63, 7, 73, 6, 10, 8, 21, 1, 66, 4, 93, 
    8, 45, 1, 50, 7, 96, 0, 70, 5, 27, 4, 72, 3, 12, 6, 70, 2, 30, 
    8, 55, 5, 78, 2, 90, 3, 85, 7, 21, 1, 43, 4, 18, 0, 98, 6, 23, 
    2, 57, 6, 97, 5, 37, 8, 15, 3, 24, 1, 43, 0, 50, 7, 78, 4,  7, 
    0, 31, 6, 12, 3, 93, 2, 87, 1, 70, 5, 10, 4, 19, 7, 40, 8, 17, 
    1, 79, 3, 46, 8, 16, 4, 78, 2, 35, 5, 45, 7, 86, 0, 47, 6, 49, 
    7, 43, 3, 13, 1,  1, 2,  9, 6, 99, 4, 99, 5, 94, 0, 65, 8, 86, 
    2, 44, 7,  9, 5,  8, 0, 62, 3, 56, 6, 92, 1, 61, 4, 36, 8, 69, 
    2, 78, 3, 52, 6, 33, 7, 47, 8, 47, 0, 82, 1, 65, 4, 88, 5, 25
  };
  const int q2274[] = {
    9, 9, // Number of jobs and machines
    8, 71, 5, 93, 1, 80, 2, 53, 4, 63, 3, 16, 0, 61, 7, 52, 6, 97, 
    4, 12, 0, 87, 6, 95, 8,  8, 3, 68, 1, 76, 2, 20, 7,  6, 5, 96, 
    0, 99, 5, 41, 3, 58, 7, 44, 2, 51, 6, 97, 1,  3, 4, 65, 8, 31, 
    2, 35, 8, 86, 7, 67, 1, 84, 4, 13, 6,  9, 3, 44, 5, 70, 0, 62, 
    6, 37, 5, 33, 0, 73, 8, 60, 4, 39, 7, 61, 3, 84, 2, 98, 1, 85, 
    8, 98, 3, 43, 7, 82, 2,  8, 6, 47, 0, 31, 5, 59, 1,  9, 4, 51, 
    4, 97, 1, 38, 5, 69, 2, 85, 7, 85, 3,  8, 0, 98, 8, 28, 6, 21, 
    1, 26, 2, 31, 4, 49, 3, 81, 7, 35, 6, 82, 8, 71, 0, 35, 5, 17, 
    0, 36, 6, 39, 3, 91, 7, 58, 8, 81, 1, 47, 4,  8, 5, 53, 2, 50
  };
  const int q2275[] = {
    9, 9, // Number of jobs and machines
    0, 41, 4, 97, 3, 45, 6, 85, 5, 97, 7, 90, 8, 34, 1, 13, 2, 36, 
    1, 32, 5, 70, 8, 58, 4,  3, 7,  2, 6, 92, 3, 23, 2, 31, 0, 26, 
    8, 49, 7, 31, 6, 12, 2, 69, 1, 52, 5, 48, 3, 54, 0, 94, 4, 86, 
    5, 35, 0, 25, 3, 44, 1, 58, 6, 84, 2, 67, 7, 79, 8, 21, 4,  5, 
    7, 28, 6, 87, 0,  2, 2, 50, 3, 74, 1, 41, 5, 45, 4, 22, 8, 57, 
    4, 70, 2,  1, 3, 75, 7, 74, 6, 26, 8, 74, 0, 82, 5, 77, 1, 67, 
    1, 64, 6, 72, 3, 35, 2, 99, 0, 56, 5, 89, 7, 60, 4, 46, 8, 99, 
    7, 72, 4, 19, 8, 16, 6, 24, 5, 27, 2, 10, 0, 64, 1, 48, 3, 25, 
    0, 73, 8, 95, 2,  8, 5, 69, 1, 37, 4, 73, 3, 98, 7, 97, 6, 49
  };
  const int q2276[] = {
    9, 9, // Number of jobs and machines
    8, 33, 1, 13, 7, 93, 6, 62, 4, 18, 3, 47, 2, 92, 5, 34, 0, 80, 
    5, 88, 1, 26, 8, 81, 0, 55, 3, 53, 7, 82, 2, 90, 6, 93, 4, 37, 
    4, 52, 0, 36, 1, 71, 7, 91, 3, 90, 6, 48, 2, 62, 5, 85, 8, 77, 
    0,  7, 5, 31, 8, 93, 4, 60, 2, 24, 7, 36, 3, 24, 1, 23, 6, 55, 
    8, 21, 5, 90, 4, 78, 0, 85, 3, 51, 1, 14, 7, 81, 2, 33, 6, 85, 
    2, 29, 7, 59, 1, 52, 3, 34, 0,  1, 6, 18, 4, 15, 5, 34, 8, 62, 
    8, 70, 2, 55, 5, 94, 0, 71, 6, 22, 3, 18, 1, 28, 4,  3, 7, 87, 
    0, 29, 3, 14, 5, 76, 8, 80, 7, 87, 6, 23, 4,  8, 1, 18, 2, 10, 
    7, 44, 1, 11, 5, 50, 8, 99, 6, 13, 2, 90, 4, 95, 0, 30, 3, 70
  };
  const int q2277[] = {
    9, 9, // Number of jobs and machines
    5, 64, 7, 35, 6, 46, 3,  9, 0, 78, 4, 72, 2, 50, 1, 46, 8, 60, 
    1, 41, 7, 43, 2, 91, 6, 69, 5, 31, 8, 58, 3, 41, 0, 22, 4, 15, 
    8,  3, 1,  2, 5, 63, 6,  5, 7, 35, 4, 65, 3, 61, 2, 67, 0, 32, 
    6, 68, 8, 42, 5, 16, 0, 62, 2, 25, 1, 31, 7,  3, 3, 52, 4, 55, 
    7, 18, 3, 45, 0, 62, 5, 41, 2, 72, 8, 48, 1, 49, 4, 91, 6, 19, 
    3, 71, 7, 53, 2, 22, 4, 54, 6, 74, 1, 22, 8, 98, 0, 18, 5, 52, 
    3, 22, 7, 31, 4, 45, 0, 82, 8, 37, 1, 69, 2, 70, 5, 38, 6, 18, 
    5, 44, 2, 67, 4,  1, 8, 18, 6, 30, 7, 27, 3, 85, 0, 70, 1, 13, 
    5, 60, 8, 27, 6, 31, 0,  4, 4, 40, 1, 69, 3, 18, 7, 51, 2, 33
  };
  const int q2278[] = {
    9, 9, // Number of jobs and machines
    3, 16, 1,  6, 8, 17, 6, 67, 5, 87, 7, 63, 4, 39, 2, 22, 0, 34, 
    7, 40, 4, 95, 8, 30, 1, 10, 6, 57, 0, 37, 3, 19, 2, 43, 5, 80, 
    8, 25, 3, 40, 4, 54, 5, 67, 1, 75, 0, 62, 7, 98, 2, 42, 6, 42, 
    3, 35, 0, 10, 5, 10, 6, 40, 4, 38, 1, 92, 2,  2, 7, 55, 8, 96, 
    2,  6, 7, 90, 6, 19, 3, 66, 8, 78, 5, 97, 1, 24, 0, 88, 4, 46, 
    8, 32, 1, 23, 2, 99, 4, 61, 3, 54, 7, 33, 5, 20, 0, 82, 6, 15, 
    5,  2, 2, 36, 8,  9, 3, 86, 1, 15, 6, 50, 7, 65, 4,  3, 0,  3, 
    3, 91, 2,  7, 1, 50, 7, 41, 8, 45, 5, 52, 4, 88, 0, 55, 6,  6, 
    4, 68, 8, 15, 2, 35, 3, 32, 7, 67, 6, 91, 0, 28, 1, 75, 5, 42
  };
  const int q2279[] = {
    9, 9, // Number of jobs and machines
    4, 58, 2, 50, 6, 93, 0, 93, 8, 24, 5, 25, 3, 98, 1,  5, 7, 31, 
    2, 56, 5, 30, 6,  2, 4, 88, 7, 78, 1, 63, 3, 56, 8, 72, 0, 95, 
    8, 72, 6, 45, 3, 78, 7, 97, 2, 30, 4, 42, 5, 77, 1,  9, 0, 90, 
    3, 70, 5, 39, 8, 59, 2, 37, 1, 33, 4, 81, 6, 98, 7, 44, 0, 33, 
    2, 90, 3, 71, 8, 86, 5, 56, 0, 44, 7, 64, 4, 58, 6, 53, 1, 43, 
    3, 88, 4, 43, 6, 27, 1, 68, 5, 80, 7, 44, 0, 15, 2,  7, 8, 64, 
    1, 61, 4, 98, 6, 60, 2,  3, 7, 69, 8, 12, 5,  9, 0, 48, 3, 70, 
    5, 68, 4, 96, 1, 25, 7, 81, 0, 71, 8, 33, 2, 69, 3, 73, 6,  6, 
    5, 44, 8, 52, 7, 35, 6, 79, 4, 37, 0, 50, 1, 56, 3, 90, 2, 17
  };
  const int q2280[] = {
    9, 9, // Number of jobs and machines
    2, 17, 4, 36, 1, 31, 8, 48, 5, 25, 0, 56, 7, 75, 3, 78, 6, 55, 
    0, 81, 3, 88, 4, 91, 8, 99, 7, 86, 1, 37, 6, 57, 2, 31, 5, 21, 
    4, 42, 2, 35, 1, 54, 6, 59, 7, 71, 5, 75, 0, 30, 8, 90, 3, 90, 
    6, 13, 7, 10, 3, 21, 8, 49, 5, 61, 0, 17, 2, 61, 4, 75, 1, 21, 
    1, 33, 4, 88, 3, 55, 2, 51, 7, 90, 0, 74, 5, 64, 6, 30, 8, 62, 
    7, 14, 1, 48, 2, 10, 8, 93, 0, 24, 3, 64, 6, 59, 5, 10, 4, 62, 
    1, 18, 7, 90, 2, 78, 5, 77, 3, 29, 0,  5, 4, 45, 6, 91, 8, 31, 
    8, 56, 1, 99, 5, 37, 4, 26, 7, 59, 3, 69, 2, 41, 0, 25, 6,  2, 
    1, 48, 3, 85, 2, 40, 8, 47, 6, 95, 7, 78, 5, 78, 0, 73, 4, 69
  };
  const int q2281[] = {
    9, 9, // Number of jobs and machines
    3,  3, 5, 75, 4, 25, 2, 36, 8, 99, 0, 24, 7, 32, 1, 77, 6, 29, 
    2, 66, 7, 79, 1, 17, 6, 66, 3, 37, 8, 10, 5, 43, 4, 38, 0, 47, 
    4, 63, 1, 81, 0, 35, 6, 97, 7,  7, 8, 75, 2, 27, 3, 63, 5, 14, 
    1,  7, 2, 59, 6,  2, 4,  4, 5,  2, 0, 86, 8, 77, 7, 35, 3, 35, 
    1, 82, 7, 97, 2, 89, 4, 62, 0, 90, 3, 17, 8, 62, 6, 67, 5, 39, 
    5, 89, 6, 92, 1, 61, 4, 26, 3, 87, 8,  4, 0, 10, 7, 92, 2, 99, 
    1, 93, 0, 95, 5, 91, 7, 39, 4, 70, 2,  5, 8, 79, 3,  9, 6, 78, 
    6, 73, 0, 28, 8, 31, 1,  1, 4, 80, 2, 92, 5, 57, 3, 54, 7, 38, 
    4, 22, 1, 52, 5, 65, 8, 84, 7, 66, 3, 77, 2, 23, 6, 86, 0, 24
  };
  const int q2282[] = {
    9, 9, // Number of jobs and machines
    2, 78, 0, 26, 3, 96, 6, 67, 7, 90, 5, 30, 8, 80, 1, 40, 4, 65, 
    0, 11, 7,  2, 6, 19, 8, 47, 4, 36, 3, 78, 1, 25, 2, 54, 5, 98, 
    6,  8, 2, 81, 7, 11, 3, 38, 4, 23, 8, 44, 1, 42, 0, 35, 5, 40, 
    7, 28, 0, 32, 4, 25, 3, 54, 6, 32, 5, 56, 1, 99, 2, 62, 8,  1, 
    6, 22, 1, 89, 3, 72, 4, 42, 2, 55, 5, 66, 7, 38, 8, 14, 0,  8, 
    5, 11, 2, 43, 0, 20, 3, 47, 4, 62, 1, 70, 7,  6, 6, 60, 8, 99, 
    2,  5, 1, 65, 4, 14, 0, 44, 7,  7, 3, 52, 8, 28, 6,  2, 5, 56, 
    3, 52, 1,  9, 6, 32, 5, 11, 2, 87, 4, 37, 8, 12, 7,  6, 0, 93, 
    1, 82, 3, 50, 4, 66, 5, 39, 6, 71, 0, 34, 8, 73, 7, 52, 2, 92
  };
  const int q2283[] = {
    9, 9, // Number of jobs and machines
    6, 94, 0, 93, 8, 72, 4,  4, 3, 69, 5, 64, 1, 27, 7, 84, 2, 89, 
    0, 32, 6, 48, 2, 85, 4, 52, 8, 86, 7, 70, 1, 76, 3, 42, 5, 32, 
    0,  8, 8, 40, 7, 43, 1, 82, 6, 17, 4, 96, 3, 77, 5, 78, 2, 94, 
    5, 79, 6, 14, 8, 53, 4, 16, 1, 22, 7, 12, 2, 15, 0, 50, 3, 36, 
    1, 98, 3, 12, 0, 87, 6, 21, 4, 95, 5, 62, 8, 84, 2, 87, 7, 50, 
    2, 27, 7, 75, 5, 88, 1, 24, 8,  5, 4, 57, 6, 59, 0, 45, 3, 61, 
    6, 44, 2, 83, 4, 28, 8, 38, 7, 86, 5, 62, 1, 59, 3, 79, 0, 10, 
    5, 53, 6, 66, 2, 48, 3, 84, 4, 72, 8, 47, 0, 73, 7, 57, 1, 99, 
    4, 23, 8, 14, 1, 20, 7, 15, 0, 11, 5, 81, 2, 44, 3, 49, 6, 49
  };
  const int q2284[] = {
    9, 9, // Number of jobs and machines
    7, 74, 4, 22, 6,  2, 3, 74, 5, 61, 1, 35, 0, 90, 2, 67, 8, 53, 
    0, 24, 5, 77, 3, 60, 2, 99, 4,  6, 8, 18, 7, 84, 6, 71, 1, 68, 
    6, 48, 1,  9, 3, 70, 0, 97, 7, 58, 4, 33, 5, 30, 8, 39, 2, 63, 
    1, 29, 2, 47, 4, 60, 0, 76, 5, 94, 3, 70, 7, 78, 6, 81, 8, 79, 
    2, 53, 8, 83, 6, 60, 0, 41, 4,  6, 1, 55, 5, 28, 3, 89, 7, 70, 
    5, 33, 6, 92, 3, 58, 7, 31, 4, 24, 2, 17, 1, 49, 0, 32, 8, 50, 
    7, 21, 0,  2, 4, 56, 8, 51, 6, 97, 3, 44, 5, 56, 1, 57, 2, 24, 
    8, 99, 2,  3, 6, 84, 5, 88, 0, 77, 3, 32, 1, 13, 7, 30, 4, 59, 
    2, 51, 3, 39, 7, 17, 1, 93, 8, 26, 0, 72, 6, 11, 4, 15, 5, 85
  };
  const int q2285[] = {
    9, 9, // Number of jobs and machines
    5, 23, 7, 75, 3, 62, 2, 51, 1, 63, 6, 75, 8, 67, 0, 31, 4, 42, 
    0, 83, 4, 54, 1, 86, 6, 49, 8, 72, 7, 59, 2, 88, 3, 31, 5, 83, 
    7,  7, 2, 88, 5, 83, 8, 10, 4, 13, 0, 36, 3, 46, 6, 77, 1, 71, 
    5, 45, 7, 29, 1, 83, 2, 87, 3, 49, 8, 95, 6,  8, 0,  6, 4,  9, 
    5, 12, 6, 68, 4, 77, 2, 73, 1, 34, 0, 40, 3, 27, 8, 48, 7, 38, 
    7,  2, 4, 66, 0, 26, 8, 18, 1, 64, 3, 90, 2,  8, 5, 26, 6, 79, 
    2, 29, 6, 61, 8, 44, 7, 55, 0, 79, 5, 89, 1, 24, 4, 85, 3, 38, 
    3, 73, 6, 36, 7, 99, 5, 15, 0, 36, 1, 16, 2, 11, 8, 36, 4, 96, 
    3, 41, 0, 31, 2, 71, 4, 40, 1, 62, 6, 93, 5, 30, 8, 13, 7, 58
  };
  const int q2286[] = {
    9, 9, // Number of jobs and machines
    5, 19, 0, 81, 7, 92, 3, 60, 2, 77, 8, 22, 1, 64, 6, 96, 4,  5, 
    1, 15, 7, 77, 8, 66, 6, 83, 4, 95, 3, 51, 2, 17, 5, 25, 0, 17, 
    7, 73, 2, 41, 1, 19, 4, 71, 0, 32, 5,  6, 6, 55, 8, 61, 3, 99, 
    0, 47, 1, 88, 5, 14, 7,  1, 4, 87, 8, 82, 3, 56, 6,  6, 2, 83, 
    4, 89, 6, 86, 1, 34, 8, 95, 0,  5, 5, 49, 3, 96, 7, 61, 2, 42, 
    1, 12, 3,  4, 5, 35, 7, 47, 8, 57, 6, 18, 0, 62, 2, 19, 4, 31, 
    7, 63, 5, 11, 2, 69, 8, 37, 1, 34, 0, 27, 4, 48, 6, 73, 3, 29, 
    8, 81, 4,  6, 1, 23, 2, 31, 0, 41, 3, 73, 5, 39, 7, 72, 6, 81, 
    6, 47, 7, 32, 8, 38, 3,  8, 2, 95, 4, 50, 1, 10, 0, 91, 5, 98
  };
  const int q2287[] = {
    9, 9, // Number of jobs and machines
    4, 82, 5, 15, 0, 23, 6, 41, 7, 30, 1, 28, 8, 52, 3, 81, 2, 70, 
    1, 64, 6, 43, 3, 29, 4, 59, 8,  5, 7, 57, 5, 46, 0, 29, 2, 20, 
    4, 91, 8, 78, 6, 16, 0, 84, 7, 15, 2, 25, 5,  7, 1, 17, 3, 93, 
    1, 64, 3, 20, 4,  3, 8, 20, 2, 74, 7, 89, 6, 94, 5, 94, 0, 13, 
    4, 65, 2,  4, 5, 66, 8, 27, 3, 36, 1,  1, 0, 89, 6, 25, 7, 31, 
    3, 91, 7, 11, 5, 60, 6,  4, 0, 36, 1,  6, 4, 66, 2, 79, 8, 22, 
    0, 38, 6, 44, 7, 79, 8, 48, 2, 84, 5, 78, 4, 89, 1, 43, 3, 51, 
    5, 52, 8, 48, 4, 14, 6,  8, 0, 53, 2,  7, 3, 49, 1, 53, 7, 35, 
    2, 29, 0, 32, 3, 66, 8, 53, 1, 95, 6, 96, 4, 68, 5, 21, 7, 70
  };
  const int q2288[] = {
    9, 9, // Number of jobs and machines
    2, 86, 4, 48, 5, 50, 7, 18, 1, 86, 3, 46, 0, 47, 6, 11, 8, 23, 
    3, 96, 8, 25, 7, 82, 4, 29, 1, 68, 2, 42, 5, 79, 0, 51, 6, 79, 
    8, 20, 5, 67, 4, 44, 7, 29, 0, 97, 3, 61, 2, 77, 1, 53, 6, 22, 
    7, 62, 4, 22, 1, 21, 2, 99, 6, 20, 3, 49, 0, 10, 8, 48, 5, 89, 
    4, 82, 7, 92, 0, 49, 6, 22, 2, 20, 3,  4, 8, 58, 1, 98, 5, 17, 
    1, 65, 0, 43, 5, 30, 8, 55, 2, 92, 7, 10, 3, 39, 6, 26, 4, 40, 
    0, 20, 4, 58, 2, 32, 1,  7, 7, 75, 8, 37, 6, 21, 3, 55, 5, 89, 
    1, 53, 7, 75, 2, 80, 4, 99, 8, 51, 6, 25, 3, 49, 5, 51, 0, 91, 
    6, 96, 8, 82, 5,  7, 7, 78, 1, 48, 4, 94, 0, 95, 2, 76, 3, 55
  };
  const int q2289[] = {
    9, 9, // Number of jobs and machines
    0, 58, 7, 57, 4, 66, 6, 97, 8, 59, 2, 48, 5, 86, 3, 53, 1, 51, 
    8, 19, 0, 43, 5, 91, 3, 10, 2, 17, 4,  4, 1, 28, 6, 53, 7, 45, 
    3, 64, 8, 56, 4, 38, 2,  2, 6, 41, 1,  4, 5, 66, 7, 45, 0, 77, 
    5, 39, 0, 60, 8, 80, 4, 66, 7, 74, 6, 84, 1, 47, 2, 92, 3, 83, 
    2, 75, 8, 87, 1, 70, 6, 95, 7, 92, 0, 52, 3, 71, 5, 69, 4, 94, 
    1, 42, 7, 45, 2, 60, 4, 44, 6, 29, 0, 89, 3, 65, 5, 65, 8, 10, 
    2, 55, 6, 67, 0, 54, 5, 56, 1, 82, 8, 81, 4, 17, 3, 44, 7, 46, 
    6, 77, 3, 16, 4, 20, 5, 39, 8, 23, 2, 17, 1, 15, 0, 82, 7, 14, 
    5, 58, 8, 16, 6,  4, 1, 46, 2, 16, 4, 15, 7, 32, 3, 57, 0, 23
  };
  const int q2290[] = {
    9, 9, // Number of jobs and machines
    7, 91, 6, 47, 8, 77, 2, 24, 4, 35, 1, 75, 3, 10, 0, 11, 5, 13, 
    1, 47, 7, 66, 5, 90, 2, 15, 6, 21, 4, 50, 8, 15, 3, 93, 0, 74, 
    8, 33, 4, 31, 3, 10, 2, 51, 0, 33, 7, 11, 5, 84, 1, 66, 6, 60, 
    4, 97, 1, 25, 6, 97, 8, 60, 2, 74, 7, 29, 5, 21, 0, 58, 3, 40, 
    4, 16, 2, 89, 6, 22, 1, 56, 8, 44, 5, 38, 7, 84, 0, 26, 3, 36, 
    8, 12, 2,  2, 0, 58, 7, 76, 3, 34, 6, 72, 5, 97, 1, 76, 4, 74, 
    6, 30, 0, 35, 4, 50, 3, 41, 7, 47, 8, 26, 2, 99, 5,  7, 1, 78, 
    3, 38, 1,  5, 2, 57, 0, 45, 6, 43, 5, 77, 4, 45, 7, 68, 8, 57, 
    2, 24, 5, 46, 4, 84, 7, 71, 1, 29, 0, 71, 6,  4, 8, 57, 3, 68
  };
  const int q2291[] = {
    9, 9, // Number of jobs and machines
    3, 68, 6, 90, 4, 12, 0, 26, 1, 83, 5,  5, 7, 63, 8, 62, 2,  2, 
    0, 81, 5, 64, 6, 82, 7, 33, 4,  6, 3, 61, 8, 72, 2,  2, 1, 30, 
    7, 19, 3,  8, 1, 49, 6, 97, 0, 23, 2, 77, 8, 80, 4, 45, 5, 13, 
    7, 50, 1, 88, 8, 22, 3, 43, 5, 80, 6, 52, 0, 81, 4, 21, 2, 74, 
    4, 91, 5, 92, 3, 27, 7, 97, 8, 51, 0, 82, 2, 71, 1, 69, 6,  8, 
    5, 30, 3,  6, 2,  3, 7, 10, 4, 45, 6, 76, 0, 26, 1, 33, 8, 33, 
    0, 55, 5, 78, 6,  1, 4, 97, 8, 59, 2, 39, 3, 54, 7, 57, 1, 99, 
    6, 68, 3, 53, 1, 67, 4, 26, 5, 35, 8, 14, 0, 35, 2,  6, 7, 49, 
    4, 17, 6, 87, 7,  5, 1, 45, 8, 30, 5, 73, 3, 89, 0, 87, 2, 66
  };
  const int q2292[] = {
    9, 9, // Number of jobs and machines
    2, 64, 1, 75, 5, 38, 4, 27, 0, 50, 7, 90, 3, 40, 6, 52, 8, 86, 
    2, 75, 7, 60, 0, 81, 8, 24, 5, 16, 6, 17, 4, 15, 1, 18, 3, 49, 
    5, 96, 4, 74, 8, 72, 3, 47, 1, 57, 2, 24, 0, 36, 6, 59, 7, 91, 
    5, 73, 6, 78, 0, 78, 7, 25, 1, 96, 2,  8, 4,  1, 3, 58, 8, 69, 
    4, 33, 6, 81, 8, 53, 1,  4, 2, 56, 5, 92, 7, 44, 3, 14, 0, 82, 
    6, 12, 1, 78, 8, 78, 5, 79, 7, 13, 0, 66, 3, 59, 2, 15, 4, 84, 
    1, 79, 3, 13, 5, 91, 6, 31, 2, 89, 7, 97, 4, 91, 8, 91, 0, 34, 
    5,  5, 7, 24, 4, 20, 2, 83, 3, 28, 1, 26, 6, 21, 0, 38, 8, 77, 
    5, 80, 6, 29, 3, 52, 8, 33, 4, 64, 0,  2, 7, 71, 1, 31, 2, 98
  };
  const int q2293[] = {
    9, 9, // Number of jobs and machines
    0, 91, 1, 50, 6, 91, 4, 35, 7, 27, 5, 34, 3, 29, 8, 48, 2, 12, 
    0, 80, 1, 96, 5, 63, 3, 81, 4, 88, 2, 88, 6, 90, 8,  8, 7,  4, 
    6, 16, 5, 44, 4, 99, 0, 99, 7, 25, 3, 96, 1, 35, 8, 12, 2, 80, 
    3, 69, 2, 38, 8, 23, 6, 29, 5, 77, 1, 69, 0, 20, 7,  9, 4, 23, 
    4, 22, 8, 57, 6, 52, 0, 47, 2, 88, 1, 69, 5, 31, 7, 37, 3, 12, 
    5, 82, 0, 84, 2, 10, 3, 22, 1, 69, 6, 65, 4, 57, 8, 29, 7, 56, 
    2, 43, 8, 58, 0, 54, 4, 24, 3, 40, 7, 32, 5, 61, 6, 71, 1, 93, 
    4, 11, 0,  9, 6, 86, 8, 39, 2, 19, 7,  6, 3, 70, 5, 84, 1, 56, 
    1, 52, 8, 44, 5, 31, 4, 79, 0, 94, 2, 22, 6, 86, 7, 80, 3, 17
  };
  const int q2294[] = {
    9, 9, // Number of jobs and machines
    0, 88, 4, 87, 7, 42, 8, 31, 1, 56, 3,  6, 5, 38, 2, 41, 6, 69, 
    1, 70, 6, 34, 0, 55, 3, 47, 8, 36, 7, 73, 5, 14, 2, 37, 4, 31, 
    0, 94, 7, 74, 2, 71, 4, 80, 3, 62, 8, 33, 6, 13, 1, 81, 5, 28, 
    7, 21, 5, 46, 3, 39, 2, 66, 6, 47, 8, 75, 4, 41, 0, 68, 1, 19, 
    2, 35, 3, 79, 6, 97, 7, 99, 0, 58, 4, 98, 8, 73, 5, 35, 1, 42, 
    1,  9, 3, 21, 8, 13, 0, 67, 7, 83, 6, 56, 4, 88, 5, 65, 2, 84, 
    2, 41, 8, 90, 7, 38, 6, 84, 5, 23, 4, 22, 0, 26, 3, 51, 1, 23, 
    6, 99, 8, 64, 2, 42, 1,  2, 0,  4, 5,  5, 4, 66, 7, 51, 3, 24, 
    6, 37, 1,  6, 3, 85, 2, 93, 8, 44, 5, 33, 4, 30, 0, 93, 7, 69
  };
  const int q2295[] = {
    9, 9, // Number of jobs and machines
    5, 42, 0, 19, 4, 44, 8, 36, 1, 73, 2, 52, 6, 66, 3, 28, 7, 24, 
    0, 19, 6, 51, 1, 84, 5, 26, 4, 74, 8, 75, 2, 38, 3, 29, 7, 80, 
    4, 31, 3, 76, 2,  9, 5, 12, 1, 73, 7, 56, 6, 13, 8, 26, 0, 24, 
    4, 75, 1, 52, 3, 93, 6, 60, 7, 40, 5, 43, 0, 35, 2, 33, 8, 42, 
    8, 11, 6, 40, 5, 47, 2, 29, 4, 94, 1, 36, 7,  9, 0,  8, 3, 21, 
    6, 78, 4, 52, 3,  8, 8, 19, 5,  1, 1, 87, 7, 86, 2, 66, 0, 62, 
    1, 99, 0, 65, 6, 63, 7,  9, 4, 63, 2,  3, 3, 24, 8, 58, 5, 86, 
    5, 53, 2, 11, 7, 40, 0, 50, 3, 10, 8, 57, 4, 72, 6, 51, 1, 92, 
    6, 44, 5, 70, 2, 82, 3, 31, 0, 91, 7, 45, 8, 66, 1, 80, 4, 17
  };
  const int q2296[] = {
    9, 9, // Number of jobs and machines
    4, 75, 1,  1, 7, 33, 6,  1, 0, 48, 3, 18, 8, 77, 2, 97, 5, 51, 
    3, 62, 4, 54, 5, 69, 8, 92, 1, 90, 2, 31, 0, 46, 7, 14, 6, 27, 
    4, 91, 8, 41, 5, 47, 2, 85, 0, 13, 3, 83, 7, 41, 6, 15, 1, 78, 
    6, 36, 0, 50, 5, 10, 3, 83, 8,  9, 4, 85, 1, 51, 7, 64, 2, 78, 
    4, 42, 8, 62, 5, 74, 3, 71, 7, 20, 6, 82, 0, 66, 1, 21, 2, 41, 
    6, 61, 4, 22, 3, 30, 7,  1, 2, 26, 1, 38, 8, 57, 0, 74, 5, 80, 
    6, 40, 0,  6, 3, 87, 4, 65, 8, 42, 5, 74, 2, 25, 1, 95, 7, 37, 
    3, 98, 5, 85, 1, 72, 0, 39, 8, 67, 4, 98, 6, 39, 2, 29, 7, 79, 
    4, 67, 6, 30, 3, 24, 7, 79, 2, 89, 8, 75, 1,  5, 0, 83, 5, 83
  };
  const int q2297[] = {
    9, 9, // Number of jobs and machines
    1, 33, 8, 21, 4, 79, 6,  3, 5, 88, 0, 33, 2, 63, 7, 80, 3, 59, 
    2, 83, 7, 60, 5, 29, 3,  4, 8, 76, 6, 81, 4, 97, 1, 13, 0, 32, 
    1, 28, 3, 51, 4, 26, 7, 61, 8, 51, 2, 80, 0, 54, 6, 57, 5, 79, 
    0, 90, 3, 71, 1, 90, 2, 47, 8, 99, 5, 30, 6, 26, 7, 68, 4, 90, 
    4, 91, 3, 31, 1, 54, 8, 49, 0, 37, 6, 60, 7,  7, 2, 68, 5, 88, 
    1, 92, 5, 16, 8, 70, 6, 98, 2, 19, 7, 25, 3, 63, 0, 21, 4, 54, 
    6, 17, 5, 70, 7, 70, 2, 41, 4, 16, 3, 75, 1, 81, 8, 23, 0, 86, 
    6,  3, 1, 62, 8, 71, 5, 42, 3,  7, 0, 66, 4, 56, 2, 22, 7, 12, 
    4, 42, 7, 12, 1,  6, 5,  4, 8, 65, 0, 87, 3, 16, 6, 88, 2,  1
  };
  const int q2298[] = {
    9, 9, // Number of jobs and machines
    6, 82, 4, 43, 2, 96, 5, 38, 1,  7, 7, 64, 8, 46, 3, 77, 0, 10, 
    8,  3, 4, 28, 2, 55, 0, 67, 1, 70, 6, 88, 3, 20, 7, 37, 5, 58, 
    2, 24, 8, 92, 7, 13, 3, 84, 0, 71, 1, 37, 5, 25, 6, 20, 4, 25, 
    7,  2, 3, 76, 5, 79, 1, 87, 4, 73, 2, 34, 6, 97, 0, 42, 8,  2, 
    3,  1, 6, 39, 2, 48, 4, 32, 5, 88, 7, 49, 0, 66, 1, 27, 8, 68, 
    0, 41, 6, 15, 3, 57, 4, 19, 1, 11, 5,  1, 8, 25, 7,  5, 2,  8, 
    5, 94, 0, 72, 6, 62, 4, 59, 1, 95, 2, 81, 7, 42, 8, 52, 3, 81, 
    5, 51, 1, 31, 0, 76, 8, 27, 6,  2, 4, 75, 3, 66, 7, 97, 2, 95, 
    2, 43, 0, 30, 4, 44, 5, 30, 3, 45, 1, 75, 7, 85, 6, 34, 8, 67
  };
  const int q2299[] = {
    9, 9, // Number of jobs and machines
    0, 23, 1,  2, 7, 74, 4, 67, 8, 32, 2,  7, 6, 73, 5, 22, 3, 14, 
    8, 35, 1, 55, 4, 96, 5, 84, 6, 68, 3, 20, 7, 85, 2, 63, 0, 25, 
    5,  1, 2, 10, 7, 89, 6, 84, 3, 45, 1, 23, 0, 31, 4, 57, 8, 52, 
    3, 83, 7, 79, 4,  2, 0, 33, 1, 98, 2, 92, 5, 12, 6, 23, 8, 36, 
    4, 88, 3, 63, 5, 59, 2, 15, 1, 60, 7, 26, 6, 32, 0, 22, 8, 29, 
    3, 63, 0, 91, 7, 32, 6, 94, 2, 86, 4, 31, 8, 94, 5, 78, 1, 16, 
    7, 19, 1, 91, 6, 92, 4, 78, 3, 85, 5, 28, 2, 41, 0, 55, 8, 21, 
    7, 53, 0, 73, 3, 31, 4, 28, 5, 34, 6, 97, 2, 18, 1, 72, 8, 13, 
    0, 94, 3, 97, 1, 69, 6, 95, 8, 36, 4,  4, 5, 43, 7, 35, 2, 18
  };
  const int q2300[] = {
    9, 9, // Number of jobs and machines
    5, 93, 6, 65, 7,  2, 8, 39, 2, 34, 0,  6, 4, 11, 3, 44, 1, 25, 
    4,  9, 5,  1, 0, 42, 7, 79, 6, 43, 1, 15, 3, 92, 8, 10, 2, 28, 
    7, 78, 1,  4, 6,  4, 5, 45, 8, 76, 4, 91, 2, 54, 3, 91, 0, 13, 
    2, 49, 0, 56, 8,  5, 5, 39, 6, 78, 4,  9, 7, 48, 1, 65, 3, 96, 
    1, 72, 6, 35, 2, 21, 8, 77, 7,  7, 0,  6, 4, 12, 3, 85, 5, 38, 
    3, 80, 6, 31, 0, 76, 7,  5, 4,  5, 2,  2, 8, 35, 5, 44, 1, 88, 
    3, 71, 8, 45, 7, 79, 5, 22, 4,  7, 6, 54, 0, 28, 1,  6, 2,  9, 
    8, 87, 1, 58, 5, 33, 4, 35, 3, 65, 0, 13, 2, 92, 6, 85, 7, 32, 
    1, 14, 0, 87, 7, 51, 4, 99, 5,  4, 2, 11, 3, 10, 6, 89, 8, 57
  };
  const int q2301[] = {
    9, 9, // Number of jobs and machines
    3, 98, 2,  8, 8, 66, 1, 50, 6, 29, 4, 22, 7, 81, 5, 72, 0, 52, 
    4, 76, 2, 84, 6, 37, 5,  5, 1, 98, 0, 48, 8, 23, 7, 47, 3, 80, 
    8, 17, 7, 92, 3, 39, 4, 10, 6,  1, 0, 72, 2, 43, 5,  7, 1, 55, 
    1, 99, 8, 72, 3, 74, 5, 30, 0, 52, 2, 73, 4, 69, 6, 61, 7, 35, 
    4, 29, 2, 37, 1, 76, 8, 19, 7,  9, 3, 18, 0,  8, 5, 99, 6, 93, 
    1, 81, 8, 96, 0, 19, 3, 80, 4, 30, 7, 31, 2, 20, 5, 34, 6, 53, 
    3, 68, 6, 56, 4, 78, 7, 74, 8, 91, 5,  5, 2, 31, 1, 13, 0, 29, 
    6, 22, 5, 52, 1, 33, 3, 10, 8, 64, 7, 69, 2, 28, 0, 88, 4, 32, 
    0, 83, 2, 90, 3, 94, 7, 36, 6, 89, 8, 30, 5, 62, 4,  4, 1, 74
  };
  const int q2302[] = {
    9, 9, // Number of jobs and machines
    2, 80, 7, 90, 6, 27, 4, 57, 3, 85, 8, 31, 0,  4, 5, 37, 1, 64, 
    4, 48, 6, 35, 3, 75, 2, 46, 1, 48, 7, 19, 8, 61, 5, 42, 0, 83, 
    2, 13, 1, 63, 6, 34, 8, 25, 0, 92, 5, 10, 3, 92, 4, 84, 7, 85, 
    6, 38, 4, 10, 7, 30, 0, 27, 5, 97, 3, 28, 8, 67, 2, 35, 1, 51, 
    6, 98, 0, 81, 8, 86, 1,  3, 2, 58, 4, 80, 5, 29, 7, 94, 3,  7, 
    1, 90, 2, 92, 3, 41, 0, 68, 7, 37, 8, 45, 6, 67, 5, 45, 4, 18, 
    1, 58, 0, 47, 8, 62, 2, 45, 4, 39, 7, 24, 3, 48, 6,  6, 5, 62, 
    2, 61, 6, 50, 8, 41, 5, 40, 0, 64, 1, 44, 3,  8, 7, 52, 4, 61, 
    8, 48, 4, 98, 3, 71, 2, 26, 6, 49, 0, 94, 5, 72, 1, 95, 7,  4
  };
  const int q2303[] = {
    9, 9, // Number of jobs and machines
    8,  4, 4, 11, 7, 14, 2, 53, 6,  5, 1, 98, 5, 43, 3, 84, 0, 32, 
    3, 86, 6,  5, 4, 36, 2, 54, 1, 71, 5, 69, 7, 48, 8, 52, 0, 46, 
    4, 85, 2, 17, 8, 80, 1, 40, 0, 58, 3, 60, 5, 97, 6, 56, 7, 65, 
    3, 72, 8, 99, 1, 51, 7, 25, 6, 69, 0, 46, 5, 59, 2, 50, 4, 94, 
    2, 53, 7, 88, 6,  7, 4, 42, 1,  6, 8, 82, 5, 88, 0, 30, 3,  4, 
    8, 18, 4, 30, 2, 18, 6, 73, 5, 54, 0, 47, 7, 58, 3, 34, 1, 99, 
    4, 72, 2, 54, 6, 45, 3,  1, 1, 18, 8, 19, 7, 44, 0, 42, 5, 82, 
    1, 26, 3, 26, 8, 48, 2, 99, 4, 85, 6, 14, 7, 86, 0, 86, 5, 47, 
    1, 10, 4, 93, 0, 81, 2, 36, 5, 71, 8, 57, 6, 52, 3, 64, 7,  4
  };
  const int q2304[] = {
    9, 9, // Number of jobs and machines
    6, 97, 1, 15, 7,  8, 5, 99, 8, 65, 4, 57, 2, 67, 0, 12, 3, 58, 
    7, 61, 0, 38, 3, 43, 8,  4, 6,  8, 1, 18, 5, 45, 4, 45, 2, 53, 
    5, 31, 8, 50, 7, 24, 3,  7, 1, 29, 0,  5, 4, 13, 2, 96, 6,  1, 
    2, 65, 7, 28, 1, 61, 4, 12, 0, 58, 8, 61, 5, 65, 3, 17, 6, 54, 
    7, 81, 2, 16, 3, 27, 5, 70, 6, 63, 4, 79, 1, 25, 0, 85, 8, 86, 
    0, 11, 5, 55, 4, 53, 8,  2, 1, 55, 2, 69, 7, 21, 6,  2, 3,  7, 
    4, 36, 3, 48, 2, 66, 0,  9, 8, 13, 5, 81, 1, 12, 6, 59, 7, 73, 
    4, 10, 3, 71, 5, 40, 1,  3, 7, 43, 0, 80, 2, 73, 6, 90, 8, 58, 
    4, 66, 0,  4, 6,  5, 3, 94, 5,  6, 2, 77, 8, 26, 1, 60, 7, 42
  };
  const int q2305[] = {
    9, 9, // Number of jobs and machines
    3,  1, 0, 24, 5, 62, 1, 77, 7, 16, 2, 85, 6, 48, 4, 53, 8, 54, 
    4, 74, 8, 16, 5, 73, 7, 40, 6, 15, 2, 36, 3, 45, 0, 13, 1, 69, 
    1,  6, 4, 76, 7, 19, 3, 94, 8, 14, 0,  5, 5, 86, 6, 34, 2,  7, 
    1, 39, 5, 41, 6, 16, 0, 29, 7, 59, 3, 21, 4,  1, 2, 75, 8, 68, 
    4, 66, 5, 93, 3, 23, 1, 97, 7, 71, 0, 54, 6, 73, 8, 11, 2, 35, 
    3, 25, 8, 12, 6, 16, 7, 86, 4, 87, 5, 45, 0, 57, 1,  4, 2, 31, 
    6, 32, 2, 83, 1, 12, 4, 89, 5, 43, 3,  2, 7, 99, 0, 64, 8, 49, 
    1, 22, 2, 54, 5, 10, 7, 91, 6, 78, 8,  1, 0, 64, 3, 14, 4, 49, 
    7, 27, 8,  6, 6,  3, 2, 32, 5, 78, 0, 34, 4, 37, 3, 35, 1, 89
  };
  const int q2306[] = {
    9, 9, // Number of jobs and machines
    4, 38, 0, 39, 6, 81, 5, 76, 3, 40, 2, 70, 8, 86, 1, 62, 7, 38, 
    5, 55, 0, 42, 2,  4, 6, 96, 3, 20, 1, 55, 8,  9, 7, 28, 4, 24, 
    6, 36, 5, 54, 3, 24, 8, 52, 2, 53, 7, 82, 1, 53, 4, 82, 0, 23, 
    4, 69, 8, 31, 2, 56, 1,  3, 7, 94, 0, 42, 6,  1, 5, 93, 3, 50, 
    1,  1, 6, 18, 3, 50, 5,  9, 2, 31, 8, 92, 0,  2, 7, 66, 4, 64, 
    8, 29, 2, 40, 4, 63, 0, 50, 1, 68, 7, 31, 6, 97, 5,  1, 3, 83, 
    0, 98, 8, 35, 7, 32, 3, 12, 6, 34, 1,  9, 4, 11, 5, 18, 2, 26, 
    8, 33, 5, 16, 7,  7, 6, 74, 0, 13, 4,  1, 3, 96, 1, 14, 2, 12, 
    0, 76, 7, 67, 1, 95, 5, 17, 3, 72, 2, 68, 6, 93, 4, 76, 8,  1
  };
  const int q2307[] = {
    9, 9, // Number of jobs and machines
    3, 88, 6, 78, 5, 14, 7, 10, 4, 84, 1,  9, 0, 90, 8, 89, 2, 58, 
    8, 42, 2, 12, 7, 80, 0, 62, 3, 56, 6, 27, 4, 40, 5,  9, 1,  7, 
    3, 67, 7, 36, 5, 46, 2, 79, 0, 64, 1, 25, 4, 47, 6, 36, 8, 85, 
    3, 95, 5, 99, 2, 62, 0,  9, 7,  6, 4, 66, 8, 77, 1, 38, 6, 64, 
    2, 60, 0, 79, 8, 58, 5, 35, 6, 65, 4,  4, 3, 49, 7, 98, 1, 79, 
    8, 46, 5, 64, 1, 78, 3, 77, 7, 51, 2, 39, 4, 67, 0, 97, 6,  8, 
    6, 96, 8, 33, 3, 77, 1, 57, 5, 32, 7, 92, 2, 87, 0, 92, 4, 35, 
    7, 18, 4, 52, 0, 51, 2, 41, 8, 79, 3, 98, 6, 79, 1, 31, 5, 52, 
    5, 18, 0, 11, 2, 30, 8, 63, 4, 13, 6, 17, 7, 88, 1,  5, 3, 90
  };
  const int q2308[] = {
    9, 9, // Number of jobs and machines
    7, 94, 6, 54, 2, 13, 1, 44, 4, 58, 3, 61, 5, 36, 8, 18, 0, 54, 
    8, 52, 3,  4, 4, 99, 7, 14, 2, 29, 6, 80, 5, 50, 0, 10, 1, 47, 
    1, 87, 5, 18, 8, 61, 0, 24, 6, 61, 7, 52, 3, 36, 4, 50, 2, 45, 
    6, 49, 3, 33, 1, 21, 2, 90, 7, 10, 0, 24, 5, 58, 4, 72, 8, 55, 
    2, 24, 5, 60, 7, 45, 8, 11, 3, 57, 6, 11, 4, 95, 0, 76, 1,  1, 
    2, 62, 1, 95, 0, 65, 4, 41, 7, 79, 5, 16, 6, 17, 3, 79, 8, 33, 
    1, 81, 8, 40, 3, 25, 7, 75, 5, 41, 4,  5, 2, 18, 6, 63, 0, 82, 
    5, 98, 8, 91, 2, 72, 6, 17, 1, 11, 4, 17, 0, 17, 3, 16, 7, 34, 
    7, 55, 6, 98, 8, 42, 5, 56, 0, 35, 1,  1, 4, 22, 2, 95, 3,  6
  };
  const int q2309[] = {
    9, 9, // Number of jobs and machines
    1, 18, 6, 96, 0, 72, 3, 81, 8, 72, 7, 74, 2, 29, 5, 29, 4, 62, 
    2, 32, 5, 60, 4, 90, 1, 51, 0, 71, 8, 94, 7, 32, 3, 55, 6, 80, 
    3, 17, 0, 84, 5, 50, 2, 45, 8, 38, 1, 39, 4, 81, 7, 24, 6, 99, 
    3, 46, 5, 19, 4, 66, 7, 76, 8, 61, 0,  4, 2, 22, 6,  9, 1, 80, 
    3, 38, 4, 77, 2, 58, 8, 35, 1,  7, 6,  4, 0, 33, 5, 34, 7, 80, 
    7, 68, 0, 91, 5, 86, 4, 41, 1, 71, 6, 95, 3, 56, 8, 68, 2, 15, 
    6, 97, 8, 53, 4, 92, 7, 28, 5, 96, 1, 39, 0, 40, 3, 67, 2,  1, 
    0, 15, 2,  2, 1, 58, 7, 26, 3, 76, 8, 19, 4, 84, 6, 41, 5, 28, 
    8, 69, 1, 24, 2, 52, 4, 69, 3, 78, 6, 43, 5, 12, 7, 30, 0, 65
  };
  const int q2310[] = {
    9, 9, // Number of jobs and machines
    0, 11, 3,  4, 2, 30, 8, 38, 7, 65, 4, 27, 6,  3, 5, 89, 1, 41, 
    7, 25, 1, 97, 5,  7, 4, 42, 6, 13, 3, 91, 2, 46, 8, 95, 0,  8, 
    7,  5, 8, 29, 4, 86, 0, 32, 1, 35, 5, 14, 6, 53, 2, 26, 3, 10, 
    3,  6, 0, 97, 8, 26, 5, 30, 2, 71, 4, 34, 7, 39, 6, 82, 1, 78, 
    8, 38, 4,  9, 7, 86, 6, 80, 5, 30, 3, 34, 2, 26, 0, 64, 1, 32, 
    7, 11, 8,  6, 0, 66, 5, 97, 4, 80, 6, 66, 3,  6, 2, 51, 1, 32, 
    1, 32, 7, 93, 0, 89, 6, 47, 2, 35, 8, 92, 5, 32, 3, 84, 4, 86, 
    4, 64, 2, 83, 8, 61, 0, 70, 5,  8, 1, 98, 3, 53, 7, 86, 6, 55, 
    4, 31, 5, 22, 1, 89, 3, 25, 8, 76, 0, 38, 7, 73, 6, 56, 2, 74
  };
  const int q2311[] = {
    9, 9, // Number of jobs and machines
    8, 97, 7, 96, 1, 22, 0, 59, 4, 93, 5, 98, 3, 41, 2, 59, 6, 89, 
    4, 11, 5,  5, 6, 86, 0, 24, 7, 53, 2, 86, 8, 80, 3,  5, 1, 81, 
    8, 30, 5, 32, 6, 33, 0, 31, 1, 95, 2, 60, 3, 56, 7, 25, 4, 83, 
    7,  6, 3, 30, 2, 72, 0,  4, 8, 61, 4, 77, 6, 33, 1, 63, 5, 41, 
    0, 44, 7, 66, 8, 38, 2, 23, 6, 72, 5, 15, 1, 43, 4, 30, 3, 32, 
    0, 47, 7, 65, 2, 29, 8, 81, 1, 34, 4, 57, 5, 82, 3, 31, 6, 81, 
    5, 14, 4, 56, 0, 15, 2, 35, 3, 85, 8,  6, 1, 20, 6, 89, 7, 92, 
    0, 48, 1, 22, 3, 94, 6, 52, 7, 55, 4, 98, 2,  4, 5, 32, 8, 30, 
    5, 16, 7, 28, 4, 38, 8, 37, 1, 97, 3, 98, 2, 50, 0, 36, 6, 22
  };
  const int q2312[] = {
    9, 9, // Number of jobs and machines
    7, 44, 3, 36, 0, 67, 4, 27, 5, 79, 8, 20, 1, 52, 6, 76, 2, 16, 
    6, 71, 0, 15, 7, 25, 8, 46, 5, 17, 3, 48, 1, 66, 2, 82, 4, 34, 
    3, 25, 8, 93, 6, 43, 5, 54, 1, 52, 7, 18, 2,  7, 0, 45, 4, 28, 
    5, 63, 6, 25, 0, 36, 2, 56, 3, 82, 4, 11, 7, 89, 1, 11, 8, 32, 
    1, 38, 8,  7, 5, 24, 2,  9, 7, 28, 4, 92, 6, 43, 0, 16, 3, 39, 
    7, 59, 2, 91, 6, 48, 5, 97, 1, 69, 3, 63, 8, 53, 4, 90, 0, 51, 
    6, 25, 1, 51, 0, 95, 3, 88, 7, 73, 4, 68, 5, 17, 2, 50, 8, 58, 
    8, 13, 2,  5, 3, 70, 1, 90, 4, 18, 7, 46, 5,  9, 6, 34, 0, 36, 
    0, 36, 5, 81, 4, 83, 7, 60, 1, 90, 2, 41, 3, 30, 8, 27, 6, 46
  };
  const int q2313[] = {
    9, 9, // Number of jobs and machines
    0, 63, 6, 89, 2, 58, 3, 31, 4, 43, 5, 80, 1, 39, 7, 17, 8, 39, 
    7,  5, 1, 53, 6, 58, 3, 31, 2,  5, 5, 15, 0, 61, 8, 45, 4, 50, 
    4, 92, 5, 80, 8, 34, 7, 59, 0, 12, 2, 65, 6, 77, 3, 64, 1, 42, 
    4, 21, 3, 25, 0, 22, 6, 94, 5, 35, 8, 33, 7, 33, 1, 20, 2, 98, 
    1, 91, 7, 56, 5, 64, 0, 62, 6, 73, 2,  9, 3, 15, 8, 16, 4, 44, 
    5, 85, 7, 45, 8,  8, 4, 58, 1, 12, 6, 26, 2, 25, 3, 76, 0, 32, 
    6, 30, 2, 57, 8, 57, 3, 44, 7, 43, 1, 59, 5, 54, 0, 77, 4, 79, 
    0, 64, 5, 66, 4, 65, 6, 60, 1, 88, 8, 17, 2,  7, 7, 52, 3,  3, 
    7, 65, 5, 75, 1, 31, 4, 94, 8, 27, 2, 69, 6, 23, 0, 22, 3, 22
  };
  const int q2314[] = {
    9, 9, // Number of jobs and machines
    3, 56, 1, 81, 0, 17, 4, 43, 8, 61, 7, 25, 5, 61, 6, 58, 2, 83, 
    6, 11, 5, 82, 2, 68, 8, 25, 3, 81, 0, 35, 1, 59, 7, 80, 4, 92, 
    3, 38, 1, 91, 2, 20, 7, 60, 6, 18, 0, 12, 4, 20, 5, 22, 8, 20, 
    3, 11, 8, 30, 0, 45, 4, 94, 5, 12, 1, 45, 6, 35, 2, 18, 7, 85, 
    8, 82, 7, 28, 6, 68, 2, 95, 3, 37, 1, 47, 0, 49, 4, 79, 5, 87, 
    0, 67, 5, 43, 4, 25, 2, 27, 8, 38, 1, 14, 6, 23, 7, 69, 3, 70, 
    7, 53, 8, 77, 4,  5, 6,  2, 2, 14, 1, 26, 5, 24, 3, 71, 0, 79, 
    1, 12, 6, 54, 0, 78, 5, 84, 2, 24, 7, 32, 8, 22, 4, 34, 3, 85, 
    3,  8, 2, 30, 0,  1, 7,  7, 6, 59, 1, 11, 4, 83, 5, 40, 8, 11
  };
  const int q2315[] = {
    9, 9, // Number of jobs and machines
    8, 53, 2, 89, 0, 83, 6, 69, 5, 24, 4, 12, 1, 71, 3, 93, 7, 21, 
    2,  8, 6,  8, 0, 69, 4,  7, 7, 46, 3,  8, 1,  2, 8, 28, 5, 21, 
    8,  1, 6, 37, 7, 52, 1, 87, 3, 16, 0, 92, 2, 35, 5, 29, 4, 94, 
    2,  4, 7, 82, 5, 75, 8, 73, 1, 29, 0, 35, 6,  3, 4, 86, 3, 44, 
    2, 80, 5, 64, 0, 87, 1, 88, 6, 10, 8, 52, 3,  1, 4, 31, 7, 89, 
    1, 74, 7, 45, 0, 41, 2, 86, 8,  6, 6, 97, 3, 90, 5, 33, 4, 25, 
    5, 72, 6, 50, 7, 37, 2, 66, 1, 40, 0, 19, 4, 85, 3, 58, 8, 19, 
    4, 25, 2, 71, 1, 81, 5, 54, 6,  7, 3, 17, 0, 23, 7, 61, 8, 25, 
    4, 78, 0, 22, 6, 75, 8, 64, 2, 29, 1, 39, 7, 37, 5, 53, 3, 55
  };
  const int q2316[] = {
    9, 9, // Number of jobs and machines
    2, 39, 5, 74, 8, 42, 0, 37, 7, 46, 1, 39, 3, 76, 4,  8, 6, 84, 
    4, 45, 3, 74, 8, 45, 0, 61, 7, 80, 6, 56, 5, 70, 2, 66, 1, 14, 
    3, 31, 1, 67, 7, 20, 2, 33, 4, 31, 6, 82, 5, 35, 8, 15, 0, 81, 
    5, 36, 4, 94, 6, 68, 7, 52, 8,  4, 2, 26, 0, 18, 3, 65, 1,  6, 
    1, 17, 2, 21, 8, 62, 6, 48, 3, 44, 5, 60, 7, 42, 0, 40, 4, 31, 
    6, 90, 4, 21, 3,  3, 0, 11, 8, 96, 1, 56, 7, 34, 5, 22, 2, 37, 
    3, 86, 6, 49, 4, 18, 1, 22, 7, 59, 0, 48, 8, 71, 2, 99, 5, 32, 
    5, 33, 2, 13, 7, 82, 6, 44, 4, 49, 3, 74, 8, 60, 0, 32, 1, 39, 
    0, 88, 7,  4, 1, 89, 3, 65, 6, 26, 2, 12, 8, 79, 5, 42, 4, 93
  };
  const int q2317[] = {
    9, 9, // Number of jobs and machines
    5,  7, 8, 61, 3, 25, 6, 83, 2, 53, 0, 39, 7, 95, 4, 81, 1, 43, 
    4, 22, 3, 95, 6,  8, 7,  7, 0, 83, 5, 59, 2, 48, 8, 64, 1, 54, 
    7, 20, 6, 29, 3, 78, 8, 82, 5, 36, 4, 77, 2, 40, 0, 10, 1, 83, 
    7, 28, 4, 42, 5, 80, 6, 48, 0, 62, 3, 78, 1, 68, 2, 99, 8, 41, 
    0, 11, 1, 33, 8,  2, 4, 57, 6, 18, 7, 54, 5, 81, 3, 98, 2, 50, 
    6, 28, 5, 35, 3, 98, 1, 39, 0, 73, 4, 85, 2, 81, 7,  7, 8, 66, 
    2, 88, 8,  1, 5, 92, 1, 21, 4, 27, 0, 37, 6, 74, 3, 69, 7, 87, 
    0, 36, 4, 55, 1, 11, 7, 38, 2, 49, 6, 57, 3, 67, 8, 69, 5, 81, 
    8,  9, 1,  1, 3, 56, 7, 70, 6, 88, 5, 31, 0, 51, 2, 53, 4, 52
  };
  const int q2318[] = {
    9, 9, // Number of jobs and machines
    7, 67, 5, 31, 4, 45, 8, 65, 3, 61, 0, 70, 2, 10, 6, 30, 1, 65, 
    1, 94, 2, 34, 0, 95, 6, 25, 5, 23, 8, 70, 4, 65, 3, 68, 7, 65, 
    1, 13, 3, 48, 0, 38, 5, 70, 4, 15, 7, 13, 2, 24, 6, 28, 8, 29, 
    2, 54, 8, 13, 1, 74, 4, 68, 6, 10, 5, 14, 0, 45, 7, 62, 3, 27, 
    3,  2, 2, 16, 0, 11, 4, 17, 8, 32, 5, 25, 1, 24, 7, 23, 6, 67, 
    0, 80, 3, 22, 8, 58, 5, 27, 6, 54, 2, 79, 4,  1, 1, 65, 7, 53, 
    3,  4, 6, 65, 2, 22, 8, 60, 4, 15, 0, 62, 5,  9, 7, 86, 1,  6, 
    3, 91, 6, 81, 0, 91, 7, 73, 2, 36, 4, 83, 1, 78, 8, 53, 5, 51, 
    8, 70, 1, 58, 5, 81, 7, 76, 6,  1, 3, 69, 4, 79, 2, 89, 0, 87
  };
  const int q2319[] = {
    9, 9, // Number of jobs and machines
    3, 79, 0, 64, 7, 10, 6, 29, 5, 81, 2,  4, 1, 74, 8, 50, 4, 69, 
    1, 77, 4, 17, 2, 82, 7, 49, 5,  5, 6, 50, 3, 83, 0, 65, 8, 19, 
    5, 47, 8, 94, 7, 24, 3, 91, 2, 45, 0, 90, 4, 82, 1, 96, 6, 89, 
    4, 63, 0, 27, 8, 27, 6,  6, 1, 40, 2, 97, 5, 37, 3, 71, 7, 83, 
    1, 11, 0, 31, 3, 18, 7, 70, 6, 26, 8, 91, 5, 21, 2, 95, 4, 12, 
    8, 34, 7, 81, 0, 88, 2, 14, 4, 60, 3, 75, 6, 45, 1, 90, 5, 80, 
    4, 53, 6, 32, 2, 19, 1, 54, 3, 95, 7, 53, 8, 36, 0, 85, 5,  8, 
    7, 92, 4, 54, 1, 79, 8,  4, 0, 42, 3,  4, 2, 38, 5, 16, 6, 38, 
    7, 19, 8, 66, 6, 38, 2, 17, 1, 43, 0, 99, 4, 76, 3, 64, 5, 12
  };
  const int q2320[] = {
    9, 9, // Number of jobs and machines
    0, 43, 6, 68, 1, 26, 7, 68, 4, 22, 3, 25, 5, 40, 8, 71, 2, 53, 
    0, 82, 3, 25, 5, 91, 1, 17, 8, 51, 6, 88, 7,  8, 2, 43, 4, 79, 
    8, 71, 6, 33, 2, 56, 5,  4, 0,  5, 7,  9, 1, 91, 4, 91, 3, 69, 
    7, 22, 3, 40, 8, 77, 2, 38, 4, 36, 1, 93, 6,  1, 0, 58, 5,  5, 
    1,  8, 4, 57, 6, 23, 5, 24, 8, 46, 3, 95, 7, 93, 2, 13, 0, 67, 
    6,  5, 8,  2, 2, 59, 1,  9, 0, 80, 7, 88, 4,  7, 5, 29, 3, 62, 
    6, 67, 3, 95, 0, 40, 1, 65, 4, 80, 7, 43, 2, 72, 8, 21, 5, 26, 
    8, 75, 7, 52, 5, 59, 6, 95, 3, 53, 1, 18, 0, 45, 2,  8, 4, 94, 
    2, 34, 7, 23, 0, 59, 6, 89, 3, 47, 4, 63, 5, 88, 8, 60, 1, 16
  };
  const int q2321[] = {
    9, 9, // Number of jobs and machines
    6, 39, 3, 80, 5, 91, 1, 78, 7, 64, 8, 25, 4, 90, 0, 58, 2, 80, 
    0, 20, 8, 96, 4, 77, 1, 39, 5, 76, 2, 73, 7, 30, 6, 10, 3, 88, 
    6, 75, 8, 45, 7,  1, 0, 37, 5, 71, 1, 65, 4, 43, 3, 15, 2, 67, 
    0, 18, 7, 68, 5, 44, 8, 76, 2, 68, 4, 53, 1, 70, 3, 39, 6,  7, 
    1, 52, 6, 80, 2, 98, 4, 63, 8, 72, 0, 28, 3,  2, 5, 29, 7, 92, 
    5, 52, 3, 47, 0, 92, 7, 99, 4, 39, 1, 91, 8, 67, 2, 58, 6, 50, 
    1, 46, 6,  3, 4, 49, 8, 14, 7, 47, 2, 39, 3, 93, 0, 99, 5, 30, 
    7, 84, 6, 98, 4, 30, 8, 23, 1, 96, 0, 21, 3, 63, 2, 75, 5, 95, 
    1, 72, 6, 25, 2, 78, 3,  9, 8, 12, 4, 35, 5, 99, 0, 19, 7, 57
  };
  const int q2322[] = {
    9, 9, // Number of jobs and machines
    6, 72, 7, 89, 4, 81, 8, 70, 0, 78, 5, 59, 1, 15, 3, 50, 2, 37, 
    0, 56, 8, 36, 5, 31, 4, 21, 2, 34, 6, 83, 1, 88, 3, 93, 7, 55, 
    5, 58, 6,  5, 3, 37, 0, 64, 8, 15, 4, 62, 1, 63, 7, 99, 2, 56, 
    7, 89, 3,  7, 0, 96, 4, 14, 2, 67, 1, 93, 6, 17, 5, 87, 8, 20, 
    3, 72, 0, 25, 6, 62, 1, 92, 8, 53, 7, 24, 4, 66, 5, 91, 2, 97, 
    0, 93, 2, 34, 6, 18, 1, 60, 7, 20, 3,  9, 5, 19, 8, 51, 4,  8, 
    8, 51, 4, 92, 5, 48, 7, 84, 0, 81, 3, 52, 6, 96, 1, 24, 2, 12, 
    2, 85, 8, 88, 6, 34, 3, 86, 4, 94, 0, 33, 7, 84, 5, 75, 1, 28, 
    4, 57, 3, 98, 5, 59, 2, 42, 1, 31, 8, 87, 6, 31, 7, 64, 0, 91
  };
  const int q2323[] = {
    9, 9, // Number of jobs and machines
    3, 12, 5, 61, 7, 95, 4, 56, 6,  5, 1, 48, 2, 98, 8, 61, 0,  5, 
    0, 16, 4, 39, 5,  6, 8, 88, 1, 32, 3,  7, 2, 47, 6, 81, 7, 97, 
    2, 27, 5, 27, 7, 80, 4, 66, 1, 33, 6, 57, 8, 39, 3, 36, 0, 94, 
    4, 98, 5, 36, 2, 56, 8, 31, 0,  2, 1,  3, 6, 42, 3, 33, 7,  2, 
    4, 48, 3, 88, 2, 54, 1, 58, 8, 23, 0, 32, 5, 93, 6, 14, 7, 93, 
    0, 28, 6, 54, 3, 58, 7, 26, 2,  9, 5, 79, 4, 98, 8, 33, 1, 59, 
    8, 61, 7, 21, 5,  8, 0, 78, 4, 78, 3, 19, 2, 24, 1, 26, 6, 29, 
    3, 72, 4, 53, 0, 73, 5,  9, 1, 45, 8, 73, 2, 64, 6, 92, 7, 30, 
    0, 66, 3, 19, 7, 88, 2, 79, 1, 26, 8, 43, 4, 75, 5, 22, 6, 22
  };
  const int q2324[] = {
    9, 9, // Number of jobs and machines
    1, 60, 4, 36, 3, 65, 8, 50, 6, 48, 5,  1, 0, 35, 7, 52, 2, 86, 
    2, 64, 1, 96, 6, 56, 4, 68, 8, 41, 5, 16, 3, 85, 0, 35, 7,  7, 
    4, 97, 2, 18, 6,  1, 5,  2, 8, 14, 7, 16, 3, 82, 1, 49, 0, 94, 
    4, 43, 8, 40, 0, 86, 5, 97, 2, 90, 7, 30, 1, 21, 3, 89, 6, 63, 
    6, 21, 4,  7, 3, 21, 8, 34, 7,  5, 5, 47, 2,  5, 1,  9, 0, 55, 
    6, 24, 2, 93, 8, 36, 3, 71, 4,  4, 7, 19, 5, 77, 1,  6, 0, 29, 
    7, 47, 0, 32, 2, 10, 8, 90, 1, 39, 6, 72, 4,  3, 3, 82, 5, 44, 
    8, 94, 6, 81, 7, 50, 1,  8, 2, 96, 0, 41, 4, 25, 5, 58, 3, 37, 
    6, 20, 3, 29, 0,  8, 7, 25, 1, 56, 2, 77, 5, 99, 8, 39, 4, 80
  };
  const int q2325[] = {
    9, 9, // Number of jobs and machines
    3, 96, 5,  6, 8, 71, 7, 55, 4, 81, 6, 82, 0, 74, 1,  8, 2, 82, 
    1,  9, 8, 98, 4,  5, 3, 54, 6, 55, 5, 93, 2, 24, 7, 81, 0, 92, 
    1, 11, 4, 55, 0, 74, 6, 26, 2, 91, 7,  7, 8, 58, 3, 65, 5, 60, 
    8, 93, 1, 95, 6, 30, 2, 82, 3, 45, 7, 35, 0, 40, 4, 71, 5,  3, 
    0, 79, 2, 74, 3, 47, 6, 59, 7, 14, 1, 12, 4, 78, 5, 68, 8, 75, 
    8, 78, 5, 96, 1,  9, 2, 61, 3, 49, 6, 98, 4, 51, 0, 67, 7, 58, 
    0, 43, 4, 43, 5, 73, 6, 23, 8, 91, 2, 11, 1, 86, 3, 87, 7, 46, 
    6, 88, 7, 15, 1, 37, 5, 62, 4, 46, 2, 17, 0, 87, 3, 34, 8, 98, 
    1, 51, 3, 72, 7,  3, 5, 80, 4,  3, 0, 62, 6, 64, 2, 34, 8, 12
  };
  const int q2326[] = {
    9, 9, // Number of jobs and machines
    2, 23, 7, 86, 0, 42, 5, 16, 6, 82, 8,  9, 3, 90, 1, 51, 4, 64, 
    2, 10, 7, 89, 8, 20, 0, 20, 1, 88, 3, 73, 6, 96, 4, 81, 5, 11, 
    5, 78, 8, 33, 0,  6, 2, 96, 1, 40, 6, 24, 4, 90, 3, 43, 7, 57, 
    3, 42, 6, 60, 4, 68, 1,  4, 7, 50, 8, 27, 5, 71, 0, 37, 2, 76, 
    0, 14, 7, 23, 2, 73, 4, 77, 6, 22, 1, 25, 5, 61, 8,  5, 3, 38, 
    6, 47, 5, 33, 1, 18, 4, 85, 3,  5, 0, 79, 2, 19, 8, 90, 7, 78, 
    1, 11, 4, 70, 2, 87, 3, 58, 0, 75, 8, 14, 5, 50, 7, 96, 6, 24, 
    4, 92, 5, 83, 2, 12, 1, 77, 0, 47, 7,  8, 8, 70, 6, 28, 3, 20, 
    2, 32, 6, 76, 1, 34, 8, 64, 4, 98, 0, 13, 3, 59, 7, 99, 5, 37
  };
  const int q2327[] = {
    9, 9, // Number of jobs and machines
    0, 14, 1, 44, 8, 29, 6, 59, 3, 61, 4, 34, 5,  5, 2, 73, 7, 45, 
    1, 92, 7, 89, 5, 87, 2, 80, 3, 80, 0, 90, 8, 83, 4, 91, 6, 69, 
    2, 92, 1, 74, 7, 25, 4, 77, 6, 74, 3, 44, 8, 39, 0, 58, 5, 61, 
    7, 62, 6, 78, 3, 96, 1, 49, 5, 43, 4, 26, 0, 18, 8, 19, 2, 68, 
    7,  9, 0, 94, 8, 11, 5, 28, 2, 71, 3, 87, 1, 89, 4,  4, 6, 53, 
    3, 14, 4, 32, 6, 31, 7, 99, 5,  6, 2, 19, 1, 87, 0, 79, 8, 45, 
    1, 42, 2, 33, 6, 84, 8, 27, 4, 84, 5, 86, 3,  2, 7, 39, 0, 27, 
    0, 39, 5, 81, 6, 29, 1, 95, 8, 96, 7, 85, 3, 89, 2, 97, 4, 85, 
    2, 32, 0, 48, 3, 74, 4, 50, 8, 42, 5, 34, 7,  2, 1, 85, 6, 71
  };
  const int q2328[] = {
    9, 9, // Number of jobs and machines
    3, 66, 8,  4, 0, 11, 7, 49, 6, 20, 5, 58, 2, 74, 4, 60, 1, 97, 
    8, 54, 4, 24, 3, 53, 1, 88, 0, 98, 7, 40, 2, 19, 5, 21, 6, 92, 
    8, 24, 4, 24, 7, 61, 6, 62, 2, 62, 5,  7, 1, 32, 0, 62, 3, 12, 
    3, 98, 2, 76, 7, 68, 4, 10, 8, 37, 1, 94, 0, 61, 6, 32, 5, 62, 
    5, 28, 0, 45, 2, 45, 3, 63, 6, 63, 8, 81, 7,  1, 4, 55, 1, 95, 
    5, 34, 6, 41, 1, 16, 3, 47, 8, 12, 2, 73, 0, 10, 7, 76, 4,  2, 
    5, 58, 2, 68, 7, 60, 0, 23, 4, 67, 8, 39, 6, 29, 3, 56, 1, 91, 
    2, 61, 1, 51, 7, 66, 8, 91, 6,  5, 0, 63, 3,  6, 5, 40, 4, 95, 
    7, 37, 6, 55, 8, 60, 4, 32, 1, 98, 5, 36, 2, 66, 0, 34, 3, 83
  };
  const int q2329[] = {
    9, 9, // Number of jobs and machines
    0, 86, 3, 62, 2, 82, 8, 75, 7, 11, 1, 30, 5, 96, 4, 17, 6, 15, 
    0, 82, 3, 66, 6, 97, 8,  8, 7, 35, 4, 28, 5, 32, 1, 59, 2, 62, 
    2, 45, 7, 14, 8, 14, 0, 70, 3, 51, 4, 52, 5, 59, 1, 66, 6, 50, 
    1, 28, 8, 10, 4, 79, 6, 42, 0, 51, 5,  8, 7, 79, 3, 40, 2,  3, 
    6, 53, 4, 76, 5, 78, 1, 32, 8, 37, 0, 81, 2, 30, 7, 42, 3, 51, 
    3, 95, 7, 89, 4, 39, 6, 53, 2, 29, 1, 79, 5, 75, 0, 72, 8, 30, 
    1, 32, 6, 29, 0, 27, 7, 35, 4, 66, 2, 99, 8, 17, 5, 31, 3, 28, 
    0,  4, 3, 21, 7, 73, 2, 92, 4, 79, 1, 51, 8, 31, 6, 88, 5, 57, 
    2, 85, 3, 36, 5, 63, 7, 26, 6,  2, 1, 28, 4, 54, 0, 23, 8, 35
  };
  const int q2330[] = {
    9, 9, // Number of jobs and machines
    6, 63, 3, 13, 8, 64, 0, 83, 2, 94, 7, 82, 1,  6, 4,  6, 5, 36, 
    4, 18, 2, 74, 8, 10, 3, 89, 0, 76, 6, 38, 5, 75, 7, 11, 1, 88, 
    5, 45, 2, 59, 0, 35, 8, 70, 3, 89, 4, 24, 6, 71, 7, 64, 1, 99, 
    4, 29, 6, 19, 5, 74, 7,  5, 2, 10, 1, 90, 8, 58, 0, 91, 3, 71, 
    2, 52, 4, 74, 0, 83, 8, 56, 7, 45, 1, 32, 3, 46, 5, 94, 6,  3, 
    7, 84, 3, 62, 5, 79, 1, 63, 0, 13, 2, 43, 4, 73, 6, 21, 8, 84, 
    3, 63, 2, 42, 5, 67, 0, 43, 6, 36, 4,  7, 7, 88, 1, 23, 8, 94, 
    2, 13, 5, 34, 0,  1, 8, 99, 6, 95, 3, 49, 1, 96, 4, 95, 7, 86, 
    2,  7, 8, 15, 3, 30, 0,  9, 4,  9, 5, 95, 7, 83, 6, 23, 1, 89
  };
  const int q2331[] = {
    9, 9, // Number of jobs and machines
    2, 82, 6, 90, 8, 29, 1, 16, 3, 21, 5, 25, 7, 10, 0, 67, 4, 66, 
    3, 60, 4, 11, 5, 43, 2, 22, 8,  4, 7, 79, 0, 48, 6, 40, 1, 49, 
    7, 19, 2, 71, 3,  2, 0,  3, 6, 17, 5, 93, 8, 33, 4, 78, 1, 93, 
    0, 12, 7, 68, 1, 89, 4, 34, 3, 42, 5, 25, 6, 65, 8, 44, 2, 79, 
    0, 51, 1, 68, 8, 69, 3,  5, 7, 11, 5,  1, 4, 11, 2, 43, 6, 33, 
    5, 12, 4, 96, 7, 25, 1, 54, 2, 21, 3, 61, 8, 49, 6, 66, 0, 14, 
    0, 91, 8,  4, 4, 16, 2,  4, 6, 54, 5, 14, 1,  6, 7, 30, 3, 69, 
    7, 63, 4, 68, 0, 29, 5, 33, 8, 47, 1, 55, 3, 55, 6, 89, 2, 16, 
    4,  3, 2, 85, 8,  5, 3, 63, 6, 53, 0, 48, 5, 60, 1, 29, 7, 49
  };
  const int q2332[] = {
    9, 9, // Number of jobs and machines
    6,  7, 3, 35, 2, 54, 5, 99, 8, 48, 7, 92, 1, 57, 0, 88, 4, 78, 
    5, 24, 3, 68, 7, 48, 4, 60, 6, 80, 2, 98, 8, 64, 0, 17, 1, 22, 
    1, 59, 0, 82, 3, 55, 7, 23, 8, 69, 4, 73, 5, 90, 2, 27, 6, 45, 
    0, 89, 5,  1, 1, 58, 2, 28, 7,  9, 3, 66, 8, 86, 6, 39, 4, 65, 
    8, 87, 4, 70, 3, 18, 7, 53, 5, 30, 0, 71, 2, 44, 1, 15, 6, 98, 
    4, 45, 8,  6, 2, 53, 7, 47, 1, 84, 5, 32, 6, 63, 0, 49, 3, 12, 
    3, 55, 2, 99, 1, 81, 4, 27, 5, 64, 6, 67, 7, 90, 8, 92, 0, 65, 
    0, 48, 5, 29, 6, 59, 3,  1, 8, 63, 7, 17, 2, 42, 4, 57, 1, 42, 
    0, 29, 5, 73, 3, 75, 2, 85, 1,  3, 4, 16, 6, 34, 8,  6, 7,  1
  };
  const int q2333[] = {
    9, 9, // Number of jobs and machines
    7, 36, 6, 12, 4, 89, 3, 52, 2, 18, 0, 93, 1, 95, 5, 62, 8, 67, 
    1, 14, 4, 11, 5, 78, 6,  5, 2, 96, 3, 40, 7, 11, 0, 56, 8,  4, 
    7, 98, 8, 91, 0, 37, 2, 47, 6, 32, 5, 15, 4, 88, 3, 77, 1, 27, 
    2, 44, 0, 24, 3, 81, 8, 45, 4, 43, 1, 48, 6,  8, 7, 52, 5, 87, 
    0, 92, 7, 94, 8, 86, 6, 41, 2, 13, 3, 80, 1, 58, 4, 75, 5, 82, 
    0, 95, 4, 42, 8, 73, 7, 37, 5, 42, 6, 19, 3, 57, 2, 13, 1,  8, 
    1,  6, 4, 56, 7, 94, 0,  6, 8, 59, 6, 28, 3, 90, 2, 37, 5, 18, 
    7, 82, 5, 49, 8, 38, 2, 55, 3, 44, 6, 98, 1,  8, 4, 31, 0, 79, 
    6,  6, 3, 88, 4, 58, 8, 68, 5, 61, 0, 51, 2, 24, 1, 19, 7, 11
  };
  const int q2334[] = {
    9, 9, // Number of jobs and machines
    7, 10, 3, 39, 8, 45, 5, 52, 1, 11, 0, 78, 4, 16, 2, 85, 6, 76, 
    6, 54, 1, 61, 4, 18, 2, 72, 0,  1, 8,  6, 5, 24, 7, 33, 3, 92, 
    4, 38, 0,  4, 7, 18, 1, 75, 6, 74, 8,  5, 3, 94, 2, 90, 5, 11, 
    8, 11, 2, 30, 4, 12, 3, 63, 7, 91, 6, 74, 0, 40, 1, 45, 5,  6, 
    6, 99, 4, 30, 8, 29, 1, 26, 2, 17, 5, 93, 3, 29, 0, 90, 7, 26, 
    7, 74, 6, 63, 0,  3, 1, 52, 4, 28, 5, 50, 2,  9, 3,  9, 8, 15, 
    6,  3, 3, 83, 5, 89, 7, 11, 1, 41, 2, 96, 0, 44, 8, 89, 4, 32, 
    7, 71, 5, 28, 4, 12, 2, 29, 3, 57, 0, 57, 6, 47, 1, 40, 8, 77, 
    2, 89, 8, 87, 6, 35, 5, 98, 4,  3, 0, 34, 3, 60, 1, 81, 7, 52
  };
  const int q2335[] = {
    9, 9, // Number of jobs and machines
    1, 98, 0, 87, 3, 98, 8, 69, 7,  7, 5, 44, 6,  9, 4,  3, 2, 86, 
    0, 88, 2, 27, 7, 68, 8, 61, 4, 70, 5, 40, 3, 98, 1, 80, 6, 65, 
    2, 37, 7, 65, 6, 12, 1, 16, 8, 12, 0, 71, 3,  3, 5, 85, 4, 95, 
    2, 98, 7, 39, 5, 68, 0,  7, 3, 59, 6, 55, 1, 18, 8, 13, 4, 54, 
    8, 46, 1, 64, 7, 96, 0, 43, 2, 11, 5, 40, 6, 69, 4,  3, 3, 42, 
    2, 16, 3, 89, 5, 84, 8, 54, 7, 80, 1,  4, 0, 86, 6, 75, 4, 89, 
    3, 26, 2, 49, 7, 66, 6, 88, 8, 11, 0, 90, 5, 55, 1, 70, 4, 40, 
    8, 65, 6,  8, 3, 42, 2, 59, 5, 50, 0, 34, 1, 32, 7, 10, 4, 66, 
    5, 44, 0, 56, 2, 28, 4, 78, 1, 78, 6, 47, 8, 14, 3, 75, 7, 91
  };
  const int q2336[] = {
    9, 9, // Number of jobs and machines
    7, 71, 1, 83, 6, 53, 4, 29, 0, 11, 8, 26, 5, 80, 2, 63, 3, 51, 
    3, 38, 0, 17, 4, 71, 5, 50, 2, 13, 1, 15, 7, 59, 8, 97, 6, 66, 
    7, 22, 0, 70, 5,  4, 1, 68, 2, 52, 3, 17, 4, 91, 8, 18, 6, 71, 
    1, 59, 5, 21, 4, 64, 2, 96, 0,  1, 6, 55, 3, 75, 8, 43, 7, 52, 
    3, 44, 4, 19, 8, 66, 5, 47, 7, 29, 1, 70, 6, 54, 2, 90, 0, 88, 
    4, 72, 0, 96, 6,  2, 7, 44, 5, 38, 2, 37, 3, 10, 8, 34, 1, 19, 
    3, 81, 2, 61, 1, 88, 4,  2, 7, 79, 0, 31, 5, 46, 8, 85, 6, 16, 
    8, 46, 7,  3, 5, 61, 0, 97, 6, 29, 1, 19, 3, 71, 2, 71, 4, 99, 
    7, 86, 3, 58, 6, 39, 0,  9, 8, 86, 4, 96, 2, 49, 5, 31, 1, 32
  };
  const int q2337[] = {
    9, 9, // Number of jobs and machines
    5, 30, 8,  2, 2, 53, 6, 34, 3, 11, 0, 74, 1, 81, 4, 73, 7, 56, 
    2, 68, 3, 51, 4,  7, 1, 64, 6, 31, 8, 82, 0, 35, 5, 91, 7, 19, 
    5, 20, 8, 71, 4, 43, 0,  7, 2, 14, 1,  8, 3, 69, 6, 70, 7, 71, 
    2,  8, 6, 59, 5,  5, 7, 63, 0, 34, 4, 51, 1, 48, 3, 88, 8, 86, 
    6, 56, 4, 85, 8, 77, 2, 85, 5,  5, 3, 50, 1, 20, 0, 82, 7,  2, 
    6, 96, 7, 38, 2, 88, 0, 23, 4, 21, 3, 36, 5, 66, 8,  5, 1,  2, 
    6, 37, 5, 27, 7,  3, 4, 91, 3,  7, 8, 12, 1, 91, 0, 68, 2, 85, 
    1, 10, 8, 33, 6, 60, 2, 10, 7, 33, 3, 93, 5, 79, 0,  4, 4, 30, 
    8,  5, 1, 96, 3,  8, 6, 58, 2, 35, 7, 95, 4,  3, 5, 14, 0, 58
  };
  const int q2338[] = {
    9, 9, // Number of jobs and machines
    8, 11, 3, 66, 2, 46, 4,  4, 6, 33, 1, 43, 0, 26, 7,  8, 5, 44, 
    2, 91, 0, 80, 1, 27, 5, 37, 7, 81, 8, 57, 3, 33, 6,  7, 4, 26, 
    3, 41, 4,  4, 0, 49, 8,  6, 2, 55, 6, 55, 7, 63, 1, 88, 5, 65, 
    6, 45, 3,  4, 2, 70, 8, 14, 7, 74, 1, 61, 0, 46, 5,  6, 4, 74, 
    5, 29, 2, 63, 1, 31, 3,  6, 0,  5, 7, 82, 6, 90, 8, 34, 4, 41, 
    5,  3, 1, 32, 7, 86, 4, 91, 2, 87, 3, 22, 0, 97, 6, 62, 8, 64, 
    0, 28, 7, 10, 5, 81, 8, 20, 4, 14, 1, 91, 6, 63, 3, 18, 2, 54, 
    3, 75, 0, 31, 7, 77, 2, 19, 5, 42, 4, 30, 1, 99, 6, 21, 8, 74, 
    4, 40, 7, 86, 3, 66, 6, 94, 2, 25, 0, 60, 1, 39, 8, 40, 5, 13
  };
  const int q2339[] = {
    9, 9, // Number of jobs and machines
    3,  4, 4, 56, 8, 70, 2, 21, 6, 79, 7,  6, 1, 98, 5, 92, 0, 29, 
    2, 61, 8, 89, 7,  1, 3, 12, 5, 96, 0, 73, 1, 74, 6, 56, 4, 71, 
    3, 16, 0, 50, 4, 52, 7, 69, 5, 25, 1, 70, 8, 63, 6, 76, 2, 41, 
    6, 37, 3, 97, 7, 65, 2, 41, 4, 64, 0, 60, 5, 86, 1, 44, 8, 45, 
    8, 11, 7, 61, 5, 21, 6, 32, 2,  2, 0, 59, 1,  1, 4, 73, 3, 19, 
    7, 11, 8,  7, 3, 98, 0, 49, 6, 23, 2, 84, 4, 79, 5, 56, 1, 98, 
    2,  3, 0, 61, 3,  2, 5, 26, 7, 44, 8, 21, 1, 25, 6, 85, 4, 90, 
    0, 64, 2, 95, 1, 62, 4, 97, 5, 23, 8, 88, 7,  2, 6, 93, 3, 80, 
    1,  7, 5, 67, 6, 53, 4,  7, 0, 40, 2, 13, 8, 14, 3, 58, 7, 84
  };
  const int q2340[] = {
    9, 9, // Number of jobs and machines
    6, 90, 4, 72, 5, 11, 8, 34, 7, 44, 0, 43, 1, 90, 2, 74, 3, 48, 
    6, 72, 7, 97, 0, 14, 8, 37, 3, 17, 4,  5, 2, 55, 1,  4, 5, 23, 
    2, 62, 4, 12, 7, 84, 3, 75, 6, 93, 8,  8, 0, 72, 1,  2, 5, 35, 
    1, 43, 8, 90, 7, 53, 2, 82, 6,  1, 3,  9, 0,  7, 5, 66, 4, 20, 
    2, 76, 4, 59, 7, 99, 0, 98, 8, 82, 6, 72, 5, 69, 1, 58, 3, 55, 
    7, 11, 5, 52, 3, 12, 6, 47, 0, 46, 2, 44, 1, 15, 4,  7, 8, 70, 
    1, 26, 4, 94, 0,  6, 2,  8, 3,  9, 8, 64, 7, 54, 5,  7, 6,  1, 
    1, 54, 4, 35, 5, 87, 3, 75, 6,  8, 7, 25, 8, 44, 2, 56, 0, 87, 
    3, 88, 1, 92, 6, 90, 7, 58, 4, 74, 2, 96, 8, 76, 5, 49, 0, 88
  };
  const int q2341[] = {
    9, 9, // Number of jobs and machines
    5, 89, 0, 40, 2, 86, 7, 44, 1, 21, 8, 40, 4, 47, 6, 86, 3, 11, 
    7, 59, 3, 72, 2, 94, 5, 30, 6, 61, 4, 73, 8, 72, 1, 81, 0, 56, 
    3, 17, 4, 31, 1, 96, 7, 71, 2, 80, 0,  2, 6, 57, 5, 46, 8, 21, 
    7, 50, 1,  1, 8, 21, 4, 55, 3, 19, 0, 17, 5, 43, 2,  1, 6, 99, 
    7, 43, 8,  7, 1, 68, 0,  7, 4, 62, 2, 99, 6,  2, 5, 92, 3, 50, 
    0,  5, 2, 54, 8, 90, 3, 57, 6, 36, 7,  4, 1, 85, 4, 30, 5, 52, 
    5, 26, 7, 20, 8, 47, 3, 19, 0, 93, 4, 29, 6, 73, 1, 28, 2, 84, 
    7, 75, 3, 11, 2, 18, 8, 11, 4, 15, 1, 56, 6, 90, 0, 15, 5, 21, 
    2, 23, 8, 92, 3, 50, 1, 16, 4, 47, 7, 11, 6, 34, 0,  1, 5, 60
  };
  const int q2342[] = {
    9, 9, // Number of jobs and machines
    8,  2, 7, 33, 5, 73, 0, 27, 2, 15, 3, 19, 1, 20, 6, 83, 4, 23, 
    4, 65, 5, 31, 7, 41, 1, 23, 0, 73, 8, 26, 2, 89, 3, 62, 6, 20, 
    6, 94, 5, 38, 8,  3, 2, 66, 1, 19, 7,  3, 3, 64, 0, 61, 4, 90, 
    0, 88, 8, 17, 3, 37, 6, 39, 1, 85, 7, 98, 5, 41, 4, 37, 2, 50, 
    6, 15, 1,  7, 4, 94, 0, 11, 8,  6, 3,  4, 7, 63, 2, 29, 5, 35, 
    2, 89, 0, 80, 1, 50, 3, 32, 7,  9, 5, 89, 6, 72, 4, 10, 8, 72, 
    1, 33, 5, 14, 2, 38, 6, 28, 4, 55, 0, 88, 7,  1, 8,  9, 3, 49, 
    7, 16, 3, 34, 6,  6, 0, 78, 5, 32, 2,  4, 4, 16, 8, 12, 1, 16, 
    3, 97, 5, 76, 7, 82, 0, 85, 2, 82, 4, 26, 1, 31, 6, 41, 8, 16
  };
  const int q2343[] = {
    9, 9, // Number of jobs and machines
    2, 35, 6, 22, 0, 48, 8, 66, 3,  9, 7, 95, 5, 87, 1, 56, 4, 59, 
    2, 84, 3, 85, 6, 92, 7, 83, 0, 64, 8, 89, 5, 55, 1, 79, 4,  5, 
    6, 69, 1,  7, 2, 80, 4, 70, 8,  9, 7, 41, 0, 28, 3, 92, 5, 92, 
    6, 73, 0, 46, 5, 82, 1, 87, 4, 61, 2, 31, 3, 91, 8, 74, 7, 10, 
    4, 10, 2, 57, 7,  1, 0, 57, 1, 90, 6, 21, 3, 48, 8, 13, 5, 62, 
    8, 17, 5, 77, 2, 86, 6, 84, 7, 25, 1, 13, 3, 99, 0, 46, 4, 65, 
    7, 71, 3, 86, 4, 52, 8, 45, 2, 31, 1, 34, 6, 35, 0, 12, 5, 90, 
    3, 68, 8, 44, 6, 62, 7, 53, 0, 67, 4, 60, 1, 17, 5, 88, 2, 26, 
    7,  7, 0, 32, 1, 42, 8, 37, 5, 12, 4, 93, 2, 34, 3, 78, 6, 54
  };
  const int q2344[] = {
    9, 9, // Number of jobs and machines
    6, 76, 0, 90, 2, 95, 1, 16, 4, 25, 3, 43, 5, 93, 8, 84, 7, 87, 
    3, 67, 2, 77, 1, 83, 8, 47, 5,  6, 0, 20, 7, 26, 4, 67, 6, 91, 
    4, 61, 2, 51, 8, 24, 6, 95, 7, 28, 1, 66, 0, 21, 5, 46, 3,  5, 
    3,  6, 0, 74, 4, 97, 7, 31, 8, 38, 1, 34, 2, 74, 6, 89, 5, 18, 
    2, 75, 7, 34, 0, 56, 6, 58, 4, 80, 1, 91, 3, 85, 8, 70, 5, 58, 
    2, 19, 4, 56, 7, 21, 3, 30, 5, 29, 6, 81, 0, 83, 8, 46, 1, 39, 
    8, 91, 3, 31, 7, 10, 0, 91, 6, 59, 2, 45, 5, 16, 1, 46, 4, 76, 
    7, 70, 0, 42, 5, 72, 3, 57, 6, 53, 2, 76, 8, 20, 1, 93, 4, 62, 
    0, 84, 1, 78, 5, 20, 6, 50, 2,  9, 4, 98, 8, 20, 3, 78, 7, 16
  };
  const int q2345[] = {
    9, 9, // Number of jobs and machines
    7, 35, 6, 34, 3, 66, 8,  9, 5, 66, 0, 88, 1, 18, 2, 61, 4, 45, 
    8, 63, 2, 55, 0, 30, 5, 15, 4, 26, 6, 19, 7, 49, 1, 51, 3,  8, 
    1, 61, 5, 61, 3, 89, 0, 95, 2, 46, 7, 62, 6, 61, 8, 19, 4, 86, 
    0, 40, 8, 92, 4, 58, 1, 87, 5, 12, 2, 33, 7, 22, 3, 38, 6, 87, 
    3, 61, 2, 56, 1, 27, 4, 11, 0, 68, 6,  9, 7, 13, 5, 56, 8, 56, 
    1, 83, 2, 24, 7, 66, 4, 85, 0, 45, 8, 50, 3, 56, 5, 91, 6, 94, 
    2, 93, 5, 30, 8, 57, 3, 60, 1,  6, 0, 82, 4, 86, 6, 79, 7, 48, 
    4, 64, 6, 35, 7, 79, 1, 83, 2, 93, 5, 26, 8, 50, 3, 24, 0, 54, 
    1, 96, 8, 56, 2, 31, 3, 56, 5, 72, 6, 83, 4, 38, 7, 42, 0, 99
  };
  const int q2346[] = {
    9, 9, // Number of jobs and machines
    1, 77, 5, 28, 0,  7, 4, 95, 2, 22, 3, 54, 7, 55, 8, 58, 6, 42, 
    0, 56, 2, 64, 8, 56, 4,  2, 7, 55, 5,  5, 1, 57, 6, 61, 3, 25, 
    7, 15, 2, 90, 6, 87, 0, 20, 8, 41, 4, 37, 1, 99, 5, 79, 3, 90, 
    8, 73, 4, 24, 7, 35, 5, 78, 2, 31, 3, 23, 0, 70, 6, 86, 1, 30, 
    2, 24, 6, 64, 1, 26, 4, 41, 5, 68, 3, 27, 8, 55, 0,  7, 7, 31, 
    1, 32, 8, 47, 5, 49, 3, 51, 2, 83, 4, 61, 6, 15, 0, 94, 7, 21, 
    2, 69, 0, 46, 4, 52, 3, 85, 7, 66, 6, 61, 8, 28, 1, 76, 5, 53, 
    2,  5, 3, 60, 6, 79, 4, 54, 7, 33, 8, 75, 1, 35, 0, 63, 5, 24, 
    1, 41, 0, 71, 2, 28, 5, 81, 8, 96, 7, 61, 6, 90, 4, 20, 3,  8
  };
  const int q2347[] = {
    9, 9, // Number of jobs and machines
    1, 91, 5, 20, 2,  5, 4, 18, 0, 19, 3, 17, 6, 54, 7, 38, 8,  8, 
    0, 22, 3, 76, 6, 75, 2, 28, 7, 36, 5, 21, 1, 77, 4, 67, 8, 34, 
    7,  9, 8, 52, 3, 91, 4, 40, 5, 41, 2, 57, 0, 10, 6, 67, 1, 42, 
    3, 27, 0, 47, 4, 43, 7, 56, 2, 49, 5, 50, 1, 41, 8, 76, 6,  9, 
    0, 17, 2, 71, 6, 80, 7, 41, 4, 88, 5, 38, 8, 47, 1, 75, 3, 51, 
    1, 41, 8, 78, 5, 85, 7, 20, 0, 45, 4, 99, 3, 38, 6, 18, 2, 74, 
    0, 56, 3, 30, 4, 20, 7, 37, 8, 87, 2, 18, 5, 30, 6, 60, 1, 83, 
    3, 79, 4, 35, 2, 14, 0, 65, 1, 59, 8, 40, 6,  4, 7, 27, 5,  7, 
    3, 38, 7, 94, 2, 82, 0, 22, 4, 53, 8, 55, 6, 52, 5, 46, 1, 19
  };
  const int q2348[] = {
    9, 9, // Number of jobs and machines
    3, 42, 8, 33, 4, 95, 6, 58, 2, 77, 5, 23, 7, 56, 0, 92, 1, 79, 
    5, 26, 2,  1, 8, 22, 4, 17, 3, 42, 6, 22, 7, 44, 0, 44, 1, 49, 
    8, 33, 4, 24, 7, 62, 1, 67, 5, 33, 2,  8, 6, 59, 3, 19, 0, 87, 
    1, 39, 0, 32, 5, 97, 6, 91, 8, 25, 4, 13, 7, 53, 2, 23, 3,  6, 
    2, 29, 6,  5, 4, 18, 1, 53, 5, 69, 0, 73, 3, 56, 7, 47, 8, 83, 
    7, 79, 1, 81, 8,  6, 5, 39, 3, 52, 2, 31, 4, 18, 6, 45, 0, 36, 
    2, 19, 4, 33, 3, 51, 7, 98, 5, 86, 8, 82, 6, 25, 0, 26, 1,  5, 
    6, 23, 5, 15, 8,  2, 4, 70, 1, 77, 0, 82, 3, 80, 7, 40, 2, 45, 
    8, 73, 6,  5, 1, 94, 0, 38, 5, 39, 7,  4, 4, 59, 2, 67, 3, 15
  };
  const int q2349[] = {
    9, 9, // Number of jobs and machines
    5, 72, 3, 58, 8, 30, 1, 93, 7,  5, 2, 26, 4,  8, 6, 33, 0, 12, 
    8, 99, 2, 92, 4, 50, 6, 70, 3, 23, 7, 54, 0, 59, 1, 16, 5, 34, 
    8, 51, 5, 44, 4, 19, 0, 99, 3, 13, 7, 57, 2, 38, 1, 96, 6, 34, 
    2, 78, 0, 65, 5, 58, 8, 99, 4, 36, 6, 48, 1, 20, 7, 18, 3, 61, 
    6, 71, 2, 38, 7, 67, 1, 49, 0, 75, 8,  4, 4, 90, 3, 69, 5,  3, 
    6,  5, 3, 20, 1, 87, 0,  4, 7, 66, 4, 34, 2, 31, 8, 50, 5, 63, 
    1, 47, 0,  6, 6, 19, 5, 44, 4, 82, 2,  8, 8, 48, 3, 86, 7, 54, 
    0, 24, 3, 59, 6,  7, 7, 13, 1, 86, 4, 38, 5, 58, 8, 64, 2, 48, 
    4, 85, 3, 87, 7, 90, 1, 34, 0, 61, 6, 82, 5,  2, 2, 97, 8, 29
  };
  const int q2350[] = {
    9, 9, // Number of jobs and machines
    8,  7, 4, 10, 2, 25, 6, 84, 7, 48, 3, 78, 1, 91, 0,  3, 5, 45, 
    6, 23, 1, 64, 2, 75, 4, 13, 0, 30, 7, 99, 5, 30, 3, 68, 8,  2, 
    5, 15, 1, 51, 0,  8, 7, 33, 2, 11, 4,  1, 3, 38, 6, 93, 8, 46, 
    8, 50, 6,  3, 3, 53, 1, 61, 4, 67, 5, 71, 7, 46, 2, 36, 0, 78, 
    7, 84, 5, 42, 0, 85, 3, 73, 4, 77, 8, 49, 6, 39, 2, 90, 1, 80, 
    3, 86, 4, 11, 6, 34, 7,  3, 2, 22, 0, 41, 1, 98, 8, 55, 5, 94, 
    2, 53, 1, 31, 6, 16, 0, 50, 8, 18, 7, 77, 4, 23, 3, 40, 5,  4, 
    7, 25, 6, 72, 0, 52, 4, 49, 5, 48, 2,  4, 8, 62, 1, 35, 3, 49, 
    7,  6, 6, 90, 4, 98, 2, 98, 3, 76, 1,  1, 8, 56, 0,  1, 5, 41
  };
  const int q2351[] = {
    9, 9, // Number of jobs and machines
    3, 36, 1, 91, 2, 41, 6, 93, 5, 40, 4, 87, 0, 42, 8, 13, 7, 71, 
    1, 99, 0, 24, 4, 14, 8, 88, 3, 54, 2,  6, 6, 77, 5, 15, 7, 39, 
    0, 11, 1, 83, 2, 77, 7, 36, 5, 49, 8, 17, 6,  3, 4, 46, 3, 93, 
    1, 40, 4, 54, 3, 76, 8, 27, 7, 34, 6, 27, 2, 56, 0, 33, 5, 98, 
    6, 93, 0, 10, 3, 98, 1, 17, 7, 34, 4, 25, 5, 99, 2, 31, 8, 35, 
    8, 58, 0, 78, 2, 34, 4, 60, 7, 95, 1, 84, 6, 79, 5, 75, 3, 30, 
    0, 14, 8,  4, 2, 78, 5, 62, 7, 37, 3, 70, 6, 68, 4, 54, 1, 61, 
    4, 32, 7, 54, 2, 23, 6,  6, 1, 40, 3, 59, 8, 60, 0, 50, 5, 24, 
    6, 16, 5, 26, 2, 96, 4, 37, 1, 18, 8, 21, 7, 21, 0, 83, 3, 20
  };
  const int q2352[] = {
    9, 9, // Number of jobs and machines
    5, 36, 8, 21, 4, 83, 0, 17, 1, 71, 3, 33, 7, 46, 2,  6, 6, 21, 
    5, 13, 2, 64, 6, 77, 7, 58, 1, 79, 4, 88, 8, 83, 0, 52, 3, 46, 
    3, 58, 5, 55, 8, 91, 4, 89, 0, 56, 6, 68, 7, 85, 2, 81, 1, 45, 
    8, 38, 4, 98, 7, 22, 0,  4, 3, 26, 6, 85, 1,  9, 5, 61, 2, 86, 
    2, 32, 6, 64, 8, 91, 4, 72, 5, 82, 7, 39, 1, 16, 0, 83, 3, 36, 
    5, 91, 1, 47, 2, 70, 7, 52, 6, 27, 0, 67, 4, 79, 3, 37, 8, 91, 
    3, 90, 7, 99, 0, 41, 1, 53, 5, 72, 8, 66, 2, 11, 4,  1, 6, 96, 
    3,  9, 5, 27, 7, 23, 1, 92, 0,  9, 4, 60, 8, 55, 2, 42, 6, 80, 
    3, 82, 8, 35, 7, 93, 6, 46, 1,  2, 0, 89, 4, 92, 2, 11, 5,  6
  };
  const int q2353[] = {
    9, 9, // Number of jobs and machines
    0, 85, 1, 95, 7, 36, 3, 86, 2, 82, 8, 14, 5, 84, 6, 75, 4, 11, 
    5, 30, 3, 60, 7, 88, 4, 61, 1, 30, 8, 42, 0, 30, 6, 87, 2, 10, 
    6, 73, 2, 14, 0, 68, 1, 79, 5, 31, 7, 77, 8, 33, 4,  5, 3, 38, 
    2, 41, 4, 23, 8, 67, 0, 84, 7, 85, 3, 88, 1, 94, 6, 94, 5, 19, 
    7, 73, 1, 94, 6, 51, 2, 64, 0, 20, 8, 81, 5, 99, 3, 84, 4, 99, 
    2, 83, 7, 35, 0,  9, 1, 57, 3, 25, 6, 24, 8, 84, 5,  4, 4, 10, 
    4, 30, 0, 67, 1,  9, 6,  3, 2, 29, 3, 47, 7, 67, 8, 90, 5, 30, 
    6, 63, 5, 58, 3, 29, 2, 19, 8, 11, 7, 41, 1, 58, 4, 51, 0, 81, 
    3, 88, 6, 62, 4, 12, 0, 28, 8, 62, 1, 85, 7, 82, 5, 99, 2, 72
  };
  const int q2354[] = {
    9, 9, // Number of jobs and machines
    7, 41, 3, 48, 2,  5, 5, 16, 4, 59, 0, 17, 1, 17, 6, 13, 8, 70, 
    3, 30, 6, 37, 7, 24, 8, 71, 1, 92, 0, 47, 5, 36, 2, 49, 4, 17, 
    1, 83, 3, 53, 8, 17, 2, 64, 0, 48, 7, 68, 5, 35, 6, 54, 4, 88, 
    5, 42, 7, 44, 3, 10, 6, 26, 8, 72, 0, 90, 4, 69, 2, 77, 1, 92, 
    3, 52, 8, 31, 4,  2, 7, 79, 6, 63, 2, 36, 1, 79, 0, 78, 5, 60, 
    3, 20, 7, 85, 5, 11, 4, 26, 0, 61, 1, 10, 8, 52, 6, 97, 2, 73, 
    4, 27, 6, 95, 2, 90, 5, 44, 3, 73, 0,  5, 7, 77, 8, 99, 1,  6, 
    7, 60, 6, 82, 5,  1, 3,  6, 2, 58, 8, 80, 1, 87, 0, 88, 4, 67, 
    7, 12, 5, 14, 0, 26, 8, 84, 6, 55, 2, 58, 3, 93, 1, 46, 4, 83
  };
  const int q2355[] = {
    9, 9, // Number of jobs and machines
    6, 25, 4, 12, 5, 82, 3, 10, 1, 99, 7, 54, 8, 61, 2, 28, 0, 84, 
    8, 76, 7, 59, 1,  3, 6, 87, 0, 70, 5, 68, 2, 56, 3, 34, 4, 57, 
    7, 13, 3, 19, 8, 15, 4, 63, 2, 52, 6, 46, 1, 81, 5, 89, 0, 87, 
    4, 86, 6, 48, 1, 26, 7, 21, 8, 87, 0, 91, 5, 91, 3, 60, 2,  7, 
    3,  9, 2, 96, 1, 28, 8, 26, 6, 17, 5, 15, 4, 96, 0, 77, 7, 55, 
    3, 58, 5, 63, 4, 95, 1,  3, 2, 29, 7,  4, 8, 89, 6, 42, 0, 48, 
    8, 69, 6, 84, 0, 66, 2, 55, 4, 70, 7, 85, 1, 64, 5, 80, 3, 30, 
    6, 30, 3, 74, 1, 21, 0, 44, 7, 19, 2, 58, 5, 91, 4, 24, 8, 38, 
    5, 42, 2, 27, 6, 85, 4, 58, 3, 28, 0, 79, 8, 31, 7, 63, 1, 96
  };
  const int q2356[] = {
    9, 9, // Number of jobs and machines
    5, 17, 8, 23, 1,  9, 7, 62, 2,  8, 3, 91, 4,  7, 6, 43, 0, 70, 
    0, 14, 5, 87, 2, 86, 7, 94, 3, 46, 1, 12, 6, 63, 4,  9, 8, 19, 
    5, 89, 1,  6, 7, 35, 3, 93, 4, 72, 2, 10, 8,  3, 6, 90, 0, 45, 
    2, 86, 5, 43, 8,  9, 4, 18, 3,  2, 6,  4, 1, 18, 0, 88, 7, 33, 
    1, 66, 5, 43, 8, 85, 4, 26, 6, 24, 0, 21, 2, 72, 7, 35, 3, 66, 
    7, 33, 6, 35, 0, 49, 3, 81, 2,  4, 4, 46, 8, 61, 1, 82, 5, 10, 
    7, 17, 6, 90, 5, 39, 1, 23, 2, 32, 3, 50, 8, 75, 0, 29, 4, 41, 
    4, 47, 2, 78, 6, 25, 7, 70, 8, 24, 5,  7, 1, 73, 0, 12, 3, 66, 
    8, 13, 2, 74, 4, 81, 7, 55, 0, 74, 3,  5, 6, 13, 1,  1, 5, 37
  };
  const int q2357[] = {
    9, 9, // Number of jobs and machines
    3, 64, 1,  7, 0, 42, 8, 11, 7, 71, 6,  5, 4, 70, 5, 42, 2, 65, 
    8,  3, 5, 59, 0, 48, 1,  8, 6, 88, 7, 22, 4, 71, 3, 24, 2, 24, 
    4, 44, 2, 16, 8, 53, 7, 21, 3, 58, 0, 49, 6, 13, 5, 28, 1, 77, 
    0, 97, 1, 51, 5, 19, 4, 63, 8, 90, 6, 72, 7, 63, 3,  9, 2, 35, 
    3,  3, 5, 25, 4, 24, 8, 91, 6, 98, 2,  6, 0, 40, 7, 97, 1, 39, 
    1, 91, 4, 29, 3, 49, 0, 14, 5, 55, 7, 90, 2, 96, 8, 29, 6, 57, 
    0, 48, 4,  2, 2, 70, 7, 20, 3,  4, 5, 58, 1, 62, 6, 98, 8, 50, 
    4, 48, 6, 46, 1, 96, 2, 29, 0, 83, 3,  7, 5, 87, 7, 31, 8, 35, 
    4, 96, 8, 37, 7, 82, 6, 86, 2, 74, 5, 59, 1, 24, 0, 37, 3, 42
  };
  const int q2358[] = {
    9, 9, // Number of jobs and machines
    5, 53, 1, 44, 4, 28, 3, 85, 8, 88, 2, 87, 0, 71, 7, 86, 6, 54, 
    1, 18, 8, 41, 3, 48, 5, 27, 7, 22, 0, 49, 2, 39, 4, 98, 6, 18, 
    8, 47, 2, 54, 5, 13, 6, 23, 4, 72, 1, 86, 3, 17, 0, 60, 7, 83, 
    0, 49, 8,  6, 6, 59, 4, 91, 5,  9, 3, 38, 7, 26, 1, 52, 2, 94, 
    7, 96, 3,  3, 4, 60, 5,  5, 8, 50, 6, 11, 2, 58, 0, 42, 1, 27, 
    3, 54, 0, 20, 2, 46, 7, 80, 6, 48, 8, 40, 5, 83, 1, 95, 4, 84, 
    8, 46, 6, 71, 0, 76, 7, 12, 2, 21, 1, 47, 5, 66, 3, 50, 4, 51, 
    7, 31, 3, 72, 4, 71, 0, 96, 5, 17, 8, 55, 2, 11, 6, 40, 1, 25, 
    6, 82, 8, 50, 4,  2, 5, 37, 0, 43, 2, 65, 1, 29, 3, 75, 7, 55
  };
  const int q2359[] = {
    9, 9, // Number of jobs and machines
    7, 97, 6, 62, 8, 34, 5, 62, 0, 46, 2, 95, 1, 42, 3, 75, 4, 75, 
    3, 85, 7, 69, 8, 43, 4, 29, 5, 43, 1, 30, 0,  6, 2, 61, 6, 30, 
    5, 49, 2, 24, 7, 35, 4, 26, 1, 89, 0, 99, 6, 18, 3,  9, 8, 56, 
    6,  7, 2, 79, 5, 89, 0, 85, 1, 43, 4, 47, 7,  7, 8, 85, 3,  7, 
    1, 79, 8, 52, 4, 68, 3, 57, 0, 39, 6, 95, 2, 63, 5, 67, 7, 41, 
    1, 11, 0, 49, 8, 91, 3, 13, 7,  1, 6, 72, 4, 53, 2, 84, 5,  6, 
    6, 18, 7, 32, 0, 99, 2, 24, 5, 44, 4, 96, 1, 46, 3, 65, 8, 81, 
    1, 55, 6, 35, 0, 53, 3, 74, 8, 85, 5,  1, 7, 19, 2, 43, 4, 49, 
    2, 18, 8, 58, 1, 14, 0,  6, 3, 74, 6, 98, 7, 70, 4, 32, 5, 13
  };
  const int q2360[] = {
    9, 9, // Number of jobs and machines
    5, 55, 6, 77, 4, 27, 7, 37, 1, 87, 3, 36, 2, 70, 0, 72, 8, 98, 
    4,  5, 6, 90, 1, 11, 2, 97, 0, 63, 8, 57, 5, 47, 7,  7, 3, 45, 
    7,  8, 1, 49, 0, 96, 8, 36, 4, 62, 3, 44, 5, 55, 2, 95, 6,  4, 
    7, 64, 2, 65, 0, 25, 3,  1, 8, 52, 4,  6, 6, 85, 5, 32, 1, 24, 
    8, 14, 1, 48, 5, 41, 0, 34, 7, 68, 3, 86, 2, 95, 6, 55, 4, 99, 
    5, 61, 2, 33, 3, 22, 7, 22, 6, 55, 4, 20, 8, 42, 1, 34, 0, 68, 
    0, 14, 3,  4, 6, 97, 2,  2, 8, 30, 5, 70, 1, 13, 7, 14, 4, 82, 
    7, 45, 5, 97, 0, 96, 1, 72, 6, 34, 8, 12, 2,  3, 3, 77, 4, 40, 
    5, 70, 8, 73, 2, 55, 6,  8, 1, 64, 3, 16, 7, 26, 0, 43, 4, 17
  };
  const int q2361[] = {
    9, 9, // Number of jobs and machines
    8, 19, 2, 72, 1, 75, 7,  6, 6, 58, 4, 14, 5, 65, 0, 32, 3,  9, 
    0, 79, 8, 66, 1, 77, 2, 11, 5, 29, 6, 35, 3, 98, 4, 90, 7, 65, 
    0, 36, 7,  6, 8, 54, 1, 18, 4, 47, 2, 89, 6, 77, 3, 61, 5, 78, 
    6, 81, 7,  5, 0,  2, 2,  4, 5, 14, 4, 68, 8, 53, 3, 83, 1, 81, 
    0, 80, 5, 11, 2, 10, 3, 45, 7, 41, 1, 61, 6, 27, 8, 19, 4, 90, 
    1, 40, 5,  7, 7, 60, 0, 71, 8, 75, 6, 98, 2,  9, 4, 48, 3, 22, 
    1, 85, 6, 46, 4, 96, 2, 98, 3, 19, 8, 20, 7, 57, 0, 46, 5, 69, 
    1, 82, 6, 65, 4, 20, 3,  5, 8,  9, 2, 16, 5,  8, 7,  6, 0,  6, 
    1, 73, 0, 20, 7, 96, 4, 47, 5, 91, 8,  3, 2, 82, 3, 82, 6, 75
  };
  const int q2362[] = {
    9, 9, // Number of jobs and machines
    4, 26, 8, 38, 5, 67, 3, 50, 2, 16, 0, 15, 1, 63, 6, 31, 7, 62, 
    8, 61, 0, 57, 4,  5, 1,  8, 7, 64, 3, 88, 2, 36, 5, 30, 6, 77, 
    1, 46, 7, 81, 5, 64, 8, 61, 6, 80, 4, 67, 2, 71, 0, 44, 3, 80, 
    5, 98, 0, 57, 3,  2, 8, 34, 2, 31, 1, 55, 6, 34, 7,  1, 4, 52, 
    7, 64, 5, 43, 3, 59, 4, 65, 8, 68, 1, 80, 2, 11, 6, 57, 0, 74, 
    6, 45, 4,  2, 2, 91, 7, 81, 5, 40, 0, 76, 1, 68, 3, 16, 8, 91, 
    8, 93, 3, 57, 0, 56, 5, 57, 1, 90, 2, 30, 4, 11, 6, 33, 7, 57, 
    4, 20, 7, 52, 6, 69, 3, 26, 1, 86, 5, 57, 2, 80, 8, 35, 0, 50, 
    2, 50, 5, 39, 1, 41, 0, 33, 8, 13, 7, 58, 4, 26, 3, 13, 6, 24
  };
  const int q2363[] = {
    9, 9, // Number of jobs and machines
    8, 34, 1, 70, 2, 33, 3, 21, 7, 55, 5, 50, 6, 76, 0, 65, 4, 58, 
    2, 75, 3, 20, 5,  6, 8, 76, 7, 64, 6, 66, 4, 19, 1, 27, 0, 20, 
    6, 54, 4, 63, 5, 20, 3,  2, 0, 30, 7, 40, 1, 67, 8, 61, 2,  9, 
    8, 41, 5, 89, 1, 88, 7, 22, 2, 60, 4, 71, 6, 66, 3, 25, 0, 80, 
    2, 99, 6,  9, 3, 93, 8, 94, 5,  4, 7, 24, 0, 90, 1, 11, 4,  4, 
    0, 36, 7, 83, 1, 83, 5, 56, 2, 85, 3, 93, 6, 14, 8, 85, 4, 64, 
    2, 55, 1, 29, 8,  6, 0, 35, 5, 51, 6, 73, 3, 46, 7, 81, 4, 31, 
    6,  4, 4, 84, 1, 12, 2,  7, 7, 80, 0, 63, 8,  8, 5, 34, 3,  5, 
    3, 41, 6, 19, 7, 55, 4, 67, 0,  4, 1, 84, 8, 78, 5, 21, 2, 22
  };
  const int q2364[] = {
    9, 9, // Number of jobs and machines
    1, 75, 6, 74, 0, 24, 4, 91, 7, 61, 8, 38, 5, 87, 2,  8, 3, 18, 
    5, 89, 7, 73, 2, 94, 0, 91, 4, 26, 3, 43, 6, 52, 8, 49, 1, 13, 
    1, 96, 0, 47, 7,  6, 6, 25, 3, 94, 5,  4, 8, 83, 2, 35, 4,  8, 
    3, 32, 1, 78, 7, 86, 0, 74, 5, 67, 8, 57, 2, 31, 6, 61, 4, 43, 
    3, 89, 1,  2, 2, 91, 0, 75, 7, 90, 4, 90, 5, 91, 8, 78, 6,  2, 
    3, 76, 8, 10, 1, 43, 0, 93, 4, 12, 2, 78, 7, 63, 5,  5, 6, 56, 
    1, 43, 4, 14, 6,  9, 2, 19, 8, 53, 7, 60, 3, 66, 0, 22, 5, 72, 
    1, 11, 3,  7, 8, 80, 6, 32, 7, 73, 5, 22, 4, 90, 0, 95, 2, 81, 
    1, 94, 6, 16, 2, 33, 4, 89, 8, 89, 7, 36, 0, 56, 5, 91, 3, 78
  };
  const int q2365[] = {
    9, 9, // Number of jobs and machines
    1, 16, 7, 66, 4, 92, 8, 30, 5, 11, 2, 80, 0, 29, 6,  7, 3, 58, 
    4, 99, 5, 16, 0, 78, 3, 97, 1, 22, 6, 57, 7, 93, 8, 65, 2, 52, 
    5, 84, 7, 58, 0, 74, 8, 60, 3,  2, 1, 74, 2, 50, 6, 29, 4,  7, 
    2, 69, 7, 42, 6, 67, 8,  3, 1, 43, 5, 20, 4, 22, 3, 14, 0, 29, 
    0,  1, 4, 61, 7, 32, 5, 99, 2, 74, 8, 13, 6, 95, 3, 30, 1, 68, 
    3, 77, 1, 95, 5, 36, 7, 67, 2, 81, 8, 96, 4, 49, 6, 26, 0, 91, 
    1,  8, 5,  5, 7,  3, 4, 72, 6, 22, 0, 95, 3, 70, 2, 32, 8, 64, 
    6, 66, 5, 31, 3, 86, 4, 36, 0, 23, 1, 41, 2, 81, 8, 62, 7, 32, 
    1, 13, 0, 40, 3, 19, 4,  3, 5, 28, 6, 15, 2, 71, 7, 78, 8, 97
  };
  const int q2366[] = {
    9, 9, // Number of jobs and machines
    0, 76, 6, 96, 8,  1, 7, 61, 5, 98, 2, 81, 3, 10, 1,  5, 4,  1, 
    1, 82, 2, 39, 4, 10, 5, 24, 0, 34, 7, 17, 8, 19, 3, 99, 6, 38, 
    0, 75, 1,  5, 2, 71, 5, 55, 3, 26, 8, 82, 6, 11, 4, 66, 7, 33, 
    8, 60, 3, 27, 1, 90, 5, 17, 2, 41, 6, 14, 7, 73, 4, 75, 0, 61, 
    2,  9, 4,  3, 8, 16, 1, 85, 5, 79, 3, 63, 0, 94, 6, 52, 7, 10, 
    0, 83, 8, 21, 2, 14, 3,  9, 6, 37, 1, 51, 7, 25, 4, 45, 5, 12, 
    2, 79, 3, 43, 6, 43, 8, 92, 4, 38, 0, 93, 1, 98, 5, 59, 7, 12, 
    1, 29, 3, 26, 5, 37, 6, 66, 8, 69, 0, 28, 7, 42, 4, 25, 2, 20, 
    5, 98, 4, 92, 6, 19, 8, 45, 3, 50, 1, 71, 7, 46, 0, 86, 2, 16
  };
  const int q2367[] = {
    9, 9, // Number of jobs and machines
    4, 32, 3, 47, 2, 74, 1, 56, 7, 48, 8, 63, 6, 28, 5, 57, 0, 61, 
    4, 38, 1, 58, 3, 11, 0, 54, 7, 23, 8, 30, 6, 46, 2, 51, 5, 45, 
    6, 23, 0, 55, 7, 77, 2, 57, 3, 90, 8, 26, 5, 67, 4, 43, 1, 34, 
    2, 90, 5, 55, 4, 99, 6, 44, 1, 74, 0, 59, 7, 76, 3, 68, 8, 95, 
    8, 62, 5, 52, 3, 96, 1, 71, 4, 97, 0, 91, 2, 56, 6, 37, 7, 52, 
    1, 26, 8, 59, 3, 53, 6, 37, 2, 18, 0, 72, 5, 35, 7,  8, 4, 97, 
    1, 62, 3, 87, 0, 43, 2, 75, 5, 48, 8, 47, 4, 18, 6, 65, 7, 71, 
    5, 24, 0, 79, 2, 98, 8, 44, 3, 58, 4, 40, 6, 35, 7, 73, 1, 55, 
    8, 34, 4, 23, 0, 60, 3, 53, 2, 56, 6, 81, 5, 43, 1,  4, 7, 66
  };
  const int q2368[] = {
    9, 9, // Number of jobs and machines
    4, 93, 1, 65, 6, 50, 7, 94, 8, 57, 5, 21, 0, 14, 3, 45, 2,  2, 
    0, 13, 6,  4, 2, 28, 8, 22, 3, 91, 1, 44, 4, 83, 7, 19, 5, 93, 
    5, 92, 4, 76, 3, 64, 0, 34, 8, 56, 7, 36, 6, 89, 2, 60, 1, 72, 
    6,  1, 0, 84, 8, 82, 2, 38, 7, 63, 5, 94, 4, 25, 3, 72, 1, 48, 
    4, 97, 1, 50, 0, 54, 5, 52, 2, 77, 6, 53, 7,  3, 8, 94, 3, 78, 
    2, 81, 6, 17, 7, 52, 0, 62, 8, 58, 4, 47, 5, 95, 3, 64, 1, 96, 
    4, 75, 6, 60, 3, 74, 7, 21, 0, 86, 8, 42, 5, 47, 1, 17, 2, 47, 
    2, 58, 5, 25, 0, 65, 7, 95, 4, 34, 8, 73, 6, 19, 3, 77, 1,  3, 
    1,  4, 3, 78, 4, 91, 7, 19, 0, 82, 5, 47, 6, 21, 2, 40, 8, 30
  };
  const int q2369[] = {
    9, 9, // Number of jobs and machines
    2, 59, 3, 92, 8, 84, 6, 84, 5, 97, 1, 93, 4, 75, 0, 72, 7,  8, 
    7, 69, 4, 75, 6, 60, 2, 65, 1, 61, 8, 82, 3, 97, 5, 79, 0, 35, 
    3, 62, 6, 38, 5, 56, 7, 21, 4, 13, 8, 21, 1, 75, 2, 54, 0, 18, 
    3, 23, 2, 94, 0, 71, 7, 40, 4, 29, 1,  4, 6, 81, 5, 34, 8, 59, 
    2, 92, 1, 71, 3, 96, 5, 42, 4, 54, 7, 84, 8, 45, 6, 22, 0, 79, 
    3, 37, 8,  9, 0, 74, 5, 24, 7, 51, 1, 88, 6, 82, 2, 89, 4, 37, 
    0, 41, 2, 26, 5, 87, 4, 56, 6, 85, 7, 14, 8, 85, 3, 28, 1, 19, 
    4, 18, 7, 14, 5,  1, 0, 34, 2, 51, 3, 39, 6, 86, 1, 85, 8, 95, 
    0, 90, 3, 75, 5, 32, 7, 37, 4, 29, 1, 13, 2, 77, 8, 51, 6, 39
  };
  const int q2370[] = {
    9, 9, // Number of jobs and machines
    4, 79, 2, 48, 1, 12, 5, 79, 3, 57, 0, 19, 8, 63, 7,  7, 6, 11, 
    0, 32, 2, 51, 8, 62, 7, 73, 5, 52, 3, 49, 1, 12, 4, 54, 6, 46, 
    3, 14, 0, 78, 6, 92, 1, 10, 4,  2, 8, 81, 5,  3, 2, 35, 7, 19, 
    0,  8, 3, 47, 4, 39, 1, 43, 7, 72, 5,  3, 2, 23, 6, 73, 8, 96, 
    1, 73, 0, 50, 2, 81, 5, 61, 8, 86, 4, 98, 3, 91, 7, 88, 6, 40, 
    5, 68, 8, 87, 7, 14, 3, 87, 2, 69, 6, 44, 4, 53, 0, 22, 1, 29, 
    2, 80, 8, 62, 3, 71, 5, 99, 7, 46, 0, 49, 1, 99, 4, 93, 6, 38, 
    8, 57, 6, 97, 4, 48, 2,  5, 7, 81, 0, 55, 1, 73, 3, 23, 5, 43, 
    3, 23, 7, 13, 1,  7, 8, 17, 5, 10, 0, 28, 6, 21, 4, 57, 2, 97
  };
  const int q2371[] = {
    9, 9, // Number of jobs and machines
    8, 41, 6, 21, 1, 50, 7, 56, 2, 95, 5, 65, 3, 46, 0, 17, 4,  8, 
    3, 32, 8, 55, 4, 82, 2, 93, 5, 10, 1, 36, 0, 62, 6, 55, 7, 84, 
    2, 57, 8, 30, 5, 89, 1, 87, 6, 37, 0, 67, 7, 46, 3, 29, 4, 39, 
    8, 91, 2, 54, 0, 28, 7, 93, 4, 47, 3, 84, 5, 61, 6, 42, 1, 50, 
    8, 10, 0, 98, 1, 42, 5, 17, 7, 87, 3, 56, 4, 33, 6, 56, 2, 67, 
    1, 42, 7, 15, 4, 53, 2, 51, 8, 99, 5, 50, 0, 48, 6, 28, 3, 19, 
    3, 60, 5, 43, 6,  1, 0, 55, 1, 17, 8,  2, 2, 58, 4, 11, 7, 69, 
    6, 35, 0, 87, 1, 99, 5, 84, 4, 41, 3, 59, 8, 52, 2, 71, 7, 68, 
    3, 32, 0, 46, 8, 13, 6, 78, 5, 24, 4, 98, 2, 12, 7, 64, 1,  1
  };
  const int q2372[] = {
    9, 9, // Number of jobs and machines
    1, 41, 2, 92, 7, 78, 3, 83, 6, 18, 4, 51, 0, 44, 8, 45, 5, 77, 
    2, 63, 1, 45, 5, 41, 8, 38, 0,  3, 7, 35, 4, 60, 3, 60, 6, 86, 
    5, 50, 7, 40, 6, 76, 3, 83, 1, 48, 8, 72, 4,  2, 0, 69, 2, 60, 
    0, 35, 4, 28, 1, 41, 5, 25, 3, 59, 2, 34, 7, 97, 6, 49, 8, 28, 
    8, 60, 4, 66, 3,  4, 7, 22, 1, 85, 0, 24, 5, 97, 6, 95, 2, 82, 
    1, 20, 4, 53, 7, 25, 3, 56, 0, 63, 2, 22, 8, 88, 5,  5, 6, 88, 
    7, 76, 4, 85, 6, 99, 1, 17, 5, 97, 3, 93, 2, 74, 8, 76, 0, 83, 
    6, 40, 5, 73, 4,  4, 3, 40, 1, 80, 0, 32, 8, 84, 2, 48, 7, 71, 
    8, 72, 7,  4, 6, 30, 3, 54, 1, 99, 5, 41, 0, 53, 2, 16, 4, 43
  };
  const int q2373[] = {
    9, 9, // Number of jobs and machines
    2, 44, 3, 45, 1, 14, 8, 88, 4, 24, 7, 68, 6, 69, 5, 11, 0, 81, 
    1, 52, 3, 44, 2, 88, 7, 93, 8, 42, 0,  7, 6, 93, 5, 85, 4, 90, 
    5, 88, 4, 17, 8, 93, 7, 69, 0, 24, 1, 35, 6, 22, 2, 76, 3, 70, 
    6, 70, 0, 11, 7, 32, 5, 19, 3, 56, 2, 25, 4, 44, 8, 59, 1, 53, 
    1, 76, 5, 25, 2, 15, 8, 32, 7, 50, 3, 10, 4, 36, 6, 23, 0,  5, 
    8, 94, 6, 70, 1, 24, 4, 16, 5, 69, 3, 77, 7, 52, 2, 96, 0, 55, 
    3, 94, 7, 45, 5, 30, 8, 26, 6, 57, 4, 96, 0,  2, 2, 66, 1, 40, 
    5, 20, 7, 23, 4, 47, 2, 97, 0, 70, 8, 37, 6, 26, 3,  1, 1, 97, 
    0, 64, 8, 51, 5,  4, 2, 92, 1, 89, 7,  9, 6, 25, 4, 21, 3,  2
  };
  const int q2374[] = {
    9, 9, // Number of jobs and machines
    8, 77, 0, 27, 6, 10, 7,  9, 5,  2, 3, 42, 4, 60, 2, 48, 1,  2, 
    5, 83, 2, 43, 7, 21, 8, 59, 6, 76, 0, 71, 3, 15, 4,  3, 1, 82, 
    5, 12, 2, 73, 8, 76, 1, 58, 6, 61, 4, 28, 3, 18, 7, 41, 0, 63, 
    8, 12, 4, 66, 0, 31, 1,  3, 5, 88, 6,  4, 3, 64, 7, 76, 2,  7, 
    1, 95, 8, 30, 4, 49, 5, 31, 7, 99, 6, 75, 3, 70, 0, 70, 2, 67, 
    0, 19, 8, 15, 4, 54, 7, 32, 1, 33, 6, 13, 2, 50, 3, 38, 5, 61, 
    8, 27, 2, 27, 4, 26, 7, 97, 0, 71, 5, 62, 1, 29, 3, 47, 6, 49, 
    1, 39, 7, 25, 4, 47, 2,  3, 8, 56, 5, 53, 0, 70, 3, 78, 6, 29, 
    7, 63, 8, 45, 3, 65, 6, 98, 5, 53, 0, 56, 1, 74, 4, 32, 2,  7
  };
  const int q2375[] = {
    9, 9, // Number of jobs and machines
    4, 35, 6, 71, 5, 97, 2,  2, 3, 26, 7, 64, 8, 20, 1, 85, 0, 43, 
    3, 24, 1, 83, 0, 81, 8, 37, 2, 63, 5, 46, 7, 26, 6, 29, 4, 46, 
    6,  1, 0, 65, 7, 36, 2, 93, 4, 15, 5, 32, 3, 43, 8, 29, 1, 74, 
    0, 74, 3, 24, 8, 49, 2, 39, 1, 59, 6, 30, 7, 77, 4,  3, 5,  9, 
    5, 71, 2, 36, 7, 97, 8, 32, 3, 11, 6, 57, 4, 73, 0, 99, 1, 59, 
    2, 41, 4, 73, 8, 67, 7, 83, 6, 87, 5, 80, 1, 33, 0,  2, 3, 20, 
    3, 29, 7, 35, 5, 46, 4, 85, 2, 47, 0, 98, 1, 62, 6, 63, 8, 29, 
    7,  4, 0, 36, 8, 68, 3, 49, 6, 66, 5, 64, 4,  5, 1, 32, 2, 99, 
    4, 95, 8, 35, 1, 78, 5, 24, 3, 54, 0, 33, 6, 15, 2, 20, 7, 29
  };
  const int q2376[] = {
    9, 9, // Number of jobs and machines
    8, 33, 0, 87, 7, 41, 1, 34, 3, 67, 5, 93, 4, 98, 2, 77, 6, 51, 
    8, 64, 7, 81, 1, 82, 3,  9, 5, 65, 6, 25, 4, 64, 2, 35, 0, 13, 
    1, 89, 5, 31, 8, 47, 6, 47, 3, 17, 4, 28, 7, 20, 2, 47, 0, 34, 
    1, 82, 2, 55, 6, 65, 4, 80, 5, 41, 7, 26, 8, 21, 0, 96, 3, 38, 
    4, 13, 0, 39, 5, 25, 1, 19, 2, 97, 7, 20, 8, 46, 6, 14, 3, 91, 
    0, 60, 7, 77, 8, 48, 2, 28, 4, 15, 3, 73, 5, 17, 6, 49, 1, 50, 
    8, 76, 4, 42, 6, 99, 2, 40, 5, 62, 1, 17, 0, 99, 7, 80, 3, 18, 
    2, 75, 1, 45, 0, 44, 6, 32, 8, 68, 7, 94, 4, 72, 3, 85, 5, 47, 
    8, 35, 0,  7, 5, 48, 2, 74, 3, 10, 6, 92, 4, 48, 7, 43, 1, 47
  };
  const int q2377[] = {
    9, 9, // Number of jobs and machines
    3, 96, 0, 32, 2,  4, 6, 61, 4, 28, 8,  4, 7,  3, 1, 44, 5, 10, 
    4, 57, 1, 57, 2, 61, 3,  1, 6, 92, 5, 41, 8, 76, 7, 64, 0, 35, 
    6, 64, 1, 62, 2, 52, 8, 49, 3, 72, 7, 26, 0, 82, 4, 42, 5, 99, 
    6, 42, 1, 30, 4, 96, 2, 51, 8, 90, 0, 53, 3, 86, 7, 88, 5, 90, 
    0, 29, 2, 72, 3, 24, 5, 34, 6, 54, 1, 30, 4, 51, 8, 28, 7, 35, 
    2, 61, 6, 25, 3, 82, 0, 37, 1, 26, 7, 24, 5,  8, 4, 79, 8, 19, 
    5, 73, 0, 26, 6, 42, 3, 34, 8, 95, 2, 91, 7, 65, 1, 60, 4, 30, 
    2,  5, 8, 59, 5,  8, 0, 40, 4, 99, 6, 47, 1, 66, 3, 11, 7, 92, 
    3, 66, 5, 46, 0, 14, 4, 17, 6, 23, 7, 92, 2, 57, 1, 19, 8,  7
  };
  const int q2378[] = {
    9, 9, // Number of jobs and machines
    4, 36, 7, 98, 0, 32, 5, 83, 3, 36, 8, 31, 6,  9, 1, 48, 2, 82, 
    0,  5, 8, 70, 6, 38, 5, 65, 7, 89, 2, 57, 3, 35, 4, 25, 1, 51, 
    3, 52, 6, 45, 5, 48, 1, 69, 0, 48, 2, 46, 7, 75, 4, 69, 8, 88, 
    8, 42, 1, 89, 6, 44, 5,  3, 2, 25, 3, 36, 7,  7, 0, 30, 4,  1, 
    7, 16, 0, 10, 1, 97, 2, 33, 3, 81, 6, 22, 4, 66, 5, 40, 8, 44, 
    0, 34, 1, 97, 3,  3, 7, 60, 8, 40, 4, 53, 5,  8, 2, 53, 6, 53, 
    8, 69, 1, 17, 2, 72, 5, 64, 0,  5, 7, 93, 6, 24, 3, 90, 4, 69, 
    6, 17, 8, 39, 2, 51, 1, 51, 5, 75, 7, 80, 3, 49, 0, 10, 4, 26, 
    5, 68, 1, 26, 3, 59, 0, 70, 8, 10, 4, 45, 6, 19, 2, 22, 7, 37
  };
  const int q2379[] = {
    9, 9, // Number of jobs and machines
    6, 19, 7, 66, 1, 59, 3, 80, 0, 53, 2, 39, 4, 25, 8, 24, 5, 93, 
    4, 88, 7, 94, 1, 35, 3, 97, 5, 78, 6, 15, 2, 85, 0, 41, 8, 69, 
    6, 43, 7,  1, 2, 46, 0, 41, 4, 89, 5, 48, 8,  6, 1, 75, 3, 74, 
    0, 19, 1, 28, 3, 81, 4, 59, 5, 20, 7, 38, 6, 63, 2, 93, 8, 43, 
    7, 75, 4, 61, 3, 90, 8,  8, 2, 26, 5, 30, 0, 56, 1, 89, 6, 77, 
    8, 72, 5, 63, 7, 53, 2, 72, 6, 15, 3, 46, 4, 41, 1, 75, 0, 70, 
    5,  7, 8, 80, 6, 80, 7, 77, 0,  7, 1, 38, 2, 89, 4, 17, 3, 84, 
    8,  2, 5, 30, 3, 63, 2, 88, 0, 76, 1, 53, 6, 86, 7, 85, 4, 89, 
    7, 73, 0, 62, 3, 49, 2, 97, 1, 92, 4, 51, 5, 42, 8, 21, 6, 18
  };
  const int q2380[] = {
    9, 9, // Number of jobs and machines
    4, 59, 5,  4, 2, 47, 3, 43, 7, 82, 8,  6, 6,  5, 1, 94, 0, 91, 
    4, 95, 6, 52, 7, 26, 2, 18, 5, 61, 1,  5, 8, 76, 0, 67, 3, 85, 
    3, 77, 0, 10, 2, 44, 4, 80, 5, 59, 7, 84, 8, 52, 1,  8, 6, 29, 
    5, 45, 0, 62, 2, 71, 1,  1, 7, 54, 4, 71, 3, 36, 8, 53, 6, 74, 
    2, 19, 3, 92, 6,  6, 4, 94, 7, 27, 1, 24, 8, 77, 5, 29, 0, 43, 
    8, 74, 7, 95, 1, 25, 6, 50, 2, 70, 0, 51, 4, 23, 3, 35, 5, 17, 
    5, 30, 2, 96, 8, 19, 1, 85, 0, 66, 4,  3, 6, 31, 7, 33, 3, 64, 
    1, 37, 4, 95, 5, 72, 3, 12, 8, 93, 0, 46, 2, 91, 6, 36, 7, 44, 
    6, 75, 1, 72, 3, 35, 7, 95, 4, 47, 2, 35, 0, 18, 5, 18, 8, 84
  };
  const int q2381[] = {
    9, 9, // Number of jobs and machines
    6, 98, 0, 38, 2, 29, 1, 47, 3, 47, 4, 99, 7, 87, 8, 93, 5, 97, 
    2, 13, 5, 73, 1, 17, 7,  5, 0, 24, 3, 91, 8, 36, 6, 44, 4,  6, 
    1, 46, 5, 82, 3, 59, 8,  7, 7, 35, 6, 23, 2, 27, 0, 71, 4, 25, 
    7, 90, 1, 46, 6, 97, 3, 59, 8, 94, 2, 11, 4,  7, 5, 37, 0, 56, 
    5, 36, 2, 58, 6, 58, 8, 42, 1, 58, 7,  3, 3, 26, 0, 25, 4, 75, 
    7, 95, 2, 88, 8, 93, 6, 56, 3, 71, 4, 19, 0, 53, 5, 73, 1, 57, 
    7, 30, 6, 56, 8, 60, 3, 79, 0, 72, 1, 83, 4, 39, 5, 48, 2, 55, 
    6,  4, 7, 24, 8, 83, 1, 43, 5, 55, 0, 77, 2, 66, 4,  6, 3, 33, 
    1,  5, 5, 90, 2, 13, 4, 17, 3, 62, 8,  9, 7, 76, 6, 46, 0, 33
  };
  const int q2382[] = {
    9, 9, // Number of jobs and machines
    0, 66, 4, 36, 3, 28, 7, 62, 1, 39, 2,  4, 8, 96, 5, 89, 6, 89, 
    3, 40, 1,  1, 0,  2, 4, 68, 5, 77, 2, 67, 8, 61, 7, 63, 6, 20, 
    0, 57, 6, 33, 3, 55, 2, 82, 5,  6, 7, 86, 4, 22, 8, 28, 1, 73, 
    7, 96, 6, 47, 5, 12, 3, 39, 8, 16, 2, 47, 0, 39, 1,  2, 4, 91, 
    1, 98, 7, 28, 0, 95, 4, 52, 3, 93, 6, 85, 8, 67, 2, 40, 5, 26, 
    6, 78, 7, 64, 5, 41, 0, 84, 3, 96, 2, 57, 8, 29, 4, 10, 1, 99, 
    1, 47, 7, 38, 5, 80, 3, 47, 2, 46, 0, 20, 6, 68, 8, 36, 4, 40, 
    5, 67, 1, 70, 0, 63, 3, 32, 7, 70, 6, 81, 4,  6, 8, 83, 2, 23, 
    3, 84, 7, 96, 8, 48, 1, 24, 2, 90, 5, 55, 0, 57, 4, 15, 6, 62
  };
  const int q2383[] = {
    9, 9, // Number of jobs and machines
    3,  5, 0, 61, 1, 30, 2, 90, 4, 62, 7, 44, 6, 47, 8, 45, 5, 30, 
    7, 62, 2, 73, 1, 62, 8, 19, 6, 57, 3, 79, 5, 97, 0, 97, 4, 97, 
    8, 21, 1, 99, 7, 70, 4, 58, 0, 20, 5,  5, 3, 54, 2, 30, 6, 32, 
    2, 41, 1, 87, 4, 62, 8, 28, 0, 85, 3, 90, 5, 95, 7, 33, 6, 37, 
    6, 70, 1, 86, 8, 67, 7, 23, 2, 26, 5, 30, 4, 19, 0,  8, 3, 49, 
    4, 95, 0, 66, 6, 55, 7, 50, 5, 12, 3, 21, 2, 16, 8, 43, 1, 64, 
    0, 77, 8, 25, 5, 79, 3, 51, 4,  6, 2, 39, 6, 88, 7, 64, 1, 83, 
    7, 99, 5, 36, 1, 25, 8, 71, 2, 97, 4, 15, 6, 23, 3, 13, 0, 18, 
    8, 28, 1, 71, 7,  1, 4, 84, 6, 69, 2, 66, 0, 42, 3, 87, 5, 79
  };
  const int q2384[] = {
    9, 9, // Number of jobs and machines
    0, 40, 8, 75, 3, 70, 1, 20, 7,  7, 4, 56, 2, 70, 5, 52, 6, 49, 
    1, 50, 7, 29, 6, 31, 4,  3, 2, 48, 3, 82, 0, 99, 8, 40, 5, 18, 
    0, 53, 7, 52, 6, 70, 2, 15, 8, 57, 1, 70, 4, 93, 5,  1, 3, 63, 
    7, 43, 5, 68, 6,  5, 0, 71, 2, 42, 8, 13, 4, 18, 3,  7, 1, 79, 
    8, 15, 1, 87, 2, 66, 7, 20, 6, 72, 4, 37, 3, 68, 0, 19, 5,  2, 
    8, 96, 5, 59, 3, 36, 6, 58, 1, 75, 0, 47, 4, 61, 2,  1, 7, 87, 
    2, 64, 7, 42, 1, 28, 5, 80, 8, 55, 4, 25, 0, 47, 3, 83, 6, 29, 
    1, 87, 8, 23, 0, 24, 2, 45, 7, 43, 3, 22, 5, 16, 6, 29, 4, 20, 
    5,  1, 7, 30, 2, 56, 0, 88, 8, 80, 3, 19, 1, 22, 4, 31, 6, 58
  };
  const int q2385[] = {
    9, 9, // Number of jobs and machines
    3, 65, 6, 92, 7,  9, 8, 38, 5, 76, 1, 80, 4, 95, 2, 66, 0, 68, 
    5, 98, 7, 67, 2, 28, 8, 87, 6, 12, 4, 71, 3, 31, 0, 60, 1, 50, 
    0, 15, 1, 84, 4, 18, 5, 64, 7, 51, 3, 53, 8, 88, 2, 66, 6, 84, 
    2, 33, 7, 66, 5, 37, 1, 88, 3, 27, 4, 84, 0, 58, 6, 36, 8, 82, 
    4, 95, 8, 91, 5, 47, 6, 92, 2, 33, 1, 54, 7, 96, 0, 23, 3,  8, 
    8, 92, 4, 54, 2, 96, 1, 42, 5, 16, 0, 52, 6, 46, 7, 70, 3, 52, 
    0, 12, 3, 75, 1,  3, 8, 33, 5, 63, 6, 77, 2, 53, 4,  6, 7, 56, 
    8, 38, 4, 81, 7, 88, 2, 16, 5, 90, 1,  3, 6, 66, 3, 63, 0, 25, 
    2,  9, 4, 17, 6, 90, 1, 12, 5, 26, 8, 72, 0, 31, 7, 12, 3, 54
  };
  const int q2386[] = {
    9, 9, // Number of jobs and machines
    4, 33, 7, 14, 3, 84, 8, 85, 1, 65, 5, 42, 0, 81, 2, 73, 6, 43, 
    0, 40, 2, 43, 7, 89, 1, 67, 4, 69, 5, 56, 8, 26, 6, 64, 3, 36, 
    8, 31, 3, 47, 4, 65, 5, 19, 2, 40, 6, 48, 0, 62, 7, 83, 1, 73, 
    7, 53, 3, 22, 0, 62, 1, 58, 2, 25, 4,  2, 5, 80, 8, 39, 6, 79, 
    4, 54, 7, 98, 6, 11, 0, 73, 2, 60, 8, 54, 5, 70, 1,  4, 3, 96, 
    1, 42, 3, 21, 7, 22, 2, 81, 8, 55, 4,  6, 0, 70, 5, 43, 6, 33, 
    3, 96, 8, 56, 2,  6, 5, 89, 7,  9, 1, 88, 0, 71, 4, 99, 6, 42, 
    8, 66, 4, 35, 6, 20, 1, 47, 0,  8, 7, 15, 2, 48, 5, 18, 3, 69, 
    7, 69, 3, 46, 6, 91, 1,  3, 2,  9, 5, 92, 0, 36, 4, 89, 8, 29
  };
  const int q2387[] = {
    9, 9, // Number of jobs and machines
    6,  3, 0, 93, 7, 39, 2, 64, 4, 71, 5, 33, 1,  7, 8, 21, 3, 83, 
    3, 72, 6,  8, 2, 54, 4, 86, 8, 39, 5, 24, 0, 13, 7, 65, 1, 83, 
    5, 80, 0, 57, 3, 20, 6, 19, 8, 26, 4, 66, 2, 88, 1, 55, 7, 58, 
    8, 49, 3, 97, 4, 49, 7, 21, 5, 72, 0, 46, 6, 92, 2, 37, 1, 56, 
    4, 64, 5, 62, 2, 30, 0, 85, 8, 55, 6, 79, 3, 88, 1, 68, 7, 97, 
    7, 36, 6, 21, 4, 72, 8, 24, 5, 63, 1, 33, 0, 80, 3, 10, 2, 45, 
    4, 58, 3, 52, 2,  7, 7, 52, 1, 57, 8, 78, 0, 31, 6, 34, 5, 45, 
    4, 43, 3, 78, 7, 89, 0, 93, 1, 18, 5, 68, 2, 26, 6, 75, 8, 30, 
    4, 24, 3, 23, 2, 19, 6,  1, 5, 22, 8, 34, 7,  8, 0,  9, 1,  1
  };
  const int q2388[] = {
    9, 9, // Number of jobs and machines
    4, 39, 8, 13, 3,  9, 5, 46, 2, 76, 7, 59, 6, 16, 1, 81, 0, 32, 
    4, 13, 8, 49, 3, 78, 6, 24, 2, 75, 1, 30, 7, 35, 5, 67, 0, 15, 
    6, 89, 1, 73, 4, 68, 5, 27, 0, 89, 8, 33, 3, 35, 7, 86, 2, 14, 
    2, 97, 5, 20, 6, 52, 0, 79, 1, 57, 7, 33, 3,  5, 4, 96, 8, 27, 
    7, 94, 4, 86, 1, 60, 2, 79, 5, 41, 0, 65, 3, 47, 6, 11, 8,  6, 
    8, 78, 6, 99, 1, 54, 0, 26, 4, 50, 5, 35, 2, 99, 3, 37, 7, 21, 
    5, 84, 2, 52, 6, 65, 1, 35, 7, 86, 3, 94, 0, 55, 8, 16, 4, 87, 
    4, 29, 1, 26, 6, 53, 5, 29, 0, 52, 3, 11, 8, 56, 7,  7, 2, 72, 
    6, 88, 3, 59, 2, 82, 7, 30, 1, 86, 8, 91, 5, 81, 0, 37, 4, 33
  };
  const int q2389[] = {
    9, 9, // Number of jobs and machines
    6, 36, 4, 56, 5, 39, 0, 69, 2, 57, 1, 16, 7, 91, 8, 26, 3, 99, 
    0, 10, 7, 54, 6,  5, 1, 87, 5,  3, 3, 36, 2,  5, 8, 34, 4, 34, 
    2,  5, 1, 12, 3, 40, 0, 53, 5, 40, 6, 78, 4, 39, 8, 46, 7, 10, 
    6, 77, 2, 23, 8, 57, 1, 89, 7, 18, 0, 48, 4, 91, 3, 25, 5, 73, 
    6, 16, 8, 50, 3, 91, 7, 88, 5, 91, 2, 18, 0, 66, 4, 13, 1, 46, 
    1, 70, 8, 83, 3,  9, 5, 26, 2, 15, 4, 75, 0, 98, 6, 92, 7, 12, 
    3, 16, 8, 92, 5, 29, 2, 12, 0, 80, 4, 58, 1, 29, 7, 10, 6, 76, 
    8, 14, 0, 78, 5, 78, 1, 38, 6, 18, 4, 63, 2, 56, 7, 10, 3, 86, 
    6, 81, 5, 34, 1, 88, 7, 66, 8,  3, 2, 57, 3, 39, 0, 16, 4, 28
  };
  const int q2390[] = {
    9, 9, // Number of jobs and machines
    3,  7, 1, 60, 6, 36, 5, 89, 4, 86, 0, 79, 8, 47, 2, 33, 7, 17, 
    4,  9, 5,  7, 0, 61, 7, 36, 6, 92, 8, 62, 3, 14, 1, 89, 2, 45, 
    3, 18, 1, 57, 2,  8, 6, 37, 7, 24, 8, 18, 0, 98, 4, 21, 5, 11, 
    0,  4, 5, 97, 7, 58, 6, 98, 3, 28, 8, 86, 1, 38, 4, 78, 2, 85, 
    2, 50, 6, 75, 5, 55, 8, 62, 0, 86, 3, 70, 7,  3, 4,  5, 1, 37, 
    2, 88, 8, 98, 7, 46, 3, 58, 1, 87, 6, 43, 5, 55, 0, 66, 4, 86, 
    1, 73, 7,  5, 5, 12, 3,  7, 4, 60, 6,  1, 8, 62, 2, 42, 0,  3, 
    0, 18, 3, 19, 7, 27, 8, 98, 5, 89, 6,  7, 1, 21, 2, 17, 4, 39, 
    2, 21, 1, 62, 5, 74, 0, 99, 4, 65, 6, 78, 7, 77, 3, 64, 8, 80
  };
  const int q2391[] = {
    9, 9, // Number of jobs and machines
    8, 38, 5, 38, 2, 73, 6,  3, 1, 61, 0, 59, 7, 26, 3, 75, 4, 76, 
    0, 36, 3, 50, 1, 20, 7, 98, 4, 38, 5, 98, 2, 41, 8, 57, 6, 16, 
    7, 48, 0, 31, 5, 34, 6, 35, 4, 74, 2, 34, 8,  8, 1, 67, 3, 14, 
    5, 38, 7, 34, 1, 75, 8, 91, 0, 32, 6, 73, 4, 74, 3, 94, 2, 11, 
    4, 43, 6, 22, 5, 69, 7, 10, 0, 23, 3, 61, 2,  9, 1, 45, 8, 93, 
    1, 11, 0, 54, 2, 34, 3, 47, 5, 95, 4, 91, 6, 95, 8, 58, 7, 86, 
    4, 72, 2, 19, 5, 16, 0,  1, 1,  8, 6, 70, 3, 75, 8, 98, 7, 21, 
    7, 31, 2, 87, 3, 98, 4, 48, 8, 37, 6, 52, 5, 68, 0, 97, 1,  5, 
    3, 73, 8, 40, 7, 17, 1, 37, 5, 47, 4, 79, 6, 70, 2, 83, 0, 69
  };
  const int q2392[] = {
    9, 9, // Number of jobs and machines
    8, 36, 6, 24, 0, 45, 4, 89, 7, 56, 1, 49, 3,  4, 5, 24, 2, 90, 
    4, 45, 5, 94, 0,  7, 7, 63, 1, 74, 2, 23, 6, 33, 8,  9, 3, 83, 
    3, 80, 1, 34, 6, 59, 4, 19, 7, 88, 0, 72, 8, 46, 5, 73, 2, 29, 
    0, 68, 2, 70, 7, 31, 5,  3, 8, 58, 3, 21, 6, 42, 1, 69, 4, 62, 
    6, 84, 2, 63, 0,  4, 7, 74, 4, 90, 5, 42, 3, 65, 1, 84, 8, 39, 
    0, 63, 3, 88, 5, 12, 2, 48, 7, 38, 1, 84, 4, 61, 6, 80, 8, 52, 
    3, 89, 2, 35, 7, 27, 8, 85, 6, 56, 0, 71, 5, 34, 4, 71, 1, 89, 
    6, 98, 1, 84, 0, 76, 3,  2, 7, 83, 2, 44, 8,  1, 4, 46, 5, 60, 
    7, 58, 6, 19, 2, 96, 5, 51, 3, 51, 0, 72, 1, 80, 4, 70, 8, 25
  };
  const int q2393[] = {
    9, 9, // Number of jobs and machines
    3, 46, 8, 45, 0, 31, 2, 22, 5, 14, 1, 78, 6, 13, 7, 24, 4, 73, 
    4, 51, 3, 60, 0, 30, 1,  7, 2, 61, 8, 57, 7, 23, 5, 36, 6, 84, 
    1, 60, 6, 34, 5,  9, 2, 94, 0, 32, 8, 68, 4, 94, 7, 53, 3, 58, 
    8, 66, 1,  4, 2, 74, 0, 84, 6, 50, 5, 70, 3, 94, 4,  9, 7, 63, 
    3, 19, 5, 34, 6, 24, 4,  1, 7, 38, 2, 52, 0,  4, 8, 70, 1, 74, 
    0, 69, 5, 73, 1, 29, 8, 43, 4, 10, 3, 26, 7,  1, 6, 28, 2, 82, 
    4, 71, 3, 68, 2, 71, 6, 85, 0, 48, 5, 73, 1, 55, 8, 64, 7, 43, 
    4, 36, 6,  7, 8, 80, 5, 43, 3, 91, 7, 95, 0,  7, 1, 50, 2, 98, 
    4, 36, 7,  7, 0, 37, 3, 49, 5, 19, 2, 73, 1, 35, 6, 73, 8, 25
  };
  const int q2394[] = {
    9, 9, // Number of jobs and machines
    8, 74, 6, 40, 1, 19, 2, 67, 3,  4, 0, 51, 4, 80, 7, 42, 5, 48, 
    5, 70, 8,  2, 4, 11, 1, 52, 0, 17, 7, 37, 6, 89, 3,  7, 2,  3, 
    1, 90, 0, 75, 6, 14, 8, 38, 4, 55, 3, 81, 2,  6, 5, 13, 7, 74, 
    6, 28, 1, 16, 0,  2, 5,  9, 7, 69, 8, 14, 3, 94, 4, 82, 2, 38, 
    2, 92, 1, 14, 5, 12, 7, 42, 4, 66, 0, 28, 8, 55, 6, 77, 3, 62, 
    3, 86, 6, 54, 4, 28, 5,  3, 7, 98, 1, 73, 8, 56, 0, 30, 2, 96, 
    7, 31, 6, 28, 2, 36, 8, 21, 4, 43, 0, 58, 3, 86, 1, 17, 5, 47, 
    5, 72, 3, 34, 1, 27, 2, 63, 7, 27, 4, 38, 8, 76, 0, 90, 6, 30, 
    6, 88, 1, 73, 2, 57, 8, 84, 3, 61, 0, 52, 4, 60, 7, 13, 5, 84
  };
  const int q2395[] = {
    9, 9, // Number of jobs and machines
    6, 41, 8, 26, 7, 92, 5, 88, 4, 31, 2, 52, 3, 99, 1,  3, 0, 56, 
    1, 81, 2, 67, 6, 63, 4, 98, 5, 28, 7, 22, 0, 58, 3, 18, 8, 36, 
    3, 16, 7,  9, 8, 42, 1, 29, 5, 88, 4, 85, 2, 12, 0,  2, 6,  1, 
    1, 61, 8, 53, 3, 59, 6, 55, 2, 58, 5, 76, 0, 87, 4, 73, 7, 92, 
    5, 19, 4, 62, 0, 66, 1, 39, 3, 72, 2, 31, 6, 61, 7, 71, 8, 98, 
    8, 42, 5, 33, 4, 67, 2, 44, 0, 19, 1, 70, 6, 70, 7, 56, 3, 17, 
    6, 82, 8, 57, 4, 79, 1, 60, 5, 77, 0, 40, 3,  9, 2, 23, 7, 47, 
    1, 27, 7, 62, 2, 47, 3, 56, 0, 92, 8, 25, 6, 69, 5, 98, 4, 85, 
    6, 82, 4, 73, 2, 43, 3,  9, 0, 71, 8, 48, 7, 78, 5, 79, 1, 70
  };
  const int q2396[] = {
    9, 9, // Number of jobs and machines
    5,  6, 7, 27, 1, 33, 4, 24, 6, 72, 8, 88, 2, 22, 0, 18, 3, 35, 
    5, 39, 1, 13, 4, 12, 8, 93, 6, 64, 0, 54, 7, 92, 2, 45, 3, 32, 
    6, 36, 8, 12, 7, 37, 2, 72, 0, 44, 4, 84, 5, 35, 3, 60, 1, 74, 
    7, 99, 6,  3, 0, 18, 3,  8, 1, 93, 5, 44, 8,  9, 2, 69, 4, 99, 
    5, 27, 0, 29, 2, 93, 1, 41, 8, 81, 6, 98, 3, 11, 7, 44, 4, 16, 
    2, 91, 6, 52, 7, 51, 3, 75, 8, 91, 0,  4, 1, 46, 4, 66, 5, 25, 
    3, 70, 1, 34, 4, 32, 5, 26, 8, 57, 7, 36, 6, 62, 2, 55, 0, 33, 
    2, 86, 3, 83, 5, 64, 0, 66, 8,  2, 6, 47, 7, 59, 1, 34, 4, 90, 
    8, 16, 5, 69, 0, 72, 6, 92, 1, 61, 7, 91, 4, 38, 3, 33, 2, 13
  };
  const int q2397[] = {
    9, 9, // Number of jobs and machines
    4, 60, 1, 14, 6, 20, 2, 64, 3, 94, 5, 72, 7, 57, 0,  4, 8, 15, 
    6, 32, 4, 14, 2, 20, 0, 83, 1, 60, 8, 37, 3, 32, 7, 94, 5, 68, 
    2, 12, 1,  5, 8, 31, 0, 66, 4, 71, 3, 81, 7, 48, 5, 71, 6, 24, 
    8,  4, 4, 69, 5, 39, 3, 47, 6, 52, 1, 34, 2, 64, 7, 92, 0, 80, 
    3, 34, 1, 47, 2, 37, 4, 70, 8, 60, 0, 27, 5, 74, 7, 88, 6, 95, 
    8, 91, 7, 90, 3, 44, 5, 91, 6, 69, 0, 84, 2, 68, 4, 51, 1, 68, 
    4, 83, 6, 42, 8, 42, 1, 94, 7, 27, 3, 71, 0, 68, 2, 11, 5,  4, 
    5, 26, 0, 28, 7, 33, 8, 85, 4, 62, 3, 81, 1, 45, 6, 61, 2,  3, 
    5, 72, 8, 18, 0, 81, 4, 50, 1, 31, 6, 42, 3, 50, 7, 87, 2, 17
  };
  const int q2398[] = {
    9, 9, // Number of jobs and machines
    6, 46, 0, 98, 7, 65, 1, 47, 2, 86, 5, 27, 4, 47, 8, 23, 3, 12, 
    7, 22, 6, 37, 2, 78, 1, 55, 3, 34, 0, 21, 4, 76, 5, 11, 8, 49, 
    5, 79, 3, 91, 8, 12, 4, 48, 0,  3, 1, 46, 7, 83, 2, 47, 6, 65, 
    4, 29, 1, 78, 3, 34, 7, 37, 2, 64, 8, 53, 0, 25, 6, 53, 5, 71, 
    3, 61, 2, 24, 6, 70, 1, 98, 0, 66, 8, 27, 5, 73, 7,  8, 4, 37, 
    7, 99, 2, 40, 1, 77, 8,  2, 6, 44, 4, 57, 5, 45, 0, 39, 3, 65, 
    8, 98, 6, 44, 7, 90, 0, 81, 5, 53, 2, 16, 1, 88, 4, 81, 3, 83, 
    6, 63, 2, 84, 0, 11, 8, 78, 4, 17, 1, 88, 7, 75, 5, 60, 3, 13, 
    4, 37, 5, 77, 3, 46, 2, 90, 1, 71, 7, 61, 0, 79, 8, 78, 6, 33
  };
  const int q2399[] = {
    9, 9, // Number of jobs and machines
    8, 10, 1, 37, 2, 71, 5, 48, 3, 28, 4, 84, 0, 49, 7, 76, 6, 46, 
    1, 16, 8, 95, 2, 50, 3, 78, 5, 92, 6, 17, 4, 57, 7, 67, 0, 38, 
    6, 92, 8, 23, 4, 73, 3, 41, 7, 61, 1, 90, 2, 14, 0, 34, 5, 17, 
    8, 95, 0, 57, 1, 80, 6, 55, 7, 60, 3, 11, 5,  6, 2, 99, 4, 77, 
    4, 34, 0, 99, 6, 62, 2, 22, 5, 28, 8, 70, 3,  8, 7, 72, 1, 41, 
    0, 92, 2, 67, 6,  2, 7, 70, 8, 52, 4, 49, 5,  2, 1, 55, 3, 77, 
    6, 98, 4, 43, 1, 62, 5,  5, 7,  3, 8, 33, 0, 75, 3, 68, 2, 92, 
    7, 55, 2, 23, 6, 64, 8, 99, 0, 14, 4, 41, 5, 78, 1,  7, 3, 82, 
    2, 47, 1, 67, 8, 88, 6, 36, 3, 26, 5, 29, 7, 67, 0, 99, 4, 37
  };
  const int q2400[] = {
    9, 9, // Number of jobs and machines
    2,  8, 0, 29, 8, 17, 1, 32, 6, 10, 4, 74, 3, 58, 7, 14, 5, 47, 
    0, 82, 4, 50, 7, 30, 1, 63, 6, 17, 5, 27, 8, 40, 3, 62, 2, 79, 
    7, 94, 0,  9, 6, 35, 5, 27, 4, 78, 2,  9, 3, 65, 8, 99, 1, 11, 
    3, 21, 0, 14, 4, 22, 1, 26, 6, 43, 8, 47, 5, 14, 2, 12, 7, 20, 
    8,  3, 2, 79, 3, 84, 5, 31, 1, 69, 0, 49, 7, 82, 4, 32, 6, 61, 
    6,  6, 0, 13, 2, 13, 8,  8, 5, 76, 3, 42, 1, 34, 4, 19, 7, 15, 
    4, 50, 6, 43, 5, 60, 2, 66, 1, 63, 0,  5, 3, 64, 7, 62, 8, 86, 
    6,  6, 5, 72, 8, 66, 1,  1, 2, 37, 7, 98, 0, 68, 3,  2, 4, 21, 
    1, 56, 8, 86, 7, 60, 6, 54, 0, 35, 3, 90, 2,  2, 4, 42, 5, 82
  };
  const int q2401[] = {
    9, 9, // Number of jobs and machines
    3, 16, 6, 17, 0, 72, 5, 48, 4, 77, 7, 28, 8, 16, 2, 60, 1, 44, 
    1, 98, 4, 87, 3, 56, 7, 38, 5, 72, 2, 20, 8, 81, 6, 34, 0, 42, 
    6, 20, 3, 14, 7, 14, 4, 17, 2,  2, 0, 91, 8, 16, 1, 40, 5, 79, 
    8, 71, 6, 52, 2, 78, 0, 53, 3, 12, 5, 96, 7, 17, 4, 35, 1, 46, 
    7, 30, 5, 43, 4, 48, 1, 40, 0, 23, 2, 31, 3, 80, 6, 77, 8, 50, 
    0, 51, 8, 42, 1, 82, 3, 19, 6,  7, 2, 93, 4, 69, 7, 56, 5, 82, 
    7, 98, 3, 91, 4, 48, 5, 97, 8, 79, 0, 10, 6, 75, 2, 84, 1, 69, 
    0, 63, 5,  6, 4, 13, 3, 83, 2, 97, 1, 90, 8, 37, 6, 43, 7, 73, 
    2, 19, 6,  5, 8,  1, 5,  9, 7, 80, 3, 10, 4,  7, 0, 66, 1, 17
  };
  const int q2402[] = {
    9, 9, // Number of jobs and machines
    4, 81, 3, 13, 7, 20, 6, 84, 1, 71, 5, 35, 8, 11, 2, 95, 0, 59, 
    7, 30, 1, 93, 4, 37, 3, 58, 5, 18, 0, 28, 8, 70, 2, 22, 6, 86, 
    6, 54, 0, 89, 3, 32, 8, 52, 5, 41, 4, 63, 7, 44, 2, 25, 1, 82, 
    5, 51, 3, 44, 8, 10, 7, 45, 1, 67, 0, 88, 4, 15, 6,  5, 2, 48, 
    2, 71, 5, 14, 0, 72, 3, 46, 4, 12, 8, 12, 1, 87, 7, 81, 6,  8, 
    1,  8, 5, 41, 0,  3, 4,  9, 7, 21, 6, 31, 3, 68, 2, 30, 8, 53, 
    4, 37, 8, 15, 1, 29, 6, 22, 7, 85, 0, 70, 2, 19, 5, 66, 3, 96, 
    5, 77, 2, 96, 7, 14, 4, 94, 0, 63, 3, 13, 1,  2, 8, 86, 6, 15, 
    3, 89, 6, 91, 7, 51, 1, 22, 2, 12, 8, 53, 0, 18, 4, 25, 5, 33
  };
  const int q2403[] = {
    9, 9, // Number of jobs and machines
    6, 25, 1, 90, 7, 33, 8,  4, 3, 19, 2, 28, 5, 98, 4, 66, 0, 98, 
    2, 75, 6,  2, 1, 52, 0, 32, 7, 66, 5, 84, 8, 34, 3, 80, 4, 49, 
    0, 41, 7,  4, 2,  7, 1, 48, 5, 14, 3, 90, 4, 30, 6, 13, 8, 66, 
    7, 72, 6, 89, 8, 87, 5, 50, 2, 23, 1, 64, 3, 55, 0, 63, 4,  7, 
    2, 87, 8, 47, 4, 23, 6,  8, 3, 54, 0, 13, 7, 47, 1, 96, 5, 95, 
    2, 64, 7, 67, 5,  8, 0,  6, 1, 68, 4, 61, 3, 47, 6, 15, 8, 60, 
    4, 18, 1,  9, 2, 54, 8, 69, 6, 66, 3, 89, 7, 93, 0, 57, 5, 46, 
    5,  5, 3, 72, 2,  9, 4,  6, 0, 30, 1, 51, 7, 81, 8, 37, 6, 49, 
    7, 96, 1, 28, 4, 94, 0,  6, 6, 76, 5, 42, 2, 58, 8, 37, 3, 17
  };
  const int q2404[] = {
    9, 9, // Number of jobs and machines
    0, 45, 1, 76, 2, 51, 4, 89, 3, 59, 6, 75, 8, 28, 7,  9, 5, 70, 
    1, 14, 7, 63, 6, 37, 4,  4, 5, 58, 2, 32, 3, 33, 0, 45, 8,  6, 
    0, 80, 4, 40, 8, 60, 5, 62, 7, 39, 2,  6, 3, 48, 1, 75, 6, 36, 
    3, 61, 2, 42, 5, 64, 4, 88, 0, 56, 1, 23, 7, 66, 6, 94, 8, 66, 
    6, 55, 5, 18, 3, 31, 2, 57, 0, 97, 4, 28, 7, 99, 1, 53, 8,  2, 
    1, 95, 3,  9, 0, 65, 5, 24, 6, 99, 4,  6, 2, 95, 7, 58, 8, 46, 
    2, 44, 1,  5, 5, 30, 7, 90, 8, 22, 6, 54, 0, 94, 4, 55, 3, 14, 
    4, 19, 8, 42, 6, 95, 0, 95, 2, 36, 5,  9, 3, 81, 7, 34, 1,  9, 
    4,  5, 6, 23, 5, 14, 7,  1, 2, 42, 8, 73, 1,  6, 3, 85, 0,  1
  };
  const int q2405[] = {
    9, 9, // Number of jobs and machines
    1, 29, 0, 23, 6, 73, 4, 96, 8, 94, 7, 64, 5, 41, 2, 53, 3, 98, 
    4, 21, 2, 94, 5, 56, 7, 79, 8, 85, 0, 47, 1, 39, 3, 28, 6, 67, 
    3, 41, 7, 54, 1, 53, 5, 39, 4, 30, 8,  6, 6, 17, 2, 36, 0, 41, 
    1,  4, 0, 11, 4, 70, 5, 72, 8, 41, 2, 90, 7, 90, 6, 35, 3, 21, 
    2, 70, 6, 74, 0, 82, 7, 13, 8, 47, 4, 96, 5,  5, 1, 56, 3, 21, 
    8, 72, 5, 48, 3, 86, 7, 99, 6, 96, 4, 33, 1, 14, 2, 22, 0, 68, 
    8, 99, 2, 66, 6,  9, 7, 89, 0, 59, 3, 16, 5, 15, 4, 93, 1, 17, 
    5, 50, 6, 53, 2, 30, 4, 26, 8, 61, 3,  4, 0, 98, 1, 97, 7, 71, 
    1, 11, 2, 89, 6, 72, 4, 36, 5, 83, 7, 28, 3, 38, 0, 13, 8, 20
  };
  const int q2406[] = {
    9, 9, // Number of jobs and machines
    5, 30, 6,  9, 3,  4, 8, 61, 7, 58, 0,  5, 2, 81, 4, 24, 1, 86, 
    7, 12, 8,  6, 6, 41, 4, 46, 2, 46, 3, 70, 5, 69, 0, 39, 1, 75, 
    0, 58, 3, 68, 5, 20, 7, 61, 1, 79, 4, 53, 6, 77, 2,  2, 8, 66, 
    8, 53, 4, 19, 5,  3, 7, 58, 1, 38, 0, 38, 6, 71, 2, 39, 3, 26, 
    3, 22, 7, 12, 0, 11, 6, 96, 5, 30, 4, 99, 1, 53, 8, 83, 2, 22, 
    0, 11, 2, 30, 6,  2, 7, 86, 5, 19, 8, 54, 3, 47, 1, 87, 4, 39, 
    8, 58, 4,  9, 5, 59, 3, 88, 0, 70, 1, 57, 7, 87, 6,  3, 2, 34, 
    0, 88, 8,  3, 6,  6, 7, 17, 4, 62, 1, 79, 3, 60, 5, 18, 2, 61, 
    6, 26, 7, 72, 2, 47, 0, 26, 8, 28, 3, 40, 4, 46, 1, 16, 5, 46
  };
  const int q2407[] = {
    9, 9, // Number of jobs and machines
    1, 33, 2, 20, 7,  1, 5, 51, 3, 66, 6, 80, 4, 70, 8, 40, 0, 28, 
    6,  6, 2, 37, 1, 35, 4, 83, 0, 46, 5, 33, 7, 74, 3, 34, 8, 65, 
    7, 16, 4, 79, 6, 47, 2, 48, 8, 95, 1, 51, 5,  4, 0, 15, 3, 96, 
    5, 54, 8, 52, 6, 47, 1, 72, 4, 54, 3, 23, 0,  6, 2, 23, 7, 31, 
    7, 29, 8, 86, 6, 63, 1, 70, 4, 81, 0, 28, 3, 68, 2, 89, 5, 35, 
    5, 84, 4, 42, 7, 89, 0,  4, 2, 81, 3, 99, 6, 39, 1, 96, 8, 94, 
    8, 34, 1, 20, 0, 14, 6, 51, 2, 91, 5, 62, 4, 42, 3, 27, 7, 12, 
    4,  9, 1, 17, 8, 96, 3, 10, 2, 82, 6, 34, 5,  9, 0, 40, 7, 56, 
    4, 48, 5, 97, 6, 33, 1, 52, 7, 43, 2, 40, 8, 21, 3, 90, 0, 20
  };
  const int q2408[] = {
    9, 9, // Number of jobs and machines
    1, 42, 6, 37, 0, 19, 7, 34, 5, 80, 3, 99, 8, 74, 2, 76, 4, 84, 
    0, 64, 1, 13, 8, 29, 6, 21, 7, 39, 5, 93, 2, 89, 3, 74, 4, 99, 
    1, 90, 6, 17, 7, 97, 5, 21, 0, 52, 8, 73, 4, 19, 3, 80, 2, 91, 
    7, 20, 0, 22, 3, 40, 2, 95, 8, 55, 5,  7, 6, 91, 1, 93, 4, 14, 
    2, 46, 6, 39, 5, 56, 4, 29, 3,  6, 8, 92, 1, 28, 7, 54, 0, 20, 
    4, 73, 3, 67, 7, 14, 5, 35, 0, 80, 2, 41, 8, 14, 1, 21, 6, 13, 
    3,  9, 1, 39, 6, 67, 0, 76, 7, 40, 4, 10, 8, 82, 5, 35, 2, 12, 
    5, 70, 7,  1, 6, 59, 2, 43, 4,  5, 0, 80, 1, 72, 8,  8, 3, 41, 
    4, 98, 8, 84, 7, 35, 3, 62, 2, 78, 6, 85, 0, 50, 1, 67, 5, 29
  };
  const int q2409[] = {
    9, 9, // Number of jobs and machines
    3, 70, 8, 89, 0, 20, 5, 43, 6, 75, 2, 53, 4, 78, 1, 99, 7, 18, 
    8, 86, 0, 46, 4, 68, 5, 12, 3,  2, 2, 25, 6, 46, 1, 47, 7, 88, 
    5, 16, 0, 50, 3, 37, 7,  6, 4, 80, 1, 84, 6, 31, 2, 41, 8, 62, 
    5, 97, 4, 86, 1, 51, 2, 50, 8, 76, 3, 79, 0, 23, 7, 51, 6, 59, 
    3, 67, 8,  9, 2, 13, 6,  9, 4, 23, 1, 24, 7, 23, 5, 68, 0, 15, 
    1,  2, 0, 10, 2, 73, 8, 95, 5, 17, 3, 94, 6, 17, 4, 81, 7, 54, 
    4, 18, 3, 89, 0, 84, 5, 96, 6, 68, 2,  9, 1, 67, 7, 78, 8, 92, 
    8, 35, 7, 95, 4, 89, 0, 26, 1,  8, 3, 54, 5, 61, 2, 51, 6, 57, 
    3, 42, 8, 46, 7, 82, 0, 51, 1, 84, 4, 66, 5, 78, 6, 41, 2, 27
  };
  const int q2410[] = {
    9, 9, // Number of jobs and machines
    6, 71, 5, 62, 0, 96, 3, 52, 1, 25, 8, 72, 7, 68, 2, 17, 4, 79, 
    7, 28, 6, 79, 5, 51, 2, 28, 4, 58, 0,  3, 3, 57, 1, 33, 8, 78, 
    0, 71, 8, 21, 6, 43, 4, 14, 1, 50, 2,  4, 7, 52, 5, 64, 3, 78, 
    4, 22, 7, 67, 6,  5, 1, 14, 0, 15, 8, 28, 5, 46, 2, 41, 3, 54, 
    6, 13, 5, 89, 4, 72, 2, 35, 8, 64, 1, 43, 3, 77, 0, 35, 7, 49, 
    7, 61, 0, 95, 3, 41, 5, 96, 1, 93, 8, 86, 4, 16, 2,  3, 6, 40, 
    2, 77, 5, 48, 8, 42, 0, 81, 1, 44, 4, 76, 6, 57, 7, 37, 3, 61, 
    6, 55, 0, 53, 4, 77, 5, 90, 8, 95, 2, 18, 3, 19, 1, 51, 7, 95, 
    7, 34, 6, 98, 5, 95, 2, 81, 1, 25, 8,  7, 3, 81, 4, 21, 0, 34
  };
  const int q2411[] = {
    9, 9, // Number of jobs and machines
    2, 67, 5, 78, 4,  4, 7, 66, 3, 92, 0, 55, 8,  5, 1, 78, 6, 50, 
    1, 12, 4, 67, 0, 55, 5, 93, 2, 18, 8, 95, 7, 70, 3, 82, 6, 92, 
    2, 70, 4, 36, 0, 55, 6,  2, 8,  2, 3, 38, 5, 34, 7, 38, 1, 74, 
    8,  6, 6, 95, 1, 89, 2, 18, 5, 30, 3, 34, 0,  9, 7,  2, 4, 35, 
    7, 77, 2, 56, 6, 54, 1, 25, 5, 14, 4, 21, 3, 71, 8, 40, 0, 87, 
    2, 95, 0, 72, 4, 29, 8, 64, 3, 61, 7, 18, 6, 57, 1, 89, 5, 52, 
    0, 28, 4, 22, 7, 79, 5, 87, 1, 65, 3, 25, 6, 27, 8, 66, 2, 59, 
    8, 31, 7, 17, 6, 85, 3, 46, 0, 92, 1, 92, 5, 89, 2, 55, 4, 96, 
    8, 17, 2, 58, 6, 62, 5, 11, 0, 82, 3, 99, 1,  8, 4, 39, 7, 67
  };
  const int q2412[] = {
    9, 9, // Number of jobs and machines
    5,  6, 4, 58, 7, 22, 8, 46, 2, 27, 1, 33, 6, 70, 0, 31, 3, 14, 
    1, 94, 0, 31, 8, 68, 5, 44, 6, 43, 7, 12, 4, 69, 2, 57, 3, 18, 
    4,  6, 5, 82, 8, 78, 2, 69, 7, 72, 0, 46, 3, 46, 1, 46, 6, 41, 
    1,  1, 7, 33, 8, 77, 4, 97, 3, 94, 2, 95, 5, 69, 0,  7, 6, 10, 
    8,  1, 0, 63, 6, 64, 3, 27, 7, 83, 2, 30, 5, 88, 4, 47, 1, 34, 
    3, 84, 8, 13, 2, 13, 6, 35, 0, 25, 4, 28, 7, 37, 1,  2, 5, 32, 
    4, 25, 2,  9, 6, 50, 5, 21, 3, 95, 0, 52, 1, 37, 8, 40, 7, 43, 
    8, 94, 5, 50, 7, 47, 3,  6, 6, 92, 4, 83, 1, 13, 2, 33, 0, 50, 
    5, 63, 3, 98, 8, 25, 0, 78, 7, 66, 1, 88, 2, 82, 6,  4, 4, 48
  };
  const int q2413[] = {
    9, 9, // Number of jobs and machines
    3, 11, 4, 31, 1, 77, 7, 49, 0, 10, 5, 40, 6, 42, 8, 30, 2, 34, 
    6, 65, 2, 32, 7, 19, 1, 73, 0, 93, 8, 85, 5, 80, 3, 67, 4,  9, 
    3, 74, 5, 90, 0, 26, 2,  8, 6, 84, 8, 61, 4,  2, 7, 82, 1,  1, 
    2,  7, 7, 86, 5, 60, 3, 18, 4, 65, 1, 70, 6, 66, 8,  6, 0, 79, 
    7,  3, 5, 36, 0, 97, 3, 93, 4,  2, 8, 10, 2, 40, 6, 75, 1, 55, 
    5, 53, 1,  8, 3, 62, 7, 90, 4, 43, 6, 22, 0,  9, 2, 17, 8, 89, 
    0, 94, 3, 87, 1, 94, 4, 31, 5, 41, 6, 95, 8,  5, 2, 32, 7, 54, 
    4, 34, 5, 65, 0, 74, 3, 51, 8, 46, 1, 32, 7, 91, 6,  4, 2, 52, 
    4, 94, 3, 12, 1, 29, 0, 97, 8, 58, 6, 26, 2, 69, 7, 80, 5, 97
  };
  const int q2414[] = {
    9, 9, // Number of jobs and machines
    7, 15, 4, 70, 1, 83, 6, 13, 3, 55, 8, 60, 0,  6, 2, 64, 5, 86, 
    2, 62, 5, 62, 8, 31, 0, 33, 1, 55, 7, 10, 3, 24, 6, 97, 4, 96, 
    3, 46, 5, 85, 4, 48, 6, 78, 2, 72, 7, 42, 0,  7, 1, 23, 8, 79, 
    1, 63, 7, 14, 2, 29, 3, 72, 5, 82, 8, 37, 4, 50, 0, 11, 6, 17, 
    8,  2, 7, 89, 2, 82, 4, 75, 6, 24, 3, 98, 0, 80, 5, 99, 1, 11, 
    1, 23, 2, 14, 0, 12, 8, 94, 6, 11, 5, 50, 7, 38, 4,  1, 3, 65, 
    1, 91, 3, 88, 4, 50, 8, 99, 6, 96, 7, 33, 0, 59, 5, 19, 2, 16, 
    2, 88, 4, 60, 3, 18, 7, 43, 6, 99, 5, 13, 8, 49, 1, 41, 0, 84, 
    6, 17, 5, 55, 3, 88, 8, 27, 2, 16, 4, 32, 1, 76, 7, 15, 0, 87
  };
  const int q2415[] = {
    9, 9, // Number of jobs and machines
    6, 73, 4, 69, 8,  8, 7, 31, 3, 67, 0, 82, 2, 68, 1, 90, 5, 77, 
    6, 49, 2, 43, 8, 84, 7, 10, 0, 96, 1, 55, 3, 40, 4, 26, 5, 50, 
    5, 19, 2,  8, 1, 75, 4,  6, 0, 60, 3, 36, 7, 99, 8, 47, 6,  6, 
    0, 38, 2, 64, 5, 63, 1, 34, 4, 89, 8, 95, 7, 81, 3, 33, 6, 50, 
    4, 87, 2, 76, 8, 47, 6, 71, 3, 33, 0,  1, 7, 42, 1, 24, 5, 80, 
    3, 96, 8, 24, 5, 81, 1, 82, 2, 55, 6, 21, 4, 64, 0, 14, 7, 87, 
    4, 28, 5, 52, 8, 19, 3,  6, 2, 27, 1, 11, 7, 83, 0, 45, 6, 54, 
    3, 81, 8, 53, 5, 62, 6, 53, 2, 84, 1, 16, 4, 60, 0, 93, 7, 37, 
    4, 28, 5, 46, 8, 21, 3, 11, 2, 89, 0, 26, 7, 71, 1, 21, 6, 35
  };
  const int q2416[] = {
    9, 9, // Number of jobs and machines
    6, 63, 1,  2, 2,  1, 8, 16, 4, 16, 5, 19, 7, 59, 0, 24, 3, 26, 
    3, 49, 8, 77, 4, 73, 0, 18, 6, 36, 2,  7, 7,  1, 5, 52, 1, 26, 
    2, 75, 1, 88, 6, 71, 7, 13, 4, 15, 8, 75, 5, 57, 3, 49, 0, 66, 
    7, 18, 4, 93, 0, 76, 1, 36, 6, 42, 3, 76, 5, 33, 2, 82, 8, 83, 
    0, 28, 7, 37, 3, 80, 5, 85, 6, 77, 1, 95, 4, 23, 8, 29, 2, 53, 
    7,  2, 2, 61, 5, 61, 1, 44, 6,  3, 0, 78, 3, 25, 4, 10, 8, 88, 
    5, 96, 6, 99, 2, 68, 0, 35, 7, 22, 3, 95, 1, 74, 8,  5, 4, 84, 
    3, 22, 0, 36, 6, 27, 7, 56, 2, 98, 8, 85, 1, 95, 4, 35, 5,  5, 
    5, 71, 4, 23, 1,  9, 3, 31, 0, 40, 7, 50, 2, 11, 8, 76, 6, 44
  };
  const int q2417[] = {
    9, 9, // Number of jobs and machines
    6, 86, 1, 81, 0, 98, 7,  5, 2, 97, 3, 76, 8, 25, 5,  7, 4, 29, 
    4, 14, 2, 93, 7, 91, 1,  6, 5, 35, 8, 95, 0, 77, 3,  7, 6, 48, 
    1, 63, 5, 16, 4, 50, 2, 49, 8, 20, 3, 69, 7, 42, 6, 73, 0, 98, 
    6, 89, 8,  3, 3, 99, 5, 89, 0, 89, 1, 64, 2,  7, 4, 94, 7, 52, 
    0, 29, 7, 50, 3,  9, 8, 29, 1, 27, 6, 72, 2, 39, 4, 78, 5, 34, 
    8, 16, 3, 60, 6, 35, 0, 94, 4, 43, 2, 22, 7, 99, 1, 55, 5, 60, 
    5, 30, 7, 48, 8, 31, 2, 42, 0,  2, 3, 78, 1, 17, 4,  6, 6, 37, 
    0, 64, 4, 36, 2, 69, 6,  6, 5, 92, 7, 17, 1, 77, 3, 73, 8, 35, 
    0, 51, 5, 72, 1, 76, 3, 29, 4, 83, 6, 85, 7, 67, 8, 32, 2, 37
  };
  const int q2418[] = {
    9, 9, // Number of jobs and machines
    7, 79, 5, 77, 0,  1, 3, 53, 8, 65, 1, 44, 6, 99, 2, 50, 4, 90, 
    1, 81, 6, 66, 4, 74, 7, 38, 5, 20, 0, 41, 3, 37, 2, 57, 8,  7, 
    5, 87, 0, 23, 2, 78, 1, 41, 6, 91, 8, 43, 4, 49, 3, 85, 7, 88, 
    1, 32, 8, 95, 7, 73, 0, 81, 6, 18, 2, 77, 3, 96, 5, 70, 4, 99, 
    0, 32, 3,  2, 5, 52, 6, 88, 8, 77, 2, 53, 1, 13, 4, 51, 7,  1, 
    8, 81, 2, 97, 5,  5, 6, 48, 3, 17, 4, 76, 7, 42, 1, 21, 0, 25, 
    4, 30, 8, 30, 2,  8, 1, 32, 5, 90, 3, 25, 0, 93, 7, 92, 6, 49, 
    3, 19, 1, 44, 8, 11, 0, 23, 5, 25, 4, 59, 2, 49, 7, 66, 6,  7, 
    4, 10, 8, 30, 0, 36, 3, 10, 1, 39, 2, 91, 7, 78, 5, 64, 6, 29
  };
  const int q2419[] = {
    9, 9, // Number of jobs and machines
    4, 55, 1,  2, 8, 12, 2, 89, 6, 48, 7, 67, 5, 86, 3, 59, 0, 14, 
    7, 61, 3, 13, 6,  7, 2, 77, 0, 78, 8, 19, 4, 63, 5, 79, 1, 40, 
    0, 57, 3, 98, 1, 49, 4, 42, 7, 87, 2, 28, 6, 52, 8, 28, 5, 17, 
    8, 24, 6,  5, 5, 36, 3, 66, 0, 30, 7, 63, 1, 26, 2, 77, 4, 63, 
    7, 82, 1, 37, 3, 48, 6, 81, 2, 58, 5, 47, 8, 12, 0, 39, 4, 44, 
    6, 11, 5, 79, 8, 61, 0, 73, 3, 77, 1, 68, 4, 84, 7, 93, 2, 77, 
    4,  3, 2,  7, 6, 53, 0,  6, 8,  7, 3, 80, 5, 10, 1, 99, 7, 26, 
    4, 70, 2, 45, 1, 50, 0, 65, 6, 42, 3, 67, 7, 46, 5, 33, 8, 77, 
    1, 45, 7, 60, 5, 86, 4, 87, 2, 83, 0, 25, 3, 13, 8, 30, 6, 91
  };
  const int q2420[] = {
    9, 9, // Number of jobs and machines
    5, 38, 4, 10, 0, 12, 6, 80, 7,  2, 1, 35, 8, 71, 3, 24, 2, 18, 
    2, 80, 4, 29, 1, 83, 0, 47, 6, 61, 5, 31, 7, 24, 3, 89, 8, 32, 
    1, 97, 6, 73, 5, 46, 0, 86, 2, 84, 7, 81, 3, 15, 4, 52, 8, 12, 
    4, 92, 2, 30, 7, 13, 1, 89, 0, 13, 8, 92, 5, 11, 6, 69, 3, 66, 
    6, 39, 3, 61, 4, 51, 5,  3, 1,  2, 2, 14, 7, 35, 8, 46, 0, 14, 
    1, 24, 7, 93, 3, 15, 4, 48, 2,  7, 5, 92, 8, 20, 0, 61, 6, 81, 
    5, 45, 2, 38, 8, 98, 7, 10, 4, 37, 6, 57, 3, 82, 1, 35, 0, 35, 
    4, 62, 1, 39, 5, 95, 0, 95, 7,  7, 6, 26, 8,  6, 2, 59, 3, 42, 
    5, 70, 3, 19, 0, 39, 4, 57, 7, 70, 6, 74, 2, 87, 1, 70, 8, 19
  };
  const int q2421[] = {
    9, 9, // Number of jobs and machines
    1, 46, 6, 29, 2,  5, 0, 83, 4, 56, 7, 78, 3, 63, 5, 54, 8, 25, 
    2, 23, 8, 71, 3, 79, 4, 82, 5, 25, 0, 34, 6, 63, 1, 18, 7, 19, 
    6, 98, 3, 32, 8, 43, 5, 78, 0, 43, 7, 75, 4, 96, 2, 85, 1, 90, 
    5, 42, 7, 47, 0, 12, 1, 62, 6, 80, 8, 83, 4, 56, 3, 69, 2, 18, 
    5, 55, 1, 26, 3, 22, 2, 71, 7, 27, 6,  4, 4, 24, 0, 13, 8, 50, 
    5, 31, 3, 88, 2, 70, 4, 47, 6, 40, 8, 84, 0, 90, 7, 21, 1, 41, 
    1, 21, 3, 55, 5, 82, 8, 83, 2, 48, 6, 68, 0, 50, 4, 43, 7, 44, 
    5, 99, 1, 12, 6, 99, 0, 25, 3, 95, 7, 92, 8, 84, 2, 55, 4, 60, 
    3, 73, 1, 66, 5, 76, 6, 68, 7, 30, 2, 27, 0,  8, 4, 34, 8, 51
  };
  const int q2422[] = {
    9, 9, // Number of jobs and machines
    2, 79, 0, 77, 3, 18, 1, 77, 8, 70, 7, 40, 6, 70, 4, 56, 5, 70, 
    2, 22, 6, 15, 1,  7, 3, 15, 8,  1, 0, 77, 7, 38, 4, 70, 5, 29, 
    1, 71, 2, 72, 4, 30, 0, 76, 3, 21, 5, 29, 6, 67, 8, 33, 7,  9, 
    2, 88, 7, 88, 8,  4, 1, 69, 6, 41, 0, 39, 3, 18, 4, 84, 5,  9, 
    5, 25, 8, 85, 3, 46, 0, 58, 4, 40, 6, 87, 2, 15, 7, 40, 1, 34, 
    7, 54, 6, 75, 3, 58, 1, 44, 4, 75, 5, 10, 8, 40, 0, 31, 2, 83, 
    5,  6, 8, 14, 1, 41, 4, 37, 2, 77, 7, 84, 6, 69, 0, 63, 3, 53, 
    8, 99, 4, 67, 1, 77, 7, 39, 5, 88, 3, 95, 0, 57, 6, 11, 2, 32, 
    8, 58, 1, 40, 5, 67, 7,  9, 0, 62, 2, 45, 4, 41, 3, 99, 6, 87
  };
  const int q2423[] = {
    9, 9, // Number of jobs and machines
    1, 93, 4, 63, 7, 35, 6,  3, 2, 88, 5, 42, 8, 84, 0,  6, 3, 65, 
    6, 65, 0, 85, 7, 11, 5, 73, 8, 55, 2, 99, 1, 95, 4, 35, 3, 34, 
    1, 58, 7, 57, 3, 34, 8, 52, 0, 39, 5, 92, 4, 47, 2, 91, 6, 70, 
    8, 98, 3, 33, 4, 32, 1,  6, 6, 22, 5,  6, 7, 37, 0, 75, 2, 27, 
    2, 84, 4, 75, 7, 71, 3, 85, 8, 67, 1, 99, 5, 49, 6, 68, 0, 42, 
    6, 70, 3, 87, 1, 57, 4, 62, 5, 17, 7, 68, 2, 62, 8, 98, 0, 27, 
    5, 32, 4, 97, 3, 60, 1, 90, 0, 78, 6, 79, 7, 10, 2, 70, 8, 64, 
    6, 72, 0, 70, 5, 60, 4, 33, 2, 13, 1, 10, 8, 40, 7, 19, 3, 23, 
    7, 44, 5, 10, 1, 26, 2, 39, 6, 56, 0, 51, 4, 65, 8, 11, 3, 64
  };
  const int q2424[] = {
    9, 9, // Number of jobs and machines
    5, 20, 1, 80, 3, 23, 6, 74, 7, 36, 4, 94, 0, 45, 2, 84, 8, 71, 
    7, 35, 1, 74, 0, 14, 3, 58, 5, 95, 6, 34, 4, 98, 2, 14, 8, 33, 
    8, 57, 0, 53, 5, 35, 2,  8, 3,  4, 4, 31, 6, 58, 7, 64, 1, 94, 
    8, 25, 3, 43, 1, 86, 7, 56, 6, 51, 4, 99, 5, 59, 2, 57, 0, 40, 
    4, 32, 7, 22, 8, 73, 1, 89, 0, 73, 3, 68, 5, 69, 6, 87, 2, 59, 
    7, 94, 3, 42, 4, 60, 1, 36, 0, 65, 5, 41, 6,  3, 2, 29, 8, 84, 
    7, 74, 1, 10, 4, 82, 3, 49, 5, 97, 6, 45, 2, 10, 0, 56, 8,  2, 
    0,  7, 7, 91, 3, 37, 4,  1, 1, 20, 6, 36, 5, 26, 8, 98, 2,  8, 
    8, 30, 3,  2, 6, 81, 7, 65, 1, 46, 0, 73, 4, 75, 2, 28, 5, 23
  };
  const int q2425[] = {
    9, 9, // Number of jobs and machines
    6, 34, 1, 56, 5, 82, 2, 13, 7, 34, 3, 45, 8, 94, 0,  9, 4, 62, 
    8, 18, 0, 35, 2, 40, 1, 41, 6, 51, 4, 33, 5, 63, 3, 83, 7, 13, 
    2, 73, 7, 88, 3, 54, 6, 35, 1, 36, 5, 98, 0,  9, 4, 71, 8, 95, 
    5,  1, 3, 20, 4, 62, 6, 47, 2, 39, 1, 34, 7, 74, 8,  7, 0, 17, 
    2, 39, 4, 12, 7, 28, 3, 38, 5, 91, 0, 38, 8, 44, 1, 67, 6, 63, 
    1, 69, 7,  3, 6,  7, 8, 80, 5, 65, 0, 32, 4, 47, 3, 56, 2, 76, 
    4, 77, 0, 75, 1, 64, 7, 52, 8, 77, 6, 10, 2, 85, 5, 36, 3, 78, 
    2, 65, 8, 25, 5,  7, 4, 65, 1, 88, 3, 22, 0, 71, 6,  8, 7, 56, 
    5, 15, 8, 31, 1, 67, 3, 35, 0, 44, 6, 92, 4, 48, 2, 19, 7, 95
  };
  const int q2426[] = {
    9, 9, // Number of jobs and machines
    8, 86, 3, 78, 7, 87, 5, 82, 4, 49, 2, 84, 6, 58, 1, 41, 0, 88, 
    6, 97, 7,  6, 2, 15, 5, 54, 3, 39, 4, 98, 1, 42, 0, 38, 8, 58, 
    8, 19, 5, 69, 3, 16, 0, 98, 7, 25, 1, 88, 4, 79, 6, 99, 2, 40, 
    5, 55, 4, 67, 8, 44, 6, 13, 0, 28, 3, 78, 7, 44, 1, 52, 2, 36, 
    7, 93, 5, 43, 1, 95, 3, 36, 8, 53, 2,  3, 6, 63, 4, 88, 0, 44, 
    5, 22, 2, 49, 3, 36, 1, 89, 4, 32, 8, 28, 0, 20, 7, 23, 6, 75, 
    8, 89, 2, 42, 0, 90, 1, 84, 7, 13, 3,  9, 4, 11, 6, 74, 5, 77, 
    7, 27, 3, 40, 8, 35, 5, 27, 6, 75, 0, 91, 4, 71, 2, 27, 1, 81, 
    8, 32, 6, 62, 7, 50, 3, 57, 4, 80, 1, 20, 2, 39, 5, 18, 0, 35
  };
  const int q2427[] = {
    9, 9, // Number of jobs and machines
    0, 82, 1, 66, 7, 18, 2, 76, 8, 48, 6, 37, 3, 45, 4, 28, 5, 53, 
    0, 25, 2, 30, 7, 14, 3, 41, 6, 51, 4, 46, 1, 74, 8, 77, 5, 64, 
    0, 66, 3, 91, 7,  9, 2, 85, 8, 92, 6,  4, 4,  4, 1, 53, 5, 80, 
    8, 11, 6,  6, 5, 37, 4, 78, 3, 52, 1, 24, 2, 40, 7, 19, 0, 93, 
    0, 83, 8, 95, 2, 89, 5, 84, 6, 29, 3, 50, 4, 57, 7, 46, 1, 65, 
    3, 25, 5,  8, 4, 71, 8, 86, 0,  1, 6, 66, 2, 63, 7, 76, 1, 87, 
    4, 35, 6, 71, 3, 36, 8, 89, 2, 84, 5, 46, 1, 20, 0, 47, 7,  3, 
    6, 94, 3, 18, 4, 80, 8, 61, 0, 94, 2, 99, 5, 61, 7, 39, 1, 38, 
    8,  8, 6, 33, 0, 27, 7, 39, 3, 67, 2, 49, 4, 65, 1, 90, 5, 15
  };
  const int q2428[] = {
    9, 9, // Number of jobs and machines
    8, 68, 4, 94, 6, 51, 1, 10, 0, 96, 3,  8, 2, 89, 5, 33, 7, 27, 
    6, 70, 8, 32, 2, 89, 5, 80, 0, 13, 7, 14, 3,  7, 1, 72, 4, 22, 
    1, 92, 3, 54, 7, 52, 8, 80, 5,  7, 6,  5, 4, 67, 2, 64, 0, 24, 
    0, 32, 6, 23, 5, 48, 7, 69, 2, 46, 1, 75, 3, 92, 8, 20, 4, 12, 
    0, 69, 6, 78, 8, 68, 7, 26, 2, 72, 5, 85, 1, 46, 4, 21, 3, 49, 
    1, 62, 4, 76, 5, 40, 0, 53, 8, 82, 3, 60, 6,  2, 2, 70, 7, 45, 
    5, 83, 2, 34, 7, 57, 4, 75, 1, 78, 8, 90, 3, 34, 0, 88, 6, 58, 
    6, 61, 7, 70, 3, 19, 8, 63, 2, 65, 4, 94, 0, 41, 5, 52, 1, 82, 
    8, 93, 7, 61, 1,  2, 2, 87, 3, 92, 6, 15, 4, 53, 0, 88, 5, 65
  };
  const int q2429[] = {
    9, 9, // Number of jobs and machines
    0, 77, 3, 15, 7,  8, 2, 84, 8,  8, 1, 84, 5, 43, 4, 59, 6, 25, 
    2,  4, 7,  7, 0, 14, 3, 37, 5, 93, 6, 49, 4, 46, 1, 51, 8, 85, 
    2,  7, 0, 87, 3, 49, 1, 50, 8, 17, 7, 30, 6,  9, 4, 26, 5, 94, 
    3, 91, 0, 41, 6, 37, 7, 64, 1,  5, 5, 85, 8, 84, 4, 19, 2, 16, 
    1, 12, 4, 71, 7, 46, 2, 32, 0, 76, 5, 44, 3, 58, 8, 12, 6, 80, 
    1, 71, 0, 90, 6, 15, 7, 85, 2, 11, 5, 39, 4,  1, 8, 36, 3, 91, 
    2,  6, 5, 36, 4, 92, 7, 43, 3, 82, 6, 13, 1, 73, 8, 12, 0, 22, 
    6, 13, 8, 61, 7, 35, 2, 31, 5, 76, 4, 41, 0, 43, 1, 32, 3, 94, 
    2, 25, 4, 75, 8, 29, 7, 73, 1, 74, 6, 65, 3, 37, 0, 93, 5, 68
  };
  const int q2430[] = {
    9, 9, // Number of jobs and machines
    6, 73, 2, 54, 8, 97, 7, 97, 3,  8, 0, 36, 5, 28, 4, 81, 1, 60, 
    2, 48, 1, 86, 8, 12, 5, 90, 7, 23, 3, 63, 6, 77, 0, 96, 4, 74, 
    4, 93, 2, 99, 8,  2, 5, 17, 3, 30, 0, 28, 6, 51, 1,  5, 7, 59, 
    6, 59, 4, 56, 3, 98, 7, 14, 0, 75, 1, 47, 2, 92, 8, 76, 5, 51, 
    7, 89, 4, 69, 5, 68, 2, 38, 6, 42, 1, 23, 8, 15, 0, 41, 3, 10, 
    2, 33, 4, 38, 1, 67, 0, 93, 6, 62, 8, 12, 5, 77, 3, 90, 7, 17, 
    4, 84, 3, 11, 5, 76, 8, 54, 6, 15, 0,  5, 2, 25, 1,  7, 7, 35, 
    3, 31, 7, 63, 6, 14, 0, 99, 1, 22, 8, 90, 5, 91, 4, 63, 2, 14, 
    6, 53, 8, 15, 3, 17, 0, 13, 1, 87, 7, 41, 4, 12, 2, 96, 5, 68
  };
  const int q2431[] = {
    9, 9, // Number of jobs and machines
    1, 30, 8,  8, 4, 75, 2, 75, 6, 71, 7, 75, 0, 54, 5, 55, 3, 86, 
    3, 96, 6,  3, 7, 62, 4,  3, 0, 97, 5, 15, 1, 27, 8, 73, 2, 47, 
    2, 65, 6, 19, 4,  1, 5, 41, 8, 48, 1, 39, 3, 44, 7, 60, 0, 97, 
    2, 44, 1, 50, 6, 67, 8, 75, 7,  8, 5, 63, 0, 96, 3, 10, 4, 72, 
    4, 28, 7, 27, 3, 70, 8, 83, 0, 59, 6, 51, 1, 23, 2, 71, 5, 20, 
    0, 62, 2,  4, 6,  2, 7, 83, 5, 92, 1, 43, 8, 23, 4, 31, 3, 67, 
    8, 31, 2, 80, 5, 53, 3, 32, 0, 67, 4, 19, 1, 47, 6, 27, 7,  6, 
    0, 45, 1, 96, 2, 48, 7, 59, 6, 72, 4, 72, 8, 19, 5, 19, 3, 42, 
    1, 83, 8, 26, 2, 94, 7, 25, 4, 29, 5, 68, 0, 96, 3, 14, 6, 33
  };
  const int q2432[] = {
    9, 9, // Number of jobs and machines
    6,  6, 3,  3, 5, 33, 7, 15, 0, 76, 2, 88, 4, 52, 1, 56, 8,  8, 
    3, 55, 6, 99, 5, 42, 0, 79, 4, 19, 2, 71, 8, 59, 1, 23, 7, 40, 
    8, 18, 3, 14, 4, 85, 0, 44, 6, 28, 5, 13, 2, 84, 1, 27, 7, 19, 
    8, 84, 5,  3, 6, 21, 0, 24, 2, 17, 1, 58, 4, 11, 7, 14, 3,  6, 
    0, 79, 5, 83, 1, 33, 8, 57, 2, 26, 4, 17, 3, 38, 6, 12, 7,  7, 
    0, 43, 7, 42, 6, 16, 5, 37, 8, 30, 2, 56, 4, 47, 1, 18, 3, 87, 
    7, 70, 1, 20, 3, 90, 4, 21, 5, 14, 8, 48, 2, 15, 0, 67, 6, 57, 
    3, 59, 1, 80, 6, 70, 8, 93, 5, 95, 4, 92, 7, 51, 0, 17, 2, 57, 
    5, 50, 0, 24, 6, 99, 8, 56, 2, 86, 1, 82, 7, 47, 4, 29, 3, 65
  };
  const int q2433[] = {
    9, 9, // Number of jobs and machines
    8, 21, 5, 89, 1, 75, 6, 62, 4, 41, 2, 58, 3,  8, 7, 74, 0, 90, 
    0, 47, 6, 89, 2, 86, 4, 74, 8, 45, 3, 28, 7, 22, 5, 33, 1, 59, 
    1,  6, 7, 61, 0, 18, 2, 82, 4, 60, 5, 12, 3, 26, 8, 73, 6, 41, 
    5, 38, 3, 38, 6, 58, 2,  6, 7, 84, 0, 66, 4, 18, 1, 51, 8, 60, 
    0,  5, 2, 70, 8, 26, 7,  5, 5, 35, 4, 36, 1,  4, 3, 31, 6, 33, 
    3, 52, 2, 63, 1, 63, 0, 61, 6, 92, 8,  2, 4, 67, 5, 84, 7, 83, 
    1, 86, 3,  5, 6, 14, 7, 92, 8, 92, 5, 49, 2,  6, 0,  5, 4, 48, 
    5, 56, 8, 71, 1, 82, 7, 99, 2,  1, 4, 97, 0, 20, 6, 20, 3, 89, 
    2, 38, 1, 69, 8, 52, 0, 97, 3, 96, 5, 35, 4, 45, 7, 14, 6, 72
  };
  const int q2434[] = {
    9, 9, // Number of jobs and machines
    7, 93, 3, 69, 1, 63, 8, 83, 4, 80, 0, 74, 2, 66, 6, 93, 5, 83, 
    7, 47, 8, 89, 2, 30, 0,  3, 1, 12, 5, 32, 3, 17, 6, 98, 4, 13, 
    0, 48, 7, 78, 6, 29, 4, 68, 2, 96, 1, 50, 8,  4, 5, 80, 3, 53, 
    5, 90, 1, 12, 8, 73, 6, 42, 4, 61, 2, 59, 3, 51, 7,  3, 0, 32, 
    8, 65, 7, 97, 3, 65, 0,  2, 2,  4, 6, 85, 4, 64, 1, 84, 5, 71, 
    7, 35, 1, 79, 5,  9, 4, 62, 3, 11, 2, 98, 8, 21, 6, 79, 0, 88, 
    8, 91, 6, 43, 7,  6, 5, 44, 4, 23, 1, 24, 0,  5, 3, 71, 2, 21, 
    5, 10, 8, 68, 2, 13, 7, 42, 0, 24, 6, 81, 4, 82, 3, 77, 1, 97, 
    1, 34, 4, 41, 2, 43, 5, 67, 7, 46, 0, 20, 8, 40, 3, 80, 6, 41
  };
  const int q2435[] = {
    9, 9, // Number of jobs and machines
    6, 96, 2, 49, 0, 52, 3, 37, 5, 54, 7, 69, 1, 77, 4,  9, 8, 80, 
    5, 60, 4, 37, 2, 95, 3, 77, 0, 75, 1, 48, 7, 46, 6, 79, 8, 42, 
    2, 65, 3, 71, 5, 24, 0, 13, 7,  3, 1, 56, 4, 71, 6, 66, 8, 89, 
    6, 35, 2, 21, 4, 11, 5, 14, 8, 36, 1, 48, 3,  4, 7, 48, 0, 53, 
    6, 94, 0, 16, 2, 18, 5, 98, 3, 64, 1, 90, 4, 84, 7, 42, 8, 10, 
    4, 10, 5, 72, 2, 45, 3, 84, 6, 34, 1,  2, 8, 90, 0, 18, 7, 15, 
    6, 72, 5,  6, 2, 84, 7, 65, 8, 96, 1,  4, 3, 74, 0,  4, 4, 77, 
    0, 97, 2, 68, 8, 47, 5, 47, 1, 29, 4, 46, 3, 65, 7, 99, 6, 42, 
    3, 69, 5, 43, 6, 67, 8, 20, 4, 78, 7, 68, 1, 95, 0, 64, 2, 26
  };
  const int q2436[] = {
    9, 9, // Number of jobs and machines
    6, 75, 5, 35, 1, 71, 8,  1, 4, 65, 2, 80, 7, 57, 0, 13, 3, 44, 
    6, 46, 2, 66, 4,  4, 1, 60, 3, 35, 8, 22, 7,  6, 0, 85, 5, 66, 
    7, 36, 1, 84, 5, 55, 2, 81, 3, 77, 4, 15, 0, 81, 6, 39, 8, 62, 
    8, 58, 4, 59, 1, 17, 0, 19, 6,  8, 7, 88, 2, 45, 5, 31, 3,  3, 
    0, 85, 5, 53, 1, 54, 3, 72, 4, 47, 8, 99, 6, 63, 2, 49, 7, 84, 
    3, 35, 6, 67, 0, 33, 7, 93, 5,  3, 8, 88, 1, 47, 2, 76, 4, 29, 
    3, 23, 6, 31, 4, 43, 5, 41, 7, 66, 1, 30, 2, 59, 0,  4, 8, 57, 
    7, 92, 1, 67, 8, 69, 5, 43, 3, 77, 0, 10, 6, 66, 4, 46, 2, 38, 
    3, 85, 1, 20, 8, 24, 2, 49, 4, 29, 6, 47, 0, 15, 7, 83, 5, 74
  };
  const int q2437[] = {
    9, 9, // Number of jobs and machines
    3, 11, 8,  6, 5, 34, 1, 63, 2, 84, 0, 96, 6, 68, 7, 42, 4, 52, 
    3, 10, 8, 14, 4, 25, 7, 49, 5, 76, 0,  4, 2, 89, 1, 61, 6, 98, 
    6,  9, 0, 80, 5, 61, 1, 83, 8, 18, 4, 24, 7, 90, 3,  6, 2, 29, 
    5, 10, 1, 55, 4, 73, 8, 71, 2, 78, 6, 11, 3, 81, 0,  1, 7, 44, 
    0, 37, 8, 74, 6, 80, 5, 43, 3, 94, 7, 55, 1, 60, 4, 71, 2,  3, 
    7, 83, 2, 27, 4,  4, 0,  7, 6, 84, 3, 59, 5, 32, 8, 42, 1, 54, 
    1, 59, 2, 46, 5, 68, 0, 33, 8, 94, 7, 34, 4, 68, 6, 78, 3, 62, 
    0, 46, 1, 52, 2, 73, 3,  8, 8, 16, 5, 90, 6, 50, 4, 34, 7,  8, 
    2, 93, 6, 15, 3, 49, 7,  1, 0, 13, 8, 90, 4,  9, 5, 25, 1, 71
  };
  const int q2438[] = {
    9, 9, // Number of jobs and machines
    8, 24, 7, 27, 3, 73, 0, 17, 4, 43, 1, 42, 5, 23, 2,  6, 6, 14, 
    1, 37, 5, 70, 0, 93, 8, 83, 6, 45, 3, 76, 4, 29, 2, 83, 7, 83, 
    0, 68, 5, 13, 7,  6, 2, 92, 1, 50, 6, 65, 8,  9, 4, 19, 3, 65, 
    5, 79, 1, 43, 0, 91, 3, 72, 7, 36, 8, 71, 6, 60, 2, 29, 4, 18, 
    3, 19, 1, 41, 6, 84, 5, 39, 8, 60, 4, 61, 7, 25, 0, 85, 2, 29, 
    2, 61, 1, 27, 0, 45, 7, 87, 6, 89, 8, 27, 5, 17, 4, 31, 3, 14, 
    6, 88, 0, 10, 4, 16, 8, 66, 5,  8, 7, 48, 1, 91, 3, 26, 2, 94, 
    4,  6, 7,  8, 0, 99, 2, 54, 5, 88, 3, 15, 1, 93, 8, 99, 6, 82, 
    7, 97, 1, 35, 8, 32, 0, 16, 3, 84, 2,  3, 5, 25, 6, 80, 4, 12
  };
  const int q2439[] = {
    9, 9, // Number of jobs and machines
    8, 80, 3, 80, 6, 26, 1, 93, 2, 99, 0, 39, 7, 86, 5, 11, 4,  4, 
    0, 51, 2,  1, 5, 98, 6, 41, 1, 35, 7, 58, 8, 28, 4, 23, 3, 76, 
    0, 71, 5, 24, 4, 11, 7, 84, 3, 98, 1, 10, 8, 29, 2, 77, 6, 47, 
    4, 39, 7,  2, 3,  6, 8, 29, 6, 60, 0, 75, 5, 85, 1, 82, 2, 63, 
    6, 57, 1,  5, 2, 94, 3, 39, 8, 23, 7, 64, 5, 49, 0,  8, 4,  4, 
    3,  1, 5, 56, 8, 32, 1, 73, 0, 65, 4, 29, 6, 77, 2, 23, 7, 55, 
    8, 99, 4, 97, 7, 14, 5, 71, 1, 53, 0, 91, 6, 82, 3, 53, 2, 11, 
    4, 97, 2, 99, 1, 39, 8, 84, 3, 16, 5, 14, 0, 79, 6, 90, 7, 76, 
    0, 64, 2, 53, 7, 23, 8, 19, 4, 43, 6, 97, 1,  8, 3, 48, 5, 59
  };
  const int q2440[] = {
    9, 9, // Number of jobs and machines
    5, 90, 7, 50, 3, 42, 1, 80, 2, 80, 8, 19, 0, 17, 6, 20, 4, 11, 
    0,  6, 7, 71, 8, 14, 2, 89, 3, 59, 6, 86, 5,  6, 1, 66, 4, 71, 
    6, 16, 4, 59, 7,  4, 8, 37, 1, 49, 3, 27, 5, 26, 0, 76, 2, 74, 
    2, 85, 1, 80, 3, 87, 0, 39, 8, 23, 5,  5, 7, 42, 6, 56, 4, 81, 
    1, 24, 0, 42, 7, 94, 8, 15, 4, 95, 6, 98, 3, 72, 2, 45, 5, 93, 
    8, 50, 7, 34, 3,  1, 4, 21, 1, 20, 5, 87, 0,  4, 6, 41, 2, 79, 
    7, 80, 6, 51, 4, 69, 8, 95, 5, 55, 2, 86, 3, 85, 1, 71, 0,  4, 
    5, 19, 3, 10, 1, 21, 2, 83, 7, 48, 0, 34, 6, 13, 8, 52, 4, 53, 
    6, 45, 4, 84, 7, 23, 3, 76, 1, 50, 8, 18, 0, 27, 2, 49, 5, 72
  };
  const int q2441[] = {
    9, 9, // Number of jobs and machines
    4, 14, 8, 95, 1, 13, 3, 11, 5, 73, 2, 78, 6, 12, 7, 50, 0, 39, 
    8, 54, 7, 84, 6, 15, 2, 15, 4, 79, 1, 32, 0, 50, 3, 85, 5, 97, 
    0, 78, 5, 60, 2, 70, 8, 21, 1, 99, 3,  4, 6, 60, 7, 89, 4, 41, 
    6, 25, 5, 25, 2, 85, 8, 75, 4,  7, 3, 55, 1, 93, 7,  5, 0, 13, 
    6, 96, 2, 13, 1, 57, 8, 12, 4, 17, 0, 35, 3, 25, 7,  4, 5,  6, 
    2, 61, 4, 96, 1, 56, 5,  5, 8, 24, 6, 80, 3, 63, 0, 65, 7, 34, 
    5, 60, 8, 84, 3, 67, 4, 87, 6, 51, 2, 16, 7, 22, 0, 65, 1, 14, 
    0, 36, 4, 11, 2, 74, 8, 76, 6, 95, 7, 98, 3, 39, 1, 50, 5, 66, 
    2, 97, 3, 43, 5, 27, 6, 55, 1, 49, 8, 70, 0, 87, 7, 60, 4, 88
  };
  const int q2442[] = {
    9, 9, // Number of jobs and machines
    0, 52, 1, 76, 5, 91, 7, 86, 4, 46, 3, 86, 8, 57, 2, 12, 6, 15, 
    5, 52, 2, 52, 1, 81, 6, 28, 8, 92, 0, 70, 7, 62, 4, 57, 3, 98, 
    5, 21, 0, 33, 1, 22, 8, 52, 2, 19, 4, 89, 6,  9, 3, 90, 7, 18, 
    5, 16, 4, 64, 8, 21, 7, 21, 3, 62, 6, 46, 1, 55, 0,  7, 2, 30, 
    8, 73, 6, 57, 0, 30, 5, 92, 2, 27, 3, 94, 7, 19, 1, 98, 4,  4, 
    3, 50, 4,  4, 5, 95, 2, 57, 1, 53, 7, 97, 6, 90, 8, 67, 0, 53, 
    3, 33, 6, 81, 1, 70, 5, 80, 8, 42, 2,  2, 7, 58, 0, 91, 4, 19, 
    4, 78, 2, 15, 1, 93, 6, 71, 0, 64, 7, 84, 5, 86, 3, 59, 8, 57, 
    3, 85, 5, 66, 1, 53, 4,  3, 7,  4, 2, 19, 0, 27, 8, 23, 6, 76
  };
  const int q2443[] = {
    9, 9, // Number of jobs and machines
    7, 24, 8, 31, 2, 68, 3, 23, 1, 94, 0, 80, 4, 75, 6, 84, 5, 45, 
    8, 41, 6, 63, 0,  2, 4, 95, 5, 20, 2, 33, 1, 40, 7, 85, 3,  2, 
    6, 26, 4, 77, 7, 96, 3, 15, 0,  6, 8, 43, 2, 10, 1, 30, 5, 44, 
    0, 80, 3, 19, 7, 69, 1, 35, 6, 74, 8, 37, 2, 39, 4, 29, 5, 71, 
    1, 54, 4, 20, 7, 83, 3, 99, 0, 24, 6, 82, 2, 26, 8, 66, 5, 36, 
    7, 83, 3, 98, 2, 73, 1, 98, 5,  2, 8, 34, 4, 75, 6, 35, 0, 79, 
    4, 87, 7, 49, 0, 13, 2, 53, 8,  2, 5, 75, 1, 93, 6, 51, 3, 95, 
    3,  7, 2, 26, 1, 74, 7, 73, 0, 93, 8, 50, 5, 74, 4, 94, 6, 25, 
    4, 82, 5, 38, 8, 84, 0, 99, 1, 52, 6, 43, 7, 42, 3, 48, 2, 47
  };
  const int q2444[] = {
    9, 9, // Number of jobs and machines
    4, 31, 1, 10, 0, 54, 5, 98, 7, 87, 3, 29, 6, 76, 8, 69, 2, 28, 
    8, 50, 3, 97, 1, 77, 4, 10, 5, 73, 2, 36, 7, 63, 0, 13, 6, 30, 
    4, 34, 1, 91, 2, 88, 6, 88, 0, 37, 3, 50, 5, 55, 8, 43, 7, 42, 
    0, 64, 2, 86, 3, 91, 4, 87, 5,  3, 6, 33, 1, 77, 8,  8, 7, 97, 
    6, 84, 2, 19, 0, 66, 4, 55, 7, 17, 3, 91, 5, 84, 8, 50, 1, 16, 
    2, 11, 0, 51, 5, 69, 8, 23, 3, 34, 1, 40, 6, 93, 7, 75, 4, 93, 
    4, 34, 1, 99, 0, 74, 3, 97, 7,  1, 2, 47, 6, 46, 5, 38, 8, 77, 
    3, 22, 1, 75, 0, 15, 2, 59, 6, 62, 7, 64, 4, 27, 5, 78, 8, 95, 
    2, 25, 8, 15, 5,  1, 3, 60, 1,  7, 7, 24, 4, 25, 0, 95, 6, 76
  };
  const int q2445[] = {
    9, 9, // Number of jobs and machines
    2,  1, 7, 94, 3, 36, 1,  9, 5, 10, 0, 89, 6, 24, 8, 16, 4, 63, 
    6, 34, 5, 49, 0, 34, 8,  6, 2, 91, 4, 70, 3, 31, 1, 67, 7, 71, 
    5, 39, 8, 80, 1, 61, 3, 87, 0, 61, 2, 42, 4, 61, 7, 32, 6, 28, 
    8, 76, 3, 45, 5, 95, 7, 31, 0, 23, 6,  7, 4, 12, 2, 66, 1,  6, 
    4, 17, 2, 93, 1, 86, 8, 92, 6,  1, 5, 30, 3, 20, 0,  5, 7, 30, 
    2, 11, 0, 14, 1, 76, 3, 12, 5, 53, 7, 23, 4, 96, 6, 80, 8, 95, 
    1, 64, 3, 80, 6, 12, 4, 38, 7, 42, 8, 20, 5, 21, 0, 17, 2, 14, 
    2, 28, 5, 25, 0, 97, 3, 26, 6, 45, 7, 22, 8, 79, 1, 16, 4,  4, 
    0, 88, 7, 72, 3, 13, 8, 84, 2, 40, 6, 57, 5, 82, 1, 70, 4, 93
  };
  const int q2446[] = {
    9, 9, // Number of jobs and machines
    0, 24, 2, 37, 3, 91, 7, 25, 6, 33, 4, 59, 1, 40, 5, 47, 8, 78, 
    6, 41, 7, 55, 3, 92, 0, 88, 8, 43, 1, 37, 2, 33, 4, 91, 5, 18, 
    4, 94, 5, 56, 0, 30, 1, 88, 7, 14, 6, 84, 3, 84, 8, 28, 2, 39, 
    1, 37, 0, 97, 3, 75, 7,  3, 5, 99, 8, 64, 4, 68, 6, 97, 2, 17, 
    7, 24, 3, 88, 8, 78, 0, 18, 4, 69, 5, 84, 2, 42, 6, 17, 1, 33, 
    3,  6, 8, 54, 0, 62, 2, 61, 1, 83, 4,  5, 7, 72, 5, 61, 6, 42, 
    0, 70, 2, 54, 8, 70, 1, 31, 5, 86, 4, 19, 7, 39, 3, 67, 6, 94, 
    0, 10, 3, 81, 7, 22, 4, 21, 2,  5, 8, 74, 5, 79, 6,  6, 1, 68, 
    5, 54, 0, 54, 2, 16, 8, 10, 7, 22, 3, 25, 4, 49, 6, 80, 1, 37
  };
  const int q2447[] = {
    9, 9, // Number of jobs and machines
    6, 66, 1, 85, 0, 91, 7, 81, 2, 13, 5, 11, 4, 76, 8, 36, 3, 23, 
    2,  9, 8, 67, 5, 87, 1, 41, 3, 14, 4, 72, 0, 50, 6, 85, 7, 70, 
    8, 47, 5, 13, 4, 52, 2, 23, 1, 40, 3, 38, 7, 34, 0, 38, 6, 54, 
    8,  8, 5, 49, 3, 98, 2, 97, 4, 51, 1,  8, 6, 33, 0, 32, 7,  3, 
    6, 62, 3, 17, 8, 50, 2, 54, 0, 61, 5, 14, 1, 58, 7, 17, 4, 31, 
    5, 74, 8, 61, 2, 24, 0, 97, 4, 38, 7, 53, 1, 43, 6, 41, 3,  8, 
    2,  7, 6, 50, 0, 50, 1, 40, 3, 87, 5,  9, 4, 34, 7, 84, 8,  4, 
    4, 86, 1, 66, 0, 73, 5, 59, 8, 60, 6, 46, 7,  6, 2, 72, 3,  7, 
    1, 14, 3, 33, 0, 26, 2, 85, 8, 78, 4, 32, 6, 92, 7, 34, 5, 49
  };
  const int q2448[] = {
    9, 9, // Number of jobs and machines
    7, 72, 1, 34, 2, 35, 8,  9, 3,  1, 4, 90, 5, 20, 6, 92, 0, 87, 
    1,  9, 6, 66, 7, 17, 5, 28, 4, 43, 0, 31, 8, 83, 3, 95, 2, 74, 
    8, 83, 1, 56, 3, 61, 4, 56, 2, 90, 6, 69, 5, 78, 7, 97, 0, 20, 
    5, 44, 3, 77, 8, 38, 7, 23, 0, 41, 6, 43, 2, 16, 4, 21, 1, 49, 
    2, 57, 8, 68, 6, 95, 7, 78, 4, 64, 5, 78, 3, 70, 1,  6, 0, 37, 
    5, 16, 7, 59, 0, 75, 4, 57, 6, 55, 1, 77, 8, 83, 3, 75, 2, 36, 
    1, 72, 4, 93, 8,  2, 0, 73, 7,  5, 3, 54, 5, 58, 2, 98, 6, 33, 
    5,  8, 1, 97, 2, 60, 4,  2, 7, 35, 6, 50, 8, 91, 3, 23, 0, 41, 
    1, 97, 5, 52, 4, 91, 6, 78, 7, 52, 8,  2, 0, 87, 3, 70, 2, 37
  };
  const int q2449[] = {
    9, 9, // Number of jobs and machines
    0, 92, 6, 36, 1, 99, 4, 78, 3, 27, 8, 13, 5,  3, 7, 31, 2,  1, 
    0, 81, 3, 48, 7, 36, 2, 73, 8,  7, 6, 42, 1, 61, 5, 53, 4, 90, 
    3,  1, 0, 26, 7, 18, 2, 54, 4, 64, 8, 86, 5, 24, 6, 18, 1, 40, 
    4, 57, 3, 15, 6, 71, 0, 23, 8, 71, 7, 66, 2, 18, 5,  5, 1, 37, 
    0, 88, 1, 24, 8, 21, 2, 38, 4, 90, 6, 20, 3, 98, 7, 91, 5,  6, 
    0, 30, 8, 73, 3, 69, 2,  1, 7, 58, 6, 99, 5, 25, 4, 36, 1, 90, 
    8, 40, 7, 63, 0, 82, 3, 43, 4, 60, 6, 29, 5, 28, 1, 75, 2, 18, 
    7, 47, 1, 59, 5, 46, 4,  2, 2, 83, 3, 41, 8, 37, 6, 66, 0,  8, 
    7, 95, 2,  4, 5, 34, 8, 53, 3, 37, 6, 98, 0,  8, 4, 22, 1, 66
  };
  const int q2450[] = {
    9, 9, // Number of jobs and machines
    3, 69, 6, 79, 5, 39, 4, 37, 1, 64, 8, 35, 2, 93, 0, 83, 7, 65, 
    2,  3, 8, 13, 0, 27, 1, 66, 5, 25, 4, 96, 7, 74, 3, 15, 6, 57, 
    2, 84, 3, 12, 5, 46, 8, 53, 6, 59, 1, 57, 0, 85, 4, 85, 7, 30, 
    8, 19, 4, 48, 5, 39, 0, 90, 2, 41, 6, 79, 7, 66, 1, 33, 3, 93, 
    8, 64, 3, 58, 5, 89, 7, 14, 2, 54, 6, 50, 0,  9, 1, 18, 4, 60, 
    6, 55, 0, 96, 5, 71, 2, 46, 3, 22, 4, 36, 1, 78, 8, 57, 7, 47, 
    1, 59, 4, 24, 3, 63, 6, 82, 8, 95, 0, 51, 2, 52, 7, 98, 5, 92, 
    6,  4, 4, 50, 0, 78, 2, 25, 7, 37, 3,  9, 1, 49, 5, 63, 8, 62, 
    7, 82, 0, 53, 8, 66, 4, 90, 2, 50, 1, 18, 6, 53, 3, 94, 5, 51
  };
  const int q2451[] = {
    9, 9, // Number of jobs and machines
    1, 35, 5, 33, 0, 60, 7,  4, 4, 71, 6, 43, 2, 62, 8, 33, 3, 44, 
    2, 20, 0, 72, 5, 74, 6, 82, 3, 16, 1, 52, 8, 10, 7, 73, 4,  6, 
    7, 88, 8, 49, 0, 10, 1, 42, 5, 13, 4, 58, 3,  9, 2, 59, 6, 82, 
    0, 84, 6, 98, 3, 85, 5, 59, 8, 26, 2,  9, 4,  3, 7, 69, 1, 92, 
    7, 61, 2, 82, 1,  5, 4, 78, 5, 75, 3, 58, 8, 47, 6, 76, 0, 39, 
    0, 47, 3, 99, 2, 83, 6, 14, 8, 43, 1, 73, 4, 20, 5, 81, 7, 54, 
    0, 74, 4, 72, 7, 85, 8, 77, 3, 84, 6, 13, 2, 12, 5, 89, 1, 45, 
    3, 51, 8, 87, 1, 30, 6, 95, 7, 78, 0, 84, 4, 21, 2, 99, 5, 11, 
    7, 54, 1, 37, 4, 22, 2, 11, 6, 14, 0, 34, 8, 61, 3, 96, 5, 29
  };
  const int q2452[] = {
    9, 9, // Number of jobs and machines
    3, 96, 0,  1, 5, 94, 1, 42, 8, 99, 4, 86, 2, 33, 7,  1, 6,  7, 
    8, 32, 3, 29, 7, 71, 4, 55, 0, 89, 5, 98, 1, 58, 6, 19, 2, 40, 
    3, 10, 6, 44, 4, 41, 5, 27, 2, 24, 8,  6, 7, 25, 1, 34, 0, 97, 
    3, 98, 1, 58, 7, 35, 2, 88, 5, 95, 0, 42, 8, 77, 6, 89, 4, 14, 
    6, 24, 5, 22, 0, 55, 4, 55, 2, 83, 7, 79, 3, 53, 1, 34, 8, 73, 
    3, 13, 6, 29, 8, 54, 1, 65, 0, 86, 5, 61, 7, 94, 4, 43, 2, 59, 
    7, 15, 8, 35, 2, 27, 1, 15, 4, 39, 0, 49, 6,  5, 3, 71, 5, 69, 
    1,  2, 6,  6, 4, 50, 3, 79, 7, 65, 0, 36, 8, 77, 5, 74, 2, 64, 
    2, 47, 1, 28, 4, 87, 7, 60, 8, 66, 3, 37, 5, 26, 0, 44, 6,  9
  };
  const int q2453[] = {
    9, 9, // Number of jobs and machines
    7, 84, 4, 84, 3, 55, 0, 60, 8, 10, 6, 91, 2, 22, 5, 51, 1, 48, 
    7, 50, 8, 50, 2, 79, 6, 44, 5, 92, 4, 66, 0, 53, 1, 23, 3, 20, 
    1, 46, 8, 54, 2,  7, 4, 66, 3, 38, 5, 54, 7, 12, 0, 81, 6,  2, 
    1, 16, 6, 39, 7, 42, 2, 23, 0, 82, 5, 53, 3, 15, 4, 69, 8, 74, 
    6, 74, 7, 25, 4, 93, 5, 78, 2, 84, 1,  7, 0, 36, 8, 58, 3, 72, 
    0, 72, 5,  9, 7, 14, 1, 34, 3, 27, 4, 54, 6, 44, 2, 81, 8, 48, 
    5, 75, 1, 26, 4, 67, 3, 49, 8, 43, 2, 89, 7, 38, 0, 34, 6,  2, 
    8, 52, 7, 80, 5,  5, 0, 95, 6, 93, 4, 62, 3, 88, 2, 95, 1, 77, 
    3, 14, 4, 93, 2, 26, 8, 24, 0, 50, 7, 62, 6, 42, 1, 84, 5, 47
  };
  const int q2454[] = {
    9, 9, // Number of jobs and machines
    2, 95, 4, 60, 3, 26, 0, 85, 7, 94, 1, 36, 8, 99, 5, 18, 6, 27, 
    4, 83, 8,  3, 3, 45, 5, 54, 2, 35, 6,  5, 0, 21, 7, 57, 1, 78, 
    3, 69, 4, 81, 5, 14, 7, 23, 1, 41, 8, 46, 6, 60, 0, 63, 2, 93, 
    7, 85, 2, 74, 4, 24, 5, 50, 6, 81, 0, 11, 3, 68, 1, 34, 8, 52, 
    3, 36, 8, 13, 5, 33, 1, 42, 7, 42, 4, 78, 2, 61, 0, 86, 6, 96, 
    7, 14, 4, 19, 1,  4, 8, 50, 3, 28, 2, 35, 5, 56, 6, 58, 0, 24, 
    1, 95, 0, 60, 5, 61, 3, 67, 4, 48, 6, 70, 7, 38, 2, 76, 8, 55, 
    0, 80, 6, 87, 2, 76, 4, 37, 5, 83, 3, 23, 8, 45, 1, 15, 7, 27, 
    5, 90, 3, 32, 0, 22, 1, 91, 6,  4, 2,  9, 4, 53, 8, 23, 7, 57
  };
  const int q2455[] = {
    9, 9, // Number of jobs and machines
    7, 59, 4, 87, 6, 84, 2,  6, 5, 84, 1, 86, 8, 78, 0, 33, 3, 84, 
    2, 66, 1, 58, 5, 62, 8,  7, 7, 14, 3, 32, 0, 21, 4, 74, 6, 59, 
    1,  6, 7, 93, 2, 89, 3, 21, 0, 93, 6, 36, 4, 51, 5, 42, 8, 64, 
    0, 18, 1, 63, 3, 94, 2, 27, 4,  7, 5, 92, 6, 50, 7, 61, 8, 14, 
    8, 30, 1, 69, 7, 44, 0, 95, 3, 78, 2, 41, 5, 64, 4, 21, 6, 89, 
    0, 82, 6, 89, 7, 37, 1, 45, 2, 86, 5, 75, 4, 48, 8, 29, 3, 67, 
    6, 75, 5, 25, 1, 31, 4, 99, 0, 79, 3, 53, 2, 35, 7, 48, 8, 61, 
    8, 99, 0, 58, 6, 93, 3, 30, 2, 49, 1, 75, 7, 63, 5, 21, 4, 34, 
    4, 73, 6, 66, 5, 42, 8, 92, 0, 72, 2, 98, 1, 10, 7, 24, 3, 17
  };
  const int q2456[] = {
    9, 9, // Number of jobs and machines
    6, 26, 8, 38, 0, 81, 7, 40, 4, 78, 1,  7, 2,  6, 5, 28, 3, 75, 
    4, 48, 1, 79, 2,  7, 0, 36, 8, 83, 6, 93, 7, 52, 5, 21, 3, 81, 
    6, 79, 0, 50, 1, 75, 2, 57, 5, 84, 7, 89, 3, 21, 8,  3, 4, 26, 
    3, 39, 6, 75, 4, 62, 0, 68, 8, 77, 2, 95, 7, 74, 1, 11, 5, 12, 
    5, 23, 6, 60, 2, 56, 4, 54, 8, 70, 0, 78, 7, 20, 1, 84, 3, 59, 
    4, 25, 3, 71, 0, 33, 7,  8, 6, 64, 8, 91, 5, 62, 1, 19, 2, 86, 
    7, 58, 5, 64, 4, 89, 0, 40, 8, 22, 1, 21, 2, 78, 3, 50, 6, 53, 
    6, 71, 7, 33, 3,  5, 5, 51, 0, 57, 2, 85, 8, 53, 1, 81, 4, 70, 
    8, 34, 0, 88, 1, 93, 5, 22, 4, 55, 7, 22, 6,  9, 2, 85, 3, 50
  };
  const int q2457[] = {
    9, 9, // Number of jobs and machines
    3, 72, 7, 89, 5, 19, 1, 54, 2, 31, 6, 46, 8, 98, 0, 80, 4, 73, 
    1, 69, 2, 18, 5, 43, 3, 80, 0, 38, 7, 55, 4,  3, 6, 19, 8, 49, 
    3, 38, 2, 27, 8, 16, 7, 33, 6, 37, 1, 43, 0, 31, 5, 53, 4, 10, 
    8,  8, 5, 11, 6, 44, 3, 67, 7, 47, 2, 62, 0, 57, 4, 52, 1, 46, 
    1, 65, 3,  3, 0, 90, 8, 15, 6, 82, 2, 43, 7, 55, 5, 34, 4,  8, 
    2, 42, 5, 27, 1, 82, 8, 67, 4, 29, 6, 59, 7, 52, 3, 25, 0, 54, 
    5, 77, 4, 61, 1, 45, 2, 20, 0, 58, 6, 31, 7, 89, 8, 35, 3, 64, 
    8, 90, 4, 21, 5, 54, 6, 38, 3, 42, 0, 96, 1,  6, 2, 89, 7, 84, 
    7, 72, 0, 24, 2, 84, 6, 89, 5, 42, 1, 61, 8, 76, 4, 23, 3, 63
  };
  const int q2458[] = {
    9, 9, // Number of jobs and machines
    8,  4, 2, 75, 3, 29, 5, 27, 6, 23, 4, 71, 0, 65, 1,  8, 7, 29, 
    2, 62, 8, 82, 1, 41, 7, 23, 4, 99, 3, 36, 6, 82, 5, 95, 0, 37, 
    1, 48, 8, 88, 2, 74, 5, 81, 3, 16, 0, 32, 6, 99, 4, 40, 7, 18, 
    2, 33, 0, 63, 5, 30, 4,  7, 3, 16, 8, 67, 7, 12, 1, 15, 6, 41, 
    5, 78, 4, 23, 7, 52, 1,  8, 3, 23, 0, 66, 6, 88, 8,  2, 2, 87, 
    0, 67, 1, 57, 4,  6, 7, 31, 8, 22, 2, 83, 6, 59, 5, 86, 3, 55, 
    0, 14, 1, 92, 6, 58, 7,  7, 5, 39, 2, 67, 8, 67, 4, 41, 3, 76, 
    2, 43, 8, 73, 3, 45, 4, 21, 1, 42, 5,  7, 7,  4, 0, 60, 6, 66, 
    2, 43, 3, 51, 1, 52, 5, 11, 6, 30, 8, 96, 7, 76, 0, 34, 4, 16
  };
  const int q2459[] = {
    9, 9, // Number of jobs and machines
    1, 80, 4, 42, 6, 28, 7, 43, 3, 96, 8, 32, 0, 85, 5,  1, 2, 42, 
    6, 51, 8, 19, 1, 56, 0, 70, 4, 18, 7,  6, 5,  5, 3, 33, 2, 83, 
    1, 83, 0, 79, 7, 52, 8, 80, 5, 87, 6, 80, 4, 17, 3,  1, 2, 44, 
    1, 54, 7, 28, 4, 47, 8, 89, 3, 65, 0,  1, 2, 37, 5, 46, 6, 49, 
    2,  2, 8, 66, 4, 92, 1, 46, 7, 19, 5, 19, 6, 24, 3, 70, 0, 83, 
    2, 81, 0, 76, 8, 14, 7, 86, 5, 65, 6, 93, 3, 24, 1, 20, 4, 26, 
    6, 98, 0, 93, 2,  1, 8, 40, 5, 79, 7, 45, 1,  9, 4, 41, 3, 70, 
    8, 69, 6, 40, 5, 68, 1, 32, 4, 64, 0, 57, 3,  9, 2, 62, 7, 27, 
    1, 69, 6, 53, 4, 14, 7,  3, 5, 16, 8, 54, 2,  4, 3, 47, 0, 16
  };
  const int q2460[] = {
    9, 9, // Number of jobs and machines
    6, 14, 2,  6, 8, 49, 7, 64, 3, 94, 0,  2, 1, 96, 4, 20, 5, 13, 
    4, 59, 2, 94, 3, 70, 6, 30, 1, 41, 7, 20, 0, 98, 5,  2, 8, 32, 
    3, 26, 0, 89, 8, 46, 6, 92, 4, 72, 2, 94, 5, 22, 1, 15, 7, 21, 
    3, 81, 6, 18, 2, 47, 7,  4, 4, 10, 0, 24, 5, 35, 1, 71, 8, 83, 
    4, 92, 0, 68, 6,  4, 3, 10, 2, 84, 5,  4, 8, 55, 1, 18, 7, 63, 
    1, 39, 2, 64, 0, 50, 4, 50, 3,  7, 7, 80, 8, 35, 5,  5, 6, 35, 
    7, 91, 8, 38, 0,  1, 3, 96, 4, 60, 6,  2, 5, 93, 1, 95, 2, 73, 
    1, 85, 5, 90, 6, 88, 0, 31, 3, 93, 4, 39, 8, 80, 7,  9, 2, 44, 
    8, 79, 7,  7, 5, 87, 4, 54, 0, 30, 6, 65, 3, 22, 2, 97, 1, 18
  };
  const int q2461[] = {
    9, 9, // Number of jobs and machines
    8, 94, 5, 97, 4, 37, 0, 70, 1, 68, 6, 62, 7, 51, 3, 47, 2, 56, 
    2, 61, 4, 22, 1, 79, 5, 53, 7, 91, 0, 72, 6, 57, 8, 40, 3, 81, 
    2, 24, 4, 92, 3, 72, 6, 74, 0, 35, 1, 82, 7, 40, 8, 92, 5, 66, 
    1,  6, 2, 68, 6, 33, 4, 51, 5, 74, 7, 74, 0, 39, 3, 58, 8, 26, 
    6, 13, 3,  7, 8, 12, 1, 47, 2,  4, 7, 71, 0, 87, 4, 60, 5, 95, 
    5,  2, 8, 42, 7, 45, 6, 24, 1, 71, 2, 28, 4, 94, 3, 71, 0, 29, 
    0, 53, 3, 14, 5, 80, 6, 44, 7, 41, 1, 43, 8, 70, 2, 59, 4, 99, 
    6, 91, 0, 64, 4, 15, 1, 19, 3, 55, 8, 78, 2, 89, 7,  6, 5, 30, 
    6, 40, 8, 79, 1, 66, 7, 60, 3, 24, 2, 17, 0, 75, 5, 11, 4, 29
  };
  const int q2462[] = {
    9, 9, // Number of jobs and machines
    0, 66, 1, 26, 5, 14, 2, 99, 8, 69, 6,  5, 4, 38, 7, 81, 3, 33, 
    2, 49, 1, 98, 7, 66, 8, 25, 3,  4, 0, 48, 5, 58, 4, 16, 6, 88, 
    7, 63, 8, 28, 0, 99, 1, 58, 2, 16, 5, 47, 6, 31, 3, 84, 4, 34, 
    4, 72, 6, 31, 8, 57, 5, 95, 7, 96, 2, 78, 0, 10, 1, 10, 3,  6, 
    4, 63, 0, 14, 5, 34, 1, 49, 8, 76, 2,  8, 6,  4, 7, 23, 3, 36, 
    6, 75, 1, 18, 7, 78, 5, 61, 4, 81, 2, 90, 3, 26, 8, 98, 0, 79, 
    1, 97, 8,  5, 4, 48, 3, 36, 2, 53, 7,  9, 0, 75, 5, 46, 6, 56, 
    5,  8, 1, 28, 3, 57, 0, 19, 4, 84, 6,  8, 8, 57, 7, 59, 2, 28, 
    6, 62, 0, 59, 1, 16, 8, 42, 7, 55, 3,  2, 2, 67, 5, 88, 4, 55
  };
  const int q2463[] = {
    9, 9, // Number of jobs and machines
    4, 37, 7, 50, 8, 95, 0, 47, 2, 62, 5, 96, 1, 81, 3, 12, 6,  6, 
    4, 75, 5, 70, 2, 80, 7, 54, 0, 77, 8, 39, 6, 51, 1,  9, 3,  9, 
    1, 45, 0, 85, 2, 65, 7, 10, 8, 94, 4, 31, 5, 51, 6, 33, 3, 24, 
    3, 49, 1, 96, 4, 35, 8, 16, 2,  4, 5, 95, 0, 76, 6, 53, 7, 91, 
    0, 39, 4, 73, 8, 17, 6, 33, 7, 16, 5, 98, 1, 48, 2,  7, 3, 58, 
    5, 53, 7, 64, 0, 11, 4, 15, 1,  2, 6, 87, 3, 81, 8, 51, 2, 86, 
    7, 69, 0, 80, 2,  1, 3, 43, 4, 18, 8, 36, 1, 80, 6, 91, 5, 35, 
    6, 47, 0, 97, 3, 59, 8, 48, 4, 85, 5, 98, 2, 61, 1, 18, 7,  5, 
    0, 73, 4, 74, 7, 31, 3, 37, 8, 24, 2, 34, 6, 64, 5, 52, 1, 41
  };
  const int q2464[] = {
    9, 9, // Number of jobs and machines
    4, 35, 3, 37, 7, 71, 8, 24, 2, 29, 0, 27, 5, 80, 6, 19, 1, 49, 
    3, 15, 4, 95, 5,  5, 7, 95, 6, 18, 8, 47, 2, 50, 1, 54, 0, 84, 
    2,  4, 1, 76, 8, 39, 4, 53, 5, 94, 3, 40, 0, 53, 6, 44, 7, 33, 
    4, 67, 6, 71, 0, 70, 8, 68, 5, 48, 7, 68, 1, 40, 2, 86, 3, 35, 
    0, 56, 3, 19, 7, 52, 6, 37, 2, 48, 5, 58, 8, 82, 4,  5, 1, 75, 
    2, 49, 4, 24, 7, 39, 0, 70, 3, 27, 5, 39, 1, 52, 8, 83, 6, 18, 
    4, 55, 7, 63, 3, 88, 1, 55, 0, 72, 6, 40, 8, 95, 2, 64, 5, 94, 
    5, 72, 1, 65, 6, 77, 2, 15, 0, 16, 7, 31, 8, 96, 4, 47, 3, 56, 
    4, 66, 7, 62, 0, 25, 3, 83, 6, 84, 2, 60, 5, 55, 8, 62, 1, 86
  };
  const int q2465[] = {
    9, 9, // Number of jobs and machines
    8, 14, 6, 45, 2, 98, 0, 13, 1,  4, 5, 77, 3, 35, 4, 42, 7, 63, 
    7, 75, 3, 69, 0, 74, 1,  5, 4, 51, 2,  6, 5, 46, 8, 46, 6, 20, 
    2, 48, 6, 66, 0, 27, 5, 44, 1, 97, 3, 13, 8, 92, 4, 96, 7, 58, 
    5,  6, 0, 56, 1, 40, 6, 18, 3, 35, 2, 82, 8, 84, 4, 67, 7, 30, 
    3, 16, 7, 91, 6, 71, 1, 86, 8, 82, 2,  8, 4, 86, 5, 72, 0, 31, 
    6, 21, 0, 57, 7, 66, 5, 70, 1, 42, 4, 31, 3, 84, 8, 12, 2, 41, 
    4, 51, 8, 29, 0, 17, 2, 50, 3, 68, 6,  2, 1,  5, 7, 97, 5, 61, 
    5, 26, 8, 78, 7, 61, 6, 63, 4, 83, 2, 25, 0, 93, 1, 13, 3, 65, 
    6, 92, 7, 46, 5, 59, 8, 26, 4, 31, 1, 46, 2, 40, 3,  4, 0, 67
  };
  const int q2466[] = {
    9, 9, // Number of jobs and machines
    8, 13, 5, 22, 2, 41, 1, 71, 6, 46, 7, 15, 4, 76, 0, 70, 3, 17, 
    1, 85, 3, 51, 7, 99, 6, 26, 0, 14, 4, 22, 8, 92, 5, 50, 2, 39, 
    2, 21, 1,  3, 5, 93, 8, 73, 7, 38, 4, 52, 0, 40, 6, 16, 3, 51, 
    6, 50, 1, 54, 7, 43, 5, 25, 4, 56, 3, 49, 8, 21, 2, 66, 0, 84, 
    4, 94, 0, 10, 7,  5, 5, 10, 8, 72, 2, 97, 6, 52, 1,  5, 3, 62, 
    6, 95, 0, 77, 5, 50, 4, 19, 1, 37, 3, 58, 2, 30, 8,  5, 7,  8, 
    0, 97, 6, 60, 8, 53, 3, 32, 1, 88, 2, 81, 4, 52, 7,  6, 5, 11, 
    6, 54, 0, 75, 5,  3, 3, 89, 1, 96, 8, 31, 7, 26, 2, 37, 4, 83, 
    7, 22, 8, 50, 1,  5, 0, 30, 5, 74, 4, 43, 2, 58, 6, 80, 3, 96
  };
  const int q2467[] = {
    9, 9, // Number of jobs and machines
    4, 15, 6, 96, 2, 50, 7, 82, 8, 69, 1, 51, 5, 99, 3, 79, 0, 56, 
    3, 52, 5, 91, 2, 27, 8, 18, 4, 23, 0, 94, 7, 37, 1, 29, 6, 57, 
    4, 90, 1, 57, 5, 26, 2, 32, 0, 14, 6, 40, 3, 39, 8, 90, 7, 34, 
    3, 46, 2, 19, 0, 93, 8, 89, 7,  6, 1, 91, 5, 67, 6, 39, 4, 58, 
    0, 92, 3, 55, 6, 42, 2, 71, 5, 68, 4, 13, 8, 91, 1, 90, 7, 41, 
    1, 77, 5, 74, 8,  6, 4, 33, 0, 42, 7, 74, 2, 87, 6, 48, 3, 80, 
    0, 22, 3, 71, 1, 36, 4, 29, 7, 91, 8, 10, 6, 60, 2, 98, 5,  5, 
    0, 27, 7, 46, 8, 98, 2, 82, 5, 41, 3,  3, 4, 13, 1,  3, 6, 41, 
    1, 82, 4, 52, 5, 90, 7, 33, 0, 42, 8, 93, 3, 94, 2, 98, 6, 49
  };
  const int q2468[] = {
    9, 9, // Number of jobs and machines
    0, 90, 1, 51, 4, 24, 8, 89, 3, 12, 7, 40, 2, 40, 5, 13, 6, 39, 
    4, 10, 6, 58, 2, 54, 7, 61, 5, 47, 0, 29, 3, 37, 1, 34, 8, 59, 
    2, 59, 0, 93, 8, 49, 7, 46, 1, 45, 6, 75, 3, 52, 4, 40, 5, 29, 
    2, 52, 0, 64, 3, 98, 4, 58, 8, 56, 7, 28, 1, 74, 5, 38, 6, 96, 
    8, 32, 0, 64, 4, 42, 2, 40, 7, 45, 5, 96, 1, 66, 6,  6, 3, 13, 
    7, 26, 4, 44, 5, 70, 3, 90, 6, 30, 8,  7, 2, 67, 1, 48, 0, 95, 
    3, 38, 2, 50, 5, 65, 7, 34, 8, 65, 1, 41, 4, 50, 0, 93, 6, 87, 
    3, 91, 6, 55, 2, 70, 8, 96, 7, 69, 5, 55, 1,  2, 0,  3, 4, 21, 
    2, 31, 3, 26, 8, 90, 0, 62, 1, 77, 5, 74, 6, 13, 7, 15, 4, 50
  };
  const int q2469[] = {
    9, 9, // Number of jobs and machines
    5, 28, 8, 82, 7, 37, 1, 80, 2, 56, 4, 16, 6, 58, 0, 96, 3, 48, 
    8, 22, 2,  7, 0, 58, 7, 20, 6, 82, 4, 10, 5, 91, 1, 23, 3, 56, 
    8, 58, 7, 65, 5, 70, 6, 48, 0, 12, 4, 52, 3, 55, 2, 11, 1, 86, 
    6, 83, 3, 46, 1, 89, 8, 14, 2, 29, 4, 58, 5,  8, 0, 51, 7, 19, 
    5, 93, 4, 57, 0, 64, 7, 46, 6, 31, 2, 30, 3, 12, 1, 36, 8, 85, 
    4, 12, 5, 62, 8, 75, 1, 26, 3, 90, 6, 24, 7, 74, 0, 66, 2, 11, 
    1, 15, 3, 37, 0, 65, 4, 77, 6, 21, 2, 16, 8, 55, 7, 22, 5, 81, 
    5, 29, 2,  4, 0, 76, 1, 69, 6, 94, 7, 53, 3, 23, 8, 62, 4, 26, 
    6, 14, 1, 84, 7, 16, 8, 77, 0, 45, 4, 25, 3,  1, 2,  9, 5, 92
  };
  const int q2470[] = {
    9, 9, // Number of jobs and machines
    2, 46, 1, 87, 0, 35, 3, 52, 7, 40, 8, 38, 6, 33, 4, 90, 5, 34, 
    8, 49, 4, 91, 6, 78, 2, 52, 7, 61, 3, 62, 1,  7, 0, 59, 5, 61, 
    4, 62, 0,  4, 5, 45, 3, 98, 7, 67, 1, 13, 6, 52, 8,  1, 2, 51, 
    6, 26, 2, 31, 0, 37, 7, 10, 4,  5, 3, 87, 8, 36, 5, 71, 1, 13, 
    3, 48, 7, 46, 1, 46, 5, 36, 6,  4, 2, 47, 0, 30, 4, 93, 8, 97, 
    6, 13, 2,  8, 4,  1, 3, 33, 7,  6, 0, 34, 5, 98, 8, 93, 1, 75, 
    1, 45, 4, 69, 0, 16, 5, 67, 7, 52, 2, 46, 3, 52, 6, 89, 8, 90, 
    7, 90, 8, 29, 6, 19, 0, 12, 1, 73, 5, 85, 4, 12, 3, 33, 2, 38, 
    1, 54, 2, 90, 8, 78, 4, 49, 7, 64, 0, 18, 6, 26, 3, 56, 5, 74
  };
  const int q2471[] = {
    9, 9, // Number of jobs and machines
    6, 15, 2,  2, 8, 22, 3, 37, 5, 38, 7, 92, 4, 23, 1, 91, 0, 23, 
    6, 42, 2, 71, 1, 57, 3, 56, 5, 98, 4, 90, 7, 58, 8, 90, 0,  8, 
    6, 29, 4, 87, 2, 43, 8, 91, 7, 54, 1, 94, 3, 44, 0, 94, 5, 13, 
    2, 97, 4, 11, 6, 29, 8, 62, 3, 60, 5,  5, 0, 23, 7, 91, 1, 36, 
    4, 46, 1, 34, 2, 88, 8, 53, 7, 91, 0, 83, 5, 68, 3, 62, 6, 76, 
    1, 74, 6, 53, 2, 60, 7, 30, 4, 60, 0, 28, 8, 39, 3, 62, 5,  7, 
    7, 52, 5, 47, 1, 61, 4, 35, 6, 44, 2, 86, 3, 41, 0, 60, 8, 24, 
    2, 19, 6, 29, 5, 61, 7, 68, 8, 65, 3, 47, 4,  2, 0, 88, 1,  6, 
    7, 61, 1, 96, 8, 71, 3, 35, 6, 46, 2, 96, 5, 40, 0, 34, 4, 44
  };
  const int q2472[] = {
    9, 9, // Number of jobs and machines
    2, 87, 3, 29, 8,  7, 0, 46, 1, 95, 4, 49, 5,  3, 7, 83, 6,  6, 
    8, 71, 2, 93, 3, 41, 4, 20, 0,  9, 5, 34, 7, 34, 6, 22, 1, 10, 
    5, 59, 6, 29, 4, 17, 0, 33, 1, 25, 2,  8, 8, 91, 3,  3, 7, 41, 
    1, 32, 7,  3, 2, 26, 3, 51, 5, 33, 6, 83, 8, 42, 4, 26, 0, 25, 
    2, 20, 8, 23, 0, 91, 3, 66, 6, 52, 4, 47, 1, 63, 5, 83, 7, 87, 
    0, 20, 6, 44, 7,  5, 5, 61, 4, 32, 1, 70, 8, 22, 2, 78, 3, 69, 
    0, 46, 4, 64, 8, 52, 1, 11, 6, 41, 2, 32, 5, 50, 7, 90, 3, 25, 
    5, 37, 4, 65, 2, 28, 0, 12, 3, 46, 1, 31, 7, 46, 6, 86, 8, 34, 
    3, 80, 8,  9, 4, 14, 5, 65, 2, 78, 1, 62, 6, 82, 0, 13, 7, 57
  };
  const int q2473[] = {
    9, 9, // Number of jobs and machines
    4, 65, 8, 96, 6,  7, 1, 35, 2, 41, 7, 17, 3, 71, 0, 88, 5, 94, 
    6, 15, 0, 38, 8, 67, 1,  1, 2, 36, 4, 34, 5, 99, 3, 39, 7, 41, 
    3,  9, 6, 64, 4, 33, 1, 84, 2, 47, 5, 32, 8, 28, 0,  4, 7, 54, 
    6,  9, 3, 79, 4,  7, 5, 23, 0, 12, 8, 72, 1,  8, 2, 48, 7, 18, 
    7, 43, 3, 80, 2, 93, 6, 91, 1, 16, 0, 14, 5, 86, 8, 64, 4, 46, 
    0, 77, 1, 96, 5, 44, 6,  1, 8,  5, 4, 17, 3, 43, 7, 39, 2, 15, 
    8, 45, 6, 95, 2, 41, 4, 56, 3, 25, 0, 29, 7, 52, 1, 36, 5, 70, 
    8, 10, 1, 69, 6, 96, 5, 10, 3, 98, 0, 77, 7, 72, 2, 89, 4, 31, 
    3, 32, 6, 83, 0, 19, 4,  3, 8, 22, 1, 86, 7, 38, 5, 68, 2, 41
  };
  const int q2474[] = {
    9, 9, // Number of jobs and machines
    8,  7, 3, 46, 4, 58, 5, 61, 7, 20, 2,  2, 1, 35, 6, 52, 0, 30, 
    7, 84, 4, 79, 1, 19, 6, 58, 2, 14, 8, 65, 5, 60, 3, 24, 0, 36, 
    6, 41, 4, 94, 2, 99, 1, 85, 3, 68, 8,  7, 7, 11, 0, 66, 5, 22, 
    2, 92, 5, 87, 1, 50, 8, 47, 0, 81, 3, 64, 7, 94, 6, 45, 4, 97, 
    2, 29, 4, 26, 1, 95, 0, 37, 5, 81, 3, 24, 6, 66, 8, 44, 7, 67, 
    0, 37, 2, 26, 5, 55, 4, 45, 8, 69, 7, 28, 1, 54, 6,  2, 3, 78, 
    1, 83, 6, 60, 7, 20, 0, 95, 4, 70, 5, 71, 8, 60, 3, 63, 2, 15, 
    3, 63, 8, 46, 2, 30, 4, 25, 6, 19, 0, 77, 1, 18, 5, 38, 7, 29, 
    2, 48, 5, 71, 6, 73, 0, 16, 8, 18, 7, 71, 1, 23, 3, 32, 4, 99
  };
  const int q2475[] = {
    9, 9, // Number of jobs and machines
    1,  3, 6, 83, 3, 83, 4, 58, 0, 97, 5, 47, 7, 11, 2, 43, 8,  7, 
    5, 17, 8, 43, 7, 61, 0, 96, 3, 67, 1, 23, 2, 12, 4, 69, 6, 22, 
    4, 49, 6, 10, 5, 68, 0, 54, 7, 23, 1, 28, 2, 40, 8, 65, 3, 49, 
    4, 87, 8, 56, 7, 23, 2, 60, 0, 42, 1, 23, 3, 10, 6, 22, 5, 98, 
    2, 29, 0, 31, 7, 69, 3, 59, 1, 70, 6, 62, 8,  7, 5, 49, 4, 31, 
    2, 90, 3, 80, 5, 41, 7, 41, 4, 81, 1, 33, 8, 32, 6, 21, 0, 93, 
    2, 70, 8, 48, 1, 36, 4, 97, 3, 14, 5,  7, 0, 31, 7, 70, 6, 45, 
    8, 62, 2, 14, 3, 21, 7,  8, 6, 12, 5, 75, 1, 88, 4, 37, 0, 70, 
    8, 90, 0, 64, 1, 34, 6, 64, 5, 66, 2, 95, 3, 96, 4, 91, 7, 98
  };
  const int q2476[] = {
    9, 9, // Number of jobs and machines
    8, 78, 6, 45, 1, 46, 3, 39, 2, 22, 0, 13, 7, 80, 5, 23, 4, 30, 
    6, 75, 1, 60, 8, 19, 0,  5, 5,  7, 2, 67, 7, 69, 3, 98, 4, 66, 
    8, 93, 4, 25, 7, 77, 6, 91, 3, 74, 1,  1, 5, 39, 0, 59, 2, 57, 
    0, 63, 5, 56, 1, 53, 4,  3, 6, 89, 3, 84, 8, 15, 7, 14, 2, 73, 
    1, 69, 2, 22, 6, 72, 8, 93, 7, 20, 0, 20, 3, 25, 4, 30, 5, 25, 
    6, 97, 1, 32, 5, 67, 2, 26, 0, 52, 7, 30, 4,  9, 8, 46, 3, 84, 
    3, 85, 7, 37, 8, 32, 4, 96, 2, 46, 1, 40, 6, 98, 0, 38, 5,  5, 
    5, 75, 3, 64, 7, 65, 1, 37, 6, 42, 8, 69, 4, 60, 2, 11, 0, 48, 
    3, 94, 1, 62, 6, 83, 0, 74, 5, 87, 2, 34, 8, 56, 7,  9, 4, 41
  };
  const int q2477[] = {
    9, 9, // Number of jobs and machines
    8, 11, 1, 45, 6, 60, 0, 62, 4, 48, 7, 31, 3, 16, 5, 67, 2, 32, 
    4, 99, 7, 95, 8, 19, 3, 81, 6, 20, 0, 99, 1, 21, 5, 78, 2, 97, 
    4,  8, 3, 17, 1, 87, 5, 97, 0, 13, 7, 36, 6, 87, 8, 10, 2, 47, 
    2, 95, 3, 24, 6, 30, 8, 73, 1, 30, 0, 53, 5,  8, 4, 67, 7, 42, 
    6, 41, 3, 34, 4, 26, 8, 41, 0, 31, 5,  3, 2, 13, 7, 84, 1,  5, 
    8, 76, 7, 56, 5,  3, 0, 72, 4, 14, 3, 77, 2, 44, 6, 33, 1, 92, 
    7, 36, 6, 22, 3, 46, 8, 54, 4, 29, 0, 48, 1, 90, 2,  6, 5, 13, 
    0, 61, 8, 94, 5, 36, 1, 19, 6, 57, 2, 69, 4, 18, 7, 83, 3, 46, 
    1, 67, 5, 98, 7,  5, 4, 31, 8, 35, 0, 86, 6, 78, 3, 11, 2, 11
  };
  const int q2478[] = {
    9, 9, // Number of jobs and machines
    4, 98, 1, 89, 0, 15, 7, 89, 2, 25, 5, 32, 8, 23, 6, 60, 3, 13, 
    8, 36, 4, 24, 3, 51, 0, 50, 2, 71, 7, 76, 5, 66, 1, 25, 6, 58, 
    5, 53, 0, 82, 6, 45, 7, 69, 2, 82, 8, 91, 1, 63, 3, 70, 4, 70, 
    0, 37, 3, 38, 2, 49, 7, 64, 1, 36, 5, 19, 6, 70, 8,  5, 4, 59, 
    2, 53, 0, 31, 7, 63, 6,  6, 3, 72, 5, 57, 8, 82, 4, 12, 1, 37, 
    2, 45, 5, 98, 7, 14, 8, 55, 4, 80, 0, 57, 1, 62, 6, 45, 3, 73, 
    1, 94, 3, 13, 4, 16, 5, 77, 7, 69, 8, 20, 2, 76, 6, 48, 0, 11, 
    1, 29, 7, 67, 0, 36, 5, 92, 2, 72, 6, 97, 8, 56, 4, 46, 3, 36, 
    2, 39, 6, 18, 3, 71, 1, 98, 4, 93, 8, 10, 7, 49, 5, 18, 0, 34
  };
  const int q2479[] = {
    9, 9, // Number of jobs and machines
    7,  5, 1, 52, 4, 68, 5, 52, 2, 99, 8, 80, 6, 84, 3, 67, 0, 53, 
    3, 78, 2, 41, 5, 49, 6, 62, 1, 67, 4, 58, 0, 70, 7, 19, 8, 94, 
    0, 79, 6, 73, 1, 81, 8,  5, 7, 64, 4, 68, 2, 17, 3, 89, 5, 71, 
    2, 78, 3, 65, 7, 37, 1, 65, 6, 93, 8, 50, 5, 12, 0,  5, 4, 53, 
    4, 96, 2, 32, 6, 76, 8, 45, 5, 49, 0, 32, 1, 18, 7, 35, 3, 31, 
    8, 21, 3, 40, 4, 21, 1, 89, 0,  9, 5, 59, 6, 61, 2, 30, 7, 63, 
    5, 27, 6,  5, 4, 22, 8, 89, 7,  5, 1, 30, 2, 53, 3, 62, 0, 78, 
    2, 26, 5, 44, 8, 16, 4, 15, 6, 11, 3, 11, 7,  4, 1, 95, 0, 85, 
    8, 68, 0, 82, 3, 92, 2, 50, 7, 19, 6,  3, 1, 77, 5, 14, 4, 79
  };
  const int q2480[] = {
    9, 9, // Number of jobs and machines
    7, 68, 8, 67, 1, 73, 2, 82, 5, 91, 4, 62, 3, 88, 0, 96, 6, 47, 
    1, 31, 5, 52, 8, 36, 3, 69, 7, 36, 6, 85, 2, 64, 4, 77, 0, 56, 
    6, 89, 5, 17, 3, 29, 0, 68, 7, 52, 8, 27, 2, 31, 1, 42, 4, 72, 
    8, 46, 5, 93, 4, 50, 0, 63, 6, 72, 2, 47, 3, 11, 1, 57, 7, 59, 
    6, 54, 0, 78, 7, 53, 3, 16, 2, 97, 8, 28, 4, 62, 5, 26, 1, 59, 
    6, 38, 8, 52, 2, 39, 5, 75, 4, 33, 3, 52, 0, 69, 1, 17, 7, 80, 
    3, 25, 2, 36, 4, 57, 1, 72, 7, 76, 0,  6, 6, 44, 8, 28, 5, 95, 
    6, 99, 1, 62, 2, 40, 5, 95, 8,  3, 3, 77, 0,  5, 7, 46, 4, 55, 
    5, 41, 4, 60, 6, 88, 0, 67, 7, 45, 8, 35, 3, 67, 2, 25, 1, 12
  };
  const int q2481[] = {
    9, 9, // Number of jobs and machines
    5, 13, 7, 59, 6, 49, 0,  4, 4, 61, 2, 40, 1, 84, 8, 23, 3, 29, 
    0, 29, 1, 69, 2, 14, 4, 26, 8, 37, 5, 71, 6, 76, 7, 61, 3, 87, 
    7, 64, 3, 35, 8,  3, 2, 79, 4, 78, 1, 33, 6,  3, 0, 82, 5, 17, 
    5, 39, 3, 72, 0,  3, 7, 14, 1, 87, 8, 78, 2, 99, 4,  1, 6, 53, 
    2, 17, 0, 12, 5, 76, 3, 46, 4, 46, 6, 40, 8, 33, 7, 85, 1, 21, 
    3, 71, 2, 21, 7, 70, 5, 40, 1, 89, 4, 74, 8, 22, 0,  3, 6, 38, 
    3, 18, 0, 72, 8, 63, 1, 40, 7, 40, 2, 38, 5, 78, 6, 30, 4, 85, 
    7, 24, 8, 28, 4, 40, 3, 50, 5, 62, 1,  1, 2, 89, 6, 14, 0, 22, 
    5, 51, 8, 28, 0, 28, 7, 97, 3, 55, 2, 97, 1, 74, 4, 90, 6, 94
  };
  const int q2482[] = {
    9, 9, // Number of jobs and machines
    5, 55, 4, 41, 1, 87, 2, 29, 6, 73, 0, 55, 3, 69, 7, 81, 8, 94, 
    8, 52, 7, 81, 4, 62, 2, 88, 0, 16, 3, 55, 6, 23, 5, 95, 1, 94, 
    6, 29, 4, 33, 0, 94, 5, 61, 8, 65, 2, 21, 7, 33, 3, 75, 1, 30, 
    6, 83, 0, 46, 5, 19, 2, 38, 8, 66, 1, 96, 7, 67, 3, 80, 4, 98, 
    0, 37, 7, 89, 6, 60, 3, 54, 5, 77, 2, 72, 4, 79, 1, 58, 8,  4, 
    1, 32, 5, 61, 0, 13, 3, 21, 2, 80, 8, 59, 4, 99, 6, 91, 7, 37, 
    0, 43, 3, 66, 1, 73, 2, 46, 6, 49, 5, 45, 8, 96, 7, 67, 4, 89, 
    8, 93, 4, 90, 7,  9, 5, 67, 1, 52, 0, 85, 2, 87, 3, 32, 6, 99, 
    0, 46, 4, 52, 3, 62, 7,  1, 2,  7, 5, 97, 1, 43, 8, 26, 6, 63
  };
  const int q2483[] = {
    9, 9, // Number of jobs and machines
    5, 18, 2, 60, 7, 37, 6, 21, 4,  7, 1, 94, 8, 85, 0, 77, 3, 18, 
    4, 94, 0, 43, 7, 71, 1, 89, 3, 17, 2, 73, 6, 85, 5, 95, 8, 63, 
    0, 54, 7, 42, 4, 71, 8, 78, 3, 26, 5, 98, 1, 45, 2, 81, 6, 56, 
    5, 46, 3, 94, 1, 56, 7, 43, 6, 13, 0, 31, 8,  5, 4, 60, 2, 25, 
    4, 82, 2, 73, 0, 66, 3, 75, 8, 91, 6, 70, 7,  9, 1, 91, 5, 43, 
    0, 91, 1, 50, 6, 13, 8, 54, 4, 71, 2,  8, 7, 12, 5, 62, 3, 89, 
    6,  6, 4, 35, 0, 38, 5, 19, 2, 77, 7, 35, 8, 35, 3, 19, 1, 49, 
    8,  7, 3, 95, 4, 37, 5, 47, 2, 11, 0,  3, 7, 39, 1, 23, 6, 72, 
    3, 21, 5, 15, 0, 26, 8, 70, 4, 17, 6, 21, 1, 30, 7, 85, 2, 84
  };
  const int q2484[] = {
    9, 9, // Number of jobs and machines
    7, 66, 0, 99, 2, 49, 3, 22, 5, 67, 8, 43, 6, 59, 1, 69, 4, 67, 
    3, 79, 5, 74, 8, 78, 6, 52, 7, 69, 2, 89, 0, 36, 1, 95, 4, 67, 
    7, 88, 0, 51, 4, 73, 1, 21, 8, 65, 2,  2, 5, 66, 3, 65, 6, 26, 
    8, 43, 5, 41, 6, 36, 0, 97, 7, 39, 3, 97, 2, 38, 4, 82, 1, 85, 
    8, 35, 1, 62, 3, 85, 7, 66, 5, 83, 4,  2, 2, 21, 6, 81, 0, 70, 
    4, 42, 0, 12, 1, 32, 5, 98, 8, 38, 2, 61, 7, 70, 3, 66, 6, 26, 
    7, 30, 5, 48, 6,  9, 4, 85, 8, 83, 3, 95, 0, 98, 2, 90, 1,  4, 
    3, 56, 1, 84, 0, 86, 8, 11, 5, 69, 2, 84, 4, 20, 7, 32, 6, 33, 
    3, 61, 7, 66, 8,  5, 0, 77, 1, 83, 2,  7, 5, 61, 6, 33, 4, 10
  };
  const int q2485[] = {
    9, 9, // Number of jobs and machines
    6, 77, 0, 46, 2,  6, 5, 29, 3,  4, 7, 60, 1, 30, 4, 57, 8, 40, 
    8,  7, 4, 86, 3, 52, 2,  4, 1, 94, 5, 66, 0, 39, 6, 41, 7, 37, 
    6, 63, 0, 92, 4, 50, 3, 10, 7, 75, 2, 98, 5, 17, 1, 53, 8, 91, 
    3, 88, 7, 35, 2, 77, 6, 66, 4, 27, 0, 86, 1, 93, 5, 23, 8, 94, 
    5, 58, 4, 52, 0, 58, 1, 97, 6, 45, 8, 88, 7, 16, 3, 99, 2, 78, 
    6, 75, 5, 21, 4, 28, 0, 23, 2,  2, 7, 13, 1, 57, 8, 61, 3, 66, 
    6, 48, 1, 66, 4, 67, 3, 22, 5, 79, 2, 37, 7, 38, 8, 96, 0, 81, 
    6, 25, 2, 61, 5, 87, 0, 93, 8, 53, 4, 73, 3,  2, 7, 36, 1, 17, 
    8, 88, 7, 36, 1, 17, 2, 67, 6, 45, 4, 79, 0, 82, 3, 99, 5,  2
  };
  const int q2486[] = {
    9, 9, // Number of jobs and machines
    8, 77, 4, 53, 0, 99, 1, 17, 5, 50, 2, 34, 7, 71, 3, 68, 6, 73, 
    5, 77, 2, 99, 3, 84, 6, 34, 1,  8, 8, 73, 0, 48, 4, 99, 7, 55, 
    4, 60, 0, 46, 3, 67, 6, 88, 2, 32, 8, 49, 1, 99, 5,  6, 7, 19, 
    4, 67, 5, 42, 7, 33, 1, 98, 3, 57, 6, 18, 0, 84, 2, 62, 8, 43, 
    1, 26, 5, 55, 8, 21, 6, 76, 7, 94, 0, 67, 2,  5, 4, 29, 3, 52, 
    0, 84, 5, 28, 4, 41, 6, 17, 7, 87, 3, 85, 8, 31, 2, 87, 1, 22, 
    5, 84, 4,  1, 8, 44, 6, 38, 0, 89, 3, 44, 2,  1, 1, 63, 7, 41, 
    8, 38, 6, 36, 7, 89, 1, 80, 3, 66, 0, 19, 2,  1, 5, 68, 4, 41, 
    6, 28, 0, 71, 2, 81, 8, 88, 5,  6, 7,  6, 1, 70, 4, 92, 3, 97
  };
  const int q2487[] = {
    9, 9, // Number of jobs and machines
    0, 95, 4, 35, 1, 11, 7, 73, 2, 85, 8,  8, 5, 12, 6, 54, 3, 39, 
    0, 40, 4,  7, 3,  1, 6, 91, 1, 10, 5,  7, 8, 35, 7, 77, 2,  9, 
    6, 83, 7, 23, 2, 15, 3, 84, 5, 91, 1, 39, 0, 94, 4, 30, 8, 11, 
    7, 13, 1, 68, 8, 67, 0,  7, 6, 56, 2, 37, 3, 24, 4, 39, 5,  7, 
    0, 46, 6, 76, 2, 14, 7, 33, 4, 28, 3, 18, 1, 82, 8, 98, 5, 41, 
    4, 16, 2,  2, 0, 49, 3,  5, 5, 81, 1, 73, 8, 60, 6, 47, 7, 76, 
    8, 30, 1, 66, 2, 89, 7, 60, 3,  2, 4, 90, 6, 44, 0, 72, 5, 81, 
    1,  4, 8, 95, 0, 30, 4, 82, 5, 44, 3, 82, 6, 27, 7, 18, 2, 39, 
    6, 42, 7, 63, 0, 12, 3, 51, 5, 28, 2, 43, 4, 22, 8, 86, 1,  9
  };
  const int q2488[] = {
    9, 9, // Number of jobs and machines
    2, 35, 8, 27, 6, 64, 3, 56, 1, 46, 0, 51, 5, 40, 7, 46, 4, 42, 
    6, 22, 2,  3, 8, 73, 7, 29, 0, 92, 5, 49, 4, 23, 3, 89, 1, 37, 
    6, 27, 5, 88, 8,  8, 1, 48, 0, 86, 3, 81, 2, 57, 7, 23, 4, 12, 
    1, 18, 0, 68, 6, 79, 7, 71, 4, 55, 8, 54, 3, 68, 2,  8, 5, 83, 
    4, 81, 0, 32, 6, 43, 5, 66, 1, 74, 3, 88, 8, 67, 7, 42, 2, 13, 
    0,  8, 5, 77, 1,  5, 3, 15, 4, 43, 6, 87, 8, 84, 7, 54, 2, 19, 
    4, 17, 5, 54, 8, 37, 2,  5, 3, 35, 0, 91, 6, 37, 1, 62, 7, 51, 
    6, 31, 3, 76, 7, 64, 0, 68, 8, 94, 5, 63, 1, 98, 2, 63, 4, 68, 
    8, 61, 1,  3, 5, 56, 4, 71, 6, 94, 7, 84, 0, 56, 3, 59, 2, 96
  };
  const int q2489[] = {
    9, 9, // Number of jobs and machines
    3,  9, 0, 72, 2, 32, 7, 21, 6, 11, 1, 14, 8,  7, 4, 89, 5, 84, 
    5, 26, 8, 69, 7, 13, 6, 42, 3, 22, 0, 47, 1, 52, 4, 34, 2, 55, 
    3, 42, 0, 88, 4,  8, 6,  4, 7, 18, 1, 21, 8, 31, 2, 86, 5, 52, 
    2,  7, 5, 44, 0, 58, 7, 80, 4, 42, 3, 89, 6, 78, 1, 27, 8, 25, 
    7, 72, 5, 37, 4, 45, 0, 29, 8, 39, 2, 69, 3, 21, 6, 84, 1, 74, 
    6, 74, 8, 45, 5, 55, 1, 82, 7, 62, 4, 14, 3, 45, 2, 73, 0, 68, 
    5, 44, 6, 94, 8, 34, 2, 77, 4, 91, 0, 11, 3, 19, 1, 65, 7, 29, 
    3, 77, 7, 43, 2, 69, 4, 54, 6, 86, 5, 14, 0, 99, 8, 47, 1, 39, 
    5, 57, 8, 33, 3, 87, 0, 15, 1, 93, 2, 50, 7, 52, 4, 62, 6, 32
  };
  const int q2490[] = {
    9, 9, // Number of jobs and machines
    8, 44, 1, 33, 7, 87, 0, 49, 6,  8, 4, 10, 3, 33, 5, 50, 2, 63, 
    3, 82, 0, 24, 7, 54, 1,  5, 5, 23, 4, 44, 8, 15, 2, 58, 6, 17, 
    8, 92, 7, 57, 2, 56, 0, 49, 4, 84, 1, 85, 3, 28, 6, 60, 5, 93, 
    1, 37, 0,  3, 5, 50, 6, 33, 7, 22, 3, 99, 4, 74, 8, 45, 2, 93, 
    4, 97, 8, 77, 0, 91, 7, 87, 2, 43, 6,  1, 3, 16, 5, 63, 1, 33, 
    5, 83, 7, 20, 4, 11, 2, 44, 0, 11, 6, 46, 8, 11, 1, 88, 3, 32, 
    4, 25, 2, 69, 1,  6, 3, 10, 5, 16, 6, 57, 8, 27, 7, 28, 0, 26, 
    4, 94, 8, 62, 7,  6, 3, 20, 2, 19, 0, 34, 1, 94, 5, 45, 6, 71, 
    5, 66, 4, 86, 6, 69, 2, 73, 1, 66, 7, 27, 3, 66, 8, 80, 0, 28
  };
  const int q2491[] = {
    9, 9, // Number of jobs and machines
    4, 11, 3,  5, 6, 46, 0, 47, 2, 52, 1, 80, 5, 36, 8, 18, 7, 61, 
    6, 48, 0, 93, 1, 46, 7, 69, 5, 89, 8, 32, 3, 93, 2, 95, 4, 94, 
    0, 59, 5, 40, 7, 36, 1,  3, 2,  1, 6, 97, 8, 88, 3, 32, 4, 80, 
    3, 59, 5, 31, 8, 58, 2, 96, 0, 27, 7, 10, 6, 83, 4, 38, 1, 93, 
    2, 89, 8, 92, 6, 34, 1, 55, 0, 46, 5, 40, 4, 89, 7, 57, 3, 88, 
    7, 56, 6, 77, 8, 94, 4,  6, 2, 88, 0, 46, 1, 68, 3, 62, 5, 68, 
    7, 34, 1, 53, 3, 83, 2, 71, 6, 73, 4, 55, 8,  5, 0, 49, 5, 10, 
    8, 54, 3, 43, 0, 47, 7, 35, 1,  5, 6, 60, 4, 86, 2, 24, 5, 71, 
    3, 96, 6, 51, 4, 31, 7, 13, 2,  7, 0, 40, 8, 76, 5, 62, 1,  2
  };
  const int q2492[] = {
    9, 9, // Number of jobs and machines
    2, 12, 7, 28, 6, 99, 5, 11, 0, 79, 8, 65, 1,  3, 4, 75, 3, 90, 
    2, 85, 3, 98, 6, 22, 8, 90, 7, 44, 0, 54, 5, 24, 4, 78, 1, 52, 
    0, 66, 4, 70, 6, 66, 5, 80, 8, 39, 1, 31, 2, 69, 7, 92, 3, 42, 
    8, 71, 3, 19, 7, 88, 1, 62, 6, 98, 0, 15, 4, 33, 2, 31, 5, 30, 
    3, 74, 5, 75, 0, 39, 2,  7, 4, 11, 8,  8, 7,  3, 1, 69, 6,  9, 
    3, 21, 4, 72, 0, 23, 6, 95, 8, 39, 7, 27, 1, 96, 2, 45, 5, 66, 
    4, 83, 6, 70, 2, 84, 5, 30, 7, 63, 0, 36, 8, 70, 1, 12, 3, 59, 
    5, 11, 1, 64, 2, 61, 0, 17, 4, 67, 8, 40, 6, 67, 7, 96, 3, 49, 
    0, 95, 2, 28, 8, 61, 7, 56, 5, 51, 1, 62, 6, 90, 3, 25, 4, 94
  };
  const int q2493[] = {
    9, 9, // Number of jobs and machines
    1,  3, 4, 35, 3,  3, 8, 72, 5, 88, 0, 73, 2,  8, 6,  6, 7, 80, 
    3, 39, 2,  6, 7, 61, 0, 13, 4,  9, 5, 11, 6, 86, 8, 79, 1, 79, 
    5, 57, 4, 77, 8, 40, 6, 59, 7, 78, 2, 16, 1, 55, 3,  7, 0, 38, 
    1, 32, 0, 10, 8, 26, 2, 54, 6, 95, 7, 93, 3, 27, 5,  7, 4, 94, 
    7, 14, 8, 45, 5,  2, 3, 74, 1, 66, 6, 61, 2, 47, 0, 11, 4, 45, 
    6, 71, 1, 29, 0, 54, 8,  1, 7,  4, 4, 90, 2, 25, 5, 25, 3, 22, 
    3, 38, 8, 43, 7, 25, 6, 88, 5, 29, 2, 64, 1, 52, 0, 86, 4, 17, 
    8, 70, 0, 93, 2, 55, 7,  4, 1, 58, 4, 27, 6, 24, 3, 10, 5, 79, 
    6, 96, 1, 29, 4, 19, 5, 75, 3,  4, 8, 10, 2, 55, 0, 29, 7, 91
  };
  const int q2494[] = {
    9, 9, // Number of jobs and machines
    1, 87, 7, 92, 3, 16, 2, 31, 8, 67, 6,  3, 0, 43, 4, 64, 5, 81, 
    8, 99, 5, 45, 7, 94, 3, 23, 0, 87, 1, 68, 6, 43, 4, 28, 2, 66, 
    5, 99, 7, 56, 3, 18, 8, 51, 6, 87, 2, 19, 0, 14, 4, 26, 1, 24, 
    8, 75, 0, 89, 7, 39, 4, 48, 3, 75, 2, 73, 5, 76, 1, 53, 6, 58, 
    8, 39, 4, 89, 3, 69, 6, 75, 2, 29, 1, 39, 0, 24, 5, 29, 7,  3, 
    0, 44, 2, 54, 1, 95, 6,  8, 4, 47, 5, 38, 8, 56, 3,  2, 7, 34, 
    1, 76, 4, 68, 8, 89, 7, 11, 0, 41, 2, 55, 3, 56, 6, 50, 5,  1, 
    5, 39, 6, 51, 8, 90, 2, 93, 0, 74, 3, 30, 4, 81, 7,  2, 1, 96, 
    5, 91, 6,  5, 2, 21, 3, 58, 1, 76, 8, 59, 0, 51, 7, 19, 4, 49
  };
  const int q2495[] = {
    9, 9, // Number of jobs and machines
    4, 54, 1, 94, 0, 32, 3, 18, 5, 99, 2, 19, 8, 70, 6, 62, 7,  5, 
    4, 92, 1, 75, 8, 95, 7,  1, 2, 52, 0, 27, 6, 64, 3, 29, 5, 15, 
    6, 68, 4, 96, 0, 81, 7, 21, 3, 41, 8, 93, 5, 97, 2, 49, 1, 87, 
    4, 12, 6, 83, 3, 55, 2, 89, 5, 94, 8, 62, 0, 16, 1,  4, 7, 34, 
    2, 83, 5, 75, 1, 99, 8, 14, 3, 65, 0, 88, 6, 30, 7, 82, 4, 61, 
    1,  7, 7, 22, 6, 58, 2, 65, 0, 16, 3, 12, 5, 84, 4, 71, 8, 33, 
    1, 82, 2, 98, 8,  7, 3, 31, 5, 16, 0, 18, 7, 73, 6, 61, 4, 87, 
    0, 55, 4, 16, 6,  7, 2, 69, 7, 55, 8, 77, 3, 18, 1, 28, 5, 46, 
    1, 14, 8, 74, 7, 99, 0, 84, 4, 28, 6, 58, 2, 94, 3, 44, 5, 69
  };
  const int q2496[] = {
    9, 9, // Number of jobs and machines
    8,  6, 6, 89, 2,  4, 7, 95, 0, 77, 5, 68, 1, 36, 3, 27, 4, 72, 
    8, 39, 1, 39, 6, 62, 7, 35, 5, 92, 2,  5, 3, 16, 4, 86, 0, 63, 
    7, 76, 2, 28, 0, 43, 6, 60, 1, 44, 3, 26, 4, 56, 8, 88, 5, 62, 
    0, 61, 2, 77, 8, 57, 4, 54, 6, 43, 3, 12, 5, 74, 7, 56, 1, 34, 
    2, 11, 1, 98, 5, 94, 0, 83, 7, 12, 8, 83, 3, 72, 6, 52, 4, 14, 
    8, 18, 5, 48, 3, 77, 6, 31, 2, 31, 0, 61, 7, 27, 4, 49, 1, 16, 
    7, 99, 6, 34, 2, 16, 1,  2, 8, 19, 5, 75, 0, 20, 3, 47, 4, 25, 
    8, 88, 7, 11, 4, 58, 5, 75, 2, 26, 3, 57, 6, 79, 0, 96, 1, 82, 
    7, 20, 4, 32, 0,  2, 1, 28, 8, 46, 6, 42, 3, 98, 5, 46, 2, 75
  };
  const int q2497[] = {
    9, 9, // Number of jobs and machines
    8, 81, 4, 61, 1, 11, 2, 52, 5, 30, 7, 35, 0, 25, 6, 81, 3, 53, 
    7, 53, 8, 23, 6, 93, 2, 58, 0, 32, 4, 45, 1, 28, 5, 63, 3, 24, 
    3, 41, 5, 78, 0,  4, 8, 58, 1, 30, 2, 84, 7, 95, 6, 39, 4, 88, 
    2, 30, 7, 82, 4, 40, 8, 63, 1, 98, 0, 67, 5, 37, 6, 16, 3, 35, 
    3, 64, 8,  3, 5, 82, 4, 66, 6, 96, 0, 76, 2, 77, 1, 94, 7, 15, 
    7, 52, 3, 11, 0, 11, 6, 98, 8, 98, 4, 82, 2, 98, 1, 37, 5, 30, 
    8, 53, 6, 81, 0, 91, 7, 62, 4, 14, 2, 23, 5,  9, 3, 48, 1,  2, 
    4, 82, 0, 93, 8, 83, 3, 29, 2,  1, 7, 37, 6, 89, 1, 73, 5, 47, 
    1,  3, 8,  1, 3,  7, 7, 87, 4, 29, 6, 46, 5, 43, 0, 34, 2, 15
  };
  const int q2498[] = {
    9, 9, // Number of jobs and machines
    8, 75, 1, 51, 5, 40, 0, 39, 3, 33, 7, 85, 2, 65, 4, 11, 6, 63, 
    4, 97, 3, 44, 0, 63, 6, 63, 2, 59, 5,  7, 8, 92, 1, 26, 7, 81, 
    4,  8, 6,  4, 1, 33, 8, 91, 5,  3, 3, 17, 7, 38, 2, 89, 0,  5, 
    4, 39, 6, 88, 7, 78, 5, 31, 1,  5, 2, 28, 0, 17, 8, 91, 3, 57, 
    2, 87, 8, 36, 4, 32, 7, 91, 1, 78, 0, 20, 5, 46, 3, 85, 6, 95, 
    2, 46, 8, 18, 7, 18, 1, 11, 4, 90, 0, 90, 5, 80, 6, 57, 3, 96, 
    7, 59, 6,  5, 2, 28, 1, 33, 8, 82, 3, 29, 4, 75, 5, 66, 0, 43, 
    1, 24, 7, 45, 5, 87, 2, 76, 6, 26, 4, 56, 0, 22, 8, 89, 3, 73, 
    6, 88, 8, 79, 3, 58, 1, 25, 4, 92, 0, 28, 7, 19, 2, 69, 5, 91
  };
  const int q2499[] = {
    9, 9, // Number of jobs and machines
    1, 51, 7, 14, 2, 68, 5, 55, 4, 81, 0, 88, 3,  1, 8, 41, 6, 24, 
    2, 22, 6, 17, 5, 86, 4, 37, 3, 65, 0, 92, 1, 33, 8, 90, 7, 29, 
    7, 89, 1, 40, 3,  5, 8, 88, 0, 91, 5, 14, 4, 47, 2, 97, 6,  6, 
    8, 87, 3, 22, 2, 36, 7, 16, 5, 30, 6, 86, 1, 57, 4, 25, 0, 60, 
    1, 36, 6, 78, 7, 59, 2, 18, 8, 69, 4, 59, 5, 64, 3, 74, 0, 62, 
    3, 66, 8, 10, 2, 69, 1,  2, 6, 81, 0, 81, 5, 13, 4, 82, 7, 86, 
    4, 30, 7, 65, 0, 94, 3, 20, 5, 18, 6, 57, 1, 46, 8, 12, 2, 88, 
    5, 90, 4, 53, 3, 99, 1, 50, 2, 24, 6, 64, 8,  5, 7, 93, 0,  5, 
    1, 36, 0, 60, 7, 62, 4, 40, 8, 30, 6, 93, 5, 93, 2,  7, 3, 88
  };
  const int q2500[] = {
    9, 9, // Number of jobs and machines
    8, 55, 6, 29, 4,  2, 2, 67, 3, 67, 7, 86, 0, 21, 5, 41, 1, 13, 
    6, 32, 4, 75, 7, 83, 1, 93, 3, 45, 8, 10, 2, 52, 0, 75, 5,  6, 
    0, 27, 5,  5, 2, 61, 1, 38, 8,  4, 6, 50, 3,  3, 7, 13, 4, 95, 
    8, 85, 7, 20, 0, 76, 1, 80, 6, 11, 2, 67, 3, 32, 5, 55, 4, 39, 
    0, 68, 1, 18, 6, 56, 7, 50, 2, 70, 5, 97, 8, 68, 4, 92, 3,  4, 
    3, 27, 2, 36, 5, 91, 7,  9, 1, 48, 6, 38, 0, 29, 4, 91, 8, 89, 
    1,  9, 6, 65, 2, 19, 5, 74, 4, 90, 3, 17, 0, 89, 7, 18, 8, 28, 
    5, 53, 1, 73, 8, 38, 0, 54, 4, 22, 6, 47, 2,  2, 7, 94, 3, 69, 
    5, 37, 1, 54, 8, 23, 2, 93, 0, 64, 3, 14, 4, 33, 6, 40, 7, 87
  };
  const int q2501[] = {
    9, 9, // Number of jobs and machines
    8, 24, 4, 44, 2, 92, 1, 74, 5, 86, 6, 68, 3, 57, 7, 42, 0, 27, 
    8, 50, 3,  6, 2, 23, 7, 29, 0, 63, 1, 63, 6, 60, 4, 13, 5, 72, 
    6, 42, 7, 29, 8, 18, 3,  6, 5, 30, 4, 96, 1, 84, 2, 31, 0, 44, 
    4, 25, 0, 78, 8, 91, 2,  8, 6, 32, 5,  6, 1, 26, 7,  2, 3, 23, 
    6, 65, 5,  3, 8, 41, 1, 19, 0, 20, 4, 29, 3, 42, 2, 90, 7, 52, 
    2, 41, 1, 43, 0,  3, 3, 82, 5, 20, 6, 92, 7, 50, 8, 14, 4, 52, 
    2, 57, 5, 36, 0, 49, 3, 45, 4, 73, 7, 30, 6, 52, 8, 86, 1, 57, 
    2, 94, 1, 99, 4, 75, 6, 38, 8, 40, 7,  2, 3, 13, 5, 88, 0, 44, 
    5, 13, 2, 75, 4, 38, 7, 28, 3, 51, 1, 23, 8, 41, 6, 59, 0, 13
  };
  const int q2502[] = {
    9, 9, // Number of jobs and machines
    2,  5, 7, 29, 3, 34, 1, 61, 8, 70, 5, 81, 6, 85, 4, 67, 0, 95, 
    1, 39, 2, 51, 8, 37, 4, 81, 6, 22, 7, 85, 5, 25, 0, 75, 3, 59, 
    5, 95, 1, 93, 2, 96, 8, 31, 3,  2, 6, 88, 7, 84, 0, 59, 4, 18, 
    1, 45, 2, 56, 0, 69, 6, 24, 4, 69, 8, 68, 7, 84, 5, 73, 3, 78, 
    3,  5, 6, 83, 4, 17, 2, 72, 0, 68, 7, 16, 5, 80, 1, 49, 8, 14, 
    6, 99, 8, 22, 1, 43, 0, 43, 7,  7, 5, 59, 3, 23, 4, 74, 2, 51, 
    3, 44, 8, 99, 2, 80, 4, 34, 7, 72, 5, 55, 6, 34, 0, 93, 1, 78, 
    8, 43, 1, 50, 4, 44, 7, 40, 0, 87, 2, 30, 6, 63, 5, 29, 3, 74, 
    5, 20, 4, 75, 2, 50, 3, 36, 7, 51, 8, 52, 6, 61, 0, 46, 1,  5
  };
  const int q2503[] = {
    9, 9, // Number of jobs and machines
    5,  1, 0, 87, 3, 39, 8, 12, 7, 27, 4, 63, 2,  3, 6, 65, 1, 84, 
    6, 50, 1, 64, 2, 65, 8, 84, 0, 93, 7, 54, 4, 91, 3, 36, 5, 21, 
    7, 55, 4, 90, 0, 19, 8, 56, 1, 84, 5, 12, 3, 61, 2, 25, 6, 93, 
    3, 94, 2, 99, 6, 27, 1, 53, 8, 51, 5, 70, 4, 37, 7, 56, 0, 15, 
    5, 70, 1, 25, 3, 94, 0, 56, 7, 53, 6, 21, 4, 40, 2, 43, 8, 74, 
    5, 29, 1, 45, 3, 52, 8, 85, 2, 79, 7, 81, 0, 35, 6, 16, 4, 15, 
    3, 25, 8, 62, 1,  3, 0, 16, 5, 15, 2, 14, 4, 44, 6, 99, 7, 40, 
    2, 46, 3, 85, 8, 52, 4, 67, 5, 93, 6, 45, 7, 38, 0, 37, 1, 35, 
    8, 84, 4, 23, 2, 48, 1, 93, 6, 56, 3, 13, 0, 99, 7, 69, 5, 99
  };
  const int q2504[] = {
    9, 9, // Number of jobs and machines
    7, 56, 5, 43, 3,  5, 1, 76, 6, 57, 8, 92, 2, 83, 0, 16, 4, 74, 
    0, 42, 2, 19, 7, 49, 8, 61, 1, 20, 6,  9, 4, 50, 5, 48, 3, 48, 
    0, 95, 1, 73, 2, 79, 7, 80, 4, 63, 3, 50, 8, 98, 6, 73, 5, 51, 
    5, 49, 7, 76, 0, 30, 8, 36, 3, 48, 2, 44, 6, 94, 1, 15, 4, 14, 
    0,  7, 1, 76, 5, 68, 2, 63, 4,  9, 6, 85, 7, 14, 3, 74, 8, 14, 
    5, 57, 1, 48, 7, 46, 0, 11, 2, 30, 3, 59, 4, 67, 8, 49, 6,  3, 
    7, 41, 4, 44, 1, 28, 8, 61, 3, 57, 6, 47, 2, 68, 0, 87, 5, 89, 
    7, 88, 5, 96, 1, 66, 0, 77, 3, 82, 4, 75, 2,  5, 8, 28, 6, 36, 
    8, 53, 2, 32, 0, 94, 7, 33, 6, 65, 5,  8, 1, 92, 3, 98, 4, 42
  };
  const int q2505[] = {
    9, 9, // Number of jobs and machines
    3,  9, 7, 87, 5, 11, 8, 60, 0, 38, 4, 72, 2, 79, 1, 48, 6, 54, 
    7,  1, 5, 78, 4, 90, 6, 88, 0, 81, 2, 84, 8, 85, 3, 89, 1, 88, 
    8, 57, 3, 59, 1, 97, 7, 44, 5, 75, 2, 99, 0, 94, 4, 68, 6, 81, 
    6, 52, 5, 73, 3, 77, 8, 67, 4, 62, 7, 19, 2, 90, 0, 92, 1, 67, 
    3, 53, 1, 64, 0, 29, 5, 67, 6, 97, 4, 21, 8, 67, 7, 41, 2, 27, 
    3, 70, 7, 70, 8, 51, 0, 97, 1, 99, 4, 66, 6, 96, 2,  1, 5, 76, 
    2, 73, 8, 23, 4, 81, 5, 96, 0, 23, 6, 71, 7,  8, 3, 17, 1,  7, 
    3, 93, 7, 58, 1, 63, 8, 65, 6, 32, 0, 48, 5, 41, 4,  4, 2, 71, 
    5, 23, 4, 39, 6,  7, 3, 92, 1, 76, 7, 96, 0, 17, 8, 52, 2, 88
  };
  const int q2506[] = {
    9, 9, // Number of jobs and machines
    8, 45, 7, 62, 1, 15, 2, 95, 0, 50, 3, 30, 6, 43, 5, 95, 4, 68, 
    5, 49, 2, 11, 6, 74, 3, 65, 7, 63, 4, 45, 1,  7, 8, 55, 0, 87, 
    3, 18, 1, 97, 7, 86, 6, 48, 8, 32, 2, 61, 0, 41, 4, 93, 5, 79, 
    2, 83, 7,  3, 4, 15, 6, 84, 0, 26, 8, 60, 5, 95, 3, 47, 1,  6, 
    2, 60, 3, 33, 6, 50, 4, 52, 1, 64, 5,  4, 8, 67, 0, 91, 7, 75, 
    6, 74, 8, 70, 5, 44, 7, 89, 4, 79, 3, 39, 2, 77, 0, 56, 1, 65, 
    2, 82, 4, 33, 0, 88, 7, 14, 5, 56, 8, 79, 6,  7, 1, 68, 3, 32, 
    1, 37, 3, 82, 5, 83, 0,  4, 4, 32, 2, 32, 7,  9, 8, 97, 6, 56, 
    5, 73, 2, 67, 6, 22, 3, 40, 7, 69, 1, 45, 8, 56, 4, 51, 0, 32
  };
  const int q2507[] = {
    9, 9, // Number of jobs and machines
    8, 99, 4, 34, 7, 92, 3, 94, 6, 60, 5, 54, 1, 74, 0, 14, 2, 67, 
    6, 88, 1, 71, 7, 10, 3, 51, 8, 86, 0, 60, 4, 26, 5, 95, 2, 18, 
    1, 66, 2,  2, 5, 99, 3, 44, 4, 88, 0, 81, 8, 18, 6, 12, 7, 32, 
    2, 47, 1, 99, 8, 45, 7, 65, 3,  7, 4, 34, 5, 39, 0, 47, 6, 14, 
    5, 69, 4, 60, 6, 28, 3, 55, 0, 95, 7, 91, 1, 16, 2, 76, 8, 96, 
    8, 40, 5, 53, 7, 91, 2, 69, 0, 74, 4, 67, 1, 83, 3, 24, 6, 29, 
    1, 26, 8, 99, 3, 45, 5, 65, 0, 29, 2, 99, 6, 38, 4, 97, 7, 39, 
    3, 87, 5, 55, 6, 74, 1, 45, 4, 63, 8, 96, 0, 89, 2, 18, 7, 55, 
    8, 43, 6, 56, 4, 44, 1, 19, 5, 34, 3,  3, 2, 36, 7, 95, 0, 10
  };
  const int q2508[] = {
    9, 9, // Number of jobs and machines
    3, 23, 1, 88, 6, 26, 8, 15, 5, 76, 0, 48, 7, 55, 2, 64, 4, 30, 
    6, 38, 2, 86, 3, 64, 1, 91, 0, 89, 8, 43, 7, 47, 4, 60, 5, 31, 
    0, 83, 4, 31, 3, 31, 8, 64, 5, 92, 6, 61, 7, 68, 2, 16, 1, 32, 
    8, 86, 0, 90, 4,  6, 7, 62, 5, 42, 2, 64, 6, 49, 3, 18, 1, 23, 
    0, 31, 6, 93, 2, 83, 7, 81, 5, 18, 1, 17, 8, 60, 4, 66, 3, 94, 
    8, 13, 1, 20, 2, 51, 7, 57, 3, 20, 0, 76, 6, 27, 4,  7, 5, 33, 
    0, 70, 5, 77, 3, 41, 4, 35, 1, 75, 8,  4, 7, 68, 2, 14, 6, 80, 
    3,  2, 8, 17, 5, 26, 1, 96, 6, 84, 7, 78, 4, 68, 2, 77, 0, 19, 
    0, 51, 8, 41, 5, 66, 6, 56, 3, 11, 4, 86, 1, 23, 2, 54, 7, 97
  };
  const int q2509[] = {
    9, 9, // Number of jobs and machines
    2, 59, 7,  8, 4, 69, 8,  7, 5, 96, 0, 33, 3, 61, 6, 66, 1, 96, 
    8, 61, 5, 82, 4,  9, 3, 46, 2, 93, 6, 12, 7, 23, 1, 85, 0, 67, 
    1, 49, 8,  6, 4, 22, 7, 68, 2, 37, 6, 49, 0, 97, 3, 44, 5, 43, 
    0, 23, 6, 26, 3, 44, 5, 53, 2, 90, 4, 72, 7, 18, 8, 19, 1, 96, 
    3, 39, 5, 33, 8, 35, 7, 72, 2, 39, 6, 98, 4, 28, 0, 64, 1, 72, 
    5, 84, 3,  8, 6, 14, 7,  1, 4, 37, 1, 94, 0, 24, 8, 50, 2, 33, 
    8, 30, 5,  5, 3, 23, 2, 75, 0, 10, 6, 73, 7, 46, 4, 25, 1, 49, 
    8, 49, 1, 75, 4, 21, 2, 47, 6, 91, 0, 97, 5, 89, 3,  7, 7, 96, 
    3, 11, 0, 57, 8, 67, 1, 68, 4,  1, 7, 35, 6, 75, 2, 10, 5, 44
  };
  const int q2510[] = {
    9, 9, // Number of jobs and machines
    2, 53, 5, 87, 6, 81, 4, 84, 0, 30, 1, 66, 8, 84, 3, 77, 7, 81, 
    1, 46, 0, 51, 4, 60, 2, 50, 3, 55, 5, 34, 8, 81, 7, 53, 6, 80, 
    4, 64, 7, 23, 3,  8, 2,  2, 0, 94, 5, 68, 8, 64, 6, 45, 1, 54, 
    6, 70, 2,  2, 7, 73, 8, 35, 3, 80, 4,  4, 1, 81, 0, 13, 5, 15, 
    4, 33, 1, 34, 3, 28, 7, 31, 6,  2, 2, 40, 0, 94, 5, 75, 8, 16, 
    8, 58, 4, 84, 5, 59, 0, 37, 2,  4, 3, 60, 6, 71, 1, 45, 7, 98, 
    1, 13, 5, 27, 2, 53, 6, 40, 3, 40, 4, 48, 0, 34, 8, 70, 7, 65, 
    3, 44, 4, 65, 8, 75, 0, 97, 6, 59, 2, 68, 1, 18, 7, 70, 5, 50, 
    3, 45, 2, 93, 6, 40, 7, 31, 0, 39, 8, 99, 1, 35, 4, 65, 5, 48
  };
  const int q2511[] = {
    9, 9, // Number of jobs and machines
    1, 18, 8,  9, 5, 14, 6, 87, 2, 61, 4,  8, 0, 73, 3, 68, 7,  1, 
    2, 32, 0, 63, 3, 85, 1, 39, 6, 41, 8, 62, 5, 41, 4, 91, 7, 66, 
    3, 79, 4, 56, 8, 15, 0, 50, 6, 25, 1, 17, 7, 77, 5, 74, 2, 18, 
    1, 60, 5, 91, 0, 49, 6, 92, 4, 89, 3, 76, 8,  3, 7, 19, 2, 47, 
    8, 96, 0, 26, 7, 44, 3, 16, 1, 31, 2, 34, 6, 31, 5, 52, 4, 97, 
    6, 76, 2,  6, 8, 73, 4, 70, 7, 66, 5, 89, 0, 63, 1, 71, 3, 48, 
    1, 96, 8, 61, 3, 63, 7, 24, 6, 48, 4, 17, 2, 43, 5, 14, 0, 35, 
    3, 11, 1,  4, 7, 17, 4, 32, 6, 80, 2, 71, 5, 61, 0, 54, 8, 93, 
    8, 32, 4, 26, 3, 18, 0, 46, 1, 90, 6, 85, 5,  6, 2, 15, 7, 43
  };
  const int q2512[] = {
    9, 9, // Number of jobs and machines
    5, 30, 6,  6, 8, 64, 3,  7, 2, 27, 7, 21, 1, 35, 4,  7, 0, 34, 
    6, 96, 5, 36, 7, 76, 4, 69, 2, 31, 0, 24, 1, 32, 8, 11, 3, 60, 
    8, 56, 0, 97, 7,  4, 4, 52, 3, 59, 2, 39, 1, 48, 6, 71, 5, 27, 
    4, 28, 8, 36, 3, 48, 0, 65, 6, 36, 1, 84, 7, 92, 2, 91, 5,  8, 
    2, 26, 4, 64, 3,  3, 8,  9, 5,  6, 7, 63, 0, 22, 6, 71, 1, 84, 
    3, 95, 8, 83, 7, 91, 4, 19, 2, 89, 5, 95, 6, 50, 0, 11, 1, 93, 
    3, 16, 2, 25, 8, 19, 5, 18, 4, 11, 6, 45, 0,  3, 1, 37, 7, 27, 
    0, 32, 4, 19, 2, 50, 1, 48, 3, 31, 7, 91, 5, 47, 8, 92, 6, 31, 
    2,  8, 8, 63, 0, 30, 7, 85, 4, 88, 3, 30, 5, 65, 6, 16, 1, 39
  };
  const int q2513[] = {
    9, 9, // Number of jobs and machines
    6, 57, 0, 67, 2, 77, 4, 33, 1, 85, 5, 95, 8, 81, 7, 63, 3, 40, 
    8, 37, 5, 63, 1, 30, 2, 47, 4, 86, 0,  9, 6, 24, 3, 45, 7, 61, 
    0, 37, 5, 50, 2, 46, 6, 56, 8, 95, 1, 10, 3, 34, 7, 10, 4, 19, 
    7, 21, 1, 20, 3, 97, 5, 65, 0, 48, 8, 43, 2, 44, 4, 25, 6, 57, 
    0, 67, 1, 16, 4,  5, 6, 15, 3, 43, 7, 12, 2, 59, 5, 74, 8, 21, 
    8,  2, 0, 90, 2, 89, 4, 75, 6, 50, 7, 43, 3, 36, 5, 90, 1, 88, 
    3,  9, 7, 12, 2, 82, 5, 13, 8, 83, 4, 19, 0, 51, 1, 67, 6, 65, 
    5, 86, 4, 60, 0,  1, 7, 54, 3, 75, 8, 92, 1, 33, 6, 44, 2, 46, 
    0, 18, 3, 16, 5, 10, 2, 38, 1,  5, 8, 15, 4, 47, 6, 28, 7, 95
  };
  const int q2514[] = {
    9, 9, // Number of jobs and machines
    4, 99, 1, 56, 7, 29, 6, 96, 5, 94, 8, 74, 0, 76, 3, 31, 2, 76, 
    0, 75, 4, 73, 2, 99, 6, 93, 3, 21, 1, 66, 8, 60, 7, 47, 5,  6, 
    6, 45, 8, 95, 4, 68, 5, 54, 7, 43, 3, 55, 2, 62, 0, 81, 1, 40, 
    1, 70, 7, 58, 0, 30, 3, 93, 5, 37, 8, 47, 4, 93, 2, 76, 6, 26, 
    8, 54, 0, 98, 7, 51, 1, 46, 3, 19, 5, 86, 4, 60, 6, 39, 2, 63, 
    6, 76, 3, 37, 2, 12, 7, 81, 1, 78, 0, 47, 8, 58, 5, 22, 4, 23, 
    3, 45, 6, 21, 0, 86, 2, 18, 4, 56, 7, 27, 8, 67, 5, 51, 1, 94, 
    6, 93, 2, 57, 0, 73, 8, 98, 7, 53, 1, 44, 4, 29, 5, 66, 3, 80, 
    7, 57, 1,  2, 6, 11, 4, 17, 0, 59, 2, 48, 3, 50, 5, 72, 8, 62
  };
  const int q2515[] = {
    9, 9, // Number of jobs and machines
    4, 82, 8,  5, 2, 12, 3, 43, 1, 66, 7, 75, 0, 32, 5,  1, 6, 54, 
    0, 23, 4, 21, 6, 24, 2, 60, 1, 52, 5, 89, 8, 52, 7, 25, 3, 32, 
    6, 31, 3, 74, 2, 45, 5, 39, 4, 98, 7, 57, 8, 46, 1, 29, 0, 57, 
    5, 44, 0, 25, 3, 52, 4, 70, 8, 26, 6, 96, 2, 75, 7, 66, 1, 47, 
    2, 86, 8, 14, 1, 23, 5, 58, 6,  7, 4, 99, 3, 12, 0, 52, 7, 55, 
    2, 95, 3,  3, 5, 69, 4, 19, 0, 67, 8, 95, 6, 76, 1, 54, 7, 79, 
    3, 29, 1, 13, 4, 43, 5, 98, 8, 56, 0, 48, 7,  3, 6, 17, 2, 23, 
    1, 37, 0, 99, 5,  4, 8, 55, 6, 15, 3, 96, 4, 19, 7, 66, 2, 63, 
    6,  5, 4, 37, 3, 60, 2, 31, 5, 45, 0, 97, 7, 75, 8, 49, 1,  5
  };
  const int q2516[] = {
    9, 9, // Number of jobs and machines
    3, 67, 6,  9, 4, 33, 2, 18, 8, 27, 0, 30, 5, 64, 7, 34, 1, 92, 
    7, 62, 4, 48, 2, 57, 0, 34, 3, 47, 8, 27, 6, 21, 1, 76, 5, 39, 
    7, 84, 2, 97, 3, 57, 8, 90, 5, 78, 0, 87, 1, 35, 6, 17, 4, 61, 
    6,  3, 2, 69, 1, 22, 4, 96, 7,  2, 8, 69, 0, 43, 5, 98, 3, 80, 
    3, 14, 0, 90, 5, 25, 4, 50, 8, 77, 7,  4, 6, 48, 2, 43, 1, 82, 
    6, 36, 1, 47, 0,  9, 3, 43, 2, 36, 7, 83, 4, 77, 5, 99, 8, 19, 
    8, 77, 3, 12, 0, 45, 6, 94, 4, 76, 5, 86, 1, 14, 7, 13, 2, 78, 
    0, 89, 8, 48, 3, 13, 1, 54, 7, 86, 6, 23, 5, 73, 4, 96, 2, 71, 
    6,  7, 8, 29, 7, 76, 3, 70, 1, 35, 4, 75, 2, 98, 5, 41, 0, 79
  };
  const int q2517[] = {
    9, 9, // Number of jobs and machines
    5, 58, 1, 69, 4, 47, 7, 72, 8, 18, 0, 18, 6, 80, 2, 70, 3, 69, 
    7, 54, 5, 80, 0, 80, 2, 91, 1, 76, 3, 75, 6, 15, 4, 41, 8, 24, 
    4, 81, 0, 78, 7, 73, 5, 91, 3, 10, 1, 58, 6, 97, 2,  9, 8, 15, 
    5, 83, 1,  6, 7, 54, 4,  5, 0, 46, 3,  1, 2, 85, 8, 20, 6, 32, 
    7, 54, 8, 14, 3, 54, 0, 56, 4, 90, 5, 25, 2, 30, 6, 48, 1, 94, 
    6, 70, 0, 26, 4, 53, 5, 49, 1, 13, 8,  1, 7,  8, 3,  9, 2, 17, 
    4, 67, 2, 95, 3, 87, 8, 14, 5, 36, 1, 23, 0,  7, 6, 83, 7, 29, 
    6, 83, 3, 27, 0, 87, 4, 63, 2, 10, 8, 38, 5, 38, 1, 23, 7, 25, 
    3, 19, 2, 93, 7, 56, 8, 75, 4, 45, 1, 96, 6, 86, 0, 94, 5, 34
  };
  const int q2518[] = {
    9, 9, // Number of jobs and machines
    1, 41, 3,  9, 0, 39, 7, 30, 2, 65, 6, 95, 5, 46, 4, 51, 8, 40, 
    2, 52, 3, 84, 4, 82, 6, 18, 7, 59, 0, 68, 8, 70, 5, 84, 1, 84, 
    4,  5, 5, 52, 8, 88, 2, 58, 1, 74, 6, 68, 3, 69, 7, 15, 0, 39, 
    6, 77, 2, 87, 0, 73, 1, 63, 3, 72, 5, 36, 4, 83, 8, 30, 7, 59, 
    8, 81, 5, 39, 0,  2, 3, 23, 2,  3, 1, 72, 4, 91, 7, 86, 6, 16, 
    2, 51, 1, 68, 5, 65, 4, 74, 7, 43, 0, 59, 8, 29, 3, 55, 6, 16, 
    7,  4, 2, 14, 6, 57, 1, 56, 0, 94, 8, 81, 4, 89, 5, 55, 3, 36, 
    5, 45, 7, 58, 3, 72, 4, 47, 6, 67, 2, 47, 0, 44, 8, 93, 1, 57, 
    6, 54, 8, 27, 1, 68, 0, 29, 4, 41, 7, 90, 3, 24, 5, 73, 2,  1
  };
  const int q2519[] = {
    9, 9, // Number of jobs and machines
    5, 10, 6, 51, 0, 90, 7, 87, 4, 96, 3, 26, 2, 25, 1, 63, 8, 60, 
    5, 11, 4, 73, 6, 60, 7, 76, 3,  8, 0, 60, 1, 36, 2,  5, 8, 32, 
    8, 53, 6, 19, 7, 57, 1, 59, 4,  2, 0, 36, 5, 45, 2, 56, 3, 74, 
    8, 64, 3, 70, 2, 26, 0, 55, 5, 48, 4, 54, 1, 55, 7, 74, 6, 74, 
    8, 97, 0, 84, 5, 18, 2, 75, 4, 55, 1, 35, 3,  6, 6,  1, 7,  8, 
    3, 86, 8, 94, 5, 46, 6, 43, 0, 31, 2, 14, 1, 51, 7, 87, 4, 68, 
    1, 87, 5, 74, 8, 29, 4, 48, 2, 67, 0, 13, 6, 84, 7, 23, 3, 71, 
    0, 54, 6, 22, 1,  6, 4, 55, 8, 83, 2, 85, 7, 77, 3,  8, 5, 58, 
    3, 11, 2, 66, 8, 48, 1, 59, 5, 95, 0, 80, 4, 58, 7, 98, 6, 99
  };
  const int q2520[] = {
    9, 9, // Number of jobs and machines
    7, 77, 2, 97, 3, 12, 8, 43, 6, 93, 0, 78, 5,  4, 4, 80, 1, 69, 
    0, 12, 8, 41, 3, 45, 6, 17, 1, 83, 4, 99, 5,  8, 2, 84, 7, 12, 
    0,  3, 5, 94, 6, 93, 1,  5, 7, 44, 3, 49, 8, 79, 2, 15, 4, 13, 
    6,  2, 0, 47, 3, 42, 7, 75, 1,  4, 5, 82, 4, 20, 2, 37, 8, 36, 
    8, 99, 4, 58, 7, 87, 0, 27, 1, 72, 2, 60, 6, 14, 5, 48, 3, 94, 
    6, 78, 4, 85, 5, 94, 0, 32, 3, 32, 1, 70, 7, 13, 2, 38, 8, 44, 
    8, 91, 3, 32, 7, 12, 0, 69, 6, 56, 5, 79, 1,  8, 4, 44, 2, 70, 
    2, 94, 0, 11, 7, 67, 8, 91, 3, 50, 4, 67, 6, 81, 5, 75, 1, 19, 
    1, 17, 8, 59, 0, 48, 2, 65, 4,  4, 6, 48, 7, 87, 5, 78, 3, 17
  };
  const int q2521[] = {
    9, 9, // Number of jobs and machines
    6, 31, 4, 32, 5, 43, 1, 89, 8, 70, 0, 78, 7, 91, 3, 61, 2, 26, 
    4, 30, 6, 56, 2, 21, 0, 93, 8, 79, 3, 26, 5, 30, 7, 86, 1, 92, 
    6, 31, 2, 14, 1, 92, 3,  7, 5, 71, 7, 45, 8, 65, 4, 92, 0, 11, 
    8, 45, 4, 49, 1, 31, 3,  7, 6, 48, 7, 88, 0, 45, 5, 54, 2, 37, 
    0, 11, 8, 14, 3, 52, 4, 13, 5, 70, 7, 71, 6,  4, 1, 28, 2, 66, 
    7, 97, 0, 11, 1,  9, 8, 69, 2, 44, 5, 87, 6, 85, 3, 13, 4, 42, 
    8, 22, 0, 74, 5, 72, 3, 26, 6, 67, 4, 65, 1,  2, 2, 31, 7, 17, 
    0, 15, 8,  2, 7, 81, 2, 62, 1,  7, 4, 83, 6, 98, 3, 73, 5, 71, 
    7, 86, 6, 68, 1, 48, 0, 79, 5, 55, 4, 35, 3, 40, 2, 28, 8, 27
  };
  const int q2522[] = {
    9, 9, // Number of jobs and machines
    5, 72, 2, 65, 3,  1, 0, 53, 8, 50, 6, 73, 1, 86, 4, 84, 7, 20, 
    4, 30, 1, 26, 8, 56, 5,  2, 0, 22, 2,  8, 7, 34, 6, 25, 3, 43, 
    3, 81, 7, 28, 4, 53, 0, 89, 8, 15, 1, 43, 6, 99, 2, 10, 5, 19, 
    2, 26, 7, 41, 6, 99, 0,  3, 8, 52, 3, 28, 1, 10, 4, 53, 5,  3, 
    3,  4, 1, 21, 6, 41, 8, 22, 5, 27, 4, 96, 7, 40, 2, 60, 0, 96, 
    5, 22, 1, 41, 7, 92, 4, 35, 2, 62, 0, 38, 3, 10, 8, 28, 6, 25, 
    5, 88, 7, 51, 6, 91, 4, 33, 8, 79, 2, 28, 0, 33, 3, 82, 1, 47, 
    7, 11, 6, 16, 1, 40, 2, 96, 3, 47, 4, 30, 8, 84, 5, 92, 0,  2, 
    7, 23, 8, 52, 3, 42, 2, 37, 5, 53, 6, 76, 1, 95, 4, 38, 0, 19
  };
  const int q2523[] = {
    9, 9, // Number of jobs and machines
    1,  6, 6, 39, 0, 80, 4, 93, 2, 95, 7, 55, 3, 35, 5, 56, 8, 47, 
    8, 37, 7, 30, 2, 28, 3, 75, 1, 25, 6, 97, 4, 38, 0, 21, 5, 22, 
    6, 22, 5, 12, 8,  7, 3, 25, 4, 23, 2,  6, 7, 47, 0, 14, 1, 72, 
    6, 89, 3, 87, 1, 47, 7, 32, 8, 79, 0,  7, 2, 84, 5, 61, 4, 93, 
    8, 92, 6,  5, 3, 56, 0, 41, 4, 85, 7, 56, 5, 65, 2, 81, 1, 73, 
    3, 45, 2, 76, 6, 25, 7, 14, 4, 87, 8, 39, 5, 38, 0, 96, 1, 89, 
    3, 18, 8, 21, 1, 19, 7, 58, 2,  6, 5, 46, 4,  3, 0, 21, 6, 92, 
    0, 63, 1, 41, 8, 66, 2, 94, 6, 31, 7, 23, 5, 90, 4, 14, 3,  9, 
    0, 70, 8, 87, 6, 62, 1, 97, 3, 19, 2, 83, 4,  5, 7, 28, 5, 34
  };
  const int q2524[] = {
    9, 9, // Number of jobs and machines
    7, 71, 1, 14, 6, 75, 5,  4, 8, 13, 4, 17, 3, 45, 2, 36, 0, 32, 
    7, 53, 2, 18, 5, 41, 3, 27, 6, 36, 0,  3, 4, 70, 1, 57, 8, 23, 
    7, 59, 2, 70, 6, 53, 5, 14, 0, 29, 3, 54, 8, 85, 1, 85, 4, 77, 
    6, 76, 7,  9, 3, 44, 0, 12, 8, 92, 2, 16, 1, 23, 4, 10, 5, 18, 
    1, 60, 8, 87, 7, 79, 4, 94, 5, 27, 2, 61, 0, 48, 3, 76, 6, 62, 
    6,  7, 2, 96, 0, 41, 8, 49, 7, 36, 3, 40, 4, 31, 1, 26, 5,  9, 
    0, 68, 1, 30, 7, 11, 2, 71, 6, 59, 5, 81, 3, 46, 4, 33, 8, 82, 
    6, 76, 5, 36, 8,  8, 0, 44, 3, 71, 7, 86, 4, 14, 1,  1, 2, 83, 
    4, 71, 0, 29, 1, 63, 6, 55, 8, 23, 5, 59, 3, 36, 7, 97, 2, 91
  };
  const int q2525[] = {
    9, 9, // Number of jobs and machines
    4, 51, 1, 66, 2, 15, 8, 39, 6,  8, 3, 62, 7, 52, 5, 49, 0, 88, 
    1,  3, 8, 29, 7, 42, 4, 77, 6, 81, 2, 78, 3, 10, 0, 36, 5, 10, 
    8, 82, 6, 55, 2, 17, 3, 12, 4,  2, 1, 32, 7, 74, 5, 40, 0, 18, 
    0, 11, 6, 97, 8,  9, 1, 86, 2, 43, 7, 44, 3, 64, 5, 79, 4, 23, 
    8, 85, 1, 24, 5, 92, 6, 27, 2, 82, 0, 93, 4, 98, 7, 80, 3, 26, 
    8, 87, 7, 96, 1, 42, 0, 80, 5, 89, 6, 89, 3,  2, 2, 91, 4, 28, 
    6, 75, 3, 79, 7, 70, 8, 67, 2, 72, 1, 61, 0, 21, 5, 90, 4, 69, 
    2,  1, 5, 57, 4, 27, 8, 28, 7, 27, 1, 86, 0, 96, 3, 86, 6, 16, 
    7, 31, 3, 63, 1, 81, 8, 25, 2, 94, 4, 99, 0, 37, 6, 40, 5, 63
  };
  const int q2526[] = {
    9, 9, // Number of jobs and machines
    4, 25, 7, 91, 2, 70, 5, 68, 8, 56, 3, 10, 1, 91, 0, 67, 6, 14, 
    6, 70, 8, 53, 3, 20, 5, 24, 0, 75, 4, 78, 7, 32, 1, 58, 2,  4, 
    7, 72, 0, 30, 1,  5, 3, 12, 5, 58, 2, 99, 6,  1, 4, 96, 8,  2, 
    7, 18, 1, 12, 0, 49, 4, 46, 8, 30, 6, 99, 3, 31, 5, 19, 2, 37, 
    0, 75, 4, 11, 7, 92, 2, 46, 3, 38, 6,  5, 5, 49, 8,  7, 1, 30, 
    6, 86, 2, 88, 3, 78, 0,  6, 5, 85, 1, 66, 7,  9, 8, 41, 4, 94, 
    8,  1, 1, 13, 0, 29, 2, 75, 4, 35, 7, 64, 5, 29, 6, 31, 3, 76, 
    6, 55, 7, 91, 1, 18, 2, 64, 3, 19, 8,  5, 5, 90, 0, 78, 4, 81, 
    1, 25, 4, 88, 2, 76, 5, 53, 3, 52, 7, 62, 8, 93, 6, 64, 0, 21
  };
  const int q2527[] = {
    9, 9, // Number of jobs and machines
    5, 62, 1, 49, 4,  5, 3, 82, 6, 73, 8,  4, 7, 21, 2, 13, 0, 47, 
    8, 83, 3, 59, 6, 14, 2, 36, 7,  2, 4, 18, 1, 55, 0, 81, 5, 31, 
    1, 20, 7, 85, 0, 21, 4, 68, 5, 45, 3, 94, 8, 39, 6, 70, 2, 24, 
    4, 99, 7, 53, 6, 84, 5, 31, 1, 65, 2, 70, 8, 31, 3, 82, 0, 55, 
    1, 77, 3, 70, 2, 19, 5, 96, 7, 29, 4, 49, 6, 37, 0, 12, 8, 54, 
    5, 36, 1, 13, 7, 75, 3, 68, 0, 91, 4,  3, 8, 37, 2, 18, 6,  7, 
    2, 71, 7, 64, 1, 36, 4, 12, 8, 28, 3, 16, 5,  2, 0, 95, 6, 42, 
    1, 81, 8,  7, 4,  3, 3, 97, 7, 36, 5, 64, 2, 33, 0, 10, 6, 90, 
    1, 73, 2, 58, 7, 34, 5, 56, 3, 11, 6, 71, 0, 94, 4, 59, 8, 64
  };
  const int q2528[] = {
    9, 9, // Number of jobs and machines
    0, 81, 8, 35, 6, 82, 4, 10, 5, 11, 1, 65, 2, 90, 3, 68, 7,  2, 
    0, 63, 8, 28, 5, 44, 7, 11, 2,  1, 1, 39, 4, 44, 6, 97, 3, 19, 
    4, 46, 8, 85, 0, 89, 5, 76, 7, 58, 6, 25, 2, 73, 3, 66, 1, 44, 
    8, 75, 3,  2, 4, 87, 7, 97, 2, 51, 1,  1, 0, 40, 6,  6, 5, 35, 
    6, 42, 2, 69, 7, 37, 8,  1, 4, 60, 3, 83, 5, 15, 1, 62, 0, 82, 
    7, 97, 8, 46, 2, 43, 3, 47, 4, 47, 6, 73, 0, 67, 5, 87, 1, 17, 
    2, 91, 1, 35, 3, 11, 4, 68, 7, 53, 0, 61, 6, 72, 8, 40, 5, 64, 
    6, 80, 0, 43, 5, 46, 3, 29, 8,  8, 4,  2, 1, 50, 7, 30, 2, 10, 
    8, 91, 2, 79, 6,  9, 0,  6, 3, 66, 7, 95, 5,  9, 1, 33, 4, 89
  };
  const int q2529[] = {
    9, 9, // Number of jobs and machines
    7, 98, 1, 44, 8, 70, 5, 31, 3, 85, 2,  6, 4, 54, 6, 50, 0,  6, 
    6, 90, 5, 94, 4, 89, 1, 40, 8, 40, 7,  8, 3, 96, 2, 57, 0, 75, 
    2, 49, 0, 36, 3, 40, 6, 39, 8, 91, 4, 83, 5, 64, 1, 28, 7, 68, 
    8, 82, 6, 31, 0, 28, 1, 92, 2, 39, 7, 91, 3, 84, 4, 65, 5, 53, 
    0, 72, 5, 65, 8, 21, 7, 87, 6, 65, 1, 26, 2, 84, 3, 20, 4, 64, 
    6, 10, 2, 52, 0, 66, 5, 52, 3, 26, 4, 43, 7, 26, 1, 75, 8, 46, 
    8, 97, 5, 50, 3, 34, 6, 42, 1, 86, 2, 79, 4, 76, 7, 62, 0, 33, 
    8, 29, 6, 83, 0, 57, 1, 18, 3, 15, 7, 75, 4, 95, 5, 54, 2, 26, 
    7, 58, 5, 59, 0, 97, 1, 93, 6, 16, 2, 71, 3, 26, 8, 11, 4, 35
  };
  const int q2530[] = {
    9, 9, // Number of jobs and machines
    5, 20, 2, 57, 4,  9, 3, 67, 1, 41, 7, 56, 8, 25, 6, 76, 0, 92, 
    3, 68, 1,  5, 5, 32, 0, 28, 4, 51, 2, 57, 6, 75, 7, 38, 8, 59, 
    3, 16, 8, 91, 1, 91, 7, 78, 2, 84, 0, 34, 4, 69, 6, 64, 5, 40, 
    2,  8, 5, 52, 0, 17, 3, 14, 4, 50, 1, 57, 6, 73, 8, 92, 7, 99, 
    6, 20, 3, 74, 4, 81, 7, 99, 5,  5, 2, 46, 0, 41, 1, 62, 8, 69, 
    3, 65, 5, 77, 0, 80, 1, 85, 6, 24, 2, 99, 4, 25, 8, 32, 7, 28, 
    8,  8, 5, 40, 3,  9, 0,  5, 2, 87, 7, 32, 4, 97, 1, 87, 6, 36, 
    5,  9, 7, 89, 2, 35, 1, 52, 3, 26, 6, 71, 8, 31, 4, 25, 0, 18, 
    0,  1, 3, 74, 8, 62, 1,  1, 4, 57, 5, 25, 2, 94, 7, 31, 6, 50
  };
  const int q2531[] = {
    9, 9, // Number of jobs and machines
    7, 51, 8, 62, 1, 31, 4, 78, 3, 18, 6,  9, 0,  2, 2, 89, 5, 99, 
    8, 98, 5, 51, 3, 87, 7, 43, 1, 99, 6, 60, 4, 29, 0, 96, 2, 85, 
    8, 52, 4, 81, 5, 70, 7, 18, 0, 14, 1,  7, 6, 82, 2, 52, 3, 14, 
    6, 49, 7, 96, 0, 74, 5, 19, 4, 89, 2, 28, 3, 31, 1, 73, 8, 96, 
    4, 94, 0, 27, 5, 78, 8, 78, 1, 33, 3, 79, 6, 34, 7, 46, 2, 72, 
    2, 98, 5, 35, 0, 37, 1, 79, 4, 58, 8, 48, 3, 23, 6, 68, 7, 84, 
    5, 39, 2, 70, 4, 97, 3, 10, 8, 94, 1, 72, 0, 96, 7, 80, 6, 20, 
    3, 75, 4,  5, 8, 70, 6, 25, 2, 76, 7, 15, 1, 10, 5, 23, 0, 13, 
    0, 80, 7, 68, 8, 31, 2, 78, 1, 19, 6, 18, 3, 71, 4, 66, 5, 14
  };
  const int q2532[] = {
    9, 9, // Number of jobs and machines
    6, 82, 0, 47, 8, 26, 2, 70, 5, 24, 1, 65, 3,  6, 4, 53, 7, 75, 
    1, 70, 8, 32, 2, 94, 6, 14, 3,  8, 7, 75, 4, 48, 5, 68, 0, 52, 
    7,  1, 0, 85, 3, 44, 8, 36, 1, 11, 5, 64, 2, 19, 6, 70, 4, 17, 
    0, 98, 3, 56, 4, 75, 7, 33, 5, 65, 6, 17, 1, 79, 8, 22, 2, 96, 
    5, 96, 1, 31, 2, 12, 7, 11, 3, 19, 0, 54, 4, 28, 6, 44, 8, 38, 
    6, 80, 2, 13, 4, 98, 8, 86, 1, 38, 5, 21, 3, 14, 0, 36, 7, 35, 
    5, 48, 8, 99, 3, 61, 6, 42, 4, 20, 7,  2, 2, 77, 1, 18, 0, 60, 
    5, 96, 3, 34, 7, 56, 4, 96, 8, 67, 0, 41, 6, 46, 2, 42, 1, 80, 
    6, 79, 7, 27, 4, 92, 2, 97, 8, 31, 1, 27, 0, 58, 3,  1, 5, 45
  };
  const int q2533[] = {
    9, 9, // Number of jobs and machines
    0, 75, 1, 98, 8, 31, 3,  6, 7, 97, 2,  4, 6, 31, 5, 73, 4, 10, 
    6, 34, 2, 18, 1,  1, 4, 66, 7, 66, 5, 82, 8, 54, 3, 16, 0, 55, 
    8, 85, 0, 46, 3, 39, 6, 46, 1, 38, 5, 75, 7,  5, 4, 15, 2, 13, 
    5, 40, 4, 35, 1, 65, 0, 40, 2, 46, 7, 35, 8, 20, 6, 84, 3, 14, 
    6, 50, 4, 66, 5, 39, 0, 80, 8, 43, 2, 99, 1, 73, 3, 19, 7, 35, 
    1, 85, 8, 66, 0, 12, 7, 75, 3, 23, 5, 11, 4, 38, 2, 15, 6,  4, 
    3, 67, 5, 53, 6, 82, 2, 90, 8, 77, 7, 59, 4,  1, 0, 22, 1, 20, 
    3, 48, 7, 77, 0, 60, 1, 12, 8, 26, 4, 12, 6, 14, 5, 89, 2, 86, 
    8, 18, 4,  1, 3, 25, 0, 65, 2,  6, 1, 75, 5, 26, 7,  2, 6, 48
  };
  const int q2534[] = {
    9, 9, // Number of jobs and machines
    8, 22, 2, 91, 3, 14, 5,  1, 0, 29, 7, 46, 1, 63, 6, 75, 4, 91, 
    8, 47, 5, 36, 4, 79, 0,  3, 6, 41, 2, 98, 3, 50, 1, 57, 7, 88, 
    2, 86, 7, 68, 0, 82, 8, 89, 6, 37, 5, 61, 3, 25, 4, 27, 1, 24, 
    6, 41, 3, 40, 1, 27, 8, 63, 7, 75, 5, 61, 2, 64, 0, 85, 4, 50, 
    6, 40, 7, 22, 4,  7, 1, 63, 3, 60, 8, 93, 5, 85, 0, 36, 2, 15, 
    7, 94, 4, 74, 0, 66, 6, 63, 1, 16, 2, 74, 8, 12, 3, 63, 5, 17, 
    8, 42, 7, 10, 0,  8, 3, 92, 4, 31, 2, 63, 1, 37, 6, 10, 5, 19, 
    8, 52, 3, 31, 2, 18, 5, 42, 1, 55, 4, 28, 6, 11, 7,  6, 0, 77, 
    3, 22, 6, 97, 4, 92, 7, 45, 2, 48, 0, 78, 8, 92, 1,  6, 5, 97
  };
  const int q2535[] = {
    9, 9, // Number of jobs and machines
    4, 66, 3, 77, 6, 76, 1, 74, 0, 43, 8, 19, 7, 87, 5, 15, 2, 14, 
    7, 38, 2, 78, 1, 82, 6, 85, 3, 63, 0,  5, 8, 34, 5, 28, 4, 79, 
    5, 16, 4, 39, 7, 39, 1, 78, 8, 37, 6, 91, 2, 93, 3, 90, 0, 79, 
    1, 30, 3, 48, 5,  7, 7, 40, 4, 88, 8, 48, 6, 53, 0, 31, 2, 42, 
    2, 31, 7, 19, 4, 29, 0, 11, 5, 70, 3, 91, 1, 22, 8, 99, 6, 67, 
    8, 80, 4, 40, 6, 21, 0, 64, 3, 89, 1, 87, 5, 22, 2, 53, 7, 93, 
    4, 32, 2,  5, 6, 93, 8, 81, 0, 74, 7, 99, 1, 98, 5, 86, 3, 64, 
    5, 69, 2, 94, 4, 99, 6, 67, 0, 33, 1, 95, 8,  6, 3, 82, 7, 43, 
    3, 62, 5, 69, 8, 63, 4, 31, 0, 93, 1, 79, 6, 28, 2, 69, 7, 10
  };
  const int q2536[] = {
    9, 9, // Number of jobs and machines
    5, 54, 0, 33, 3,  9, 4, 63, 6, 39, 1, 43, 2, 49, 7, 23, 8, 52, 
    3, 89, 0, 20, 2, 21, 1, 14, 7, 78, 8, 81, 4, 81, 5, 57, 6, 32, 
    0, 61, 7,  3, 8, 31, 2, 13, 4, 87, 3, 95, 6, 40, 1, 46, 5, 97, 
    8, 69, 6,  7, 3, 35, 7,  8, 2, 12, 4, 94, 0, 35, 5, 17, 1, 44, 
    4, 41, 2, 42, 1,  2, 8, 31, 0, 90, 5, 37, 6, 40, 3, 26, 7, 34, 
    5, 18, 3, 19, 6, 89, 7, 87, 4, 67, 8, 45, 1, 75, 0, 51, 2, 85, 
    1, 32, 7, 10, 4, 60, 0, 60, 8, 18, 3,  2, 6, 23, 2, 38, 5, 85, 
    4, 60, 0, 50, 5, 54, 2, 15, 6,  6, 3, 28, 1, 28, 7, 35, 8, 62, 
    6, 88, 4, 88, 5, 91, 0, 50, 1, 23, 2, 50, 7, 10, 3, 71, 8, 82
  };
  const int q2537[] = {
    9, 9, // Number of jobs and machines
    7, 88, 6, 24, 0, 68, 8, 57, 2,  4, 1, 55, 5, 50, 3, 41, 4, 35, 
    2, 64, 5, 27, 7, 47, 0,  3, 4, 49, 1, 94, 8, 16, 3, 15, 6, 27, 
    8, 46, 4, 97, 2, 25, 3, 90, 5, 78, 6, 46, 1, 82, 0, 25, 7, 45, 
    4, 10, 5, 79, 6, 28, 8, 38, 3, 20, 0, 44, 1, 93, 2, 59, 7, 93, 
    7, 67, 0, 68, 2, 88, 8, 38, 6, 33, 1, 19, 4, 91, 3, 32, 5, 16, 
    4, 34, 1, 37, 3, 66, 5, 13, 0, 58, 8, 39, 2, 33, 6, 76, 7, 90, 
    5, 54, 0, 44, 2, 67, 7, 80, 3, 74, 6, 33, 4, 11, 1, 26, 8, 88, 
    5, 82, 7, 17, 6, 99, 3, 38, 0, 91, 8, 61, 1, 99, 4, 38, 2, 11, 
    0, 75, 8,  5, 2, 16, 3, 25, 7, 52, 5,  7, 4, 32, 1, 74, 6, 90
  };
  const int q2538[] = {
    9, 9, // Number of jobs and machines
    2, 53, 0, 43, 8, 57, 5, 61, 4, 29, 7, 72, 1, 67, 6, 72, 3, 93, 
    1, 45, 4, 17, 3, 41, 8, 56, 2, 49, 7, 35, 6, 94, 5, 19, 0, 11, 
    3, 84, 4, 91, 7, 50, 8,  1, 5, 15, 1, 83, 6, 11, 0, 22, 2, 45, 
    1, 56, 3,  4, 0, 17, 2, 15, 8, 29, 6, 32, 5, 91, 4,  3, 7, 14, 
    5, 53, 0, 32, 6, 80, 8, 56, 4, 58, 1, 30, 2, 78, 3, 71, 7, 29, 
    7, 31, 4, 54, 6,  3, 5, 37, 0, 87, 3, 17, 1, 76, 2, 38, 8, 34, 
    1, 56, 7,  3, 3, 68, 5,  4, 8, 55, 0, 62, 2, 63, 4, 60, 6,  7, 
    7, 84, 6, 73, 8,  8, 3, 92, 0, 70, 4, 51, 2, 29, 1, 81, 5,  8, 
    7, 67, 3, 71, 6, 61, 5, 54, 0, 11, 4, 67, 2, 95, 8, 89, 1,  9
  };
  const int q2539[] = {
    9, 9, // Number of jobs and machines
    2, 66, 5, 64, 6, 32, 1, 99, 4, 13, 3, 70, 8,  2, 0, 65, 7, 55, 
    4, 69, 8,  8, 7, 14, 0, 90, 6, 62, 5, 72, 2, 45, 3, 54, 1, 63, 
    3, 53, 1, 88, 6, 87, 5, 13, 8, 44, 7, 51, 4, 29, 0, 55, 2, 87, 
    0, 32, 7, 42, 6, 24, 1,  3, 4, 71, 5, 35, 2, 73, 3, 59, 8, 40, 
    0, 73, 6, 98, 5, 41, 8, 72, 4, 51, 7, 91, 3, 77, 1, 29, 2, 36, 
    1, 61, 3, 45, 4, 13, 2, 90, 0, 53, 5,  8, 6, 13, 8, 24, 7, 55, 
    5, 36, 2, 29, 6, 15, 8, 61, 1, 71, 7, 29, 3,  1, 4, 46, 0, 92, 
    5, 15, 3, 97, 8, 23, 7, 18, 2, 61, 4, 57, 1, 14, 0, 57, 6, 99, 
    7, 67, 0, 24, 4, 46, 6, 30, 3,  6, 2, 42, 1, 49, 5, 74, 8, 92
  };
  const int q2540[] = {
    9, 9, // Number of jobs and machines
    3, 74, 6, 81, 2, 62, 4, 35, 1, 14, 0, 16, 8, 22, 7, 68, 5,  4, 
    6, 55, 5, 81, 0, 82, 3, 41, 2, 57, 8, 78, 7, 94, 1,  7, 4, 33, 
    8, 80, 6, 58, 2, 97, 0, 20, 3, 54, 1,  9, 5, 45, 4, 24, 7, 63, 
    0, 75, 8, 19, 2,  1, 6,  5, 5, 36, 1, 74, 7, 15, 4,  6, 3, 37, 
    0, 54, 7, 43, 5, 57, 8, 83, 3, 24, 4, 23, 1, 87, 2, 87, 6, 28, 
    2, 46, 1, 58, 3, 63, 0, 68, 8, 77, 6, 81, 7,  1, 4, 64, 5, 71, 
    0, 31, 7, 15, 3, 82, 2, 50, 1, 84, 4, 33, 5, 59, 6,  5, 8, 99, 
    4, 24, 7, 25, 8, 61, 6,  2, 0,  9, 1, 52, 3, 81, 5, 68, 2, 78, 
    8, 28, 6, 86, 5, 84, 2, 93, 0,  8, 7, 21, 3, 28, 1, 22, 4, 79
  };
  const int q2541[] = {
    9, 9, // Number of jobs and machines
    5, 15, 7, 37, 4, 54, 6,  3, 2, 16, 0,  8, 3, 73, 1, 68, 8, 33, 
    7, 48, 5, 37, 4, 40, 8, 61, 0, 86, 3, 60, 2, 11, 1, 25, 6, 14, 
    4, 81, 0, 85, 6,  4, 1, 80, 2, 71, 7, 67, 8, 76, 3, 22, 5, 38, 
    3, 66, 2, 91, 4, 40, 5, 26, 0, 43, 6,  7, 7, 53, 1, 40, 8, 78, 
    2, 23, 5, 47, 8, 95, 1, 11, 6, 12, 4, 51, 3,  6, 7, 47, 0, 26, 
    3, 79, 8, 26, 7,  8, 2, 57, 1, 90, 6, 14, 0, 59, 5, 85, 4, 71, 
    0, 90, 2, 30, 7, 83, 8, 30, 6, 65, 1, 14, 5, 76, 3, 14, 4, 42, 
    2, 48, 6, 24, 1, 50, 5, 56, 8, 60, 0, 89, 7,  6, 3, 58, 4, 82, 
    0,  7, 2, 16, 3, 48, 1, 81, 4, 93, 5, 64, 8, 58, 6,  3, 7, 88
  };
  const int q2542[] = {
    9, 9, // Number of jobs and machines
    4, 36, 2, 25, 6, 46, 3, 87, 1, 22, 7, 89, 5, 96, 8, 71, 0, 75, 
    0,  6, 4, 74, 2, 99, 8, 98, 5, 69, 3, 84, 7, 70, 6,  8, 1, 79, 
    6, 41, 2, 85, 4, 79, 0,  4, 3, 57, 8, 47, 7, 87, 1, 59, 5, 48, 
    5, 10, 7, 42, 0, 91, 8, 45, 2, 36, 1, 48, 6, 57, 4, 71, 3, 73, 
    3, 32, 2, 24, 7, 96, 4, 66, 8, 41, 1, 55, 0, 21, 5, 80, 6,  9, 
    1, 31, 3, 21, 5, 80, 8, 19, 2, 10, 6, 37, 0, 74, 7, 45, 4, 76, 
    6, 13, 2, 98, 7, 55, 4, 48, 8,  6, 0, 49, 5,  7, 1, 24, 3, 33, 
    3, 96, 4, 26, 1, 84, 7, 37, 8, 66, 6, 80, 5, 17, 0, 94, 2, 70, 
    2, 14, 0, 60, 8, 90, 7, 61, 6,  8, 1, 61, 5, 78, 4, 73, 3, 78
  };
  const int q2543[] = {
    9, 9, // Number of jobs and machines
    8,  7, 7, 19, 2, 92, 4, 18, 1,  5, 3, 89, 6, 52, 5, 46, 0, 36, 
    7, 77, 5,  3, 6, 16, 2, 45, 0, 23, 8, 24, 1, 20, 3, 51, 4,  8, 
    6,  6, 8, 58, 5, 66, 1, 91, 2, 61, 0, 61, 4, 27, 7, 23, 3, 90, 
    8, 36, 2, 32, 4, 96, 5, 20, 7, 32, 6, 57, 0, 59, 3, 50, 1, 84, 
    7, 13, 0, 60, 5,  2, 1, 86, 2, 41, 4, 10, 3, 56, 8, 71, 6,  2, 
    3, 51, 8, 53, 5, 27, 0, 10, 1, 78, 4, 75, 2, 11, 6, 57, 7, 46, 
    6, 99, 7, 25, 8,  5, 0, 15, 1, 39, 4, 85, 2, 25, 3, 58, 5, 49, 
    4, 49, 3, 61, 5, 99, 8, 90, 0, 24, 1, 39, 6, 58, 7, 88, 2, 87, 
    7, 61, 4,  3, 2, 43, 5, 50, 0, 45, 3, 93, 6,  4, 1, 92, 8, 68
  };
  const int q2544[] = {
    9, 9, // Number of jobs and machines
    7, 63, 6, 13, 4, 88, 2, 64, 8, 45, 5, 57, 0, 29, 3, 17, 1, 30, 
    7, 63, 1, 38, 2, 48, 0,  6, 3, 56, 4, 29, 6, 64, 8, 14, 5, 57, 
    6, 22, 8, 17, 7, 16, 4, 85, 3, 47, 5, 31, 1, 70, 2, 59, 0, 34, 
    4, 30, 6, 95, 5, 19, 0, 36, 8, 63, 3, 94, 2, 80, 7, 42, 1,  9, 
    3,  5, 4,  9, 2, 42, 1, 21, 5, 58, 8, 46, 0, 73, 6, 47, 7, 55, 
    0, 77, 2, 84, 4,  4, 7, 39, 5, 87, 1, 69, 8, 71, 3, 28, 6, 46, 
    1, 41, 2, 27, 5, 40, 8, 32, 6, 34, 3, 61, 7, 44, 0, 66, 4, 11, 
    3, 14, 2, 46, 4, 28, 7,  9, 8, 25, 5, 11, 6, 62, 0, 98, 1, 43, 
    2, 70, 5, 16, 8, 46, 7, 33, 1, 59, 0, 22, 6, 64, 3, 70, 4, 84
  };
  const int q2545[] = {
    9, 9, // Number of jobs and machines
    4, 60, 3,  6, 2, 67, 6, 80, 0, 18, 5, 80, 7,  8, 1, 26, 8,  2, 
    3, 25, 5, 97, 8, 12, 1, 83, 7, 40, 6, 95, 4, 17, 0, 66, 2, 74, 
    2, 92, 5, 29, 4, 87, 7, 90, 8, 76, 3, 94, 0, 53, 1, 27, 6,  6, 
    6, 10, 8, 80, 1, 64, 2, 99, 3, 64, 4, 94, 7, 75, 5, 80, 0, 99, 
    1, 89, 4, 24, 0,  8, 7, 55, 6, 15, 3,  9, 2, 88, 5, 95, 8,  2, 
    7, 34, 8, 55, 4, 32, 0, 65, 1, 54, 5, 25, 2, 81, 3,  5, 6, 97, 
    3, 18, 0, 41, 1, 44, 2, 67, 8, 35, 5, 98, 4, 58, 7, 31, 6, 22, 
    6, 49, 8,  9, 1,  4, 3, 75, 5, 45, 0, 58, 2, 78, 7, 36, 4, 79, 
    3, 96, 8, 77, 1, 43, 4, 76, 6, 50, 0, 75, 7, 27, 2, 84, 5, 41
  };
  const int q2546[] = {
    9, 9, // Number of jobs and machines
    1, 55, 7, 63, 8, 44, 4, 71, 6, 39, 0, 37, 5, 82, 3, 53, 2, 23, 
    5, 27, 8, 71, 2, 55, 0, 87, 3, 59, 1, 74, 6,  5, 4, 40, 7, 75, 
    5, 39, 6, 54, 2,  6, 0, 11, 7, 34, 1, 43, 3, 42, 4, 59, 8, 53, 
    2, 81, 3, 92, 7, 98, 1, 49, 6, 80, 4, 19, 0, 29, 8, 55, 5, 27, 
    0, 42, 2, 54, 8, 17, 1, 29, 7, 12, 3, 74, 5, 36, 6, 34, 4, 42, 
    0, 58, 2, 24, 3, 17, 5, 57, 7, 13, 4, 88, 1, 37, 8, 70, 6, 52, 
    5, 74, 0, 89, 4, 71, 8, 51, 1, 52, 2, 93, 6, 61, 7, 75, 3, 22, 
    2, 73, 4, 33, 6, 96, 5, 98, 0,  2, 7, 24, 8, 58, 1, 93, 3, 83, 
    7, 59, 8, 36, 6, 19, 0,  2, 5, 96, 4, 59, 2, 13, 3,  8, 1, 99
  };
  const int q2547[] = {
    9, 9, // Number of jobs and machines
    3, 43, 7, 54, 1, 50, 4, 51, 6, 10, 5, 86, 0, 76, 2,  7, 8, 59, 
    0,  9, 7, 38, 1, 47, 8, 10, 6, 74, 5, 73, 2, 73, 4, 67, 3, 81, 
    3, 39, 7, 46, 1, 61, 5, 37, 0,  8, 2, 15, 8, 51, 6, 47, 4, 16, 
    6, 18, 3,  9, 5, 31, 4, 75, 8,  2, 7,  9, 2, 16, 1, 54, 0, 23, 
    1, 69, 5,  8, 8, 32, 0, 86, 7, 92, 6, 66, 2, 69, 4, 90, 3, 40, 
    7, 89, 5, 29, 8, 75, 0, 25, 6, 62, 3, 85, 2, 10, 1, 36, 4, 61, 
    1, 92, 7, 78, 5,  1, 2,  1, 8, 81, 0, 16, 6, 25, 3, 97, 4, 59, 
    3,  2, 4,  4, 6, 83, 2, 52, 7, 41, 5, 84, 1, 11, 0, 15, 8, 17, 
    4, 90, 6, 65, 5, 14, 3, 58, 7,  2, 2, 22, 8, 79, 1, 73, 0,  5
  };
  const int q2548[] = {
    9, 9, // Number of jobs and machines
    4, 30, 1, 26, 3, 62, 8, 59, 6, 76, 2, 37, 0, 17, 7, 13, 5, 78, 
    6, 33, 5, 42, 2, 96, 0, 81, 4, 30, 1, 17, 3, 31, 8, 45, 7, 24, 
    2, 13, 6, 79, 7, 60, 1, 45, 3, 17, 8, 65, 5, 19, 0, 64, 4,  2, 
    4,  1, 3, 62, 0, 87, 6, 33, 8, 85, 1, 59, 5, 36, 2, 33, 7, 21, 
    6, 65, 0, 36, 3, 76, 8, 65, 2, 48, 4, 56, 1, 76, 7, 48, 5, 20, 
    3, 60, 5, 24, 1, 46, 7, 22, 4, 13, 0, 21, 6, 92, 8, 21, 2, 17, 
    1, 72, 4, 56, 7, 31, 6, 68, 2, 43, 5, 66, 8, 98, 0, 23, 3, 97, 
    0, 10, 7, 98, 1, 25, 2, 42, 8,  5, 5,  8, 6, 36, 3, 87, 4, 79, 
    5, 23, 1, 98, 8, 40, 3, 15, 0, 95, 7, 97, 4, 43, 2, 70, 6, 13
  };
  const int q2549[] = {
    9, 9, // Number of jobs and machines
    7, 22, 1, 95, 0, 91, 4, 47, 8, 70, 5, 68, 2, 75, 3,  7, 6, 99, 
    7, 33, 5, 43, 8, 17, 0, 82, 2, 24, 1, 85, 3, 33, 6, 67, 4, 40, 
    4, 86, 2, 50, 6, 83, 1, 73, 0, 46, 5, 47, 3, 73, 7, 40, 8, 97, 
    6, 97, 3, 12, 5, 57, 7, 30, 4, 29, 2, 62, 0, 10, 8, 75, 1, 39, 
    2, 35, 0, 69, 7, 98, 6, 61, 5, 17, 3, 74, 4, 97, 1, 20, 8, 23, 
    3, 78, 7, 88, 6, 27, 0, 24, 2, 30, 1, 47, 5, 87, 4, 93, 8, 37, 
    1, 82, 2, 42, 3, 17, 5, 83, 6, 46, 0, 10, 4, 81, 7, 94, 8, 15, 
    2, 87, 8, 29, 1, 90, 3, 48, 5, 79, 7, 70, 6, 99, 0,  5, 4, 29, 
    7,  2, 1, 20, 8, 72, 0, 83, 6, 62, 2,  5, 3, 34, 4, 30, 5, 75
  };
  const int q2550[] = {
    9, 9, // Number of jobs and machines
    7, 59, 4, 78, 2, 69, 6, 75, 3, 29, 8, 79, 5, 80, 1, 57, 0, 78, 
    8,  1, 3, 24, 0,  5, 6,  7, 7, 34, 2, 81, 5, 57, 1, 12, 4, 53, 
    8, 95, 5,  3, 7, 88, 6, 45, 2, 27, 1, 80, 0, 88, 3, 13, 4, 20, 
    7, 26, 1,  3, 5, 85, 0, 99, 8, 83, 4,  1, 2, 24, 6, 18, 3, 77, 
    0, 88, 2, 68, 6, 58, 8, 54, 7, 78, 5, 14, 1, 72, 4, 78, 3, 48, 
    4, 57, 3, 30, 6, 19, 5, 41, 8, 70, 7, 51, 1, 96, 0, 17, 2, 86, 
    3, 66, 0, 78, 2, 56, 4,  2, 5, 88, 1, 26, 6, 45, 8, 11, 7,  4, 
    8, 34, 0,  3, 4, 19, 1, 37, 5,  8, 7, 51, 2, 27, 6, 64, 3, 85, 
    0, 31, 3, 71, 6, 67, 5, 84, 1, 70, 2, 65, 4, 45, 7, 68, 8, 58
  };
  const int q2551[] = {
    9, 9, // Number of jobs and machines
    6, 66, 7, 87, 1, 24, 8,  8, 4, 79, 0, 30, 2, 51, 3, 82, 5, 68, 
    7, 59, 8, 36, 2, 20, 4, 70, 3, 50, 6,  6, 5, 86, 1, 25, 0, 59, 
    5, 44, 4, 18, 8, 15, 3,  2, 6, 33, 7, 63, 2, 71, 1,  3, 0, 20, 
    2, 43, 4, 98, 6, 80, 3, 26, 5, 20, 0, 55, 7, 21, 1, 83, 8, 93, 
    8, 65, 6,  4, 3, 35, 1, 25, 7, 59, 0, 56, 2, 82, 4, 96, 5, 88, 
    8, 73, 1, 11, 6, 14, 2, 69, 7, 85, 4, 28, 3, 99, 0, 89, 5, 63, 
    1, 81, 8, 33, 6, 96, 3, 61, 4, 72, 7, 73, 0, 40, 2, 51, 5, 32, 
    0, 41, 1, 90, 3, 42, 6, 53, 8, 10, 5, 47, 2, 36, 7, 50, 4, 76, 
    2, 46, 1, 36, 0, 84, 3, 29, 4,  9, 7, 27, 5,  1, 6, 58, 8, 69
  };
  const int q2552[] = {
    9, 9, // Number of jobs and machines
    6, 71, 4, 17, 1, 24, 7, 48, 8, 51, 2, 93, 3, 94, 0, 27, 5, 29, 
    8, 43, 6, 67, 7, 66, 3, 55, 2, 93, 4, 82, 0, 24, 1, 41, 5, 83, 
    7,  5, 5, 32, 6, 21, 2, 39, 8,  2, 4, 48, 1, 32, 0, 12, 3, 97, 
    8, 95, 1, 40, 6, 52, 3,  2, 4, 34, 2, 50, 0,  4, 7, 68, 5, 33, 
    0, 17, 8, 89, 1, 83, 3, 54, 7, 80, 6, 23, 2, 95, 4, 97, 5, 61, 
    8, 34, 4, 77, 7, 38, 0, 11, 3, 25, 6, 60, 5, 85, 2, 20, 1, 88, 
    5, 51, 2, 72, 3, 30, 1, 73, 8,  7, 6, 27, 7, 96, 0, 57, 4, 26, 
    5, 15, 4, 26, 1, 24, 2, 96, 7, 29, 8, 14, 6, 52, 3, 96, 0,  9, 
    8, 79, 7, 46, 5, 80, 3, 68, 1, 36, 0, 52, 4, 84, 2, 94, 6, 36
  };
  const int q2553[] = {
    9, 9, // Number of jobs and machines
    5, 49, 6, 17, 2, 59, 7, 90, 8, 72, 3, 87, 4, 48, 0, 21, 1, 89, 
    1, 66, 4, 54, 3,  3, 0, 21, 6,  3, 5, 89, 2, 96, 7, 60, 8, 52, 
    8, 25, 7, 93, 0, 65, 5, 17, 1, 48, 3, 29, 2, 59, 4, 96, 6, 20, 
    3, 74, 7, 87, 8, 71, 2, 11, 1, 31, 0, 54, 6, 45, 5, 49, 4, 15, 
    1,  7, 8, 14, 7, 91, 0, 74, 5, 23, 6, 21, 3, 75, 2, 25, 4, 60, 
    4,  5, 7, 30, 0,  4, 6, 81, 5, 72, 2, 69, 3, 35, 1, 47, 8, 76, 
    5, 81, 1, 44, 3, 98, 4, 31, 2,  9, 0, 66, 6,  1, 8, 24, 7, 75, 
    7, 66, 3, 58, 2,  3, 8, 10, 5,  7, 4, 22, 0, 95, 1,  9, 6, 28, 
    2, 54, 0, 14, 4, 55, 3, 41, 8, 96, 1,  6, 7, 17, 6,  9, 5, 74
  };
  const int q2554[] = {
    9, 9, // Number of jobs and machines
    5, 17, 0, 48, 2,  1, 1, 86, 7, 47, 6, 90, 3, 10, 4, 83, 8, 68, 
    0,  7, 2, 93, 4, 58, 3, 15, 7, 55, 8, 18, 5, 90, 1, 29, 6, 24, 
    2,  2, 5, 92, 8, 21, 3, 99, 0,  5, 4, 57, 7, 51, 1, 71, 6, 50, 
    1, 63, 3, 79, 4, 36, 7, 40, 8,  6, 5, 71, 2, 22, 0, 96, 6, 18, 
    1, 64, 8, 30, 6, 44, 0, 83, 7, 36, 5, 31, 3, 44, 4, 31, 2, 64, 
    5, 63, 7, 59, 6, 72, 2, 93, 8, 78, 4, 44, 1, 61, 0, 50, 3, 18, 
    5, 33, 3, 70, 1, 42, 6, 79, 8, 17, 0,  1, 2, 10, 7, 36, 4, 89, 
    0, 33, 8, 99, 5, 12, 6, 14, 1, 59, 2, 64, 3, 85, 4, 73, 7, 30, 
    6, 50, 7, 16, 3, 62, 2, 68, 8, 61, 4, 47, 5, 85, 0, 33, 1, 31
  };
  const int q2555[] = {
    9, 9, // Number of jobs and machines
    7, 10, 4, 56, 0, 64, 5, 91, 2, 58, 6, 43, 1, 24, 3,  6, 8, 95, 
    8, 72, 1, 47, 2,  1, 3, 19, 6, 32, 7, 38, 0, 96, 4, 33, 5, 21, 
    8,  4, 2, 35, 3,  8, 0, 30, 1, 15, 6, 73, 4, 79, 7, 87, 5, 71, 
    4, 69, 3, 92, 2, 72, 5, 31, 7, 45, 8, 16, 0, 74, 6, 69, 1, 66, 
    0, 92, 3, 40, 2, 98, 1, 20, 4, 11, 8,  2, 7, 34, 6, 99, 5, 83, 
    2, 44, 7, 21, 5, 17, 4, 48, 6, 26, 1, 36, 8, 32, 3, 26, 0, 16, 
    2, 22, 1, 36, 3, 82, 6, 95, 5, 80, 7, 69, 4, 79, 0, 28, 8, 13, 
    5, 31, 7, 92, 0, 85, 3, 82, 8, 75, 1, 83, 2, 40, 6, 39, 4, 80, 
    2,  6, 8, 20, 5, 79, 0, 79, 1, 71, 7, 74, 4, 57, 3, 80, 6, 15
  };
  const int q2556[] = {
    9, 9, // Number of jobs and machines
    2, 44, 0, 74, 5, 99, 7, 25, 1, 18, 8, 89, 6, 88, 4, 91, 3, 26, 
    4, 66, 2, 19, 0, 56, 1, 94, 5, 61, 3, 91, 6, 32, 8, 69, 7, 44, 
    8, 35, 1, 89, 5, 56, 6,  3, 4, 85, 0, 84, 7, 74, 3, 51, 2, 99, 
    7, 81, 4, 63, 1, 18, 6, 60, 2, 13, 8, 25, 3, 45, 5, 12, 0, 88, 
    8, 84, 4, 93, 2, 72, 6, 30, 5, 62, 1, 18, 3, 73, 0,  6, 7, 80, 
    4, 36, 3, 71, 8,  5, 0, 37, 1, 36, 2,  4, 7, 40, 6, 96, 5, 47, 
    3, 37, 4, 57, 2, 49, 5, 53, 7, 36, 1, 99, 6, 38, 0, 55, 8,  1, 
    6, 97, 7, 98, 5, 81, 3, 78, 8, 18, 2, 47, 0, 32, 4, 92, 1, 75, 
    3, 47, 8, 89, 0, 94, 7, 16, 2, 45, 4, 16, 1, 18, 6, 93, 5, 34
  };
  const int q2557[] = {
    9, 9, // Number of jobs and machines
    7, 34, 5, 42, 6,  4, 1, 37, 4, 62, 3, 39, 8, 19, 0, 12, 2, 42, 
    2, 41, 7, 18, 4, 47, 6, 70, 1, 46, 8, 69, 5, 58, 3, 28, 0, 79, 
    6,  8, 3, 57, 2, 95, 7, 12, 1, 24, 5,  2, 8, 15, 4, 37, 0, 77, 
    0, 11, 1, 50, 6, 84, 7, 63, 8, 69, 4, 57, 5,  3, 2, 30, 3, 74, 
    0,  8, 3, 82, 7, 53, 4, 67, 8, 83, 1, 97, 5, 35, 6, 34, 2, 34, 
    6, 24, 0, 25, 3, 31, 8, 68, 4, 66, 5, 72, 1, 34, 2, 22, 7, 81, 
    5, 99, 2, 27, 3, 45, 0, 23, 4, 66, 8, 41, 7, 48, 6, 15, 1, 49, 
    8, 40, 2, 28, 5, 31, 4, 25, 0, 49, 7, 27, 1,  4, 6, 11, 3, 69, 
    4,  3, 7, 92, 8, 37, 1,  2, 2, 94, 0, 45, 5, 51, 3, 90, 6, 31
  };
  const int q2558[] = {
    9, 9, // Number of jobs and machines
    2, 83, 0, 95, 4, 76, 1, 84, 8, 83, 6, 64, 5, 28, 7, 99, 3, 80, 
    2, 38, 1, 45, 8, 28, 6, 75, 7, 73, 0, 73, 5, 73, 3,  8, 4, 66, 
    8, 49, 5,  6, 7, 69, 2, 43, 4, 30, 6, 27, 0, 66, 3, 53, 1, 50, 
    1, 63, 3, 24, 4,  7, 0, 99, 7, 59, 8, 70, 6, 70, 5, 66, 2, 89, 
    5, 37, 3,  9, 0, 13, 1, 71, 4, 62, 2, 70, 6, 77, 7, 45, 8, 81, 
    8, 33, 7, 46, 5, 57, 6,  2, 1, 35, 3, 78, 4, 46, 2, 34, 0, 10, 
    4, 50, 6, 74, 8, 66, 5,  7, 0, 65, 2, 69, 1, 75, 3,  3, 7, 51, 
    3, 77, 7, 41, 6, 12, 4, 65, 8, 91, 0, 58, 1, 65, 2,  4, 5, 84, 
    1, 64, 8, 20, 0,  1, 4, 64, 5,  5, 6, 14, 7, 30, 3, 87, 2, 85
  };
  const int q2559[] = {
    9, 9, // Number of jobs and machines
    1, 21, 0, 75, 3, 10, 2,  9, 4, 60, 5, 94, 7, 20, 6, 28, 8, 43, 
    2, 69, 0, 97, 6,  7, 3, 18, 1, 29, 5, 29, 7, 69, 8, 78, 4, 19, 
    2, 37, 6, 79, 7, 27, 5,  5, 0,  5, 1, 45, 8, 38, 3, 26, 4, 90, 
    5, 65, 6, 24, 7, 88, 3, 43, 2,  5, 1, 19, 0, 39, 4, 21, 8, 36, 
    8, 62, 7, 19, 2, 81, 4, 52, 5, 87, 0, 85, 3, 82, 6, 99, 1, 38, 
    2, 65, 7, 82, 4, 60, 0, 36, 1, 14, 6, 17, 3, 58, 5, 97, 8, 39, 
    3, 10, 6, 61, 4, 80, 0, 78, 5,  3, 2,  4, 8, 53, 1, 90, 7, 17, 
    5,  5, 8, 41, 1, 56, 7,  8, 2, 62, 4,  2, 6, 91, 0, 87, 3, 49, 
    1, 57, 3, 83, 7, 41, 8, 34, 2, 81, 0, 67, 5, 90, 4, 58, 6,  6
  };
  const int q2560[] = {
    9, 9, // Number of jobs and machines
    5, 31, 7, 40, 6, 11, 8, 84, 1, 64, 0, 71, 2,  4, 3, 24, 4, 95, 
    5, 73, 6, 27, 2, 61, 1, 23, 3, 27, 8, 10, 0, 22, 7, 53, 4, 13, 
    1, 82, 7, 73, 8, 84, 2, 66, 3, 57, 6, 32, 5, 43, 0, 63, 4, 55, 
    6, 63, 7, 99, 2, 92, 8, 56, 5, 71, 0, 43, 4, 46, 3, 32, 1,  5, 
    8, 69, 2, 33, 0, 71, 1, 88, 4, 19, 5, 54, 3, 11, 7, 13, 6, 81, 
    2, 38, 0, 23, 7,  3, 3, 84, 6, 99, 8, 22, 1, 49, 4, 22, 5, 20, 
    7, 51, 1, 11, 8, 59, 6, 64, 4, 77, 5, 78, 3, 19, 2, 50, 0, 81, 
    8, 79, 4, 31, 3, 21, 1, 74, 5,  2, 0, 88, 6,  1, 2, 32, 7, 80, 
    2, 65, 8, 29, 0, 22, 3, 83, 6, 48, 7, 35, 4, 32, 1, 65, 5, 18
  };
  const int q2561[] = {
    9, 9, // Number of jobs and machines
    7, 15, 1, 33, 3, 65, 8, 91, 5, 46, 2, 57, 6, 20, 4, 15, 0, 49, 
    8, 96, 3,  7, 0, 71, 4, 24, 1, 22, 5, 70, 7, 58, 6, 76, 2, 68, 
    3, 78, 5, 46, 0, 31, 2, 45, 4, 40, 6, 14, 8, 59, 7, 29, 1, 94, 
    2, 41, 3, 75, 7, 95, 1, 29, 0, 18, 5, 41, 4, 35, 6, 89, 8, 95, 
    6, 82, 8, 13, 2, 39, 1, 93, 7, 50, 0, 75, 3, 78, 5, 98, 4, 40, 
    8,  5, 1, 58, 5, 45, 6, 58, 3, 31, 7, 66, 2, 72, 4, 14, 0, 62, 
    1, 90, 8, 11, 7, 59, 4, 30, 5, 45, 0, 28, 3, 69, 6, 19, 2, 73, 
    5, 63, 1, 32, 0, 74, 2, 81, 8, 25, 3, 99, 4, 94, 7, 37, 6, 32, 
    0, 26, 2, 78, 5, 38, 8, 60, 1, 79, 6, 62, 3, 46, 7, 51, 4, 66
  };
  const int q2562[] = {
    9, 9, // Number of jobs and machines
    8,  8, 7, 40, 6, 36, 5, 72, 2, 97, 1, 68, 0, 21, 4, 61, 3, 12, 
    8, 95, 4, 96, 6, 66, 5, 91, 2, 17, 0, 14, 1, 37, 7, 62, 3,  6, 
    5, 23, 4, 47, 1, 84, 0, 62, 2, 70, 7, 70, 6, 98, 8, 74, 3, 45, 
    0, 77, 6, 46, 3, 81, 5, 62, 8, 57, 2, 14, 1, 53, 7, 48, 4, 27, 
    4, 15, 1, 89, 0, 88, 7, 73, 3, 52, 8, 10, 5, 28, 2, 64, 6, 46, 
    4, 32, 2, 36, 1, 75, 5, 37, 3, 70, 0, 95, 6, 88, 8, 93, 7, 27, 
    6, 51, 5, 87, 2,  8, 4, 19, 3, 90, 8, 83, 1, 91, 0, 16, 7, 19, 
    3, 53, 2, 18, 1, 23, 0,  9, 8, 78, 6, 31, 4,  8, 7, 48, 5, 20, 
    0,  9, 6, 51, 8, 41, 4, 77, 1,  6, 3, 49, 5, 36, 7, 31, 2, 95
  };
  const int q2563[] = {
    9, 9, // Number of jobs and machines
    2, 35, 6, 95, 0, 80, 3,  1, 1, 23, 4, 28, 7, 15, 8, 34, 5, 63, 
    6, 50, 5, 62, 8, 85, 2, 99, 3, 43, 0, 16, 7, 95, 4, 99, 1, 84, 
    8, 71, 3, 79, 0, 53, 2, 53, 6, 12, 5, 69, 4, 69, 7, 98, 1, 43, 
    0, 15, 8, 80, 6, 68, 4,  2, 7, 68, 1, 88, 3, 92, 5, 27, 2, 37, 
    5, 60, 3, 61, 2,  2, 6, 19, 8, 64, 1, 47, 7, 35, 0, 44, 4, 90, 
    7, 59, 5, 56, 6, 53, 4, 45, 3, 60, 1, 10, 8, 32, 0, 71, 2, 56, 
    3, 89, 5, 23, 2, 82, 8, 10, 0, 28, 1, 63, 7, 14, 6, 18, 4, 27, 
    3, 27, 2, 52, 0, 58, 1, 13, 8, 34, 6, 51, 5, 38, 4, 63, 7, 62, 
    2, 63, 7, 22, 1, 47, 5, 99, 3, 97, 6, 36, 4, 63, 0, 19, 8, 29
  };
  const int q2564[] = {
    9, 9, // Number of jobs and machines
    5, 58, 1, 58, 2, 30, 8, 23, 7, 43, 4, 67, 3, 24, 6, 89, 0, 67, 
    2, 49, 4, 34, 8, 80, 5, 96, 1, 69, 3, 15, 0, 64, 7, 31, 6, 45, 
    8, 19, 5, 97, 2, 12, 7, 95, 3, 57, 1, 55, 6,  6, 0, 92, 4, 70, 
    5, 99, 0, 79, 1, 97, 6, 80, 7, 62, 3, 53, 4, 33, 8, 13, 2, 79, 
    6, 88, 0, 47, 4,  7, 8, 96, 1, 47, 3, 70, 5,  7, 2, 46, 7, 59, 
    3, 71, 5, 95, 0, 43, 6, 16, 7, 29, 1, 70, 2, 14, 4, 72, 8, 58, 
    1, 71, 6, 80, 4,  7, 7, 99, 5, 93, 0, 51, 8, 86, 3, 91, 2, 10, 
    0, 67, 1, 94, 2, 84, 8, 13, 6, 88, 3, 63, 5, 34, 7,  5, 4, 74, 
    3, 35, 2, 85, 5, 90, 7, 55, 8, 46, 1,  8, 0, 62, 6, 62, 4, 32
  };
  const int q2565[] = {
    9, 9, // Number of jobs and machines
    6, 25, 2, 53, 4, 77, 0, 74, 5, 80, 7, 52, 1, 78, 3, 34, 8, 44, 
    8, 55, 3, 96, 6,  2, 5, 97, 1, 33, 0,  7, 7, 96, 2, 81, 4, 99, 
    3, 30, 6, 50, 5, 32, 1, 54, 4, 79, 0, 31, 7, 15, 8, 88, 2, 37, 
    7, 26, 3,  3, 6,  7, 1, 83, 2, 41, 5, 39, 4, 92, 0, 16, 8, 55, 
    8, 56, 3, 54, 2, 11, 4, 95, 1, 18, 5, 83, 7, 94, 0, 49, 6, 44, 
    6, 36, 7,  7, 8, 98, 1,  3, 0, 79, 5, 96, 3, 82, 4, 17, 2, 60, 
    6,  7, 8, 23, 7, 27, 2, 47, 0, 54, 4, 10, 1, 89, 3, 77, 5, 51, 
    4, 57, 0, 82, 6,  9, 7, 43, 8, 38, 2, 42, 5, 20, 3, 35, 1, 39, 
    8, 44, 6, 26, 3, 42, 5, 90, 2, 43, 1, 91, 0, 83, 4, 30, 7, 55
  };
  const int q2566[] = {
    9, 9, // Number of jobs and machines
    5, 82, 7, 76, 1, 91, 6, 95, 8, 45, 4, 33, 2, 18, 3,  7, 0,  7, 
    1, 84, 2, 45, 8, 26, 5,  4, 4, 94, 6, 90, 3, 57, 0, 55, 7, 11, 
    2, 99, 5, 94, 3, 74, 0,  4, 4, 21, 1, 59, 6, 19, 8, 19, 7, 39, 
    6,  5, 7,  9, 5, 38, 2, 96, 8,  2, 4, 92, 0, 53, 3, 92, 1, 37, 
    5, 23, 8,  2, 6, 61, 7, 68, 1, 48, 4,  1, 3, 48, 0, 34, 2, 61, 
    8, 49, 2, 27, 0, 22, 1, 37, 3,  1, 4, 20, 6, 48, 7, 45, 5, 43, 
    0, 18, 5, 76, 6, 52, 1, 15, 7, 31, 2, 13, 4, 92, 8, 54, 3, 69, 
    1, 96, 0, 65, 5, 27, 3, 66, 2, 91, 4, 65, 8, 36, 6, 90, 7, 83, 
    6, 57, 4, 56, 8, 63, 2, 33, 7, 12, 5,  7, 0, 16, 3, 39, 1, 97
  };
  const int q2567[] = {
    9, 9, // Number of jobs and machines
    6, 73, 2, 23, 1,  9, 0, 94, 5, 93, 3, 56, 7, 59, 8, 86, 4, 22, 
    7, 39, 3, 50, 6, 60, 4, 67, 2, 42, 1, 39, 5, 47, 8, 60, 0, 47, 
    6, 51, 7, 58, 4, 61, 8, 30, 5, 42, 2, 32, 1, 57, 0, 77, 3, 96, 
    4, 41, 3, 22, 1, 35, 2, 29, 6, 85, 7, 62, 8,  5, 0, 29, 5, 82, 
    7, 25, 5, 55, 3, 70, 6, 24, 0, 80, 1, 50, 2, 77, 8, 32, 4, 93, 
    1, 40, 5, 58, 0, 37, 8, 92, 2, 86, 6, 40, 4, 77, 7, 53, 3, 66, 
    8, 94, 5, 11, 4, 82, 3, 69, 0, 82, 1, 79, 7, 16, 6, 41, 2, 57, 
    4, 12, 1, 24, 5, 98, 3, 55, 7,  5, 0, 92, 2, 21, 6, 64, 8, 84, 
    3, 62, 4, 45, 8, 94, 7, 41, 0, 85, 2, 45, 1, 93, 6, 65, 5, 90
  };
  const int q2568[] = {
    9, 9, // Number of jobs and machines
    1, 84, 7, 50, 8, 47, 0, 22, 3, 90, 6, 25, 4, 16, 2, 15, 5,  1, 
    3, 78, 6,  9, 2, 37, 5, 12, 0, 27, 8, 20, 1, 38, 7, 82, 4, 85, 
    3, 28, 6, 15, 8, 35, 4, 20, 7, 37, 1, 66, 2, 98, 0, 53, 5, 81, 
    3, 96, 1, 74, 8, 15, 5, 77, 4, 38, 7, 65, 0, 49, 6, 51, 2, 72, 
    5, 60, 2, 75, 3, 40, 1, 96, 6, 59, 4, 59, 0, 87, 8, 67, 7, 33, 
    7, 55, 3, 39, 6, 68, 1, 98, 8, 86, 4, 72, 2, 26, 0, 74, 5, 58, 
    2, 72, 6, 68, 7, 35, 4, 66, 0, 23, 3, 67, 5, 99, 1, 56, 8, 13, 
    7, 81, 4, 92, 6, 67, 5, 81, 1, 35, 8, 77, 0, 50, 2, 10, 3, 16, 
    6, 10, 0, 31, 5, 33, 2, 80, 7, 95, 8, 66, 3, 70, 1,  2, 4, 43
  };
  const int q2569[] = {
    9, 9, // Number of jobs and machines
    4, 36, 6, 10, 1, 91, 3, 46, 7, 10, 2, 27, 5, 95, 8, 88, 0, 58, 
    5, 64, 4, 11, 7, 20, 3, 51, 0, 56, 6, 56, 8, 21, 2, 11, 1, 84, 
    4, 20, 3,  3, 2, 23, 0, 83, 8, 82, 5, 66, 1, 32, 6, 55, 7, 96, 
    8, 43, 0, 53, 2,  9, 5, 72, 6, 37, 4, 46, 3, 36, 1, 73, 7, 86, 
    6, 70, 7, 80, 2, 92, 1, 37, 5, 81, 4, 77, 8,  9, 3, 96, 0, 65, 
    4, 53, 1, 41, 3, 77, 2, 84, 7, 22, 5, 54, 0, 12, 8, 74, 6, 42, 
    8, 87, 4, 26, 7, 70, 2, 14, 3, 59, 0, 50, 6, 68, 5,  9, 1, 75, 
    5, 78, 4,  2, 1, 10, 3, 37, 0, 21, 8, 38, 2, 76, 7, 40, 6, 20, 
    4, 31, 8, 73, 7, 42, 5, 17, 1,  2, 6, 75, 3, 99, 0, 77, 2, 94
  };
  const int q2570[] = {
    9, 9, // Number of jobs and machines
    8, 42, 6, 69, 5, 31, 4,  9, 2, 27, 7, 70, 1, 19, 0, 15, 3, 34, 
    1, 53, 4, 40, 7, 35, 8, 69, 3, 28, 5, 54, 6, 24, 0, 41, 2,  4, 
    0, 25, 3, 18, 5, 63, 1, 89, 7, 26, 2,  5, 4, 38, 8, 92, 6, 17, 
    7, 83, 8, 66, 3, 85, 5, 36, 4,  3, 2,  8, 1, 46, 6, 67, 0, 81, 
    6, 14, 7, 47, 1,  9, 2, 49, 5, 18, 4, 44, 3, 89, 0, 69, 8, 82, 
    0, 86, 5, 12, 6, 30, 3, 61, 8, 88, 2, 54, 4, 73, 7, 35, 1, 13, 
    1, 75, 2, 71, 3, 40, 0, 22, 5, 58, 7,  3, 4, 97, 8, 83, 6, 14, 
    7, 85, 5, 69, 8, 80, 1, 29, 3, 97, 6,  1, 2, 95, 0, 71, 4, 42, 
    4,  5, 2, 13, 3,  3, 8, 77, 7, 99, 6, 79, 5, 95, 1, 94, 0,  5
  };
  const int q2571[] = {
    9, 9, // Number of jobs and machines
    0, 90, 6, 36, 2, 93, 7, 44, 5, 32, 3,  3, 4,  8, 8, 74, 1, 44, 
    1, 82, 0, 58, 8, 60, 3,  4, 7,  2, 6, 53, 2, 59, 4, 85, 5, 27, 
    0, 94, 6, 14, 8, 51, 3, 58, 7, 42, 4, 34, 5,  9, 1, 52, 2, 12, 
    3, 65, 0, 75, 7, 92, 8, 42, 5, 49, 2, 65, 4, 28, 1, 78, 6, 69, 
    1, 95, 8, 53, 0, 50, 4, 46, 7, 16, 2, 28, 3, 36, 6, 72, 5, 36, 
    5, 78, 3, 13, 6, 38, 1, 49, 2, 11, 0, 81, 8, 27, 7,  4, 4, 21, 
    5, 17, 8, 84, 7, 57, 0, 37, 6, 21, 2, 92, 4, 86, 1, 50, 3, 15, 
    2,  3, 8, 55, 7, 13, 3,  6, 6, 15, 1, 97, 4, 10, 0, 14, 5, 11, 
    1, 12, 8, 36, 4, 66, 3, 86, 6, 57, 7, 65, 2, 73, 5, 33, 0, 22
  };
  const int q2572[] = {
    9, 9, // Number of jobs and machines
    2, 40, 3, 92, 8, 56, 7, 95, 1, 30, 0, 28, 6, 15, 4, 21, 5, 93, 
    1, 27, 4, 56, 2, 71, 0, 58, 8,  7, 6, 48, 5, 16, 7, 34, 3, 18, 
    7,  4, 1,  1, 4, 35, 0, 85, 2, 13, 6, 25, 8,  8, 3, 95, 5, 70, 
    2, 69, 6, 33, 5, 58, 1, 33, 4,  3, 8, 42, 7, 67, 3, 78, 0, 56, 
    4, 54, 8, 87, 7, 86, 1, 54, 2, 56, 6, 98, 3, 25, 5, 85, 0, 49, 
    2, 92, 3, 51, 5, 35, 0, 26, 8, 62, 6, 92, 1, 38, 7, 76, 4, 84, 
    4, 71, 1, 32, 0, 57, 2, 13, 7, 40, 8, 46, 6, 21, 5, 22, 3, 58, 
    7, 95, 6,  2, 3, 90, 1, 63, 5, 77, 4, 79, 8, 94, 0, 18, 2, 96, 
    3, 20, 2, 14, 7, 80, 8, 43, 0, 65, 5, 19, 6, 72, 1, 22, 4, 48
  };
  const int q2573[] = {
    9, 9, // Number of jobs and machines
    5, 52, 1, 89, 8, 68, 6, 16, 7,  3, 4, 50, 3, 23, 0, 48, 2, 62, 
    4, 20, 7,  7, 8, 38, 3, 65, 2, 88, 1,  7, 0, 54, 6, 38, 5, 33, 
    1, 70, 3, 54, 0, 95, 7, 45, 8, 51, 6, 82, 5, 88, 4,  8, 2, 12, 
    3, 88, 2, 19, 4, 27, 7, 35, 8,  9, 0, 34, 6, 35, 1, 22, 5, 16, 
    0, 79, 6, 38, 7, 32, 1,  5, 5, 73, 3, 26, 2, 16, 8, 99, 4, 76, 
    2, 81, 4, 61, 3, 32, 6, 22, 7, 71, 1, 66, 8, 90, 5, 64, 0, 45, 
    3, 82, 7, 88, 2, 12, 8, 94, 0, 24, 1, 79, 4, 65, 6, 16, 5, 72, 
    3, 44, 1, 73, 7, 46, 5, 51, 4, 96, 0, 96, 2, 51, 8, 67, 6, 13, 
    5, 82, 6,  4, 8,  6, 2, 41, 1, 39, 4, 78, 7, 16, 3, 70, 0, 12
  };
  const int q2574[] = {
    9, 9, // Number of jobs and machines
    0, 77, 7, 22, 5,  7, 1, 33, 4, 27, 2, 80, 3,  6, 8, 44, 6, 76, 
    8, 27, 0, 49, 7, 61, 3, 16, 6, 30, 1, 39, 2, 87, 5,  7, 4, 64, 
    4, 89, 7, 90, 8, 51, 2, 46, 1, 59, 5, 60, 3, 19, 6,  4, 0, 81, 
    7, 40, 3, 34, 4, 18, 2, 80, 1, 35, 8, 50, 0, 40, 6, 95, 5, 74, 
    5, 88, 6, 41, 0, 53, 8, 34, 7, 75, 2, 86, 1, 69, 3, 27, 4, 10, 
    3, 63, 2, 65, 1, 21, 8, 94, 4, 93, 6, 13, 5, 26, 0, 16, 7, 79, 
    1, 68, 6, 98, 2, 72, 0, 43, 8, 43, 4, 14, 3, 67, 5, 83, 7, 64, 
    0, 61, 7, 33, 1, 17, 2, 36, 5, 31, 3, 67, 6, 55, 8, 10, 4, 21, 
    3, 17, 0, 67, 6, 44, 4, 15, 5, 84, 7, 86, 2, 74, 1, 10, 8, 19
  };
  const int q2575[] = {
    9, 9, // Number of jobs and machines
    0, 79, 3, 69, 1, 67, 2, 61, 7, 24, 4, 73, 5, 40, 8,  8, 6, 20, 
    7, 46, 2, 27, 3, 54, 8, 41, 6, 61, 4,  5, 0, 47, 1, 48, 5, 70, 
    5, 96, 6, 75, 0, 99, 1, 98, 2, 29, 7, 95, 4, 58, 8, 94, 3, 47, 
    4, 63, 5, 47, 0, 65, 3,  3, 7, 53, 2, 79, 6, 62, 1, 48, 8, 79, 
    3, 97, 1, 21, 8, 20, 5, 33, 7, 81, 4, 41, 0, 62, 6, 83, 2, 91, 
    3, 50, 2, 72, 8, 91, 6, 68, 7, 77, 1, 47, 5, 65, 4,  7, 0, 20, 
    5, 22, 0,  4, 8, 90, 2, 13, 3, 76, 6,  5, 7,  3, 4, 24, 1, 37, 
    8, 81, 0, 78, 7, 98, 4, 93, 5, 93, 3, 25, 2, 20, 6, 91, 1, 37, 
    3, 86, 4, 49, 2, 53, 1, 99, 5, 21, 0, 98, 6,  6, 7, 13, 8, 84
  };
  const int q2576[] = {
    9, 9, // Number of jobs and machines
    6, 44, 2, 86, 8, 51, 4, 20, 1, 49, 5, 48, 0, 15, 3, 58, 7, 56, 
    8, 87, 5, 40, 7, 53, 6, 95, 0, 99, 4, 12, 3, 42, 1, 62, 2,  1, 
    8, 12, 3, 45, 6, 92, 0, 98, 7, 71, 5, 45, 4, 26, 1, 35, 2, 83, 
    7, 88, 5,  6, 6, 53, 3, 27, 1, 33, 0, 66, 8, 50, 4, 83, 2, 82, 
    5,  4, 6, 58, 3,  7, 2, 21, 8, 37, 1, 20, 0, 50, 4, 58, 7, 61, 
    5, 71, 4, 61, 1, 56, 8, 31, 6, 72, 0, 92, 2, 20, 7, 41, 3, 82, 
    0, 53, 5, 12, 1, 14, 2, 58, 4,  8, 6, 47, 3, 61, 8, 59, 7, 51, 
    8, 91, 1,  4, 0, 32, 2, 91, 7,  8, 6, 16, 3, 23, 5,  1, 4, 19, 
    3, 79, 4, 47, 6, 95, 1,  6, 7, 16, 8, 79, 2, 79, 0, 34, 5, 98
  };
  const int q2577[] = {
    9, 9, // Number of jobs and machines
    3, 39, 0, 55, 6, 82, 5, 66, 4, 58, 2, 84, 8, 79, 7, 31, 1, 95, 
    4, 95, 1, 44, 3, 80, 0, 63, 7, 58, 6, 66, 2, 95, 8, 29, 5,  1, 
    1, 24, 6, 69, 2, 72, 4, 58, 3, 74, 5, 65, 0, 80, 8, 54, 7, 45, 
    8, 92, 6, 38, 0, 44, 4, 19, 1, 92, 3, 16, 2, 34, 7, 26, 5, 71, 
    1, 56, 6,  9, 8,  6, 3,  3, 4, 37, 7, 10, 0, 89, 5, 87, 2, 16, 
    4, 28, 6, 10, 3, 78, 1, 69, 0, 39, 5, 66, 2, 56, 7, 17, 8,  8, 
    2, 71, 7, 20, 8,  5, 6, 72, 3, 46, 1, 72, 0,  5, 5, 95, 4, 37, 
    7, 60, 6, 86, 0, 14, 5, 75, 1, 48, 3, 93, 4, 79, 2, 10, 8, 89, 
    2, 62, 6, 31, 8, 10, 3,  6, 7, 36, 5, 38, 1, 48, 0, 41, 4, 94
  };
  const int q2578[] = {
    9, 9, // Number of jobs and machines
    3, 82, 0, 25, 7, 67, 1, 16, 2, 78, 6,  5, 8, 65, 4, 69, 5, 59, 
    7, 51, 8, 59, 5, 43, 6, 38, 1, 85, 0,  5, 3, 48, 4, 96, 2, 16, 
    1, 98, 6, 55, 7, 11, 3, 85, 8,  9, 4, 74, 0, 47, 5, 80, 2, 89, 
    5,  2, 0, 55, 8, 22, 2, 77, 1, 96, 4, 40, 3,  2, 7, 68, 6, 65, 
    2, 50, 3, 71, 4, 84, 6, 44, 8, 65, 5, 46, 7, 48, 1, 28, 0, 97, 
    4, 70, 7, 77, 0,  1, 1, 38, 5, 46, 3, 18, 8, 99, 2, 69, 6, 14, 
    2,  1, 1, 50, 3, 49, 6, 57, 0, 66, 8, 47, 7, 78, 5, 25, 4, 90, 
    6, 30, 3, 77, 0, 91, 2, 40, 8,  8, 1, 75, 5, 31, 7, 11, 4, 51, 
    3, 78, 1, 93, 5, 11, 7, 50, 2, 49, 8,  2, 6, 60, 4, 70, 0,  3
  };
  const int q2579[] = {
    9, 9, // Number of jobs and machines
    5, 84, 1, 22, 6, 54, 2, 33, 4, 56, 0, 37, 7, 38, 8, 56, 3, 15, 
    4, 57, 1, 40, 5, 79, 7, 42, 8, 97, 6, 74, 0, 42, 3, 91, 2, 50, 
    5, 98, 7, 88, 8, 67, 1, 10, 2, 78, 4, 23, 6, 77, 3, 47, 0, 88, 
    2,  2, 4,  1, 5, 44, 0, 52, 8, 20, 3, 36, 1, 45, 7, 59, 6, 57, 
    2, 21, 3, 27, 1, 41, 6, 33, 4,  1, 5, 34, 8, 85, 0, 18, 7, 44, 
    0, 33, 8,  3, 4, 76, 1, 87, 7, 17, 3, 49, 6, 81, 5, 84, 2, 79, 
    4, 89, 6, 37, 0, 39, 3, 98, 7, 88, 2, 28, 8, 16, 1, 95, 5, 54, 
    1, 39, 3, 66, 8, 18, 6, 37, 4, 85, 0, 35, 7, 64, 2, 12, 5,  4, 
    5, 42, 4, 21, 0, 87, 7, 50, 6, 28, 1, 81, 3, 20, 8, 55, 2, 34
  };
  const int q2580[] = {
    9, 9, // Number of jobs and machines
    5, 20, 1, 86, 2, 73, 7,  8, 3, 65, 4,  8, 8, 88, 6, 14, 0, 95, 
    1, 17, 8, 21, 2, 69, 7, 83, 4, 38, 6, 94, 0, 53, 5, 99, 3, 78, 
    2, 30, 8, 82, 7, 57, 6, 40, 1, 75, 5,  8, 3, 40, 4, 32, 0, 54, 
    5, 34, 1, 90, 4, 57, 6, 46, 2, 91, 7, 88, 8, 30, 0, 98, 3, 35, 
    2, 12, 0, 71, 6, 10, 4, 62, 8, 25, 1, 13, 7, 98, 5,  2, 3, 31, 
    6, 82, 8, 64, 0, 14, 4, 28, 2, 10, 5, 39, 7, 37, 1, 55, 3, 53, 
    3, 97, 7, 70, 8, 33, 6, 53, 5,  1, 2, 88, 4, 27, 1, 39, 0, 50, 
    3, 54, 2, 73, 6, 69, 4, 65, 1, 83, 7, 34, 5, 42, 8, 54, 0, 67, 
    0, 33, 6, 54, 7, 86, 8, 89, 1, 35, 2, 83, 3, 86, 4, 72, 5, 13
  };
  const int q2581[] = {
    9, 9, // Number of jobs and machines
    1, 28, 0,  8, 8, 18, 5, 10, 2, 73, 6, 27, 7, 66, 3, 29, 4, 14, 
    2, 93, 1, 88, 5, 19, 6, 75, 4, 44, 8, 56, 7, 10, 3, 16, 0, 90, 
    6, 52, 7, 13, 3, 64, 8, 56, 0, 66, 4, 11, 5, 74, 1, 76, 2, 75, 
    4, 72, 2,  4, 8, 23, 7, 95, 5, 63, 3, 91, 1, 98, 6, 56, 0, 93, 
    0, 52, 7,  8, 8, 72, 2, 16, 4, 62, 1, 83, 6, 70, 3, 49, 5,  8, 
    0, 58, 5, 78, 2, 46, 6, 12, 1, 90, 4, 41, 8, 61, 7, 81, 3, 69, 
    3, 67, 8, 65, 4, 45, 2, 13, 5,  1, 6,  9, 0, 78, 7, 38, 1, 78, 
    3,  3, 1, 47, 2,  8, 8, 44, 7, 73, 6, 85, 0, 27, 4, 67, 5, 96, 
    7, 52, 3, 63, 6, 29, 8,  4, 1, 39, 2, 65, 0, 15, 4, 84, 5, 24
  };
  const int q2582[] = {
    9, 9, // Number of jobs and machines
    8, 68, 3, 25, 1, 57, 2, 61, 0, 73, 4, 22, 7, 48, 6,  9, 5, 10, 
    7, 92, 2, 27, 1, 68, 6, 45, 3, 50, 5, 55, 4, 95, 0, 39, 8, 15, 
    4, 29, 6, 37, 7, 64, 1, 39, 8, 44, 3, 56, 0, 24, 5, 60, 2, 89, 
    5, 53, 6, 87, 7, 93, 4, 13, 8, 67, 2, 31, 0, 44, 1, 82, 3, 77, 
    8, 21, 0, 59, 6,  7, 5, 67, 1, 51, 2, 59, 3, 74, 4, 33, 7, 33, 
    3, 35, 7,  3, 0, 13, 4, 86, 5, 69, 8, 98, 6, 39, 1, 45, 2, 16, 
    8, 42, 6, 67, 7, 94, 4, 47, 0, 78, 5, 38, 1, 97, 3, 72, 2, 56, 
    5, 77, 0, 28, 6, 34, 8, 37, 2, 87, 1, 76, 7, 15, 4, 16, 3, 95, 
    7, 89, 2,  1, 8, 62, 1, 15, 4, 70, 6, 38, 3, 18, 0, 98, 5, 95
  };
  const int q2583[] = {
    9, 9, // Number of jobs and machines
    6,  9, 7, 24, 1, 72, 8, 43, 0, 70, 4, 17, 2, 30, 3, 50, 5, 82, 
    8, 49, 5, 39, 4, 80, 6, 95, 1, 39, 7, 57, 3, 42, 2, 82, 0, 14, 
    4, 26, 1, 38, 3, 15, 6, 12, 0, 30, 5, 70, 2, 20, 8, 15, 7, 89, 
    3, 28, 4,  4, 0, 79, 2, 27, 6, 62, 5, 25, 8, 38, 7, 53, 1, 10, 
    3, 10, 5, 17, 4, 33, 0, 35, 2, 77, 6, 22, 1, 43, 8, 27, 7, 39, 
    8, 48, 2, 84, 0, 38, 6, 83, 3, 28, 5, 65, 7, 43, 4, 79, 1,  4, 
    8, 94, 6, 41, 5, 14, 4,  4, 3, 35, 7,  3, 2,  7, 1, 39, 0, 30, 
    5, 25, 1, 58, 7, 88, 6, 99, 2, 60, 8, 63, 4, 44, 3, 78, 0, 25, 
    5, 21, 6,  8, 3, 26, 2, 68, 0, 20, 4, 42, 7, 93, 8, 82, 1, 45
  };
  const int q2584[] = {
    9, 9, // Number of jobs and machines
    5, 79, 6, 75, 0, 35, 7, 19, 1, 23, 2, 97, 3, 81, 4,  3, 8, 69, 
    4, 27, 3, 72, 8,  1, 1, 61, 6, 25, 7, 59, 0, 21, 2,  9, 5, 93, 
    7,  3, 6, 16, 8, 97, 0,  2, 4, 60, 1, 98, 5, 97, 3, 21, 2, 72, 
    1, 56, 0, 93, 7, 60, 5, 68, 3, 87, 8,  5, 6, 62, 2, 99, 4,  7, 
    2, 55, 7, 73, 3, 43, 8, 32, 1, 35, 0, 67, 6, 85, 5, 58, 4, 67, 
    4, 87, 8, 13, 7, 45, 6, 61, 3, 62, 0, 92, 1, 13, 2, 86, 5, 19, 
    7, 91, 4, 11, 6, 79, 1, 94, 5, 89, 0, 23, 8,  4, 3, 23, 2, 65, 
    3, 36, 6, 42, 7, 64, 4, 64, 2, 78, 8, 32, 1, 16, 0, 27, 5,  3, 
    7, 38, 6, 20, 4, 84, 8, 28, 2, 78, 1, 13, 5, 86, 3, 42, 0, 83
  };
  const int q2585[] = {
    9, 9, // Number of jobs and machines
    2, 45, 1, 95, 8, 98, 4,  7, 5, 28, 0, 20, 7, 59, 6, 32, 3, 20, 
    2, 89, 6, 94, 0, 41, 5, 55, 3, 68, 7, 87, 4, 18, 8, 14, 1, 60, 
    4, 80, 1, 20, 6, 69, 8, 21, 0, 24, 3, 68, 5, 83, 7, 99, 2, 95, 
    7, 68, 5,  6, 0, 55, 1, 94, 6, 21, 2, 38, 4, 12, 8, 35, 3, 86, 
    0, 55, 5, 24, 4, 54, 7, 95, 1, 45, 8, 43, 2, 98, 6, 80, 3, 80, 
    2, 64, 0, 12, 8, 18, 3, 87, 6,  4, 5,  3, 7, 86, 4, 69, 1, 22, 
    5, 49, 4,  9, 7, 54, 1, 79, 8, 77, 6, 19, 3, 25, 2,  5, 0,  4, 
    2,  6, 7, 82, 0, 15, 8,  4, 1,  4, 6, 84, 3, 96, 4, 27, 5,  4, 
    6, 44, 4, 15, 3, 77, 8, 49, 1, 96, 0, 30, 5,  3, 7, 19, 2, 62
  };
  const int q2586[] = {
    9, 9, // Number of jobs and machines
    6, 67, 2, 16, 1, 59, 8, 30, 5, 52, 7, 48, 3, 26, 4, 95, 0, 90, 
    4, 81, 0, 34, 2, 79, 8, 32, 1, 22, 3, 77, 6, 96, 7, 21, 5, 76, 
    1, 98, 4, 90, 0, 66, 6, 45, 3, 58, 2, 65, 8, 22, 5,  1, 7, 52, 
    1, 11, 2, 78, 8, 20, 7, 93, 6, 44, 5, 46, 3,  2, 4,  8, 0, 59, 
    6, 16, 0,  8, 3, 17, 8, 68, 7,  9, 4, 80, 2, 41, 1,  7, 5,  4, 
    1, 54, 2, 33, 3, 86, 8, 30, 7, 39, 4, 17, 0, 97, 6, 12, 5, 20, 
    1, 13, 7, 44, 8, 65, 6, 32, 0, 27, 2, 42, 3, 52, 4, 55, 5,  6, 
    1, 41, 0, 36, 4, 99, 8, 43, 6,  7, 5, 36, 7, 41, 2, 43, 3, 17, 
    4, 77, 1, 75, 6, 90, 5,  8, 2, 35, 3, 67, 8, 55, 0, 81, 7, 70
  };
  const int q2587[] = {
    9, 9, // Number of jobs and machines
    1, 20, 5, 45, 0, 77, 2, 63, 6,  1, 3, 95, 4, 41, 8, 49, 7, 62, 
    8, 54, 2, 43, 4, 69, 5, 17, 6, 16, 7, 61, 1, 22, 0, 61, 3, 51, 
    1, 74, 4, 35, 8, 91, 3, 61, 7, 16, 5, 34, 2, 15, 0, 26, 6, 17, 
    1, 46, 7,  9, 8, 59, 0, 38, 2, 17, 4, 82, 3, 66, 5, 34, 6,  3, 
    8, 76, 4, 66, 7, 77, 2, 88, 3, 98, 0, 35, 5, 76, 6, 92, 1, 62, 
    2, 87, 5, 97, 3, 25, 6, 60, 0, 72, 7, 23, 1, 31, 4, 63, 8, 94, 
    5, 40, 2, 95, 6,  8, 7, 87, 3, 27, 8,  2, 4, 13, 0, 99, 1, 70, 
    7, 89, 2, 17, 5, 11, 0, 44, 3, 89, 6, 42, 8, 20, 4, 32, 1, 49, 
    1, 56, 7, 81, 0, 63, 6, 82, 4, 54, 3, 72, 8,  3, 2, 96, 5, 46
  };
  const int q2588[] = {
    9, 9, // Number of jobs and machines
    2,  5, 0,  9, 4, 83, 7, 73, 3, 95, 6, 37, 1, 17, 5, 88, 8, 52, 
    0, 38, 6, 90, 2, 89, 8, 67, 3, 15, 5, 27, 1, 65, 4, 55, 7, 23, 
    7, 19, 0, 15, 3, 67, 2, 57, 6, 49, 5, 97, 4, 10, 1, 46, 8, 26, 
    7, 30, 3, 65, 0, 29, 2, 45, 8, 46, 4, 93, 6, 54, 5, 21, 1, 80, 
    6,  9, 8, 81, 2, 20, 5, 11, 0, 19, 7, 12, 4, 33, 3, 11, 1, 12, 
    5, 79, 7, 30, 8, 39, 3,  7, 6, 66, 4, 98, 1, 34, 2, 92, 0, 24, 
    5, 63, 2, 19, 8, 52, 7, 90, 3, 34, 1,  5, 6, 22, 0, 46, 4, 87, 
    6, 25, 2, 72, 4, 55, 0, 30, 5, 20, 3, 68, 7, 41, 8, 77, 1, 87, 
    1, 43, 2, 94, 5, 79, 0, 90, 8, 82, 4, 44, 3, 62, 7, 95, 6, 75
  };
  const int q2589[] = {
    9, 9, // Number of jobs and machines
    3, 85, 1, 75, 4, 42, 2, 58, 8, 23, 6, 49, 5, 16, 7, 85, 0, 93, 
    3, 93, 7, 33, 4, 73, 2,  2, 0, 72, 1, 64, 8, 33, 5, 88, 6, 28, 
    1, 21, 4, 39, 2, 63, 8, 19, 3, 82, 6, 13, 0, 45, 5, 62, 7, 90, 
    7, 64, 0, 16, 6, 25, 4, 51, 2, 88, 1, 28, 3, 34, 5, 14, 8, 41, 
    2, 44, 3,  5, 4,  2, 8, 59, 6, 82, 0, 32, 5, 52, 1, 49, 7, 10, 
    7, 61, 0, 47, 3, 70, 8, 48, 1,  2, 2, 61, 5, 74, 6, 17, 4, 63, 
    4, 71, 7, 76, 8, 19, 0, 54, 5, 19, 6,  5, 1, 44, 3, 92, 2, 33, 
    5, 29, 0, 88, 4, 48, 7,  8, 8, 80, 6, 37, 2, 40, 3,  5, 1, 15, 
    4, 31, 6, 71, 2, 33, 8, 31, 0, 84, 1, 36, 5, 56, 7, 21, 3, 82
  };
  const int q2590[] = {
    9, 9, // Number of jobs and machines
    7, 23, 4, 73, 8, 53, 2, 32, 5, 73, 6, 91, 3, 46, 0, 92, 1, 21, 
    8, 36, 2, 61, 5, 63, 7, 17, 4, 73, 1, 85, 6, 57, 0, 75, 3, 74, 
    0, 45, 8, 73, 2, 75, 3,  4, 4, 49, 5, 10, 6, 72, 7, 14, 1, 59, 
    0, 37, 1, 39, 3, 44, 6, 60, 8, 74, 4,  9, 5,  8, 7, 12, 2, 99, 
    2, 58, 6, 79, 3, 41, 8, 14, 7, 55, 1, 13, 4,  8, 0, 93, 5, 15, 
    2, 79, 0, 24, 7, 92, 4, 57, 5,  2, 1, 30, 3, 49, 6, 72, 8, 64, 
    1, 49, 7, 62, 6, 54, 2, 68, 0, 92, 5, 86, 3, 90, 8, 87, 4, 51, 
    6, 30, 3, 69, 1, 49, 5, 31, 7,  1, 4, 35, 8, 19, 2, 40, 0, 48, 
    2, 98, 4, 73, 0, 36, 5, 39, 3, 80, 8, 69, 1, 12, 6, 88, 7, 68
  };
  const int q2591[] = {
    9, 9, // Number of jobs and machines
    8, 10, 1, 84, 0, 30, 2, 41, 7, 53, 6, 89, 4,  2, 5,  4, 3, 89, 
    6, 13, 5, 88, 7, 56, 4, 68, 8,  7, 2, 73, 3, 88, 0, 14, 1, 13, 
    4, 56, 1, 78, 5, 57, 2, 90, 8, 93, 6, 58, 0, 57, 7, 30, 3, 70, 
    1, 10, 7, 96, 3, 54, 8, 62, 2, 67, 5, 30, 0, 70, 6, 72, 4, 20, 
    4, 41, 0, 41, 6, 46, 2, 34, 7,  5, 3,  4, 8, 24, 5, 91, 1,  6, 
    7, 61, 3, 41, 8, 23, 1, 14, 0, 53, 6, 66, 2, 87, 5, 49, 4, 36, 
    1, 33, 0, 26, 6, 33, 5, 63, 4, 68, 2,  9, 7, 97, 3, 15, 8,  2, 
    0, 41, 4, 26, 1, 33, 5, 32, 7, 10, 3, 68, 6, 34, 8, 33, 2, 98, 
    6, 56, 0,  7, 5, 86, 8, 87, 3, 11, 2, 14, 7, 28, 1, 38, 4, 25
  };
  const int q2592[] = {
    9, 9, // Number of jobs and machines
    0, 97, 5, 70, 8, 11, 7, 87, 1, 13, 3, 90, 4, 17, 2, 60, 6, 10, 
    2, 92, 4, 67, 3, 96, 8, 45, 5, 30, 7, 13, 0, 94, 6, 34, 1, 20, 
    0, 47, 2, 28, 8, 99, 1,  2, 5, 39, 4, 58, 3, 30, 7, 36, 6, 71, 
    3, 18, 7, 64, 0, 45, 6, 14, 2, 19, 1, 66, 4, 81, 8, 68, 5, 40, 
    3, 95, 1, 58, 8, 63, 5, 85, 0, 23, 7, 61, 4, 11, 6, 67, 2, 98, 
    3, 11, 7, 97, 0,  2, 1, 90, 6, 80, 5, 22, 2, 52, 8, 70, 4, 93, 
    7, 13, 6, 11, 3, 33, 4, 61, 1, 75, 8, 27, 5, 48, 0, 30, 2, 91, 
    6, 33, 3, 79, 1, 90, 8,  6, 0, 26, 4, 47, 7, 32, 2, 65, 5, 82, 
    1,  4, 5, 46, 3, 67, 0, 25, 6, 34, 7, 83, 2,  5, 4,  8, 8, 17
  };
  const int q2593[] = {
    9, 9, // Number of jobs and machines
    1, 91, 5, 30, 6, 50, 2, 51, 0, 58, 4, 90, 3, 55, 7, 91, 8, 36, 
    7, 43, 1, 58, 5,  1, 3,  6, 0, 71, 4, 78, 6, 66, 2, 25, 8, 12, 
    1, 36, 4, 27, 7, 88, 0, 68, 8, 74, 5,  8, 6,  9, 3, 50, 2, 42, 
    5, 91, 2,  2, 7, 32, 4, 60, 0, 71, 6, 40, 8, 68, 3, 55, 1, 43, 
    7, 51, 6, 97, 5, 43, 2, 40, 0, 59, 8, 83, 3, 47, 1, 56, 4, 33, 
    1, 40, 8, 72, 2, 43, 5,  1, 3, 74, 0, 25, 6, 94, 4, 97, 7, 82, 
    7, 43, 1,  8, 3, 65, 2, 54, 5,  7, 0, 99, 8, 12, 4, 65, 6, 23, 
    4, 94, 5, 30, 1, 93, 6, 32, 0, 69, 2,  8, 7, 53, 3, 88, 8, 16, 
    1, 49, 3, 26, 7, 43, 6, 26, 2, 87, 5, 99, 4, 50, 8, 95, 0, 84
  };
  const int q2594[] = {
    9, 9, // Number of jobs and machines
    4, 41, 8,  3, 3, 47, 6, 78, 5, 58, 2, 21, 7, 44, 0, 27, 1, 77, 
    3, 63, 8, 56, 5, 36, 1, 31, 0, 29, 7,  4, 6, 80, 4, 99, 2, 92, 
    8, 39, 2, 91, 1, 30, 0, 17, 6,  6, 4, 14, 7, 95, 5, 61, 3, 90, 
    0, 30, 8, 40, 3, 76, 2, 26, 7, 18, 4, 70, 5, 23, 6, 55, 1, 67, 
    6, 54, 4, 10, 5, 69, 2, 80, 1,  6, 0, 96, 3, 23, 7, 70, 8, 12, 
    6, 14, 1, 44, 4, 15, 3,  5, 7, 22, 8, 33, 0, 35, 5, 26, 2, 61, 
    0, 12, 5, 63, 1, 40, 7, 96, 2, 95, 8, 63, 3, 50, 6, 16, 4,  9, 
    4, 59, 0, 89, 7, 15, 2, 25, 5, 35, 6, 26, 1, 65, 8, 94, 3, 71, 
    8, 87, 7, 95, 5, 46, 4, 88, 2,  4, 3,  3, 0, 77, 6, 42, 1, 98
  };
  const int q2595[] = {
    9, 9, // Number of jobs and machines
    8, 11, 0, 15, 1, 48, 6, 33, 4, 61, 2, 27, 7, 46, 5, 98, 3, 16, 
    7,  6, 4, 64, 1, 75, 6, 95, 8, 70, 2, 26, 0, 81, 3, 65, 5, 37, 
    7, 13, 5, 32, 3, 33, 6, 92, 2, 49, 1, 68, 4, 77, 0, 25, 8, 79, 
    4, 62, 8, 53, 3, 26, 1, 37, 0, 72, 5, 41, 7, 41, 6, 18, 2,  9, 
    3, 37, 7,  2, 0, 31, 8, 22, 4, 15, 1, 47, 6, 40, 2, 19, 5, 60, 
    8, 79, 3,  7, 1, 19, 5, 94, 2, 71, 7, 97, 6, 76, 0, 53, 4, 16, 
    7, 96, 2, 40, 5, 99, 3, 26, 4, 26, 6, 35, 8, 23, 0, 51, 1, 67, 
    3, 13, 7, 92, 5, 22, 0,  1, 8, 89, 6, 58, 4, 15, 1, 64, 2, 54, 
    7, 22, 6, 45, 3, 85, 2, 10, 8, 86, 5, 88, 1, 50, 0, 87, 4, 89
  };
  const int q2596[] = {
    9, 9, // Number of jobs and machines
    2, 89, 5, 36, 6, 94, 1, 23, 4, 24, 7, 28, 0,  5, 3, 21, 8, 67, 
    0, 52, 7, 48, 3, 12, 6, 86, 5, 75, 1, 58, 4, 32, 8, 99, 2, 36, 
    3, 97, 6, 94, 8, 55, 7,  8, 0, 78, 1, 27, 2, 62, 5, 38, 4,  8, 
    5, 12, 3, 67, 8, 84, 7, 53, 0,  5, 1, 69, 6, 29, 4, 74, 2, 33, 
    5, 39, 4, 52, 8, 49, 0, 58, 6, 47, 3, 56, 1, 23, 2, 54, 7, 66, 
    8, 72, 2, 42, 7, 41, 5, 13, 0,  3, 3, 92, 1,  7, 6, 50, 4, 15, 
    5, 15, 0, 95, 7,  2, 1, 30, 6,  6, 2, 51, 8, 21, 4,  6, 3, 89, 
    4, 99, 3, 81, 5, 10, 7, 95, 1,  1, 0, 50, 2, 50, 6, 13, 8, 49, 
    3, 43, 2, 40, 6, 67, 5, 41, 4, 90, 0, 79, 1, 43, 7, 74, 8, 43
  };
  const int q2597[] = {
    9, 9, // Number of jobs and machines
    1, 65, 7, 87, 4, 44, 6,  9, 5, 33, 8, 54, 0, 49, 2, 29, 3, 17, 
    0, 92, 7, 84, 1, 84, 4, 59, 3, 92, 8, 88, 2, 96, 6,  9, 5, 75, 
    1, 21, 7, 99, 8,  6, 2, 70, 5, 41, 3, 59, 0, 71, 6, 35, 4, 82, 
    5, 51, 1, 42, 8, 40, 4, 84, 7, 31, 3, 27, 2,  2, 0, 76, 6, 56, 
    2, 45, 3, 94, 5, 51, 0, 51, 8, 36, 4, 31, 1, 81, 7, 48, 6, 40, 
    2, 48, 7, 10, 5, 42, 8, 50, 1,  9, 6, 81, 4, 84, 3,  3, 0, 15, 
    0, 69, 1,  9, 5,  5, 8, 44, 3,  7, 6, 58, 4, 48, 2, 42, 7, 42, 
    3, 67, 5, 13, 1, 71, 6, 78, 8, 76, 0, 41, 7, 34, 2, 82, 4, 93, 
    4, 60, 0, 82, 6, 22, 5, 82, 8,  1, 7, 75, 3, 20, 1, 85, 2, 55
  };
  const int q2598[] = {
    9, 9, // Number of jobs and machines
    6, 77, 3, 57, 4, 41, 8,  9, 5, 94, 2, 61, 1,  8, 0, 51, 7, 25, 
    1, 98, 8, 60, 0, 13, 2, 35, 3,  3, 4, 55, 7,  5, 5, 44, 6, 70, 
    4, 61, 0, 77, 3, 51, 7,  8, 1, 53, 5, 32, 8, 11, 6, 20, 2, 23, 
    4, 56, 8, 71, 0, 67, 1, 35, 3, 21, 7, 28, 2, 42, 6, 66, 5, 25, 
    6, 25, 8, 66, 3, 53, 7, 67, 4, 61, 5, 82, 0, 91, 2, 73, 1, 99, 
    2,  7, 5,  5, 0, 33, 6, 25, 3, 22, 4, 52, 1, 82, 8, 25, 7, 24, 
    0, 41, 8, 63, 1, 27, 3, 33, 7, 77, 2, 69, 4, 89, 5, 42, 6, 71, 
    7, 90, 6, 86, 0, 61, 8, 49, 2, 68, 3, 93, 1, 60, 4, 75, 5, 66, 
    7, 33, 4, 95, 3,  8, 6, 19, 8,  6, 1, 76, 0,  8, 5,  8, 2, 45
  };
  const int q2599[] = {
    9, 9, // Number of jobs and machines
    1, 41, 2, 83, 0,  9, 8, 13, 3,  7, 5,  7, 6, 20, 4, 37, 7, 64, 
    3, 14, 5, 30, 4, 56, 0, 21, 2, 77, 6, 31, 1, 85, 8,  5, 7, 85, 
    3, 59, 5, 68, 6, 84, 4, 86, 7, 31, 8, 17, 1, 49, 2, 84, 0, 99, 
    1, 43, 4, 61, 2, 98, 8, 72, 5,  3, 7, 27, 3, 90, 6, 30, 0, 55, 
    1, 37, 4, 21, 3, 31, 0, 61, 6, 68, 8, 98, 7, 39, 5, 26, 2, 45, 
    6, 59, 8, 19, 0, 26, 2, 20, 7, 40, 5, 43, 4, 12, 3, 79, 1,  6, 
    8, 13, 2, 20, 0, 17, 5, 87, 7, 67, 6, 44, 1, 28, 3, 79, 4, 93, 
    4, 71, 7, 80, 8, 80, 6,  6, 0, 53, 2, 64, 1, 66, 3, 57, 5, 32, 
    0, 73, 2, 84, 4,  5, 5,  8, 3, 57, 6, 67, 8, 39, 7, 83, 1,  9
  };
  const int q2600[] = {
    9, 9, // Number of jobs and machines
    5, 33, 4, 65, 1, 94, 0, 42, 2, 26, 8, 24, 7, 96, 3, 70, 6,  6, 
    0, 65, 6, 13, 7, 98, 4, 52, 8, 28, 5, 50, 3, 93, 2,  2, 1, 79, 
    4, 14, 8, 33, 3, 96, 7, 72, 0,  3, 5, 50, 2, 10, 1, 39, 6, 81, 
    7, 71, 6, 84, 1, 25, 5, 77, 3, 15, 4, 75, 8, 85, 0,  9, 2, 44, 
    8, 65, 1,  4, 6, 39, 7, 48, 5, 43, 2, 27, 3, 47, 4, 15, 0, 51, 
    8, 73, 2, 23, 0, 90, 6, 51, 5, 54, 3, 65, 4, 72, 1, 14, 7, 62, 
    6, 34, 3, 66, 1, 30, 5,  1, 8, 66, 0, 43, 2,  6, 7, 49, 4, 54, 
    0, 45, 4, 29, 3, 85, 8, 34, 5, 88, 1, 99, 2, 24, 6, 82, 7, 59, 
    0, 84, 1, 23, 8, 86, 7,  4, 2, 97, 3, 48, 5, 41, 4, 30, 6, 65
  };
  const int q2601[] = {
    9, 9, // Number of jobs and machines
    1, 24, 2, 47, 3, 34, 7, 29, 4,  2, 0, 95, 5, 90, 8, 16, 6, 51, 
    8, 31, 1, 79, 2, 14, 3, 63, 4, 91, 6, 11, 7, 25, 5, 19, 0, 28, 
    8,  1, 4, 65, 2, 24, 5, 97, 7, 66, 6,  3, 1,  9, 0,  1, 3, 85, 
    6, 16, 0,  9, 4, 25, 5, 36, 7,  2, 8, 37, 2, 44, 1, 95, 3, 42, 
    4, 33, 8, 41, 5, 46, 0, 57, 6, 97, 1, 95, 7, 86, 2,  4, 3, 26, 
    6, 10, 1,  3, 2, 55, 8, 67, 7,  3, 4, 93, 5, 65, 3, 41, 0, 83, 
    2, 58, 3, 10, 5, 62, 0,  6, 4, 67, 8, 93, 1, 58, 6, 38, 7, 38, 
    1, 32, 2, 20, 7, 62, 4, 23, 8, 42, 5, 64, 3, 47, 0, 83, 6, 46, 
    4, 82, 5, 29, 7, 86, 1, 17, 6, 98, 2, 66, 0, 19, 3, 14, 8, 29
  };
  const int q2602[] = {
    9, 9, // Number of jobs and machines
    8, 20, 1, 38, 2, 26, 4, 40, 5, 83, 6, 97, 3, 15, 7,  5, 0,  2, 
    4, 97, 3, 16, 0, 21, 2, 54, 5, 26, 7, 21, 6, 16, 1, 87, 8, 70, 
    3, 48, 0, 52, 1, 56, 8, 90, 4, 65, 6,  1, 5, 93, 2, 52, 7, 77, 
    8, 89, 2, 62, 6, 92, 1, 62, 4, 43, 7, 23, 0, 80, 5, 50, 3, 47, 
    5, 37, 8, 25, 0, 71, 4, 39, 3,  7, 1, 94, 2, 38, 7, 95, 6, 47, 
    1, 16, 4, 16, 5, 24, 3, 21, 2, 46, 0, 35, 6, 95, 8, 35, 7, 74, 
    3, 36, 1,  6, 0, 48, 6, 25, 4, 41, 7, 83, 5, 91, 2, 41, 8, 80, 
    2, 29, 8, 68, 3, 41, 5, 75, 1, 79, 4, 11, 7, 72, 6, 49, 0, 19, 
    0, 77, 8, 42, 1, 85, 6, 54, 7, 77, 3, 52, 5, 55, 2, 92, 4, 27
  };
  const int q2603[] = {
    9, 9, // Number of jobs and machines
    3,  1, 7, 52, 8, 58, 1, 34, 4, 26, 0, 91, 2, 53, 6, 82, 5, 14, 
    1, 99, 4, 66, 8, 52, 2, 73, 3, 11, 0, 62, 6, 37, 5, 15, 7, 48, 
    5, 77, 2, 78, 1, 26, 4, 13, 7, 48, 6, 97, 0, 83, 8, 41, 3, 62, 
    5, 13, 3, 24, 0, 25, 6,  1, 4, 70, 7, 19, 1, 25, 8, 94, 2, 63, 
    1, 88, 5, 22, 3, 18, 0, 80, 2, 55, 7, 67, 8, 31, 6, 32, 4, 14, 
    7, 67, 1, 34, 5, 67, 8, 86, 6, 52, 2, 78, 3, 39, 0, 70, 4, 50, 
    7, 72, 0, 33, 8, 91, 6, 43, 2, 25, 5, 56, 4, 12, 3, 45, 1, 34, 
    3, 65, 7, 85, 5, 96, 8, 56, 0, 12, 2, 47, 1, 16, 6, 65, 4, 78, 
    4, 64, 6, 84, 5, 55, 7,  4, 1, 60, 0, 62, 3, 12, 2, 86, 8, 18
  };
  const int q2604[] = {
    9, 9, // Number of jobs and machines
    6, 70, 2,  9, 3, 23, 7, 37, 8,  7, 5, 38, 0, 70, 4,  1, 1,  7, 
    6, 20, 1,  1, 2, 93, 4, 45, 3, 84, 8, 37, 5, 66, 7, 70, 0, 29, 
    2, 84, 0, 95, 8, 98, 7, 12, 1,  3, 6, 43, 5, 98, 3, 75, 4, 30, 
    2, 32, 5, 50, 8, 93, 1,  9, 4,  4, 3, 73, 6, 93, 7, 63, 0, 47, 
    7, 57, 4, 44, 3, 51, 1,  5, 6, 14, 0, 96, 2, 89, 8, 16, 5, 23, 
    2, 23, 1,  6, 4, 49, 6, 87, 5, 23, 3, 89, 0, 55, 8, 11, 7, 65, 
    7, 23, 8, 50, 1, 78, 3, 71, 2, 93, 6, 69, 4, 51, 0, 65, 5, 60, 
    7, 20, 1, 24, 3, 35, 2, 97, 0, 42, 6, 44, 8, 56, 4, 58, 5, 93, 
    7, 30, 8, 77, 0, 73, 2, 21, 3, 78, 1, 96, 5, 71, 6, 45, 4, 34
  };
  const int q2605[] = {
    9, 9, // Number of jobs and machines
    3, 10, 1,  6, 7, 91, 8, 64, 2, 77, 0, 50, 6, 22, 5, 65, 4, 84, 
    8, 57, 3, 85, 4, 69, 2,  9, 5, 35, 7, 50, 6, 90, 1, 17, 0, 10, 
    2, 23, 4, 35, 8, 34, 0,  1, 7, 33, 1, 25, 6, 65, 5, 27, 3, 67, 
    1, 17, 7, 38, 3, 62, 2, 68, 4, 89, 5, 49, 8, 90, 6, 37, 0, 38, 
    7, 43, 3,  8, 6, 65, 0, 37, 2,  5, 8, 82, 1, 63, 4, 17, 5, 80, 
    4, 43, 1, 77, 7, 88, 8, 33, 3, 39, 6, 28, 0, 50, 2, 68, 5, 34, 
    0, 93, 2, 29, 3, 91, 4, 50, 5, 56, 6, 31, 8, 27, 1, 95, 7, 85, 
    2,  5, 0, 59, 3, 37, 6, 86, 7,  9, 1, 29, 4, 34, 5,  2, 8, 66, 
    4, 20, 6, 91, 3, 52, 0, 63, 7, 92, 2, 20, 5,  9, 8, 59, 1, 24
  };
  const int q2606[] = {
    9, 9, // Number of jobs and machines
    1, 38, 5, 45, 7, 67, 3,  3, 6, 57, 4, 44, 2, 38, 8, 29, 0, 14, 
    8, 72, 0, 56, 7,  4, 2, 21, 5, 68, 6, 75, 4, 61, 3, 20, 1,  3, 
    5, 49, 4, 39, 0, 45, 7, 19, 2, 96, 6, 72, 3, 10, 1, 39, 8, 77, 
    5,  9, 8, 29, 3, 64, 1, 67, 7, 84, 2, 52, 0, 65, 4, 23, 6, 47, 
    8, 87, 3,  2, 0, 55, 5, 86, 4, 16, 2,  7, 7, 67, 6, 43, 1, 44, 
    8, 69, 7, 49, 2, 51, 4, 20, 0, 30, 3, 91, 6, 60, 5, 46, 1, 63, 
    6, 10, 8, 59, 4, 14, 1,  6, 7, 66, 0, 92, 5, 77, 2, 44, 3, 34, 
    5, 67, 2, 81, 7, 77, 8, 59, 3, 28, 0, 84, 4, 88, 1, 33, 6, 54, 
    3,  9, 7, 77, 8, 31, 4, 67, 2, 26, 5, 13, 0, 26, 1, 86, 6, 17
  };
  const int q2607[] = {
    9, 9, // Number of jobs and machines
    7, 91, 8, 10, 3, 92, 5,  8, 0, 74, 1,  9, 6, 61, 2, 27, 4, 29, 
    8, 76, 2, 20, 7, 85, 3, 44, 0, 61, 4, 96, 6, 97, 5, 23, 1,  1, 
    2, 83, 0, 35, 4, 55, 1, 23, 7, 83, 5,  3, 6, 56, 8, 81, 3, 60, 
    5, 26, 7, 12, 2, 73, 4, 41, 6,  9, 0,  1, 3, 69, 1, 63, 8, 84, 
    0, 35, 6, 78, 5, 74, 3, 61, 8, 11, 4, 93, 2, 19, 1, 42, 7,  5, 
    5, 20, 0, 90, 4, 50, 3, 26, 8, 57, 7, 60, 1, 55, 6, 68, 2, 55, 
    0, 30, 6, 12, 1, 94, 3,  2, 5, 78, 4, 66, 7, 12, 8,  1, 2, 77, 
    0, 30, 7, 32, 6, 28, 4, 33, 5,  2, 1, 22, 8, 63, 3, 38, 2, 14, 
    4, 27, 8,  1, 2, 59, 6, 23, 1, 62, 0, 25, 5,  5, 3, 34, 7,  6
  };
  const int q2608[] = {
    9, 9, // Number of jobs and machines
    1, 78, 5, 46, 6, 77, 8, 93, 0, 31, 4, 75, 7, 10, 2, 71, 3, 39, 
    2, 86, 3, 58, 7, 55, 5,  7, 6, 11, 1,  4, 0, 58, 4, 25, 8, 79, 
    1, 88, 5,  7, 7, 34, 8, 52, 4, 19, 2, 81, 3, 16, 0, 51, 6, 26, 
    1,  4, 5, 52, 4, 55, 0, 83, 3, 11, 8, 48, 7, 14, 6, 33, 2, 11, 
    6, 46, 0, 84, 8, 11, 5, 54, 3, 99, 7, 72, 4, 76, 2, 47, 1, 32, 
    3, 93, 1, 59, 6, 78, 7, 10, 8, 83, 0, 26, 2, 85, 5, 62, 4,  9, 
    5,  8, 4,  7, 1, 91, 6, 94, 7, 12, 2, 52, 8, 67, 3, 44, 0, 91, 
    5, 41, 0, 61, 6, 33, 3, 11, 8, 57, 2, 23, 1, 28, 7, 59, 4, 12, 
    6,  7, 7, 97, 0, 20, 5, 26, 2, 33, 8,  1, 4,  9, 1, 20, 3, 79
  };
  const int q2609[] = {
    9, 9, // Number of jobs and machines
    2, 81, 1, 37, 6, 84, 3, 52, 8, 71, 7, 94, 5, 17, 0, 78, 4, 92, 
    2, 48, 5, 27, 3,  8, 0, 41, 1, 64, 6, 14, 7, 16, 4, 45, 8, 10, 
    6, 58, 8, 81, 5, 34, 7, 76, 4, 95, 3, 31, 0, 52, 2, 24, 1, 48, 
    5, 51, 3,  1, 0, 75, 8, 35, 7, 36, 4, 69, 2, 44, 1, 50, 6, 56, 
    1, 48, 5, 73, 0, 63, 8, 79, 4, 65, 3, 46, 2, 85, 6, 67, 7, 63, 
    5, 30, 1, 32, 6, 13, 4, 11, 8, 33, 2, 96, 7, 86, 3, 69, 0, 42, 
    6,  1, 1, 35, 7, 59, 5, 94, 2, 28, 8, 89, 4, 98, 3, 52, 0, 30, 
    0,  4, 4, 25, 1, 13, 3, 10, 7, 19, 6, 35, 5,  6, 8, 89, 2, 45, 
    0, 64, 4, 24, 5, 84, 2, 71, 1, 65, 6, 46, 8, 23, 7, 42, 3, 49
  };
  const int q2610[] = {
    9, 9, // Number of jobs and machines
    6, 31, 4, 85, 8, 46, 7, 93, 1, 35, 3,  9, 2, 84, 0, 38, 5,  4, 
    7, 65, 0, 65, 6, 13, 5, 34, 3, 35, 2, 65, 8, 68, 4, 58, 1, 45, 
    8, 89, 1, 37, 4, 55, 2, 62, 6, 13, 5, 99, 3,  7, 7, 83, 0,  9, 
    8, 26, 7, 49, 2,  5, 6, 31, 1, 36, 0, 77, 5, 79, 3, 32, 4, 65, 
    2, 94, 3, 66, 4, 13, 1, 54, 6, 22, 5,  3, 0, 11, 8, 24, 7, 81, 
    7, 85, 5, 43, 8, 93, 4, 72, 2, 55, 3, 53, 6,  2, 0, 26, 1, 56, 
    7, 23, 5, 75, 0, 91, 2, 57, 1,  4, 8, 22, 3, 27, 4, 17, 6, 32, 
    4, 30, 5, 30, 6, 26, 8, 65, 0,  1, 1, 98, 3, 18, 2, 59, 7, 81, 
    2, 99, 3,  8, 4, 20, 1, 29, 0,  2, 5, 46, 7,  6, 8, 65, 6, 47
  };
  const int q2611[] = {
    9, 9, // Number of jobs and machines
    3, 14, 0, 44, 6, 81, 7,  2, 1, 36, 8,  5, 4, 18, 2, 15, 5, 90, 
    2, 59, 4, 59, 1, 27, 7, 44, 5, 94, 8, 56, 0, 28, 3, 21, 6, 12, 
    8, 58, 5, 19, 0, 52, 4, 71, 1, 73, 7, 13, 2, 51, 3, 74, 6, 52, 
    0, 28, 6, 93, 1, 27, 3, 37, 8, 81, 2, 93, 7, 93, 5, 71, 4, 49, 
    3, 71, 1, 25, 8,  3, 5, 30, 2,  2, 0, 75, 7, 22, 6, 14, 4, 72, 
    6,  4, 1, 81, 3, 22, 5, 16, 8, 66, 4, 95, 7,  3, 2, 98, 0, 76, 
    8, 26, 4, 80, 5, 58, 7, 20, 0, 67, 6, 55, 2, 19, 1, 14, 3, 54, 
    8, 25, 3, 52, 6, 13, 0,  3, 4,  6, 2, 28, 5, 11, 7, 37, 1, 89, 
    4,  3, 2, 83, 8, 58, 0, 68, 1, 27, 6,  6, 7, 80, 5, 68, 3, 67
  };
  const int q2612[] = {
    9, 9, // Number of jobs and machines
    8, 71, 3, 93, 0, 12, 2, 64, 1, 44, 4, 37, 5, 85, 7, 60, 6, 81, 
    2, 37, 3, 29, 5, 45, 7, 43, 0, 18, 4,  3, 1, 70, 8, 88, 6, 89, 
    5, 47, 1, 28, 2, 12, 3, 73, 6, 20, 7, 52, 8,  3, 4, 83, 0, 35, 
    0, 29, 7,  4, 2, 48, 5, 20, 8,  4, 3, 17, 4, 80, 1, 82, 6, 18, 
    2, 72, 3, 44, 1, 48, 7, 78, 4, 48, 0, 14, 5, 93, 6,  1, 8,  5, 
    1, 40, 2, 97, 4, 10, 5, 66, 3, 68, 7, 87, 8, 16, 6, 93, 0, 93, 
    5, 35, 8, 46, 4, 92, 7, 84, 6, 30, 1, 39, 2, 45, 3, 66, 0, 42, 
    5, 81, 3, 66, 0, 15, 8, 88, 2, 72, 6, 47, 4,  2, 1, 88, 7, 65, 
    2, 94, 3, 50, 4, 81, 6, 70, 1,  7, 0, 54, 5, 63, 8, 66, 7, 27
  };
  const int q2613[] = {
    9, 9, // Number of jobs and machines
    2, 64, 3, 37, 6, 86, 4, 26, 5, 60, 8, 26, 7, 47, 1, 66, 0, 82, 
    5, 79, 0, 24, 1, 72, 6, 64, 2, 55, 8, 40, 3, 47, 4, 91, 7, 14, 
    2, 97, 3, 83, 8, 53, 4,  4, 7, 52, 0, 50, 1, 96, 5, 95, 6, 70, 
    4, 58, 6, 39, 2, 35, 5, 74, 8, 40, 0, 76, 7, 74, 3, 63, 1,  3, 
    3, 50, 4, 74, 6, 80, 8,  4, 0, 70, 2, 43, 5, 39, 1, 31, 7, 35, 
    1, 50, 5, 95, 4, 15, 6, 96, 7, 82, 0, 37, 8, 73, 3, 66, 2, 70, 
    3, 21, 1,  5, 5, 78, 2, 24, 8, 99, 6, 98, 7,  7, 0, 26, 4, 71, 
    6, 27, 5, 33, 3, 99, 4, 52, 2, 55, 8, 94, 7, 98, 0, 37, 1, 74, 
    7, 65, 3, 93, 8, 64, 6, 95, 5, 16, 4,  6, 2, 97, 0, 22, 1, 92
  };
  const int q2614[] = {
    9, 9, // Number of jobs and machines
    8, 43, 3, 58, 7, 85, 0, 46, 1, 49, 5, 60, 2, 13, 6, 85, 4, 67, 
    3, 86, 1, 14, 2, 63, 6, 63, 8, 81, 5, 28, 4, 65, 0, 59, 7, 34, 
    2, 34, 8, 82, 7, 57, 5, 34, 4, 71, 0, 30, 3, 10, 6, 67, 1, 85, 
    4, 10, 5, 55, 1, 65, 0, 11, 6, 26, 7, 15, 3,  8, 2, 45, 8, 31, 
    6, 94, 8, 74, 5, 40, 3, 12, 7, 49, 2, 78, 4, 33, 0, 73, 1,  5, 
    8, 75, 0, 81, 6,  6, 1, 63, 5, 67, 2, 54, 7, 83, 3, 53, 4, 95, 
    5, 91, 6,  1, 4, 90, 1, 34, 0,  1, 2, 36, 7, 80, 8, 39, 3, 33, 
    4, 27, 5, 16, 7, 93, 3, 14, 8, 88, 1, 18, 0,  4, 2,  8, 6, 38, 
    0, 94, 1, 44, 4, 54, 2, 51, 6, 62, 5, 54, 7, 92, 3, 80, 8, 95
  };
  const int q2615[] = {
    9, 9, // Number of jobs and machines
    8, 72, 0, 56, 1, 27, 5, 98, 7, 56, 3, 22, 4, 72, 6, 56, 2, 65, 
    4, 39, 8, 20, 5, 48, 6,  2, 0, 75, 3, 25, 1, 13, 2, 23, 7, 36, 
    1, 84, 6, 61, 3, 23, 0, 91, 2, 53, 5, 74, 4, 23, 7, 90, 8, 76, 
    0, 59, 1, 40, 5, 83, 2, 95, 3, 72, 6,  6, 7, 62, 4, 81, 8, 55, 
    7, 36, 8, 27, 2, 50, 3, 39, 1, 66, 4, 23, 6, 68, 5, 50, 0, 34, 
    0, 63, 3, 77, 8, 22, 4, 55, 2, 55, 7, 90, 6, 85, 1, 62, 5, 68, 
    6, 89, 1, 82, 8, 67, 5, 98, 7, 97, 3, 14, 2, 27, 0, 12, 4, 67, 
    4,  8, 7, 25, 5, 69, 0, 93, 6,  5, 1, 27, 8, 96, 3, 54, 2, 17, 
    3,  3, 8, 13, 5, 54, 2, 29, 7,  2, 1, 53, 6,  2, 0, 30, 4, 49
  };
  const int q2616[] = {
    9, 9, // Number of jobs and machines
    4, 13, 1, 60, 7, 32, 3, 67, 6, 58, 5, 33, 8, 48, 2, 42, 0, 85, 
    7, 98, 8, 47, 0, 98, 6, 36, 3,  8, 2, 41, 5, 57, 1, 36, 4, 50, 
    1, 80, 5, 69, 7, 87, 3, 51, 8, 98, 6, 39, 0, 68, 2, 82, 4, 37, 
    8, 62, 4, 15, 3, 63, 7, 11, 6, 12, 5, 92, 1, 47, 0, 31, 2, 42, 
    1, 71, 3, 63, 5, 85, 2, 97, 6, 80, 4, 47, 7, 68, 8, 44, 0, 15, 
    5, 78, 1, 68, 8, 20, 3, 85, 2, 21, 4,  5, 0, 24, 6, 32, 7, 47, 
    5, 64, 7, 53, 1,  9, 2, 46, 8, 43, 4, 89, 0, 90, 6, 45, 3, 87, 
    4, 75, 6,  8, 2, 62, 7, 78, 1, 90, 3, 62, 8, 27, 5, 48, 0, 63, 
    5, 19, 0, 51, 7, 77, 1, 71, 8, 81, 4, 48, 2, 97, 3, 95, 6, 93
  };
  const int q2617[] = {
    9, 9, // Number of jobs and machines
    5, 77, 6, 29, 3, 34, 1, 23, 4, 37, 8, 29, 0, 34, 7, 40, 2, 92, 
    8, 62, 5, 31, 2, 38, 3, 21, 6, 75, 4, 99, 7, 39, 0, 90, 1, 24, 
    3, 84, 7, 52, 6, 57, 1, 56, 5,  6, 2, 38, 8,  1, 0, 52, 4, 70, 
    0, 42, 4, 77, 2, 31, 6, 58, 7,  9, 5, 33, 8, 64, 1, 17, 3, 27, 
    3, 72, 1, 18, 2, 64, 5, 27, 7,  1, 6, 12, 4, 32, 8, 29, 0, 52, 
    1,  3, 0, 11, 2, 64, 4, 21, 6, 36, 5, 57, 7, 17, 8, 63, 3, 13, 
    7, 55, 4, 44, 0, 93, 3, 93, 2, 59, 8, 51, 5, 78, 1, 68, 6, 52, 
    8, 28, 6, 67, 1, 21, 0, 62, 2, 72, 4, 34, 5, 21, 3, 78, 7, 86, 
    1, 85, 4, 14, 7, 82, 3, 21, 0, 86, 8, 65, 2, 20, 5, 19, 6, 20
  };
  const int q2618[] = {
    9, 9, // Number of jobs and machines
    3, 69, 7, 38, 4, 14, 6, 80, 5, 29, 2, 45, 8, 96, 0, 40, 1, 68, 
    2, 43, 5, 77, 1, 37, 8, 37, 7, 46, 4, 94, 0, 67, 3, 79, 6, 55, 
    8, 53, 5, 98, 4, 53, 0, 13, 2, 94, 1, 16, 3, 57, 6, 47, 7, 88, 
    5, 21, 4, 18, 2, 21, 8, 19, 1, 96, 6, 53, 0, 42, 3,  2, 7, 66, 
    6, 90, 1, 10, 7, 61, 2, 41, 3,  6, 4, 30, 0, 71, 8,  2, 5, 32, 
    5, 71, 2, 85, 8, 44, 6, 67, 0, 35, 7, 91, 4, 63, 1, 70, 3, 50, 
    8, 28, 6, 80, 5, 44, 2, 36, 0, 56, 7, 64, 3, 39, 1, 76, 4, 88, 
    6, 83, 1,  1, 8, 63, 4, 68, 2, 90, 0, 39, 3,  4, 5, 31, 7, 23, 
    8,  4, 2, 16, 4, 42, 3, 11, 7, 26, 6, 12, 5,  4, 0, 21, 1, 39
  };
  const int q2619[] = {
    9, 9, // Number of jobs and machines
    3, 61, 6, 97, 0, 79, 5, 86, 4, 40, 8, 39, 2, 25, 1, 55, 7,  9, 
    8, 62, 3, 15, 5, 68, 0, 26, 6, 30, 2, 35, 7, 51, 4, 85, 1, 62, 
    2, 78, 0, 76, 7, 24, 1, 14, 8,  5, 5, 36, 3,  1, 6, 61, 4, 71, 
    5, 13, 6, 84, 4, 22, 3, 35, 7,  9, 1,  1, 8, 46, 0, 32, 2,  8, 
    5, 71, 3, 49, 7, 55, 0, 70, 6, 42, 4, 38, 1, 63, 8, 12, 2, 82, 
    3, 33, 8, 33, 4, 29, 0, 39, 6, 61, 1, 42, 2, 17, 7, 47, 5, 74, 
    2, 59, 3, 99, 6, 89, 1, 12, 7, 68, 4, 55, 5, 31, 8, 63, 0, 24, 
    2, 16, 5, 96, 4, 33, 8, 21, 1, 72, 6, 76, 7, 79, 0, 67, 3, 59, 
    5, 84, 0, 90, 2,  7, 6, 42, 7, 15, 3, 36, 8, 32, 4, 79, 1, 58
  };
  const int q2620[] = {
    9, 9, // Number of jobs and machines
    8, 12, 4, 56, 6, 72, 5, 92, 0, 94, 1, 31, 7, 39, 2, 47, 3, 21, 
    1, 16, 8, 15, 4, 40, 2,  1, 3, 21, 6,  5, 0, 90, 5, 58, 7, 94, 
    6, 22, 7,  8, 1, 55, 0, 33, 4, 95, 8, 69, 5, 83, 3, 37, 2, 25, 
    3, 48, 6, 27, 0, 43, 5, 13, 7, 41, 8, 97, 2, 36, 4, 62, 1, 84, 
    1, 28, 2, 44, 4, 36, 7, 58, 6, 74, 0, 80, 5, 62, 3, 23, 8, 67, 
    7, 68, 4, 56, 3, 49, 6, 30, 1, 68, 0,  4, 2, 77, 8, 14, 5, 23, 
    4, 48, 5,  6, 0, 10, 6, 30, 3, 85, 2, 78, 7, 64, 8, 35, 1, 26, 
    3, 99, 1, 59, 6, 30, 4, 49, 7, 39, 2, 73, 5, 81, 0, 10, 8,  7, 
    8, 24, 7, 34, 5, 77, 1, 31, 2, 55, 0, 75, 3, 73, 6, 75, 4, 92
  };
  const int q2621[] = {
    9, 9, // Number of jobs and machines
    2, 58, 8, 55, 0, 38, 1, 26, 6, 60, 3, 51, 4, 43, 7, 44, 5, 15, 
    5, 82, 6, 58, 1, 23, 3, 78, 2, 41, 0, 18, 8, 10, 7, 35, 4, 14, 
    4, 95, 2, 59, 3, 30, 6, 94, 5, 59, 8, 44, 1,  9, 7, 14, 0, 81, 
    6, 25, 8, 87, 2, 53, 5, 12, 7, 60, 1, 81, 3, 15, 0,  6, 4, 51, 
    8, 15, 5, 83, 6, 39, 7, 39, 0, 38, 2, 32, 4,  7, 3, 18, 1, 25, 
    1, 54, 2, 83, 5, 69, 0, 88, 8, 37, 3, 51, 4, 90, 6, 50, 7, 61, 
    3, 48, 8,  3, 2, 19, 4, 38, 6, 87, 5, 58, 1, 74, 7,  5, 0, 88, 
    0, 78, 8, 34, 3, 50, 1,  8, 5, 45, 2, 56, 6, 64, 7, 86, 4, 83, 
    3, 45, 7, 93, 4, 84, 8, 18, 5, 94, 0, 30, 2, 33, 6, 48, 1,  1
  };
  const int q2622[] = {
    9, 9, // Number of jobs and machines
    5, 26, 1, 75, 6, 79, 8, 35, 3, 51, 4, 39, 7, 43, 2, 96, 0, 26, 
    1,  8, 2, 31, 5, 23, 3, 11, 0, 94, 8, 54, 7, 17, 6, 46, 4, 56, 
    8, 92, 4, 53, 6, 65, 3, 35, 5,  4, 1, 89, 7,  9, 0,  2, 2, 19, 
    2, 16, 8, 21, 6, 22, 4,  8, 0, 95, 5, 83, 3, 21, 7, 38, 1, 15, 
    3, 22, 0, 19, 7, 81, 1, 34, 5,  7, 6, 33, 2, 95, 4, 79, 8, 35, 
    1, 12, 8, 51, 4, 24, 0, 29, 5,  3, 7, 15, 3, 48, 2, 26, 6,  9, 
    6,  4, 0, 69, 3, 53, 7, 79, 4,  7, 5, 19, 2,  8, 1,  1, 8, 19, 
    0, 65, 3, 13, 2, 17, 5, 18, 8, 29, 1, 75, 6, 27, 4,  8, 7,  1, 
    0, 82, 8,  5, 2, 91, 5, 69, 3, 14, 1,  7, 6,  6, 7, 93, 4, 48
  };
  const int q2623[] = {
    9, 9, // Number of jobs and machines
    0, 55, 5, 95, 7, 56, 3, 32, 2, 41, 6, 42, 1,  1, 8,  4, 4, 43, 
    5, 71, 3,  1, 7, 48, 4, 28, 0, 60, 1, 16, 8, 69, 2, 78, 6, 52, 
    8, 72, 4,  1, 0,  6, 7, 29, 3, 28, 5, 17, 2, 76, 1, 69, 6,  1, 
    3, 39, 5, 30, 2, 27, 8, 46, 0, 15, 1, 55, 6, 89, 7, 84, 4, 55, 
    4,  2, 2, 33, 7, 14, 5, 50, 8, 89, 3, 32, 1, 24, 6, 71, 0, 44, 
    4, 27, 5, 80, 8, 66, 3,  6, 2, 15, 0,  5, 1, 13, 6, 63, 7, 87, 
    4, 91, 8,  8, 3, 24, 6, 90, 5,  4, 2, 48, 0, 32, 1, 48, 7, 17, 
    4, 84, 7, 52, 1,  4, 2,  2, 3,  9, 0,  1, 8, 90, 5, 46, 6, 28, 
    6, 46, 3, 27, 7, 38, 2, 80, 4, 15, 5, 57, 8, 31, 0, 41, 1, 39
  };
  const int q2624[] = {
    9, 9, // Number of jobs and machines
    4,  5, 2, 96, 5, 92, 0, 75, 1, 96, 8, 22, 7, 99, 3, 52, 6, 73, 
    0,  4, 1, 79, 3, 88, 5,  2, 7, 49, 4, 59, 2, 82, 8,  2, 6, 70, 
    4, 22, 6, 29, 1, 43, 0, 17, 7, 69, 3, 50, 8,  7, 2, 26, 5, 40, 
    8, 67, 7, 77, 3, 87, 5, 60, 1, 48, 0, 16, 6, 45, 4, 46, 2, 98, 
    6,  8, 3, 91, 1, 28, 5, 72, 8, 41, 4, 20, 0, 78, 7, 83, 2, 90, 
    8, 31, 7, 11, 6, 22, 5, 15, 3, 36, 4, 13, 0, 42, 1, 79, 2, 56, 
    1, 78, 6, 13, 4, 98, 8, 64, 2,  9, 3, 70, 0, 34, 7, 96, 5, 96, 
    3,  6, 4, 32, 7, 22, 1, 76, 5, 17, 8, 60, 6, 99, 2,  2, 0, 66, 
    0, 34, 4, 90, 6,  9, 3, 58, 7, 73, 5, 15, 1, 19, 8, 46, 2, 34
  };
  const int q2625[] = {
    9, 9, // Number of jobs and machines
    5,  5, 0, 47, 7, 59, 8, 29, 1, 32, 6, 36, 3, 79, 2, 22, 4, 86, 
    3, 65, 8, 23, 4, 56, 2, 41, 5, 64, 1, 50, 7,  5, 6, 16, 0, 15, 
    1, 54, 0, 26, 6, 77, 7, 33, 5, 25, 3, 28, 4, 67, 2, 82, 8,  1, 
    2, 75, 5, 60, 7, 53, 1,  7, 3, 38, 4, 92, 6, 95, 8, 35, 0, 45, 
    7, 23, 0, 63, 1, 70, 6, 62, 4, 28, 3, 69, 5, 57, 2, 37, 8, 62, 
    5, 37, 0, 46, 7, 53, 1, 69, 4, 78, 2, 20, 8, 59, 3, 75, 6, 21, 
    5,  1, 2, 62, 6, 42, 0, 29, 8, 59, 4, 49, 1, 46, 7, 29, 3, 48, 
    2, 81, 6, 56, 1, 51, 7, 52, 3,  3, 0, 35, 5, 12, 4, 36, 8, 75, 
    4, 46, 7, 60, 6, 41, 0, 36, 1, 78, 8, 58, 5, 80, 3, 34, 2, 42
  };
  const int q2626[] = {
    9, 9, // Number of jobs and machines
    3, 91, 8, 42, 0, 37, 1, 47, 5, 53, 2, 65, 4, 85, 7, 60, 6, 74, 
    8,  9, 3, 19, 6, 33, 1, 51, 5,  4, 4, 79, 7, 53, 0, 36, 2, 30, 
    8, 36, 4, 25, 7, 43, 5, 68, 0, 78, 6, 91, 2, 37, 3, 71, 1, 31, 
    3, 65, 2, 14, 6, 67, 1, 60, 7, 99, 4, 21, 0, 60, 5, 42, 8,  2, 
    6, 53, 8, 95, 5, 53, 2, 94, 0, 60, 7, 29, 1, 92, 4, 15, 3, 98, 
    4, 70, 0, 81, 6, 91, 7, 10, 1, 88, 5, 28, 2, 82, 3, 47, 8, 30, 
    0, 40, 4, 82, 1, 95, 8, 79, 2, 26, 7, 98, 3, 47, 6, 11, 5, 92, 
    8, 39, 6, 64, 5, 24, 3, 67, 2, 42, 0, 47, 1, 38, 7, 14, 4, 49, 
    6, 15, 0, 94, 2, 23, 3,  8, 8, 60, 5, 56, 4, 61, 1, 46, 7, 76
  };
  const int q2627[] = {
    9, 9, // Number of jobs and machines
    8, 55, 6, 82, 7, 84, 0, 71, 3, 41, 1, 37, 4, 25, 5, 38, 2, 31, 
    4,  5, 6, 14, 8, 24, 5, 43, 2, 68, 3, 43, 0, 38, 1, 41, 7, 36, 
    8, 28, 4, 35, 6, 25, 1, 33, 0, 76, 2, 57, 5, 30, 7, 47, 3, 84, 
    4, 61, 8, 45, 1, 79, 3, 28, 7, 33, 5, 76, 6, 39, 0, 87, 2, 46, 
    8,  3, 2, 26, 7, 18, 4, 62, 5, 32, 1,  5, 6, 25, 3, 31, 0, 68, 
    5, 31, 3, 96, 6, 69, 7, 34, 8, 82, 0,  7, 4,  6, 2, 13, 1, 82, 
    5, 66, 4, 24, 6, 23, 7, 87, 3, 23, 1, 35, 8, 26, 0, 76, 2, 20, 
    6, 37, 2, 41, 0, 15, 3, 98, 8,  5, 1, 91, 4,  2, 7, 26, 5, 41, 
    6, 24, 3, 62, 5, 40, 4, 82, 2, 49, 8, 71, 1, 95, 0, 33, 7,  3
  };
  const int q2628[] = {
    9, 9, // Number of jobs and machines
    6, 58, 8, 53, 2, 50, 1, 31, 5, 97, 7, 68, 4, 11, 3, 13, 0, 26, 
    3, 56, 6, 82, 7, 62, 1, 18, 4, 18, 0, 98, 2, 73, 5, 11, 8, 54, 
    0, 81, 5, 50, 2, 86, 7, 15, 4, 40, 6,  9, 3, 41, 8, 45, 1, 73, 
    5, 14, 4, 20, 6, 64, 7, 21, 8,  6, 0, 22, 3, 61, 1, 42, 2, 53, 
    2, 49, 4,  2, 3,  1, 0, 22, 6, 97, 5, 79, 7, 29, 8, 99, 1, 34, 
    6, 13, 2, 52, 8, 59, 5, 74, 4, 27, 1, 30, 3, 90, 7, 84, 0, 61, 
    3, 18, 1,  4, 2, 56, 4, 29, 5, 93, 0, 61, 6, 51, 7,  5, 8,  3, 
    0, 30, 7, 15, 8, 76, 2, 18, 5,  9, 6, 91, 3, 54, 1, 40, 4, 11, 
    1, 58, 3, 81, 6, 55, 0, 70, 5, 70, 4,  7, 8, 76, 2,  4, 7, 31
  };
  const int q2629[] = {
    9, 9, // Number of jobs and machines
    5, 76, 6, 11, 7, 67, 0, 32, 1, 59, 8, 68, 3, 97, 4, 37, 2, 87, 
    3, 31, 0, 48, 8, 16, 6, 51, 2, 35, 4, 17, 7, 33, 5, 41, 1, 85, 
    7, 11, 2, 88, 0, 33, 3,  6, 4, 98, 5, 34, 1, 96, 8,  9, 6, 10, 
    2, 82, 6, 37, 0, 30, 4,  7, 5, 54, 7, 38, 3, 76, 8, 62, 1, 85, 
    7, 39, 1, 21, 4, 63, 5, 84, 8, 64, 6, 41, 2, 26, 0, 77, 3, 61, 
    1, 23, 5, 22, 0, 62, 4, 46, 6,  1, 8, 60, 2, 23, 3, 71, 7, 16, 
    8, 48, 6, 62, 4, 17, 7, 97, 2, 32, 0, 64, 3, 96, 1, 51, 5, 86, 
    1, 68, 0, 14, 2, 80, 5, 69, 8, 83, 7, 61, 3, 82, 6, 92, 4, 22, 
    6, 11, 4, 88, 1, 42, 7,  5, 2, 92, 3, 35, 0,  4, 8, 11, 5, 87
  };
  const int q2630[] = {
    9, 9, // Number of jobs and machines
    5, 32, 6, 93, 8, 74, 0, 65, 2, 50, 3, 43, 1, 51, 7, 41, 4, 76, 
    4, 74, 8, 21, 2, 11, 6, 29, 7, 52, 0, 55, 5, 51, 3, 51, 1, 68, 
    4, 69, 7, 90, 3, 26, 2, 92, 6, 36, 1, 89, 0, 16, 5, 60, 8, 10, 
    8,  7, 4, 19, 0, 37, 6, 98, 3, 93, 1, 14, 5, 50, 2, 62, 7, 28, 
    3, 43, 1, 38, 7, 73, 6, 18, 0, 78, 4, 47, 5, 93, 2, 70, 8, 94, 
    2,  1, 6,  7, 4, 90, 1, 45, 8, 15, 0, 69, 5, 24, 7, 32, 3, 60, 
    6, 48, 1, 85, 0, 47, 5, 31, 8, 36, 7,  3, 3, 50, 4, 75, 2, 93, 
    2, 55, 3, 15, 0, 32, 5, 45, 7, 74, 8, 74, 6, 76, 4, 63, 1, 73, 
    0, 22, 3, 69, 5, 71, 1, 59, 4, 29, 7, 30, 6, 78, 2, 51, 8, 83
  };
  const int q2631[] = {
    9, 9, // Number of jobs and machines
    4, 80, 5, 67, 6, 78, 1, 35, 8, 39, 7, 26, 2, 21, 0, 69, 3, 18, 
    2, 83, 0,  8, 8, 98, 5, 87, 4, 45, 6, 12, 7, 20, 1, 85, 3, 25, 
    3,  4, 0, 57, 4, 37, 7, 45, 2, 59, 6, 10, 1,  8, 5, 41, 8, 45, 
    8, 29, 6, 29, 5, 37, 2, 46, 0, 92, 7, 43, 4, 82, 3, 96, 1, 40, 
    5, 19, 4, 89, 8, 54, 6, 80, 7, 17, 0, 92, 3, 89, 1, 44, 2, 66, 
    7,  7, 1, 80, 2, 26, 4, 39, 5, 79, 3, 58, 8, 95, 0,  4, 6, 56, 
    2, 76, 5, 37, 8, 51, 4, 59, 7, 79, 6, 87, 0, 32, 1, 10, 3, 94, 
    0, 49, 8, 95, 1, 74, 2,  4, 7, 42, 5, 81, 6, 77, 4, 53, 3, 73, 
    3, 17, 0, 60, 4, 85, 6, 28, 7, 35, 5, 45, 8, 79, 2, 95, 1, 79
  };
  const int q2632[] = {
    9, 9, // Number of jobs and machines
    8, 14, 7, 90, 1, 15, 3, 60, 2, 10, 4, 46, 6, 64, 0, 63, 5, 66, 
    2, 72, 5, 98, 1, 14, 4, 37, 3, 61, 0,  4, 8, 44, 7, 92, 6, 41, 
    4, 65, 5, 30, 2, 41, 7, 93, 1, 62, 8, 86, 3, 22, 0,  5, 6, 77, 
    5, 63, 6, 30, 7, 88, 3, 19, 0, 45, 4, 85, 8, 83, 2, 60, 1, 77, 
    8, 76, 5, 93, 3, 91, 2, 50, 4, 97, 1, 21, 7, 97, 6, 46, 0, 15, 
    6, 82, 2, 24, 0, 50, 3, 52, 1, 32, 8, 38, 5, 92, 4,  2, 7, 72, 
    7, 44, 6, 81, 1, 41, 5, 30, 8, 26, 3, 98, 0, 52, 4, 19, 2, 73, 
    7, 20, 6, 83, 0, 81, 4, 70, 8, 53, 1,  7, 2, 86, 3, 90, 5, 36, 
    3, 93, 6, 44, 1, 63, 4, 55, 7, 26, 0, 28, 8, 91, 2,  1, 5, 96
  };
  const int q2633[] = {
    9, 9, // Number of jobs and machines
    8, 51, 1, 36, 5, 73, 3, 57, 7, 36, 0, 38, 6, 86, 4, 34, 2, 43, 
    8, 83, 5, 12, 7, 41, 6, 96, 4,  5, 3, 70, 0, 29, 1, 40, 2, 10, 
    4, 66, 6, 93, 5, 90, 1, 61, 0, 96, 3, 72, 7, 38, 2, 23, 8, 94, 
    7, 31, 3, 30, 4, 88, 2, 57, 5, 75, 1, 87, 6,  3, 8, 81, 0, 41, 
    3, 80, 2, 76, 4,  6, 6, 32, 1, 81, 5, 87, 0, 98, 8, 50, 7, 89, 
    5, 28, 0, 28, 4, 36, 2, 31, 7, 94, 6, 46, 8, 36, 3, 73, 1, 30, 
    1, 82, 8, 51, 0, 40, 6, 27, 4, 29, 2, 85, 7, 99, 3, 82, 5, 29, 
    3, 29, 2, 81, 4, 37, 8, 41, 1, 33, 5, 31, 6, 80, 7,  5, 0,  6, 
    8, 47, 5, 90, 0, 53, 2, 96, 6, 75, 7, 44, 4, 39, 3, 79, 1, 59
  };
  const int q2634[] = {
    9, 9, // Number of jobs and machines
    1, 13, 0, 85, 2, 55, 8, 66, 4, 28, 7,  9, 3, 52, 5,  5, 6, 29, 
    8, 48, 2, 34, 4, 57, 1, 20, 3, 60, 7, 28, 5, 75, 6, 63, 0, 84, 
    4, 41, 7, 72, 0, 93, 6,  7, 2, 49, 8, 58, 1, 64, 3, 38, 5, 26, 
    0, 13, 2, 19, 3, 91, 5, 57, 6, 80, 8, 21, 7, 45, 1,  9, 4, 16, 
    0,  1, 7, 13, 6, 32, 1, 13, 2, 54, 4, 30, 5, 18, 3, 11, 8, 48, 
    2, 49, 8, 23, 7,  1, 3, 89, 5,  2, 1, 46, 6, 41, 4, 88, 0, 86, 
    1, 51, 5, 93, 3, 61, 4, 63, 2, 36, 0,  1, 7, 75, 6, 68, 8, 57, 
    3, 57, 4, 80, 6, 75, 5, 38, 2, 70, 7, 33, 8, 58, 1, 42, 0, 62, 
    0, 22, 5, 17, 4, 84, 8, 63, 1, 44, 3, 14, 2, 82, 6, 33, 7,  6
  };
  const int q2635[] = {
    9, 9, // Number of jobs and machines
    7,  9, 3, 28, 4, 33, 8, 68, 1, 49, 0, 75, 5, 75, 6, 58, 2, 30, 
    7, 29, 2, 99, 3, 16, 8, 11, 5, 47, 4, 71, 0,  8, 6, 83, 1, 15, 
    4, 33, 6, 37, 8, 86, 1, 97, 3, 63, 0, 24, 5, 11, 7, 11, 2, 25, 
    6, 98, 8, 48, 1, 84, 5, 29, 0, 21, 7, 44, 3,  5, 4, 72, 2, 16, 
    0, 70, 6, 77, 4, 15, 1, 55, 8, 52, 3, 30, 7, 99, 5, 32, 2, 94, 
    5, 24, 3, 12, 7, 28, 8, 86, 2, 19, 1, 94, 0, 18, 4, 74, 6,  6, 
    5, 26, 7, 16, 3, 29, 0, 54, 1, 67, 8, 72, 2, 86, 4, 10, 6, 34, 
    4, 58, 3, 56, 5, 34, 7, 49, 0, 11, 2, 18, 6, 12, 8, 71, 1, 67, 
    4, 30, 8, 24, 1, 71, 3, 76, 5, 70, 0, 11, 6, 30, 7, 46, 2,  6
  };
  const int q2636[] = {
    9, 9, // Number of jobs and machines
    8,  7, 6, 81, 4, 14, 5, 42, 3, 90, 7, 56, 1, 52, 2, 46, 0, 98, 
    7, 71, 2, 37, 8, 30, 1, 93, 5, 75, 4, 25, 0,  7, 3, 24, 6, 31, 
    1, 75, 2, 60, 7, 66, 6, 38, 4, 35, 3, 19, 0, 66, 5, 76, 8, 65, 
    0, 98, 4, 71, 5, 37, 1, 77, 7, 34, 8, 79, 6, 45, 3, 44, 2, 33, 
    2, 74, 6, 66, 8, 84, 5, 67, 0, 47, 4, 11, 3, 64, 7, 52, 1, 20, 
    4, 19, 6, 97, 0, 31, 7, 53, 2, 57, 3, 59, 1, 24, 5,  4, 8, 10, 
    6, 31, 1, 34, 4, 91, 5, 98, 2, 32, 8, 81, 7,  5, 0, 88, 3, 56, 
    8, 55, 1, 74, 4, 37, 0, 10, 6, 59, 2, 40, 7, 14, 3, 18, 5, 38, 
    2, 46, 6, 84, 0, 30, 1, 23, 7, 55, 3, 16, 5, 54, 8, 40, 4,  2
  };
  const int q2637[] = {
    9, 9, // Number of jobs and machines
    8, 91, 3, 16, 6, 87, 1, 61, 2, 84, 7, 76, 4, 97, 0, 44, 5, 38, 
    8,  1, 7, 50, 0, 88, 3, 87, 2, 70, 6, 44, 1, 21, 5, 96, 4,  9, 
    5, 92, 1, 68, 4, 82, 6,  5, 0, 38, 2, 10, 3, 24, 8, 69, 7, 37, 
    4, 77, 8,  9, 5, 84, 0, 68, 1, 65, 6, 67, 7, 69, 3, 42, 2, 19, 
    1, 92, 5, 75, 0, 54, 2, 73, 4, 32, 3,  7, 6,  2, 7, 82, 8, 79, 
    3, 37, 7, 13, 1, 25, 6, 12, 2, 84, 4, 19, 8, 37, 0, 80, 5, 16, 
    4, 76, 0, 53, 1, 90, 7, 39, 2, 59, 8, 28, 5, 60, 3, 20, 6, 37, 
    8, 95, 1, 49, 5, 54, 7, 57, 3,  3, 6,  6, 4, 19, 2, 92, 0, 28, 
    0, 65, 3, 40, 5,  3, 8, 40, 7, 54, 2, 23, 6, 94, 1, 51, 4, 53
  };
  const int q2638[] = {
    9, 9, // Number of jobs and machines
    1, 33, 6,  8, 0, 62, 7, 45, 3,  8, 2,  2, 8, 24, 5, 10, 4, 60, 
    8, 78, 4, 85, 5, 90, 3, 45, 1,  1, 2,  2, 7, 29, 6, 95, 0, 50, 
    8, 28, 6, 70, 0, 41, 2, 56, 7, 60, 3, 26, 4,  2, 5, 11, 1, 98, 
    6,  9, 3, 44, 4, 23, 7, 63, 1, 97, 8, 85, 0, 77, 2, 81, 5, 56, 
    4, 43, 6,  2, 7, 93, 1, 76, 2, 46, 0, 27, 5, 59, 8, 58, 3, 29, 
    2, 17, 5, 90, 0, 47, 8, 14, 3, 94, 1, 45, 4, 49, 6, 23, 7, 52, 
    7,  1, 2, 63, 5, 71, 8,  8, 1, 10, 4, 20, 0, 59, 3, 75, 6, 19, 
    2, 21, 4, 35, 6, 81, 7, 31, 3, 35, 5, 98, 1, 94, 0,  2, 8,  7, 
    4, 15, 0, 61, 1, 82, 3, 52, 7, 49, 8,  2, 6, 77, 2,  8, 5, 45
  };
  const int q2639[] = {
    9, 9, // Number of jobs and machines
    4, 22, 3, 27, 6, 38, 2, 51, 0, 53, 8, 32, 7, 56, 1, 39, 5, 73, 
    1, 25, 6, 72, 5, 45, 0, 88, 7, 84, 8, 58, 3, 36, 2, 33, 4, 19, 
    6, 13, 0,  8, 2, 13, 4, 91, 5, 11, 3, 93, 8, 86, 1, 30, 7, 26, 
    8, 78, 3, 68, 5, 90, 0,  1, 1,  4, 7, 87, 6, 19, 2, 16, 4, 79, 
    4,  1, 3, 57, 0, 54, 1, 85, 8, 94, 7,  2, 2, 20, 6,  6, 5, 40, 
    7, 86, 5, 55, 6, 90, 1, 72, 4, 48, 0, 19, 3, 42, 2, 88, 8, 91, 
    3, 35, 6, 57, 5, 24, 8, 38, 1, 36, 7, 34, 4, 31, 2, 84, 0, 20, 
    5, 42, 4, 57, 3, 10, 8, 48, 1, 17, 7, 88, 6, 31, 0,  2, 2, 97, 
    6, 47, 2, 41, 8, 87, 5, 32, 4, 43, 0, 62, 7, 27, 1, 26, 3, 85
  };
  const int q2640[] = {
    9, 9, // Number of jobs and machines
    5,  5, 6, 19, 8,  3, 0, 49, 3, 83, 2,  2, 4, 54, 7, 49, 1, 74, 
    1, 78, 8, 94, 6, 53, 5, 76, 2, 96, 7, 66, 4, 53, 0, 16, 3, 87, 
    4, 70, 3, 36, 8, 62, 0, 24, 7, 51, 5, 67, 6, 29, 2, 25, 1, 28, 
    7, 15, 8, 64, 2, 27, 4, 92, 1,  4, 5, 54, 3, 25, 6,  3, 0, 55, 
    5, 48, 3, 13, 7,  8, 1, 16, 8, 57, 4, 88, 0, 31, 2,  5, 6, 41, 
    0, 31, 7,  9, 3, 34, 4, 92, 6, 32, 5, 48, 1, 16, 2, 96, 8, 43, 
    8, 26, 3, 85, 5, 97, 2, 62, 6, 46, 1, 96, 0, 21, 4, 17, 7, 21, 
    6, 48, 7, 56, 2, 32, 3, 26, 0,  8, 4, 91, 8, 15, 1, 16, 5, 28, 
    1, 69, 7, 39, 5, 10, 2, 30, 8, 27, 3, 41, 4, 94, 6, 15, 0, 97
  };
  const int q2641[] = {
    9, 9, // Number of jobs and machines
    6, 92, 4,  8, 3,  5, 8, 96, 1, 18, 5, 11, 7, 92, 2, 98, 0, 68, 
    6, 59, 3, 26, 0, 18, 7, 56, 5, 52, 1, 63, 2, 23, 8, 45, 4, 51, 
    3, 46, 5, 56, 2,  5, 0, 14, 8, 78, 7, 58, 4, 46, 1, 17, 6, 19, 
    5, 94, 7,  5, 0, 55, 8, 87, 6, 10, 4, 67, 2, 63, 3, 54, 1, 65, 
    8, 98, 3, 11, 7, 51, 4, 46, 0, 47, 5, 54, 1, 18, 6, 38, 2, 55, 
    5, 84, 1,  7, 7, 77, 0, 51, 6, 11, 2,  3, 8, 84, 4, 35, 3, 86, 
    7, 60, 2, 68, 0, 13, 5,  6, 3,  3, 1, 41, 4, 14, 6, 71, 8, 82, 
    3,  6, 4, 21, 5, 13, 1,  7, 6, 40, 8, 14, 0, 45, 7, 90, 2, 62, 
    6, 29, 2, 96, 5, 99, 0, 21, 4, 19, 8, 16, 3, 40, 7, 64, 1, 34
  };
  const int q2642[] = {
    9, 9, // Number of jobs and machines
    6, 62, 8, 92, 0, 90, 1, 60, 4, 57, 5, 33, 3, 47, 2, 44, 7, 25, 
    8, 72, 5, 19, 7, 74, 1, 30, 0, 98, 6, 19, 4, 29, 3, 11, 2, 76, 
    6, 65, 0, 36, 4, 54, 3, 61, 2, 17, 5, 76, 1, 38, 7, 65, 8,  3, 
    4, 83, 2,  7, 6, 35, 1,  2, 5, 72, 3, 85, 8, 23, 7,  8, 0, 63, 
    8, 85, 6, 86, 2,  3, 0, 89, 7, 10, 1, 49, 5, 66, 4, 79, 3,  9, 
    4,  5, 1, 61, 8, 43, 6, 26, 0, 53, 3, 90, 7, 28, 5, 53, 2, 41, 
    7, 35, 4, 37, 2, 17, 3, 23, 1, 22, 5, 16, 0, 83, 6, 82, 8, 86, 
    7, 38, 1, 92, 3,  2, 2, 73, 5, 65, 0, 60, 4,  4, 6,  7, 8, 77, 
    5, 66, 1, 85, 0, 96, 2,  1, 3, 21, 7, 90, 8, 71, 4, 51, 6, 90
  };
  const int q2643[] = {
    9, 9, // Number of jobs and machines
    4, 18, 2, 16, 5, 49, 3, 20, 6, 96, 7, 59, 0,  5, 8, 37, 1,  2, 
    6, 19, 5, 32, 0, 76, 2, 51, 1, 22, 4, 77, 8, 32, 7, 19, 3, 27, 
    0, 15, 6, 69, 5, 94, 2,  3, 4, 90, 8, 57, 3, 31, 7, 61, 1, 11, 
    3, 10, 5, 62, 0, 93, 2, 91, 6, 87, 4, 42, 7, 78, 1, 23, 8, 82, 
    0, 72, 4, 17, 7, 88, 8, 70, 2, 83, 1, 16, 5, 96, 6, 26, 3, 97, 
    2, 58, 7, 51, 0, 68, 8, 46, 4, 26, 1, 39, 6, 47, 3, 95, 5, 23, 
    4, 54, 2, 63, 7,  4, 8, 23, 5, 78, 6, 24, 3, 96, 1, 70, 0, 49, 
    7, 11, 4, 27, 8, 17, 2, 66, 3, 45, 5, 10, 1, 54, 0, 30, 6, 42, 
    3, 70, 0, 60, 5, 68, 6, 95, 2, 71, 7, 75, 8, 70, 1, 66, 4, 16
  };
  const int q2644[] = {
    9, 9, // Number of jobs and machines
    3, 48, 6, 29, 7, 67, 5, 91, 1, 63, 2, 34, 0, 51, 4, 54, 8, 43, 
    6, 57, 7,  6, 2, 73, 3, 16, 8, 40, 0, 10, 4, 92, 1, 55, 5, 59, 
    8, 56, 7,  3, 0, 20, 5, 28, 6, 46, 3, 75, 1, 92, 4, 73, 2,  6, 
    8, 45, 5, 88, 4, 67, 1, 51, 0, 78, 6, 49, 7, 79, 3, 95, 2, 96, 
    4, 74, 5, 18, 3, 51, 2, 21, 7, 76, 6, 78, 1,  7, 0, 45, 8, 81, 
    5, 80, 7, 63, 8, 11, 6, 70, 3, 55, 0, 97, 1, 13, 4, 86, 2, 50, 
    0,  5, 8, 25, 4, 81, 6, 68, 2,  7, 5, 73, 3, 93, 1, 60, 7, 55, 
    2, 17, 8, 33, 7,  6, 0, 29, 6, 43, 3, 29, 4, 43, 1, 94, 5, 87, 
    8, 31, 3, 78, 0,  5, 1,  1, 2, 96, 4, 82, 5,  9, 7, 58, 6, 76
  };
  const int q2645[] = {
    9, 9, // Number of jobs and machines
    8, 89, 0, 42, 6, 61, 1, 26, 2, 12, 3, 68, 7, 26, 5, 69, 4, 80, 
    2, 57, 7, 74, 0, 15, 8,  5, 5, 24, 3, 76, 1, 20, 6, 71, 4,  3, 
    8,  1, 4, 31, 5, 87, 3, 34, 1, 86, 7, 43, 0, 89, 6, 95, 2, 80, 
    6, 56, 4, 21, 5, 33, 2, 90, 8, 65, 3,  3, 7, 58, 0, 51, 1, 41, 
    6, 50, 7, 77, 5, 12, 0, 16, 3, 14, 2, 38, 8, 63, 4, 17, 1, 11, 
    8, 48, 5, 69, 2, 56, 7, 22, 4, 81, 0, 82, 3, 90, 1, 52, 6, 26, 
    7, 82, 6, 84, 1, 44, 5, 56, 2, 25, 8, 15, 4, 51, 3, 81, 0, 71, 
    1, 47, 4, 80, 2, 20, 7, 95, 6, 67, 3, 40, 5, 58, 8, 36, 0, 46, 
    3, 51, 7, 79, 8, 15, 1, 35, 5, 37, 6, 51, 4, 24, 2, 74, 0, 76
  };
  const int q2646[] = {
    9, 9, // Number of jobs and machines
    7, 11, 1, 27, 8, 40, 6, 79, 3, 30, 5, 90, 0,  4, 4, 80, 2, 75, 
    2, 25, 6, 52, 1, 43, 7, 62, 3, 82, 5, 54, 0, 93, 8, 23, 4, 67, 
    7, 81, 2, 46, 1,  9, 6, 62, 0, 57, 3, 36, 4, 13, 5, 47, 8, 46, 
    1, 37, 0, 40, 6, 96, 8, 24, 2, 13, 3, 40, 4, 94, 7, 58, 5, 31, 
    2, 62, 1, 79, 4, 49, 5, 81, 6,  5, 8, 17, 3,  3, 7, 54, 0,  6, 
    5, 35, 6, 12, 8, 55, 0,  1, 4, 71, 1, 85, 7, 59, 3, 34, 2,  7, 
    2, 12, 1,  5, 0, 73, 5, 25, 6, 28, 7, 37, 4, 84, 3, 75, 8, 24, 
    1, 94, 5, 21, 6, 97, 8, 34, 4, 87, 7, 37, 2, 10, 3, 61, 0,  5, 
    8, 44, 2,  8, 1, 11, 4,  1, 6, 46, 3, 89, 5, 20, 7, 66, 0, 78
  };
  const int q2647[] = {
    9, 9, // Number of jobs and machines
    3, 59, 1, 55, 4, 39, 5, 61, 2, 39, 0, 89, 7, 38, 8, 49, 6, 40, 
    3, 98, 8, 17, 7, 26, 2, 62, 4, 65, 1,  9, 6, 38, 0, 41, 5, 46, 
    4, 88, 8, 75, 1,  5, 6, 86, 2, 98, 7,  9, 0, 10, 5, 15, 3, 49, 
    1, 38, 3, 36, 4,  8, 7, 58, 0, 49, 5, 22, 6, 63, 8, 22, 2,  1, 
    7, 55, 2, 18, 0, 91, 6, 37, 4, 42, 5, 63, 3, 87, 1, 25, 8, 44, 
    6, 62, 5, 77, 4, 86, 3, 28, 8, 82, 2, 51, 1, 43, 0, 33, 7, 10, 
    3, 14, 2, 49, 6, 31, 8, 54, 4, 54, 1, 67, 0, 26, 5, 47, 7, 74, 
    2, 30, 6, 83, 5,  6, 1,  3, 3, 55, 8, 54, 7, 49, 4, 24, 0, 91, 
    2, 69, 4, 48, 8, 95, 5, 81, 0,  2, 7, 68, 3, 92, 6, 99, 1, 93
  };
  const int q2648[] = {
    9, 9, // Number of jobs and machines
    4, 99, 3, 83, 0, 49, 8, 89, 6, 24, 5, 57, 7, 21, 2, 24, 1, 87, 
    5,  4, 8, 62, 6, 28, 2, 15, 1, 89, 0, 84, 7, 31, 4, 57, 3, 24, 
    2, 12, 8, 18, 1, 74, 6, 26, 0, 70, 7, 43, 4, 81, 5, 81, 3, 83, 
    8, 66, 4, 63, 0, 65, 1, 38, 3, 95, 6,  6, 5, 44, 7, 63, 2, 31, 
    4, 97, 6, 36, 2,  5, 7, 50, 5, 58, 0, 76, 1, 52, 8, 32, 3, 93, 
    0, 21, 5, 14, 6, 96, 7, 31, 3,  8, 1, 22, 8, 91, 2, 48, 4, 24, 
    2, 99, 7, 84, 6, 78, 8, 84, 0, 85, 3, 25, 1, 20, 5, 23, 4, 71, 
    4, 22, 2, 99, 6, 92, 5, 79, 8, 61, 1, 10, 3, 87, 0, 91, 7, 44, 
    4, 75, 2, 47, 7, 87, 5, 46, 3, 81, 8, 84, 0,  3, 1, 40, 6, 58
  };
  const int q2649[] = {
    9, 9, // Number of jobs and machines
    8, 61, 3, 76, 6, 35, 4, 20, 7, 75, 1, 16, 2, 68, 5, 61, 0, 15, 
    0, 43, 6, 41, 1, 53, 7, 90, 4, 49, 5,  6, 2, 59, 3, 55, 8, 42, 
    8, 42, 1, 38, 7, 57, 0,  1, 3, 59, 6, 32, 2, 50, 4, 10, 5,  2, 
    1, 70, 3, 57, 0, 59, 5, 31, 7, 79, 2, 21, 8,  9, 6, 22, 4, 69, 
    1, 95, 4, 40, 3, 22, 8, 28, 0, 98, 5, 15, 7, 74, 6,  4, 2,  2, 
    4, 53, 2,  8, 8, 83, 6, 94, 5, 53, 1, 45, 3, 13, 7,  2, 0, 56, 
    1, 79, 8, 18, 4, 70, 2, 54, 0,  6, 7, 50, 6, 18, 5, 62, 3, 24, 
    7, 34, 2, 12, 5, 76, 4, 46, 3, 75, 6,  5, 1, 75, 8, 39, 0, 35, 
    2, 46, 6, 75, 0, 34, 1, 92, 3, 78, 5, 59, 4, 90, 7, 83, 8, 72
  };
  const int q2650[] = {
    9, 9, // Number of jobs and machines
    3, 29, 0, 58, 1, 27, 4, 30, 7, 13, 8, 50, 2, 42, 5, 34, 6,  6, 
    5, 66, 7, 66, 6, 60, 4,  5, 2, 46, 0, 18, 3,  2, 1, 90, 8,  8, 
    8, 94, 1,  4, 4, 66, 6, 16, 5, 28, 3, 54, 7, 33, 2, 55, 0, 74, 
    8, 11, 6,  2, 4, 63, 5, 42, 1, 79, 2, 94, 7,  7, 3, 45, 0, 43, 
    6, 40, 0, 99, 3, 51, 2, 16, 1, 70, 5, 62, 7, 26, 4, 34, 8, 67, 
    8, 39, 5, 55, 7, 36, 1, 13, 6, 68, 2, 31, 4,  6, 0, 80, 3, 69, 
    4,  9, 5, 84, 0, 22, 6,  3, 1, 88, 7, 49, 8, 48, 3, 93, 2, 65, 
    1, 82, 3, 76, 7, 46, 0, 17, 6,  6, 8,  4, 5, 80, 2, 17, 4, 91, 
    5, 33, 2, 87, 7, 66, 8, 18, 4, 42, 1, 18, 6, 45, 0, 95, 3, 84
  };
  const int q2651[] = {
    9, 9, // Number of jobs and machines
    3, 20, 4, 59, 0, 78, 8, 84, 5, 91, 7, 93, 6, 97, 2, 20, 1, 26, 
    2, 27, 0, 74, 6, 82, 8,  3, 3, 42, 4, 72, 1, 74, 5, 55, 7, 65, 
    2, 10, 7, 89, 1, 92, 8, 96, 4, 56, 3, 78, 6, 81, 0, 21, 5, 92, 
    0, 75, 8, 99, 5,  3, 6, 80, 2,  2, 7, 80, 4, 23, 3, 76, 1,  6, 
    3, 43, 5,  3, 0, 46, 7, 92, 1, 30, 4, 40, 8,  9, 2, 26, 6, 61, 
    1, 48, 0, 16, 4, 56, 3, 55, 6, 64, 2, 19, 5, 78, 7, 49, 8, 28, 
    5, 55, 3, 22, 8, 25, 7, 52, 6, 78, 4, 69, 0, 97, 2, 90, 1, 39, 
    0,  7, 6, 10, 3, 62, 4, 12, 5, 33, 7, 48, 8, 17, 1, 61, 2, 14, 
    4, 55, 6, 80, 1, 44, 5,  5, 8, 68, 2, 67, 7,  7, 0, 28, 3, 52
  };
  const int q2652[] = {
    9, 9, // Number of jobs and machines
    7, 91, 5, 36, 8, 48, 6, 59, 0, 80, 3, 93, 4, 72, 1, 16, 2, 62, 
    3, 48, 8, 27, 1, 94, 6, 36, 7, 44, 0, 23, 5, 49, 2, 76, 4, 74, 
    1, 58, 5,  5, 2, 29, 4, 39, 7, 32, 0, 45, 8,  6, 3, 45, 6, 65, 
    0, 88, 6,  7, 7, 87, 5, 72, 1, 10, 8, 56, 4, 65, 2, 93, 3, 42, 
    4, 89, 2, 27, 0, 84, 8, 54, 1, 86, 5, 95, 6, 21, 3, 45, 7, 51, 
    7, 28, 2, 26, 4, 93, 5, 85, 8, 44, 1, 54, 6, 83, 3, 79, 0, 20, 
    0, 77, 8, 33, 5, 12, 1, 30, 7, 26, 4, 38, 2, 55, 6, 10, 3, 69, 
    4, 20, 6, 96, 2,  2, 8,  3, 1, 28, 0, 49, 3, 61, 5, 76, 7, 73, 
    5, 35, 7, 28, 0, 70, 6, 44, 4, 82, 1, 93, 2, 49, 8, 25, 3, 82
  };
  const int q2653[] = {
    9, 9, // Number of jobs and machines
    2, 78, 1, 70, 8, 66, 5, 23, 6, 89, 4, 19, 3, 30, 7, 88, 0, 91, 
    6, 73, 5, 56, 8, 81, 2, 13, 0,  7, 7, 16, 1, 61, 3, 83, 4, 22, 
    8, 99, 3,  4, 4, 85, 2, 45, 7, 84, 5, 42, 1, 54, 0, 45, 6, 96, 
    0, 54, 4,  4, 7, 13, 3, 66, 2, 56, 1, 95, 8,  3, 5, 14, 6, 48, 
    8, 57, 5, 75, 3, 50, 6,  2, 4, 32, 7, 78, 1, 40, 0, 22, 2, 34, 
    5, 25, 8, 22, 2, 96, 0, 31, 4, 14, 7, 97, 6,  1, 3,  9, 1,  5, 
    0, 61, 7, 78, 2, 85, 6, 93, 3, 40, 8, 84, 5, 62, 1, 80, 4, 74, 
    3, 93, 0, 88, 1, 88, 8, 52, 2, 66, 7, 29, 4, 45, 6, 69, 5, 98, 
    6, 46, 2, 14, 1, 98, 3, 84, 0, 94, 7, 88, 5, 65, 8, 73, 4, 42
  };
  const int q2654[] = {
    9, 9, // Number of jobs and machines
    6, 32, 8,  9, 7, 64, 0, 12, 4, 64, 5, 57, 1, 11, 2, 76, 3, 19, 
    3, 69, 6, 29, 1, 21, 5, 67, 0, 43, 7, 21, 4, 29, 2, 17, 8, 66, 
    5, 80, 6, 39, 8, 56, 7, 37, 1, 99, 3, 33, 2, 75, 4, 43, 0, 18, 
    7, 70, 5, 48, 6,  8, 2, 10, 4, 54, 1, 26, 8, 77, 3, 45, 0, 19, 
    8, 96, 5, 33, 2, 98, 3, 71, 6, 29, 1, 66, 0, 15, 7, 37, 4, 77, 
    3, 18, 0, 77, 5, 61, 7, 25, 2, 71, 6, 54, 1, 12, 4, 76, 8, 86, 
    1, 57, 4, 50, 5,  2, 2, 41, 6, 34, 3, 63, 0, 87, 8, 92, 7, 48, 
    1, 61, 3, 22, 7, 88, 2,  4, 5, 55, 0,  1, 4, 40, 8,  8, 6, 49, 
    2, 74, 5, 78, 7, 31, 6,  9, 8, 66, 1, 85, 0, 70, 3, 64, 4, 79
  };
  const int q2655[] = {
    9, 9, // Number of jobs and machines
    5, 88, 6, 58, 4, 22, 1, 38, 7, 95, 2,  6, 0, 23, 8, 75, 3, 53, 
    3, 14, 6,  7, 0, 40, 8, 32, 1, 59, 4, 57, 2, 45, 5, 81, 7, 31, 
    1, 24, 5, 25, 0, 44, 6, 13, 8,  3, 3, 35, 2,  1, 7, 85, 4, 61, 
    7, 40, 3, 48, 0, 99, 5, 50, 2, 95, 8, 24, 4, 55, 6,  9, 1, 63, 
    7,  9, 0, 38, 4, 17, 3, 28, 1, 28, 2, 59, 5, 43, 6, 34, 8, 70, 
    6, 77, 3, 91, 4, 90, 2, 80, 8, 41, 5, 76, 0, 28, 1, 84, 7, 46, 
    7, 77, 3, 71, 8, 92, 4, 30, 2, 84, 6, 46, 1, 36, 5, 48, 0, 76, 
    5, 38, 4, 36, 3, 93, 6,  4, 0, 35, 7, 18, 2, 64, 8, 93, 1, 99, 
    4, 79, 7, 67, 1, 48, 6, 18, 5, 12, 2,  2, 3, 27, 0, 35, 8, 61
  };
  const int q2656[] = {
    9, 9, // Number of jobs and machines
    2, 24, 3, 67, 6, 33, 5, 67, 7, 61, 1, 21, 0, 17, 8, 83, 4, 36, 
    7, 51, 3, 72, 6, 71, 4, 95, 5, 19, 2, 34, 1, 88, 0, 88, 8, 56, 
    7, 49, 0, 75, 3, 91, 1, 52, 4, 25, 8, 76, 5, 55, 2, 29, 6, 41, 
    4, 67, 5, 72, 8, 92, 0, 46, 7, 37, 6, 96, 1, 49, 2, 24, 3, 73, 
    3, 48, 5, 39, 2,  1, 6,  4, 8,  1, 1, 14, 7, 45, 4, 88, 0, 38, 
    3, 85, 7, 19, 2, 27, 5, 11, 0, 31, 4, 20, 1, 94, 6,  9, 8, 40, 
    0, 95, 2, 33, 5, 18, 7, 10, 8, 42, 1, 23, 4, 89, 6, 58, 3, 26, 
    2, 75, 8, 59, 7, 16, 4, 90, 0,  3, 1, 35, 3, 29, 6, 93, 5, 92, 
    3, 66, 8, 74, 4, 96, 0, 40, 1, 79, 6, 92, 7, 24, 5, 84, 2, 51
  };
  const int q2657[] = {
    9, 9, // Number of jobs and machines
    3, 29, 2, 68, 8, 43, 1, 66, 6, 73, 0, 50, 4, 18, 5, 73, 7, 89, 
    5, 37, 1, 37, 8, 59, 7, 80, 4,  6, 3, 47, 6, 91, 2, 28, 0, 24, 
    1, 67, 4, 33, 3, 96, 6, 18, 7, 15, 0, 40, 2,  3, 5, 98, 8, 39, 
    8, 94, 0,  2, 2, 42, 1, 50, 6, 36, 5, 52, 3, 91, 7, 23, 4, 82, 
    6,  1, 4, 27, 5,  6, 2, 46, 7, 67, 1, 77, 8, 56, 0, 15, 3, 53, 
    7, 99, 3, 65, 6, 81, 0, 70, 2, 88, 4, 67, 1, 99, 8,  1, 5, 55, 
    1, 96, 8, 99, 0, 18, 6, 90, 3,  9, 7,  5, 2, 83, 5, 21, 4, 30, 
    5, 49, 1, 89, 2, 34, 0, 46, 8, 26, 4, 16, 7, 83, 3, 55, 6, 18, 
    3, 22, 4, 64, 8, 84, 1, 25, 0, 51, 7, 44, 6, 70, 5, 62, 2, 56
  };
  const int q2658[] = {
    9, 9, // Number of jobs and machines
    1, 95, 0, 20, 3, 20, 7, 98, 5, 66, 2, 13, 4, 92, 6, 33, 8, 29, 
    1, 70, 2, 88, 3,  8, 7, 93, 4,  5, 5, 49, 8, 40, 0, 14, 6, 45, 
    0, 91, 1, 23, 4, 41, 7, 98, 8, 94, 5, 94, 2, 28, 3, 42, 6, 25, 
    6, 30, 1, 33, 7, 24, 5, 56, 4, 18, 0, 17, 8, 79, 2, 81, 3, 96, 
    7, 86, 0, 44, 4, 21, 3, 11, 2, 19, 5, 77, 6,  6, 8,  7, 1, 78, 
    4, 29, 7, 54, 8, 97, 5, 85, 0, 81, 2, 80, 3, 63, 6, 83, 1, 41, 
    3, 90, 7, 81, 2, 82, 5, 30, 6, 57, 8, 29, 4, 93, 0, 11, 1, 33, 
    2, 73, 5, 84, 6, 73, 0, 51, 4,  9, 7, 18, 1, 99, 8, 34, 3, 45, 
    3,  9, 2, 49, 4, 66, 1, 21, 0, 59, 8, 30, 5, 77, 7, 83, 6, 12
  };
  const int q2659[] = {
    9, 9, // Number of jobs and machines
    4, 78, 5, 12, 6, 23, 2,  1, 8,  6, 1, 63, 0, 53, 3, 63, 7, 61, 
    4, 71, 5, 20, 0, 39, 6, 30, 2, 80, 3, 27, 8, 40, 1, 32, 7, 46, 
    5, 17, 7, 98, 2, 57, 1, 69, 4, 56, 3, 54, 8, 33, 6, 66, 0, 81, 
    3, 65, 0, 73, 8,  2, 1, 61, 7, 17, 2, 84, 6, 17, 4, 22, 5, 22, 
    2, 52, 8, 78, 1, 41, 4, 27, 7, 31, 3, 66, 0, 81, 5, 53, 6, 15, 
    5, 10, 4, 67, 2,  4, 6, 46, 7, 39, 3, 99, 1, 53, 8, 78, 0, 40, 
    7, 76, 8, 53, 6, 91, 2, 81, 1, 14, 5, 10, 4,  5, 3,  2, 0, 49, 
    7, 51, 0, 73, 4,  7, 5, 27, 2, 30, 8, 71, 6, 30, 3, 94, 1, 93, 
    1, 82, 4,  1, 3, 22, 5, 61, 8, 79, 7, 62, 0, 16, 6,  4, 2, 98
  };
  const int q2660[] = {
    9, 9, // Number of jobs and machines
    4, 86, 7, 33, 0, 19, 1, 40, 5,  1, 6, 38, 2,  8, 3,  1, 8, 63, 
    4, 14, 8,  7, 2, 33, 0, 48, 1, 91, 6, 63, 5, 46, 3, 91, 7, 79, 
    7, 97, 8, 88, 5, 11, 6, 47, 2, 50, 0, 39, 4, 28, 1, 85, 3,  6, 
    7, 76, 3, 48, 0, 50, 4,  7, 2, 45, 1, 80, 5, 52, 6, 16, 8, 25, 
    2, 12, 5, 53, 0, 93, 7, 88, 1, 30, 4, 47, 3, 96, 6, 48, 8, 86, 
    4, 60, 8, 97, 6,  2, 3, 95, 1, 23, 0, 94, 5, 47, 2, 66, 7, 55, 
    7, 52, 0, 42, 1, 63, 3, 53, 5, 12, 4, 70, 2, 43, 8, 33, 6, 76, 
    6, 16, 1, 68, 5, 88, 2, 25, 7, 68, 0, 98, 8, 56, 4, 76, 3, 72, 
    1, 24, 3, 46, 4, 34, 8, 51, 5, 30, 6, 19, 7, 27, 0, 84, 2, 31
  };
  const int q2661[] = {
    9, 9, // Number of jobs and machines
    2, 48, 0, 24, 8, 57, 7, 96, 4, 52, 3, 86, 5, 38, 6, 65, 1, 46, 
    3, 56, 1, 56, 2, 90, 7, 89, 5, 17, 8, 41, 6, 90, 4, 20, 0, 68, 
    1, 72, 3, 42, 6, 99, 7, 82, 2, 69, 5, 69, 0, 52, 8, 28, 4, 54, 
    3, 34, 2, 49, 4, 68, 6, 28, 8, 69, 0, 47, 1, 51, 5, 85, 7, 98, 
    2,  1, 4, 26, 7, 26, 3, 26, 8, 91, 1, 76, 5,  2, 0, 27, 6, 98, 
    0, 63, 3, 93, 1, 63, 2, 66, 7,  4, 4, 78, 5, 21, 8, 72, 6, 28, 
    3, 29, 0, 99, 5, 46, 8, 84, 6, 56, 7, 68, 2, 73, 1, 46, 4, 76, 
    7, 70, 3,  9, 0, 85, 8, 92, 1, 94, 2,  8, 5, 62, 6, 75, 4,  2, 
    3, 58, 1, 54, 7, 69, 2, 36, 4, 25, 8, 64, 6, 62, 0, 93, 5, 88
  };
  const int q2662[] = {
    9, 9, // Number of jobs and machines
    3, 93, 6, 10, 1, 52, 5, 72, 8, 37, 4, 52, 7, 90, 2, 45, 0, 32, 
    8, 71, 4, 79, 3, 89, 7, 48, 2, 87, 5, 52, 0, 93, 6, 87, 1, 77, 
    7, 70, 1, 36, 8,  6, 5, 32, 3, 45, 0, 90, 2, 58, 4, 22, 6, 62, 
    7,  7, 0, 10, 2, 73, 3, 13, 4, 33, 6,  8, 1, 36, 8, 49, 5, 46, 
    0, 34, 1, 30, 2, 88, 7, 66, 3,  7, 6, 82, 5, 42, 4, 31, 8, 35, 
    4, 90, 1, 92, 0,  1, 6, 35, 5, 53, 7, 51, 2, 75, 3, 87, 8, 95, 
    5, 72, 2, 55, 6,  6, 8, 87, 4, 45, 1, 54, 3, 99, 7, 90, 0,  7, 
    8, 58, 3, 31, 7, 72, 5, 54, 6, 98, 2, 74, 4, 50, 1, 49, 0, 34, 
    4,  8, 5, 41, 0, 16, 6, 38, 3, 93, 2, 16, 7, 23, 1, 33, 8,  1
  };
  const int q2663[] = {
    9, 9, // Number of jobs and machines
    6, 50, 7, 39, 5, 73, 3, 47, 4, 82, 0, 44, 8, 30, 1,  9, 2, 62, 
    4, 49, 1, 44, 8, 63, 0, 75, 3, 53, 2, 79, 5, 10, 6, 37, 7, 19, 
    4, 35, 8, 45, 1,  5, 6, 46, 0, 95, 7, 59, 3, 27, 5, 39, 2, 51, 
    6, 85, 4, 31, 5, 10, 8, 66, 7, 57, 2, 99, 0, 79, 1, 33, 3, 21, 
    7, 36, 6, 84, 3,  9, 0, 28, 4, 51, 5, 38, 2, 79, 8, 37, 1, 66, 
    3, 26, 0, 59, 1, 61, 7, 58, 5, 15, 4, 20, 8, 89, 6, 82, 2,  4, 
    8, 82, 4, 91, 1, 12, 0, 19, 6, 50, 7, 65, 3,  7, 5, 56, 2,  1, 
    3, 82, 0, 16, 7, 38, 5, 11, 6, 63, 2, 11, 4, 89, 8, 88, 1, 12, 
    4, 73, 2, 33, 5, 17, 0, 12, 6, 10, 8, 78, 1, 48, 3, 57, 7, 45
  };
  const int q2664[] = {
    9, 9, // Number of jobs and machines
    1, 24, 8, 62, 0, 45, 4, 75, 3, 26, 6, 75, 5, 57, 2, 40, 7, 15, 
    1, 14, 8, 64, 6, 33, 7, 69, 4, 57, 2, 14, 0, 85, 5, 38, 3, 83, 
    5, 12, 7, 65, 8, 57, 6,  5, 2, 70, 1, 90, 3,  9, 4, 40, 0, 77, 
    8, 51, 6, 71, 4, 79, 0, 50, 1, 30, 3, 93, 7, 92, 5, 20, 2, 40, 
    8, 65, 1, 63, 5, 56, 2, 29, 7, 40, 0,  5, 6,  2, 4, 11, 3, 30, 
    3, 31, 0, 10, 7, 43, 4, 80, 2, 16, 6, 14, 8, 20, 1, 70, 5, 33, 
    7, 37, 4, 33, 8, 40, 5,  9, 1, 75, 0, 65, 6, 27, 2, 44, 3, 93, 
    0, 59, 5, 24, 4, 74, 2, 55, 8,  1, 1, 72, 6, 10, 3, 69, 7, 67, 
    2, 93, 8, 90, 7, 82, 3, 39, 0, 12, 5, 95, 6, 93, 4, 75, 1,  3
  };
  const int q2665[] = {
    9, 9, // Number of jobs and machines
    0, 19, 7, 97, 3, 54, 6, 78, 5, 15, 2, 72, 8, 30, 1, 88, 4, 80, 
    8, 17, 1, 71, 7, 17, 2, 59, 5, 60, 0, 78, 3, 92, 4, 33, 6, 41, 
    8, 41, 3, 31, 7, 41, 0, 11, 1, 35, 5, 90, 6, 35, 4, 94, 2, 76, 
    6, 76, 4, 97, 3, 15, 1, 12, 0, 66, 5, 56, 7, 12, 8, 11, 2, 85, 
    6, 41, 0, 77, 1, 55, 8, 80, 3,  9, 4, 87, 7, 82, 5, 73, 2, 53, 
    2, 96, 4, 89, 7, 48, 5, 59, 1, 26, 6, 84, 8, 18, 3,  2, 0, 97, 
    2, 51, 0, 38, 8, 88, 3,  8, 7, 68, 4,  6, 1,  9, 6, 54, 5, 23, 
    0, 55, 4, 46, 2, 84, 7, 35, 1, 78, 5, 39, 8, 51, 6, 41, 3, 74, 
    5, 78, 7, 58, 6, 10, 8, 99, 2, 20, 0, 17, 4, 30, 3, 47, 1, 94
  };
  const int q2666[] = {
    9, 9, // Number of jobs and machines
    7, 47, 5, 94, 3, 67, 1, 69, 6, 23, 0, 75, 8, 72, 4, 76, 2, 38, 
    5, 95, 4, 67, 6, 16, 7, 78, 1, 12, 0, 78, 2, 74, 8, 64, 3,  9, 
    5, 94, 0, 15, 8,  6, 1, 57, 3,  4, 2, 77, 4, 39, 6, 43, 7, 35, 
    5, 88, 0, 88, 6, 36, 3, 47, 4, 90, 7, 19, 8, 38, 2, 41, 1, 31, 
    1, 74, 6, 65, 5,  6, 3, 17, 2, 59, 4, 41, 0,  4, 8, 19, 7, 28, 
    1, 44, 3, 39, 7, 16, 4, 76, 5, 10, 8, 75, 2, 81, 6, 16, 0, 69, 
    6, 74, 0, 60, 8, 62, 1, 89, 7, 14, 2, 18, 3, 81, 5, 95, 4, 26, 
    7, 19, 0, 88, 3, 83, 5, 35, 2, 56, 4, 64, 1, 10, 6, 41, 8, 71, 
    7, 29, 4,  4, 5,  6, 1, 88, 8, 44, 2, 43, 3, 77, 0, 91, 6, 75
  };
  const int q2667[] = {
    9, 9, // Number of jobs and machines
    2, 41, 8, 90, 1, 50, 3, 85, 6, 43, 5, 40, 4,  8, 0, 70, 7, 52, 
    6, 84, 0,  4, 7, 83, 3, 42, 8, 85, 5, 83, 2, 63, 4, 53, 1, 78, 
    3, 60, 5, 44, 8, 61, 0, 70, 2, 62, 6, 62, 1, 54, 4, 76, 7, 81, 
    2, 93, 7, 46, 8, 89, 5, 77, 3, 20, 6, 71, 1, 84, 0, 54, 4, 45, 
    6, 22, 0,  5, 1, 80, 4, 98, 5,  6, 3, 22, 7, 70, 8, 86, 2, 34, 
    2, 11, 3, 52, 4, 25, 1, 73, 0, 22, 7, 99, 8, 74, 5, 38, 6, 58, 
    7, 64, 3, 68, 1, 83, 5, 47, 4, 66, 2, 73, 6, 53, 8, 69, 0, 97, 
    4, 39, 1, 66, 3, 13, 5, 40, 7, 79, 2, 63, 6, 58, 8, 50, 0, 41, 
    7, 52, 5, 76, 4, 53, 0, 83, 2, 47, 6, 28, 1, 81, 8, 70, 3, 40
  };
  const int q2668[] = {
    9, 9, // Number of jobs and machines
    6, 10, 1, 95, 4, 20, 7, 82, 8, 97, 5, 37, 3, 86, 0, 15, 2,  6, 
    5, 39, 1, 99, 7, 33, 4, 93, 6, 35, 0, 23, 2, 15, 3, 24, 8, 64, 
    6, 31, 1, 50, 3, 64, 5, 79, 4,  1, 7,  8, 2, 27, 8, 94, 0, 60, 
    8, 47, 5, 31, 4, 37, 6, 48, 1, 59, 3, 55, 2,  7, 0, 21, 7, 79, 
    4,  1, 5, 46, 2, 37, 6,  6, 1, 35, 0, 18, 8, 75, 7, 51, 3, 33, 
    7, 51, 5, 77, 3, 44, 0, 29, 4, 29, 2, 81, 6, 63, 1, 42, 8, 87, 
    3, 67, 2, 93, 4, 14, 8, 15, 6, 34, 1, 77, 7, 85, 0, 49, 5, 57, 
    2, 85, 3, 69, 0, 77, 8, 58, 4, 21, 7, 29, 1, 46, 6, 12, 5, 62, 
    5, 35, 2, 12, 3, 86, 0, 36, 1, 83, 4, 40, 8, 97, 6, 61, 7,  4
  };
  const int q2669[] = {
    9, 9, // Number of jobs and machines
    6, 60, 1,  4, 2, 82, 8, 44, 7, 21, 4, 40, 3, 23, 5, 77, 0, 25, 
    3, 87, 6, 41, 4, 29, 8, 78, 0, 35, 2, 43, 5, 90, 7, 25, 1, 22, 
    0, 14, 7,  3, 8, 43, 3, 33, 5, 40, 2, 94, 1, 91, 4, 60, 6, 82, 
    0, 61, 5, 42, 1, 16, 8, 10, 6, 58, 2, 44, 7,  4, 3, 25, 4, 66, 
    3, 53, 2,  2, 1, 24, 0, 22, 4, 34, 6, 97, 8, 87, 7, 96, 5, 80, 
    4, 80, 7, 75, 6, 44, 3, 20, 0, 43, 8, 30, 5, 72, 1,  2, 2, 58, 
    1, 87, 0, 93, 7, 17, 4, 13, 5, 67, 8, 88, 3, 45, 6, 77, 2,  4, 
    7, 36, 4, 79, 8,  9, 0, 77, 5, 94, 1, 67, 2, 59, 3, 79, 6, 58, 
    5, 29, 3, 15, 6,  6, 1, 70, 7, 82, 8, 61, 2, 52, 4, 65, 0, 82
  };
  const int q2670[] = {
    9, 9, // Number of jobs and machines
    1, 53, 0, 33, 6, 57, 8, 10, 7, 36, 5, 60, 3, 40, 2, 62, 4, 68, 
    7, 54, 8, 92, 3, 67, 6, 98, 2, 47, 1,  6, 4,  9, 5, 53, 0, 83, 
    5, 19, 7, 76, 3, 87, 1, 20, 2, 79, 0, 82, 4, 94, 6, 14, 8, 39, 
    8, 89, 1, 17, 6, 26, 2,  3, 7,  9, 5, 70, 3, 89, 4, 11, 0, 52, 
    1, 45, 6, 18, 3, 64, 4, 98, 8, 77, 5, 40, 0, 27, 2, 18, 7, 53, 
    7,  8, 4, 36, 6, 53, 3,  2, 2, 83, 5,  2, 0,  7, 8, 62, 1, 51, 
    4, 17, 7, 16, 1,  9, 3, 84, 5, 53, 2, 25, 8,  7, 0, 78, 6, 51, 
    0, 30, 7, 85, 3, 71, 1, 64, 8, 33, 4, 24, 6, 50, 2, 51, 5, 64, 
    8, 59, 3, 68, 2, 56, 4, 25, 7, 43, 1, 19, 6, 15, 0, 21, 5, 82
  };
  const int q2671[] = {
    9, 9, // Number of jobs and machines
    0,  8, 6, 17, 4, 70, 5,  5, 8, 71, 1, 43, 2, 70, 3, 95, 7,  5, 
    3, 10, 5, 94, 4, 17, 2, 67, 6, 77, 1, 95, 8, 37, 7, 99, 0, 16, 
    4, 71, 0, 89, 8, 69, 1, 16, 7, 29, 5, 30, 2,  6, 6, 63, 3, 63, 
    8, 95, 3, 88, 1, 96, 7, 77, 6, 30, 2, 88, 5, 32, 4, 58, 0, 94, 
    5, 59, 6, 54, 1, 22, 7, 46, 4,  9, 0, 34, 3, 99, 2, 59, 8, 57, 
    1, 50, 7, 72, 3,  1, 2, 36, 6, 98, 5, 68, 8, 63, 4, 37, 0, 41, 
    0,  6, 5, 41, 2, 28, 7, 64, 1, 85, 3, 78, 8, 54, 6,  8, 4, 74, 
    8, 35, 5, 20, 6, 44, 4, 68, 1,  2, 3, 15, 7, 69, 0, 46, 2, 26, 
    7, 40, 0, 92, 1, 83, 8, 47, 5, 11, 4, 44, 3, 88, 6, 80, 2, 31
  };
  const int q2672[] = {
    9, 9, // Number of jobs and machines
    8, 90, 7, 80, 6, 90, 1, 28, 5, 90, 4, 43, 2, 53, 0, 72, 3, 88, 
    5, 39, 2, 99, 1, 41, 8, 57, 4, 73, 0, 97, 3, 43, 7, 54, 6, 63, 
    5, 89, 6, 80, 8, 79, 4, 47, 3, 49, 0,  4, 7, 54, 2, 25, 1,  2, 
    4, 50, 0, 82, 1,  6, 3, 86, 8, 74, 2, 21, 6, 37, 7, 56, 5, 91, 
    4, 27, 1, 73, 5, 84, 7, 83, 0, 66, 3, 58, 2, 84, 8, 36, 6, 95, 
    4, 73, 5, 73, 6,  9, 7, 58, 3, 56, 8, 55, 2, 30, 0, 34, 1, 67, 
    5, 29, 4, 62, 6, 41, 3, 55, 0, 16, 8, 41, 1, 18, 7, 50, 2, 50, 
    6, 52, 1, 64, 8, 12, 7, 19, 2, 10, 4, 47, 3, 31, 5, 90, 0, 98, 
    3, 29, 8, 59, 4, 68, 1, 54, 0,  7, 6, 56, 5, 61, 2, 44, 7, 29
  };
  const int q2673[] = {
    9, 9, // Number of jobs and machines
    5, 60, 6, 40, 4, 99, 2, 88, 3, 32, 7, 44, 8, 80, 0, 50, 1, 58, 
    5,  5, 7,  2, 6, 24, 2, 28, 4, 28, 8, 53, 1, 87, 3, 10, 0, 61, 
    4, 99, 0, 20, 2, 50, 7, 69, 8, 59, 1, 35, 3, 38, 6, 12, 5, 79, 
    2, 75, 8, 41, 1,  9, 7, 66, 6, 41, 0, 80, 5, 19, 3, 33, 4, 92, 
    5,  3, 1, 49, 2, 43, 0, 90, 7, 89, 3, 95, 4, 83, 6, 69, 8, 42, 
    0, 85, 2, 71, 3, 51, 7, 96, 6, 68, 4, 33, 8, 66, 5, 31, 1, 24, 
    6, 88, 0, 66, 5, 14, 7, 37, 1,  5, 8, 20, 2, 72, 3, 38, 4,  6, 
    0, 79, 2, 86, 4, 45, 8, 93, 3, 95, 6, 52, 1, 54, 5, 51, 7, 31, 
    2, 46, 3, 44, 6, 94, 4, 80, 7, 22, 1, 25, 8, 73, 5, 52, 0, 20
  };
  const int q2674[] = {
    9, 9, // Number of jobs and machines
    2, 39, 4, 49, 8, 80, 5,  4, 6, 45, 7, 14, 0, 49, 1, 13, 3, 73, 
    1,  3, 4, 98, 3, 94, 6, 16, 7, 33, 8, 23, 2, 98, 5, 60, 0, 63, 
    8, 67, 7, 83, 6, 48, 0, 51, 3, 84, 2, 85, 4, 90, 5, 59, 1, 96, 
    6, 77, 2, 65, 4, 25, 7, 72, 1, 30, 3, 24, 5, 88, 0, 71, 8, 87, 
    5, 86, 2, 95, 6, 67, 0, 22, 1, 23, 4, 50, 8, 68, 7, 61, 3, 86, 
    0, 83, 5, 51, 8, 10, 4, 61, 1,  2, 3, 14, 6, 18, 7, 35, 2, 55, 
    6, 67, 7,  4, 8, 26, 1, 94, 2,  9, 4, 41, 0, 33, 5, 28, 3, 13, 
    0, 65, 1, 16, 2, 69, 3,  4, 8, 78, 6, 63, 4, 46, 5,  7, 7, 88, 
    5, 46, 4,  5, 6, 37, 3, 27, 0, 72, 1,  6, 7, 89, 2,  5, 8, 18
  };
  const int q2675[] = {
    9, 9, // Number of jobs and machines
    6,  9, 0, 96, 7,  1, 4, 93, 2, 74, 3, 32, 8, 75, 5, 68, 1, 63, 
    1, 55, 6, 10, 0,  5, 4, 53, 2, 22, 5, 59, 8, 11, 3, 85, 7, 83, 
    6, 94, 1, 47, 3, 16, 2, 40, 5,  6, 4,  1, 7, 11, 0, 82, 8, 79, 
    1, 12, 4,  3, 3, 51, 5,  3, 6, 60, 2, 29, 0, 17, 7, 46, 8, 49, 
    6, 47, 7, 24, 4, 39, 8,  6, 1,  6, 5, 84, 3, 28, 2,  4, 0, 48, 
    7, 23, 4,  8, 5, 40, 0, 74, 8,  7, 1, 56, 2, 94, 6, 25, 3,  8, 
    3, 85, 5, 93, 4, 97, 8, 78, 2, 91, 6, 73, 7, 52, 1, 79, 0, 88, 
    3, 15, 0, 49, 5,  2, 4, 13, 7, 37, 2, 84, 8,  4, 1, 53, 6, 29, 
    6, 21, 7, 19, 0, 20, 1, 60, 3,  5, 4, 42, 8, 16, 5, 23, 2,  3
  };
  const int q2676[] = {
    9, 9, // Number of jobs and machines
    2, 50, 7, 97, 6, 97, 4, 47, 8, 75, 5, 53, 1, 74, 0, 50, 3, 79, 
    5, 37, 0, 48, 3, 46, 7, 21, 2, 37, 4, 65, 1, 18, 8,  9, 6, 36, 
    7,  4, 8, 90, 3, 25, 2, 50, 6, 49, 4, 59, 1, 24, 5, 49, 0, 80, 
    6, 36, 7, 30, 3, 81, 1, 95, 0, 84, 4, 12, 2, 19, 5, 80, 8, 53, 
    1,  4, 8, 19, 2, 56, 0, 50, 5,  9, 6, 70, 3, 13, 4, 58, 7, 67, 
    4, 84, 7, 16, 0, 34, 8, 81, 6, 72, 5,  2, 3, 46, 1, 68, 2, 81, 
    2, 49, 1, 38, 4, 45, 8, 24, 7,  5, 0, 54, 3, 27, 6, 41, 5, 15, 
    2, 47, 8, 86, 4, 66, 0, 21, 7, 41, 1, 76, 3, 76, 6, 45, 5, 71, 
    4, 18, 0, 44, 5, 24, 3, 44, 7, 41, 6, 25, 8,  2, 1, 50, 2, 54
  };
  const int q2677[] = {
    9, 9, // Number of jobs and machines
    0, 70, 2, 98, 5, 26, 1, 43, 4, 90, 8, 55, 7, 43, 3, 52, 6, 43, 
    0, 79, 3, 22, 2, 94, 7,  8, 8, 80, 4, 90, 6, 47, 1, 78, 5, 48, 
    4, 81, 6, 20, 3, 36, 1, 53, 8, 22, 2, 71, 0, 47, 7, 96, 5, 67, 
    0, 27, 8, 80, 5, 13, 6, 87, 3, 25, 7, 89, 4, 49, 1, 87, 2, 86, 
    0, 54, 3, 31, 1, 66, 5, 64, 4, 57, 7,  4, 2, 50, 6, 94, 8, 65, 
    6, 35, 4, 45, 1, 89, 0, 32, 3, 40, 8, 52, 2, 61, 7, 91, 5, 91, 
    0, 37, 8, 17, 2, 64, 3, 99, 4, 50, 7, 80, 6, 18, 1, 50, 5, 72, 
    2, 51, 3, 49, 0,  7, 1, 62, 6, 69, 8, 75, 4,  7, 5, 97, 7, 24, 
    5, 17, 7, 64, 8, 58, 3, 22, 6, 87, 0, 69, 4, 59, 2, 92, 1, 74
  };
  const int q2678[] = {
    9, 9, // Number of jobs and machines
    8, 16, 5, 16, 6, 38, 2,  5, 4, 51, 1, 16, 3, 80, 7, 20, 0, 97, 
    1, 44, 2, 89, 5, 81, 3, 22, 6, 43, 0, 28, 8, 64, 7, 18, 4, 45, 
    0, 24, 8, 21, 1, 55, 6, 13, 4, 90, 3, 63, 5, 56, 7, 47, 2, 94, 
    6, 47, 3, 97, 2, 30, 1, 75, 8, 49, 5, 77, 0, 40, 4, 42, 7, 85, 
    5, 10, 4, 58, 6, 64, 7, 37, 8, 12, 0, 75, 3, 87, 1, 35, 2,  8, 
    7, 55, 4, 93, 5, 92, 0, 65, 3, 70, 2, 30, 8, 54, 1, 40, 6, 29, 
    5, 66, 4, 99, 0,  2, 8,  5, 2, 64, 3, 34, 1, 98, 6, 91, 7, 10, 
    2, 81, 4, 54, 7, 63, 5, 29, 3, 19, 6, 25, 1, 18, 8, 93, 0, 36, 
    1, 92, 5, 34, 0, 27, 6, 59, 8, 43, 4, 32, 2, 64, 3, 33, 7, 40
  };
  const int q2679[] = {
    9, 9, // Number of jobs and machines
    8, 30, 1, 52, 5, 65, 4, 74, 3, 49, 7, 70, 2, 57, 0, 72, 6, 51, 
    8,  1, 5, 61, 1, 50, 7, 35, 0, 50, 6, 78, 2, 66, 4, 57, 3, 47, 
    7, 43, 1, 10, 2, 65, 6, 66, 3, 75, 5, 11, 0, 59, 8, 94, 4, 60, 
    3, 93, 5, 94, 8, 44, 4, 41, 6, 51, 7, 79, 1, 13, 0, 63, 2, 47, 
    6, 96, 3, 82, 7, 85, 4, 52, 2, 11, 5, 26, 0, 86, 1, 65, 8, 48, 
    7, 35, 5, 79, 8, 71, 2, 92, 6,  9, 4, 56, 0, 62, 1, 44, 3,  5, 
    6, 21, 4, 34, 7, 79, 5, 25, 3,  1, 8, 33, 1, 88, 0, 68, 2, 17, 
    2, 88, 1, 43, 5, 76, 4, 29, 6, 42, 7, 35, 3, 71, 8, 88, 0, 14, 
    2, 51, 0, 38, 8, 94, 6, 14, 1, 43, 5, 71, 3, 43, 7, 12, 4, 15
  };
  const int q2680[] = {
    9, 9, // Number of jobs and machines
    4, 16, 6, 70, 5,  1, 0, 25, 2, 38, 3, 39, 1, 51, 8, 65, 7,  9, 
    5, 73, 3, 12, 4, 85, 7, 49, 1, 70, 6,  4, 0, 94, 2, 28, 8, 70, 
    8, 41, 6, 55, 7, 89, 1, 89, 5, 41, 4, 92, 0, 59, 2, 85, 3, 95, 
    4, 12, 0, 92, 2, 83, 7, 50, 6, 15, 1, 53, 3, 35, 8, 60, 5,  2, 
    8,  9, 5, 13, 0, 17, 1, 75, 6, 81, 7, 44, 2,  6, 3, 68, 4, 82, 
    1, 20, 4, 22, 8, 81, 3, 76, 2, 58, 0,  3, 5, 85, 7, 88, 6, 68, 
    1, 24, 2, 98, 5, 90, 7, 48, 0, 21, 4,  2, 8, 89, 3, 42, 6, 10, 
    3, 63, 6, 48, 0, 74, 2, 84, 5, 67, 8, 64, 1, 50, 7, 77, 4, 44, 
    3, 87, 2, 24, 4, 70, 8, 23, 6, 78, 0, 38, 7,  1, 1, 77, 5, 53
  };
  const int q2681[] = {
    9, 9, // Number of jobs and machines
    8, 59, 1, 69, 7, 47, 0, 36, 5, 80, 4, 41, 2, 51, 6, 20, 3, 38, 
    0, 89, 4, 18, 7,  2, 8, 59, 5, 64, 6, 93, 3, 14, 1, 27, 2, 74, 
    4, 55, 2,  7, 5, 90, 1, 22, 3, 82, 8, 74, 7, 97, 6, 92, 0, 37, 
    3, 12, 0, 30, 8, 44, 1, 47, 4, 37, 2, 56, 5, 32, 7, 56, 6, 71, 
    2, 57, 5, 91, 0, 83, 3, 35, 1, 94, 8, 51, 6,  1, 7, 35, 4, 72, 
    7, 26, 8, 77, 4, 84, 0, 91, 5,  5, 2, 17, 6, 31, 3, 49, 1, 14, 
    0, 84, 6, 59, 7, 32, 5, 31, 2, 76, 3, 20, 4, 86, 1, 85, 8, 28, 
    2, 56, 7, 66, 4, 91, 5, 41, 0,  5, 3, 40, 1, 13, 6, 82, 8, 19, 
    6, 81, 8, 95, 0, 57, 2, 83, 3, 58, 4, 54, 5, 40, 7, 28, 1, 83
  };
  const int q2682[] = {
    9, 9, // Number of jobs and machines
    4, 89, 0, 44, 6, 45, 8, 29, 3, 24, 2, 72, 1,  2, 7, 77, 5, 32, 
    6, 40, 4, 84, 8, 26, 1, 29, 2, 54, 0, 14, 7, 30, 5, 57, 3, 46, 
    6,  9, 8, 74, 1, 64, 2,  7, 3,  8, 4, 13, 5,  8, 7, 24, 0, 18, 
    5, 49, 1, 77, 3, 43, 0, 50, 8, 64, 4, 64, 7, 29, 2, 68, 6, 44, 
    8, 31, 2, 41, 7, 97, 5, 18, 3, 23, 0, 37, 4, 63, 6, 15, 1, 36, 
    5, 16, 0, 51, 7, 52, 1, 81, 2, 96, 4, 46, 3, 33, 6, 51, 8,  9, 
    1, 98, 2, 36, 8, 54, 5, 53, 7,  7, 0, 17, 3, 14, 6, 56, 4, 68, 
    6, 22, 0, 66, 7, 14, 5,  8, 8, 83, 4, 83, 3, 99, 2, 36, 1, 89, 
    0, 91, 3, 87, 2, 80, 1, 19, 8, 23, 5, 92, 4, 28, 7, 50, 6, 77
  };
  const int q2683[] = {
    9, 9, // Number of jobs and machines
    8, 84, 0,  8, 3, 26, 6, 95, 5, 39, 7, 52, 1,  1, 4, 21, 2, 82, 
    7, 73, 6, 82, 8, 69, 5, 49, 0, 64, 2,  3, 1, 17, 4, 76, 3, 61, 
    8, 95, 1,  7, 0, 19, 3, 33, 5, 99, 7,  3, 4, 39, 6, 44, 2, 70, 
    0, 24, 2, 35, 8, 59, 1, 56, 4, 94, 5, 41, 6, 72, 7, 76, 3, 45, 
    0, 30, 8, 35, 1, 74, 2, 80, 6, 39, 4, 68, 5, 91, 3, 30, 7, 67, 
    5, 50, 2, 48, 1, 46, 4, 74, 8, 71, 3, 74, 7, 35, 6, 73, 0, 32, 
    4, 68, 2, 79, 6, 57, 3, 56, 5, 21, 8, 60, 1,  4, 7, 79, 0, 62, 
    5, 68, 6, 45, 0,  3, 7, 23, 8, 75, 2, 63, 3, 17, 4, 61, 1, 61, 
    6, 49, 7,  6, 3, 42, 1, 68, 0, 46, 4, 42, 2, 35, 5, 45, 8, 27
  };
  const int q2684[] = {
    9, 9, // Number of jobs and machines
    2, 58, 6, 37, 4, 88, 1, 52, 5, 40, 7, 21, 8, 16, 0, 77, 3, 82, 
    3, 43, 5, 35, 0, 80, 7, 75, 6, 60, 4, 70, 1, 86, 8, 86, 2,  2, 
    2, 22, 0, 75, 6,  4, 7, 51, 5, 64, 1, 51, 3, 75, 4, 86, 8, 82, 
    1, 30, 3, 24, 4, 59, 0, 12, 6, 52, 2, 61, 8, 61, 5, 93, 7, 21, 
    3, 21, 7, 19, 2, 12, 6, 94, 5, 24, 0, 91, 1, 67, 8, 48, 4, 37, 
    5, 68, 6, 38, 7, 87, 8, 20, 4, 16, 2, 77, 0, 90, 3,  1, 1, 74, 
    6, 19, 5, 32, 8, 23, 3, 31, 2, 75, 4, 27, 0,  3, 7, 81, 1, 46, 
    4, 68, 2, 61, 3, 52, 5, 63, 8, 91, 0, 53, 1, 53, 7,  8, 6, 99, 
    6,  9, 4, 44, 7, 12, 8, 54, 1, 93, 0, 20, 3, 17, 2, 22, 5, 63
  };
  const int q2685[] = {
    9, 9, // Number of jobs and machines
    1, 18, 0, 63, 8, 57, 5, 42, 7,  9, 4,  9, 6,  2, 2, 82, 3, 45, 
    2, 34, 6, 76, 1, 52, 8, 39, 5, 74, 0, 96, 7, 42, 4, 67, 3, 18, 
    3, 76, 0, 88, 6, 25, 7, 93, 4, 39, 8, 39, 2, 85, 1, 39, 5, 35, 
    0, 61, 6, 91, 8, 82, 4, 74, 7, 74, 2, 33, 5, 41, 1, 17, 3, 87, 
    2, 58, 8, 35, 5, 82, 6, 23, 0, 84, 7,  5, 1, 29, 3, 27, 4, 15, 
    5, 55, 3, 51, 2, 58, 6, 36, 4, 52, 0, 68, 7, 34, 1, 68, 8, 88, 
    1, 37, 5, 84, 6, 38, 2, 80, 4, 78, 0, 17, 7, 80, 8, 75, 3, 86, 
    1, 97, 0, 21, 6, 63, 2,  4, 5, 87, 8, 63, 3, 93, 4, 85, 7, 73, 
    3, 23, 2, 60, 8, 22, 7, 80, 0,  9, 4, 41, 1,  2, 5, 33, 6, 43
  };
  const int q2686[] = {
    9, 9, // Number of jobs and machines
    2, 36, 4, 87, 5, 68, 3, 44, 6, 46, 1, 68, 8, 80, 0, 90, 7, 70, 
    7, 38, 5,  9, 8,  1, 4, 75, 6, 58, 1, 13, 0, 47, 3, 89, 2, 63, 
    6, 54, 5, 99, 7, 44, 0, 58, 8, 97, 3,  7, 1,  6, 2, 92, 4, 91, 
    2, 30, 3, 96, 1, 86, 4, 44, 6, 86, 7, 91, 5, 45, 0, 37, 8, 66, 
    6, 60, 4, 51, 3, 71, 8,  9, 7, 16, 5, 77, 1, 20, 0, 44, 2,  6, 
    7, 51, 1, 60, 8, 50, 5, 31, 4, 79, 3, 39, 2, 16, 0, 80, 6, 83, 
    0, 16, 8, 88, 1, 60, 5, 48, 4, 50, 2, 68, 7, 42, 6,  8, 3, 72, 
    0, 69, 1, 45, 4,  1, 2,  8, 6, 76, 8, 83, 5, 45, 3, 16, 7, 26, 
    5, 36, 1, 18, 0, 50, 4, 30, 7, 37, 2, 81, 3, 21, 8, 93, 6, 42
  };
  const int q2687[] = {
    9, 9, // Number of jobs and machines
    4, 64, 3,  9, 2, 87, 0, 50, 7, 80, 5, 50, 6, 45, 1, 19, 8,  2, 
    0, 61, 4, 75, 7, 36, 8, 43, 5, 83, 6, 24, 3, 34, 2, 92, 1, 81, 
    4, 94, 8, 76, 6, 59, 1,  5, 3, 24, 7, 59, 2, 12, 5, 86, 0, 81, 
    8, 99, 2, 92, 6, 80, 0, 36, 4, 71, 5, 37, 7, 19, 1, 48, 3, 46, 
    3,  7, 0, 49, 4, 80, 6,  7, 8, 17, 5, 76, 1, 65, 2, 57, 7,  8, 
    6, 82, 5, 76, 1,  2, 8, 66, 3, 79, 0, 75, 4, 38, 7, 60, 2, 81, 
    2, 71, 0, 96, 4, 30, 8, 95, 7, 89, 6, 37, 5, 81, 3,  3, 1, 86, 
    0, 35, 4, 77, 5, 96, 8, 15, 6, 67, 2, 34, 7, 74, 1, 78, 3, 39, 
    2, 23, 7, 23, 3, 44, 0, 18, 5, 33, 4, 90, 6, 98, 1, 75, 8, 22
  };
  const int q2688[] = {
    9, 9, // Number of jobs and machines
    1, 13, 2, 57, 0, 19, 6, 28, 3, 96, 4, 74, 5, 72, 8, 29, 7, 21, 
    8, 39, 7, 94, 1, 43, 4, 11, 3, 14, 6, 82, 0, 13, 2, 64, 5, 38, 
    5, 84, 3,  1, 2, 30, 0, 43, 6, 68, 8, 90, 1, 15, 7, 53, 4, 53, 
    8, 78, 5, 34, 2,  5, 3, 96, 6, 56, 7, 82, 1,  3, 4, 20, 0, 43, 
    5, 92, 6,  6, 3, 96, 1, 41, 4, 14, 0, 36, 7, 68, 8, 31, 2, 34, 
    7, 33, 1, 89, 0, 35, 8, 93, 6, 12, 4, 64, 5, 48, 2, 43, 3, 60, 
    1, 69, 7, 44, 3, 88, 8, 90, 2, 69, 5, 35, 4, 30, 6, 29, 0, 82, 
    4, 48, 6,  2, 1, 71, 3, 98, 7, 64, 0,  3, 8, 49, 5, 29, 2, 47, 
    1, 63, 7, 99, 2, 26, 6, 16, 5, 42, 0, 82, 4, 20, 3, 68, 8, 74
  };
  const int q2689[] = {
    9, 9, // Number of jobs and machines
    5, 22, 3,  5, 1, 45, 4, 18, 2, 80, 7, 68, 0, 90, 8,  8, 6, 20, 
    3, 22, 2, 53, 5, 76, 8, 80, 6, 18, 0, 52, 1, 12, 7, 17, 4,  1, 
    2,  3, 5, 49, 3,  5, 0, 97, 1, 98, 4, 80, 8, 43, 7, 50, 6, 77, 
    6, 95, 2, 90, 0, 22, 4, 32, 3, 93, 8,  2, 1, 82, 5, 80, 7, 13, 
    6,  5, 3,  4, 4, 62, 1, 58, 5,  8, 7,  7, 8, 20, 2, 90, 0,  5, 
    5, 86, 7, 60, 2, 80, 6, 45, 1, 36, 3, 40, 0, 40, 8, 51, 4, 10, 
    2, 61, 5, 97, 3, 35, 7, 40, 0, 58, 4, 99, 8, 56, 6, 67, 1, 62, 
    0, 75, 6, 63, 3, 50, 1, 16, 4, 19, 7, 39, 5, 12, 8,  7, 2, 75, 
    4, 71, 6, 65, 3, 39, 7,  5, 5, 92, 1, 12, 8, 52, 0, 72, 2, 52
  };
  const int q2690[] = {
    9, 9, // Number of jobs and machines
    4, 34, 1,  4, 6,  8, 2, 44, 5, 73, 3, 66, 0, 28, 7, 92, 8, 14, 
    8,  7, 2, 37, 4, 84, 6, 41, 1, 82, 3, 34, 0, 97, 7, 97, 5, 78, 
    0,  2, 6, 79, 5, 35, 3, 81, 2,  7, 1, 10, 8,  9, 7, 46, 4,  8, 
    8, 95, 3, 10, 6, 83, 4, 60, 7, 38, 0,  3, 2, 82, 1, 37, 5, 86, 
    1, 67, 5, 54, 0, 50, 4, 94, 2, 70, 7, 19, 8, 46, 6, 30, 3, 14, 
    1, 41, 4, 30, 8, 38, 7, 77, 6, 69, 3, 22, 5, 87, 2, 60, 0, 15, 
    3, 46, 4, 65, 8, 16, 2, 98, 5, 81, 7, 67, 1, 41, 0, 41, 6, 75, 
    7, 83, 2, 38, 8,  6, 4, 63, 1, 62, 3, 19, 5, 11, 6, 92, 0, 44, 
    8, 37, 2, 43, 5, 53, 0, 97, 4, 92, 6, 75, 1,  5, 3, 89, 7, 86
  };
  const int q2691[] = {
    9, 9, // Number of jobs and machines
    5, 78, 4, 70, 7, 65, 2, 84, 0, 82, 3, 86, 6, 13, 1, 18, 8, 34, 
    4, 23, 3, 85, 1, 13, 8, 19, 0, 14, 6,  2, 7, 58, 5, 41, 2, 69, 
    7, 93, 2, 75, 3, 26, 5, 65, 1,  1, 4, 12, 6, 25, 8,  5, 0, 56, 
    4, 72, 6, 14, 8, 26, 7, 60, 0, 92, 3, 82, 1,  2, 2, 90, 5, 83, 
    2, 80, 3, 24, 4, 93, 7, 61, 6, 10, 0, 90, 1, 63, 5, 82, 8,  9, 
    1, 60, 0, 42, 4, 42, 2, 78, 3, 98, 5, 17, 6, 89, 8, 53, 7, 77, 
    1,  8, 4, 71, 2, 98, 7, 98, 6, 71, 8, 89, 5, 22, 0, 58, 3, 23, 
    2, 71, 8, 86, 4, 24, 7, 35, 0, 23, 3, 25, 6, 12, 1, 85, 5, 55, 
    2, 81, 0, 59, 3, 17, 5, 12, 6, 31, 1, 72, 8, 56, 4, 76, 7, 33
  };
  const int q2692[] = {
    9, 9, // Number of jobs and machines
    6, 64, 4, 13, 3, 21, 1, 35, 0, 59, 2, 41, 8, 94, 5, 87, 7, 45, 
    2, 13, 1, 76, 7, 40, 5, 60, 4, 69, 8, 83, 0, 72, 6, 97, 3, 90, 
    7, 70, 2, 36, 8, 50, 6, 48, 0, 10, 1, 31, 5, 14, 3, 86, 4,  9, 
    8, 47, 7, 73, 3, 47, 4, 33, 6,  6, 1, 15, 2, 93, 5, 35, 0, 38, 
    7, 20, 8, 66, 6, 98, 5, 73, 3, 55, 4, 14, 1, 78, 0, 13, 2, 68, 
    2, 19, 8,  6, 4, 40, 3, 32, 1, 62, 0, 65, 7,  5, 6, 31, 5, 70, 
    2, 38, 1, 73, 4,  9, 7, 92, 5, 22, 0, 42, 6, 28, 3, 99, 8, 65, 
    1, 62, 8, 50, 3, 15, 7, 87, 6, 32, 5, 42, 4, 42, 0, 91, 2, 87, 
    3, 51, 4, 99, 0, 84, 5, 90, 2, 10, 8, 74, 7, 97, 6, 84, 1, 42
  };
  const int q2693[] = {
    9, 9, // Number of jobs and machines
    1, 24, 5, 14, 4, 99, 0, 21, 7, 50, 3, 94, 6, 68, 8, 44, 2, 46, 
    7, 82, 6, 88, 8, 90, 1, 98, 5, 87, 3, 56, 2, 29, 4, 27, 0, 90, 
    2, 83, 6, 21, 8, 73, 1, 62, 0, 12, 7, 76, 3, 27, 4, 55, 5, 32, 
    2, 39, 3, 44, 0,  4, 1,  6, 8, 76, 4, 95, 5, 23, 7, 63, 6, 35, 
    7, 52, 8, 56, 4, 57, 0, 50, 3, 63, 2, 29, 5, 59, 1, 22, 6, 85, 
    5, 38, 7, 49, 1, 36, 8, 49, 6, 87, 0, 95, 4, 33, 3, 75, 2, 98, 
    6,  2, 0, 79, 1, 67, 4,  5, 3, 35, 2, 82, 8, 49, 5, 49, 7, 29, 
    8, 37, 7, 86, 2,  6, 0,  9, 6,  9, 4, 31, 1, 61, 5, 95, 3, 87, 
    4, 90, 5, 80, 7, 30, 3, 56, 0, 66, 1, 61, 6, 20, 2, 24, 8, 60
  };
  const int q2694[] = {
    9, 9, // Number of jobs and machines
    3, 82, 6, 83, 8, 58, 2, 99, 1, 23, 0, 51, 7, 93, 5,  7, 4, 99, 
    8, 17, 3, 30, 7, 88, 1, 17, 2, 58, 6, 22, 0, 99, 5, 91, 4,  3, 
    2, 16, 6, 65, 3, 61, 4, 63, 8, 13, 0, 55, 5, 36, 1, 22, 7, 18, 
    0, 11, 6, 62, 2, 19, 8, 13, 1, 49, 5, 60, 7, 72, 4, 13, 3, 96, 
    2,  5, 0, 39, 7, 65, 8, 72, 3, 82, 5, 63, 4, 80, 6, 12, 1, 91, 
    1, 72, 3, 78, 8, 96, 0, 73, 6, 27, 5, 66, 2, 99, 4, 81, 7, 70, 
    7,  6, 3, 81, 0, 52, 5, 71, 1, 49, 6, 96, 8, 74, 4, 86, 2, 35, 
    5, 35, 6, 79, 0, 38, 2, 42, 8, 33, 4, 63, 1, 92, 7, 76, 3, 97, 
    3,  5, 4,  1, 0, 26, 7, 32, 6,  7, 8, 25, 5, 40, 1, 37, 2, 96
  };
  const int q2695[] = {
    9, 9, // Number of jobs and machines
    2, 76, 8, 98, 3, 58, 0, 91, 1, 95, 4, 38, 5, 28, 6, 45, 7, 67, 
    7,  7, 5,  6, 6, 48, 4, 80, 3,  9, 8, 17, 2, 92, 1, 23, 0, 25, 
    5, 66, 4, 52, 0, 84, 3, 68, 8, 67, 6,  5, 7, 43, 2, 73, 1, 47, 
    2, 46, 5, 30, 8, 75, 4, 10, 7,  5, 0, 11, 3,  5, 6, 66, 1,  9, 
    1, 65, 0, 36, 3, 38, 7, 14, 8, 60, 6, 81, 2, 32, 4, 34, 5, 49, 
    0, 52, 5, 35, 8,  1, 4, 48, 2, 68, 6, 99, 3, 33, 7,  6, 1, 41, 
    8,  1, 5, 92, 1,  9, 4, 11, 2, 94, 3, 82, 7,  8, 6, 20, 0, 64, 
    6, 78, 7, 41, 3, 52, 0, 49, 4, 31, 1, 14, 5, 20, 2, 73, 8,  4, 
    3, 12, 5,  2, 0, 25, 2, 97, 8,  8, 4, 15, 1, 59, 7, 96, 6, 34
  };
  const int q2696[] = {
    9, 9, // Number of jobs and machines
    2, 60, 4, 36, 5, 57, 7, 32, 8, 68, 1, 80, 3, 77, 0, 36, 6, 11, 
    7, 66, 5,  3, 3, 88, 1, 12, 8, 66, 6, 58, 0, 73, 2, 12, 4, 20, 
    7, 65, 6, 42, 2, 72, 0, 31, 8, 87, 5, 97, 3, 10, 4, 50, 1, 53, 
    2, 41, 5, 11, 8, 59, 1, 20, 4, 62, 6, 76, 0, 82, 3, 31, 7, 92, 
    6, 72, 2, 45, 0,  1, 1, 26, 4, 62, 3, 25, 8, 37, 5, 91, 7, 48, 
    3, 85, 5, 89, 7, 72, 6, 63, 1, 29, 0, 87, 8, 56, 2, 72, 4, 73, 
    1, 49, 4, 76, 6, 97, 7, 63, 5, 94, 0, 89, 8,  7, 3, 90, 2, 31, 
    4, 34, 2, 72, 0, 61, 5, 81, 7, 40, 1, 63, 8, 26, 3, 38, 6, 91, 
    0, 20, 7, 36, 5, 85, 2, 66, 8, 12, 1, 48, 6, 68, 3, 14, 4, 46
  };
  const int q2697[] = {
    9, 9, // Number of jobs and machines
    8, 62, 1, 28, 2, 37, 5, 24, 0, 30, 3, 71, 7, 53, 4,  5, 6, 13, 
    6, 68, 0, 14, 2, 19, 3, 28, 8, 16, 1, 56, 5,  6, 4, 45, 7, 73, 
    2, 96, 3, 74, 0, 82, 1, 37, 4,  6, 6, 70, 5, 86, 8, 43, 7, 84, 
    0, 93, 8, 19, 7, 19, 4, 57, 6, 53, 3, 85, 5, 55, 1, 75, 2, 64, 
    6, 53, 1,  2, 2, 18, 0, 37, 8, 16, 4,  8, 3, 73, 7, 69, 5, 78, 
    4, 50, 1, 44, 3, 16, 7, 51, 5, 89, 2, 76, 8, 18, 6, 95, 0, 45, 
    5, 57, 6, 58, 7, 66, 1, 62, 3, 72, 2,  6, 8, 56, 0, 76, 4, 95, 
    1, 46, 3, 21, 7, 14, 5, 55, 0, 78, 8, 37, 2, 23, 6, 81, 4,  2, 
    1, 96, 2, 44, 4,  9, 5, 73, 8, 53, 7, 28, 3, 23, 6, 89, 0,  5
  };
  const int q2698[] = {
    9, 9, // Number of jobs and machines
    4, 52, 3,  2, 2, 94, 0, 50, 8, 10, 1, 72, 7, 75, 6, 61, 5,  3, 
    5, 42, 1,  4, 4, 42, 3, 57, 8,  9, 6, 90, 0, 26, 2, 21, 7, 77, 
    7, 61, 6, 84, 0, 84, 4, 70, 1, 34, 8, 81, 2, 91, 5, 60, 3, 98, 
    6, 38, 0,  7, 7, 66, 1, 49, 8, 75, 3, 37, 2, 54, 5, 34, 4, 47, 
    0, 82, 5, 37, 6, 87, 8, 80, 2, 76, 3,  1, 7, 83, 1, 74, 4, 96, 
    6, 96, 0, 41, 3, 84, 2, 15, 7, 94, 4, 81, 8, 64, 5,  1, 1, 10, 
    3, 68, 7, 13, 8,  5, 4, 75, 2,  1, 0,  5, 1, 93, 5, 46, 6, 49, 
    8, 47, 0, 22, 6, 39, 1, 89, 4, 81, 2, 41, 5, 55, 7, 43, 3, 12, 
    2, 78, 4, 30, 7,  1, 8, 51, 5, 60, 0, 69, 1, 35, 6, 35, 3, 98
  };
  const int q2699[] = {
    9, 9, // Number of jobs and machines
    1, 46, 2, 43, 4, 45, 7, 80, 5, 32, 6, 52, 3, 40, 8, 32, 0, 81, 
    4, 25, 2, 30, 8, 21, 0, 11, 1,  8, 7, 45, 3, 99, 6, 99, 5, 94, 
    3, 74, 0, 49, 6, 59, 8, 94, 5, 98, 1, 20, 4, 81, 2, 61, 7,  8, 
    3, 62, 7, 63, 8, 44, 4, 30, 0, 31, 5, 81, 1, 89, 6, 22, 2, 51, 
    3, 99, 1, 52, 8, 83, 2, 72, 0, 49, 5, 27, 6, 81, 7, 54, 4, 55, 
    6, 77, 5, 38, 3, 44, 1, 19, 4, 19, 7, 74, 0, 67, 2,  7, 8, 20, 
    7, 18, 2, 43, 3, 37, 4, 25, 1, 44, 6, 55, 0, 34, 5, 71, 8, 67, 
    1, 67, 6, 55, 2, 70, 7, 52, 0, 64, 3, 60, 8, 26, 4, 59, 5, 80, 
    3, 10, 2,  8, 8, 37, 5, 42, 1, 56, 0, 78, 6, 26, 7, 33, 4, 74
  };
  const int q2700[] = {
    9, 9, // Number of jobs and machines
    5, 33, 1,  6, 7, 73, 0, 20, 8, 14, 6, 32, 4, 94, 2, 83, 3,  1, 
    6, 92, 1, 61, 7, 20, 5, 49, 2, 83, 8, 24, 3, 57, 0, 42, 4, 48, 
    7, 77, 6, 27, 0, 19, 1,  5, 8, 86, 5, 45, 3, 65, 2, 91, 4, 58, 
    8, 12, 1, 29, 5, 23, 2, 72, 7, 21, 0, 98, 4, 27, 6, 45, 3, 76, 
    7, 62, 5, 69, 2, 71, 3, 86, 0, 92, 6, 66, 4,  2, 1,  8, 8, 56, 
    4, 13, 0, 33, 1, 28, 7, 48, 8, 28, 6, 17, 5, 52, 2, 79, 3, 36, 
    4, 94, 7, 33, 3, 22, 6, 81, 5, 36, 1, 70, 2, 40, 8, 17, 0, 94, 
    8, 79, 7, 37, 3, 37, 6, 47, 2, 85, 1,  3, 5, 31, 4, 53, 0,  2, 
    6, 78, 5, 60, 2, 60, 4, 64, 3, 89, 0,  9, 7,  6, 8,  5, 1, 38
  };
  const int q2701[] = {
    9, 9, // Number of jobs and machines
    1, 80, 3, 22, 2, 69, 6, 24, 4, 82, 8, 72, 7, 21, 5, 15, 0, 82, 
    5, 95, 1, 75, 4, 40, 3, 19, 6, 63, 7, 32, 8, 21, 0, 47, 2, 49, 
    8, 97, 1, 42, 3, 72, 5, 78, 2, 74, 4, 81, 0, 57, 6,  1, 7, 55, 
    2, 61, 5, 25, 6, 64, 8, 17, 7, 93, 3, 23, 0, 59, 1, 10, 4, 47, 
    7, 92, 6, 47, 3, 16, 4, 89, 8, 45, 5, 37, 1, 56, 0, 38, 2, 20, 
    5, 16, 6, 67, 3, 27, 8, 13, 1, 88, 7, 24, 2, 13, 4, 28, 0, 74, 
    7, 42, 8, 81, 5, 70, 0, 72, 4, 82, 6, 11, 3, 50, 2, 24, 1, 60, 
    4, 58, 7, 89, 1, 23, 2,  7, 8, 61, 0, 97, 5, 64, 3, 27, 6, 86, 
    0, 81, 1, 32, 5, 95, 3, 87, 6, 23, 8, 88, 7, 97, 4, 25, 2, 21
  };
  const int q2702[] = {
    9, 9, // Number of jobs and machines
    6, 56, 3, 53, 4, 92, 0, 38, 1, 90, 7, 80, 8, 27, 2, 91, 5, 49, 
    0, 79, 1, 94, 8, 57, 3, 85, 7,  1, 2, 68, 4, 49, 6, 14, 5, 59, 
    0, 53, 3, 73, 5, 53, 8, 50, 6, 64, 7, 33, 1, 25, 2, 78, 4, 95, 
    1, 54, 2, 49, 7, 56, 3, 83, 0, 95, 4, 29, 6, 30, 5, 31, 8, 50, 
    8, 17, 5, 42, 6, 26, 1, 29, 0, 19, 7, 82, 4, 26, 2, 85, 3, 40, 
    2, 36, 7, 67, 3, 13, 1, 85, 5, 47, 4, 96, 0, 49, 8, 10, 6, 36, 
    5, 80, 1, 76, 8, 42, 3, 96, 0, 81, 6, 76, 2, 87, 4, 65, 7, 79, 
    0, 61, 6, 89, 8, 59, 2, 62, 1, 60, 7, 44, 3, 57, 5, 33, 4, 44, 
    1, 10, 7, 24, 3, 78, 8, 57, 0, 70, 4, 22, 5, 38, 2, 40, 6, 61
  };
  const int q2703[] = {
    9, 9, // Number of jobs and machines
    2, 84, 7, 50, 3, 47, 1, 78, 5, 93, 0, 29, 8, 22, 4, 77, 6, 95, 
    2,  8, 0, 94, 8, 27, 1, 34, 3, 20, 6, 97, 4, 23, 5, 90, 7,  8, 
    3, 47, 8, 43, 5, 47, 2, 74, 7, 31, 0, 22, 1, 82, 4, 45, 6, 94, 
    7,  1, 4, 29, 3, 74, 5, 24, 1, 22, 0, 48, 2, 97, 8, 91, 6, 22, 
    6, 71, 1, 72, 2, 67, 7, 10, 5, 95, 3, 33, 8, 54, 0, 65, 4, 22, 
    2, 86, 0, 12, 4, 27, 1, 10, 8, 20, 5, 23, 7, 79, 6, 26, 3, 58, 
    5, 23, 6, 74, 3, 71, 1, 31, 7, 95, 2, 77, 0, 80, 4, 18, 8, 62, 
    7, 89, 6, 60, 2, 27, 0, 41, 8, 59, 1,  8, 3, 13, 4, 15, 5, 63, 
    1, 24, 6, 56, 3, 18, 4, 86, 0, 45, 2, 49, 5, 79, 7, 54, 8, 62
  };
  const int q2704[] = {
    9, 9, // Number of jobs and machines
    4, 34, 8, 39, 0, 55, 5, 63, 6, 56, 1, 68, 7, 14, 3, 34, 2, 54, 
    3, 78, 8, 76, 6, 55, 7, 29, 4, 24, 2, 60, 5, 75, 0, 94, 1, 70, 
    7, 57, 6, 77, 4,  1, 8, 56, 1, 17, 0, 67, 3, 76, 5, 30, 2, 92, 
    7, 14, 2, 64, 1, 80, 6, 46, 4, 95, 5, 89, 0, 85, 3, 72, 8, 23, 
    1, 80, 6, 62, 4, 50, 8, 79, 7, 31, 3, 42, 2, 19, 0, 65, 5, 19, 
    7, 84, 4, 29, 0, 55, 1, 91, 8, 45, 6, 17, 2,  7, 3, 62, 5, 71, 
    2, 96, 6, 60, 4, 71, 1, 11, 7, 61, 0, 57, 3, 34, 8, 75, 5, 32, 
    0, 75, 3, 13, 8, 84, 7,  7, 4,  8, 2, 17, 5, 85, 6, 46, 1,  8, 
    4, 82, 8,  5, 1, 66, 2, 86, 5, 90, 3, 45, 7, 83, 0, 37, 6, 76
  };
  const int q2705[] = {
    9, 9, // Number of jobs and machines
    5, 18, 6, 97, 3, 39, 4, 29, 0, 70, 8, 93, 7, 26, 2, 97, 1, 15, 
    5, 34, 2, 19, 1,  2, 4,  1, 7, 73, 8, 25, 6, 46, 0, 69, 3, 75, 
    2, 74, 8, 90, 5, 36, 6, 79, 4, 12, 1, 12, 0, 62, 3, 40, 7, 83, 
    8, 11, 2, 16, 0, 96, 3, 30, 6, 46, 1, 15, 7, 60, 4, 41, 5, 47, 
    2, 74, 0,  5, 3, 71, 6, 80, 4, 12, 1, 94, 7, 78, 5, 77, 8, 71, 
    1, 56, 0, 22, 4, 93, 3, 49, 8, 63, 2, 31, 7, 44, 6, 39, 5, 30, 
    8, 40, 6, 54, 1, 37, 0, 99, 4, 74, 7, 99, 2, 39, 3, 58, 5, 70, 
    7, 25, 6, 27, 8, 25, 3, 48, 1, 64, 0, 58, 2, 91, 5, 31, 4,  5, 
    3, 73, 1, 23, 4, 47, 5, 89, 2, 93, 0, 36, 6, 89, 8,  7, 7, 93
  };
  const int q2706[] = {
    9, 9, // Number of jobs and machines
    4, 30, 8, 81, 6, 59, 0, 96, 2, 95, 3,  1, 7, 18, 5, 22, 1, 99, 
    8,  9, 6, 87, 3, 15, 0, 80, 1,  3, 4, 58, 7, 40, 5, 79, 2, 42, 
    8, 20, 2, 55, 7, 65, 3, 81, 1, 16, 4, 16, 5, 88, 6, 90, 0, 64, 
    2, 53, 6, 55, 3, 99, 4, 52, 0, 33, 1, 52, 8, 70, 5, 62, 7, 76, 
    1, 34, 4, 22, 8, 54, 7, 32, 0, 57, 2, 46, 6, 21, 5, 33, 3, 28, 
    8,  1, 4, 50, 7, 39, 5, 25, 0, 26, 6, 29, 1,  3, 3, 63, 2, 84, 
    6, 50, 7,  6, 2, 96, 8, 32, 4, 66, 1, 88, 0,  4, 5, 10, 3, 27, 
    5, 73, 2, 47, 4,  6, 7, 58, 1,  1, 8, 97, 0, 13, 3, 15, 6, 54, 
    4, 12, 1, 98, 5, 53, 7, 45, 8, 41, 2, 68, 0, 71, 6, 53, 3, 30
  };
  const int q2707[] = {
    9, 9, // Number of jobs and machines
    4, 68, 8, 54, 3, 49, 1, 43, 2, 30, 7, 86, 0, 85, 5, 12, 6, 83, 
    8, 10, 4, 23, 3, 69, 1, 69, 0, 74, 6,  3, 2, 16, 7, 65, 5, 49, 
    5, 40, 6, 74, 2, 30, 1, 42, 4, 27, 7, 27, 8, 59, 3, 54, 0,  6, 
    3, 42, 6, 70, 7, 33, 8,  3, 4, 51, 2, 65, 1, 52, 0,  2, 5,  4, 
    5, 63, 3, 12, 2, 69, 4,  7, 8, 84, 1, 56, 7, 61, 0, 36, 6, 52, 
    8, 25, 1,  2, 2,  4, 6, 99, 5, 42, 7, 77, 0, 76, 3, 52, 4,  4, 
    3, 72, 2, 24, 6, 40, 1, 33, 7, 30, 5, 20, 8, 46, 4, 68, 0, 52, 
    0, 45, 5, 72, 6, 65, 1, 80, 3, 22, 2, 85, 8, 32, 7, 98, 4, 67, 
    6, 32, 8, 80, 7, 47, 0, 56, 1, 96, 3, 39, 2, 11, 5, 98, 4, 73
  };
  const int q2708[] = {
    9, 9, // Number of jobs and machines
    5, 54, 2, 82, 8, 16, 0, 94, 1, 49, 7, 94, 6, 96, 4, 19, 3, 52, 
    7, 12, 3, 72, 4, 68, 8,  7, 5, 89, 6, 69, 2, 85, 0, 39, 1, 71, 
    7, 18, 6, 78, 3, 17, 5, 56, 4, 12, 0, 34, 2, 12, 1, 95, 8, 63, 
    6, 12, 7, 68, 5, 28, 2, 15, 0, 46, 8, 83, 3, 44, 1,  2, 4, 95, 
    5, 20, 3, 88, 0, 12, 2, 92, 8, 78, 6, 85, 4, 58, 1, 42, 7, 82, 
    6, 25, 0, 39, 3, 12, 1, 59, 4, 70, 7, 29, 5, 89, 8, 16, 2, 16, 
    0, 18, 8, 75, 5, 83, 7, 27, 4, 16, 6, 94, 2, 97, 1, 44, 3, 99, 
    2,  4, 8, 83, 4, 27, 7,  2, 6, 27, 0, 14, 5, 96, 1, 33, 3, 86, 
    7, 74, 6, 97, 1,  8, 3, 60, 5, 29, 4, 13, 0,  8, 8, 96, 2, 83
  };
  const int q2709[] = {
    9, 9, // Number of jobs and machines
    4, 98, 2, 98, 8, 40, 5, 11, 7,  5, 0, 88, 1, 52, 3, 37, 6, 85, 
    2, 32, 3, 12, 1, 39, 7, 73, 5, 90, 8, 87, 0, 68, 4, 85, 6, 10, 
    7, 49, 3, 35, 5, 70, 0,  2, 1, 77, 4, 64, 2, 15, 6, 22, 8, 83, 
    0, 26, 4, 72, 8, 44, 1, 48, 5, 44, 6,  1, 7, 78, 2, 91, 3, 33, 
    5,  6, 7, 73, 3, 55, 8, 76, 6,  7, 0, 90, 2, 57, 4, 99, 1, 23, 
    7, 42, 4, 89, 8, 76, 6, 45, 2, 16, 0, 94, 5, 40, 3, 33, 1, 28, 
    1, 67, 7, 25, 0, 65, 3, 28, 4, 47, 5, 23, 2,  5, 8,  2, 6, 50, 
    2, 14, 0, 78, 1, 73, 8, 89, 6, 98, 7,  4, 3, 80, 4, 41, 5, 43, 
    5, 22, 3, 73, 8, 79, 0, 12, 1, 87, 6, 36, 7, 55, 4, 36, 2, 24
  };
  const int q2710[] = {
    9, 9, // Number of jobs and machines
    6, 96, 4,  9, 8, 38, 0, 27, 2, 85, 7, 31, 3, 31, 1, 37, 5,  7, 
    6, 79, 3, 11, 0, 59, 5, 89, 7, 11, 2,  4, 4, 42, 8,  5, 1, 19, 
    8, 32, 2,  1, 1, 55, 7, 17, 6, 76, 0, 82, 5, 91, 3, 49, 4, 88, 
    2, 24, 0, 19, 7, 99, 1, 33, 3, 10, 8, 17, 5, 97, 6, 98, 4, 45, 
    7, 76, 8, 20, 3, 46, 1,  2, 5, 63, 6, 53, 2, 22, 0, 19, 4, 19, 
    0, 45, 6, 11, 8, 10, 4, 74, 2, 94, 3, 32, 7, 24, 5, 68, 1, 53, 
    8, 60, 4, 41, 0, 61, 3, 58, 1, 13, 7, 41, 5, 74, 2,  1, 6, 18, 
    2,  1, 4, 74, 6, 44, 5, 50, 1, 11, 3,  6, 7, 76, 8, 35, 0, 89, 
    5, 44, 7, 94, 0, 13, 6, 13, 3, 91, 4, 23, 2, 67, 1, 85, 8, 36
  };
  const int q2711[] = {
    9, 9, // Number of jobs and machines
    1, 15, 6, 35, 2, 35, 4, 28, 5,  3, 7, 72, 8,  1, 3, 26, 0, 55, 
    1, 53, 8, 10, 7, 53, 2, 75, 4, 29, 5, 49, 6, 86, 0, 70, 3,  4, 
    5, 45, 2, 10, 0, 82, 6, 73, 3, 69, 7, 28, 4, 69, 8, 29, 1, 65, 
    8, 30, 6, 24, 4,  3, 5, 45, 1, 94, 0, 11, 7, 42, 3, 55, 2, 38, 
    8, 41, 3, 88, 4, 77, 5, 28, 6, 17, 2, 39, 0, 17, 7, 45, 1, 44, 
    1, 53, 8, 17, 6, 65, 2, 31, 5, 27, 7, 19, 3, 90, 0, 44, 4, 85, 
    4, 27, 0, 65, 2,  4, 8, 18, 1, 32, 3, 79, 6, 24, 7, 85, 5,  6, 
    4, 98, 5, 69, 1,  9, 7,  7, 0, 63, 3, 72, 6, 76, 8, 67, 2, 33, 
    3, 87, 5, 68, 0, 98, 2, 41, 8,  4, 4, 87, 6, 90, 7, 67, 1, 47
  };
  const int q2712[] = {
    9, 9, // Number of jobs and machines
    1, 27, 0,  5, 4, 90, 6, 17, 5, 45, 7, 40, 2, 46, 3, 93, 8,  7, 
    0, 32, 1, 33, 8, 95, 4, 30, 7, 91, 6, 25, 3, 45, 2, 20, 5, 59, 
    5, 87, 0, 72, 6, 85, 1, 31, 4, 16, 8, 29, 7, 56, 3, 68, 2, 93, 
    1, 99, 7, 21, 5,  4, 0, 53, 6, 52, 3, 60, 2, 52, 8, 20, 4, 75, 
    8, 54, 1, 63, 2, 22, 4, 31, 0, 85, 6, 52, 5, 59, 7, 81, 3,  9, 
    5, 37, 1, 80, 7, 80, 2, 69, 4, 16, 6, 38, 3, 46, 0, 56, 8, 49, 
    5, 77, 7, 42, 3, 58, 6, 50, 1, 98, 4, 87, 2, 51, 0, 76, 8, 23, 
    6, 68, 5, 79, 8, 93, 2, 38, 1, 57, 0, 36, 4, 46, 3, 94, 7, 17, 
    3, 42, 1, 63, 4, 70, 5, 76, 0, 59, 6, 21, 8, 95, 7, 17, 2, 50
  };
  const int q2713[] = {
    9, 9, // Number of jobs and machines
    3, 20, 0, 73, 8, 81, 4, 25, 6, 65, 7, 69, 1, 93, 5, 63, 2, 37, 
    3, 49, 0, 77, 4, 35, 1, 29, 2, 89, 8, 88, 7, 13, 6, 55, 5, 97, 
    3, 87, 2, 40, 6,  6, 1, 36, 5, 27, 0, 53, 7,  3, 4, 51, 8, 79, 
    2,  7, 4, 32, 1, 79, 0, 84, 6, 92, 3, 52, 8,  2, 5, 62, 7, 41, 
    0, 46, 4,  6, 1, 88, 3, 23, 2, 12, 8, 79, 5, 55, 6, 28, 7, 91, 
    6, 71, 1,  5, 0, 75, 2, 84, 5,  3, 3, 83, 7, 78, 4, 97, 8, 64, 
    6, 10, 0,  6, 1, 95, 5, 45, 3, 14, 8, 87, 2, 29, 4, 81, 7, 50, 
    7, 68, 6, 10, 2, 43, 5, 78, 8, 72, 3, 81, 1, 77, 0, 21, 4, 24, 
    0, 45, 3, 28, 4, 97, 7, 53, 8, 20, 2,  3, 1, 61, 6, 91, 5, 33
  };
  const int q2714[] = {
    9, 9, // Number of jobs and machines
    7, 69, 6,  9, 5, 36, 1, 34, 2, 15, 3, 15, 0, 67, 4, 43, 8, 39, 
    4, 60, 2, 26, 1, 78, 5, 24, 7,  6, 0, 81, 6, 34, 8, 50, 3, 89, 
    0, 62, 4, 80, 6, 54, 1, 32, 8, 37, 7,  3, 2, 28, 5, 64, 3, 36, 
    1, 61, 8, 34, 0, 47, 4, 36, 2, 88, 3, 80, 5, 81, 7, 69, 6, 64, 
    3, 15, 6, 10, 7, 46, 5, 84, 0, 65, 8, 58, 4,  2, 1, 91, 2,  9, 
    0, 42, 4, 81, 7, 52, 2, 40, 8, 23, 1, 18, 6, 91, 5,  9, 3, 89, 
    7, 83, 1, 15, 6, 89, 3, 47, 4,  6, 8, 94, 0, 39, 2, 25, 5, 89, 
    3, 23, 6, 82, 4, 12, 5, 31, 8, 30, 2, 81, 0, 92, 1, 17, 7, 16, 
    5, 25, 6, 25, 4, 45, 1, 15, 2, 40, 8, 80, 3, 12, 7, 42, 0, 97
  };
  const int q2715[] = {
    9, 9, // Number of jobs and machines
    8, 44, 0, 42, 6, 52, 4, 63, 3,  8, 7, 21, 1, 41, 2, 65, 5, 69, 
    1, 43, 3,  2, 7, 40, 5,  2, 2, 61, 8, 10, 0, 19, 4, 49, 6, 77, 
    8, 10, 2, 41, 0, 92, 5, 79, 3, 98, 4, 15, 7, 93, 1, 10, 6, 71, 
    3, 98, 0, 39, 1, 66, 8, 44, 2, 29, 5, 35, 4, 37, 7, 75, 6, 91, 
    3, 82, 5, 50, 6, 57, 2, 67, 4, 57, 8, 57, 1, 39, 7, 20, 0, 96, 
    1, 29, 6, 46, 8, 16, 7, 84, 2, 62, 3, 63, 4, 30, 5,  6, 0, 31, 
    3, 94, 1, 36, 6, 75, 2, 88, 8,  9, 0,  4, 5,  2, 4, 87, 7, 62, 
    6, 95, 0, 27, 2, 42, 4, 90, 1, 11, 7, 31, 8, 61, 3, 12, 5, 43, 
    6,  1, 4, 36, 0,  7, 3, 12, 5, 63, 1, 45, 8, 17, 2, 17, 7, 94
  };
  const int q2716[] = {
    9, 9, // Number of jobs and machines
    8, 72, 3, 16, 6, 33, 0, 30, 5, 68, 1, 48, 7, 46, 2, 39, 4, 66, 
    6, 79, 7, 59, 5,  1, 4, 53, 1, 78, 0, 31, 8, 19, 3,  1, 2, 39, 
    1, 97, 7, 18, 2, 71, 3, 72, 4, 64, 8, 60, 6, 94, 0, 34, 5, 71, 
    2, 58, 1, 15, 6, 27, 3, 33, 0, 40, 5,  9, 4, 19, 7, 61, 8, 23, 
    3, 30, 2, 12, 8, 76, 7, 94, 0, 88, 5, 65, 4, 47, 6,  4, 1, 41, 
    1, 24, 6, 96, 4, 64, 3, 73, 0, 32, 2, 46, 8, 60, 7, 50, 5,  1, 
    3, 31, 4, 99, 6, 83, 8, 79, 0, 95, 7, 15, 2, 78, 5, 39, 1, 87, 
    7,  4, 0,  8, 2, 52, 3,  6, 6, 75, 4, 39, 8, 77, 5, 16, 1, 94, 
    6, 24, 7,  7, 1, 61, 3, 60, 2, 27, 5, 81, 4, 29, 8,  2, 0, 74
  };
  const int q2717[] = {
    9, 9, // Number of jobs and machines
    6, 54, 5, 38, 1, 81, 0, 90, 4, 27, 7, 28, 3, 30, 8, 52, 2, 90, 
    2, 12, 4, 19, 6, 27, 8, 15, 3, 24, 7, 27, 1, 60, 5,  6, 0, 83, 
    4, 30, 0, 30, 1, 68, 2, 20, 8, 75, 3, 57, 7, 85, 6,  2, 5, 74, 
    6, 22, 7,  4, 3, 12, 5, 54, 8, 74, 2, 28, 4, 59, 1, 70, 0, 79, 
    4, 71, 3,  9, 6, 47, 8, 56, 0, 70, 2,  5, 5,  4, 1, 50, 7, 74, 
    0, 15, 8, 33, 5, 34, 3, 59, 6, 88, 4, 82, 7, 93, 1, 92, 2,  1, 
    8,  6, 7, 79, 5, 80, 3, 32, 1, 77, 6,  4, 0, 25, 2,  9, 4, 70, 
    1,  6, 3, 61, 2, 57, 8, 76, 7, 30, 4, 70, 5, 36, 6, 33, 0, 41, 
    0, 77, 1, 69, 4, 86, 2, 69, 3, 73, 6, 83, 7, 76, 8, 28, 5, 92
  };
  const int q2718[] = {
    9, 9, // Number of jobs and machines
    2, 89, 0, 41, 3, 74, 1, 17, 7, 35, 4, 73, 6, 94, 5,  4, 8, 57, 
    2, 31, 1, 63, 7, 54, 4, 60, 0, 93, 5, 69, 8, 82, 6, 45, 3, 89, 
    5, 27, 0, 57, 3,  4, 4, 92, 6, 37, 2, 45, 1, 94, 7, 21, 8, 98, 
    3, 36, 5, 49, 8, 14, 0, 72, 6, 31, 2, 93, 4, 64, 1, 92, 7, 75, 
    1, 24, 4, 64, 7, 64, 2, 37, 0, 62, 8, 97, 6, 91, 5, 74, 3, 33, 
    4,  6, 0, 27, 7, 61, 8, 62, 1, 31, 5, 26, 2, 24, 6, 95, 3, 85, 
    7, 35, 5, 61, 8, 96, 2, 90, 4, 26, 6, 80, 1, 74, 0,  3, 3, 48, 
    2, 39, 3, 18, 4, 79, 8, 13, 7, 35, 6, 49, 1, 33, 0, 96, 5, 81, 
    1,  1, 6, 47, 8, 46, 4, 70, 7, 73, 3, 35, 2, 59, 0,  2, 5, 20
  };
  const int q2719[] = {
    9, 9, // Number of jobs and machines
    5, 21, 8, 54, 1,  7, 4, 96, 2, 32, 3, 16, 6, 24, 0,  9, 7, 80, 
    2, 42, 8, 67, 0, 16, 6, 43, 3, 50, 1, 69, 4, 49, 5, 34, 7,  7, 
    7, 27, 4, 13, 8, 37, 5, 11, 0, 89, 3, 49, 2, 44, 6,  8, 1, 53, 
    8, 76, 4, 54, 7, 67, 1, 76, 2, 53, 5, 89, 6, 22, 0, 38, 3, 52, 
    7, 61, 6, 49, 5, 88, 0, 17, 1, 34, 8,  8, 2,  7, 3, 21, 4, 27, 
    6, 85, 0, 22, 5, 34, 8, 48, 7, 69, 3,  2, 1, 36, 4, 64, 2, 21, 
    7, 88, 2, 76, 4, 50, 6, 86, 3, 71, 5, 77, 0, 59, 8, 70, 1, 79, 
    4, 43, 6, 44, 8, 37, 7, 61, 1, 83, 5, 86, 3, 48, 2, 60, 0, 76, 
    1, 53, 8, 83, 4, 74, 5, 10, 3, 82, 6, 41, 2, 44, 0, 42, 7, 94
  };
  const int q2720[] = {
    9, 9, // Number of jobs and machines
    6, 43, 4, 13, 0, 63, 8, 48, 1,  1, 2, 79, 5, 59, 3, 35, 7, 57, 
    6,  2, 0, 61, 1,  8, 5, 84, 4, 69, 7, 65, 2, 95, 3, 61, 8, 29, 
    3, 87, 6, 21, 1, 95, 8, 10, 2, 58, 7, 75, 0, 31, 5, 53, 4, 24, 
    1, 36, 2, 98, 4, 99, 7, 65, 3, 28, 6, 70, 5, 81, 8, 40, 0, 22, 
    7, 64, 2, 26, 3, 20, 8, 46, 6,  6, 0, 68, 4, 76, 1, 32, 5, 96, 
    7, 17, 0, 53, 4, 84, 6, 67, 2,  9, 3, 89, 5, 70, 1, 77, 8, 15, 
    6, 62, 1, 25, 8, 72, 5,  1, 0, 16, 2, 58, 7, 41, 4, 58, 3, 34, 
    4, 41, 6, 86, 0, 36, 7, 95, 2, 44, 1, 87, 5, 75, 8, 15, 3, 33, 
    8, 97, 4, 69, 1, 47, 6, 14, 5,  1, 7,  6, 3, 84, 2, 60, 0, 35
  };
  const int q2721[] = {
    9, 9, // Number of jobs and machines
    3, 89, 8, 93, 4, 15, 0,  2, 1, 16, 2, 47, 5, 54, 7, 41, 6, 69, 
    6, 17, 1, 53, 7, 49, 8, 46, 0, 78, 2, 69, 3, 40, 5, 68, 4,  7, 
    8, 44, 4, 58, 6, 96, 2, 88, 0, 34, 5, 68, 7, 78, 1, 41, 3, 65, 
    6, 37, 8, 96, 0, 92, 5, 97, 1, 93, 3, 12, 2, 64, 4, 17, 7, 97, 
    3, 53, 6, 82, 2,  8, 1, 70, 5, 86, 0, 55, 4, 68, 8, 89, 7, 88, 
    2,  8, 1, 23, 4, 74, 0, 80, 5, 48, 6, 70, 3, 94, 8, 12, 7, 75, 
    4,  1, 5, 39, 2, 61, 7, 63, 8, 74, 3, 41, 6, 46, 1,  6, 0, 32, 
    2, 46, 3, 58, 8,  4, 5, 33, 7, 87, 1, 40, 6, 65, 0, 85, 4, 13, 
    1,  8, 3, 33, 6, 20, 4, 29, 0, 94, 7, 46, 8, 65, 2, 70, 5, 61
  };
  const int q2722[] = {
    9, 9, // Number of jobs and machines
    2,  3, 0, 81, 1, 64, 3, 89, 8, 88, 7,  2, 4, 64, 6, 12, 5, 26, 
    8, 47, 2, 76, 0, 62, 1, 80, 5, 51, 6, 38, 4, 12, 3,  8, 7, 29, 
    0, 63, 1, 37, 7, 76, 2, 44, 4, 14, 5, 46, 3, 77, 6, 53, 8, 24, 
    4,  7, 3, 65, 6, 95, 5, 11, 0, 11, 2, 44, 8, 55, 7, 35, 1, 59, 
    1, 28, 3, 80, 0, 75, 2, 39, 5, 91, 8, 46, 4, 56, 6, 85, 7, 78, 
    5,  7, 6, 48, 3, 81, 7, 74, 1, 42, 0, 15, 2, 78, 8, 45, 4, 37, 
    5, 53, 6, 96, 4, 46, 2, 61, 1, 31, 8, 25, 0,  7, 7, 27, 3, 28, 
    2, 88, 6, 63, 4, 99, 3,  1, 7, 74, 0, 99, 8, 62, 5, 87, 1, 10, 
    5, 97, 7, 64, 1, 23, 4, 40, 6, 66, 2,  4, 8, 78, 3, 46, 0,  2
  };
  const int q2723[] = {
    9, 9, // Number of jobs and machines
    2, 70, 0,  4, 8, 59, 7, 57, 5, 97, 3, 82, 4,  7, 6,  5, 1, 17, 
    0, 53, 6, 99, 4, 43, 2, 59, 3, 72, 5, 28, 1, 74, 7,  4, 8, 69, 
    8, 69, 0, 27, 6, 40, 4, 16, 1, 46, 7, 68, 3, 37, 5,  7, 2, 90, 
    4, 14, 0, 48, 6, 88, 7, 32, 2, 17, 3, 71, 5, 36, 8, 45, 1, 34, 
    8, 71, 4, 48, 6, 30, 0, 43, 5,  9, 3, 50, 7, 38, 2, 99, 1, 53, 
    6, 26, 4, 47, 3, 66, 1, 62, 5, 50, 2, 63, 0, 48, 7, 29, 8,  4, 
    1, 68, 8, 10, 4, 46, 0, 87, 6, 96, 7, 57, 2, 26, 3, 67, 5, 86, 
    0, 79, 7,  3, 4, 49, 8, 11, 2,  8, 6, 98, 3, 37, 5, 19, 1, 12, 
    1, 34, 3, 75, 5, 76, 7, 38, 4, 91, 8, 15, 2, 80, 6, 38, 0, 83
  };
  const int q2724[] = {
    9, 9, // Number of jobs and machines
    0, 86, 3,  3, 5, 71, 6, 68, 1, 81, 4, 85, 8,  3, 7, 10, 2, 38, 
    4, 47, 5, 50, 0, 42, 8, 53, 3, 90, 7, 28, 2, 14, 6, 75, 1, 24, 
    8, 30, 3, 62, 7, 60, 2,  5, 6, 59, 5, 38, 0, 65, 1, 87, 4, 39, 
    1, 68, 0, 75, 4, 14, 6, 13, 5, 48, 3, 91, 8, 52, 7, 76, 2, 25, 
    1, 67, 0, 87, 4, 68, 8, 32, 7, 90, 3, 25, 5, 21, 2, 64, 6, 25, 
    1, 16, 8, 12, 0, 83, 2, 70, 3, 13, 4, 79, 5, 21, 7, 69, 6, 62, 
    1, 68, 4, 64, 7, 15, 0, 54, 3, 87, 6, 10, 5,  5, 8, 91, 2, 49, 
    5, 93, 3, 79, 0, 88, 6, 63, 8, 75, 7, 36, 4, 91, 2, 84, 1, 86, 
    3, 73, 6, 58, 5, 70, 4,  1, 2, 16, 0,  1, 7, 72, 1,  6, 8, 30
  };
  const int q2725[] = {
    9, 9, // Number of jobs and machines
    6, 31, 2, 29, 8, 41, 7,  2, 4,  7, 1, 54, 3, 34, 0, 31, 5, 77, 
    2,  3, 1,  1, 7, 83, 8, 66, 6,  2, 4, 34, 5, 95, 3, 31, 0, 60, 
    6, 73, 0, 65, 5, 86, 3, 36, 2, 13, 4, 18, 1, 70, 7, 88, 8, 81, 
    3, 60, 4, 22, 8,  5, 1, 71, 7, 18, 6, 99, 0, 49, 5, 98, 2,  2, 
    4, 71, 2, 72, 5, 20, 1, 67, 8, 74, 7, 68, 3, 15, 0, 21, 6, 76, 
    3, 30, 0, 81, 2, 95, 7, 77, 5, 77, 1, 96, 6, 76, 8, 65, 4, 92, 
    5, 77, 1, 32, 8, 57, 0, 27, 4, 30, 2, 55, 3, 15, 6, 93, 7, 48, 
    6, 27, 1, 71, 7, 88, 8, 84, 3, 70, 4, 97, 0, 16, 5,  1, 2, 40, 
    1,  3, 5, 48, 7, 37, 2, 45, 3, 20, 4, 87, 6, 31, 8, 32, 0, 73
  };
  const int q2726[] = {
    9, 9, // Number of jobs and machines
    0,  2, 7, 84, 6, 43, 4, 81, 5, 20, 1,  5, 3, 35, 2, 34, 8, 62, 
    1, 44, 4, 74, 2, 96, 8, 12, 6, 11, 5, 33, 0, 94, 3, 62, 7, 56, 
    2, 62, 5, 39, 6, 96, 8, 87, 7, 77, 0, 99, 1, 43, 3, 44, 4, 32, 
    8, 84, 6, 38, 1, 68, 7, 29, 3, 52, 5, 44, 0, 51, 2, 94, 4, 85, 
    4, 34, 1, 14, 3, 34, 8, 87, 0, 49, 7, 19, 5, 44, 2, 85, 6, 27, 
    3, 87, 1, 50, 5, 39, 2, 71, 6, 61, 7, 55, 8, 88, 0, 90, 4,  8, 
    5, 33, 2, 41, 0, 16, 4, 15, 3, 53, 7, 48, 8, 82, 1, 25, 6, 43, 
    8, 25, 3, 25, 2, 94, 4, 39, 5, 72, 7, 21, 6, 11, 0, 51, 1,  4, 
    5, 42, 8, 56, 3, 27, 1, 22, 4, 63, 2, 53, 0, 64, 6, 25, 7, 81
  };
  const int q2727[] = {
    9, 9, // Number of jobs and machines
    0, 34, 4, 58, 7, 10, 8, 62, 3,  8, 6, 72, 1, 18, 2, 15, 5, 36, 
    7, 49, 8, 72, 6, 30, 0, 47, 5, 45, 3, 68, 4, 92, 2, 11, 1, 50, 
    3, 74, 2, 68, 8, 61, 0, 57, 4, 59, 7, 81, 6, 60, 1, 39, 5, 68, 
    7, 44, 2, 25, 5, 24, 1, 86, 0, 81, 3, 37, 6,  5, 8, 40, 4, 54, 
    7, 80, 3, 95, 1, 98, 4,  4, 2, 62, 6, 99, 5, 98, 0, 99, 8, 51, 
    5, 67, 8, 49, 3, 94, 6, 98, 1, 18, 7,  9, 2, 30, 0, 77, 4, 58, 
    8, 51, 6, 86, 0, 26, 4, 91, 7, 35, 5,  6, 1, 80, 3, 31, 2, 14, 
    5,  5, 3, 29, 4, 23, 1, 23, 2, 31, 6, 91, 8, 31, 7, 38, 0, 59, 
    0, 65, 4, 31, 3, 76, 8, 95, 7, 28, 2,  2, 5, 97, 6, 68, 1, 24
  };
  const int q2728[] = {
    9, 9, // Number of jobs and machines
    1, 63, 4,  5, 5, 69, 3, 18, 8, 47, 7, 35, 6, 12, 2, 65, 0, 70, 
    5, 88, 2, 19, 0, 15, 3, 21, 8, 43, 1, 16, 6, 51, 4, 24, 7, 28, 
    1, 41, 7, 86, 5, 55, 0, 28, 2, 88, 6, 78, 8, 26, 4, 40, 3, 49, 
    5, 31, 7, 22, 8, 47, 4, 83, 2, 31, 1, 92, 0, 28, 3, 22, 6, 20, 
    6, 73, 3, 49, 1, 73, 2, 78, 5, 28, 4,  7, 0, 15, 8, 34, 7, 55, 
    7, 39, 5,  3, 8, 74, 0, 24, 4, 80, 3, 38, 2, 27, 6, 11, 1, 77, 
    8, 17, 1,  8, 0, 26, 5, 19, 3, 33, 6, 92, 7, 54, 2, 63, 4, 49, 
    7, 99, 0, 97, 5, 94, 3, 88, 2, 89, 4, 57, 8, 86, 6, 88, 1, 68, 
    8, 47, 1, 47, 6, 71, 7, 94, 5, 30, 3, 25, 0, 68, 2, 40, 4,  1
  };
  const int q2729[] = {
    9, 9, // Number of jobs and machines
    7, 62, 3,  8, 2, 27, 8, 14, 0, 20, 5, 22, 6,  7, 1, 53, 4,  5, 
    8, 19, 7,  7, 2,  9, 6, 82, 0, 53, 1, 71, 5, 62, 3, 10, 4, 54, 
    7, 15, 3, 80, 1, 49, 4, 49, 8, 75, 6, 97, 2, 48, 0, 72, 5, 45, 
    0, 93, 4, 34, 1, 79, 3, 46, 8, 97, 5, 97, 6, 72, 7, 46, 2, 18, 
    3, 51, 5, 86, 1, 14, 8,  2, 0, 80, 6, 16, 4, 84, 7, 77, 2, 34, 
    6, 48, 4, 98, 5, 39, 3, 20, 0, 38, 7, 24, 2, 61, 1, 19, 8, 94, 
    6, 92, 0, 20, 1, 39, 3, 74, 5, 94, 7, 66, 4,  4, 2, 86, 8, 26, 
    4, 11, 0, 23, 3, 81, 7, 32, 5, 70, 2, 54, 6, 43, 8, 76, 1, 82, 
    2, 11, 0, 47, 6, 88, 1, 82, 4, 18, 5,  5, 8, 58, 3, 26, 7, 81
  };
  const int q2730[] = {
    9, 9, // Number of jobs and machines
    6, 69, 8, 39, 4, 92, 3, 29, 2, 43, 0, 58, 7, 55, 5, 85, 1, 18, 
    6, 35, 7, 52, 3, 26, 1, 71, 2, 34, 8,  4, 5, 92, 0, 22, 4, 60, 
    2, 24, 1, 95, 5,  9, 6, 39, 0, 45, 8,  7, 4, 24, 7, 62, 3, 99, 
    7, 82, 1, 82, 8, 98, 3, 11, 4, 96, 0, 24, 5, 27, 2, 80, 6, 78, 
    4, 89, 5,  5, 1, 36, 8, 85, 2,  1, 6, 51, 0, 29, 7, 83, 3, 77, 
    3, 36, 2, 92, 0, 46, 7, 69, 4, 80, 6, 98, 8, 50, 5,  4, 1, 48, 
    3,  4, 6, 47, 8, 47, 4, 50, 1, 49, 0, 59, 7, 30, 2, 49, 5,  4, 
    0, 71, 5, 53, 2, 31, 8, 31, 6, 72, 1, 19, 7,  8, 3, 63, 4, 36, 
    0, 15, 2, 74, 5, 87, 4, 59, 8, 25, 1, 52, 7, 17, 3, 32, 6, 35
  };
  const int q2731[] = {
    9, 9, // Number of jobs and machines
    3,  4, 7, 11, 0, 39, 6, 74, 2, 93, 1, 26, 5, 92, 4, 37, 8, 40, 
    2,  9, 4, 12, 1, 59, 7, 87, 3,  2, 8, 97, 6, 99, 0, 20, 5,  7, 
    4, 55, 6,  5, 7, 88, 0, 98, 5, 59, 1, 92, 2, 68, 3,  9, 8, 55, 
    4, 83, 7, 67, 2, 29, 1, 63, 8, 59, 6, 37, 0, 29, 3, 18, 5, 25, 
    1, 10, 6, 48, 0, 29, 8, 76, 2, 92, 3, 14, 4, 73, 5, 32, 7, 16, 
    1, 61, 8, 46, 6, 96, 3, 90, 7, 95, 2, 40, 4, 95, 5, 77, 0, 55, 
    8,  9, 5, 26, 7, 18, 0,  9, 3, 63, 2,  5, 6, 68, 4, 99, 1, 31, 
    2, 28, 3, 48, 5, 37, 0, 24, 7, 56, 6, 14, 1, 20, 4, 82, 8, 78, 
    7, 67, 2, 11, 3, 77, 8, 34, 4, 41, 1, 66, 0, 27, 5, 38, 6, 72
  };
  const int q2732[] = {
    9, 9, // Number of jobs and machines
    0, 42, 8, 11, 2, 13, 6, 46, 7, 17, 5,  6, 4, 27, 3, 35, 1, 38, 
    4, 76, 3, 83, 8,  4, 7, 53, 1, 31, 5, 32, 2, 44, 0, 78, 6, 85, 
    7, 97, 2, 14, 1, 37, 3, 43, 5, 85, 6, 76, 0, 79, 8, 87, 4, 24, 
    0, 93, 7, 50, 2, 34, 8, 23, 3, 21, 5, 64, 4, 36, 6, 32, 1, 47, 
    8, 56, 7, 94, 4, 87, 2, 90, 3, 70, 6, 47, 5,  5, 0,  2, 1,  4, 
    5, 24, 4, 61, 8, 86, 1, 53, 0, 39, 2, 42, 6, 80, 3, 45, 7, 42, 
    0, 37, 4, 43, 7, 58, 6, 45, 8, 17, 2, 28, 3, 86, 5, 32, 1, 65, 
    2, 37, 6, 60, 3, 54, 0, 80, 4, 27, 1, 50, 5, 21, 8, 12, 7, 99, 
    2, 73, 3, 47, 0, 95, 7, 21, 5,  5, 1, 92, 8, 70, 4, 99, 6, 41
  };
  const int q2733[] = {
    9, 9, // Number of jobs and machines
    2,  6, 6, 86, 4, 33, 3, 86, 1, 88, 0,  3, 8, 18, 7, 18, 5, 28, 
    8, 82, 0,  7, 6, 93, 2, 21, 4, 35, 5, 64, 7, 68, 3, 68, 1, 59, 
    1, 88, 4, 73, 8, 71, 3,  9, 6, 60, 5, 56, 0, 65, 7, 19, 2, 57, 
    0, 23, 4, 80, 1, 98, 7, 29, 8, 81, 5, 42, 2, 84, 3, 81, 6, 86, 
    0, 39, 2, 77, 3, 33, 7, 62, 4, 70, 6, 80, 5, 74, 1, 41, 8, 10, 
    5, 24, 0, 53, 3, 96, 8, 83, 2, 90, 1,  4, 6, 62, 4, 28, 7, 79, 
    4, 47, 7, 35, 8, 52, 5, 77, 0, 40, 2, 76, 1, 81, 6, 61, 3, 99, 
    5, 28, 6, 94, 7,  5, 4, 58, 2,  8, 0, 80, 1, 95, 3, 64, 8, 40, 
    3, 24, 1, 11, 5,  4, 0, 38, 4, 74, 2, 48, 6, 10, 8, 84, 7, 99
  };
  const int q2734[] = {
    9, 9, // Number of jobs and machines
    5, 51, 8, 98, 7, 20, 3, 73, 2, 23, 1, 30, 6, 81, 0, 35, 4,  6, 
    7, 92, 3,  2, 0, 24, 1, 76, 6, 45, 4, 69, 5, 85, 8, 12, 2, 64, 
    7, 66, 4, 31, 0, 93, 6, 48, 1, 27, 3, 91, 8, 30, 5, 56, 2, 59, 
    2, 47, 5,  5, 1, 82, 6,  6, 4, 39, 8, 66, 3,  2, 7, 55, 0, 49, 
    5, 33, 4,  2, 3, 49, 7, 96, 8, 56, 1, 34, 2,  8, 6, 65, 0, 56, 
    0, 71, 6, 60, 2, 86, 8, 44, 3, 64, 5, 37, 4, 35, 1, 76, 7, 26, 
    0, 80, 6, 47, 2, 11, 1, 63, 5, 54, 8, 74, 3, 71, 4, 23, 7, 67, 
    0,  9, 3, 43, 5, 85, 8, 84, 1, 14, 6, 19, 2,  8, 4, 89, 7, 94, 
    3, 73, 1, 83, 5, 76, 2, 89, 7, 56, 0, 43, 4,  7, 8, 14, 6, 33
  };
  const int q2735[] = {
    9, 9, // Number of jobs and machines
    2, 77, 0, 13, 8, 40, 7,  8, 6, 26, 3, 55, 4, 21, 1, 13, 5, 63, 
    6, 62, 3, 67, 0, 21, 8, 11, 7, 88, 5, 94, 2, 23, 1, 16, 4, 79, 
    2, 37, 6, 82, 4, 83, 0, 59, 5, 23, 1, 31, 8, 60, 7, 47, 3, 77, 
    6, 43, 0, 31, 7, 65, 3, 37, 5, 60, 8, 32, 2, 27, 4, 90, 1, 47, 
    8, 20, 0, 20, 5, 24, 7, 60, 2, 19, 4, 94, 6, 54, 3, 50, 1, 68, 
    8, 35, 1, 85, 0, 34, 7, 46, 4, 76, 5, 62, 2,  6, 3, 50, 6, 58, 
    0, 25, 5,  3, 2, 52, 6, 14, 3, 42, 8, 80, 1, 96, 7, 83, 4, 98, 
    4, 62, 8, 87, 0, 66, 1, 64, 6,  6, 5, 91, 2, 99, 3, 53, 7, 88, 
    0, 97, 1, 18, 7, 11, 6, 72, 2, 51, 4, 17, 5, 78, 8, 76, 3, 40
  };
  const int q2736[] = {
    9, 9, // Number of jobs and machines
    6, 44, 0, 56, 7, 73, 5, 87, 1, 42, 4,  5, 2, 41, 3, 71, 8, 39, 
    1, 52, 5, 70, 8, 18, 4, 70, 0, 50, 7,  6, 3, 64, 2, 33, 6, 59, 
    1, 83, 6, 71, 5, 40, 2, 11, 0, 64, 4, 57, 3,  5, 8, 24, 7, 14, 
    3, 26, 8, 97, 0, 46, 2,  2, 4,  3, 1, 68, 7, 69, 5, 13, 6, 19, 
    1, 23, 2, 13, 6, 12, 0, 79, 7, 55, 8, 62, 5, 40, 3, 41, 4, 81, 
    8, 34, 0, 88, 6, 35, 4, 50, 7, 56, 1, 62, 3, 32, 5, 85, 2, 33, 
    8, 15, 5, 78, 4, 60, 2, 46, 7, 71, 1, 63, 6, 28, 3,  8, 0, 97, 
    2, 21, 1, 47, 4, 13, 5, 95, 3,  8, 6, 50, 8, 91, 7,  2, 0, 31, 
    5, 17, 4, 30, 6, 11, 2, 86, 3, 32, 0, 40, 8, 20, 7, 65, 1, 80
  };
  const int q2737[] = {
    9, 9, // Number of jobs and machines
    4, 15, 3, 82, 8, 55, 0, 31, 6, 95, 5, 82, 7, 86, 2, 66, 1, 30, 
    4, 66, 3, 49, 7, 40, 2, 24, 6, 42, 1, 58, 0, 52, 5, 12, 8, 54, 
    2, 46, 0, 33, 5, 60, 4, 47, 1, 44, 7, 32, 3, 49, 6, 95, 8, 34, 
    6,  2, 0, 53, 4, 82, 1, 46, 8, 84, 3, 94, 7, 25, 5, 77, 2, 33, 
    8, 70, 7,  3, 6, 83, 5, 24, 4, 23, 2, 86, 3, 95, 0, 19, 1, 76, 
    8, 78, 0, 74, 4, 80, 2,  2, 3, 21, 7,  6, 1, 29, 5, 59, 6, 21, 
    3, 98, 7,  9, 5, 75, 4, 26, 8, 67, 2, 80, 6, 81, 0, 32, 1, 11, 
    3, 32, 4, 38, 0, 82, 2, 65, 6, 57, 7, 75, 8,  6, 1,  8, 5, 53, 
    4, 36, 5, 34, 6, 78, 8, 14, 0, 21, 7, 42, 1,  5, 2, 31, 3, 37
  };
  const int q2738[] = {
    9, 9, // Number of jobs and machines
    0, 30, 1, 77, 2, 46, 8, 34, 3,  9, 5, 41, 4, 82, 6, 30, 7, 69, 
    4, 88, 5, 76, 7, 78, 1,  5, 6, 46, 0, 77, 3, 59, 8, 45, 2, 13, 
    6, 74, 0, 82, 7, 19, 2,  7, 3, 37, 1, 13, 4, 64, 8, 97, 5, 34, 
    3,  2, 6, 64, 2,  5, 1,  5, 5, 18, 0, 20, 4, 99, 7, 71, 8, 92, 
    5, 70, 8, 57, 2, 24, 1, 92, 0,  9, 7, 83, 4, 68, 6, 27, 3, 33, 
    7, 83, 3, 97, 5, 35, 8, 34, 0, 33, 2, 24, 6, 13, 4, 64, 1, 51, 
    0, 19, 4, 23, 3, 73, 5, 82, 7, 47, 8, 81, 6, 85, 1, 81, 2, 33, 
    3, 92, 6,  9, 7, 64, 4, 60, 8, 36, 5,  5, 2, 89, 1, 79, 0,  2, 
    3, 99, 2, 90, 4, 49, 6, 83, 5, 45, 7, 96, 8, 99, 1, 22, 0, 65
  };
  const int q2739[] = {
    9, 9, // Number of jobs and machines
    3, 64, 1,  5, 7, 47, 6, 59, 4, 33, 8, 57, 5, 45, 0, 49, 2, 69, 
    6,  3, 4, 20, 3, 54, 1, 42, 7, 45, 8, 72, 5, 52, 0, 30, 2, 35, 
    8, 99, 3, 40, 5, 78, 4, 75, 7, 33, 2, 50, 6,  3, 0, 66, 1, 31, 
    3, 98, 1, 55, 2, 78, 8, 36, 6, 39, 7, 40, 0, 33, 4,  1, 5, 25, 
    1, 69, 5,  7, 7, 12, 6, 96, 8, 73, 4, 26, 3, 25, 2, 83, 0,  9, 
    7, 11, 1, 16, 0,  2, 3, 63, 4, 86, 8, 30, 2, 47, 5, 68, 6, 32, 
    5, 75, 2,  4, 3, 14, 0, 10, 7, 44, 1, 42, 8, 22, 4, 46, 6, 25, 
    7, 72, 8, 60, 1,  2, 6, 41, 3, 53, 0, 20, 4, 65, 5, 80, 2, 45, 
    2, 82, 1, 49, 3, 85, 6, 96, 5, 88, 7, 54, 4,  6, 0, 21, 8, 27
  };
  const int q2740[] = {
    9, 9, // Number of jobs and machines
    3,  4, 7, 52, 8, 59, 5, 95, 1, 12, 4, 68, 6, 64, 2, 13, 0, 95, 
    6, 60, 7, 80, 3, 23, 0, 17, 2, 52, 4, 81, 1, 20, 5, 52, 8, 37, 
    0, 57, 8, 27, 5, 56, 3, 65, 1, 68, 4, 35, 7, 87, 6, 74, 2, 93, 
    6, 51, 0, 76, 1, 99, 4, 22, 2, 29, 8, 89, 5, 38, 7, 48, 3, 93, 
    0, 21, 8, 66, 2, 90, 1, 24, 7, 92, 6, 23, 5, 61, 4, 99, 3, 79, 
    5,  2, 3, 38, 4, 95, 2, 44, 8, 42, 0, 10, 6,  8, 1, 74, 7, 55, 
    2, 52, 4, 99, 5,  4, 3,  5, 8, 19, 1, 90, 0, 33, 6, 47, 7, 22, 
    6, 59, 8, 12, 0, 47, 4, 26, 2, 54, 3, 55, 5, 50, 1, 49, 7, 96, 
    5, 65, 1, 59, 7, 91, 6, 61, 4, 91, 8, 52, 3, 93, 2, 20, 0, 97
  };
  const int q2741[] = {
    9, 9, // Number of jobs and machines
    2, 31, 7, 47, 6, 84, 0, 24, 1, 55, 8, 12, 3, 79, 4, 89, 5, 77, 
    1, 15, 4,  3, 0, 64, 7, 57, 6, 16, 5, 59, 3, 33, 2, 75, 8, 41, 
    8, 16, 0, 63, 1, 56, 5, 34, 4, 27, 3, 13, 6, 41, 7,  4, 2,  5, 
    8, 29, 7, 79, 3, 92, 6, 77, 4, 71, 2, 23, 5, 18, 1, 43, 0, 31, 
    6, 26, 7, 36, 5, 25, 2, 22, 8, 63, 1,  3, 0, 44, 3, 11, 4, 13, 
    3, 10, 5, 71, 4, 14, 8, 42, 1, 41, 0, 97, 2,  9, 6,  2, 7, 37, 
    6, 67, 5, 27, 2, 75, 3, 97, 8, 20, 4, 42, 0, 97, 1, 51, 7, 86, 
    1,  9, 0, 54, 7, 60, 2, 37, 3, 20, 8, 65, 5,  6, 6, 21, 4, 78, 
    1, 45, 4, 27, 6, 24, 0, 50, 8, 88, 7, 68, 5, 22, 2, 74, 3, 10
  };
  const int q2742[] = {
    9, 9, // Number of jobs and machines
    3, 77, 5, 32, 1, 75, 8, 65, 7, 63, 0, 97, 2, 98, 4, 70, 6, 91, 
    5, 67, 3, 34, 6, 32, 7, 49, 4, 56, 2, 86, 0,  7, 1, 57, 8, 64, 
    6, 84, 4, 49, 7, 43, 3, 19, 8, 58, 5, 73, 2, 58, 0, 51, 1, 45, 
    2, 91, 1, 97, 4,  5, 6, 38, 7, 96, 8, 41, 0, 21, 5, 33, 3, 16, 
    3, 91, 2, 62, 5, 45, 7, 10, 1, 35, 6, 84, 4, 62, 0, 68, 8,  4, 
    3, 44, 4, 30, 1, 79, 7, 56, 6, 18, 5, 69, 8, 15, 0, 41, 2, 11, 
    8,  6, 5, 52, 4, 90, 6,  1, 0, 47, 7,  6, 1, 45, 2, 33, 3, 77, 
    4, 26, 7, 11, 0, 18, 3, 47, 6, 91, 2, 41, 5, 40, 8, 64, 1, 64, 
    8, 27, 0, 89, 6, 95, 5, 68, 4, 56, 7, 85, 1,  8, 2, 84, 3, 43
  };
  const int q2743[] = {
    9, 9, // Number of jobs and machines
    3,  2, 0, 51, 7, 32, 4,  9, 1, 66, 6, 58, 8, 73, 5, 92, 2, 10, 
    7, 17, 2, 79, 4, 59, 6, 56, 8, 21, 0, 11, 5, 28, 1, 78, 3, 39, 
    6, 54, 7,  1, 5,  1, 4, 95, 8,  6, 3, 92, 2, 35, 0, 57, 1, 60, 
    5,  4, 0,  7, 2, 52, 1, 38, 4, 30, 8, 24, 7, 83, 3, 27, 6, 58, 
    0, 75, 3, 73, 4, 50, 1, 54, 2, 82, 6, 68, 5, 47, 8, 65, 7, 34, 
    1, 64, 4, 51, 7, 65, 6, 89, 2, 46, 0, 56, 8, 97, 5, 56, 3, 81, 
    6, 10, 7, 35, 5, 94, 2, 86, 4, 93, 1, 86, 3, 98, 0, 27, 8,  5, 
    6, 45, 8, 22, 2, 85, 3, 46, 7, 19, 0, 11, 5, 89, 4, 97, 1, 47, 
    3, 18, 1, 41, 0, 41, 5, 55, 2, 20, 6,  2, 4, 63, 8, 29, 7, 33
  };
  const int q2744[] = {
    9, 9, // Number of jobs and machines
    4, 78, 3,  7, 2, 63, 6, 37, 1, 46, 8, 34, 5,  8, 7, 98, 0, 21, 
    2, 21, 0, 28, 5, 47, 6, 75, 1,  3, 7, 32, 4, 86, 3, 58, 8, 41, 
    1, 91, 8, 42, 5, 59, 3,  1, 6, 10, 2, 85, 7, 25, 0, 28, 4, 29, 
    5, 87, 4, 45, 8, 91, 1, 92, 2, 33, 7,  4, 6, 69, 0, 62, 3, 30, 
    4, 20, 6, 77, 7, 40, 2, 21, 1,  2, 0, 47, 3, 17, 5, 38, 8, 95, 
    7, 80, 2, 36, 8,  3, 3, 41, 5, 51, 0, 88, 1, 80, 4, 46, 6, 67, 
    7, 95, 8, 75, 2, 12, 1, 25, 3, 49, 4, 23, 0, 15, 6, 72, 5, 31, 
    3, 56, 1, 22, 0,  7, 7, 39, 6, 51, 2, 29, 4, 70, 5, 68, 8, 26, 
    3, 78, 1, 52, 0, 61, 2, 83, 6, 89, 7, 91, 8, 75, 4,  4, 5,  1
  };
  const int q2745[] = {
    9, 9, // Number of jobs and machines
    7, 79, 0, 28, 1, 19, 6, 36, 2, 73, 8, 14, 4, 44, 3, 19, 5, 21, 
    6, 58, 8, 92, 0, 94, 3, 91, 5, 47, 7, 79, 4, 18, 2, 13, 1, 25, 
    8, 17, 5, 35, 4, 45, 0, 71, 1, 80, 7, 27, 3, 60, 2,  8, 6, 86, 
    1, 83, 6, 94, 4, 67, 5, 37, 2, 45, 7, 90, 8, 65, 0, 21, 3, 28, 
    1, 57, 0, 55, 7, 97, 2, 11, 4, 67, 6, 48, 3, 95, 8, 32, 5, 61, 
    2, 85, 0, 14, 4, 53, 3, 58, 5, 56, 8, 82, 7, 77, 1, 68, 6, 64, 
    1, 67, 7, 51, 0, 70, 6, 28, 5, 19, 4, 47, 3,  2, 2, 51, 8, 90, 
    7, 39, 4,  7, 3, 44, 5, 49, 0, 12, 6, 35, 2, 46, 1, 16, 8, 55, 
    6, 68, 5,  5, 1, 88, 8, 60, 3, 56, 4, 35, 7, 61, 0, 93, 2, 91
  };
  const int q2746[] = {
    9, 9, // Number of jobs and machines
    7, 38, 1, 18, 0, 63, 4, 69, 2, 18, 3, 98, 8, 89, 5, 82, 6, 54, 
    6, 20, 4, 23, 1, 41, 8, 22, 2, 66, 7, 11, 3, 35, 0, 71, 5, 87, 
    4, 83, 8, 80, 0, 54, 5, 12, 3, 36, 7, 46, 6, 41, 2,  4, 1, 11, 
    2, 25, 3, 72, 7, 69, 1, 76, 8, 60, 0, 52, 5, 94, 4, 38, 6, 49, 
    6, 42, 1, 77, 3, 50, 0, 36, 8,  4, 2, 68, 7, 43, 4,  5, 5, 19, 
    7,  9, 8, 69, 3,  6, 1, 84, 6, 65, 2, 53, 5, 58, 0, 41, 4, 35, 
    0, 60, 2, 70, 5, 64, 8,  3, 3,  8, 1, 86, 6, 14, 7, 65, 4, 41, 
    4, 37, 0, 77, 5, 86, 6, 76, 7, 35, 2, 72, 8, 84, 3, 81, 1, 51, 
    8, 50, 2, 39, 7, 52, 6, 18, 0, 91, 4, 58, 5, 24, 1, 94, 3, 94
  };
  const int q2747[] = {
    9, 9, // Number of jobs and machines
    0, 54, 8, 19, 4, 52, 3, 32, 5, 65, 7, 50, 2, 70, 6, 52, 1, 51, 
    2, 23, 1, 16, 8, 49, 6, 61, 4, 63, 0, 14, 3, 88, 5, 16, 7, 64, 
    0, 35, 8, 60, 1, 10, 4, 61, 2, 55, 3, 92, 5, 24, 7, 33, 6, 79, 
    8, 80, 7, 51, 1, 91, 2, 29, 0, 34, 6, 60, 3, 69, 4, 91, 5, 73, 
    2,  5, 5, 79, 6, 65, 4, 17, 8, 54, 3,  3, 0, 61, 7, 29, 1,  7, 
    4, 10, 2, 91, 6, 83, 3, 54, 5, 87, 0, 25, 7, 80, 8, 45, 1, 14, 
    3, 67, 2, 86, 1, 53, 6, 22, 0, 87, 5, 25, 8, 69, 4, 82, 7, 62, 
    2, 75, 1, 23, 3, 55, 4, 70, 0, 61, 7,  9, 6, 48, 5, 74, 8,  5, 
    0, 56, 4, 32, 8,  1, 1, 62, 5,  8, 7, 80, 2, 23, 3, 75, 6, 67
  };
  const int q2748[] = {
    9, 9, // Number of jobs and machines
    1, 15, 3, 51, 8, 21, 4, 26, 7, 34, 6, 31, 2, 41, 0, 50, 5, 15, 
    1, 13, 7, 38, 0, 49, 8, 64, 6, 93, 3, 67, 4, 59, 5, 34, 2, 68, 
    3, 14, 6, 30, 1,  4, 8, 70, 2, 22, 4, 95, 7, 97, 0, 88, 5, 47, 
    6,  9, 4, 93, 3, 69, 5, 35, 2, 65, 7,  2, 0, 52, 8, 73, 1, 95, 
    2, 30, 6, 65, 1,  1, 7, 96, 5, 60, 4, 11, 3, 81, 8, 87, 0, 57, 
    6, 53, 4, 24, 8, 23, 0, 53, 7, 55, 1, 14, 2, 24, 3, 31, 5, 60, 
    3, 48, 0, 92, 8, 30, 1, 41, 2, 82, 5, 39, 6, 93, 4, 62, 7, 42, 
    2, 23, 5,  5, 8, 88, 3, 48, 7, 47, 4, 54, 1, 64, 6, 46, 0, 25, 
    3, 42, 7, 91, 2, 28, 4, 68, 0, 43, 8, 53, 5, 60, 6, 63, 1, 16
  };
  const int q2749[] = {
    9, 9, // Number of jobs and machines
    5, 39, 2, 94, 8, 75, 4, 37, 1, 42, 7, 89, 0, 79, 3, 15, 6, 69, 
    2, 98, 7, 61, 3, 70, 1, 52, 0, 75, 8, 65, 6, 31, 5, 11, 4, 22, 
    2, 87, 7, 44, 4, 87, 3,  2, 0, 80, 8, 66, 6, 39, 5, 32, 1, 97, 
    6, 32, 2, 48, 7,  2, 3, 41, 5, 60, 1, 67, 8, 66, 4, 89, 0, 68, 
    2,  5, 0, 24, 4, 37, 1, 51, 6, 54, 7, 66, 5, 45, 8, 22, 3,  9, 
    6,  5, 7,  9, 3, 70, 5, 31, 1, 18, 2, 74, 0, 49, 8, 88, 4,  1, 
    2, 36, 6, 55, 3, 30, 5, 53, 7, 20, 0, 40, 1, 24, 4, 39, 8, 25, 
    4, 15, 8, 19, 0, 96, 7, 65, 3, 43, 1, 28, 2, 45, 5, 84, 6, 14, 
    8, 54, 5, 35, 6, 49, 4, 33, 3, 67, 0, 89, 2, 96, 7, 88, 1,  8
  };
  const int q2750[] = {
    9, 9, // Number of jobs and machines
    0, 88, 8, 62, 3, 72, 1, 42, 2, 16, 5, 26, 6, 80, 7, 57, 4,  4, 
    3, 53, 2, 45, 8, 54, 0, 23, 4, 39, 5, 85, 6, 61, 1, 57, 7,  4, 
    7, 18, 5, 83, 4, 20, 6, 35, 8, 30, 1, 85, 3, 85, 0, 88, 2, 41, 
    3, 38, 1, 24, 7, 86, 2, 71, 5, 43, 4,  6, 0,  7, 8, 75, 6,  2, 
    4, 31, 8, 68, 3, 29, 7,  8, 1, 86, 6, 71, 2, 14, 5, 24, 0, 67, 
    4, 86, 7, 13, 2, 22, 6, 80, 1, 80, 0,  3, 8,  4, 5,  1, 3, 74, 
    4, 77, 0, 41, 8, 84, 1, 18, 3, 92, 7, 47, 6, 50, 2,  2, 5, 60, 
    7, 30, 4, 40, 0, 63, 2, 31, 8, 73, 3, 99, 1, 37, 5, 25, 6, 31, 
    6, 93, 3, 38, 0, 84, 5, 72, 2, 39, 8, 95, 7, 55, 1, 44, 4, 91
  };
  const int q2751[] = {
    9, 9, // Number of jobs and machines
    2, 66, 5, 17, 0, 93, 6, 59, 1, 84, 8, 78, 3, 47, 4, 90, 7,  8, 
    4, 15, 0, 43, 7, 34, 1, 20, 6, 99, 2, 87, 8,  9, 5, 76, 3, 88, 
    2, 73, 0, 15, 5, 19, 4,  8, 7, 60, 8, 50, 6,  4, 1, 13, 3, 20, 
    1, 61, 2, 88, 4, 83, 6, 39, 7, 74, 5, 74, 3, 75, 8, 61, 0,  6, 
    8, 42, 6, 97, 1, 21, 0, 15, 7, 75, 3, 23, 4,  2, 5, 51, 2, 51, 
    4,  2, 6, 26, 3, 36, 1, 78, 7, 30, 5, 50, 8, 51, 2, 81, 0, 97, 
    0, 38, 5, 61, 6, 76, 1, 15, 3, 12, 4, 19, 7,  5, 2, 48, 8, 21, 
    6, 81, 4, 42, 1, 73, 0, 55, 8, 14, 5, 27, 3, 55, 7,  8, 2, 74, 
    1,  5, 3, 69, 7, 21, 8, 23, 6,  6, 0,  6, 4, 62, 5, 12, 2, 76
  };
  const int q2752[] = {
    9, 9, // Number of jobs and machines
    8, 22, 7, 71, 2, 52, 0, 46, 4, 73, 3, 58, 1,  5, 5,  1, 6, 47, 
    2,  9, 3, 23, 7, 98, 4, 36, 8, 49, 5,  3, 6, 79, 1, 53, 0, 14, 
    3, 16, 0, 44, 1,  4, 5, 72, 7,  4, 6, 89, 8, 66, 4, 58, 2, 71, 
    4, 44, 6, 29, 2, 47, 7,  3, 3, 72, 5, 41, 8, 47, 0,  7, 1, 94, 
    6, 96, 2, 90, 3, 55, 1, 82, 7, 94, 8, 27, 5, 78, 4, 95, 0, 27, 
    1, 81, 2, 60, 8, 18, 3, 45, 7, 13, 0, 92, 6, 37, 4, 21, 5, 42, 
    1, 96, 4, 53, 0, 19, 2, 33, 6, 53, 8, 40, 5, 89, 3, 34, 7, 39, 
    4, 92, 3, 29, 5, 82, 8, 10, 7, 38, 1, 54, 6, 31, 0, 52, 2,  4, 
    0, 71, 1, 68, 6, 92, 2, 97, 8, 14, 5, 20, 7, 44, 4, 18, 3,  9
  };
  const int q2753[] = {
    9, 9, // Number of jobs and machines
    2,  9, 1, 76, 6, 58, 8, 56, 4, 57, 3, 89, 0, 35, 5, 68, 7, 97, 
    3, 62, 4, 81, 2, 87, 8, 81, 7, 81, 1, 48, 5, 87, 6, 76, 0, 60, 
    1,  8, 7, 50, 4, 30, 3, 57, 8, 29, 0, 16, 2, 79, 6, 73, 5, 81, 
    3, 31, 5,  1, 2, 70, 0, 69, 1, 38, 7, 51, 6, 28, 8, 36, 4, 86, 
    2, 76, 3, 32, 8,  8, 0, 65, 5, 15, 6, 67, 4, 31, 7, 47, 1, 52, 
    7, 61, 3, 30, 4, 30, 8, 29, 0, 77, 6, 34, 2, 19, 5, 58, 1, 78, 
    8, 91, 6, 40, 7, 41, 0, 60, 1, 71, 3, 50, 2, 81, 5, 81, 4, 94, 
    7,  2, 1,  7, 6, 32, 0, 79, 4, 35, 5,  9, 2, 82, 3, 58, 8, 77, 
    6, 85, 5, 93, 2, 89, 4, 45, 7, 19, 0, 48, 3,  7, 1, 29, 8,  2
  };
  const int q2754[] = {
    9, 9, // Number of jobs and machines
    8, 35, 1, 12, 2, 82, 5, 89, 4, 98, 6, 18, 3, 30, 0, 27, 7, 54, 
    2, 37, 6, 17, 0, 37, 5, 72, 7, 53, 1, 75, 3, 16, 4, 88, 8, 12, 
    1, 34, 3, 27, 4, 81, 5, 98, 7, 35, 2, 83, 8, 51, 6, 78, 0, 62, 
    6, 45, 5, 91, 4, 61, 8, 91, 3, 94, 0, 59, 7, 26, 2, 27, 1, 80, 
    5, 27, 8, 76, 2,  7, 0, 10, 4, 35, 1, 78, 3, 40, 7,  4, 6, 34, 
    8, 13, 5,  1, 7, 62, 2, 55, 3, 55, 6, 78, 4, 36, 1, 59, 0, 83, 
    2, 41, 1, 44, 6, 89, 0, 42, 8, 62, 3, 63, 7, 55, 5, 93, 4, 97, 
    2, 31, 1, 17, 6, 75, 5,  1, 8, 67, 3, 19, 4, 87, 0, 51, 7, 51, 
    7, 88, 1, 40, 2, 63, 0, 76, 3, 69, 4, 97, 5, 56, 8, 19, 6, 74
  };
  const int q2755[] = {
    9, 9, // Number of jobs and machines
    2, 63, 7, 11, 1, 52, 3, 61, 5, 35, 8, 65, 0, 40, 6, 21, 4, 82, 
    4, 47, 1,  2, 2, 30, 6, 25, 0, 84, 3, 52, 8, 37, 7, 25, 5, 29, 
    2, 68, 6, 38, 0, 11, 5, 39, 3,  2, 8, 76, 4, 93, 7, 76, 1, 66, 
    4, 33, 6, 13, 5, 83, 8, 52, 1, 29, 7, 20, 3, 48, 0, 37, 2, 39, 
    8, 63, 3, 93, 0, 27, 1, 57, 2, 31, 7, 46, 4, 23, 5, 81, 6, 92, 
    4, 96, 5, 54, 7, 12, 3, 35, 8, 16, 1, 64, 6, 35, 2, 54, 0, 69, 
    2, 55, 1, 29, 6, 68, 0, 54, 4, 18, 3, 71, 7, 65, 5, 38, 8, 69, 
    2, 82, 3, 58, 6, 75, 1, 34, 7, 19, 8, 38, 5, 33, 0, 74, 4, 74, 
    1, 62, 2, 30, 0, 26, 4, 49, 3, 68, 8, 71, 7, 20, 5, 61, 6, 89
  };
  const int q2756[] = {
    9, 9, // Number of jobs and machines
    7, 31, 4, 29, 8, 80, 3,  5, 1, 42, 2, 99, 6, 49, 0, 56, 5, 68, 
    1, 41, 5, 45, 2, 55, 8, 68, 6, 59, 4, 57, 7, 26, 0, 37, 3, 41, 
    4, 72, 1, 64, 0, 95, 3, 82, 8, 16, 5, 53, 7, 73, 6, 44, 2, 88, 
    2,  1, 0, 10, 7, 98, 3, 31, 4, 39, 1,  9, 5, 36, 6, 56, 8, 41, 
    8, 90, 0, 35, 3, 75, 2, 31, 4, 99, 7, 74, 6, 72, 5, 70, 1, 30, 
    7, 30, 0,  6, 5,  9, 2, 10, 8, 89, 1, 93, 6, 59, 4, 53, 3, 67, 
    4, 97, 6, 82, 0, 44, 1, 70, 7, 27, 3, 36, 2, 82, 5, 50, 8,  8, 
    4, 27, 1, 91, 0, 76, 7, 85, 6, 54, 3, 64, 2, 90, 8, 64, 5, 44, 
    6, 27, 5, 72, 7, 90, 3, 75, 2, 47, 1, 43, 0, 66, 4, 90, 8, 93
  };
  const int q2757[] = {
    9, 9, // Number of jobs and machines
    4, 94, 7, 26, 5, 94, 2, 35, 0, 40, 1, 51, 3, 69, 6, 54, 8, 80, 
    0, 50, 1,  9, 3, 84, 5, 42, 8, 52, 7, 99, 2, 26, 4, 18, 6,  5, 
    8, 98, 1,  8, 0,  9, 4, 77, 7, 74, 6, 33, 3, 19, 5, 57, 2, 85, 
    6, 92, 4, 78, 2, 26, 3, 87, 7, 53, 1, 49, 8, 87, 5, 70, 0, 29, 
    6,  1, 4, 63, 2, 45, 1,  8, 7, 32, 8, 73, 5, 97, 0, 60, 3, 28, 
    2, 57, 8,  2, 6, 52, 4,  7, 5, 17, 3, 64, 0, 70, 7, 40, 1, 41, 
    4, 74, 5, 40, 1, 83, 7, 37, 3, 16, 6, 25, 8, 62, 2, 14, 0,  6, 
    3, 39, 4, 42, 5, 44, 8, 75, 1, 46, 6, 29, 7, 28, 0, 56, 2, 53, 
    0, 39, 5, 71, 7, 65, 8, 41, 1, 82, 3, 16, 4, 39, 2, 13, 6, 67
  };
  const int q2758[] = {
    9, 9, // Number of jobs and machines
    8, 87, 1, 73, 6, 21, 2, 80, 0, 15, 5, 78, 7, 87, 3, 16, 4, 20, 
    1, 43, 5, 63, 4, 80, 6, 93, 3, 42, 0, 24, 2, 13, 7, 79, 8, 43, 
    5,  5, 4, 32, 6, 84, 8,  6, 0, 70, 2, 66, 1, 34, 3, 62, 7, 53, 
    6, 51, 4, 69, 3, 26, 2, 21, 7,  2, 8, 29, 1, 22, 0, 98, 5,  8, 
    2, 45, 3,  8, 4, 54, 1,  9, 0, 77, 7, 60, 6, 53, 5, 45, 8, 55, 
    2, 31, 6, 23, 1, 57, 4, 28, 0, 94, 8, 17, 3, 69, 7,  4, 5, 33, 
    3,  4, 8, 17, 4, 65, 5, 74, 6, 54, 2,  9, 1, 55, 0, 79, 7, 53, 
    3, 78, 0, 95, 2, 38, 1, 59, 4, 55, 7, 13, 8, 65, 5, 60, 6, 11, 
    2, 80, 6, 44, 5,  9, 8, 49, 3, 18, 1, 16, 4, 10, 7, 91, 0, 98
  };
  const int q2759[] = {
    9, 9, // Number of jobs and machines
    8, 92, 2,  3, 3, 15, 4, 98, 6, 91, 0, 40, 7, 41, 5, 58, 1, 99, 
    2, 75, 3, 19, 4, 11, 0, 30, 6, 36, 8, 57, 5, 18, 1, 76, 7, 67, 
    7, 78, 5, 23, 3,  2, 2, 17, 0, 99, 8, 96, 1, 52, 4, 65, 6, 31, 
    4, 91, 8,  8, 6, 90, 5, 98, 2,  4, 3, 34, 7, 69, 0, 74, 1, 86, 
    1, 70, 6, 85, 3, 78, 4, 37, 2, 60, 0,  2, 5, 31, 8, 26, 7, 18, 
    2, 79, 5, 22, 0, 16, 6, 64, 8, 18, 1, 58, 7, 39, 4, 95, 3, 33, 
    5,  4, 7, 59, 2,  9, 6, 15, 8, 90, 3,  7, 1, 26, 4, 61, 0,  4, 
    6, 38, 4, 13, 1, 24, 5, 16, 7, 65, 3, 90, 8, 39, 2, 16, 0, 59, 
    3, 12, 5, 11, 8, 27, 0, 57, 4, 69, 1, 91, 2,  5, 7, 45, 6, 11
  };
  const int q2760[] = {
    9, 9, // Number of jobs and machines
    4, 10, 6, 48, 5, 36, 1, 29, 3, 61, 2,  2, 7, 20, 8, 62, 0, 91, 
    8, 24, 4, 52, 7, 34, 5, 96, 3, 47, 0, 22, 2, 49, 6,  1, 1, 49, 
    2, 79, 7, 11, 5, 81, 3, 27, 0, 74, 1,  9, 4, 50, 6, 27, 8,  9, 
    1, 93, 0, 68, 7, 23, 4, 90, 3, 17, 6, 56, 5,  2, 2, 27, 8, 90, 
    3, 78, 6, 53, 0, 91, 4,  7, 8, 75, 1, 49, 2, 93, 5, 80, 7, 45, 
    8, 68, 5, 25, 1, 33, 2, 48, 0, 25, 3, 38, 7, 75, 4,  1, 6, 31, 
    2, 38, 6, 39, 3, 44, 7, 97, 5, 80, 0,  5, 1, 77, 8, 68, 4, 92, 
    1, 26, 4, 53, 3, 45, 7, 29, 8, 81, 6, 51, 2, 88, 0, 79, 5, 75, 
    2, 73, 6,  1, 7,  7, 1, 88, 3, 18, 0, 82, 4,  7, 5, 25, 8,  6
  };
  const int q2761[] = {
    9, 9, // Number of jobs and machines
    0, 25, 5, 99, 8, 54, 1, 86, 4, 93, 3, 81, 2, 81, 7, 63, 6, 86, 
    0, 38, 1, 61, 2, 20, 5, 30, 8, 71, 7, 17, 6, 27, 4, 60, 3, 88, 
    4, 99, 8, 60, 1, 13, 0, 98, 2, 41, 5, 71, 6, 22, 7, 84, 3,  4, 
    7, 57, 1, 68, 2, 80, 3, 72, 5, 33, 6, 45, 0, 38, 4, 80, 8, 44, 
    6, 74, 3, 12, 1,  2, 4, 38, 8,  2, 0, 21, 7, 18, 2, 86, 5, 89, 
    2, 43, 6, 44, 4, 75, 5, 43, 1, 27, 3, 31, 7, 39, 8, 57, 0, 10, 
    5, 91, 0, 64, 2, 31, 1, 90, 3, 55, 8, 40, 7, 86, 4, 24, 6, 26, 
    0,  6, 8, 79, 4, 49, 5, 72, 2, 50, 7, 30, 1, 55, 3,  2, 6, 78, 
    4,  8, 3, 80, 8, 45, 7, 74, 1, 85, 2, 99, 6, 26, 0, 50, 5, 56
  };
  const int q2762[] = {
    9, 9, // Number of jobs and machines
    3, 81, 5, 24, 6, 48, 2, 64, 1, 11, 8, 94, 4, 44, 7, 70, 0, 50, 
    0, 11, 3, 13, 2, 90, 5, 78, 8, 73, 6, 40, 4, 92, 1, 68, 7, 95, 
    5, 33, 0,  9, 7,  4, 2, 67, 8,  1, 4, 99, 3, 97, 1, 12, 6, 11, 
    1, 49, 4, 42, 8,  6, 5, 70, 3, 13, 0,  6, 7, 22, 6, 33, 2, 88, 
    8, 41, 2, 40, 5, 67, 4, 83, 7, 38, 3, 21, 1, 77, 6, 71, 0, 97, 
    5, 39, 7, 31, 6, 65, 1, 50, 4, 68, 8, 91, 0, 87, 2, 99, 3, 20, 
    6, 17, 4, 28, 8,  1, 2,  4, 1, 25, 3,  7, 7, 10, 5, 59, 0, 67, 
    6,  4, 1, 55, 5, 74, 8, 16, 0,  9, 2, 61, 4, 99, 3, 89, 7, 42, 
    6, 81, 5,  6, 1, 96, 0, 37, 4, 54, 2, 80, 3,  7, 7, 15, 8, 14
  };
  const int q2763[] = {
    9, 9, // Number of jobs and machines
    6, 41, 8, 93, 2, 38, 3, 69, 7, 18, 1, 94, 5,  6, 0, 83, 4,  2, 
    3,  3, 2,  2, 7, 61, 5, 67, 0, 48, 6, 46, 1, 24, 8, 46, 4, 58, 
    4, 72, 2,  9, 0, 65, 5, 74, 8, 63, 7, 68, 6, 55, 3, 98, 1, 73, 
    3, 10, 2, 92, 0, 49, 1, 22, 6, 30, 4, 91, 5,  3, 7,  5, 8, 84, 
    3, 33, 7, 23, 2, 97, 8, 53, 5, 29, 0, 64, 6, 80, 1, 27, 4, 98, 
    4,  1, 0, 26, 6, 88, 3, 26, 2, 94, 8, 82, 1, 74, 5, 57, 7, 61, 
    3, 83, 4, 13, 7, 18, 1, 63, 6, 52, 0, 55, 5,  8, 8, 41, 2, 88, 
    0,  9, 6, 17, 1, 10, 7, 92, 3, 58, 2, 87, 8, 52, 5, 27, 4,  2, 
    0, 76, 3, 10, 8,  9, 1,  2, 6, 66, 4, 13, 5,  4, 7,  9, 2, 76
  };
  const int q2764[] = {
    9, 9, // Number of jobs and machines
    8,  9, 2, 42, 6, 26, 5, 25, 4, 73, 0, 37, 1, 76, 7,  2, 3, 60, 
    6, 60, 7, 11, 4,  7, 2, 12, 0, 20, 3, 31, 1, 86, 5, 38, 8, 28, 
    3, 52, 7, 41, 5,  7, 6, 48, 8, 80, 1, 25, 0, 34, 4, 86, 2, 62, 
    4, 28, 5,  5, 0, 32, 6, 64, 2, 40, 7, 68, 1, 40, 8, 25, 3, 43, 
    8, 39, 6, 25, 4, 25, 3, 51, 1, 37, 2, 77, 0, 77, 5, 91, 7, 95, 
    2, 92, 1, 55, 0, 21, 7, 83, 3, 46, 5, 63, 8, 97, 6,  2, 4, 10, 
    3, 85, 2, 91, 1, 44, 5, 96, 8, 53, 6, 42, 0, 38, 4, 60, 7, 97, 
    1, 64, 3, 84, 5, 61, 4, 23, 0, 73, 8, 77, 7, 39, 2, 32, 6, 66, 
    6,  5, 8, 64, 5, 86, 2, 43, 7, 55, 3, 24, 1, 40, 0, 66, 4, 53
  };
  const int q2765[] = {
    9, 9, // Number of jobs and machines
    7,  4, 0, 37, 6, 70, 4, 64, 3,  8, 1, 32, 2, 69, 5, 72, 8, 36, 
    7,  2, 2, 19, 0, 85, 6, 41, 3, 37, 1, 47, 4, 99, 8, 95, 5, 21, 
    5, 36, 6, 98, 0, 19, 3, 36, 7, 50, 1, 96, 2, 30, 8, 25, 4, 88, 
    2, 74, 1, 83, 3, 27, 0, 29, 7, 72, 5, 32, 4, 27, 8, 56, 6, 29, 
    4, 88, 8, 91, 5, 84, 1, 67, 7, 74, 3, 91, 0,  7, 6, 90, 2, 48, 
    8, 88, 5, 35, 1, 91, 2, 98, 0,  2, 7, 50, 6, 49, 3, 17, 4, 91, 
    6, 71, 8, 72, 3, 27, 0, 54, 4, 70, 1,  1, 7, 75, 2, 59, 5, 91, 
    6, 40, 3, 24, 4, 76, 1, 58, 0, 20, 5, 32, 7, 90, 8, 98, 2, 82, 
    1, 19, 2, 36, 7, 80, 8, 88, 3, 97, 5, 24, 4, 82, 0, 76, 6, 12
  };
  const int q2766[] = {
    9, 9, // Number of jobs and machines
    1, 48, 5, 43, 8,  3, 2, 14, 4, 19, 6, 39, 7, 46, 3, 58, 0, 57, 
    8, 85, 7, 10, 2, 43, 6, 24, 5, 21, 1, 93, 4, 82, 0, 14, 3, 79, 
    2, 89, 7, 67, 4, 67, 3, 44, 6, 99, 5, 89, 8, 16, 0, 84, 1, 29, 
    4, 73, 6,  5, 8, 85, 7, 74, 5, 46, 0, 79, 2, 81, 1, 63, 3, 79, 
    1, 14, 4, 64, 3, 61, 0,  1, 8, 69, 7, 48, 2, 38, 5, 91, 6, 92, 
    6, 10, 1, 90, 2, 90, 0, 76, 7,  5, 8, 44, 5, 30, 3, 73, 4, 45, 
    8, 72, 7, 81, 4,  6, 5,  5, 3, 95, 0, 44, 2, 87, 1,  8, 6, 94, 
    0, 10, 7, 22, 4, 72, 1, 69, 3, 60, 2,  2, 5, 69, 8, 89, 6, 65, 
    5, 27, 6, 12, 1, 56, 0, 34, 3, 45, 7, 12, 2, 83, 4, 15, 8, 67
  };
  const int q2767[] = {
    9, 9, // Number of jobs and machines
    8, 68, 0, 85, 7, 32, 1, 14, 3, 16, 5, 58, 6, 22, 2,  7, 4, 34, 
    2, 22, 8, 27, 1, 82, 5, 29, 0, 85, 6, 60, 7,  9, 4, 32, 3, 16, 
    0, 90, 3, 45, 6, 28, 5, 45, 1, 37, 7, 63, 8, 65, 4, 99, 2, 62, 
    1,  5, 5, 68, 8, 37, 3, 84, 2, 55, 0, 99, 4, 97, 6, 50, 7, 66, 
    4,  4, 1, 80, 3, 65, 6, 31, 2, 28, 5, 49, 8,  2, 7, 83, 0, 98, 
    3, 61, 1,  9, 7, 53, 0,  3, 8, 71, 6, 55, 4, 61, 2, 95, 5, 80, 
    3, 64, 2, 36, 8, 97, 5,  4, 6, 32, 0, 18, 1, 16, 7, 67, 4, 88, 
    4, 97, 0, 31, 7, 21, 5, 61, 1, 82, 3, 87, 6, 56, 2, 71, 8,  4, 
    0, 25, 4, 91, 6, 42, 5, 37, 2, 85, 1, 84, 8, 74, 7, 84, 3, 96
  };
  const int q2768[] = {
    9, 9, // Number of jobs and machines
    8, 84, 4, 77, 0, 50, 6, 72, 5, 86, 7, 93, 1, 51, 2, 51, 3, 82, 
    6, 49, 5, 66, 1, 36, 8, 67, 2, 97, 4, 35, 0, 64, 7, 89, 3, 12, 
    8, 67, 4, 14, 1, 46, 5,  6, 6, 68, 3, 79, 0, 87, 2, 77, 7, 58, 
    7, 32, 3, 79, 8, 22, 0, 64, 4, 31, 5, 20, 2, 25, 6, 29, 1, 23, 
    4, 77, 3, 88, 5, 98, 8, 72, 6, 44, 1, 76, 7, 56, 2, 60, 0, 38, 
    2, 18, 3, 47, 7, 90, 0, 80, 1, 35, 5, 80, 8, 34, 6, 20, 4, 17, 
    2, 74, 7, 79, 0, 86, 3, 55, 5, 74, 6, 35, 8, 72, 1, 83, 4,  9, 
    1, 21, 7, 72, 4, 19, 5, 48, 8, 65, 0, 51, 2, 11, 3, 36, 6, 25, 
    8, 26, 3, 19, 6, 63, 2, 71, 0, 52, 7, 64, 5, 50, 4, 80, 1, 22
  };
  const int q2769[] = {
    9, 9, // Number of jobs and machines
    1, 38, 5, 40, 6, 54, 4, 30, 7, 49, 0, 83, 3, 94, 2, 79, 8, 65, 
    7, 49, 4, 78, 3, 86, 6, 89, 0, 73, 8,  9, 2, 99, 5, 31, 1, 39, 
    2, 74, 4,  1, 0,  7, 7, 45, 8, 67, 3, 20, 1, 17, 5, 99, 6, 58, 
    7, 85, 8, 13, 0, 36, 2, 52, 6,  4, 1, 44, 3, 87, 4, 38, 5, 73, 
    4, 61, 3, 59, 6, 14, 2, 21, 1, 61, 7, 17, 5, 15, 0, 76, 8, 47, 
    6, 43, 5, 83, 8, 48, 1, 93, 3,  4, 2, 55, 0, 67, 7, 89, 4, 22, 
    4, 88, 7, 66, 6, 80, 2, 22, 5, 84, 8, 56, 3, 39, 1, 42, 0,  5, 
    4, 83, 6, 68, 1, 56, 5, 71, 7, 43, 2, 47, 8, 59, 3, 23, 0, 59, 
    4, 87, 2,  3, 8, 64, 6, 89, 7, 18, 1, 62, 0, 95, 5, 78, 3, 10
  };
  const int q2770[] = {
    9, 9, // Number of jobs and machines
    6, 50, 7, 44, 2, 85, 3, 34, 1,  3, 5, 19, 0,  1, 4, 49, 8, 31, 
    2, 33, 0, 37, 1, 64, 5, 28, 4, 26, 7, 39, 8, 71, 3, 60, 6, 94, 
    5, 70, 0, 17, 1, 57, 7, 79, 2, 71, 3, 22, 8, 32, 6, 46, 4,  9, 
    8, 31, 1, 33, 7, 99, 5, 37, 4, 34, 6, 27, 2, 33, 0, 45, 3, 74, 
    8,  3, 5, 61, 3, 90, 2, 96, 1, 25, 6, 53, 4, 18, 7, 29, 0, 48, 
    3, 43, 7, 32, 2, 63, 4, 25, 1, 52, 6, 91, 0, 82, 5, 34, 8, 91, 
    6, 17, 7, 71, 1, 84, 4, 28, 0, 58, 5, 38, 3, 22, 8,  6, 2, 49, 
    4, 86, 2,  1, 7, 50, 6, 87, 0,  7, 5, 18, 1, 14, 3, 85, 8, 74, 
    5, 48, 7, 69, 4, 37, 1,  7, 2, 47, 6,  7, 8, 66, 0, 95, 3, 78
  };
  const int q2771[] = {
    9, 9, // Number of jobs and machines
    6, 94, 3,  7, 7, 18, 5, 11, 8, 23, 1, 75, 0, 16, 4, 90, 2, 91, 
    7, 37, 2, 46, 4, 56, 1, 19, 0, 95, 3, 36, 6, 11, 8, 61, 5, 63, 
    8, 95, 7, 59, 4, 20, 2, 94, 3, 74, 0, 59, 1, 81, 6, 67, 5, 91, 
    8, 20, 5, 62, 4, 46, 3, 86, 1, 97, 0,  6, 2,  3, 7, 51, 6, 43, 
    2, 21, 3, 79, 0, 53, 4,  7, 1, 80, 7, 27, 6, 82, 5, 48, 8, 29, 
    6, 53, 7, 81, 2, 99, 5, 83, 8,  3, 0, 22, 3, 87, 4, 99, 1, 55, 
    7, 70, 3, 38, 1, 45, 2, 94, 8, 76, 5, 44, 0, 54, 4, 28, 6, 20, 
    5, 11, 2,  4, 4, 12, 3, 91, 8,  9, 1, 29, 0, 87, 6, 67, 7, 37, 
    7, 52, 2, 41, 6,  1, 4, 50, 3, 88, 0, 65, 8, 41, 1, 52, 5, 53
  };
  const int q2772[] = {
    9, 9, // Number of jobs and machines
    6,  5, 0, 45, 4, 46, 8, 76, 3, 56, 2, 75, 1, 98, 7, 39, 5, 30, 
    1,  4, 4, 80, 6, 68, 2, 78, 8, 62, 7, 26, 5, 73, 0, 72, 3, 11, 
    2, 80, 1, 14, 4, 36, 3, 97, 7, 38, 0, 23, 6, 58, 5, 58, 8,  2, 
    2, 56, 6, 54, 4, 77, 3, 34, 7, 54, 1, 99, 0, 69, 8, 78, 5, 27, 
    4, 35, 1, 61, 8, 14, 7, 11, 3, 46, 5, 31, 6, 79, 0, 81, 2, 92, 
    2, 28, 7, 64, 8, 95, 1, 46, 6, 51, 0,  6, 5, 45, 3, 76, 4, 54, 
    5, 45, 2, 69, 8, 56, 1, 21, 0, 17, 6, 11, 7, 69, 3, 27, 4,  9, 
    8, 21, 3, 92, 4, 36, 1,  6, 6, 75, 2, 40, 0, 93, 7,  1, 5, 63, 
    4, 47, 2,  1, 5, 84, 8, 74, 7, 87, 0, 27, 6, 27, 1, 18, 3, 39
  };
  const int q2773[] = {
    9, 9, // Number of jobs and machines
    0, 63, 7, 76, 5, 79, 1,  1, 4, 61, 8, 57, 2,  8, 6, 46, 3, 39, 
    0, 39, 6, 98, 2, 34, 4, 22, 7, 46, 1, 85, 5,  6, 8, 41, 3, 43, 
    8, 39, 4, 58, 1, 26, 0,  8, 6, 94, 5, 67, 7, 85, 3, 54, 2, 24, 
    7, 72, 0, 51, 2, 34, 8, 39, 4, 54, 1, 35, 6,  3, 3, 34, 5, 66, 
    1,  6, 3, 97, 6, 10, 4, 49, 5, 69, 2, 24, 7,  2, 8, 75, 0, 76, 
    7, 64, 0, 25, 3, 88, 5, 69, 6, 73, 2, 40, 8, 60, 1, 37, 4, 29, 
    3, 31, 0, 80, 4, 92, 8, 64, 2, 68, 5,  3, 6, 97, 1, 58, 7, 52, 
    1, 90, 2, 27, 5, 61, 6, 24, 4, 98, 0, 26, 3, 44, 8, 28, 7, 67, 
    1, 28, 0, 26, 3, 56, 4, 94, 2, 35, 6, 62, 7, 14, 5, 35, 8, 51
  };
  const int q2774[] = {
    9, 9, // Number of jobs and machines
    1, 12, 0, 83, 4, 85, 3, 12, 6, 30, 5, 82, 2, 88, 7, 40, 8, 22, 
    7, 21, 3, 34, 8, 51, 6, 18, 5, 59, 1, 69, 2, 65, 0, 26, 4, 90, 
    3, 24, 1, 19, 7, 96, 5, 22, 8, 79, 0, 79, 2, 14, 4, 10, 6, 95, 
    7, 56, 0, 38, 1, 64, 8, 35, 5, 77, 3, 32, 6,  3, 2, 41, 4, 89, 
    3, 81, 7, 24, 8, 89, 1,  7, 2, 77, 4, 49, 5, 82, 0, 92, 6,  4, 
    1, 13, 8, 47, 2, 11, 7, 20, 0, 47, 5,  2, 3, 82, 6, 31, 4, 41, 
    6, 62, 4, 19, 2, 22, 1, 22, 0,  5, 5,  3, 7, 74, 8, 26, 3, 79, 
    0,  6, 6,  9, 7, 55, 1, 19, 8, 54, 3, 68, 2, 73, 4,  4, 5, 14, 
    3,  8, 0, 41, 2, 24, 5, 81, 4, 44, 8, 19, 6, 25, 1, 88, 7, 90
  };
  const int q2775[] = {
    9, 9, // Number of jobs and machines
    2, 75, 6, 38, 7, 89, 1, 73, 4, 35, 5, 10, 0, 24, 8, 72, 3, 43, 
    1, 54, 7, 58, 6, 12, 8, 32, 3, 69, 5, 11, 2, 96, 4, 20, 0, 77, 
    4, 91, 8, 81, 2, 83, 0, 84, 6, 54, 7, 74, 3, 48, 1, 30, 5, 43, 
    7, 64, 3, 53, 1,  5, 6, 68, 0, 48, 8, 55, 2, 52, 4, 33, 5, 41, 
    2, 64, 1, 78, 4,  5, 0, 37, 3, 12, 6, 54, 8, 16, 5, 79, 7, 50, 
    5, 62, 7,  1, 8, 86, 4, 70, 2, 21, 0,  9, 1, 73, 3, 95, 6, 35, 
    5, 31, 1, 87, 4, 79, 8, 94, 7, 12, 2, 56, 0, 60, 3, 16, 6, 85, 
    4, 83, 0, 62, 5, 87, 2, 23, 6, 62, 8, 63, 3, 53, 1, 99, 7,  9, 
    8, 63, 6, 78, 5, 82, 0, 50, 1, 96, 7, 47, 3, 59, 2, 21, 4, 23
  };
  const int q2776[] = {
    9, 9, // Number of jobs and machines
    0, 22, 3,  6, 8, 75, 1,  6, 5,  3, 7,  3, 6, 75, 2, 16, 4, 43, 
    4, 43, 3, 80, 1, 67, 2, 73, 7, 57, 0,  5, 8,  8, 6,  2, 5, 69, 
    0, 86, 3,  1, 6, 74, 1, 26, 4, 59, 7, 52, 8, 71, 5, 32, 2, 99, 
    6, 74, 1, 75, 7,  3, 3, 79, 4, 86, 0, 73, 5, 77, 8, 92, 2, 70, 
    4, 98, 3, 75, 0, 16, 6, 93, 8, 25, 5, 71, 2, 49, 1, 91, 7, 72, 
    7, 91, 1, 92, 3, 48, 4, 50, 8, 75, 2, 22, 0, 22, 5, 15, 6, 25, 
    2, 28, 5, 87, 6, 46, 4, 94, 0, 91, 3, 41, 7, 16, 1,  3, 8, 37, 
    1, 70, 3, 99, 0, 93, 5, 98, 7,  2, 8, 43, 2, 97, 4, 99, 6, 11, 
    3, 47, 1, 57, 8, 73, 5, 51, 4, 53, 0, 81, 7, 88, 6, 26, 2, 77
  };
  const int q2777[] = {
    9, 9, // Number of jobs and machines
    1, 22, 6,  5, 3, 31, 0, 11, 2, 43, 5, 90, 4, 20, 8, 33, 7, 84, 
    0, 75, 7, 71, 4, 48, 1, 27, 2, 51, 8, 66, 5, 75, 3, 98, 6, 15, 
    5, 15, 1, 31, 0, 41, 4, 98, 7, 19, 3, 91, 2, 50, 6, 92, 8, 38, 
    4, 61, 2, 57, 0,  7, 7, 74, 1,  5, 5, 40, 3, 39, 6, 11, 8, 26, 
    5, 66, 4, 59, 0, 69, 8, 24, 3, 27, 1,  1, 7,  6, 6, 36, 2, 16, 
    6, 31, 2, 10, 7, 28, 3, 75, 1, 75, 8, 67, 5, 90, 4, 28, 0, 44, 
    2, 98, 0, 86, 7, 65, 8, 29, 6, 81, 5, 68, 1, 92, 3, 16, 4, 99, 
    7, 73, 4, 34, 0, 91, 2, 69, 3, 87, 1,  1, 5, 81, 6, 79, 8, 18, 
    7, 21, 0, 81, 1, 74, 6,  2, 5, 13, 8, 15, 4, 91, 3, 20, 2, 31
  };
  const int q2778[] = {
    9, 9, // Number of jobs and machines
    7, 17, 5, 37, 2, 14, 3,  7, 6, 57, 4,  1, 8, 91, 1, 23, 0, 92, 
    4, 69, 7, 85, 0, 51, 2, 68, 5, 57, 1, 83, 6, 56, 3, 66, 8, 55, 
    4, 86, 3, 79, 5, 66, 2, 99, 6, 33, 7, 63, 0, 95, 8, 56, 1, 21, 
    7, 93, 1, 17, 8, 95, 0, 39, 2,  1, 3,  1, 5, 46, 6, 32, 4, 10, 
    1, 75, 8, 86, 5, 36, 4, 73, 3, 43, 2, 91, 0, 45, 6, 73, 7, 28, 
    7, 48, 4, 31, 2, 98, 3, 93, 5, 57, 0, 14, 1,  2, 6, 75, 8,  5, 
    7, 19, 6, 14, 1, 80, 3, 69, 4, 97, 2,  3, 0, 47, 5, 98, 8, 30, 
    0, 83, 5, 73, 1, 40, 4, 92, 2,  2, 6, 32, 8,  5, 7, 73, 3, 12, 
    0, 90, 7, 51, 3, 38, 2, 92, 1,  2, 4, 88, 5, 55, 8, 92, 6, 35
  };
  const int q2779[] = {
    9, 9, // Number of jobs and machines
    8, 47, 6, 19, 4, 99, 0, 65, 5, 39, 3, 13, 7, 88, 2, 48, 1, 92, 
    6, 60, 0, 48, 4, 53, 7, 57, 5, 32, 3, 64, 1, 44, 2, 98, 8, 73, 
    6, 26, 1, 92, 7, 41, 4, 93, 3, 81, 0, 37, 2, 93, 8, 37, 5, 82, 
    5, 69, 2, 68, 6, 76, 4, 61, 8, 10, 1, 83, 0, 85, 3, 48, 7, 49, 
    3, 61, 4, 80, 0, 57, 1, 62, 2, 60, 7, 51, 8,  2, 6,  1, 5, 74, 
    2, 46, 0, 91, 3, 59, 4, 98, 6, 81, 8, 31, 5, 77, 1, 12, 7, 12, 
    8, 73, 4, 38, 0, 42, 5, 83, 6, 51, 3, 71, 7,  8, 1, 25, 2, 74, 
    8, 34, 3, 31, 6, 36, 0, 32, 2, 20, 7, 29, 4, 59, 5, 37, 1, 60, 
    7, 74, 2, 13, 1, 40, 5, 20, 8, 69, 4, 98, 3, 29, 6, 34, 0, 54
  };
  const int q2780[] = {
    9, 9, // Number of jobs and machines
    3, 22, 7, 23, 4, 84, 6, 88, 1,  7, 2, 43, 8, 80, 0, 61, 5, 15, 
    5, 68, 2, 72, 1, 29, 6,  2, 7, 18, 3, 73, 4, 91, 0, 19, 8,  7, 
    6, 50, 0, 59, 5, 29, 3, 56, 4, 19, 2, 99, 7, 21, 1, 50, 8, 75, 
    1, 60, 2, 24, 8, 18, 0, 61, 7, 14, 5, 23, 3, 69, 4, 17, 6, 34, 
    5, 80, 2, 59, 4,  9, 3, 38, 7, 28, 6, 85, 8, 91, 1,  1, 0, 28, 
    7, 41, 0, 29, 6, 52, 8, 95, 3, 13, 4, 57, 5, 53, 1, 29, 2, 91, 
    5, 49, 0, 79, 4, 63, 6, 36, 2, 67, 7, 68, 8, 81, 1, 78, 3, 63, 
    4, 93, 7, 15, 1,  2, 8, 28, 6, 18, 0, 19, 3,  7, 5, 16, 2, 38, 
    7,  2, 0, 84, 3, 11, 4, 95, 8, 38, 5, 21, 6, 29, 1, 50, 2, 79
  };
  const int q2781[] = {
    9, 9, // Number of jobs and machines
    3,  5, 7, 94, 1, 38, 6,  1, 8, 42, 2, 83, 4, 84, 0, 69, 5, 88, 
    7, 36, 4, 17, 1, 37, 3, 43, 2, 68, 8, 59, 5, 81, 6, 26, 0, 79, 
    1, 10, 0, 65, 8, 30, 3, 91, 4, 40, 5, 94, 2, 51, 6, 68, 7, 16, 
    5, 42, 7, 88, 1, 49, 3, 46, 8, 78, 4, 36, 0, 94, 6, 52, 2,  6, 
    8, 38, 7, 96, 6, 21, 3, 78, 1, 78, 2, 92, 0, 34, 5, 26, 4, 93, 
    1,  3, 8,  7, 0, 16, 2, 93, 4, 86, 3, 61, 5, 44, 7, 25, 6, 62, 
    3, 18, 4, 65, 1, 36, 6, 26, 7, 25, 5, 85, 2, 35, 8, 20, 0, 23, 
    0,  9, 6, 41, 1, 19, 8, 55, 7, 63, 3, 71, 4, 69, 5, 23, 2, 20, 
    2, 43, 0, 17, 8,  4, 5, 51, 3, 71, 6, 59, 7, 36, 1, 14, 4, 49
  };
  const int q2782[] = {
    9, 9, // Number of jobs and machines
    4, 37, 3, 38, 5, 80, 0, 33, 6, 96, 1, 18, 2, 43, 8, 73, 7, 82, 
    7, 99, 6, 40, 8, 47, 1, 26, 5, 24, 4, 34, 2, 83, 3, 58, 0, 66, 
    6, 60, 8, 84, 2, 46, 0, 51, 3, 60, 5, 13, 7,  3, 4, 73, 1, 46, 
    2, 98, 1, 91, 5, 76, 6, 89, 8, 69, 3, 12, 7, 51, 4, 86, 0, 36, 
    6, 67, 4, 16, 7, 19, 0, 41, 2, 11, 3, 78, 1, 86, 5, 28, 8, 51, 
    7, 40, 2, 49, 8, 18, 4, 31, 1, 99, 3, 39, 6, 32, 0, 10, 5, 51, 
    4, 54, 6, 89, 3, 14, 5, 97, 0, 34, 1, 65, 7, 69, 8, 15, 2, 63, 
    4, 15, 7, 76, 1, 53, 0, 24, 8, 47, 3, 92, 5, 40, 2, 67, 6, 55, 
    3, 92, 0, 76, 7, 25, 4, 76, 8, 84, 6, 45, 1, 34, 5, 70, 2, 20
  };
  const int q2783[] = {
    9, 9, // Number of jobs and machines
    1, 81, 4, 99, 6, 37, 3, 83, 8, 40, 5, 99, 7, 27, 0, 68, 2, 74, 
    4, 71, 8, 42, 5, 94, 2, 51, 6, 67, 7, 65, 0,  1, 3, 72, 1, 18, 
    4, 31, 5, 53, 0, 80, 8, 65, 1, 17, 6, 69, 7, 68, 3, 54, 2, 10, 
    1, 71, 5, 71, 8, 57, 0, 23, 2, 39, 7, 15, 6, 38, 4, 83, 3, 57, 
    2, 54, 3,  9, 8, 68, 1, 52, 5, 27, 6, 43, 0, 44, 4, 31, 7, 84, 
    3, 92, 2, 82, 1, 86, 8, 29, 4, 15, 6, 67, 5, 15, 0, 68, 7, 89, 
    1, 44, 6, 39, 4, 86, 3, 51, 7, 31, 2, 71, 5, 32, 0, 11, 8, 32, 
    0, 31, 3,  6, 4, 85, 5, 94, 1, 83, 7, 95, 8, 44, 2, 90, 6, 77, 
    4, 52, 0, 41, 2, 51, 1, 95, 7, 67, 8, 69, 5, 44, 3, 66, 6, 52
  };
  const int q2784[] = {
    9, 9, // Number of jobs and machines
    0, 35, 5,  7, 6, 41, 3, 97, 1, 30, 2, 10, 7, 31, 4, 36, 8, 17, 
    1, 99, 7,  5, 2, 24, 6, 12, 4, 88, 8, 56, 0, 14, 5, 17, 3, 91, 
    6, 73, 2, 98, 3, 71, 5, 38, 7, 34, 0, 47, 4, 92, 8, 76, 1, 42, 
    5, 23, 3, 10, 4, 68, 6, 12, 8, 36, 0, 92, 1, 30, 7, 14, 2, 17, 
    3, 83, 4, 11, 5, 25, 2, 20, 8, 15, 6, 38, 0, 26, 7, 22, 1, 57, 
    2, 21, 7, 24, 1, 94, 4, 16, 5,  2, 6, 78, 8, 41, 3, 73, 0, 81, 
    4,  3, 0, 39, 5, 51, 7, 63, 8, 60, 3, 29, 2, 86, 1, 95, 6, 68, 
    5, 31, 0, 48, 8, 32, 2, 72, 3, 41, 1, 17, 4, 43, 7, 60, 6, 58, 
    5, 76, 2,  8, 7, 31, 6, 65, 8, 60, 0, 98, 3, 29, 1, 29, 4, 82
  };
  const int q2785[] = {
    9, 9, // Number of jobs and machines
    2, 49, 5, 60, 4, 10, 1,  8, 6, 90, 7, 79, 8,  8, 0,  1, 3, 70, 
    1, 75, 2,  7, 5, 90, 3, 13, 8, 96, 0, 67, 4, 57, 7,  2, 6, 26, 
    8, 91, 3, 37, 1, 63, 2,  2, 7,  3, 4, 86, 0, 97, 5, 33, 6, 49, 
    3, 27, 4, 45, 1, 86, 2, 64, 6, 42, 5, 92, 0, 69, 8, 46, 7,  8, 
    8, 74, 3, 43, 0, 84, 6, 27, 7, 72, 1, 20, 5, 14, 2, 65, 4, 31, 
    8, 30, 4, 50, 2,  1, 5, 73, 6, 14, 1, 11, 0, 61, 7, 74, 3, 48, 
    4, 25, 7, 59, 1,  2, 5, 41, 6, 31, 3, 74, 0,  3, 2, 74, 8, 18, 
    6, 13, 7, 57, 3, 47, 5, 17, 1, 21, 8, 86, 2, 73, 0, 32, 4, 75, 
    3, 11, 1, 74, 8, 98, 7, 17, 0, 96, 2, 73, 4, 66, 5, 80, 6, 78
  };
  const int q2786[] = {
    9, 9, // Number of jobs and machines
    7, 69, 0, 14, 6, 57, 2, 29, 3, 37, 1, 72, 5, 64, 4, 29, 8, 83, 
    1, 77, 5, 86, 2, 97, 7, 40, 0, 68, 8, 12, 3,  1, 4, 99, 6, 34, 
    4, 36, 6, 69, 1, 22, 0, 87, 3, 40, 5, 52, 7, 58, 8, 45, 2, 45, 
    4,  1, 8, 63, 6, 96, 2, 72, 1, 73, 5, 70, 7, 64, 3, 90, 0, 43, 
    4, 18, 6, 27, 3, 22, 0,  5, 7,  4, 5, 69, 8, 56, 1, 95, 2, 88, 
    4,  6, 0, 53, 8,  4, 6, 70, 2, 24, 5,  5, 1,  7, 3, 37, 7, 70, 
    3, 70, 6, 81, 7, 29, 4, 97, 2, 97, 8, 73, 0, 99, 1, 78, 5, 20, 
    5, 96, 3, 50, 7, 71, 1, 67, 0, 56, 4, 64, 6, 67, 2, 16, 8, 63, 
    5, 40, 4, 28, 1,  1, 8, 37, 6, 86, 3, 27, 2, 80, 0, 40, 7, 48
  };
  const int q2787[] = {
    9, 9, // Number of jobs and machines
    8, 10, 7, 50, 5, 45, 3, 33, 4,  1, 2, 88, 1, 40, 6, 22, 0, 64, 
    5, 99, 6, 86, 4, 11, 7, 38, 2, 82, 0, 82, 1, 19, 3, 17, 8,  2, 
    1, 39, 8, 79, 5, 99, 6, 20, 7, 47, 4, 13, 3, 82, 0, 10, 2, 45, 
    0, 84, 2, 18, 5, 37, 3, 19, 8, 87, 4, 83, 6, 99, 1, 56, 7, 83, 
    2, 65, 0,  3, 1, 68, 4, 24, 7, 44, 8, 72, 5, 72, 3, 83, 6, 11, 
    0, 38, 5, 58, 8, 61, 2, 40, 1,  8, 3, 49, 4, 14, 7, 89, 6, 89, 
    5, 61, 4, 37, 0, 67, 7, 73, 1, 23, 3, 84, 8,  4, 2, 93, 6, 63, 
    6, 27, 8, 15, 3, 12, 1, 54, 7, 81, 4, 31, 2, 51, 0, 37, 5, 60, 
    1, 32, 6, 63, 8, 68, 2,  1, 7,  5, 4, 62, 3,  2, 0, 84, 5, 41
  };
  const int q2788[] = {
    9, 9, // Number of jobs and machines
    1, 17, 3, 83, 7, 52, 0, 34, 8, 47, 6, 67, 2, 86, 4, 20, 5, 92, 
    8, 13, 4, 35, 2, 84, 7, 97, 6, 87, 0, 67, 5,  4, 3, 64, 1, 42, 
    0, 75, 6,  1, 1, 90, 8,  2, 5, 34, 7, 69, 4, 58, 3, 29, 2, 96, 
    7, 56, 6, 55, 8, 56, 3, 56, 1, 36, 0, 68, 4, 66, 2, 20, 5, 70, 
    5, 97, 8, 92, 0, 55, 1,  7, 7,  5, 3, 16, 4, 86, 6, 60, 2, 54, 
    3, 24, 8, 78, 7, 24, 1,  9, 5, 98, 6,  4, 4, 83, 2, 57, 0, 84, 
    1, 33, 3, 72, 6, 18, 0,  1, 8, 98, 4, 36, 5, 36, 7, 43, 2, 92, 
    2, 90, 3, 81, 6, 50, 5, 71, 4, 26, 1, 57, 8, 21, 7, 79, 0, 80, 
    2,  2, 6, 28, 7, 43, 4, 67, 0, 14, 8,  8, 1, 78, 5, 93, 3, 56
  };
  const int q2789[] = {
    9, 9, // Number of jobs and machines
    3, 89, 2, 75, 1, 74, 8, 17, 6, 37, 4, 97, 0, 56, 7, 75, 5, 91, 
    1,  5, 7, 59, 6, 26, 0, 44, 8, 66, 4, 14, 3, 23, 2, 75, 5, 91, 
    4, 52, 3, 22, 2, 67, 5, 66, 7, 50, 0, 94, 8, 48, 6, 49, 1, 92, 
    6, 94, 1, 60, 7, 80, 8, 97, 2, 18, 3, 61, 5, 29, 4, 41, 0, 22, 
    1, 51, 7, 43, 3, 33, 2, 49, 5, 67, 8, 22, 0, 50, 6, 29, 4, 59, 
    3, 79, 7, 72, 2, 44, 6, 19, 4, 27, 1, 98, 0, 32, 5, 81, 8, 80, 
    6,  5, 4, 31, 8, 45, 7, 74, 2, 21, 3, 14, 1, 23, 5, 80, 0, 12, 
    1, 56, 2, 60, 0, 52, 5,  8, 3, 44, 4, 17, 8, 22, 7, 19, 6, 43, 
    7, 50, 0, 77, 2, 62, 4, 46, 3,  9, 1, 10, 5, 43, 8, 30, 6, 14
  };
  const int q2790[] = {
    9, 9, // Number of jobs and machines
    1, 60, 8, 82, 0, 76, 5, 85, 3, 80, 4, 58, 7, 99, 2, 70, 6, 39, 
    1,  4, 3, 82, 5, 11, 8, 46, 7, 40, 2, 74, 4, 66, 0, 14, 6, 74, 
    1, 18, 8, 87, 6, 71, 0, 68, 7, 27, 5, 47, 4, 71, 2, 40, 3, 44, 
    3, 51, 0, 60, 2, 59, 5, 96, 7, 15, 1, 15, 4, 47, 8,  6, 6, 19, 
    6, 20, 4, 28, 7,  2, 2, 24, 8, 44, 1, 88, 5, 30, 0, 47, 3, 62, 
    7, 84, 8, 54, 5, 29, 3, 41, 4, 80, 6, 30, 2, 95, 0, 27, 1, 65, 
    0,  2, 3, 87, 8, 85, 4, 20, 1, 61, 2, 40, 6, 20, 7,  9, 5, 57, 
    7,  4, 1, 59, 3, 37, 6, 58, 8, 19, 0, 85, 4, 90, 2, 19, 5, 89, 
    4, 27, 1, 53, 3, 51, 8, 20, 6, 74, 5,  5, 2, 74, 0, 35, 7, 95
  };
  const int q2791[] = {
    9, 9, // Number of jobs and machines
    2, 21, 5, 86, 0,  3, 8, 23, 4, 52, 6, 66, 7, 86, 1, 77, 3, 72, 
    2,  6, 7, 28, 3, 51, 6, 95, 5, 17, 8, 75, 0, 19, 4, 97, 1,  7, 
    7, 46, 3, 36, 1, 51, 8, 27, 2, 60, 0, 37, 4, 32, 6, 88, 5, 54, 
    6, 99, 1, 97, 5, 42, 3, 11, 0, 23, 7, 33, 8, 65, 4, 99, 2, 14, 
    6, 35, 5, 27, 7, 71, 0, 21, 8, 47, 1, 57, 3, 25, 4, 19, 2, 59, 
    1, 94, 0, 49, 3, 24, 2,  4, 4, 45, 8, 23, 7, 32, 5, 25, 6, 64, 
    6, 48, 5, 93, 7, 57, 1, 78, 3, 77, 2, 12, 8, 82, 0, 62, 4, 54, 
    3, 25, 1, 58, 6, 43, 0, 43, 2, 36, 4, 89, 7, 77, 8, 72, 5, 79, 
    6, 61, 7, 35, 1,  7, 8, 62, 0, 81, 5, 22, 3, 44, 2, 62, 4, 68
  };
  const int q2792[] = {
    9, 9, // Number of jobs and machines
    5,  3, 3,  8, 8, 34, 0, 70, 4, 16, 7, 86, 1, 50, 6, 80, 2, 77, 
    0, 70, 2, 46, 8, 43, 3, 33, 6, 70, 5, 66, 1, 61, 4,  9, 7, 46, 
    8, 54, 1, 62, 7, 28, 0, 89, 4, 38, 3, 60, 2, 11, 5, 18, 6, 89, 
    4, 66, 8, 34, 5, 25, 1, 83, 7, 72, 0, 76, 3, 22, 2, 73, 6, 25, 
    5, 58, 3, 78, 8, 20, 1, 38, 7, 15, 0, 91, 6, 57, 2, 11, 4,  4, 
    4, 99, 2, 92, 0, 86, 8, 18, 1, 39, 3, 78, 6, 94, 7, 26, 5, 36, 
    3,  8, 0, 74, 4, 94, 6, 80, 7, 46, 5, 16, 8, 11, 1, 27, 2, 78, 
    7, 37, 1, 60, 3, 41, 5, 32, 2, 67, 6, 36, 0, 27, 8, 25, 4, 48, 
    8, 99, 6, 27, 4, 83, 0, 35, 2, 57, 1, 90, 5, 85, 7, 22, 3, 41
  };
  const int q2793[] = {
    9, 9, // Number of jobs and machines
    3, 23, 7, 83, 2, 62, 0, 33, 6, 69, 1, 98, 5, 29, 8, 25, 4, 60, 
    1, 35, 7, 18, 4, 92, 2, 89, 3, 12, 0, 58, 8, 47, 6, 85, 5, 45, 
    8, 18, 7, 91, 6, 88, 3, 57, 4, 91, 5,  7, 0, 42, 1, 30, 2, 68, 
    1, 93, 5, 69, 4, 82, 6, 79, 8, 21, 3, 50, 2, 13, 7, 10, 0, 36, 
    5, 91, 4, 95, 3, 91, 1, 18, 8, 67, 2, 62, 0, 13, 7, 54, 6, 27, 
    7, 29, 1, 15, 3, 12, 5, 97, 6, 71, 8, 42, 0, 43, 2, 20, 4, 30, 
    4, 66, 8, 87, 5, 35, 7, 12, 1, 81, 6, 25, 0, 15, 2, 68, 3, 36, 
    5, 96, 2, 89, 1, 35, 6, 17, 4, 75, 8,  2, 7,  8, 3, 81, 0, 60, 
    0, 25, 7, 49, 8, 49, 4, 13, 3,  2, 2, 75, 5, 42, 6, 32, 1, 24
  };
  const int q2794[] = {
    9, 9, // Number of jobs and machines
    5, 47, 3, 81, 4, 57, 2, 49, 0, 68, 8, 95, 7, 21, 1, 86, 6, 93, 
    3, 56, 1, 76, 7, 95, 5, 95, 0, 22, 8,  3, 2, 85, 4, 53, 6, 15, 
    4, 38, 8, 58, 2,  6, 5, 68, 3, 97, 7, 62, 0, 10, 6,  8, 1, 43, 
    4, 85, 3, 73, 5, 27, 1, 30, 2,  9, 6, 39, 7, 49, 8, 44, 0, 28, 
    8, 91, 4, 14, 7,  7, 0, 25, 6, 66, 5,  9, 3, 92, 1, 62, 2, 74, 
    1, 97, 3, 45, 2, 52, 0, 23, 7,  7, 4, 22, 6, 27, 5, 41, 8,  1, 
    6, 68, 3, 54, 4, 25, 1, 69, 8, 92, 7,  8, 0,  9, 2, 78, 5, 22, 
    1, 86, 5, 80, 3, 53, 6, 38, 8, 27, 0, 66, 4, 64, 2, 27, 7, 29, 
    8, 57, 1, 41, 7, 78, 5, 55, 2, 90, 6, 15, 3, 42, 0, 79, 4, 62
  };
  const int q2795[] = {
    9, 9, // Number of jobs and machines
    3, 23, 0, 53, 2, 74, 5, 42, 7, 39, 1, 19, 4, 44, 8, 83, 6, 60, 
    4, 96, 3, 31, 2, 51, 8, 93, 5, 25, 0, 32, 6, 96, 7, 47, 1, 15, 
    3, 35, 7, 52, 2, 63, 1, 70, 8, 25, 5, 90, 6, 87, 4, 84, 0, 71, 
    7,  2, 6, 96, 0, 71, 2, 30, 8, 61, 3, 94, 1,  2, 5, 44, 4, 79, 
    3,  3, 4, 16, 6, 52, 8, 16, 1, 50, 7,  6, 5, 94, 0, 77, 2, 63, 
    8, 25, 6,  4, 5, 27, 0, 97, 2, 69, 4, 16, 3, 69, 1, 72, 7, 83, 
    8, 97, 3, 45, 2,  3, 7, 23, 4, 33, 6, 83, 0, 68, 5, 50, 1, 53, 
    2,  4, 3, 41, 5, 84, 4, 84, 7, 81, 0, 22, 6, 90, 1, 53, 8, 80, 
    0, 42, 3, 25, 6, 80, 7, 22, 1, 46, 2, 47, 8, 43, 5, 95, 4, 31
  };
  const int q2796[] = {
    9, 9, // Number of jobs and machines
    8, 92, 7, 60, 6, 13, 4, 76, 2, 92, 3, 43, 0, 30, 1, 41, 5, 94, 
    2, 22, 5, 61, 4, 18, 6, 37, 3, 83, 7, 81, 0, 90, 8, 18, 1, 50, 
    6, 50, 3, 61, 0, 47, 7, 35, 2, 71, 4,  8, 1, 43, 5, 48, 8, 67, 
    8, 21, 7, 36, 2, 33, 3, 35, 6, 23, 4, 19, 1, 88, 0, 60, 5, 30, 
    8, 98, 1, 25, 3, 66, 4, 57, 6, 69, 2,  5, 5, 56, 7, 49, 0, 83, 
    2, 53, 8, 76, 6, 91, 3, 57, 4, 93, 0, 12, 7, 98, 1, 97, 5, 11, 
    5, 18, 4, 27, 8, 89, 0, 81, 2, 40, 3, 47, 7, 48, 1, 34, 6, 30, 
    5, 19, 4, 49, 3, 66, 1, 89, 8, 10, 7, 59, 0, 52, 6, 54, 2, 57, 
    4, 52, 8, 70, 7, 93, 5, 18, 0,  5, 3, 70, 6,  6, 1, 73, 2, 45
  };
  const int q2797[] = {
    9, 9, // Number of jobs and machines
    6, 39, 5, 16, 8, 86, 7, 70, 2, 75, 3,  1, 1, 64, 0, 55, 4, 55, 
    3, 89, 0, 73, 7, 29, 5, 22, 2, 52, 1, 68, 4, 49, 6, 46, 8, 89, 
    8, 56, 5, 31, 0, 87, 4, 21, 3, 61, 2,  9, 1, 22, 7,  2, 6, 60, 
    0, 23, 2, 91, 3, 59, 4, 63, 8, 90, 1, 52, 7, 47, 5, 78, 6, 70, 
    6,  4, 5, 45, 8, 74, 1,  9, 3, 77, 4, 99, 0, 23, 2, 53, 7, 13, 
    5, 94, 0, 34, 8, 73, 6, 55, 1,  4, 4, 75, 3, 47, 2,  2, 7, 85, 
    1, 81, 4, 80, 8, 33, 3, 22, 2, 36, 0, 81, 5, 45, 7, 42, 6, 57, 
    2, 72, 7, 84, 6, 35, 8, 34, 3, 39, 1, 77, 4, 53, 5,  9, 0, 47, 
    6, 83, 8,  4, 4, 38, 1,  7, 3,  6, 7, 37, 5, 36, 0,  6, 2, 18
  };
  const int q2798[] = {
    9, 9, // Number of jobs and machines
    3, 54, 7, 34, 1, 36, 6, 12, 8, 42, 4, 94, 5, 28, 0, 39, 2, 86, 
    7, 31, 4, 82, 2, 77, 0, 32, 5, 26, 6, 49, 8, 37, 1, 27, 3, 31, 
    5, 57, 3, 99, 1, 31, 7,  3, 8, 85, 6, 81, 4, 99, 2, 14, 0, 42, 
    5,  1, 6, 33, 1, 67, 3, 11, 2, 96, 0,  3, 4, 23, 8, 96, 7, 36, 
    2, 23, 8, 13, 6, 92, 3, 51, 1, 16, 4, 54, 5, 79, 0, 93, 7,  3, 
    0, 90, 4, 79, 3, 25, 7,  8, 1, 20, 5, 98, 2, 10, 8, 88, 6, 55, 
    4,  1, 2, 60, 7, 82, 3, 13, 0, 15, 6, 68, 5, 90, 1, 43, 8, 19, 
    2, 58, 6, 33, 1, 80, 3, 70, 4, 35, 5, 46, 8, 48, 7, 39, 0, 63, 
    8, 70, 5, 56, 3, 43, 1, 21, 7, 87, 2, 63, 0, 32, 6, 21, 4, 92
  };
  const int q2799[] = {
    9, 9, // Number of jobs and machines
    6, 15, 5, 21, 1, 60, 3, 44, 0, 51, 8, 37, 4, 20, 2, 68, 7, 51, 
    2, 40, 8, 83, 3,  8, 4, 82, 1, 81, 5, 20, 6,  5, 0, 15, 7, 21, 
    0, 22, 6, 69, 8, 77, 2, 64, 1, 48, 5, 35, 7, 24, 3, 74, 4, 84, 
    2, 69, 6, 57, 1, 44, 5, 22, 8, 43, 4, 67, 0, 22, 3, 95, 7, 22, 
    8, 45, 6, 12, 4, 57, 1, 76, 3, 57, 2, 40, 7, 60, 5,  2, 0, 27, 
    1, 91, 2, 17, 5, 26, 8, 36, 0, 12, 6, 86, 4, 37, 3,  4, 7, 25, 
    6, 75, 5, 10, 8,  5, 7, 91, 0, 29, 3, 30, 1, 18, 2, 87, 4, 67, 
    6, 71, 8, 61, 0, 95, 7,  8, 2, 27, 1, 21, 3, 72, 4, 14, 5, 17, 
    7, 49, 3, 22, 2, 88, 1, 90, 8, 23, 6, 57, 5, 83, 0, 82, 4,  3
  };
  const int q2800[] = {
    9, 9, // Number of jobs and machines
    1, 80, 5, 99, 3, 52, 6, 73, 2, 92, 7, 72, 8, 33, 4, 85, 0, 94, 
    5, 59, 3, 12, 4,  6, 7, 94, 6, 22, 2, 16, 0, 82, 1, 33, 8, 30, 
    3, 27, 0,  3, 6, 50, 8, 16, 4, 30, 7, 62, 2, 36, 5, 35, 1, 74, 
    0, 32, 7, 74, 5, 74, 3, 67, 4, 92, 6, 35, 2, 24, 1, 93, 8, 88, 
    2, 79, 5, 33, 1, 68, 4,  6, 6, 97, 0, 99, 8,  9, 3, 74, 7, 64, 
    0, 13, 2, 88, 4, 76, 5, 91, 1, 78, 8, 58, 7, 73, 3, 75, 6, 45, 
    7, 96, 0, 41, 1, 36, 3, 71, 2, 31, 5, 88, 6,  5, 8, 26, 4,  7, 
    5, 31, 6, 15, 4, 24, 0,  5, 1,  1, 2, 61, 8,  3, 7, 69, 3, 12, 
    8, 85, 6, 67, 0, 80, 4, 96, 5, 72, 7, 35, 2, 34, 3, 59, 1, 46
  };
  const int q2801[] = {
    9, 9, // Number of jobs and machines
    4, 61, 0, 25, 5, 48, 6, 23, 2,  2, 7, 32, 3, 87, 8, 76, 1, 64, 
    2, 21, 8,  8, 4, 74, 6, 58, 3, 15, 5, 49, 1, 66, 7, 65, 0, 13, 
    4, 17, 7, 98, 8,  2, 5, 99, 2, 70, 6, 76, 1, 56, 3, 34, 0, 32, 
    6, 89, 4, 39, 7, 94, 2, 58, 8, 55, 5, 91, 3, 81, 1, 80, 0, 64, 
    5, 90, 6, 12, 1, 45, 7, 21, 8, 80, 2, 99, 4, 99, 0, 78, 3,  5, 
    4, 90, 7, 46, 3,  1, 6, 20, 1, 53, 0,  7, 5, 72, 8, 26, 2, 68, 
    7, 57, 1, 20, 4, 41, 5,  4, 3, 80, 2, 24, 0, 93, 8, 68, 6, 45, 
    7, 50, 3, 86, 1, 98, 0, 34, 6, 28, 5, 13, 8, 40, 2, 30, 4, 49, 
    2, 51, 6, 48, 4, 33, 7, 90, 3, 18, 5, 69, 0,  5, 1, 56, 8, 13
  };
  const int q2802[] = {
    9, 9, // Number of jobs and machines
    8, 74, 6,  4, 7, 56, 5, 83, 2, 26, 3,  8, 0, 12, 4, 10, 1, 57, 
    6, 60, 2, 95, 8, 15, 5, 34, 7,  7, 3, 30, 1, 23, 0, 16, 4, 97, 
    4, 87, 0, 29, 8, 63, 6, 76, 5,  3, 7, 61, 3, 28, 1, 26, 2, 23, 
    2, 74, 7, 78, 3, 22, 6, 12, 4, 73, 1, 26, 8, 40, 0, 31, 5, 56, 
    7, 14, 8, 38, 4, 16, 5, 61, 6, 72, 1, 48, 2, 70, 0, 53, 3, 96, 
    3, 51, 7, 88, 1, 56, 0,  1, 5, 93, 4, 59, 6, 95, 8, 11, 2,  4, 
    0, 79, 2, 23, 4, 10, 8, 84, 3, 93, 5,  3, 6, 91, 7, 45, 1, 25, 
    0, 99, 6, 79, 2, 76, 4, 84, 3, 44, 1, 63, 8, 60, 7, 58, 5, 22, 
    8, 66, 1, 96, 3, 15, 5, 37, 2, 52, 7, 86, 4, 39, 0, 65, 6, 19
  };
  const int q2803[] = {
    9, 9, // Number of jobs and machines
    5, 30, 0, 86, 3, 87, 6, 55, 4,  1, 7, 35, 2, 64, 1, 88, 8, 52, 
    3,  4, 6, 41, 1, 21, 2, 93, 0, 87, 7, 91, 5, 58, 8, 90, 4, 30, 
    6, 77, 8, 23, 2, 37, 5, 87, 0, 77, 3, 28, 7, 89, 1,  5, 4, 16, 
    0, 33, 4,  7, 5, 95, 8, 34, 7, 93, 2, 71, 3, 52, 6, 20, 1, 84, 
    2, 91, 5, 69, 8, 18, 6, 32, 0, 28, 4, 37, 3, 34, 7,  4, 1, 53, 
    5, 83, 6, 36, 4, 12, 3, 92, 7, 11, 2, 87, 1, 99, 0, 17, 8, 61, 
    4, 83, 5, 80, 0, 89, 2,  1, 7, 91, 3, 22, 6, 69, 1, 84, 8, 34, 
    7, 96, 4, 31, 5, 66, 2, 44, 1, 93, 8, 49, 6, 93, 0,  5, 3, 27, 
    3, 94, 7, 21, 1, 21, 4, 97, 2, 33, 6, 53, 5, 82, 8, 75, 0, 99
  };
  const int q2804[] = {
    9, 9, // Number of jobs and machines
    2, 39, 3, 40, 4, 55, 6, 70, 5, 62, 0, 15, 8, 53, 1, 60, 7, 14, 
    4, 91, 5, 48, 8, 54, 7, 77, 6, 60, 3,  8, 0, 77, 2, 11, 1, 45, 
    7, 97, 4, 46, 8, 11, 5, 41, 1, 87, 6, 74, 2, 49, 0, 64, 3, 44, 
    2, 26, 5, 51, 1, 76, 0, 42, 3, 29, 8, 19, 4,  5, 7, 79, 6, 98, 
    2,  7, 6, 58, 5, 75, 8, 94, 0, 99, 7, 75, 3, 21, 4,  2, 1, 80, 
    4, 71, 8, 58, 6, 18, 1, 99, 3, 74, 5, 15, 2, 88, 0, 11, 7, 28, 
    8, 61, 0, 57, 4, 46, 1, 19, 3, 52, 6, 80, 7, 92, 5, 91, 2, 89, 
    6, 96, 3,  4, 5, 45, 0, 94, 4,  5, 2, 61, 7, 80, 8, 31, 1, 12, 
    7, 30, 6, 20, 0, 68, 3, 70, 5, 80, 8, 26, 1, 69, 2, 95, 4, 75
  };
  const int q2805[] = {
    9, 9, // Number of jobs and machines
    7, 68, 8, 17, 6, 26, 3,  6, 2, 25, 1, 42, 5, 10, 0, 36, 4, 59, 
    7, 53, 4, 18, 0, 47, 8, 34, 2,  7, 6, 51, 5, 50, 1,  8, 3, 21, 
    3, 64, 7, 92, 8, 38, 4, 29, 0, 92, 6, 99, 1, 85, 2, 87, 5, 84, 
    6, 34, 4,  2, 8, 34, 0, 65, 3, 70, 1, 47, 5, 52, 7, 43, 2, 38, 
    1, 52, 6, 61, 4, 97, 5, 81, 8, 65, 3, 15, 0, 74, 7, 40, 2, 56, 
    3, 19, 4, 61, 2, 45, 0,  8, 6, 87, 1, 11, 8, 60, 7, 27, 5, 40, 
    3,  7, 2,  7, 1, 86, 0, 69, 5, 78, 7, 27, 4, 17, 8, 97, 6, 26, 
    2,  1, 6, 58, 0, 86, 1,  9, 3, 28, 4, 27, 8, 13, 7, 52, 5, 90, 
    7, 75, 1, 78, 8, 52, 5, 46, 4, 81, 0, 14, 2, 35, 3, 71, 6, 34
  };
  const int q2806[] = {
    9, 9, // Number of jobs and machines
    3, 17, 6, 13, 2, 62, 0, 19, 4, 39, 8, 18, 1, 32, 7, 56, 5, 38, 
    1, 14, 5, 52, 8, 93, 7,  9, 0,  8, 3, 66, 2, 25, 4, 88, 6, 35, 
    1, 37, 8, 15, 6, 95, 4, 37, 3, 38, 7, 55, 2, 71, 0, 80, 5, 29, 
    3, 16, 7, 50, 8, 57, 0, 71, 4, 15, 5, 77, 6, 40, 2, 29, 1, 58, 
    1, 37, 6, 60, 4, 11, 8,  7, 3, 55, 7,  3, 0, 89, 5, 62, 2, 67, 
    5, 45, 7, 50, 4, 30, 1, 62, 6, 13, 8, 59, 3, 21, 0, 57, 2,  7, 
    5, 36, 0, 55, 8, 33, 7, 15, 2, 80, 6,  5, 1, 72, 3, 68, 4, 26, 
    7, 95, 2, 88, 3, 40, 5, 20, 8, 94, 6, 10, 0, 69, 1, 48, 4, 71, 
    2, 93, 3, 73, 6, 98, 7, 73, 0, 88, 4, 66, 1,  5, 5, 31, 8, 89
  };
  const int q2807[] = {
    9, 9, // Number of jobs and machines
    8, 37, 2, 53, 3, 14, 6, 24, 1, 38, 0, 21, 5, 29, 4, 79, 7, 14, 
    0, 33, 4, 79, 6, 16, 1, 84, 8, 97, 3, 86, 7, 35, 5, 43, 2, 22, 
    4, 48, 5, 15, 8, 79, 7, 52, 0, 58, 2, 49, 3, 12, 6, 87, 1, 37, 
    2, 75, 1, 48, 7, 14, 0, 97, 3, 28, 8, 92, 6, 10, 4, 98, 5, 33, 
    5, 38, 3, 30, 1, 85, 6, 84, 8, 61, 2, 36, 0, 29, 7, 35, 4, 51, 
    6, 57, 1, 30, 3, 83, 0, 78, 7, 86, 8, 47, 2, 62, 4, 45, 5, 67, 
    5, 72, 7, 15, 1, 33, 4, 96, 3, 85, 0, 24, 2, 41, 6, 16, 8, 31, 
    8, 22, 4, 26, 1, 29, 2, 71, 7, 72, 6, 35, 5, 86, 3, 38, 0, 53, 
    2, 67, 5,  9, 7, 82, 4, 89, 8, 13, 3, 76, 1, 67, 6, 21, 0, 48
  };
  const int q2808[] = {
    9, 9, // Number of jobs and machines
    5, 22, 6, 26, 1, 68, 3, 40, 0, 78, 2, 82, 8, 52, 4, 96, 7, 96, 
    5, 97, 6, 10, 1, 29, 7, 24, 3, 51, 0, 46, 2, 31, 4, 28, 8, 17, 
    4,  2, 2, 75, 5, 45, 0, 38, 8, 74, 6, 83, 3, 66, 7, 93, 1, 38, 
    1, 55, 4, 20, 7,  6, 2, 43, 3, 95, 8, 50, 0, 36, 5, 24, 6, 39, 
    1, 34, 2, 33, 3, 23, 7, 94, 4, 75, 6, 35, 0, 15, 8, 55, 5, 73, 
    2, 76, 3, 87, 8, 20, 6, 27, 4, 78, 7, 53, 1, 42, 0, 56, 5, 39, 
    6, 27, 5, 58, 7, 79, 8, 32, 1, 94, 2,  8, 4, 52, 3, 26, 0, 43, 
    3, 62, 6, 56, 7, 76, 5, 35, 4, 99, 0, 81, 2, 21, 8, 15, 1, 60, 
    4, 76, 7, 65, 0, 13, 5, 57, 1,  2, 8, 38, 6, 11, 3, 57, 2, 83
  };
  const int q2809[] = {
    9, 9, // Number of jobs and machines
    6, 99, 5, 82, 7, 37, 8, 57, 3, 49, 2, 69, 4, 13, 0,  3, 1, 57, 
    1,  3, 5, 86, 3, 83, 7,  9, 8, 45, 4, 88, 6, 75, 2, 63, 0, 63, 
    7, 21, 1, 69, 2, 77, 6, 76, 8, 80, 3, 14, 4, 93, 0, 61, 5, 15, 
    5, 90, 7, 46, 6, 97, 8, 89, 1, 72, 0, 78, 2, 63, 3, 88, 4,  5, 
    5, 17, 3, 19, 0, 76, 1, 42, 8, 62, 2, 65, 4, 36, 6, 43, 7, 24, 
    3, 33, 2,  4, 1, 15, 4, 63, 5, 16, 7, 76, 0, 86, 6, 14, 8, 79, 
    5, 81, 7, 72, 4, 20, 6, 63, 0, 86, 8, 21, 3, 82, 1, 92, 2, 80, 
    1, 12, 3, 80, 6, 52, 8, 35, 7, 19, 0, 73, 4,  7, 5, 21, 2, 21, 
    1, 53, 3, 62, 0, 26, 8, 86, 4, 25, 2, 14, 7, 42, 6, 53, 5, 61
  };
  const int q2810[] = {
    9, 9, // Number of jobs and machines
    4, 34, 3, 63, 8, 75, 6, 41, 7, 75, 2, 78, 1, 40, 0, 20, 5,  6, 
    0, 71, 5, 20, 3,  5, 7, 78, 2, 20, 8, 48, 6, 47, 4, 48, 1, 29, 
    1, 80, 2, 32, 7, 67, 0, 20, 8, 39, 3, 54, 6, 91, 4, 81, 5, 39, 
    8, 89, 4, 47, 2, 10, 7, 82, 5, 90, 3, 55, 1, 54, 0, 85, 6, 38, 
    4, 26, 0, 84, 3, 53, 1, 96, 8, 59, 7, 70, 5, 71, 2, 21, 6, 57, 
    7, 67, 5, 29, 0, 63, 2, 13, 8, 97, 1, 28, 3, 43, 4,  4, 6, 34, 
    7, 58, 6, 75, 0, 90, 3, 32, 5, 84, 1, 90, 8, 39, 4, 91, 2, 69, 
    6, 55, 0, 61, 2, 33, 1, 20, 4, 67, 8,  5, 5, 33, 7, 59, 3, 85, 
    4, 17, 5, 88, 2, 12, 7, 34, 1, 28, 6, 31, 3, 65, 0, 20, 8, 43
  };
  const int q2811[] = {
    9, 9, // Number of jobs and machines
    1, 66, 6, 56, 3, 78, 4, 50, 2, 62, 5, 27, 0, 33, 8, 62, 7, 99, 
    6, 13, 5, 13, 2, 20, 4, 96, 7, 25, 1, 22, 3, 51, 8, 27, 0, 42, 
    6, 54, 2, 43, 5, 11, 1, 67, 3, 28, 0, 95, 4, 61, 7, 83, 8, 63, 
    6, 89, 8, 24, 4, 92, 7,  9, 1, 48, 3, 48, 2, 23, 0,  2, 5, 15, 
    2,  7, 1, 42, 5, 96, 0, 15, 7, 24, 6, 38, 4,  1, 3, 20, 8, 39, 
    8,  4, 5, 44, 2, 87, 0, 75, 7, 51, 1,  3, 3, 82, 4, 84, 6, 25, 
    8, 33, 0, 64, 7, 66, 4, 40, 1,  6, 2, 60, 5, 12, 3, 73, 6, 54, 
    8, 58, 0, 84, 6, 69, 4, 14, 7, 33, 5, 42, 1, 75, 3, 89, 2, 89, 
    4,  2, 3, 22, 7, 15, 6, 42, 0, 35, 2, 13, 5, 65, 8, 86, 1,  5
  };
  const int q2812[] = {
    9, 9, // Number of jobs and machines
    7, 21, 8, 59, 0, 24, 4, 65, 2, 52, 3, 75, 5, 46, 1, 73, 6, 23, 
    0, 56, 5,  1, 6, 13, 2, 99, 4, 83, 1, 86, 8, 25, 3, 61, 7, 88, 
    7, 41, 5, 63, 0, 40, 6, 58, 2, 26, 8, 36, 1, 67, 3, 16, 4, 62, 
    2, 80, 7, 35, 1,  1, 0, 73, 3, 52, 4, 51, 5, 74, 6, 94, 8, 10, 
    3, 47, 6, 32, 1, 44, 5, 36, 0, 56, 2, 42, 8, 88, 7, 48, 4,  1, 
    0, 70, 8, 93, 3, 85, 4, 47, 6, 88, 7, 87, 2, 79, 1, 80, 5, 14, 
    7, 74, 5, 19, 3, 53, 2, 25, 6, 58, 1, 51, 8, 28, 0, 73, 4,  8, 
    6, 72, 2, 38, 1, 79, 8, 33, 0, 56, 5, 89, 4, 16, 3, 54, 7, 98, 
    8, 68, 5, 45, 7, 88, 2, 53, 4, 11, 3, 41, 0,  5, 1, 58, 6, 51
  };
  const int q2813[] = {
    9, 9, // Number of jobs and machines
    7, 15, 1, 20, 5,  8, 8, 59, 6, 71, 4, 87, 3, 18, 2, 93, 0, 27, 
    6, 97, 0, 96, 4, 82, 2, 75, 7, 52, 8, 18, 3, 90, 1, 71, 5, 14, 
    3, 19, 2, 74, 4, 81, 8, 64, 7, 93, 0, 65, 6, 54, 1, 45, 5, 69, 
    4, 42, 2, 38, 0, 74, 8, 23, 3, 54, 1, 56, 6,  6, 7, 46, 5, 48, 
    3, 88, 4, 11, 5, 80, 2, 17, 0, 85, 7,  1, 6, 13, 1, 88, 8, 25, 
    7, 26, 0, 73, 3,  6, 4, 93, 1, 75, 8, 29, 5, 85, 2, 34, 6, 74, 
    5, 97, 4, 90, 8, 77, 7, 92, 3, 43, 2, 45, 6, 63, 0, 52, 1, 28, 
    2,  4, 5, 99, 0, 48, 1, 68, 3,  2, 4, 40, 6, 39, 7, 13, 8, 77, 
    2, 53, 0, 33, 7, 68, 4, 63, 6, 62, 8, 26, 1, 71, 3, 34, 5, 36
  };
  const int q2814[] = {
    9, 9, // Number of jobs and machines
    6, 73, 8, 23, 4, 27, 7, 56, 2, 43, 5, 90, 3,  4, 0, 83, 1, 44, 
    0, 24, 8, 58, 1, 99, 3, 80, 4, 64, 6, 75, 5, 53, 7, 14, 2, 75, 
    0, 34, 4, 62, 3, 30, 6, 82, 5, 36, 7, 37, 8, 20, 1, 26, 2, 64, 
    6, 95, 8, 72, 4, 82, 5, 85, 7,  9, 1, 35, 2, 27, 0, 99, 3, 85, 
    8, 89, 7, 90, 5,  3, 0, 74, 1, 60, 2, 62, 4, 83, 3, 15, 6, 52, 
    7, 50, 5, 20, 1, 44, 0, 84, 8, 78, 4, 43, 6, 73, 3, 56, 2, 58, 
    1, 34, 5, 88, 8, 14, 4, 39, 7, 36, 0, 91, 3, 56, 2, 29, 6, 86, 
    1, 22, 7, 77, 6, 54, 3, 56, 2, 53, 8, 62, 5,  9, 4, 18, 0, 85, 
    4, 48, 1,  6, 7, 44, 8, 20, 5, 26, 3, 24, 6, 81, 2,  1, 0, 98
  };
  const int q2815[] = {
    9, 9, // Number of jobs and machines
    5, 99, 8, 39, 3, 53, 7, 83, 2, 80, 4, 83, 1, 48, 6, 98, 0, 92, 
    6, 49, 3, 15, 0, 33, 5, 77, 4, 77, 1, 85, 7, 26, 2, 32, 8, 19, 
    4, 42, 3, 60, 1, 69, 6, 98, 7, 28, 5, 59, 2, 92, 8, 42, 0, 42, 
    3,  2, 7, 36, 1, 92, 6, 26, 5, 94, 4, 73, 0, 69, 2, 44, 8, 81, 
    8, 88, 3,  5, 1, 90, 6, 89, 4, 92, 5, 79, 7, 32, 0, 60, 2, 24, 
    2, 64, 8, 42, 3, 21, 4, 74, 5, 84, 7, 82, 6, 29, 1, 27, 0, 67, 
    4, 55, 1, 55, 5,  3, 8, 29, 3,  7, 7, 35, 0, 97, 6, 63, 2, 69, 
    1, 76, 0, 86, 7, 94, 5, 45, 6, 71, 4, 46, 8, 96, 3, 88, 2, 37, 
    4, 88, 8,  1, 3, 50, 2, 97, 0, 63, 7, 80, 6,  4, 1, 11, 5, 95
  };
  const int q2816[] = {
    9, 9, // Number of jobs and machines
    4, 80, 5,  6, 6, 74, 7, 32, 1, 14, 3, 19, 8, 84, 0, 81, 2, 51, 
    4, 58, 8, 35, 6, 82, 7, 87, 3, 68, 1, 55, 0, 99, 5,  5, 2, 86, 
    4, 30, 6, 13, 3, 35, 2, 76, 7, 80, 5, 37, 8, 27, 1, 63, 0,  2, 
    0,  3, 3, 50, 5, 98, 8, 20, 7,  7, 1, 91, 2, 49, 6, 11, 4, 32, 
    5, 57, 8, 59, 1, 19, 3, 73, 7, 11, 2, 41, 0, 55, 4, 10, 6, 67, 
    7, 60, 4, 99, 1, 45, 8, 82, 6, 65, 2, 12, 0, 83, 3, 31, 5, 84, 
    7,  2, 1, 19, 8, 62, 0, 47, 6, 29, 5, 28, 4,  8, 3, 44, 2, 11, 
    2, 97, 3,  8, 7, 31, 0, 53, 4, 10, 8, 61, 6, 18, 5, 24, 1, 84, 
    2, 90, 3, 76, 6, 98, 5, 80, 4, 55, 8, 64, 7, 27, 1, 58, 0,  5
  };
  const int q2817[] = {
    9, 9, // Number of jobs and machines
    5, 24, 8, 72, 4, 72, 7, 77, 1,  7, 3, 28, 6, 90, 2, 62, 0, 34, 
    8, 55, 5, 36, 1, 59, 7, 88, 0, 24, 2, 18, 6, 25, 4, 20, 3, 35, 
    1, 63, 2, 15, 4, 61, 7, 84, 6, 12, 8, 77, 5, 30, 0, 88, 3, 81, 
    4, 84, 0, 54, 7, 54, 3, 25, 6, 82, 5, 96, 1, 90, 8,  8, 2, 93, 
    0, 99, 7, 26, 8, 58, 5,  8, 3, 38, 2, 11, 4, 11, 6, 31, 1, 46, 
    0, 47, 5, 45, 1, 12, 2, 56, 7, 70, 8, 75, 6, 18, 3,  8, 4,  1, 
    0, 97, 2, 24, 4, 29, 8, 28, 1, 32, 6, 77, 5, 15, 3, 63, 7, 68, 
    4, 55, 3, 65, 1, 32, 0, 49, 5, 36, 8, 73, 2, 78, 6,  3, 7, 45, 
    1, 97, 4, 40, 5, 45, 7, 93, 8, 15, 2, 67, 6, 25, 0, 35, 3, 93
  };
  const int q2818[] = {
    9, 9, // Number of jobs and machines
    4,  1, 1, 16, 0, 37, 3, 36, 8, 76, 5, 58, 6, 17, 2, 72, 7,  3, 
    3, 66, 0, 43, 1, 67, 4, 77, 8, 54, 7, 19, 5, 86, 6, 20, 2, 29, 
    3, 85, 0, 66, 7, 25, 5, 36, 8, 88, 1, 82, 2, 25, 6, 68, 4, 19, 
    3, 91, 5,  3, 7, 75, 0, 17, 2, 34, 4, 46, 6, 24, 1, 70, 8, 33, 
    0,  5, 3, 95, 2, 12, 5, 50, 1, 12, 8, 96, 4,  3, 6, 48, 7, 56, 
    5, 34, 3, 67, 2,  5, 8, 59, 7, 59, 0, 31, 4, 92, 6, 14, 1, 76, 
    1, 13, 0, 69, 7, 89, 8, 54, 4, 50, 6, 45, 2, 22, 5, 67, 3, 52, 
    2, 60, 5, 62, 6,  6, 3, 29, 7, 32, 1, 20, 0, 96, 8, 38, 4, 18, 
    3, 86, 2, 97, 5, 96, 1,  5, 0, 35, 7, 25, 8, 97, 4, 98, 6, 43
  };
  const int q2819[] = {
    9, 9, // Number of jobs and machines
    1, 48, 0, 44, 2, 17, 6, 97, 4, 79, 5, 60, 3, 60, 8, 79, 7, 54, 
    7, 91, 2, 93, 3, 81, 4, 59, 1,  3, 6, 88, 5, 68, 8, 95, 0, 84, 
    4, 85, 5,  8, 6, 22, 8,  9, 2,  3, 0, 37, 1, 27, 7, 49, 3,  1, 
    0, 22, 4, 87, 1, 73, 6, 97, 8, 36, 5, 28, 3, 90, 2, 89, 7, 10, 
    2, 63, 3, 81, 0, 54, 4, 11, 6, 36, 7, 86, 1, 66, 5,  5, 8, 98, 
    0, 41, 6, 52, 7, 35, 5, 63, 3, 87, 2, 79, 1, 52, 8, 23, 4, 84, 
    7, 82, 1, 56, 4, 75, 8, 72, 2, 90, 0, 22, 3, 22, 5, 83, 6, 10, 
    1, 66, 6,  2, 7, 14, 4,  3, 5,  8, 8, 98, 2, 73, 0, 56, 3, 54, 
    7, 53, 3, 14, 8, 57, 6, 23, 4, 67, 0, 49, 2, 41, 5, 91, 1, 94
  };
  const int q2820[] = {
    9, 9, // Number of jobs and machines
    6, 73, 7, 56, 2, 76, 5, 44, 1,  6, 0,  1, 3, 45, 8, 74, 4, 14, 
    5, 34, 7, 20, 2, 99, 4, 67, 6, 98, 0,  7, 3, 78, 8, 29, 1, 66, 
    8, 79, 1, 21, 2, 99, 6, 88, 3, 92, 4, 71, 5, 66, 7, 47, 0, 29, 
    0, 68, 4, 18, 7, 23, 2, 13, 5, 49, 6, 85, 8, 81, 3, 11, 1, 53, 
    7, 32, 5, 65, 3, 93, 2, 32, 1, 43, 4, 86, 8, 39, 6, 22, 0, 74, 
    8, 60, 5, 73, 0, 76, 2, 88, 7, 84, 4, 66, 1, 78, 6, 79, 3, 75, 
    1, 98, 8, 86, 2, 93, 7, 28, 0, 65, 5, 68, 6, 37, 4, 40, 3, 54, 
    6, 13, 7,  7, 1, 48, 2, 36, 4, 25, 0,  5, 8, 53, 5, 94, 3, 22, 
    1, 89, 2, 23, 3,  5, 0, 54, 5, 96, 4, 92, 8, 82, 6, 29, 7, 13
  };
  const int q2821[] = {
    9, 9, // Number of jobs and machines
    1, 99, 3,  3, 4, 39, 5, 50, 8, 14, 6, 72, 2,  7, 7, 71, 0, 21, 
    0, 57, 2, 54, 8, 34, 5, 48, 1, 89, 4, 42, 3, 12, 6, 10, 7, 83, 
    4, 82, 6,  2, 3, 15, 8, 82, 5, 56, 2, 12, 0, 84, 7, 39, 1, 58, 
    7, 29, 0, 41, 8, 15, 1, 99, 2, 22, 4,  1, 6, 54, 5, 54, 3, 20, 
    4,  6, 3, 75, 7, 81, 2, 23, 1, 54, 8, 44, 0, 82, 6, 99, 5, 41, 
    3, 27, 0, 55, 2, 28, 6, 28, 8, 64, 1, 15, 7, 17, 5, 42, 4, 90, 
    8, 32, 1, 76, 6, 80, 4, 76, 7, 21, 3, 12, 0, 77, 5, 46, 2, 28, 
    4, 33, 7,  9, 5, 29, 8, 89, 6, 93, 3, 77, 1, 72, 0, 14, 2, 10, 
    1, 11, 4, 50, 6, 96, 3, 37, 0, 35, 2,  8, 5, 77, 8,  3, 7, 58
  };
  const int q2822[] = {
    9, 9, // Number of jobs and machines
    8, 10, 1, 34, 2, 46, 0, 58, 6, 16, 5, 61, 4, 42, 7, 19, 3, 19, 
    8, 13, 5, 52, 4, 30, 7, 75, 6, 12, 1, 41, 3,  3, 2, 31, 0, 15, 
    1, 82, 8,  8, 6, 43, 5, 67, 0, 82, 2, 82, 4, 75, 7, 46, 3, 24, 
    7, 47, 2, 17, 1,  4, 0, 57, 5, 59, 6, 47, 8, 54, 3,  3, 4, 67, 
    4, 34, 0, 34, 3, 60, 7, 52, 5, 85, 6, 43, 8, 96, 1, 82, 2, 11, 
    0, 32, 7, 25, 5, 41, 2, 53, 3,  5, 1,  3, 4, 18, 6, 43, 8, 41, 
    0, 91, 6, 72, 2, 28, 5, 44, 4, 73, 7, 25, 3, 29, 1, 28, 8, 90, 
    1,  4, 7, 84, 2, 31, 8,  4, 0, 39, 5, 40, 3, 63, 6, 49, 4, 64, 
    1, 23, 8, 38, 7, 48, 5, 78, 6, 93, 2, 53, 4,  8, 0, 86, 3, 41
  };
  const int q2823[] = {
    9, 9, // Number of jobs and machines
    7,  1, 5, 88, 6, 68, 3, 93, 0, 81, 8, 15, 4, 35, 2, 48, 1, 88, 
    5,  5, 0, 65, 3, 89, 1, 49, 6, 53, 2, 78, 4, 51, 8, 67, 7, 17, 
    6,  6, 8, 72, 2, 12, 7, 53, 0, 66, 1, 83, 5, 34, 3, 39, 4, 50, 
    4, 24, 2,  7, 5, 13, 3,  7, 6, 98, 0, 42, 7, 19, 1, 54, 8, 89, 
    1, 23, 7, 70, 5, 74, 4,  5, 0, 61, 8,  7, 2, 35, 6,  6, 3, 46, 
    5, 88, 7, 15, 3, 18, 4, 33, 2, 11, 6, 77, 1, 53, 0, 20, 8, 44, 
    2, 15, 6, 18, 0, 54, 5, 77, 4, 63, 3, 41, 8, 81, 7, 55, 1, 23, 
    8, 57, 2, 35, 6, 36, 5, 77, 3, 87, 1, 68, 7, 67, 4, 61, 0, 57, 
    7, 92, 3, 71, 6, 66, 4, 74, 0, 25, 8, 93, 1, 50, 2, 94, 5, 72
  };
  const int q2824[] = {
    9, 9, // Number of jobs and machines
    5, 67, 2, 69, 6, 44, 8, 94, 0, 34, 7, 83, 4, 84, 3, 11, 1, 96, 
    6, 67, 4, 25, 8, 66, 1, 44, 2, 80, 0, 93, 7, 37, 5, 29, 3,  9, 
    3, 25, 5, 11, 7, 24, 6, 69, 2, 73, 4, 86, 0, 39, 1, 20, 8, 36, 
    2,  5, 1, 15, 7, 38, 5, 86, 3, 93, 4, 81, 6, 70, 0, 61, 8, 13, 
    3, 98, 7, 17, 4, 26, 0,  5, 1,  8, 2, 60, 6, 94, 8, 15, 5, 56, 
    2, 89, 0, 57, 6, 70, 8, 43, 3, 93, 5, 96, 1,  3, 7, 66, 4,  4, 
    3, 64, 1, 62, 2,  2, 6, 19, 5, 64, 7, 81, 4, 79, 8, 80, 0, 86, 
    6, 59, 1, 62, 3,  8, 8, 40, 0, 26, 4, 71, 5, 36, 7, 53, 2, 13, 
    7, 31, 2, 56, 3,  8, 6, 86, 5, 18, 1, 27, 8, 72, 0, 55, 4, 48
  };
  const int q2825[] = {
    9, 9, // Number of jobs and machines
    3, 90, 0, 28, 4, 29, 8, 48, 2,  8, 1, 72, 7, 63, 6, 92, 5, 61, 
    0, 38, 8, 50, 3, 62, 4, 95, 7, 98, 5, 21, 1, 23, 2, 84, 6, 67, 
    3, 26, 7, 97, 5, 55, 4, 19, 6, 55, 2, 61, 8, 28, 0, 35, 1, 93, 
    7, 91, 8, 42, 4, 66, 1, 90, 5, 18, 6, 59, 0, 68, 2, 20, 3, 86, 
    0, 75, 5, 96, 1, 78, 6, 42, 8, 20, 2, 13, 4, 44, 3,  8, 7, 95, 
    1, 53, 6, 28, 5, 57, 4, 64, 3, 40, 0, 27, 7, 26, 8, 36, 2, 98, 
    0, 25, 1, 24, 4, 19, 2, 46, 8, 85, 5, 35, 6, 43, 3, 61, 7, 72, 
    8, 31, 4, 68, 3, 91, 7, 13, 6, 31, 1, 86, 0, 18, 5, 87, 2, 14, 
    7, 60, 0, 28, 8, 38, 3, 41, 4, 86, 1, 39, 2, 97, 6,  9, 5, 53
  };
  const int q2826[] = {
    9, 9, // Number of jobs and machines
    8, 85, 6, 40, 1, 30, 4,  6, 3,  8, 0, 20, 2, 85, 5, 83, 7, 57, 
    1, 55, 8, 54, 3, 81, 0, 66, 6, 48, 4, 79, 2, 59, 5, 68, 7, 39, 
    0, 60, 5, 20, 7, 43, 1, 41, 6, 31, 8, 88, 3, 71, 4, 66, 2, 68, 
    4, 38, 2, 74, 0, 55, 5, 40, 3, 36, 6, 49, 8,  6, 1, 61, 7, 36, 
    5, 83, 4, 79, 1,  4, 8,  4, 3, 54, 7, 47, 2, 57, 6, 21, 0, 25, 
    7, 53, 0, 17, 6,  7, 1, 16, 8, 71, 4,  4, 3, 65, 2, 83, 5, 63, 
    2, 79, 5, 45, 4, 62, 6, 33, 0, 59, 3, 60, 7, 49, 8, 10, 1, 99, 
    2, 93, 6, 65, 7, 54, 8,  3, 3, 10, 4,  6, 1, 45, 5, 68, 0, 46, 
    0, 39, 1,  8, 5, 13, 8, 18, 4, 70, 2, 60, 6, 60, 3, 31, 7, 19
  };
  const int q2827[] = {
    9, 9, // Number of jobs and machines
    2, 45, 7, 71, 0, 50, 8, 35, 3, 29, 1, 35, 4, 29, 5, 57, 6,  1, 
    4, 85, 1, 21, 6, 76, 5,  4, 0, 82, 3, 90, 8, 42, 2, 89, 7, 81, 
    7, 83, 5, 33, 4,  5, 3, 26, 8, 69, 2, 30, 1, 76, 0,  5, 6,  8, 
    6, 98, 1, 32, 4, 84, 2, 95, 0,  8, 5, 76, 8, 12, 3, 17, 7, 80, 
    3,  9, 6, 80, 0, 31, 4, 45, 8, 59, 5, 83, 7, 75, 2, 56, 1, 94, 
    2, 51, 3, 40, 7, 55, 5, 92, 0, 20, 1, 52, 8, 13, 4, 77, 6, 24, 
    4, 22, 8, 17, 5, 30, 2, 60, 0, 86, 1, 22, 7, 20, 6,  8, 3, 54, 
    0, 50, 5, 63, 1, 60, 2, 74, 7, 74, 6, 60, 3, 97, 4, 45, 8, 98, 
    1, 19, 3, 12, 7,  7, 0, 23, 6, 35, 4, 87, 8, 94, 5, 65, 2, 94
  };
  const int q2828[] = {
    9, 9, // Number of jobs and machines
    2, 50, 5,  1, 3, 17, 1, 89, 0, 69, 8, 36, 4, 80, 7, 82, 6, 67, 
    4, 68, 0, 43, 1, 39, 8, 68, 3, 33, 5, 12, 6, 36, 2, 64, 7, 18, 
    6, 63, 1, 67, 3, 76, 7, 55, 2, 99, 8, 24, 0, 94, 5, 77, 4, 58, 
    6, 93, 2, 25, 0, 10, 5, 63, 1, 31, 7, 59, 4, 82, 8, 84, 3, 40, 
    0, 37, 6, 80, 2, 38, 4,  5, 1, 35, 5, 23, 7, 31, 8, 18, 3, 94, 
    4, 26, 6, 69, 0, 40, 3, 84, 8, 43, 2,  5, 1, 89, 7, 13, 5, 74, 
    1, 16, 6, 21, 3, 85, 7, 99, 5, 56, 8, 54, 2, 26, 4, 54, 0, 99, 
    6, 46, 8,  2, 1,  6, 0,  4, 4, 77, 3, 53, 7, 61, 5, 70, 2, 25, 
    1,  5, 3, 82, 8, 11, 7, 57, 5, 88, 0,  4, 4, 94, 6, 89, 2, 45
  };
  const int q2829[] = {
    9, 9, // Number of jobs and machines
    8,  9, 1, 56, 5, 41, 0, 70, 4, 40, 6, 19, 2, 60, 7, 85, 3, 80, 
    2, 55, 4, 87, 0, 92, 6, 31, 1, 87, 8, 37, 7, 83, 5, 19, 3, 91, 
    3,  8, 4, 84, 5, 38, 1, 83, 2, 57, 8, 35, 7, 29, 0, 29, 6,  5, 
    3,  4, 4, 25, 1, 22, 0, 35, 2, 81, 5, 28, 7,  7, 8,  9, 6, 52, 
    6, 76, 2, 57, 4, 23, 7, 80, 1, 51, 0, 11, 5, 23, 8, 70, 3, 49, 
    4, 64, 8, 26, 1, 61, 5, 78, 2, 37, 3, 25, 0, 84, 7, 74, 6, 94, 
    7, 80, 2, 11, 8, 61, 6, 29, 5, 16, 1, 51, 0, 59, 3, 27, 4,  7, 
    3, 58, 5, 38, 1, 47, 7, 51, 4, 80, 0, 68, 8, 45, 2, 49, 6,  8, 
    5, 28, 6, 12, 2, 95, 0, 15, 1, 59, 3, 44, 4, 86, 8,  3, 7, 23
  };
  const int q2830[] = {
    9, 9, // Number of jobs and machines
    8, 46, 2, 74, 1, 43, 6, 58, 0, 87, 7, 85, 4, 19, 3, 78, 5, 81, 
    0, 29, 5, 10, 3, 26, 8, 11, 6, 52, 4, 27, 7, 49, 1, 82, 2, 85, 
    6,  7, 5, 34, 2, 69, 0, 77, 4, 28, 7, 96, 8, 75, 1, 53, 3, 82, 
    1, 77, 6, 72, 2, 21, 8, 18, 7, 31, 3,  4, 5, 97, 0, 51, 4, 27, 
    6, 14, 4, 48, 7, 40, 3, 29, 8, 90, 2, 32, 0, 24, 1, 68, 5, 66, 
    6, 45, 7, 57, 3, 22, 8, 94, 0, 42, 4, 19, 2, 76, 5, 69, 1, 38, 
    4, 63, 0, 21, 7, 25, 6, 55, 5, 84, 1, 42, 3, 44, 2, 52, 8, 15, 
    0, 98, 2, 40, 6, 41, 4, 42, 3,  9, 8, 45, 1,  2, 5, 56, 7, 49, 
    7, 41, 0, 58, 4, 97, 1, 55, 3, 77, 5, 48, 8, 34, 2, 17, 6, 13
  };
  const int q2831[] = {
    9, 9, // Number of jobs and machines
    8, 57, 7,  8, 6, 65, 4, 39, 5, 84, 0, 89, 3, 98, 1, 24, 2, 37, 
    8, 46, 2, 47, 7, 35, 0, 93, 6, 91, 5, 32, 3, 44, 4, 11, 1, 95, 
    1,  8, 5, 96, 0, 85, 7, 85, 4, 33, 8, 38, 2, 60, 6, 56, 3, 60, 
    5,  2, 3, 84, 2, 45, 7, 12, 4, 89, 6, 89, 1, 67, 8, 34, 0,  4, 
    2, 19, 4, 74, 8, 28, 0, 90, 7, 23, 5, 76, 3, 92, 6, 44, 1, 96, 
    1, 91, 0, 71, 6,  2, 3, 69, 5, 89, 7, 70, 2, 20, 4, 26, 8,  2, 
    1, 78, 0, 63, 4, 51, 8, 56, 7, 64, 6, 31, 3, 25, 5, 10, 2, 39, 
    2, 19, 0, 37, 6, 27, 1, 89, 4, 33, 3, 52, 5, 13, 8, 80, 7, 27, 
    5, 82, 4, 72, 1, 88, 0, 87, 7, 96, 8, 33, 6, 56, 3, 95, 2, 89
  };
  const int q2832[] = {
    9, 9, // Number of jobs and machines
    0, 41, 7, 53, 5, 97, 2, 10, 3, 13, 4,  1, 6, 13, 8, 49, 1, 81, 
    0, 87, 1, 64, 5,  3, 7, 85, 6, 75, 3, 69, 2, 86, 8, 29, 4, 84, 
    2, 37, 7, 57, 3,  2, 5, 23, 6, 63, 4, 82, 0, 74, 8, 98, 1, 84, 
    3, 20, 8,  3, 7, 86, 0, 35, 6,  7, 2, 90, 5, 32, 4,  7, 1,  8, 
    6, 65, 0,  2, 8, 92, 3, 67, 1, 60, 5, 84, 4,  4, 2, 49, 7, 12, 
    7, 22, 0, 73, 1, 39, 5, 49, 4, 76, 2, 90, 8, 46, 3, 10, 6, 98, 
    4, 99, 1, 77, 7, 31, 5, 19, 6, 73, 3, 73, 8, 15, 0, 46, 2,  2, 
    3, 90, 6,  8, 1, 52, 5, 54, 8, 33, 4, 18, 0, 11, 2,  4, 7, 80, 
    6, 35, 0, 43, 3, 72, 7, 65, 5, 82, 2, 59, 1, 75, 8, 74, 4,  8
  };
  const int q2833[] = {
    9, 9, // Number of jobs and machines
    4, 79, 6, 43, 8, 20, 7, 35, 0, 26, 3, 15, 5, 15, 2, 93, 1, 56, 
    0, 29, 2, 19, 3, 82, 7,  5, 4, 42, 1, 18, 5, 73, 8, 10, 6, 16, 
    3, 21, 0,  9, 7,  1, 5, 53, 6, 91, 1, 70, 4, 50, 8,  9, 2, 92, 
    8, 14, 4, 23, 1, 37, 2,  7, 0, 50, 3, 69, 6, 30, 7, 17, 5,  1, 
    5, 94, 2, 89, 0, 80, 7, 58, 1, 56, 6,  2, 4, 17, 8, 53, 3, 43, 
    4, 22, 2, 18, 7, 85, 3, 35, 1, 26, 5, 27, 8, 90, 6, 87, 0, 34, 
    0, 61, 4, 44, 5, 86, 6, 80, 8, 69, 3, 77, 7, 99, 1, 74, 2, 41, 
    8, 62, 6, 73, 3, 36, 0, 12, 7, 97, 4,  8, 5, 37, 1, 47, 2, 20, 
    7, 20, 5,  8, 6, 57, 3, 87, 4, 82, 2, 17, 1, 53, 0, 38, 8, 55
  };
  const int q2834[] = {
    9, 9, // Number of jobs and machines
    7, 29, 3, 84, 6, 38, 8, 93, 5, 93, 0, 55, 2, 18, 4, 51, 1, 56, 
    2, 15, 1,  5, 5, 76, 3, 33, 6, 48, 7, 28, 8, 56, 0, 40, 4, 28, 
    5, 35, 7, 56, 4, 56, 2, 53, 0, 39, 1, 45, 3, 59, 8, 47, 6, 73, 
    7, 34, 6,  2, 0, 41, 8, 18, 3, 88, 5, 23, 1, 76, 4, 16, 2, 80, 
    8, 88, 5,  8, 0, 94, 6, 74, 4, 10, 2, 22, 3, 66, 7, 84, 1, 62, 
    4, 53, 0, 45, 1, 26, 7, 99, 3, 13, 6, 33, 8, 49, 5, 25, 2,  5, 
    6, 15, 0, 91, 5, 59, 8, 80, 4, 98, 1,  8, 3, 69, 2, 55, 7, 19, 
    6, 28, 1, 75, 0, 83, 2, 80, 5, 92, 3,  3, 8, 69, 4, 62, 7, 98, 
    5, 43, 4,  9, 2, 78, 7, 86, 8, 59, 0, 33, 1, 95, 3, 41, 6, 12
  };
  const int q2835[] = {
    9, 9, // Number of jobs and machines
    1, 20, 7, 87, 5, 52, 3, 15, 0, 24, 4, 55, 8, 60, 2, 44, 6, 97, 
    3, 54, 4, 28, 7, 89, 1, 21, 0, 87, 2, 73, 6, 40, 8, 21, 5, 55, 
    6, 51, 7, 10, 4, 30, 1, 98, 3,  5, 0, 28, 2, 38, 5, 53, 8, 65, 
    6, 80, 7, 36, 2, 12, 5, 87, 8, 79, 3, 62, 4, 53, 1, 49, 0, 23, 
    6, 68, 2, 85, 3, 58, 0, 50, 7, 64, 8, 76, 5, 19, 4, 55, 1, 60, 
    5, 24, 8, 68, 7,  2, 2, 89, 6, 45, 0, 90, 4, 34, 3, 64, 1, 64, 
    4, 45, 8, 57, 7, 66, 0, 89, 6, 48, 2, 18, 1, 37, 3,  8, 5, 63, 
    4, 40, 8, 99, 6, 94, 7, 13, 3, 69, 1, 96, 5, 28, 2, 53, 0, 51, 
    0, 11, 2, 37, 6, 29, 4,  8, 8, 52, 5,  9, 3, 19, 7, 30, 1, 66
  };
  const int q2836[] = {
    9, 9, // Number of jobs and machines
    0, 52, 2, 25, 4, 48, 8, 66, 1,  1, 6, 26, 3, 94, 5, 68, 7, 68, 
    1, 81, 6, 10, 2,  7, 0, 51, 5, 44, 3, 86, 7, 20, 4, 19, 8, 76, 
    5, 21, 3, 67, 2, 80, 6, 21, 4,  4, 1, 52, 7, 77, 8, 67, 0, 17, 
    7, 19, 2, 51, 8, 26, 5, 43, 0,  5, 3, 61, 6, 58, 4, 72, 1, 80, 
    4, 14, 2, 52, 3, 37, 0, 86, 6, 23, 5, 11, 1, 61, 7, 70, 8, 68, 
    1, 38, 8, 22, 5, 18, 4, 47, 7, 77, 2, 36, 6, 46, 0, 84, 3, 14, 
    8, 72, 0, 85, 5, 83, 2, 13, 7, 78, 3, 51, 6, 48, 1, 65, 4, 72, 
    3, 98, 6, 27, 5, 96, 1, 84, 4, 88, 7,  4, 0, 45, 2, 92, 8, 88, 
    7, 42, 6, 14, 8, 12, 2, 74, 1, 92, 5, 23, 3, 94, 0, 24, 4, 84
  };
  const int q2837[] = {
    9, 9, // Number of jobs and machines
    2, 91, 8, 32, 6, 80, 7,  2, 3, 71, 5, 27, 0, 97, 4, 13, 1,  6, 
    6, 62, 1, 87, 4, 94, 3, 29, 8, 96, 2, 36, 0, 85, 7, 28, 5, 37, 
    8, 53, 1, 11, 7, 16, 0, 62, 3, 55, 4, 74, 2, 34, 6, 80, 5, 67, 
    6, 53, 5, 57, 8, 18, 4, 50, 3, 48, 7, 73, 2, 69, 0, 10, 1, 23, 
    2, 15, 8, 96, 4, 96, 1, 37, 3, 63, 7, 26, 0, 40, 6, 16, 5, 96, 
    0,  3, 1, 52, 4, 76, 2, 85, 3, 98, 6, 24, 8, 75, 5, 30, 7, 99, 
    0, 69, 4, 34, 3, 51, 6, 54, 2, 76, 5, 10, 8, 82, 1, 90, 7, 70, 
    5, 73, 2, 98, 4, 21, 6, 50, 0,  8, 7, 87, 1, 50, 3, 85, 8, 44, 
    4, 98, 2, 77, 8, 34, 7, 58, 0, 30, 3, 29, 1, 72, 5, 30, 6, 25
  };
  const int q2838[] = {
    9, 9, // Number of jobs and machines
    0, 19, 8, 91, 4, 75, 7, 81, 6, 44, 2,  3, 5, 82, 1, 21, 3, 92, 
    2, 17, 5, 48, 6, 30, 1, 83, 7,  2, 3, 48, 0, 63, 8, 31, 4, 21, 
    2, 91, 5,  8, 4, 86, 8, 20, 0, 77, 7, 18, 1, 41, 3, 40, 6, 84, 
    4, 57, 5, 98, 3, 66, 6, 82, 1, 84, 2, 16, 0, 50, 7, 33, 8, 45, 
    0, 61, 6, 84, 7, 78, 1, 39, 2, 13, 3, 19, 8, 41, 5,  6, 4, 60, 
    6, 87, 8, 74, 0,  4, 2,  3, 1, 85, 4, 98, 5, 37, 7, 25, 3, 87, 
    2, 26, 6, 35, 5, 24, 7, 84, 4, 34, 1, 84, 8, 83, 0, 89, 3, 83, 
    1,  6, 4,  1, 6, 45, 3, 49, 8, 82, 2, 45, 5, 81, 7, 55, 0, 48, 
    1, 67, 5, 90, 0, 89, 8, 79, 6, 40, 4, 73, 7, 26, 3, 51, 2, 68
  };
  const int q2839[] = {
    9, 9, // Number of jobs and machines
    6, 56, 7, 61, 8, 38, 2, 36, 3, 10, 5, 35, 4, 62, 1, 38, 0, 91, 
    6,  9, 7, 51, 4, 63, 3, 20, 5, 19, 2, 64, 1, 34, 0, 82, 8, 18, 
    8, 29, 4, 91, 7, 15, 1, 94, 2, 81, 5, 88, 3, 70, 6, 81, 0,  4, 
    6, 13, 0, 92, 3, 62, 2, 84, 8, 82, 7,  1, 5, 92, 1, 91, 4, 46, 
    3,  6, 1, 54, 7, 11, 6, 61, 8, 63, 5, 58, 2, 60, 0, 69, 4, 12, 
    7, 59, 8, 77, 4, 76, 6, 81, 0, 86, 2, 68, 5, 56, 1, 19, 3, 21, 
    4, 94, 8,  9, 0, 35, 6, 66, 3, 45, 2, 87, 7, 37, 1,  8, 5, 82, 
    8, 99, 1, 28, 0,  4, 2, 45, 6, 33, 3, 15, 4, 86, 5, 47, 7, 33, 
    6,  5, 8, 51, 3, 61, 1, 68, 5, 35, 0, 67, 4, 64, 7, 86, 2,  1
  };
  const int q2840[] = {
    9, 9, // Number of jobs and machines
    2, 29, 6, 74, 1,  9, 8, 86, 3, 74, 7, 98, 0, 84, 4, 12, 5, 43, 
    1, 99, 7, 48, 0, 50, 8, 73, 5, 83, 2, 80, 6, 52, 3, 83, 4, 37, 
    8,  9, 2, 72, 3, 69, 6, 90, 4, 48, 7, 24, 5, 85, 0, 37, 1, 28, 
    1, 42, 4, 37, 2,  4, 8, 70, 5, 34, 3,  1, 7, 54, 0, 86, 6, 24, 
    0, 91, 8, 37, 4, 12, 1, 78, 5, 70, 6, 93, 7, 53, 2,  3, 3, 26, 
    3, 31, 6, 78, 2, 23, 4,  9, 8, 15, 5, 63, 1, 31, 7, 36, 0, 21, 
    8, 86, 3,  3, 1, 59, 0, 85, 7, 85, 2, 25, 5, 74, 6, 59, 4,  3, 
    3, 30, 0, 10, 7, 95, 4, 36, 8, 92, 1, 25, 6,  7, 5, 85, 2, 12, 
    8, 56, 2, 92, 7, 84, 6, 23, 5, 87, 3, 92, 4, 93, 0,  2, 1, 92
  };
  const int q2841[] = {
    9, 9, // Number of jobs and machines
    4, 27, 1, 43, 8, 22, 2, 86, 3, 11, 5, 98, 6,  2, 7, 23, 0, 97, 
    5, 63, 2, 32, 1, 73, 8, 71, 4, 93, 0, 20, 3, 43, 7, 28, 6, 56, 
    8,  9, 4, 69, 1, 19, 0, 42, 7,  6, 3, 69, 2, 42, 6, 39, 5, 37, 
    5, 63, 0, 72, 2, 26, 7,  1, 3, 14, 8, 16, 4, 11, 1, 78, 6, 16, 
    8, 34, 3, 55, 5, 28, 1, 37, 0, 21, 4, 80, 2, 90, 6, 84, 7, 13, 
    1, 11, 3, 39, 4, 78, 0, 80, 2, 44, 5, 83, 7,  5, 8, 17, 6, 15, 
    4, 55, 8, 25, 3, 79, 5, 88, 0, 90, 2, 44, 7, 58, 1, 69, 6, 97, 
    5, 53, 1,  9, 7, 31, 3, 17, 8, 46, 6, 49, 2, 88, 4, 35, 0, 44, 
    0,  8, 6,  3, 8, 82, 3, 56, 2, 39, 1, 19, 7,  7, 5, 74, 4, 11
  };
  const int q2842[] = {
    9, 9, // Number of jobs and machines
    4, 35, 3, 26, 2, 38, 6,  5, 0, 85, 7, 77, 1, 83, 8, 39, 5, 38, 
    4, 37, 2, 59, 7, 61, 8,  7, 1, 46, 5, 45, 0, 89, 6,  6, 3, 82, 
    0, 55, 2, 65, 7,  8, 8, 45, 5, 50, 4, 71, 1, 68, 6, 21, 3,  4, 
    2, 59, 6, 92, 1, 76, 3, 20, 5, 36, 4, 19, 7, 80, 8, 82, 0, 16, 
    4, 37, 7, 26, 5, 21, 3, 12, 0, 31, 1, 50, 2, 58, 8, 94, 6, 11, 
    2, 89, 0, 26, 4, 94, 3, 75, 5, 17, 6, 46, 7, 88, 1, 85, 8, 41, 
    0, 82, 3, 26, 7, 82, 2, 13, 6, 29, 8, 20, 5, 90, 4, 85, 1,  3, 
    5, 80, 8, 78, 1, 68, 7, 57, 3, 49, 2, 73, 6, 62, 4,  2, 0, 59, 
    6, 50, 7, 33, 2, 58, 5, 70, 0, 38, 1,  4, 3, 43, 8, 91, 4,  2
  };
  const int q2843[] = {
    9, 9, // Number of jobs and machines
    8, 51, 2, 95, 1, 34, 7, 93, 5, 12, 3, 35, 0, 27, 4, 19, 6,  6, 
    3, 67, 0, 13, 6, 60, 1, 40, 5, 69, 4, 70, 7, 96, 8, 27, 2, 91, 
    7, 53, 1, 86, 8, 49, 3, 98, 5, 65, 2, 72, 0, 49, 6, 70, 4, 75, 
    5, 45, 7, 94, 0, 31, 4, 32, 1, 20, 6, 38, 3, 59, 2, 86, 8,  2, 
    3, 95, 8, 65, 1, 99, 6, 42, 4, 57, 5, 48, 0, 38, 7, 69, 2, 90, 
    4, 33, 1, 72, 8, 44, 2, 26, 5, 66, 3, 54, 0,  3, 6, 61, 7, 56, 
    1, 97, 6, 12, 3, 25, 2, 21, 4, 37, 7, 49, 0, 57, 8, 25, 5, 72, 
    4, 33, 3, 27, 0, 86, 7, 71, 5, 66, 1, 81, 2, 65, 6, 25, 8, 44, 
    1, 15, 8, 71, 3, 39, 4, 85, 5, 17, 2, 79, 0, 24, 6, 51, 7, 71
  };
  const int q2844[] = {
    9, 9, // Number of jobs and machines
    3, 84, 4, 20, 6, 35, 2, 28, 8, 99, 5, 98, 1, 85, 0, 89, 7, 45, 
    1, 51, 6, 25, 3, 40, 2, 85, 0, 37, 4, 32, 5, 86, 8, 54, 7, 19, 
    7,  4, 1, 48, 5, 30, 2, 63, 3, 98, 6, 61, 8, 35, 4, 51, 0,  7, 
    2,  2, 4, 23, 1, 74, 8, 98, 0, 27, 3, 32, 7, 31, 6,  9, 5, 94, 
    7,  5, 1, 33, 5, 27, 8, 51, 3, 91, 6, 26, 4, 51, 0, 99, 2, 20, 
    1, 64, 5, 91, 3, 44, 2, 91, 0, 39, 8, 11, 7,  3, 6, 38, 4, 52, 
    8, 22, 6, 12, 3, 36, 2, 29, 1, 10, 0, 52, 7, 81, 5, 57, 4, 10, 
    0, 37, 6,  3, 4, 42, 3,  2, 5,  9, 2, 14, 7, 35, 8, 66, 1, 79, 
    4, 68, 1, 92, 2, 81, 3, 96, 6, 62, 5, 16, 8, 54, 7, 57, 0, 61
  };
  const int q2845[] = {
    9, 9, // Number of jobs and machines
    2, 56, 1, 69, 0, 92, 4, 15, 7, 53, 3, 78, 8, 54, 6, 56, 5, 81, 
    2, 62, 4, 70, 3, 48, 1, 53, 8, 38, 0, 20, 6, 17, 5, 92, 7, 86, 
    8, 40, 1, 66, 2, 96, 4, 26, 5, 11, 6, 20, 0, 85, 7,  3, 3, 94, 
    1, 41, 6, 75, 2, 51, 0, 21, 7, 40, 5, 92, 4, 96, 8, 97, 3,  7, 
    3, 63, 0, 55, 2, 73, 7,  4, 8, 41, 1, 40, 5, 73, 4, 71, 6, 10, 
    0, 28, 3, 38, 5, 37, 8, 49, 4, 62, 1, 44, 7, 37, 6, 73, 2, 84, 
    3, 28, 1, 59, 7, 48, 6,  1, 8, 52, 0, 59, 2, 32, 5, 69, 4, 33, 
    5, 54, 7, 69, 1, 86, 6, 75, 4, 29, 8, 13, 3, 20, 2, 73, 0, 81, 
    7, 20, 5,  3, 8, 86, 4, 29, 2, 53, 1, 69, 0, 71, 3, 62, 6, 65
  };
  const int q2846[] = {
    9, 9, // Number of jobs and machines
    5, 37, 4, 94, 0, 61, 2,  2, 8, 82, 6,  6, 1, 30, 3,  5, 7, 42, 
    2,  9, 8, 92, 7, 90, 4, 92, 6, 31, 3, 35, 5, 77, 1, 16, 0,  9, 
    3, 10, 2, 65, 8, 51, 5, 35, 0, 85, 7, 21, 6, 59, 1, 76, 4, 51, 
    2, 78, 3, 33, 5, 75, 6, 56, 0,  8, 7, 54, 1, 54, 8, 51, 4,  1, 
    4, 57, 8, 95, 6, 20, 5, 62, 7, 88, 1, 55, 2, 97, 3, 94, 0, 42, 
    8, 52, 6, 72, 7, 56, 5, 66, 3, 79, 1,  9, 4, 97, 2, 10, 0, 84, 
    6, 76, 8, 99, 2, 83, 7, 29, 1, 84, 5, 67, 4, 77, 3, 64, 0, 57, 
    0, 81, 7,  2, 6, 94, 5, 75, 8, 10, 2,  5, 1, 79, 3, 33, 4, 22, 
    7, 24, 1, 96, 5, 50, 0, 62, 6,  3, 4,  6, 2, 39, 8, 24, 3, 72
  };
  const int q2847[] = {
    9, 9, // Number of jobs and machines
    7, 12, 8,  8, 6, 45, 2, 47, 0, 12, 3, 87, 5, 90, 1,  2, 4, 14, 
    5, 36, 7, 20, 4, 55, 6, 93, 1, 66, 2, 65, 0, 55, 8, 92, 3, 68, 
    5, 43, 0, 64, 1, 19, 3, 65, 4, 11, 7, 97, 6, 26, 2, 63, 8,  8, 
    4,  8, 1, 77, 2, 82, 0, 41, 6, 19, 5, 89, 3, 63, 7,  9, 8, 85, 
    4, 53, 1, 19, 7, 41, 0, 67, 5, 79, 6, 96, 8, 87, 2,  5, 3, 80, 
    1, 31, 2, 22, 0, 93, 7,  7, 4, 14, 6, 92, 5, 27, 8, 65, 3, 46, 
    2, 73, 4,  3, 1,  3, 7, 21, 5, 81, 6, 16, 0, 20, 3,  9, 8, 28, 
    5, 73, 6, 40, 7, 43, 4, 70, 1, 10, 2, 53, 0, 39, 8, 95, 3, 69, 
    3, 94, 4, 84, 6,  4, 1, 91, 8, 31, 2, 80, 7, 25, 0, 97, 5, 30
  };
  const int q2848[] = {
    9, 9, // Number of jobs and machines
    2, 40, 0,  6, 4, 75, 8, 15, 3, 46, 1, 58, 7, 58, 6, 71, 5, 14, 
    2, 51, 8, 44, 3, 39, 4, 27, 1, 66, 7, 72, 0, 89, 6, 54, 5, 23, 
    6, 37, 2, 46, 5, 93, 7, 76, 3, 94, 4, 86, 8, 88, 1, 89, 0, 64, 
    2, 85, 6, 42, 5, 16, 7, 25, 3, 85, 4, 35, 0, 94, 1,  5, 8, 51, 
    5, 25, 4, 60, 1, 71, 6, 78, 8, 57, 7, 70, 0, 67, 3, 32, 2, 36, 
    7, 92, 4, 49, 8, 48, 6, 18, 5, 43, 1, 13, 3, 49, 0,  1, 2, 53, 
    0, 49, 6, 27, 2, 27, 7, 99, 3, 44, 8, 27, 1, 28, 5, 47, 4, 91, 
    5, 52, 4, 29, 0, 16, 7, 86, 3, 25, 1, 54, 8, 18, 6, 78, 2, 70, 
    3, 83, 7, 55, 2, 44, 4, 76, 1, 34, 0, 15, 6, 59, 5, 93, 8, 62
  };
  const int q2849[] = {
    9, 9, // Number of jobs and machines
    4, 48, 8, 21, 1, 82, 2, 33, 7, 90, 3, 49, 5, 43, 0, 93, 6, 17, 
    5, 68, 2, 91, 3,  6, 4, 65, 8, 69, 7, 39, 6,  3, 0, 43, 1,  8, 
    8, 60, 3, 11, 5, 37, 2, 11, 4, 69, 6, 97, 0, 94, 1, 87, 7, 83, 
    7, 81, 2, 77, 8, 65, 0, 74, 1, 14, 3, 22, 5, 87, 6, 65, 4, 16, 
    7, 34, 3, 57, 4, 38, 8, 25, 5, 94, 2, 17, 6,  1, 1, 16, 0, 35, 
    5, 51, 4, 99, 0, 16, 2, 60, 6, 19, 7, 19, 3, 23, 1, 95, 8, 15, 
    2, 34, 6, 62, 3, 64, 4, 91, 8, 28, 1, 37, 5, 61, 0, 16, 7, 64, 
    8, 93, 1, 93, 4, 65, 7,  9, 3, 78, 2, 19, 5, 83, 0, 26, 6, 77, 
    0, 26, 7,  3, 1, 60, 2, 47, 6, 47, 8, 24, 3, 23, 4, 75, 5, 84
  };
  const int q2850[] = {
    9, 9, // Number of jobs and machines
    5, 13, 0, 91, 6, 71, 8, 18, 1, 89, 4, 16, 7, 17, 2, 99, 3, 10, 
    4, 47, 7, 34, 1, 58, 8, 17, 0, 40, 6, 61, 3, 48, 2, 31, 5, 38, 
    0, 30, 1, 51, 7, 66, 5, 74, 2, 24, 3, 49, 4,  5, 6, 32, 8, 31, 
    8, 65, 4, 40, 3, 80, 2, 69, 0, 18, 7, 89, 5, 89, 1, 82, 6, 85, 
    7, 99, 5, 46, 4, 15, 6, 69, 3, 32, 1, 25, 8, 85, 0, 47, 2, 65, 
    8, 77, 4, 95, 5, 83, 6, 44, 0, 16, 2, 69, 7, 75, 3, 25, 1, 56, 
    0, 56, 6, 41, 5, 32, 3, 66, 1, 74, 7, 33, 2, 49, 8, 66, 4, 45, 
    3, 87, 6, 71, 4, 24, 0, 95, 5, 87, 2, 40, 1, 12, 8, 25, 7, 85, 
    4, 78, 7, 38, 1, 81, 0, 46, 3, 85, 6, 88, 5, 10, 8,  8, 2, 84
  };
  const int q2851[] = {
    9, 9, // Number of jobs and machines
    2, 40, 6, 46, 3, 91, 5, 40, 8, 81, 0, 24, 1, 74, 7, 85, 4, 24, 
    5,  2, 1, 96, 0, 99, 3, 65, 8, 68, 7, 92, 4, 51, 6, 30, 2, 80, 
    5, 42, 6, 21, 8, 19, 7, 55, 0, 34, 1, 91, 4, 41, 3,  5, 2, 61, 
    3, 24, 6, 42, 0, 86, 7, 49, 4, 79, 1, 21, 5, 87, 2, 85, 8, 30, 
    0, 12, 5, 89, 7, 91, 1, 23, 2, 53, 4, 57, 6, 68, 8, 14, 3, 93, 
    0, 29, 2, 81, 1, 76, 8, 69, 3, 20, 5, 79, 6, 16, 7, 11, 4,  6, 
    2, 53, 3, 61, 5, 31, 0,  7, 1, 10, 8, 56, 6, 65, 4, 39, 7, 63, 
    1, 45, 4, 52, 5, 68, 3, 52, 7,  2, 0, 11, 2, 99, 6, 11, 8, 96, 
    5, 78, 4, 25, 8, 92, 1, 28, 7, 18, 3, 23, 2, 39, 0, 30, 6, 36
  };
  const int q2852[] = {
    9, 9, // Number of jobs and machines
    6, 49, 3, 38, 5, 81, 4, 89, 1,  6, 2, 63, 0, 29, 8, 81, 7, 78, 
    6, 44, 5, 85, 8, 52, 0,  2, 3, 63, 4, 81, 1, 88, 7, 50, 2,  7, 
    3, 58, 2, 58, 6, 91, 1, 95, 8, 57, 4, 36, 0, 14, 7,  9, 5, 59, 
    2, 19, 5, 21, 0,  9, 1, 24, 4, 46, 8, 64, 6, 71, 3, 62, 7, 55, 
    0, 90, 6, 63, 3, 26, 2, 55, 8,  7, 7, 35, 5, 35, 4, 15, 1, 21, 
    6, 98, 5,  4, 8, 54, 7, 58, 2, 91, 4, 91, 3, 82, 0, 17, 1, 36, 
    3, 42, 0, 59, 5,  1, 1, 50, 6, 47, 2, 11, 4, 90, 8, 92, 7, 83, 
    1, 75, 2, 32, 8,  2, 5, 23, 7, 32, 6, 65, 4, 51, 3, 34, 0, 27, 
    8, 55, 4, 21, 0, 32, 1, 61, 3, 91, 6,  7, 7, 44, 2, 80, 5, 95
  };
  const int q2853[] = {
    9, 9, // Number of jobs and machines
    7, 89, 1, 78, 4, 62, 3, 46, 5, 76, 6, 59, 2, 96, 0, 11, 8, 40, 
    7,  4, 6, 44, 4, 68, 5,  6, 8, 20, 0, 51, 2, 72, 3, 16, 1,  1, 
    8, 90, 4,  6, 0, 12, 1, 84, 6, 23, 5,  5, 2, 28, 7, 72, 3, 54, 
    6, 84, 2, 16, 7, 88, 4, 56, 8, 41, 5, 27, 1, 22, 3,  4, 0, 74, 
    3, 39, 1, 97, 4, 66, 5, 98, 8,  6, 7, 51, 0, 92, 6, 44, 2, 55, 
    4, 31, 0, 34, 1, 84, 7, 42, 6, 56, 3, 94, 2, 37, 8, 39, 5, 97, 
    7, 16, 3, 61, 1, 59, 2, 88, 0, 79, 6, 61, 5, 34, 4, 71, 8, 30, 
    2, 28, 8, 98, 6, 94, 1, 42, 5, 27, 4, 57, 3, 82, 0, 49, 7, 31, 
    7, 20, 8, 97, 3, 69, 5, 25, 6, 43, 4, 42, 2,  6, 1, 30, 0, 96
  };
  const int q2854[] = {
    9, 9, // Number of jobs and machines
    2, 47, 1, 43, 4, 96, 5, 80, 0, 44, 6, 51, 8, 11, 7, 38, 3, 92, 
    6, 56, 0, 73, 5, 59, 1, 87, 4, 95, 7,  4, 2, 80, 3, 11, 8, 17, 
    3, 22, 5, 60, 6, 58, 8, 93, 7, 90, 0, 28, 4, 38, 1, 25, 2, 97, 
    5, 62, 3, 87, 7, 53, 4, 12, 0, 13, 2, 15, 1, 28, 8, 82, 6, 45, 
    2,  9, 4, 28, 3, 74, 0, 80, 1, 77, 8, 67, 5, 86, 6, 74, 7, 59, 
    7, 72, 6, 61, 0, 20, 1, 18, 5, 37, 2, 85, 4, 72, 3, 39, 8, 98, 
    0, 72, 2, 97, 8, 99, 1, 86, 5, 29, 6, 56, 3, 78, 7, 77, 4, 12, 
    7, 76, 4, 72, 1, 99, 2, 15, 8, 86, 5, 42, 6, 42, 3, 88, 0, 50, 
    3, 64, 2, 85, 6, 49, 0, 39, 5, 67, 7, 91, 4, 11, 8, 62, 1, 53
  };
  const int q2855[] = {
    9, 9, // Number of jobs and machines
    8, 99, 5, 39, 4, 29, 3, 80, 0, 30, 7, 24, 2, 93, 1, 17, 6, 33, 
    0, 70, 7, 75, 8, 55, 1, 74, 3, 75, 6, 78, 5, 35, 2, 72, 4, 50, 
    8, 33, 5, 92, 1, 14, 7, 41, 6,  7, 3, 69, 4, 78, 0, 78, 2, 27, 
    5, 79, 1, 72, 2, 60, 7, 40, 6, 31, 8, 15, 0, 39, 4, 38, 3, 30, 
    2, 75, 6, 93, 8, 12, 1, 31, 5, 19, 0, 49, 4, 89, 3,  8, 7, 37, 
    5,  6, 8, 47, 3,  4, 2, 70, 1, 38, 4,  7, 6, 70, 0, 25, 7,  3, 
    7, 55, 3, 41, 4, 48, 5, 84, 2,  5, 8, 58, 6, 80, 1,  2, 0, 80, 
    4, 95, 7, 78, 6, 29, 5, 63, 3, 33, 1, 24, 0, 76, 8, 41, 2, 36, 
    3, 34, 8, 13, 0, 51, 2, 49, 4, 85, 7, 82, 5, 63, 6, 36, 1, 44
  };
  const int q2856[] = {
    9, 9, // Number of jobs and machines
    7,  2, 5,  7, 4, 94, 0, 25, 3,  3, 8,  1, 1, 95, 6, 96, 2, 77, 
    4,  4, 1, 53, 3, 85, 6, 86, 7, 17, 0, 60, 5, 27, 2, 53, 8, 51, 
    5, 41, 8, 48, 6, 97, 4, 20, 2, 12, 0, 46, 7, 53, 3, 76, 1, 93, 
    0, 82, 8, 94, 4, 44, 1, 71, 5,  8, 2, 36, 7, 88, 6, 77, 3, 29, 
    7, 79, 1, 15, 8, 80, 5, 77, 0, 27, 2, 44, 6,  4, 4, 78, 3, 44, 
    0, 79, 2, 12, 6, 81, 8, 97, 1, 36, 5, 11, 4, 73, 3, 39, 7, 45, 
    8, 38, 2,  1, 7, 39, 1, 29, 0, 91, 6, 50, 5, 92, 4, 80, 3, 79, 
    6, 22, 2, 77, 5, 64, 0, 39, 4,  5, 3, 49, 7,  1, 1, 12, 8, 57, 
    4, 95, 0, 91, 5, 56, 3, 32, 1, 66, 6,  7, 2, 78, 7, 55, 8, 85
  };
  const int q2857[] = {
    9, 9, // Number of jobs and machines
    6, 83, 7, 14, 0, 18, 4, 53, 3, 77, 2, 73, 8, 14, 1, 56, 5, 22, 
    7, 28, 2, 42, 3, 67, 0, 28, 5, 44, 8, 71, 4, 66, 6, 32, 1, 56, 
    5, 86, 2, 82, 4, 90, 7, 98, 0, 52, 8, 72, 6, 99, 3, 17, 1, 15, 
    8, 80, 6, 30, 5, 29, 0, 55, 7,  2, 1, 13, 3, 46, 4, 11, 2, 58, 
    5, 46, 3, 88, 0, 40, 6, 51, 1, 68, 2, 85, 7, 47, 4, 81, 8, 39, 
    6, 16, 8, 89, 1, 56, 4, 60, 3,  1, 2,  3, 0,  2, 7, 24, 5, 46, 
    5, 99, 4, 26, 3, 78, 6, 73, 0, 78, 1, 69, 7, 34, 2, 48, 8, 13, 
    4, 10, 0, 36, 3, 42, 1, 92, 6, 24, 2, 20, 8, 68, 5, 50, 7, 85, 
    6, 22, 5, 45, 7, 71, 3, 75, 4,  1, 1, 59, 8, 40, 2, 74, 0, 19
  };
  const int q2858[] = {
    9, 9, // Number of jobs and machines
    5, 21, 7,  9, 0, 29, 2, 40, 1, 25, 3, 39, 6, 20, 4, 29, 8, 42, 
    5, 27, 4, 85, 3, 40, 0, 93, 2, 72, 8, 45, 6, 82, 1, 95, 7, 11, 
    2, 97, 7, 39, 4,  7, 3, 45, 5, 95, 0, 63, 6, 31, 8, 89, 1, 83, 
    7, 73, 6, 61, 5, 50, 0, 87, 4, 28, 2, 87, 3, 86, 8, 39, 1, 43, 
    2, 34, 0, 36, 5, 93, 3, 55, 4, 82, 6, 76, 8,  7, 1, 16, 7, 79, 
    4, 52, 5, 40, 8, 78, 6, 84, 2, 32, 7, 45, 1, 60, 0, 53, 3, 22, 
    3, 55, 6, 39, 4, 15, 7, 70, 0, 25, 5, 99, 8, 26, 2, 55, 1, 36, 
    5, 15, 0, 87, 7, 61, 1, 10, 3, 30, 8, 26, 4, 74, 2,  1, 6, 61, 
    2, 63, 6, 23, 3, 21, 5, 75, 1, 86, 7, 59, 0, 52, 4, 16, 8, 51
  };
  const int q2859[] = {
    9, 9, // Number of jobs and machines
    4, 52, 5, 35, 8, 21, 1, 31, 0, 31, 7, 23, 3, 77, 2, 84, 6, 95, 
    3, 96, 7, 42, 6, 98, 2, 77, 8, 76, 0, 87, 5, 40, 1, 32, 4,  7, 
    3, 74, 1, 46, 5, 64, 2, 63, 4, 19, 6, 66, 8, 37, 7, 69, 0, 81, 
    2, 19, 4, 28, 3,  9, 1, 19, 0, 62, 6, 79, 5, 48, 7, 63, 8, 25, 
    4, 61, 8, 11, 6, 83, 3, 64, 7,  6, 0, 45, 2, 72, 1, 84, 5, 66, 
    6, 35, 1, 88, 8, 48, 5,  1, 2, 48, 3, 11, 7, 22, 0, 42, 4, 94, 
    2, 47, 4, 93, 0, 10, 6, 17, 8, 86, 7, 21, 5, 97, 3,  4, 1, 22, 
    7, 85, 2, 48, 5,  7, 3, 39, 8, 87, 6, 28, 4, 25, 1, 21, 0, 18, 
    3, 42, 8, 41, 5, 75, 4,  2, 6, 51, 0, 62, 1, 30, 7, 98, 2, 79
  };
  const int q2860[] = {
    9, 9, // Number of jobs and machines
    6, 29, 7, 31, 3, 10, 0, 90, 8, 77, 5, 79, 1, 17, 4, 88, 2, 80, 
    5, 60, 3,  7, 7, 56, 8, 57, 4, 51, 6, 11, 2, 90, 0,  4, 1,  4, 
    2, 63, 7, 58, 8, 55, 5, 76, 1, 38, 6, 31, 4, 26, 0,  5, 3, 63, 
    5,  8, 0, 23, 8, 18, 1, 51, 3, 87, 4, 81, 2, 77, 7, 46, 6, 41, 
    5, 35, 6, 91, 0, 30, 3, 76, 2, 13, 7, 46, 1, 17, 8, 33, 4, 82, 
    8, 68, 6, 18, 3, 77, 7, 30, 2, 88, 0,  8, 4, 73, 1, 24, 5,  7, 
    3, 70, 4, 13, 7,  7, 2, 60, 5, 73, 1, 37, 6, 26, 8,  4, 0, 43, 
    6,  7, 4,  4, 8, 66, 5, 38, 3, 97, 7, 91, 2, 97, 1, 78, 0, 20, 
    1, 24, 8, 31, 2, 23, 4, 90, 5, 27, 3, 74, 7, 32, 0, 13, 6, 76
  };
  const int q2861[] = {
    9, 9, // Number of jobs and machines
    8, 88, 6, 46, 0, 21, 1, 54, 2, 35, 3,  3, 4, 14, 7, 32, 5, 34, 
    5, 84, 3, 16, 6, 88, 4, 40, 2, 47, 1, 51, 7, 88, 0, 50, 8, 67, 
    6, 76, 1, 17, 3, 35, 4, 18, 2, 15, 8, 69, 5, 29, 7, 86, 0, 92, 
    3, 74, 8, 92, 2, 47, 5, 59, 7, 27, 6, 78, 0, 21, 4, 23, 1, 68, 
    3, 64, 4, 55, 5, 90, 2, 28, 6, 68, 7, 71, 1, 86, 0, 45, 8,  3, 
    7, 19, 8, 28, 3, 98, 6, 56, 5, 23, 1, 73, 0, 93, 4, 74, 2, 72, 
    5, 17, 1, 15, 2, 27, 4, 19, 3, 30, 8,  3, 7, 16, 0, 57, 6, 23, 
    3, 59, 5, 40, 8, 12, 1, 64, 2, 95, 4, 41, 6, 82, 7, 98, 0, 43, 
    1, 53, 2, 92, 7, 34, 5, 10, 4, 19, 3, 92, 0, 49, 6, 17, 8, 76
  };
  const int q2862[] = {
    9, 9, // Number of jobs and machines
    5, 83, 3,  9, 8, 14, 4, 52, 2, 17, 0, 58, 7, 94, 6, 33, 1, 37, 
    0, 27, 2, 17, 3, 22, 7, 84, 4, 67, 8, 18, 1, 99, 6,  4, 5, 23, 
    5, 67, 1, 40, 8, 99, 3, 78, 0,  4, 4, 55, 6, 23, 7, 23, 2, 86, 
    1, 18, 5, 47, 6, 33, 7,  8, 4, 20, 0, 75, 2, 42, 3, 29, 8, 79, 
    1, 48, 6, 10, 7, 29, 2, 57, 0, 92, 8, 50, 5, 43, 4, 57, 3, 59, 
    6, 91, 7, 72, 3, 50, 8, 35, 2, 27, 4, 83, 5, 29, 0, 81, 1, 64, 
    5, 50, 3, 71, 4, 76, 7,  5, 0, 61, 8,  9, 6, 16, 1, 43, 2, 39, 
    2, 45, 1, 94, 5,  5, 3, 51, 8, 30, 4, 36, 6, 25, 0, 70, 7, 30, 
    1, 66, 4, 91, 6, 98, 0, 43, 2, 72, 7, 76, 3, 34, 8, 72, 5, 39
  };
  const int q2863[] = {
    9, 9, // Number of jobs and machines
    6,  9, 3, 53, 1, 26, 8, 54, 5, 46, 7, 77, 4, 35, 0, 99, 2,  8, 
    5, 83, 7, 37, 4, 71, 2,  7, 0, 79, 8, 82, 3, 82, 1, 95, 6, 76, 
    4, 57, 6, 84, 2, 74, 8, 61, 3, 80, 0, 68, 5, 19, 1, 97, 7, 27, 
    8, 26, 5, 69, 4, 71, 0, 13, 1, 51, 6, 92, 3, 87, 7, 38, 2, 53, 
    6, 95, 0, 38, 7, 96, 5, 68, 8, 77, 3, 88, 2, 63, 4, 61, 1, 37, 
    2, 67, 8, 68, 7, 28, 4, 10, 0, 23, 1, 76, 6, 32, 3, 18, 5, 78, 
    6, 61, 1, 72, 0, 60, 2, 56, 4, 33, 7, 27, 8, 82, 5, 50, 3, 97, 
    3, 24, 1, 12, 6, 42, 2, 13, 0, 77, 8, 81, 7, 68, 5, 16, 4, 52, 
    7, 29, 5, 56, 8, 82, 0,  6, 6, 44, 4, 81, 2, 77, 3, 61, 1, 99
  };
  const int q2864[] = {
    9, 9, // Number of jobs and machines
    6, 64, 3,  4, 0, 50, 2, 90, 8, 14, 7, 69, 5, 92, 1, 47, 4,  5, 
    2, 96, 8, 34, 1, 83, 3, 35, 4, 21, 0, 37, 6, 14, 7, 45, 5, 77, 
    7, 40, 0, 43, 1, 89, 4, 58, 3, 57, 5, 67, 8, 42, 6, 96, 2, 49, 
    4, 85, 7, 88, 0, 98, 8, 74, 1,  5, 5, 85, 3, 55, 2, 52, 6, 28, 
    2, 59, 0, 79, 1, 47, 5, 24, 3, 84, 6,  7, 8, 88, 4, 57, 7, 26, 
    1, 19, 8,  3, 6,  7, 4, 32, 7, 80, 0, 50, 2, 41, 5,  3, 3,  9, 
    7, 46, 4, 90, 0, 64, 8,  2, 6, 94, 3,  2, 5, 85, 1, 65, 2, 96, 
    4, 82, 5, 73, 7, 98, 2, 87, 3, 83, 0, 94, 6, 31, 1, 23, 8, 31, 
    4, 17, 1,  9, 0, 63, 3, 40, 2, 82, 5, 12, 7, 10, 8, 57, 6,  7
  };
  const int q2865[] = {
    9, 9, // Number of jobs and machines
    8, 49, 6, 28, 3, 84, 1, 16, 4, 78, 5, 27, 0, 98, 7, 82, 2, 95, 
    7,  5, 0, 29, 8, 19, 3, 11, 2, 61, 6, 32, 1, 99, 5, 28, 4, 59, 
    0, 38, 4, 85, 1, 68, 2, 32, 8, 97, 7, 33, 3, 72, 6, 69, 5, 94, 
    0, 49, 8, 96, 1, 80, 3, 35, 2, 44, 4, 36, 6, 89, 7, 57, 5, 44, 
    1, 86, 3, 14, 4, 75, 2,  5, 7, 18, 6, 84, 0, 36, 8, 93, 5, 83, 
    7, 76, 6, 94, 4, 25, 1, 49, 8, 97, 2, 86, 0, 58, 3, 55, 5, 69, 
    7, 92, 5, 21, 2, 93, 4, 94, 6, 96, 3, 72, 1, 27, 0, 85, 8,  6, 
    8, 73, 5, 51, 7, 24, 4, 54, 0, 10, 1, 83, 2, 89, 3, 27, 6, 76, 
    1, 96, 0, 59, 6, 30, 3,  8, 8, 35, 4, 55, 5, 44, 2, 90, 7, 74
  };
  const int q2866[] = {
    9, 9, // Number of jobs and machines
    4, 94, 6, 56, 8, 19, 3, 41, 2, 76, 7, 26, 0, 27, 1,  2, 5, 44, 
    0, 70, 2, 20, 6, 94, 7, 73, 4, 18, 3, 79, 8, 26, 5, 95, 1, 90, 
    2, 99, 3, 54, 7,  6, 0, 26, 8, 10, 4, 84, 5, 55, 6, 20, 1,  4, 
    0, 55, 1,  5, 4, 73, 3, 11, 6, 58, 7, 21, 8, 96, 5, 70, 2, 15, 
    3, 80, 5,  3, 8, 41, 1, 97, 2, 49, 0, 99, 6, 64, 4, 69, 7,  7, 
    3, 52, 8, 78, 5,  4, 2, 84, 7, 40, 4, 31, 1, 96, 6, 64, 0, 48, 
    2, 12, 8, 24, 6, 54, 1,  4, 0, 98, 4, 64, 5, 88, 7, 21, 3, 28, 
    6, 59, 3, 31, 2,  7, 0, 28, 7, 46, 8, 21, 4, 52, 5, 40, 1, 66, 
    4, 87, 5, 75, 6, 70, 7, 50, 0, 40, 3, 82, 1, 21, 8, 91, 2, 57
  };
  const int q2867[] = {
    9, 9, // Number of jobs and machines
    3, 98, 7, 12, 5, 30, 8, 80, 4, 60, 0, 98, 6, 81, 1, 92, 2, 31, 
    5,  6, 6, 82, 7, 78, 4, 95, 8, 71, 1, 10, 3, 89, 2, 44, 0, 77, 
    2, 33, 6, 85, 4, 72, 5,  2, 0, 36, 8,  1, 3,  4, 1, 52, 7, 53, 
    1, 42, 7, 11, 2, 38, 0, 57, 3, 53, 8, 64, 6, 57, 4, 86, 5, 59, 
    0, 19, 7, 36, 3, 85, 8, 68, 1, 61, 4, 63, 2, 63, 5, 64, 6, 58, 
    4, 28, 1, 80, 6, 16, 3, 34, 8, 75, 5, 79, 0, 71, 2, 48, 7, 20, 
    5,  5, 7, 92, 8, 95, 4, 49, 0, 11, 1, 11, 3, 23, 6,  5, 2, 76, 
    7, 88, 3, 64, 1, 16, 2, 27, 8,  3, 5, 83, 6,  2, 4, 61, 0,  6, 
    1, 87, 0, 51, 7, 88, 6,  7, 8,  2, 4, 13, 2, 21, 3, 20, 5, 35
  };
  const int q2868[] = {
    9, 9, // Number of jobs and machines
    3, 25, 2, 17, 1, 19, 8, 45, 5, 85, 4, 69, 6, 65, 0, 57, 7, 27, 
    6, 12, 5, 83, 0, 80, 7, 15, 4, 87, 2, 25, 3, 27, 8, 99, 1, 53, 
    7, 19, 6, 20, 2, 12, 5, 73, 0, 66, 4, 42, 8, 80, 3, 38, 1,  6, 
    4,  3, 7, 81, 2, 90, 1, 59, 8, 84, 3, 36, 5, 47, 6, 61, 0, 74, 
    8, 90, 7, 78, 5, 81, 1, 32, 0, 94, 4, 51, 6, 86, 2, 24, 3, 46, 
    2, 50, 7, 31, 8, 36, 5, 81, 1, 95, 0, 95, 4, 39, 3, 59, 6, 69, 
    5, 14, 8, 11, 1, 40, 0, 43, 2,  6, 3, 92, 7, 13, 4, 34, 6, 67, 
    2, 20, 8, 35, 1,  8, 3, 84, 0, 23, 6, 56, 7, 77, 4, 78, 5, 88, 
    8, 90, 4, 64, 3, 68, 1, 39, 7, 99, 5, 40, 2, 81, 0,  7, 6, 53
  };
  const int q2869[] = {
    9, 9, // Number of jobs and machines
    0, 35, 8,  1, 7,  9, 6,  9, 5, 65, 2, 37, 3, 64, 1, 49, 4, 29, 
    5, 12, 0, 30, 8, 74, 6, 56, 1,  1, 7, 13, 3, 83, 2, 41, 4, 65, 
    8, 66, 3, 57, 5, 14, 6, 17, 7, 40, 0, 31, 4, 19, 1, 59, 2, 42, 
    0, 89, 4, 40, 1, 19, 7, 31, 6, 66, 2, 93, 5, 56, 3, 30, 8, 61, 
    1, 92, 3, 65, 2, 39, 6, 98, 5, 97, 4,  4, 7, 94, 0, 17, 8,  9, 
    6, 48, 8, 88, 2, 25, 0, 49, 3,  8, 5, 72, 7, 65, 1, 44, 4, 35, 
    5, 56, 8, 83, 0, 85, 2, 52, 3, 71, 4, 63, 7, 51, 6, 78, 1, 64, 
    2, 90, 8, 49, 5, 52, 0, 60, 1, 89, 4, 17, 7,  6, 3, 99, 6, 62, 
    3, 27, 2, 89, 5, 59, 1, 17, 0,  1, 7, 20, 4, 31, 6,  8, 8,  1
  };
  const int q2870[] = {
    9, 9, // Number of jobs and machines
    2, 98, 5, 33, 3, 58, 8,  3, 0, 24, 1, 67, 6, 37, 4, 28, 7,  9, 
    8, 98, 6, 97, 4, 90, 0, 18, 3, 78, 1, 58, 2, 77, 7, 78, 5, 85, 
    8, 48, 3, 56, 1, 78, 7, 61, 0, 64, 2, 62, 6, 38, 4, 74, 5, 46, 
    6, 70, 8, 20, 5, 91, 0, 70, 7, 16, 1, 53, 3, 25, 4, 59, 2, 82, 
    5, 14, 2, 23, 0,  7, 7,  1, 1, 36, 6, 46, 4, 28, 3,  5, 8, 86, 
    3, 66, 0,  9, 6,  7, 2, 49, 5, 89, 4, 59, 7, 52, 8, 42, 1, 20, 
    7, 53, 0, 65, 1, 24, 8, 84, 4, 17, 5, 17, 6, 35, 2, 41, 3, 88, 
    3, 55, 7, 15, 0, 84, 8, 40, 6, 83, 2,  2, 1, 50, 4, 88, 5,  3, 
    8, 88, 7, 70, 1, 93, 4, 96, 3, 16, 6,  4, 0, 56, 5, 47, 2, 66
  };
  const int q2871[] = {
    9, 9, // Number of jobs and machines
    3, 84, 8, 69, 2, 37, 0, 22, 5, 21, 6, 61, 4, 85, 1,  4, 7, 47, 
    8, 30, 3, 64, 7, 42, 2, 27, 4, 59, 6, 81, 5, 99, 1, 76, 0, 70, 
    0, 88, 2, 54, 1, 88, 8, 45, 3, 18, 5, 34, 4, 20, 7, 98, 6,  1, 
    7, 67, 5, 86, 8, 57, 3, 13, 4, 42, 0, 11, 6, 30, 1, 75, 2,  9, 
    2, 25, 4, 76, 6, 50, 5, 85, 8, 25, 7,  1, 1, 11, 3, 64, 0, 48, 
    4, 50, 6, 18, 8,  3, 1,  7, 2, 87, 7, 47, 5, 93, 3,  2, 0, 19, 
    4, 26, 7, 54, 3, 10, 6, 46, 5, 58, 0, 44, 1, 39, 2, 12, 8, 11, 
    6, 19, 7, 93, 2, 41, 3, 89, 8, 68, 0, 98, 1, 53, 4, 65, 5, 44, 
    1, 45, 5, 41, 7, 28, 8, 90, 2,  9, 6, 46, 0, 76, 3, 59, 4, 26
  };
  const int q2872[] = {
    9, 9, // Number of jobs and machines
    6, 71, 2, 11, 0, 69, 7, 70, 3,  5, 4,  5, 8,  9, 5,  8, 1, 17, 
    6,  1, 5, 17, 1, 72, 4, 30, 7, 92, 2, 36, 8, 22, 3, 50, 0, 98, 
    1, 20, 8, 34, 7, 32, 3, 58, 2, 91, 5, 17, 4, 88, 6, 29, 0, 16, 
    3, 88, 4, 35, 1, 68, 6, 45, 7, 34, 8,  2, 0, 53, 2, 50, 5, 14, 
    6, 67, 1, 87, 4, 45, 8, 89, 2, 26, 5, 45, 0, 50, 3, 83, 7, 51, 
    0, 80, 6, 85, 5, 75, 7,  7, 4, 82, 1, 69, 2, 42, 3, 27, 8, 97, 
    4, 66, 1, 80, 5, 52, 2, 61, 8, 47, 6, 25, 0, 85, 3, 58, 7,  9, 
    6, 17, 2, 87, 8,  6, 3, 20, 4, 18, 0, 72, 7, 92, 1, 17, 5,  3, 
    4, 10, 3,  7, 1, 97, 8, 99, 0, 10, 5, 94, 2, 96, 7, 37, 6, 10
  };
  const int q2873[] = {
    9, 9, // Number of jobs and machines
    4, 93, 5, 86, 7, 26, 1, 93, 3, 30, 0, 63, 8, 97, 2, 28, 6, 12, 
    8, 10, 1, 85, 7, 33, 6, 58, 2, 88, 4, 77, 3, 93, 5, 64, 0, 60, 
    1, 78, 0, 79, 3,  9, 7, 53, 6, 27, 4, 77, 5,  4, 8, 68, 2, 36, 
    1, 37, 6,  6, 3, 51, 5, 19, 7, 96, 8, 87, 0, 11, 2, 62, 4, 10, 
    2, 28, 6, 19, 0, 23, 1, 49, 8,  8, 5, 46, 3, 75, 4, 99, 7,  9, 
    2,  7, 0, 66, 3, 94, 6, 26, 5, 86, 7, 52, 1, 27, 8, 52, 4, 30, 
    6, 53, 4,  1, 1, 87, 2, 80, 7,  1, 5, 42, 0, 84, 3, 89, 8, 97, 
    1, 42, 0, 24, 7, 22, 5, 48, 6, 54, 4, 49, 3, 14, 2, 54, 8, 20, 
    2, 57, 6, 92, 5, 83, 0, 62, 1, 86, 8, 22, 7, 79, 4, 78, 3, 24
  };
  const int q2874[] = {
    9, 9, // Number of jobs and machines
    7, 93, 4, 37, 2, 59, 0, 67, 3,  7, 1, 36, 5, 51, 6,  1, 8, 62, 
    5, 86, 7, 94, 4, 15, 1, 42, 2, 78, 3, 88, 8, 21, 0, 57, 6, 55, 
    2, 29, 3, 76, 0, 76, 8, 32, 5, 97, 4, 45, 7, 11, 6, 71, 1, 48, 
    7, 65, 6, 95, 4, 57, 1, 11, 8, 56, 5,  3, 2, 50, 0, 51, 3,  6, 
    6, 68, 3, 56, 2, 31, 8, 76, 5, 24, 4, 19, 0, 87, 7, 11, 1, 21, 
    0, 35, 6, 93, 5, 54, 8, 50, 7, 52, 1, 88, 4, 35, 3, 66, 2, 59, 
    2, 91, 4, 35, 0, 66, 6, 60, 1,  8, 8, 17, 5, 12, 7, 36, 3,  2, 
    5, 69, 4, 26, 2, 30, 1,  6, 8,  6, 3, 55, 6, 92, 0, 44, 7, 98, 
    4, 80, 1, 41, 7, 71, 5, 75, 8, 50, 3, 47, 6, 46, 0, 25, 2, 83
  };
  const int q2875[] = {
    9, 9, // Number of jobs and machines
    3,  6, 2,  3, 0, 22, 7, 12, 1, 85, 8, 15, 6, 50, 4, 47, 5, 97, 
    4, 34, 0, 58, 6, 65, 5, 58, 2, 83, 7, 16, 3, 34, 1, 34, 8, 60, 
    2, 51, 6, 48, 1, 20, 7, 34, 4, 46, 8,  3, 3, 17, 5, 71, 0, 47, 
    0, 40, 4, 98, 7, 44, 8, 70, 2, 28, 3, 72, 6,  2, 5, 82, 1, 95, 
    0, 74, 4,  3, 3, 59, 5, 50, 8, 13, 7, 15, 1, 34, 2,  4, 6, 25, 
    3, 16, 5, 99, 6, 47, 2, 94, 0, 92, 7,  4, 1, 96, 4, 37, 8,  3, 
    4, 72, 6, 24, 8, 97, 5, 33, 2, 87, 3, 17, 7, 93, 0, 26, 1, 84, 
    1, 67, 2, 67, 0, 60, 5, 90, 7, 13, 6, 79, 3, 95, 8,  5, 4, 48, 
    6, 62, 3, 99, 7, 22, 5,  5, 0, 68, 2, 71, 1,  1, 8, 61, 4, 93
  };
  const int q2876[] = {
    9, 9, // Number of jobs and machines
    7, 19, 5, 81, 1, 36, 4, 74, 3, 45, 6, 81, 8, 56, 2, 69, 0, 28, 
    4, 52, 1, 16, 2, 18, 3, 60, 6, 91, 5, 35, 7, 27, 0, 70, 8, 16, 
    2, 16, 7, 45, 5, 52, 6, 18, 8, 29, 0, 31, 1, 42, 4, 14, 3, 11, 
    7, 44, 0, 74, 1, 71, 4, 60, 8, 32, 2, 88, 5, 64, 3, 89, 6, 95, 
    5, 71, 2, 98, 6, 19, 7, 92, 1, 24, 8, 42, 4, 80, 3, 97, 0, 38, 
    8, 24, 1, 30, 3, 95, 0, 56, 5, 10, 7, 36, 4, 86, 6, 22, 2, 85, 
    8, 29, 0, 74, 5, 58, 4, 44, 6, 98, 1, 32, 3, 63, 2, 78, 7,  1, 
    5, 92, 8, 52, 2,  3, 7, 68, 6, 76, 1, 35, 0, 85, 4, 36, 3, 13, 
    3, 88, 0, 28, 4, 91, 8, 57, 6, 60, 1, 45, 7,  2, 2, 25, 5, 31
  };
  const int q2877[] = {
    9, 9, // Number of jobs and machines
    4, 91, 1, 13, 8, 82, 5,  3, 3, 73, 0, 22, 2, 51, 7, 83, 6, 81, 
    4, 76, 5, 65, 2, 53, 0,  4, 1, 23, 7,  5, 6, 68, 3, 13, 8, 68, 
    8, 26, 3, 95, 0, 27, 6, 39, 7, 31, 2, 74, 1, 55, 5, 59, 4, 60, 
    7, 73, 1, 88, 3, 74, 6, 85, 8, 59, 2, 23, 0, 88, 4, 27, 5, 70, 
    1, 83, 8, 42, 4, 35, 6, 67, 0, 46, 7, 81, 3, 36, 5, 46, 2, 35, 
    5, 60, 3, 84, 8, 37, 7, 14, 4, 74, 0, 14, 6,  6, 1, 43, 2, 24, 
    4, 69, 5, 59, 0,  6, 6, 65, 1, 79, 3,  1, 7, 56, 8, 45, 2, 31, 
    7, 49, 6, 45, 0, 13, 2, 77, 5,  2, 1, 27, 4, 29, 8, 64, 3, 61, 
    2,  6, 4, 45, 8, 60, 6, 41, 0, 83, 7, 83, 3, 48, 1, 53, 5, 73
  };
  const int q2878[] = {
    9, 9, // Number of jobs and machines
    6, 13, 8, 95, 7, 50, 2, 63, 5, 84, 1,  4, 3, 24, 0, 73, 4, 63, 
    8, 43, 6, 66, 5, 63, 1, 59, 7, 84, 2, 82, 3, 26, 4, 72, 0, 41, 
    8, 65, 6, 67, 7, 81, 3, 61, 5, 28, 0, 71, 4, 33, 2, 95, 1, 27, 
    8, 93, 6, 40, 4, 64, 3, 71, 5, 84, 7, 15, 0, 51, 1, 87, 2, 55, 
    1,  8, 4, 52, 2, 60, 6, 83, 0, 67, 3, 52, 8, 34, 7, 25, 5, 46, 
    8, 21, 6, 65, 2, 83, 4, 91, 3, 15, 5, 80, 0,  2, 7, 26, 1, 64, 
    1,  7, 2, 15, 5, 58, 7,  9, 0, 49, 3, 14, 8, 33, 6,  7, 4,  4, 
    2, 74, 7, 94, 0, 44, 3, 44, 5, 89, 1,  7, 6, 45, 8, 73, 4, 83, 
    8, 67, 1, 23, 4, 12, 2, 55, 6, 42, 0, 41, 5, 89, 7, 23, 3, 55
  };
  const int q2879[] = {
    9, 9, // Number of jobs and machines
    1,  2, 5, 41, 4, 68, 2, 18, 3, 42, 8, 10, 0, 62, 6, 66, 7, 17, 
    4, 77, 1, 50, 2, 15, 0, 44, 3, 63, 6, 97, 7, 24, 5, 98, 8, 60, 
    6, 70, 7, 33, 3, 49, 5, 94, 4, 21, 1, 46, 8, 35, 2, 27, 0, 25, 
    1, 39, 2, 58, 7, 83, 6, 90, 5, 37, 3, 92, 8, 56, 0, 56, 4, 34, 
    4, 77, 7, 24, 3,  2, 6, 90, 2, 10, 5, 68, 1, 34, 0, 66, 8, 14, 
    8, 51, 6, 52, 5, 30, 3, 37, 1, 34, 7, 55, 2, 91, 4, 60, 0, 15, 
    1, 95, 3, 76, 7, 21, 4, 40, 0, 72, 6, 22, 5, 68, 8, 76, 2, 43, 
    2, 53, 8, 36, 1, 51, 5, 31, 7, 82, 4, 27, 3, 94, 6, 51, 0, 70, 
    7, 43, 4, 21, 5, 61, 2, 56, 0, 87, 8, 50, 3, 61, 1, 64, 6, 88
  };
  const int q2880[] = {
    9, 9, // Number of jobs and machines
    3, 93, 4, 38, 6, 92, 1, 30, 7, 95, 8,  4, 2, 29, 5, 64, 0, 72, 
    7, 53, 4, 69, 6, 31, 1, 71, 2, 36, 3, 27, 5, 73, 0, 69, 8, 97, 
    4,  7, 7, 60, 0, 47, 8, 64, 1, 96, 3, 80, 2,  4, 5, 71, 6, 92, 
    6, 94, 1,  7, 0, 67, 5, 15, 7, 17, 3, 71, 8, 86, 4, 32, 2, 21, 
    7, 13, 6, 96, 1, 78, 4, 33, 2, 62, 5, 35, 8, 49, 0, 34, 3, 79, 
    7, 42, 0, 25, 5, 47, 3, 53, 1,  4, 4, 63, 6, 15, 2,  2, 8, 65, 
    1, 80, 7, 36, 8, 70, 3, 19, 5, 20, 6, 38, 0, 46, 4, 18, 2, 52, 
    8, 42, 1, 25, 6, 20, 7, 58, 3, 30, 4, 55, 2, 26, 5, 60, 0, 85, 
    0, 83, 8, 75, 1, 53, 2, 60, 6, 56, 7, 38, 4,  5, 5, 20, 3, 46
  };
  const int q2881[] = {
    9, 9, // Number of jobs and machines
    2, 89, 5, 97, 7, 41, 3, 10, 1, 13, 4, 95, 8,  4, 6, 17, 0, 58, 
    1, 49, 3, 89, 2, 90, 8, 17, 5, 80, 7, 44, 0, 98, 4, 46, 6, 47, 
    4, 73, 3, 37, 0, 85, 8, 97, 5, 58, 6,  5, 1, 56, 2, 35, 7, 31, 
    8, 63, 0, 99, 4, 66, 6, 47, 2, 17, 3, 93, 5, 44, 1, 85, 7, 17, 
    8, 59, 3, 91, 1, 24, 2, 86, 4, 17, 6, 90, 7, 96, 5, 76, 0, 37, 
    3, 95, 4, 91, 0, 48, 6, 82, 5,  1, 8, 72, 2, 69, 1, 36, 7, 55, 
    5,  7, 2, 25, 3, 45, 4, 47, 0, 53, 1, 75, 7,  3, 6,  9, 8, 97, 
    4, 86, 5, 71, 7, 37, 8, 42, 2, 91, 0, 32, 3, 39, 6, 14, 1, 71, 
    8, 60, 1, 96, 0, 46, 2, 69, 6, 37, 7, 55, 5, 34, 4, 76, 3, 18
  };
  const int q2882[] = {
    9, 9, // Number of jobs and machines
    3, 21, 4, 61, 7, 71, 6, 78, 1, 82, 8, 40, 5, 60, 2,  7, 0, 14, 
    8, 48, 2, 93, 6, 14, 7, 10, 0, 83, 1, 91, 4, 46, 3, 36, 5, 54, 
    1, 22, 2, 19, 3, 31, 5, 40, 8, 59, 4, 92, 7, 30, 0, 27, 6, 28, 
    7, 58, 3, 40, 4, 83, 5,  1, 6, 35, 8, 25, 2, 29, 0, 86, 1, 67, 
    4, 52, 0, 88, 1, 66, 5, 96, 2, 20, 8, 51, 7, 19, 3, 64, 6, 11, 
    8, 34, 4, 17, 7,  2, 6,  1, 3, 69, 0, 79, 2, 45, 5, 96, 1, 86, 
    0, 21, 8, 85, 6, 52, 3, 45, 4, 89, 1, 69, 5,  6, 2, 35, 7, 75, 
    7, 42, 4, 89, 3, 97, 8,  6, 1, 35, 2, 49, 5, 76, 6,  4, 0, 38, 
    8, 14, 7, 73, 6, 65, 5, 35, 2, 43, 0, 62, 4, 71, 3, 75, 1, 36
  };
  const int q2883[] = {
    9, 9, // Number of jobs and machines
    3, 13, 7, 69, 4, 11, 8, 57, 1, 94, 0, 90, 2, 11, 5, 32, 6, 64, 
    8,  5, 6, 96, 3, 92, 4, 41, 2, 40, 0, 57, 1, 38, 7, 46, 5, 55, 
    3, 31, 7, 87, 0, 68, 2, 22, 8, 16, 1, 91, 5, 69, 4, 35, 6, 91, 
    3, 60, 4, 65, 0, 49, 1, 98, 8, 63, 2, 87, 6, 33, 5, 87, 7, 80, 
    6, 85, 0, 57, 2, 56, 5,  9, 7, 58, 3, 37, 4, 92, 8,  3, 1, 18, 
    0, 68, 2, 52, 7, 73, 5, 71, 4,  9, 6, 82, 8, 14, 3, 20, 1, 91, 
    4, 80, 5, 54, 2, 29, 0, 49, 3, 41, 8, 23, 7, 63, 1, 58, 6,  3, 
    0,  2, 8, 46, 7, 69, 3, 73, 4, 58, 5, 58, 6, 62, 1, 96, 2, 30, 
    2, 94, 3, 80, 1, 67, 5, 23, 6, 71, 0, 65, 8, 47, 4, 77, 7, 17
  };
  const int q2884[] = {
    9, 9, // Number of jobs and machines
    8, 47, 5, 79, 1, 58, 7,  5, 0, 84, 2, 79, 4, 97, 3,  3, 6, 33, 
    8, 96, 1, 54, 2, 64, 5, 18, 7, 28, 6,  5, 0, 80, 4, 38, 3, 93, 
    7, 78, 6, 83, 0, 82, 2, 78, 5, 17, 1, 78, 4, 52, 8,  2, 3, 31, 
    0, 35, 3, 30, 2, 53, 6, 95, 1, 89, 4, 15, 5, 54, 8,  4, 7, 75, 
    3, 87, 7, 11, 2, 30, 4,  2, 6, 44, 0, 59, 8, 74, 1, 44, 5, 98, 
    7, 96, 2, 73, 0, 25, 4, 82, 8, 80, 3, 67, 6, 46, 1, 77, 5, 21, 
    5,  5, 6, 87, 7, 46, 0, 78, 1, 15, 2, 26, 3, 80, 8, 86, 4, 40, 
    8, 99, 7, 75, 6,  1, 3, 32, 0, 60, 5, 22, 4, 36, 2,  7, 1, 64, 
    3, 72, 4, 49, 0, 36, 8, 89, 6, 40, 5, 44, 2, 12, 1, 62, 7,  2
  };
  const int q2885[] = {
    9, 9, // Number of jobs and machines
    3, 93, 2,  6, 1,  4, 6, 46, 7, 30, 4, 49, 5, 89, 8, 47, 0, 88, 
    6, 73, 2, 88, 3, 33, 4, 20, 7, 82, 1, 44, 5, 99, 0, 70, 8, 18, 
    0, 51, 4, 40, 1, 76, 7,  2, 5, 96, 8, 65, 3, 44, 6, 30, 2, 64, 
    3, 88, 0, 21, 2, 43, 8, 81, 5, 57, 6, 72, 1, 39, 7, 10, 4, 70, 
    1, 67, 2, 55, 6,  7, 4, 27, 5, 89, 7, 68, 3, 27, 8, 27, 0, 76, 
    7, 14, 5, 89, 3,  1, 0, 99, 4, 82, 6, 66, 1, 94, 8, 44, 2, 40, 
    1, 20, 8, 18, 4, 81, 6, 25, 5, 65, 2, 47, 7,  5, 3, 54, 0,  6, 
    4, 98, 3, 15, 8, 34, 7, 98, 1, 10, 2, 99, 6, 44, 0, 82, 5, 56, 
    8, 12, 3, 36, 7, 26, 1, 86, 5, 41, 4, 49, 6, 28, 2, 56, 0, 20
  };
  const int q2886[] = {
    9, 9, // Number of jobs and machines
    4, 91, 6, 98, 1, 70, 5, 18, 8, 81, 7, 95, 2,  9, 0, 98, 3,  8, 
    1, 57, 5, 25, 6, 39, 7, 27, 0, 43, 3, 43, 2,  8, 4, 59, 8, 50, 
    5, 90, 0, 83, 1, 31, 3, 37, 7, 59, 4, 43, 8, 90, 2, 48, 6, 12, 
    3,  3, 0, 23, 4, 48, 6, 99, 2, 56, 1, 18, 7, 28, 5,  4, 8, 88, 
    3, 99, 8, 88, 7, 90, 6, 74, 5, 97, 1, 74, 0, 42, 2, 76, 4, 67, 
    0, 50, 8, 28, 7, 35, 4, 18, 5, 12, 2, 76, 3, 37, 6, 93, 1, 75, 
    4, 93, 2, 43, 5, 42, 6, 11, 1, 35, 8, 37, 3, 64, 7, 30, 0, 37, 
    8, 51, 5, 91, 3,  9, 7, 72, 2, 45, 1,  3, 4, 96, 6, 30, 0, 68, 
    2, 13, 4, 45, 0, 27, 1, 38, 7, 32, 8, 65, 5, 36, 3,  5, 6,  6
  };
  const int q2887[] = {
    9, 9, // Number of jobs and machines
    4,  6, 2, 57, 3, 19, 1, 44, 8,  4, 0, 77, 5, 60, 6, 55, 7, 82, 
    6, 13, 2, 44, 5, 43, 3, 19, 4,  2, 7, 23, 1, 92, 8,  9, 0, 69, 
    3, 27, 2, 53, 6, 71, 7, 64, 0, 20, 5, 70, 1, 83, 8, 44, 4, 90, 
    2, 77, 3, 28, 1, 94, 8, 94, 5, 32, 7, 41, 6, 86, 4, 43, 0, 27, 
    8, 71, 2, 62, 7, 94, 4, 91, 3, 60, 6, 45, 0, 86, 5, 56, 1, 16, 
    6, 58, 8, 39, 3, 14, 0, 97, 1, 12, 4, 55, 2, 95, 7, 88, 5, 70, 
    2,  4, 1, 73, 7,  6, 3, 45, 4, 26, 6, 54, 8, 17, 0, 11, 5, 91, 
    3, 94, 2, 61, 8, 16, 6, 69, 0, 40, 1, 96, 7, 99, 4, 84, 5, 66, 
    5, 31, 0, 46, 6, 66, 7, 11, 4, 71, 2, 11, 3, 32, 8, 33, 1, 91
  };
  const int q2888[] = {
    9, 9, // Number of jobs and machines
    3, 83, 0, 87, 1, 91, 8, 56, 5, 11, 4, 34, 7, 11, 6, 16, 2, 63, 
    1, 80, 3, 59, 0,  1, 7, 93, 8, 71, 6, 28, 4, 21, 5, 56, 2,  2, 
    7, 20, 6, 32, 1, 72, 0, 85, 3, 75, 2,  4, 8, 14, 4, 19, 5, 94, 
    2,  7, 0, 61, 6, 88, 5, 28, 3, 19, 7, 26, 1, 34, 4, 28, 8, 68, 
    2, 27, 1, 75, 4,  3, 5, 45, 6,  4, 7, 29, 8, 39, 3, 72, 0, 71, 
    4, 20, 1, 49, 2, 40, 0, 96, 5, 35, 7, 79, 6, 97, 3, 64, 8, 43, 
    3, 81, 4, 85, 6, 11, 0, 72, 2,  3, 8,  9, 5, 15, 1, 90, 7,  3, 
    2, 35, 8, 63, 5, 66, 6, 54, 4, 67, 1, 17, 0, 63, 3,  3, 7, 35, 
    3,  2, 7,  9, 1,  5, 6, 97, 0, 58, 4, 19, 2, 42, 8, 87, 5, 27
  };
  const int q2889[] = {
    9, 9, // Number of jobs and machines
    3, 69, 0, 72, 5, 77, 1, 83, 6, 64, 2,  1, 4, 58, 8, 87, 7, 85, 
    4, 21, 3, 95, 1, 45, 2, 83, 0, 35, 5, 45, 8, 54, 6, 63, 7, 49, 
    5, 86, 0, 81, 2, 30, 4, 26, 8, 25, 1, 34, 3, 26, 7, 87, 6, 78, 
    8, 23, 5, 11, 3, 55, 7,  7, 2, 71, 1, 93, 0, 28, 4, 80, 6, 86, 
    3, 23, 2, 34, 7, 44, 5, 92, 8, 82, 1, 43, 6, 55, 0, 91, 4,  3, 
    0, 87, 3, 95, 1, 56, 6, 43, 7, 58, 4, 37, 2, 17, 8, 65, 5, 74, 
    1, 73, 8, 23, 4, 52, 0, 45, 2, 35, 7, 58, 6,  5, 3, 10, 5, 72, 
    0, 54, 7, 56, 6, 43, 4, 63, 8, 63, 2, 53, 1, 88, 5,  9, 3, 92, 
    6, 33, 8, 35, 1, 78, 2, 94, 3, 26, 4, 59, 5, 62, 0, 15, 7, 56
  };
  const int q2890[] = {
    9, 9, // Number of jobs and machines
    1, 28, 6, 89, 0, 23, 4, 88, 3, 28, 8, 99, 7, 42, 5, 35, 2, 85, 
    4, 36, 6,  9, 7, 76, 8, 64, 3, 97, 1, 70, 5,  9, 2,  8, 0, 75, 
    2,  4, 8, 69, 7, 87, 5, 76, 3, 28, 4, 54, 6, 73, 1, 12, 0, 90, 
    1, 71, 8, 56, 3, 22, 0, 79, 2, 98, 5, 74, 7, 71, 6, 47, 4, 25, 
    8, 48, 2, 99, 5, 69, 7,  5, 0, 90, 6, 11, 1, 12, 4, 28, 3, 33, 
    3, 45, 0, 69, 5, 93, 1, 59, 2, 70, 6, 74, 8, 20, 4, 38, 7, 73, 
    0, 36, 4, 34, 6, 45, 3, 27, 7, 32, 8, 51, 1, 69, 2, 13, 5, 14, 
    4, 18, 1, 89, 0, 68, 5,  8, 8,  3, 3, 25, 6, 40, 2, 54, 7, 17, 
    8, 81, 5, 13, 7, 55, 6, 90, 0,  8, 4, 74, 1, 38, 2, 21, 3, 31
  };
  const int q2891[] = {
    9, 9, // Number of jobs and machines
    8, 27, 3,  3, 7, 67, 5, 13, 1, 86, 2, 33, 4, 15, 0, 78, 6, 28, 
    4, 13, 2, 80, 5, 47, 8, 82, 7, 20, 3, 17, 1, 81, 0, 26, 6, 31, 
    8, 10, 4, 17, 6, 66, 1,  1, 0, 14, 5, 51, 2, 40, 3, 75, 7, 80, 
    5, 41, 0, 16, 2, 35, 3, 57, 6, 83, 1, 28, 4, 80, 8, 67, 7, 80, 
    4, 96, 3, 58, 6, 92, 2, 97, 8, 95, 0, 57, 5, 99, 1, 17, 7, 57, 
    3, 36, 1,  7, 2, 60, 0, 95, 8, 58, 4, 99, 7, 76, 6, 76, 5, 18, 
    3, 36, 1, 30, 8, 19, 2, 75, 5, 84, 0, 10, 6, 17, 7, 57, 4, 23, 
    6, 72, 3,  4, 0, 26, 1, 40, 4, 63, 8, 64, 7, 90, 5, 78, 2, 16, 
    8, 30, 5, 43, 2, 91, 7, 15, 6, 65, 1,  2, 0, 23, 4,  4, 3, 54
  };
  const int q2892[] = {
    9, 9, // Number of jobs and machines
    1, 44, 4, 11, 6, 35, 8, 91, 5, 89, 3, 75, 2,  3, 7, 51, 0, 17, 
    5, 20, 8, 97, 1, 91, 4, 64, 2, 91, 7, 50, 0, 30, 6, 97, 3, 25, 
    4,  6, 6, 72, 1, 63, 8,  3, 0, 94, 3, 19, 5, 64, 2, 70, 7, 14, 
    0,  7, 7, 69, 3, 64, 2, 68, 4, 83, 8,  4, 5, 61, 1, 98, 6, 23, 
    1, 42, 3, 45, 8, 51, 2,  9, 7, 30, 6, 56, 4, 76, 5, 89, 0, 56, 
    7, 40, 6, 49, 1,  5, 5, 90, 2, 61, 0, 20, 4,  1, 3, 41, 8, 71, 
    0, 21, 7, 77, 2,  9, 4, 79, 3, 45, 6, 53, 1, 32, 5, 24, 8, 11, 
    7,  8, 5, 41, 3, 93, 0, 15, 4, 99, 8, 14, 6, 17, 1, 34, 2, 94, 
    1, 43, 4, 96, 8, 97, 2,  6, 5, 85, 3, 16, 7, 74, 0, 51, 6, 15
  };
  const int q2893[] = {
    9, 9, // Number of jobs and machines
    8, 27, 5, 28, 3, 99, 1, 49, 7, 16, 0, 38, 4, 13, 2, 63, 6, 18, 
    5, 86, 0,  5, 7, 11, 6, 84, 4, 22, 2, 33, 1, 73, 8, 23, 3, 90, 
    3, 54, 5, 23, 1, 77, 6, 97, 8, 60, 0, 65, 4, 80, 2, 21, 7, 14, 
    7, 73, 4, 28, 0, 28, 5, 90, 6, 82, 8, 75, 1, 91, 2, 63, 3, 75, 
    4,  6, 1, 63, 3, 58, 5, 66, 0, 31, 2,  1, 6, 31, 7, 82, 8, 61, 
    8, 99, 1, 23, 4, 12, 6, 49, 0, 35, 3, 62, 2, 40, 7, 23, 5, 49, 
    0, 52, 3, 68, 5, 70, 7, 61, 4,  9, 2, 62, 1, 76, 8, 52, 6,  8, 
    2, 68, 8, 46, 4, 52, 3, 66, 0, 10, 5,  5, 6, 95, 7, 15, 1, 48, 
    0, 61, 6, 26, 4, 82, 5, 40, 2, 56, 3, 83, 7, 21, 1, 49, 8, 72
  };
  const int q2894[] = {
    9, 9, // Number of jobs and machines
    6, 90, 0, 25, 3, 32, 7, 45, 4, 26, 2, 10, 8, 59, 1, 34, 5, 79, 
    4, 40, 3, 29, 2, 89, 5, 90, 6, 42, 7, 43, 1, 37, 0, 47, 8, 29, 
    3, 81, 2, 37, 7, 52, 0, 72, 6, 16, 8, 93, 5, 54, 4, 94, 1,  3, 
    3, 27, 8, 52, 0,  2, 4,  6, 5, 29, 7, 73, 2, 18, 1, 49, 6, 11, 
    3, 98, 6,  1, 4, 79, 2, 67, 1, 71, 0, 96, 8, 14, 7, 34, 5,  4, 
    1, 97, 8, 98, 2, 98, 5, 38, 3, 83, 6, 55, 4,  1, 0, 67, 7, 39, 
    8, 13, 2, 57, 1, 12, 4, 40, 7, 49, 5, 84, 3, 68, 6, 84, 0, 31, 
    2, 38, 3, 94, 8, 14, 0, 94, 6, 90, 1, 59, 5, 37, 4,  9, 7, 52, 
    3, 63, 5, 75, 6, 99, 4, 66, 7, 77, 0, 74, 2, 61, 1,  8, 8, 60
  };
  const int q2895[] = {
    9, 9, // Number of jobs and machines
    5, 37, 4, 25, 8, 41, 2, 22, 1, 13, 7, 75, 6,  8, 3, 21, 0, 31, 
    6, 51, 1, 59, 5, 89, 0, 75, 2, 27, 8, 99, 7, 85, 4, 30, 3, 26, 
    5, 45, 2, 35, 1, 88, 4, 10, 3, 89, 6,  7, 7, 42, 8, 93, 0, 60, 
    2, 50, 0, 54, 8, 55, 7, 80, 5, 11, 1,  2, 4, 98, 3, 12, 6, 70, 
    5, 79, 7, 81, 4,  6, 1, 10, 3, 44, 0, 77, 2, 66, 6, 57, 8, 10, 
    6, 54, 4,  8, 7, 95, 1,  6, 5, 33, 8, 23, 0, 58, 2, 74, 3, 92, 
    5, 20, 4, 25, 3, 42, 6, 81, 8, 75, 2,  1, 7, 72, 0, 75, 1, 18, 
    0, 99, 2, 28, 8, 18, 5, 72, 7, 91, 3, 35, 6, 53, 4, 17, 1, 83, 
    1, 54, 3, 89, 8, 96, 7, 46, 6, 94, 2, 33, 4, 42, 5, 26, 0, 34
  };
  const int q2896[] = {
    9, 9, // Number of jobs and machines
    1, 64, 2, 85, 5, 61, 6, 78, 8, 61, 3, 54, 7, 19, 4, 17, 0, 59, 
    3,  8, 2, 64, 5, 14, 8, 72, 7,  6, 4, 54, 6, 79, 1, 52, 0,  9, 
    6, 63, 2, 92, 0, 32, 7, 60, 3, 72, 8, 73, 1, 50, 5, 81, 4, 75, 
    3, 69, 7, 14, 5, 81, 4, 81, 6, 36, 2, 32, 8, 44, 1,  6, 0, 68, 
    0, 66, 7, 91, 5, 75, 8, 47, 6, 89, 4, 11, 3, 10, 1, 11, 2, 12, 
    7, 48, 3, 93, 6,  8, 4, 66, 8, 47, 1,  8, 2, 52, 5, 53, 0, 71, 
    5, 27, 3, 36, 8, 64, 1,  8, 2, 38, 7, 70, 6, 77, 0, 53, 4, 58, 
    7,  2, 2, 65, 6, 38, 8, 84, 4, 69, 0, 32, 5, 10, 3, 96, 1, 97, 
    8, 63, 4, 96, 5, 51, 2, 42, 1, 76, 7,  8, 0, 22, 6, 13, 3, 79
  };
  const int q2897[] = {
    9, 9, // Number of jobs and machines
    1, 58, 7, 82, 2, 39, 8, 55, 0, 74, 4,  6, 5, 22, 3, 81, 6,  2, 
    8, 60, 2, 98, 0, 94, 5, 38, 6, 93, 1, 88, 7, 31, 4, 89, 3, 24, 
    4,  5, 5, 67, 2, 63, 7, 37, 1, 63, 0, 53, 3, 13, 8, 12, 6, 90, 
    0, 48, 3, 96, 1,  7, 4, 29, 8, 77, 6,  5, 2, 41, 5, 57, 7, 37, 
    5, 87, 1, 97, 3, 79, 7, 52, 4, 68, 8, 19, 0, 16, 2, 50, 6, 72, 
    1, 85, 3, 32, 7, 21, 8, 95, 6, 64, 0, 95, 5, 56, 2, 60, 4, 98, 
    1, 29, 7, 44, 3, 36, 0, 17, 8, 66, 6, 70, 4, 46, 5,  2, 2, 69, 
    1, 30, 5, 56, 7, 54, 0, 25, 6, 78, 3, 54, 8, 23, 4, 73, 2, 14, 
    1, 40, 0, 62, 8, 71, 3, 40, 4, 14, 7, 57, 5, 69, 2, 70, 6, 86
  };
  const int q2898[] = {
    9, 9, // Number of jobs and machines
    3, 71, 7, 46, 1,  3, 0,  7, 2, 43, 8, 16, 6, 15, 5, 26, 4, 26, 
    0, 92, 6,  1, 2, 94, 8, 65, 7,  1, 5, 98, 4, 84, 3, 21, 1, 24, 
    7, 89, 0, 46, 4, 22, 8,  8, 2, 17, 5, 77, 6, 50, 1, 18, 3, 13, 
    6, 61, 5, 27, 0, 64, 1, 60, 2, 52, 3, 66, 4, 19, 8, 59, 7, 86, 
    6, 18, 7,  9, 8,  8, 0, 38, 4, 22, 2, 38, 1, 56, 5, 47, 3, 73, 
    3, 83, 0, 89, 8, 32, 6, 42, 2, 18, 1, 25, 7, 88, 5, 34, 4, 69, 
    1, 90, 8, 94, 7, 45, 2, 19, 3, 59, 5, 79, 4, 49, 0,  4, 6, 50, 
    2, 47, 4, 59, 1, 73, 5, 43, 0, 61, 7, 45, 8, 54, 6, 98, 3, 77, 
    8, 34, 4, 15, 2, 25, 5, 74, 1, 93, 6, 65, 3, 20, 7, 91, 0, 49
  };
  const int q2899[] = {
    9, 9, // Number of jobs and machines
    3, 50, 1, 70, 7, 42, 5, 50, 6, 15, 4, 94, 8,  5, 0, 87, 2, 85, 
    8, 69, 7, 69, 2, 77, 5,  2, 6, 15, 3, 93, 4, 42, 0,  4, 1, 56, 
    3, 47, 8, 37, 4, 64, 1, 61, 0, 22, 2, 26, 7, 55, 6, 79, 5, 87, 
    0, 23, 8, 33, 5, 18, 6, 55, 7,  6, 4, 42, 1, 38, 2, 20, 3, 39, 
    7, 43, 3, 20, 8, 52, 4, 38, 6, 58, 0, 17, 5, 80, 1,  8, 2, 84, 
    6, 79, 8, 50, 2, 88, 7, 73, 0, 83, 1, 33, 3, 17, 4,  7, 5, 32, 
    0, 15, 6,  2, 5, 65, 8, 39, 7, 48, 2, 23, 4, 56, 1, 36, 3, 50, 
    8, 74, 0, 36, 1, 50, 6, 26, 4, 42, 2,  1, 5, 47, 3,  6, 7, 85, 
    4, 34, 7, 20, 2, 17, 6, 21, 3, 32, 8, 53, 0, 66, 5, 74, 1,  4
  };
  const int q2900[] = {
    9, 9, // Number of jobs and machines
    2, 34, 6, 79, 5, 88, 3, 95, 1, 95, 0, 84, 4, 64, 7, 40, 8, 91, 
    0, 21, 8, 57, 1, 61, 6,  6, 4, 52, 5, 45, 3, 98, 2, 14, 7, 95, 
    3, 40, 4, 31, 1, 12, 6, 18, 8, 58, 7, 34, 5, 37, 0, 16, 2, 80, 
    6, 54, 0, 54, 4, 69, 2, 59, 5, 50, 3, 18, 7, 88, 8, 34, 1, 80, 
    6, 75, 1, 99, 0, 36, 7, 10, 8,  3, 2, 61, 5, 29, 4, 31, 3, 10, 
    2, 25, 5, 28, 3, 72, 7, 68, 6, 15, 4, 40, 8, 77, 0, 72, 1,  7, 
    0, 61, 1, 14, 7, 80, 8, 59, 6, 43, 2, 77, 4, 11, 5, 45, 3, 88, 
    5, 65, 6, 64, 1, 90, 3, 13, 8,  6, 4, 86, 7, 86, 2, 39, 0, 60, 
    7, 25, 4, 67, 1, 58, 8, 39, 6, 31, 5, 10, 2, 42, 3, 77, 0, 34
  };
  const int q2901[] = {
    9, 9, // Number of jobs and machines
    4, 28, 7, 21, 1, 52, 6, 87, 5, 65, 8, 18, 2, 72, 3, 39, 0, 88, 
    0, 11, 8, 30, 3, 19, 6, 21, 1, 58, 7,  6, 5,  7, 4, 48, 2, 68, 
    0,  3, 1, 95, 8, 68, 7, 76, 5, 58, 3, 45, 2, 83, 4, 51, 6,  9, 
    6,  4, 7, 40, 8, 17, 4, 69, 3, 60, 5, 85, 0, 49, 2, 93, 1, 94, 
    2,  9, 6, 40, 1, 43, 3, 49, 0, 69, 8, 35, 7, 96, 5, 50, 4, 69, 
    5, 35, 7, 73, 4, 81, 0,  1, 2, 20, 1, 44, 8,  2, 6, 43, 3, 99, 
    0, 47, 2, 52, 5, 74, 6, 67, 4, 18, 3,  8, 8, 12, 1, 90, 7, 20, 
    8,  2, 2, 87, 0, 69, 7, 94, 5,  7, 1, 75, 3, 93, 6, 17, 4, 86, 
    7,  9, 2, 24, 5, 41, 6, 86, 1, 86, 4, 59, 8, 75, 3, 29, 0, 87
  };
  const int q2902[] = {
    9, 9, // Number of jobs and machines
    6, 38, 8, 73, 1,  3, 2, 16, 3, 19, 0, 42, 7, 14, 5, 49, 4, 62, 
    3, 58, 8, 79, 4, 27, 2, 67, 7, 10, 1, 31, 6, 32, 0, 76, 5, 54, 
    0, 57, 2, 72, 1, 36, 4, 58, 7, 13, 5, 59, 8, 71, 6, 70, 3, 24, 
    2, 74, 3, 88, 8, 31, 0, 66, 6,  9, 7, 96, 1, 12, 5, 71, 4, 13, 
    8, 65, 7, 74, 6, 63, 1, 58, 0, 27, 3, 92, 5, 86, 4, 49, 2, 45, 
    0, 68, 7, 32, 4, 10, 5, 96, 3, 83, 2,  4, 6, 64, 1, 75, 8, 94, 
    4, 90, 2, 21, 0, 93, 7, 50, 3,  7, 5, 30, 1, 44, 6, 20, 8, 73, 
    5, 56, 4, 89, 1, 20, 2, 16, 6, 35, 3, 59, 7, 34, 8, 26, 0, 60, 
    4, 45, 2, 48, 1, 26, 5, 90, 0, 49, 3, 27, 7,  7, 8, 24, 6, 47
  };
  const int q2903[] = {
    9, 9, // Number of jobs and machines
    7, 11, 6,  4, 3, 78, 0, 97, 8, 53, 4, 44, 2, 95, 1, 45, 5, 25, 
    7, 46, 4, 63, 0,  6, 1, 29, 3, 75, 5, 85, 6, 61, 8, 41, 2, 90, 
    3, 31, 7, 96, 2, 88, 1, 79, 5, 33, 6, 83, 4, 15, 0, 36, 8, 26, 
    4, 44, 8, 39, 6,  8, 0, 30, 1, 66, 3, 93, 7,  5, 2, 53, 5, 83, 
    6,  6, 0, 51, 8, 64, 5, 68, 1, 88, 4, 28, 3, 67, 7, 26, 2, 21, 
    2, 77, 4,  4, 0, 52, 8, 55, 6, 74, 5, 53, 3, 30, 1, 83, 7, 74, 
    4, 54, 1, 21, 8, 61, 0,  5, 3, 82, 2, 91, 5, 47, 7, 85, 6, 94, 
    0, 52, 1, 11, 3, 11, 6, 27, 2, 78, 8, 59, 7, 33, 5, 46, 4, 75, 
    2, 56, 1, 15, 5, 44, 4, 37, 7,  1, 8, 56, 3, 52, 6, 16, 0, 19
  };
  const int q2904[] = {
    9, 9, // Number of jobs and machines
    8, 12, 3, 45, 6,  4, 2, 70, 4, 56, 7, 26, 5, 45, 0, 62, 1, 78, 
    8, 73, 1, 31, 5, 65, 0, 68, 2, 13, 6, 69, 3, 62, 4, 22, 7, 85, 
    2, 96, 3, 75, 5,  6, 7, 85, 6, 71, 1, 71, 0,  4, 8, 98, 4, 23, 
    4, 16, 6,  4, 0, 67, 2, 81, 3, 50, 1, 27, 7, 52, 8, 17, 5, 94, 
    6, 15, 1, 73, 2, 52, 0, 45, 3, 54, 5, 20, 4, 37, 7, 13, 8, 32, 
    2, 48, 4, 14, 6, 72, 0, 97, 7,  4, 3, 56, 5, 52, 1, 46, 8, 33, 
    7, 38, 4, 15, 8, 95, 3, 58, 2, 80, 1, 77, 6, 63, 0, 23, 5, 69, 
    6, 80, 2, 56, 7,  1, 3, 33, 4, 12, 1, 66, 5, 37, 8, 74, 0, 32, 
    3,  8, 7, 18, 4, 19, 2, 56, 8, 18, 6, 88, 5, 64, 0,  7, 1,  8
  };
  const int q2905[] = {
    9, 9, // Number of jobs and machines
    4, 45, 6, 60, 2, 62, 0, 97, 5, 90, 8, 54, 1,  4, 3, 45, 7, 48, 
    5, 66, 0, 33, 4, 77, 7, 60, 8,  4, 6, 68, 3, 39, 1, 90, 2, 44, 
    8, 70, 7, 50, 1, 45, 2, 13, 6, 18, 3, 99, 0, 58, 5, 21, 4, 69, 
    6, 31, 7, 11, 0, 20, 8, 53, 5, 48, 3, 17, 4, 27, 1,  1, 2, 28, 
    2, 41, 5, 47, 4, 77, 6, 12, 1, 19, 7, 27, 8, 47, 0, 30, 3, 64, 
    3,  3, 7,  4, 5, 93, 8, 26, 4, 40, 0, 56, 2, 31, 1, 43, 6, 42, 
    3, 88, 2, 27, 0, 36, 8, 23, 7, 42, 5, 25, 6,  8, 1, 25, 4, 66, 
    8, 55, 1, 11, 7, 97, 4, 89, 3, 64, 5,  7, 0, 65, 6, 41, 2, 78, 
    5, 95, 8, 62, 1, 51, 0, 71, 4, 12, 6, 86, 3, 93, 7, 14, 2, 81
  };
  const int q2906[] = {
    9, 9, // Number of jobs and machines
    4, 68, 3, 25, 5, 34, 0, 80, 7, 82, 1, 99, 6, 42, 2, 95, 8, 57, 
    1, 12, 7, 93, 6, 49, 5, 37, 0, 39, 8, 15, 2, 33, 3, 12, 4, 57, 
    3, 63, 5, 28, 4, 83, 8, 54, 0, 57, 6, 47, 2, 90, 1, 53, 7, 20, 
    2, 30, 5,  3, 6, 23, 7, 90, 0, 49, 8, 46, 4, 97, 3, 15, 1, 87, 
    1,  7, 8, 33, 4,  9, 3, 43, 7,  2, 0, 45, 5, 40, 2, 57, 6, 27, 
    7, 81, 3, 93, 5,  3, 8, 53, 2, 71, 6, 83, 0, 83, 1, 20, 4, 61, 
    3,  8, 7, 30, 8, 38, 5, 14, 0, 39, 6, 40, 2, 14, 4, 14, 1,  1, 
    6, 49, 5, 48, 2, 43, 1, 47, 3, 32, 4, 77, 8, 83, 0, 83, 7, 77, 
    3, 55, 6, 19, 1, 40, 2, 57, 8, 71, 0, 88, 4, 33, 7, 22, 5, 72
  };
  const int q2907[] = {
    9, 9, // Number of jobs and machines
    5, 44, 3, 39, 2, 57, 1, 13, 6, 21, 8, 48, 4, 93, 0, 72, 7, 81, 
    0,  5, 2, 79, 1, 11, 5, 42, 4,  6, 3, 52, 8, 94, 7, 98, 6, 59, 
    8, 76, 7,  6, 3, 30, 5, 89, 4, 10, 2, 16, 0, 93, 1, 58, 6, 61, 
    2, 81, 3, 78, 4, 35, 0, 41, 5, 58, 1, 90, 8, 91, 6, 59, 7, 46, 
    8, 28, 4, 53, 3, 38, 1, 38, 6,  5, 0, 35, 7, 52, 5, 21, 2, 21, 
    6, 29, 2, 83, 1,  8, 7, 47, 4, 99, 5, 63, 8, 66, 3, 22, 0, 65, 
    6, 60, 1, 83, 8, 16, 7, 77, 2, 17, 5, 94, 4, 47, 0, 82, 3, 33, 
    6, 22, 5, 12, 1, 83, 2, 33, 4, 26, 7, 22, 8, 74, 3, 10, 0, 33, 
    7, 75, 8, 23, 4, 54, 0, 73, 5, 60, 2, 39, 6,  6, 1, 65, 3, 19
  };
  const int q2908[] = {
    9, 9, // Number of jobs and machines
    8,  5, 3, 90, 1, 97, 6, 34, 2, 72, 4, 14, 0, 42, 5,  2, 7, 75, 
    0,  3, 2, 62, 3, 10, 5, 57, 8, 74, 4, 33, 7, 17, 6, 95, 1, 67, 
    2, 26, 1, 93, 7, 68, 5, 59, 6, 97, 0,  7, 8, 59, 4, 52, 3,  9, 
    4, 25, 1,  3, 3, 66, 7, 11, 6, 38, 5, 45, 0, 22, 2, 24, 8, 20, 
    8, 78, 1, 49, 6, 21, 3,  1, 7, 14, 5, 42, 4, 35, 2, 47, 0, 17, 
    4, 57, 1, 74, 8, 89, 0, 83, 7, 71, 5, 99, 3, 87, 6, 48, 2, 70, 
    5, 75, 4, 49, 6, 11, 8,  5, 0, 42, 2, 18, 7, 20, 1, 82, 3,  4, 
    6, 16, 8,  3, 7, 63, 5, 34, 1, 24, 0, 80, 3, 63, 2, 83, 4,  7, 
    5, 67, 3, 11, 7, 42, 6, 79, 4, 12, 1, 71, 0, 72, 8, 52, 2, 21
  };
  const int q2909[] = {
    9, 9, // Number of jobs and machines
    6, 84, 0, 93, 3, 97, 5,  5, 1, 97, 8, 86, 4,  4, 2, 44, 7, 73, 
    7, 14, 3, 33, 2, 41, 4, 16, 5, 75, 1,  1, 8, 40, 6, 69, 0, 67, 
    8, 69, 0, 10, 2, 50, 1, 90, 4, 61, 6,  3, 5, 33, 3, 70, 7, 15, 
    6, 90, 7, 37, 2, 56, 0, 48, 5, 70, 3, 36, 1, 38, 4, 48, 8, 73, 
    6,  8, 2, 68, 0, 13, 7, 11, 8, 27, 4, 24, 3, 81, 5, 77, 1, 99, 
    7, 37, 1, 64, 0, 53, 3, 43, 4, 92, 2, 36, 6, 20, 5, 84, 8, 44, 
    8, 34, 6,  2, 0,  7, 5, 30, 7, 16, 1, 10, 4,  2, 2, 63, 3, 23, 
    7,  6, 3, 82, 6, 96, 8, 29, 2, 11, 5, 82, 0,  8, 4,  8, 1, 33, 
    2, 52, 1,  3, 0, 84, 6,  9, 8, 76, 3, 66, 7, 26, 4, 44, 5, 95
  };
  const int q2910[] = {
    9, 9, // Number of jobs and machines
    0, 98, 3, 76, 8,  3, 6, 14, 5, 29, 1,  5, 7, 54, 4, 48, 2, 54, 
    3, 67, 6, 65, 5, 77, 7, 70, 0, 94, 1, 52, 2, 18, 4, 83, 8, 55, 
    5, 21, 3,  4, 8, 86, 0, 79, 2, 87, 6, 95, 7, 59, 1, 81, 4, 13, 
    6, 83, 1, 10, 8, 59, 4, 36, 0, 16, 3, 27, 5, 80, 7, 17, 2,  5, 
    8,  3, 5,  6, 7, 21, 2, 26, 3, 51, 6, 37, 1, 25, 0,  7, 4, 54, 
    5, 23, 0, 48, 2, 64, 8, 50, 6, 60, 3, 46, 7, 75, 1,  1, 4, 68, 
    1, 36, 2, 85, 4, 64, 3, 94, 6, 21, 5, 49, 8, 51, 0, 41, 7, 96, 
    7, 97, 4, 11, 6, 40, 3, 73, 2, 77, 5, 92, 8,  8, 1,  2, 0, 12, 
    6, 55, 1, 46, 3, 89, 8, 90, 4,  2, 5, 77, 2, 22, 7, 82, 0, 51
  };
  const int q2911[] = {
    9, 9, // Number of jobs and machines
    5, 95, 6, 84, 8, 51, 4, 22, 1, 45, 3, 86, 7, 40, 0,  9, 2, 33, 
    1, 37, 5, 94, 8, 52, 2, 52, 3, 40, 7, 51, 4, 90, 6, 27, 0,  9, 
    1, 33, 3, 27, 4, 97, 5, 98, 8, 92, 0, 71, 2, 85, 6, 51, 7,  4, 
    1, 24, 6, 10, 2, 66, 7,  4, 4,  7, 3, 28, 8, 62, 5, 25, 0, 96, 
    4,  9, 2, 56, 7, 89, 6, 42, 8, 13, 3, 96, 5, 40, 1, 56, 0, 31, 
    2, 73, 4, 60, 3, 12, 8, 25, 1, 72, 5, 91, 0, 28, 6, 82, 7, 48, 
    1, 89, 6, 73, 2, 26, 3, 98, 5, 58, 8, 87, 7,  1, 4, 82, 0, 16, 
    8, 61, 3,  7, 0,  9, 4, 15, 1, 79, 5,  2, 2, 31, 6, 16, 7, 22, 
    4,  9, 7, 14, 3, 91, 0, 99, 5, 36, 1, 27, 6, 74, 2, 22, 8, 88
  };
  const int q2912[] = {
    9, 9, // Number of jobs and machines
    6, 96, 0, 56, 1, 66, 7, 62, 5, 10, 8, 67, 3, 38, 2, 39, 4, 68, 
    0, 68, 5, 75, 4, 33, 7, 77, 2,  6, 3, 66, 6, 30, 1, 45, 8, 74, 
    4, 15, 1, 81, 5, 59, 2, 41, 3, 82, 8,  5, 7, 67, 0, 71, 6, 16, 
    0, 17, 5, 75, 1, 18, 4,  5, 3, 54, 2, 42, 8, 40, 7, 10, 6, 94, 
    7, 81, 8, 64, 4, 57, 3,  8, 2, 25, 0, 90, 6,  4, 5, 54, 1, 23, 
    0, 32, 1, 40, 2, 62, 8, 70, 5, 93, 4, 55, 7, 59, 6, 43, 3, 99, 
    4, 98, 2, 61, 6, 24, 7, 60, 0, 69, 8, 51, 5,  2, 3, 14, 1, 87, 
    0, 28, 6, 31, 2, 68, 3, 58, 5, 65, 8, 43, 1, 82, 7, 57, 4, 67, 
    8, 73, 7, 97, 3, 49, 0,  8, 6, 96, 4, 84, 1, 81, 5, 64, 2, 32
  };
  const int q2913[] = {
    9, 9, // Number of jobs and machines
    6, 50, 5, 45, 8, 86, 1, 72, 4, 94, 3, 42, 0, 26, 7, 12, 2, 94, 
    0, 87, 1, 82, 5, 92, 8,  1, 4, 57, 2, 89, 6, 65, 3, 26, 7, 90, 
    0, 93, 4, 47, 8, 48, 2, 90, 6, 85, 5, 14, 1, 17, 3, 80, 7, 52, 
    7, 66, 0, 94, 4, 19, 2, 81, 5, 20, 6, 68, 8, 73, 3, 93, 1, 59, 
    5, 38, 0, 35, 1,  6, 2, 81, 7, 60, 8, 12, 3, 93, 4, 23, 6,  5, 
    0, 99, 3, 94, 2, 12, 6, 18, 4, 78, 1, 15, 8, 15, 7,  9, 5, 27, 
    4,  3, 5,  4, 1, 97, 7, 67, 6, 23, 0,  8, 3, 72, 2, 91, 8, 41, 
    6,  4, 0, 81, 1, 79, 2, 58, 8, 29, 4, 50, 5, 20, 3, 56, 7, 35, 
    6,  1, 4, 38, 1, 58, 8,  4, 3, 41, 5, 13, 0, 59, 2, 80, 7, 47
  };
  const int q2914[] = {
    9, 9, // Number of jobs and machines
    0, 27, 3, 31, 1, 23, 2, 87, 6, 46, 8, 47, 7, 13, 4, 15, 5, 12, 
    2, 27, 8, 88, 3, 32, 6, 50, 1, 64, 5,  4, 7, 64, 0, 46, 4, 30, 
    2, 70, 6, 46, 1, 88, 0, 24, 4, 15, 5, 13, 8,  1, 3, 77, 7, 41, 
    0, 20, 7, 53, 5, 75, 1, 79, 8, 18, 2, 97, 3,  7, 4, 44, 6, 66, 
    2,  5, 3, 53, 8, 78, 6,  4, 5, 74, 7, 79, 0,  5, 1, 42, 4, 59, 
    0, 20, 1, 85, 5, 41, 3, 82, 7, 67, 4, 79, 6, 51, 2, 51, 8, 32, 
    8,  3, 7, 38, 4, 69, 6, 74, 0, 66, 2, 28, 3, 58, 1, 51, 5, 22, 
    1, 98, 4, 37, 7, 31, 3, 86, 2, 26, 6,  7, 5, 76, 8, 66, 0, 53, 
    3, 66, 7, 42, 1, 12, 5, 56, 0, 91, 2, 27, 8, 36, 4, 57, 6, 46
  };
  const int q2915[] = {
    9, 9, // Number of jobs and machines
    4, 85, 8, 14, 7, 16, 0, 56, 6, 70, 5, 33, 1, 59, 2, 15, 3, 98, 
    7, 47, 0, 37, 8, 17, 6, 32, 3, 10, 1, 86, 4, 70, 5,  9, 2, 78, 
    7, 70, 0, 60, 4, 29, 8, 35, 1, 82, 2, 66, 5, 82, 6, 43, 3, 12, 
    8, 83, 3, 12, 2, 26, 1, 57, 7, 79, 6, 62, 5, 37, 0, 67, 4, 88, 
    4, 53, 8, 88, 5, 31, 2, 94, 7, 82, 6, 53, 0, 65, 3, 64, 1, 13, 
    7,  1, 3, 36, 2, 96, 0, 52, 1, 68, 8, 11, 6, 33, 5, 63, 4, 61, 
    5, 55, 8,  1, 6, 94, 0, 91, 3,  7, 4,  4, 1, 37, 2, 44, 7, 93, 
    7, 49, 5, 55, 6, 29, 2, 45, 3, 97, 0, 16, 1, 41, 4, 63, 8, 56, 
    0, 17, 4, 38, 7, 40, 1, 47, 6, 79, 2, 28, 5, 26, 8, 78, 3, 79
  };
  const int q2916[] = {
    9, 9, // Number of jobs and machines
    8, 35, 7, 85, 1,  5, 3, 52, 6, 33, 2,  8, 4, 35, 5, 30, 0, 48, 
    4, 56, 2, 19, 7, 60, 1, 28, 5, 64, 0, 15, 8, 55, 6, 25, 3, 65, 
    0, 24, 2, 16, 4, 80, 1, 89, 8, 66, 5, 81, 3, 84, 7, 56, 6, 22, 
    2, 47, 6, 90, 7, 87, 8, 52, 4, 41, 5, 89, 3, 31, 1,  9, 0, 25, 
    5, 53, 7, 93, 1, 68, 2, 13, 6,  2, 0, 18, 8, 10, 3, 32, 4, 98, 
    0, 44, 2, 65, 8, 55, 6, 22, 4, 46, 3, 95, 7, 54, 1, 88, 5, 86, 
    0, 66, 3, 11, 4, 79, 2,  6, 8, 10, 6, 36, 7, 58, 1, 13, 5, 67, 
    6, 69, 2, 67, 8, 74, 5, 31, 1, 86, 3, 72, 7, 27, 0, 88, 4, 73, 
    2, 18, 3, 94, 6, 12, 5, 16, 4, 87, 0, 90, 1, 72, 8, 50, 7, 17
  };
  const int q2917[] = {
    9, 9, // Number of jobs and machines
    0,  1, 4, 75, 1,  8, 6, 11, 8, 97, 7, 64, 5, 26, 3, 62, 2,  7, 
    5, 77, 7, 46, 2, 75, 4,  7, 0, 81, 6, 99, 1, 69, 3, 34, 8,  5, 
    7, 43, 0, 95, 2, 40, 6, 15, 1, 95, 8, 69, 4,  5, 3, 67, 5, 99, 
    6, 21, 1, 12, 3, 96, 0, 77, 8, 40, 4, 66, 5, 37, 7, 85, 2,  7, 
    5, 66, 1, 79, 3, 75, 8, 58, 0, 75, 7, 84, 2, 94, 6, 13, 4, 42, 
    8, 48, 6, 57, 5, 33, 4, 44, 0, 50, 2, 84, 7,  9, 1, 77, 3, 40, 
    4, 42, 8, 19, 5, 64, 6, 92, 2, 73, 1, 22, 3, 55, 7, 77, 0, 40, 
    7, 65, 3, 14, 2, 69, 6,  7, 5, 20, 0, 86, 4, 95, 1, 88, 8,  9, 
    8, 95, 3, 28, 7, 69, 5,  1, 4, 85, 2, 46, 6, 33, 1, 22, 0, 30
  };
  const int q2918[] = {
    9, 9, // Number of jobs and machines
    4, 65, 0, 80, 7, 36, 2, 30, 8, 33, 5, 35, 1, 80, 3, 66, 6, 99, 
    4, 72, 2, 46, 0, 67, 7, 76, 1, 31, 5, 50, 6,  3, 8, 31, 3, 36, 
    4, 12, 3, 27, 8, 61, 2, 86, 7, 52, 6, 34, 0, 93, 5, 51, 1, 14, 
    7, 34, 2, 70, 5, 75, 8, 46, 0, 49, 3, 31, 6, 61, 4, 87, 1,  6, 
    5, 73, 0, 16, 3, 23, 6, 88, 7, 65, 2, 61, 8, 22, 4, 21, 1, 80, 
    0, 89, 6, 66, 4, 71, 7, 28, 8, 55, 3, 89, 5, 17, 2, 25, 1, 22, 
    0, 60, 5, 33, 2, 73, 8, 30, 4, 14, 7, 22, 3, 40, 6, 90, 1, 50, 
    7, 28, 4, 11, 8, 99, 3, 32, 5, 15, 6,  4, 2, 39, 1, 19, 0, 88, 
    2, 12, 3, 99, 8, 62, 7, 31, 5, 12, 1, 82, 0, 60, 4, 93, 6, 93
  };
  const int q2919[] = {
    9, 9, // Number of jobs and machines
    6,  8, 7,  4, 1,  6, 8, 64, 5, 41, 0,  9, 3, 41, 4, 64, 2, 64, 
    7, 96, 6, 51, 0, 23, 1, 37, 2, 92, 4, 38, 3, 72, 5, 20, 8, 39, 
    5, 91, 0, 68, 2, 68, 6, 50, 4, 97, 3, 32, 7, 93, 8, 83, 1,  5, 
    1, 13, 8, 28, 3, 18, 0, 65, 7, 64, 4, 44, 2, 48, 5, 58, 6, 12, 
    7, 45, 3, 22, 2, 69, 5, 66, 4,  5, 0, 66, 1, 90, 8, 60, 6, 86, 
    1, 37, 2, 50, 3, 82, 5, 16, 0, 70, 6, 27, 7, 23, 8, 26, 4, 61, 
    4,  7, 3, 58, 6, 19, 2,  2, 7, 66, 5, 10, 1, 63, 0, 41, 8, 19, 
    5, 82, 0,  4, 6, 30, 8, 98, 4, 79, 1, 53, 2, 31, 3, 18, 7,  9, 
    3, 16, 6, 90, 1, 33, 7, 44, 4, 83, 8,  2, 5, 12, 2,  2, 0, 77
  };
  const int q2920[] = {
    9, 9, // Number of jobs and machines
    3, 76, 5, 33, 8, 99, 7, 82, 0, 48, 6, 34, 2, 94, 1,  2, 4, 21, 
    4, 25, 1,  9, 0, 19, 5, 47, 2, 24, 7, 86, 3, 57, 6, 14, 8, 73, 
    4, 19, 0, 64, 8, 71, 1, 99, 5, 45, 7,  8, 6,  4, 2, 16, 3, 40, 
    4, 71, 2, 21, 1, 70, 7, 28, 6, 59, 0, 63, 8, 31, 5,  6, 3, 53, 
    1, 30, 7, 45, 4, 40, 2, 32, 3, 79, 5, 31, 6, 80, 8, 36, 0, 48, 
    2, 83, 6, 31, 4, 30, 3, 75, 8, 10, 5, 87, 1,  8, 0,  6, 7, 29, 
    8, 65, 3, 22, 4,  4, 0, 32, 5, 91, 6, 83, 7, 68, 2, 24, 1, 52, 
    1, 73, 4, 98, 8, 68, 7, 85, 2, 25, 5, 87, 3, 14, 0, 57, 6, 54, 
    5, 54, 3,  1, 0, 94, 6, 24, 7, 56, 2, 11, 8, 88, 1, 99, 4, 82
  };
  const int q2921[] = {
    9, 9, // Number of jobs and machines
    8, 41, 3,  8, 6, 87, 0, 72, 2, 92, 7, 57, 1, 28, 5, 98, 4, 16, 
    7, 80, 8, 71, 5, 66, 1, 10, 6, 24, 0, 60, 2, 17, 4, 19, 3, 95, 
    4, 47, 8, 87, 0, 74, 5, 72, 6, 72, 3, 43, 2, 52, 7, 36, 1, 80, 
    3, 54, 6, 10, 5, 82, 1, 86, 7, 50, 2, 19, 4, 91, 0,  2, 8, 93, 
    2, 82, 0,  9, 7, 64, 1,  8, 3, 81, 8, 69, 4, 39, 5,  8, 6, 79, 
    7, 97, 1, 63, 6, 73, 4, 86, 0, 86, 3, 97, 8, 77, 5, 26, 2, 25, 
    4, 72, 5, 94, 8, 83, 1,  1, 6, 75, 3,  9, 0, 21, 2, 87, 7, 51, 
    1, 16, 8, 91, 3, 49, 0, 74, 5, 32, 6, 32, 4, 61, 7, 17, 2, 44, 
    2, 34, 3, 20, 4, 74, 8, 55, 0, 14, 1, 43, 5, 19, 6, 76, 7, 96
  };
  const int q2922[] = {
    9, 9, // Number of jobs and machines
    7, 37, 8, 55, 6, 34, 0, 57, 3, 46, 1, 89, 2, 74, 5, 68, 4, 83, 
    0, 88, 5, 73, 1, 57, 7, 71, 3, 68, 2, 68, 8, 53, 6, 50, 4, 34, 
    2, 65, 5, 94, 6, 14, 8, 39, 0, 92, 7, 92, 3, 88, 1, 46, 4, 64, 
    3, 99, 8, 12, 4, 34, 6, 49, 0, 64, 1, 57, 2, 55, 7, 26, 5, 69, 
    1, 88, 0, 85, 5, 86, 8, 82, 7, 94, 4, 84, 3, 12, 2, 15, 6, 14, 
    0, 47, 7, 52, 3, 92, 5, 20, 1, 19, 4, 82, 8, 30, 6,  4, 2, 87, 
    5, 96, 7, 39, 3, 90, 4, 82, 1, 91, 0,  7, 6, 26, 8, 84, 2, 35, 
    5, 33, 1, 99, 0, 36, 3, 81, 2, 52, 6, 60, 7, 24, 8, 82, 4,  5, 
    4, 60, 3, 37, 5, 61, 7, 42, 8, 77, 0, 26, 2, 90, 6, 74, 1, 46
  };
  const int q2923[] = {
    9, 9, // Number of jobs and machines
    6, 37, 5, 49, 7, 58, 4, 64, 1, 40, 2, 30, 8, 16, 0, 30, 3, 17, 
    4, 80, 6, 25, 0, 91, 8, 75, 2, 69, 7, 64, 3, 76, 5, 12, 1, 14, 
    4, 95, 0, 96, 2, 29, 5, 73, 7, 64, 1, 87, 3, 32, 8, 52, 6, 71, 
    8, 65, 1, 89, 7, 84, 6, 99, 0, 31, 3,  8, 5, 95, 4, 38, 2, 43, 
    0, 25, 2,  1, 4, 42, 1, 79, 3, 82, 7,  6, 6, 23, 8, 96, 5, 69, 
    4, 72, 7, 28, 8, 70, 6, 57, 0, 10, 5, 59, 1, 57, 2, 59, 3, 87, 
    2, 91, 0, 78, 3, 41, 4, 37, 5,  8, 7, 58, 1, 72, 6, 95, 8,  1, 
    1, 93, 7, 82, 2, 96, 5,  2, 8, 34, 6, 35, 3, 82, 4, 98, 0, 24, 
    4, 43, 1, 62, 8, 29, 2, 87, 0,  1, 7, 97, 5, 12, 6, 57, 3, 67
  };
  const int q2924[] = {
    9, 9, // Number of jobs and machines
    8, 38, 1, 76, 4, 83, 5, 67, 7, 54, 3, 46, 2, 15, 6, 49, 0, 10, 
    2, 88, 6,  9, 0, 24, 4, 11, 1, 36, 7, 63, 5, 36, 3, 63, 8, 93, 
    8, 42, 5, 97, 2, 10, 6, 33, 4, 60, 7, 57, 1, 27, 3, 53, 0, 71, 
    8, 20, 1, 56, 6,  5, 0, 26, 7, 43, 4, 39, 2, 76, 5, 74, 3, 80, 
    8,  2, 4, 53, 0, 70, 2, 26, 6, 76, 7, 74, 3, 90, 5, 66, 1, 46, 
    1,  3, 6, 68, 3, 43, 4, 72, 5, 90, 0, 83, 8,  7, 7, 16, 2, 79, 
    7, 94, 5, 22, 8,  9, 4, 61, 0, 78, 1, 55, 2, 89, 6, 92, 3, 68, 
    2,  3, 1, 68, 7, 48, 8, 67, 0, 37, 3, 14, 6, 23, 5,  8, 4, 11, 
    2, 53, 5, 14, 4, 93, 0, 16, 1, 71, 7, 18, 3, 89, 8, 54, 6, 24
  };
  const int q2925[] = {
    9, 9, // Number of jobs and machines
    2,  6, 7, 62, 6, 71, 5, 54, 3, 63, 0, 95, 1, 85, 4, 21, 8, 85, 
    6, 89, 4,  9, 8, 24, 7, 77, 1, 91, 2,  6, 3, 12, 0, 94, 5, 89, 
    2, 13, 8, 38, 4, 65, 7, 47, 3, 12, 6, 86, 0,  8, 5, 52, 1, 91, 
    6, 38, 2, 82, 0, 21, 5, 87, 1, 51, 3, 49, 7, 40, 4, 23, 8, 62, 
    2, 19, 6, 76, 4, 45, 5, 96, 7, 43, 1, 20, 3, 59, 8, 26, 0, 40, 
    2, 56, 7, 29, 5, 19, 6, 15, 4, 98, 0, 89, 1, 94, 3, 55, 8, 21, 
    4, 61, 7, 21, 8, 45, 2, 58, 1, 98, 3, 79, 6, 47, 5, 99, 0, 72, 
    6, 45, 0, 82, 8, 80, 2, 99, 3,  9, 5, 44, 1, 31, 7, 82, 4, 82, 
    8,  2, 1, 48, 4, 31, 5, 17, 2, 90, 3, 94, 7, 31, 6, 49, 0, 18
  };
  const int q2926[] = {
    9, 9, // Number of jobs and machines
    3,  5, 1, 51, 4, 60, 7, 24, 5, 53, 6,  9, 0, 64, 2, 98, 8, 17, 
    0, 40, 4, 99, 5, 89, 8, 69, 1, 77, 7, 86, 3, 40, 2, 20, 6, 16, 
    0, 10, 3, 78, 5, 95, 4, 20, 7, 26, 2,  6, 1, 70, 8, 41, 6, 89, 
    5, 20, 1,  4, 0,  6, 3, 71, 8, 81, 7, 38, 2, 67, 6, 13, 4, 18, 
    5, 49, 6, 19, 1, 24, 4, 60, 2, 37, 8, 44, 7,  7, 3, 87, 0, 35, 
    8, 99, 2, 53, 7, 52, 5, 10, 4, 28, 3, 54, 6, 24, 1, 32, 0, 70, 
    8, 78, 0, 67, 4, 73, 1, 56, 6, 74, 7, 54, 2, 50, 5, 50, 3, 18, 
    5, 40, 7, 13, 1, 37, 3, 66, 6, 15, 2, 27, 4, 90, 8,  5, 0, 40, 
    1, 12, 5, 75, 4, 28, 8, 14, 6, 93, 7, 54, 2, 48, 0, 63, 3, 69
  };
  const int q2927[] = {
    9, 9, // Number of jobs and machines
    2, 90, 7,  3, 4, 74, 1, 17, 6, 17, 5, 71, 0, 44, 8,  5, 3, 94, 
    0, 12, 2, 29, 7, 16, 1, 90, 5,  2, 3, 51, 6, 21, 4, 44, 8, 26, 
    6, 95, 1, 77, 7, 51, 5, 56, 0,  1, 2, 27, 4, 80, 8, 52, 3, 27, 
    4, 14, 7, 44, 5, 72, 2, 42, 6, 27, 1, 79, 8, 18, 0,  1, 3, 73, 
    7, 33, 0, 94, 2, 79, 4, 54, 8, 61, 3, 55, 1, 35, 5, 20, 6, 95, 
    4, 55, 3, 90, 5, 62, 7, 13, 0, 96, 8, 87, 1, 96, 2, 79, 6, 92, 
    0, 14, 5, 96, 6, 59, 4, 25, 3, 20, 2, 69, 8, 50, 1, 27, 7, 55, 
    6, 96, 2, 61, 4, 98, 0, 93, 7, 32, 8, 41, 1, 20, 5, 98, 3, 91, 
    0, 54, 1, 74, 7, 42, 4, 48, 5, 34, 2, 90, 3, 28, 6, 96, 8, 25
  };
  const int q2928[] = {
    9, 9, // Number of jobs and machines
    2, 77, 4, 56, 5, 43, 1, 14, 8, 54, 0, 95, 6, 58, 3, 92, 7, 66, 
    7, 83, 1, 32, 3, 37, 4, 21, 8, 98, 2, 11, 5, 52, 0, 99, 6, 28, 
    7, 72, 6, 35, 0,  6, 3, 19, 2, 46, 4, 75, 5, 83, 8, 26, 1, 71, 
    7, 52, 0, 70, 6, 20, 1,  5, 3, 23, 8, 34, 4, 24, 5, 23, 2,  7, 
    5, 16, 8, 69, 6, 50, 4,  3, 1,  8, 3, 39, 7, 81, 0, 86, 2, 84, 
    4, 99, 0,  4, 8, 21, 5, 70, 6, 40, 3, 70, 2, 30, 7, 38, 1, 78, 
    6, 17, 3, 58, 5, 91, 2, 12, 4,  3, 0, 66, 7, 32, 8, 59, 1, 82, 
    0, 10, 3, 36, 7, 17, 4, 12, 5, 40, 1, 89, 8, 19, 6, 19, 2, 18, 
    5, 33, 0, 68, 7, 86, 2, 43, 3, 30, 6, 81, 8, 74, 1, 30, 4,  5
  };
  const int q2929[] = {
    9, 9, // Number of jobs and machines
    0, 86, 1, 61, 5, 19, 2, 35, 7, 88, 4, 44, 6, 78, 3, 37, 8, 99, 
    2,  6, 3, 55, 5, 72, 1, 37, 0, 46, 6, 29, 8, 67, 4, 77, 7, 41, 
    6, 33, 5, 93, 4,  2, 2, 29, 0, 25, 7, 11, 3, 53, 8,  8, 1, 80, 
    1, 18, 0, 15, 6, 32, 5, 24, 3, 70, 4, 14, 8, 22, 7, 98, 2, 23, 
    0, 86, 5, 49, 7, 83, 3,  4, 2, 82, 8,  3, 1, 56, 6, 78, 4, 38, 
    8, 64, 5, 57, 2, 65, 0,  1, 7, 20, 3, 15, 4, 98, 6,  4, 1, 28, 
    0, 17, 1,  5, 5,  9, 6, 21, 7, 69, 2, 69, 8, 91, 3,  5, 4, 97, 
    8, 42, 5, 25, 4, 47, 2, 27, 3, 72, 1, 59, 7, 22, 6, 98, 0, 64, 
    1, 71, 2, 88, 4,  3, 6, 18, 5, 83, 8, 14, 7, 41, 0, 34, 3, 32
  };
  const int q2930[] = {
    9, 9, // Number of jobs and machines
    7, 96, 4, 72, 5, 26, 8, 58, 0, 29, 1, 20, 2,  9, 6,  9, 3,  9, 
    0, 16, 7, 84, 2, 39, 1, 33, 6, 45, 4, 40, 3, 65, 8, 80, 5, 38, 
    1, 28, 5, 52, 3, 39, 8, 51, 0, 32, 7, 32, 2, 67, 4, 68, 6, 20, 
    3, 43, 6, 92, 7, 12, 1, 82, 0, 17, 4, 14, 2, 39, 5, 92, 8, 83, 
    2, 59, 8, 54, 0, 65, 1, 49, 5, 35, 6, 33, 3, 66, 4, 73, 7, 58, 
    2, 26, 5, 85, 4, 60, 8, 56, 3, 45, 6, 80, 1, 26, 0, 44, 7, 19, 
    8, 31, 0, 90, 3, 97, 2, 32, 6, 21, 7, 71, 4, 52, 1, 74, 5, 37, 
    6, 28, 8, 90, 5, 96, 0, 84, 2, 89, 7, 18, 4, 71, 3, 82, 1, 40, 
    2, 14, 7, 65, 5, 91, 6, 89, 3, 14, 4, 76, 8, 66, 1, 16, 0, 86
  };
  const int q2931[] = {
    9, 9, // Number of jobs and machines
    7, 16, 6, 31, 4, 42, 3, 89, 8, 64, 5, 88, 0, 17, 1, 69, 2, 52, 
    2, 94, 3, 51, 1, 27, 5, 91, 0, 47, 7, 48, 6, 65, 8, 76, 4, 88, 
    8, 93, 5, 28, 2, 37, 4, 62, 6, 47, 1, 84, 7,  7, 0, 43, 3, 65, 
    1, 10, 7, 68, 8, 61, 0, 67, 3, 67, 2, 66, 5, 48, 4,  1, 6, 12, 
    2, 49, 6, 27, 0, 44, 1, 31, 4, 20, 7, 95, 3, 89, 8, 28, 5,  3, 
    2, 75, 1, 61, 0, 34, 7, 37, 5, 99, 3, 25, 4, 73, 6, 31, 8, 28, 
    6, 96, 3, 52, 1, 47, 7, 96, 2, 55, 4, 13, 5,  1, 0, 53, 8, 38, 
    1, 26, 5, 50, 2, 10, 8, 68, 7, 94, 3, 96, 6, 65, 0, 59, 4, 14, 
    2, 87, 6, 43, 7, 12, 0, 26, 3, 78, 8, 25, 5, 88, 1, 82, 4, 82
  };
  const int q2932[] = {
    9, 9, // Number of jobs and machines
    6, 71, 5, 58, 4, 47, 8, 80, 0, 84, 2, 74, 7, 58, 1,  7, 3, 14, 
    2, 10, 0, 14, 6, 94, 5, 43, 4, 70, 7,  9, 8, 68, 3, 32, 1, 73, 
    8, 67, 1, 36, 7, 17, 2, 20, 5,  8, 3,  9, 6, 94, 0, 83, 4, 49, 
    1, 83, 0, 22, 2, 17, 6, 44, 3, 36, 4, 50, 5, 55, 8, 88, 7, 50, 
    4, 75, 7, 64, 5,  9, 0, 62, 3, 54, 8, 27, 2, 15, 6, 92, 1, 26, 
    6, 27, 2, 56, 1, 84, 3, 64, 5, 57, 4, 79, 8, 76, 0, 12, 7, 90, 
    6, 36, 0, 90, 8, 61, 7, 21, 4, 82, 2, 76, 1, 81, 3, 70, 5, 49, 
    1, 20, 5,  9, 7, 68, 8, 32, 3, 65, 4, 73, 0, 98, 6, 53, 2, 39, 
    7, 38, 2, 31, 1, 41, 8, 78, 5, 77, 4, 75, 0, 14, 3, 30, 6, 66
  };
  const int q2933[] = {
    9, 9, // Number of jobs and machines
    0, 42, 4, 42, 3, 48, 6, 86, 2, 61, 5, 30, 8, 99, 1, 19, 7, 26, 
    8,  5, 5, 72, 1, 84, 2, 62, 3, 57, 4, 11, 6,  6, 0, 40, 7, 11, 
    5, 16, 6, 98, 1, 21, 3, 49, 8, 44, 0,  2, 4, 49, 7, 97, 2, 93, 
    2, 54, 5, 82, 1, 60, 7, 70, 6, 50, 4,  6, 8, 29, 0, 90, 3, 50, 
    4, 76, 0,  8, 2, 14, 8, 51, 5, 22, 1,  1, 3, 59, 7, 40, 6, 84, 
    0, 37, 8, 16, 7, 56, 4, 64, 6, 61, 2, 24, 5, 58, 3, 76, 1, 21, 
    8, 22, 6, 73, 0, 97, 5, 71, 4, 87, 2, 17, 3, 16, 7, 82, 1, 19, 
    0, 42, 7, 98, 6, 60, 8, 72, 5, 42, 2, 38, 3, 80, 4, 94, 1,  5, 
    0, 45, 4, 65, 1, 81, 3, 74, 8, 42, 7, 90, 6, 82, 2,  9, 5, 14
  };
  const int q2934[] = {
    9, 9, // Number of jobs and machines
    2, 49, 0, 36, 5, 32, 6, 27, 3, 41, 4,  9, 7,  8, 1,  9, 8, 75, 
    7, 17, 2,  5, 6, 28, 3, 59, 0, 58, 1, 97, 4, 54, 5, 90, 8, 81, 
    6, 67, 1, 74, 3, 92, 2, 71, 8, 61, 5, 98, 4, 14, 0,  9, 7, 31, 
    2, 47, 7, 41, 6, 42, 5, 93, 8, 31, 1, 36, 0, 73, 4, 34, 3,  4, 
    6, 20, 1, 94, 0, 70, 3, 67, 4, 20, 7, 56, 2,  9, 5, 23, 8,  6, 
    1, 31, 4, 36, 7, 54, 0, 52, 6, 60, 3, 28, 2, 96, 8,  5, 5, 36, 
    8, 68, 6, 39, 7, 21, 4, 36, 2, 12, 0, 45, 1, 55, 5, 94, 3, 68, 
    4, 99, 2, 51, 6, 25, 3, 65, 5, 56, 1, 95, 8, 52, 0,  5, 7, 78, 
    5, 48, 6, 53, 1, 43, 8, 59, 2, 55, 3, 68, 4, 89, 7, 95, 0, 12
  };
  const int q2935[] = {
    9, 9, // Number of jobs and machines
    5, 32, 0, 59, 8, 77, 1, 29, 7, 43, 6, 60, 4, 34, 3, 74, 2, 78, 
    0, 63, 7, 19, 4, 51, 6, 41, 2, 28, 5, 73, 3, 99, 8, 36, 1, 98, 
    7, 92, 2, 42, 6, 67, 0, 11, 5, 81, 4, 47, 8, 16, 3, 92, 1, 20, 
    3, 70, 0, 46, 7, 72, 1, 77, 6, 67, 5, 24, 8, 59, 4, 50, 2, 42, 
    1, 85, 3, 64, 6, 82, 0, 65, 5, 95, 2, 44, 8, 96, 7, 89, 4, 73, 
    8, 97, 7, 88, 0, 69, 1, 18, 4, 67, 2, 16, 3, 42, 6, 58, 5, 52, 
    1, 18, 7, 55, 5, 39, 6, 94, 8, 29, 4, 72, 2, 34, 3, 47, 0,  1, 
    1, 83, 4, 53, 2, 21, 8, 25, 5, 47, 3, 22, 6, 77, 7, 59, 0, 39, 
    0, 71, 1, 40, 2, 18, 6, 86, 7, 20, 4, 63, 5, 73, 3, 17, 8, 64
  };
  const int q2936[] = {
    9, 9, // Number of jobs and machines
    8, 36, 5, 69, 4, 28, 1, 19, 7, 92, 0, 38, 6, 74, 3, 88, 2, 69, 
    5, 84, 3, 21, 2, 54, 4,  8, 0, 48, 7, 39, 8, 50, 1, 85, 6, 19, 
    1, 33, 4, 43, 2, 70, 0, 60, 3, 33, 6, 49, 7, 55, 5, 24, 8, 71, 
    1,  1, 0, 33, 8, 81, 3, 25, 7, 83, 2, 42, 5, 44, 4, 41, 6, 62, 
    7, 59, 5, 71, 2, 33, 4, 29, 6, 35, 0, 21, 1, 61, 8, 70, 3, 70, 
    2, 57, 5, 21, 4, 74, 3, 22, 8, 23, 6, 33, 0, 18, 7, 40, 1, 77, 
    6, 73, 8, 78, 5, 21, 7, 79, 4,  4, 1, 67, 0, 74, 3, 89, 2, 96, 
    3, 36, 8, 44, 5, 16, 4, 52, 0, 97, 2, 39, 1, 61, 6, 83, 7, 31, 
    7, 70, 4,  5, 0, 44, 3, 71, 5, 54, 6, 32, 1, 12, 2, 72, 8, 25
  };
  const int q2937[] = {
    9, 9, // Number of jobs and machines
    0,  5, 6, 11, 7, 69, 3, 46, 2, 99, 1, 45, 5, 66, 8, 47, 4, 66, 
    2, 92, 5, 12, 0, 70, 6, 34, 1, 90, 8, 96, 4, 19, 7, 42, 3, 98, 
    8, 21, 5, 73, 3, 14, 1, 18, 2, 70, 4, 57, 6, 13, 7, 18, 0, 48, 
    5, 71, 8, 22, 0, 79, 1, 97, 6, 54, 4, 36, 7, 45, 2, 83, 3, 94, 
    0, 80, 5, 61, 4, 66, 6, 23, 8, 93, 1, 71, 2,  1, 3, 10, 7,  4, 
    3, 29, 5, 79, 1, 27, 8, 32, 4, 24, 7, 49, 6, 39, 2, 97, 0, 33, 
    4, 18, 3, 36, 0,  1, 5, 85, 7, 30, 1, 21, 2, 85, 8, 86, 6, 96, 
    4, 39, 1, 36, 5, 30, 8, 90, 7, 91, 2, 73, 3, 10, 0, 29, 6, 44, 
    1, 83, 5, 27, 6, 69, 0, 64, 8, 29, 4,  7, 7, 31, 3, 70, 2,  7
  };
  const int q2938[] = {
    9, 9, // Number of jobs and machines
    7, 14, 8, 75, 3, 79, 5, 78, 6, 48, 1, 66, 4, 64, 0, 20, 2, 41, 
    0, 50, 3, 31, 1, 22, 5, 88, 6, 19, 4, 16, 8,  4, 2, 69, 7, 97, 
    6, 89, 3, 93, 1, 41, 5, 17, 2, 65, 8, 17, 0,  3, 7, 87, 4, 88, 
    1, 68, 6, 28, 2, 16, 4, 29, 7, 72, 0, 34, 5, 98, 3, 92, 8, 68, 
    2,  6, 8, 74, 6, 90, 7, 26, 3, 93, 0, 26, 5, 83, 1, 47, 4, 50, 
    2, 97, 6, 49, 3,  9, 0, 11, 7, 28, 1, 52, 4, 70, 5, 71, 8, 88, 
    4, 36, 7, 49, 3, 12, 2, 30, 1, 12, 6, 59, 0,  9, 5, 97, 8,  6, 
    4,  9, 3,  7, 2, 67, 7, 87, 5, 90, 6, 26, 8, 67, 0, 46, 1, 78, 
    1, 77, 4, 10, 0, 17, 5, 52, 6, 17, 3, 66, 7, 14, 2, 12, 8, 34
  };
  const int q2939[] = {
    9, 9, // Number of jobs and machines
    0, 46, 2, 52, 7, 55, 6, 26, 5, 90, 4, 83, 8,  7, 1, 94, 3, 68, 
    0, 47, 7, 29, 8, 21, 6, 91, 4, 42, 2, 87, 3, 12, 1, 33, 5, 85, 
    5, 16, 7, 79, 8, 19, 4,  2, 0, 48, 1, 52, 6, 16, 2, 38, 3, 18, 
    7, 96, 4, 51, 2,  4, 8, 18, 0, 20, 5, 40, 1, 80, 6, 46, 3, 37, 
    3, 40, 5, 44, 4, 89, 6, 79, 8, 39, 2, 43, 1, 68, 7, 96, 0, 54, 
    6, 94, 3, 60, 5,  8, 4, 29, 2, 51, 7, 57, 0, 67, 1,  5, 8, 90, 
    2, 21, 7, 53, 6,  9, 8, 53, 5, 87, 0, 43, 3, 89, 4, 11, 1, 90, 
    1, 32, 8, 53, 6, 20, 0, 99, 4, 11, 2,  8, 7, 88, 3, 30, 5, 28, 
    2, 55, 8, 87, 6, 24, 5, 17, 1, 66, 4,  1, 7, 22, 3, 96, 0, 89
  };
  const int q2940[] = {
    9, 9, // Number of jobs and machines
    8, 67, 6,  5, 5, 58, 1, 69, 7,  2, 2, 24, 4, 44, 0, 85, 3, 69, 
    7, 21, 4, 74, 1, 58, 2, 39, 0, 76, 3, 95, 8, 87, 5, 94, 6, 71, 
    1, 56, 3, 46, 0, 63, 4,  7, 7, 12, 8, 96, 5, 42, 2, 34, 6, 65, 
    0, 95, 8, 72, 3, 35, 4, 23, 7, 41, 1,  3, 2, 12, 6, 23, 5, 89, 
    4,  3, 7, 52, 5, 24, 6, 63, 1, 88, 3, 20, 8, 71, 2, 50, 0, 21, 
    5, 46, 3, 37, 7, 36, 4, 29, 8, 26, 1, 60, 6, 55, 0, 79, 2,  5, 
    6, 54, 4, 62, 1,  5, 8, 24, 3, 84, 7, 27, 0, 53, 5, 32, 2, 52, 
    0, 48, 3,  2, 4, 98, 2, 94, 5,  4, 8, 85, 7, 50, 1, 49, 6, 74, 
    2,  5, 3, 24, 8, 36, 7, 81, 5, 52, 1, 52, 6, 45, 0,  1, 4,  6
  };
  const int q2941[] = {
    9, 9, // Number of jobs and machines
    1, 63, 8, 41, 5, 67, 6,  2, 4, 25, 7, 71, 2, 71, 0, 63, 3, 22, 
    2, 93, 6, 47, 8, 84, 4, 83, 0, 96, 5, 61, 1, 83, 3,  5, 7,  9, 
    1, 35, 3, 79, 0, 42, 7, 63, 8, 56, 4, 28, 5,  9, 6, 35, 2, 80, 
    3, 88, 0, 89, 1, 26, 8, 26, 5, 48, 7, 36, 6, 91, 2, 30, 4, 54, 
    5, 79, 8, 92, 1, 16, 4, 26, 3, 34, 2, 45, 6, 36, 7,  5, 0, 11, 
    0, 63, 4, 83, 3, 92, 6, 46, 7, 94, 8,  7, 5, 56, 1, 99, 2, 20, 
    7, 95, 6, 68, 3,  3, 8, 31, 0, 29, 5, 38, 4, 71, 1, 74, 2, 43, 
    8, 49, 3, 94, 4, 66, 6, 94, 5, 68, 2, 48, 0, 44, 1, 23, 7, 96, 
    3, 88, 0, 27, 8, 73, 6, 44, 4, 93, 2, 23, 1, 52, 5, 97, 7, 34
  };
  const int q2942[] = {
    9, 9, // Number of jobs and machines
    4, 23, 0, 71, 5, 56, 3, 56, 1, 34, 6, 79, 8, 83, 2, 87, 7,  3, 
    0, 24, 7, 19, 5, 72, 6, 22, 1, 17, 3, 28, 8, 31, 4, 70, 2, 19, 
    0, 53, 8, 97, 3, 21, 5, 84, 4, 58, 1, 49, 7,  7, 6, 75, 2, 80, 
    8, 38, 4,  7, 3, 93, 7,  8, 2, 39, 0, 89, 6, 77, 1, 58, 5, 30, 
    1, 73, 8, 52, 5, 38, 6, 42, 0, 33, 2, 55, 4, 25, 3,  1, 7, 81, 
    5, 91, 0, 79, 3, 88, 8,  9, 6, 17, 7,  3, 2, 57, 4, 57, 1, 11, 
    2, 71, 5, 54, 7,  5, 1, 99, 6, 22, 8, 29, 3, 96, 4, 43, 0, 35, 
    2, 82, 8, 94, 0, 33, 6, 96, 3, 27, 5, 47, 1, 83, 4, 23, 7, 42, 
    7, 64, 5, 58, 2, 86, 3, 30, 1, 67, 6, 59, 4, 28, 8, 80, 0, 43
  };
  const int q2943[] = {
    9, 9, // Number of jobs and machines
    2, 23, 7, 46, 1,  4, 5, 20, 8, 95, 3, 35, 0,  6, 4, 75, 6,  6, 
    1, 64, 4, 54, 5, 12, 2,  1, 6, 85, 0, 11, 3, 61, 7, 69, 8,  5, 
    6,  9, 3, 26, 4, 26, 7, 53, 0, 49, 2, 82, 1, 33, 5, 87, 8, 29, 
    6, 25, 3, 48, 0, 54, 2, 16, 8, 86, 1, 45, 4, 72, 7, 27, 5, 47, 
    8, 34, 1, 13, 4,  4, 0, 25, 2, 56, 6, 86, 5, 56, 7, 72, 3, 92, 
    7, 73, 6,  7, 3, 14, 8, 42, 4, 32, 2, 55, 0, 17, 1, 89, 5, 69, 
    1, 28, 6, 81, 3, 67, 4, 14, 2, 80, 7,  1, 8, 31, 0,  9, 5, 99, 
    0, 85, 8, 42, 1, 85, 3, 53, 2, 86, 6, 76, 5, 67, 7, 22, 4, 74, 
    4, 14, 0, 75, 3, 93, 7, 60, 8, 29, 6, 67, 5, 18, 2, 94, 1,  3
  };
  const int q2944[] = {
    9, 9, // Number of jobs and machines
    6, 28, 5, 97, 7, 99, 8, 56, 0, 13, 3, 87, 1,  6, 2, 18, 4, 71, 
    1, 75, 0, 18, 3,  1, 7, 69, 8, 64, 2, 19, 5, 37, 6, 40, 4, 30, 
    7, 62, 0, 92, 5, 90, 8, 71, 1, 19, 2, 96, 3, 12, 4, 67, 6, 90, 
    0, 64, 6, 27, 3, 89, 2, 71, 1, 45, 7, 52, 5, 26, 8,  7, 4, 91, 
    5, 96, 1, 94, 2, 22, 8, 19, 4, 71, 0, 19, 6, 46, 3, 41, 7, 11, 
    4, 53, 0, 66, 2, 55, 1, 86, 6, 55, 7, 11, 5, 34, 8, 15, 3, 48, 
    5, 56, 4, 86, 8, 13, 6, 44, 3, 91, 7, 50, 2, 74, 0, 43, 1, 78, 
    4, 59, 5, 57, 3,  7, 6, 49, 7, 73, 1,  3, 0, 58, 8, 39, 2, 53, 
    7, 47, 2, 23, 1, 93, 0, 50, 3, 59, 5, 11, 6, 97, 4, 60, 8, 37
  };
  const int q2945[] = {
    9, 9, // Number of jobs and machines
    5, 71, 8, 84, 0,  1, 1, 49, 6, 56, 2, 72, 7, 48, 4, 93, 3, 93, 
    3, 36, 4, 20, 5, 43, 7, 54, 8, 83, 2, 90, 0, 90, 1, 62, 6, 33, 
    3, 33, 5, 14, 7,  3, 6, 90, 8,  1, 4, 48, 2, 27, 0, 49, 1, 66, 
    3, 47, 2,  3, 0, 87, 7, 90, 1, 19, 4, 16, 6, 24, 5,  1, 8, 31, 
    2, 79, 1,  2, 3, 12, 5, 82, 6, 80, 4, 57, 0, 80, 8, 56, 7, 78, 
    3, 43, 1, 53, 8, 13, 7, 34, 5, 18, 0, 62, 6, 33, 2, 93, 4, 94, 
    4, 34, 7, 96, 1, 23, 2, 22, 0, 25, 6, 34, 3,  8, 5, 24, 8, 51, 
    2, 16, 6, 55, 0, 33, 8, 21, 1, 24, 7, 26, 5, 85, 4, 85, 3, 70, 
    6, 88, 0, 38, 1, 29, 2, 14, 3, 90, 7, 36, 4, 65, 8, 78, 5, 52
  };
  const int q2946[] = {
    9, 9, // Number of jobs and machines
    0, 99, 8, 78, 1, 94, 3,  6, 5, 32, 4, 45, 6, 23, 7, 17, 2, 73, 
    5, 39, 6,  3, 1, 32, 3, 42, 8, 48, 2, 61, 7, 94, 0, 81, 4, 15, 
    7, 50, 4, 29, 5, 80, 0, 93, 3, 23, 2, 96, 8, 33, 1, 76, 6,  5, 
    2, 73, 8, 56, 0, 29, 6, 92, 3, 93, 4, 45, 5, 81, 1, 62, 7, 53, 
    1, 58, 6, 48, 0, 50, 7, 42, 2, 52, 3, 62, 4, 46, 5, 58, 8, 19, 
    5, 37, 8, 83, 1, 67, 4, 39, 2, 26, 0, 20, 3, 59, 6,  5, 7, 10, 
    8,  3, 4, 88, 7,  7, 3, 47, 1, 91, 6, 22, 5, 82, 0, 33, 2, 20, 
    5, 56, 2, 28, 0, 91, 6,  5, 8, 88, 7, 88, 1, 88, 3, 60, 4, 89, 
    3, 77, 4, 27, 0, 20, 8, 94, 1, 23, 6, 77, 5, 11, 2, 96, 7, 27
  };
  const int q2947[] = {
    9, 9, // Number of jobs and machines
    6, 17, 4, 94, 8, 89, 2, 97, 5, 61, 7, 10, 1, 79, 0, 33, 3, 97, 
    1, 16, 0, 10, 4, 57, 7, 66, 6,  5, 3,  8, 8, 53, 5, 35, 2, 46, 
    0,  4, 2, 35, 1, 56, 3,  3, 8, 95, 6, 73, 7, 39, 4, 43, 5, 77, 
    0, 33, 5, 14, 4, 48, 2, 82, 8, 57, 6, 79, 1, 33, 3, 21, 7, 21, 
    4, 35, 0, 76, 3, 27, 6, 54, 7, 78, 8, 13, 2, 38, 5,  3, 1, 86, 
    3, 39, 2, 80, 0, 96, 4, 26, 8, 52, 1, 88, 7, 72, 6, 54, 5, 14, 
    4, 88, 2, 80, 1, 33, 5, 34, 0, 42, 6, 79, 7, 22, 3, 57, 8, 44, 
    0, 22, 5, 93, 2, 51, 7, 70, 3,  6, 1, 51, 6, 76, 4, 92, 8, 14, 
    8, 39, 3, 73, 2, 97, 0, 52, 7, 23, 6, 10, 5, 33, 1, 52, 4, 17
  };
  const int q2948[] = {
    9, 9, // Number of jobs and machines
    5, 74, 1, 35, 3, 28, 0, 65, 7, 15, 6,  2, 4, 36, 2, 65, 8, 21, 
    3, 71, 4, 87, 0, 78, 7, 19, 1,  8, 5, 46, 2, 82, 6, 87, 8, 50, 
    0, 99, 5, 19, 1, 86, 2, 61, 7, 31, 3, 60, 8, 88, 4, 76, 6,  3, 
    1, 99, 7, 10, 2, 47, 6, 73, 5,  4, 4, 10, 0, 88, 3, 34, 8, 80, 
    3, 51, 8, 13, 5, 85, 1, 65, 7, 27, 0, 84, 6, 11, 4, 61, 2, 11, 
    7, 22, 5, 64, 8, 14, 4,  3, 3,  1, 1, 44, 0, 51, 6, 10, 2, 21, 
    2,  4, 4, 33, 3, 88, 5, 38, 1, 11, 0, 46, 8, 93, 6, 77, 7, 55, 
    6, 47, 2, 24, 8,  6, 3, 13, 5, 81, 7, 21, 1, 58, 0, 75, 4, 16, 
    8, 33, 0, 97, 2, 51, 5, 65, 7, 73, 4, 57, 6, 88, 1, 94, 3, 60
  };
  const int q2949[] = {
    9, 9, // Number of jobs and machines
    5,  9, 8, 39, 4, 29, 1, 79, 6,  6, 2, 90, 3, 43, 0, 90, 7, 41, 
    0, 33, 1, 29, 2, 35, 6, 96, 4, 97, 7, 75, 3, 67, 8, 10, 5, 86, 
    6, 49, 7, 39, 5, 91, 0, 28, 2, 19, 4, 95, 3, 16, 8, 97, 1, 41, 
    5, 93, 0, 71, 6, 38, 2, 95, 8,  9, 4, 45, 1, 63, 7, 56, 3, 23, 
    8, 66, 1, 29, 2, 26, 0, 77, 4, 60, 7, 35, 3, 79, 6, 83, 5, 83, 
    4, 37, 5, 49, 8, 77, 7, 89, 2, 27, 3, 59, 1, 46, 6, 77, 0, 79, 
    3, 23, 5, 12, 0, 29, 6, 32, 2, 40, 7, 27, 4, 99, 1, 98, 8, 44, 
    1, 93, 8, 71, 5, 72, 4, 37, 6, 75, 7, 66, 2, 31, 0, 87, 3, 59, 
    8, 46, 6,  8, 4, 33, 3, 74, 7, 92, 0, 71, 1, 72, 5, 63, 2, 97
  };
  const int q2950[] = {
    9, 9, // Number of jobs and machines
    3, 45, 7, 89, 4, 31, 1, 36, 2, 92, 0, 63, 5, 76, 6, 63, 8, 51, 
    3, 14, 4, 97, 1, 16, 2, 35, 5,  4, 0, 29, 7, 25, 8, 80, 6, 18, 
    8, 34, 2, 72, 1, 97, 0, 64, 6, 10, 5, 59, 3, 30, 4, 42, 7,  4, 
    1, 99, 6, 80, 7,  1, 2, 62, 0, 81, 3,  6, 5, 92, 8, 28, 4, 74, 
    5, 67, 7, 56, 4, 81, 8, 37, 6, 50, 2, 37, 3, 60, 1, 28, 0, 83, 
    4, 32, 1, 33, 0, 98, 6, 16, 3, 22, 8,  9, 7, 23, 5, 65, 2, 70, 
    0, 79, 5, 50, 6, 12, 3, 19, 8, 18, 2, 97, 1, 24, 7,  6, 4, 66, 
    3, 72, 8, 39, 4, 15, 6,  1, 1, 23, 2, 48, 5, 57, 7, 43, 0, 72, 
    6, 78, 5, 43, 8, 93, 4, 59, 1,  1, 0, 17, 3, 41, 2, 38, 7,  7
  };
  const int q2951[] = {
    9, 9, // Number of jobs and machines
    1, 61, 7, 18, 3, 55, 4, 64, 0, 93, 5, 78, 8, 99, 6, 46, 2,  5, 
    2,  3, 0,  4, 7, 65, 4, 82, 8,  2, 6, 13, 3, 52, 1, 27, 5, 83, 
    8, 84, 1, 63, 7, 67, 3, 67, 6, 64, 5, 94, 0, 18, 2, 73, 4,  5, 
    7, 26, 1,  8, 2, 91, 0, 18, 4, 93, 8, 24, 3, 67, 6, 43, 5, 40, 
    3, 60, 2, 25, 7, 95, 0, 86, 8, 76, 5, 70, 6, 31, 1, 85, 4, 89, 
    2, 30, 6, 62, 8, 24, 7, 16, 0, 12, 3, 75, 5, 82, 1, 82, 4, 35, 
    6,  5, 4, 93, 2, 79, 0, 11, 8, 22, 1, 51, 3, 19, 5, 54, 7, 52, 
    2, 39, 4, 79, 6, 38, 1, 64, 3, 60, 0, 42, 5, 46, 8,  3, 7, 12, 
    6, 14, 3, 25, 1, 89, 2, 55, 4, 16, 7, 17, 0, 20, 5, 10, 8, 20
  };
  const int q2952[] = {
    9, 9, // Number of jobs and machines
    7, 66, 4, 80, 2, 76, 3, 11, 0, 36, 8, 30, 5, 75, 6, 60, 1, 54, 
    2, 50, 6,  6, 8,  3, 5, 96, 4, 46, 1, 22, 3, 38, 7, 17, 0, 50, 
    6, 59, 5, 56, 2,  3, 4, 59, 1, 20, 8, 13, 0, 36, 3, 28, 7, 32, 
    7, 68, 0, 25, 6, 70, 5, 54, 2, 88, 3, 75, 4, 67, 8, 41, 1, 15, 
    2, 85, 0, 39, 1, 38, 5, 68, 3, 24, 6, 23, 4, 53, 7, 10, 8, 44, 
    5, 91, 0, 79, 6, 56, 4, 16, 7, 41, 1, 19, 8, 91, 3, 50, 2, 47, 
    3, 20, 7,  2, 4, 10, 2, 16, 0, 80, 8, 67, 5, 14, 1, 62, 6, 14, 
    4, 67, 2,  6, 8, 32, 5, 55, 0,  3, 6, 76, 1, 91, 7, 26, 3, 38, 
    4, 59, 2, 74, 0, 87, 7, 38, 3,  3, 8,  7, 6, 48, 1, 52, 5, 38
  };
  const int q2953[] = {
    9, 9, // Number of jobs and machines
    2, 45, 6,  9, 7, 96, 5, 37, 3, 28, 8, 25, 0, 17, 1, 52, 4, 79, 
    0, 22, 4, 66, 2, 60, 1,  4, 3, 89, 7, 66, 5, 83, 8, 79, 6, 93, 
    3, 67, 5, 81, 7, 68, 2, 95, 8, 59, 1, 79, 0, 73, 6, 57, 4,  8, 
    6, 81, 1, 50, 3,  3, 7, 82, 5, 98, 8, 22, 2, 90, 4, 89, 0, 48, 
    7, 53, 8, 49, 6, 49, 1, 74, 5,  2, 2, 33, 0,  5, 4, 40, 3,  2, 
    3, 91, 7, 68, 6, 97, 0, 20, 1, 31, 5, 19, 4, 70, 2, 67, 8, 65, 
    8, 55, 6,  1, 7, 95, 5,  2, 1,  3, 2, 77, 4, 51, 0, 65, 3, 23, 
    8, 74, 0, 54, 6, 25, 7, 81, 5, 18, 2, 18, 1, 97, 3, 64, 4, 43, 
    7, 53, 2, 57, 6, 25, 1, 36, 3,  5, 8, 33, 0, 47, 4, 87, 5, 23
  };
  const int q2954[] = {
    9, 9, // Number of jobs and machines
    7, 68, 1, 45, 8, 65, 0, 43, 5, 51, 3, 16, 4, 59, 6, 26, 2, 70, 
    4, 15, 7, 41, 1, 34, 5, 83, 2, 13, 3, 35, 6, 64, 0, 16, 8, 75, 
    7, 62, 5, 49, 3, 84, 0, 31, 2, 10, 4, 80, 6, 91, 8, 94, 1, 75, 
    6, 79, 0, 41, 5, 76, 3, 90, 7, 45, 1, 69, 8, 26, 4, 86, 2, 14, 
    6, 63, 4, 82, 8, 17, 7, 67, 2,  4, 5,  6, 3, 28, 0, 14, 1, 95, 
    6, 24, 8, 38, 5, 15, 2, 48, 3, 49, 0,  1, 4, 26, 1, 14, 7, 64, 
    6, 39, 7, 83, 3, 36, 1, 27, 5, 53, 8, 19, 0, 35, 4, 47, 2, 82, 
    4, 29, 1, 68, 7, 50, 2, 77, 0, 49, 6, 40, 5, 41, 8, 31, 3, 81, 
    0, 29, 1, 23, 3, 49, 7, 62, 5, 31, 2, 89, 8, 78, 6, 60, 4, 19
  };
  const int q2955[] = {
    9, 9, // Number of jobs and machines
    5, 96, 8,  5, 0, 93, 4, 61, 2, 98, 3, 23, 7, 37, 1, 82, 6,  6, 
    4, 31, 1, 90, 3, 22, 0, 58, 2, 80, 6, 26, 7, 86, 8, 26, 5,  8, 
    1, 86, 4, 74, 2, 47, 8, 19, 7,  6, 6,  9, 0, 29, 5, 42, 3, 92, 
    1, 11, 4,  9, 5,  1, 2, 96, 6, 57, 7,  2, 3, 85, 0, 91, 8, 66, 
    0,  5, 6, 82, 1, 95, 4, 63, 5, 86, 7, 40, 8, 25, 3, 43, 2, 20, 
    0,  7, 7, 43, 4, 12, 6, 73, 2, 47, 1, 82, 5, 85, 8, 43, 3, 80, 
    8, 33, 3, 79, 5, 86, 0, 82, 1, 66, 2, 17, 7, 42, 6, 73, 4, 40, 
    1, 88, 7,  6, 3, 64, 2, 70, 5, 46, 8, 34, 6, 74, 0, 91, 4, 41, 
    7, 66, 8, 35, 3, 75, 6, 87, 5, 22, 1, 59, 2, 68, 4, 95, 0, 39
  };
  const int q2956[] = {
    9, 9, // Number of jobs and machines
    5,  5, 2, 34, 6, 65, 3, 96, 4, 82, 8,  1, 7, 24, 1, 27, 0, 73, 
    6, 77, 8, 92, 3, 13, 7, 34, 1, 38, 2, 92, 5,  1, 4, 40, 0, 20, 
    2, 60, 3, 95, 8, 34, 4, 58, 7, 38, 5, 81, 0, 36, 1, 97, 6,  6, 
    2, 73, 6, 96, 0, 92, 1,  2, 5, 22, 3,  7, 8, 14, 7, 18, 4, 85, 
    2, 63, 6, 49, 0, 58, 5, 29, 8,  5, 1,  6, 3, 83, 7, 55, 4, 21, 
    4, 90, 7, 12, 8,  5, 5, 13, 2, 65, 0, 70, 1, 59, 6, 53, 3,  8, 
    7, 90, 5, 61, 2, 78, 6, 63, 4, 55, 0,  4, 3, 24, 1, 84, 8, 80, 
    4,  3, 2, 33, 8, 59, 0, 31, 6, 85, 7, 40, 1, 33, 5, 74, 3, 43, 
    3, 79, 8, 44, 2, 62, 0, 58, 5,  8, 6, 55, 1, 37, 7, 92, 4, 96
  };
  const int q2957[] = {
    9, 9, // Number of jobs and machines
    2, 56, 8, 95, 6, 59, 3, 19, 1, 47, 0, 15, 5, 25, 4, 46, 7, 16, 
    5, 59, 4, 81, 6, 55, 7,  1, 8, 20, 3, 73, 0, 78, 1, 71, 2,  6, 
    4, 17, 7, 59, 3, 87, 6, 43, 0, 60, 2, 55, 8, 24, 5, 38, 1, 41, 
    0, 18, 1, 94, 3, 98, 5, 26, 6, 24, 8, 51, 7, 19, 2, 32, 4, 63, 
    0, 30, 6, 56, 2, 82, 8, 86, 1, 63, 7, 22, 5, 18, 3, 77, 4, 51, 
    4, 43, 0, 51, 6, 14, 1, 79, 3, 41, 5, 25, 2, 23, 7, 30, 8, 90, 
    3, 56, 8,  4, 6, 79, 2, 99, 0, 99, 5, 95, 4, 62, 1, 49, 7, 67, 
    4, 58, 5, 90, 8, 54, 7, 67, 0, 68, 1, 51, 6, 70, 3, 65, 2, 25, 
    6, 42, 2, 74, 3, 18, 4, 93, 7, 44, 1, 11, 5, 60, 0, 25, 8, 64
  };
  const int q2958[] = {
    9, 9, // Number of jobs and machines
    1, 37, 7, 73, 0, 35, 4, 23, 6, 90, 8, 91, 5, 81, 3, 14, 2, 74, 
    1, 11, 0, 34, 5, 42, 8, 46, 6, 50, 4, 55, 7,  9, 2, 62, 3, 93, 
    5, 82, 3, 18, 1, 79, 2, 17, 0, 70, 6, 72, 8, 69, 4, 42, 7, 31, 
    0, 32, 1, 34, 6,  5, 5,  4, 2, 15, 7, 54, 3, 41, 4, 79, 8, 25, 
    2, 91, 8, 27, 0, 45, 1, 73, 3, 16, 5, 56, 7, 56, 6,  1, 4, 24, 
    4, 91, 8, 42, 7, 94, 5, 81, 6, 68, 0, 64, 3, 84, 1, 78, 2, 95, 
    8, 62, 3, 11, 7, 21, 4, 67, 1, 13, 5, 88, 0, 36, 2, 53, 6,  2, 
    7, 79, 1, 39, 0,  1, 6, 96, 2, 46, 4, 76, 8, 27, 3, 23, 5, 13, 
    8, 73, 2, 87, 5, 98, 4, 87, 6, 55, 1, 97, 0, 64, 7, 50, 3, 75
  };
  const int q2959[] = {
    9, 9, // Number of jobs and machines
    0, 98, 6, 55, 3, 49, 8, 11, 4, 25, 1, 52, 2, 43, 7, 80, 5, 77, 
    0, 34, 6, 86, 2, 45, 1, 75, 5, 54, 8, 21, 3,  8, 4, 56, 7, 26, 
    0, 11, 5, 38, 3,  9, 6, 88, 1, 56, 7, 58, 8, 76, 2, 19, 4, 78, 
    3, 30, 5, 79, 7, 52, 1, 29, 8, 95, 4, 63, 2, 73, 6,  9, 0, 76, 
    3, 97, 5,  8, 0, 62, 1, 24, 8, 43, 7, 45, 4, 36, 6,  1, 2,  4, 
    6, 49, 0, 39, 8, 30, 1, 53, 7,  4, 3, 51, 2, 66, 5, 78, 4, 56, 
    0,  8, 2,  1, 1, 67, 4, 84, 7, 72, 5, 54, 8, 85, 3, 28, 6, 68, 
    2, 70, 6,  2, 8, 20, 5, 71, 1, 67, 7, 74, 3, 68, 0, 69, 4, 40, 
    1, 65, 0, 26, 2,  1, 7, 93, 8, 10, 6, 40, 5, 75, 4, 28, 3, 14
  };
  const int q2960[] = {
    9, 9, // Number of jobs and machines
    5, 77, 8, 63, 7, 13, 4, 65, 3, 60, 6, 39, 2, 96, 1, 64, 0, 97, 
    8, 26, 5, 14, 4, 57, 1, 53, 7, 44, 0, 76, 2, 99, 6, 74, 3, 86, 
    1, 83, 2, 22, 6, 20, 5,  8, 3, 93, 0, 64, 4, 65, 7, 82, 8, 58, 
    4, 92, 5, 29, 3, 13, 8, 71, 2, 52, 6,  6, 1, 44, 7, 88, 0, 50, 
    2, 11, 8, 27, 1, 65, 6, 20, 5, 59, 0, 12, 7, 16, 3,  9, 4, 41, 
    3, 68, 4, 67, 5, 67, 6, 82, 8, 76, 2, 46, 7, 63, 1,  7, 0, 86, 
    2,  8, 5, 43, 0, 91, 3, 15, 6, 48, 7, 36, 8, 31, 1,  5, 4,  3, 
    3, 80, 0, 16, 6, 13, 7, 62, 1, 82, 2,  1, 4, 77, 8, 79, 5, 31, 
    7, 77, 8, 74, 2, 73, 1, 90, 0, 27, 4, 32, 3, 80, 6, 40, 5, 21
  };
  const int q2961[] = {
    9, 9, // Number of jobs and machines
    4, 10, 8, 13, 2, 94, 3, 47, 6, 64, 0, 32, 1, 47, 5, 41, 7,  1, 
    2, 52, 6, 76, 0,  2, 7, 12, 1, 57, 8, 63, 3, 34, 4, 89, 5, 33, 
    5, 30, 2, 42, 4, 97, 7, 44, 1, 75, 6, 59, 3, 81, 8, 76, 0, 51, 
    5, 18, 0, 39, 2, 53, 1, 48, 7, 76, 3, 98, 4, 58, 6, 42, 8, 38, 
    3, 37, 0, 38, 6, 42, 5,  9, 1, 62, 2, 23, 4, 97, 7, 34, 8, 15, 
    3, 89, 5, 87, 2, 65, 6, 74, 0, 41, 4, 34, 8, 90, 1, 64, 7, 25, 
    6, 27, 7, 42, 3, 53, 8,  3, 2, 29, 1, 18, 4, 38, 5, 19, 0, 97, 
    5, 43, 1, 94, 8, 58, 7, 24, 2, 98, 3,  3, 0, 65, 4, 81, 6, 10, 
    2, 84, 4, 50, 0, 48, 3, 46, 1, 95, 7, 89, 8, 99, 5, 92, 6, 87
  };
  const int q2962[] = {
    9, 9, // Number of jobs and machines
    5, 82, 8, 99, 1, 73, 6, 61, 7, 36, 3, 87, 2, 26, 0, 50, 4,  5, 
    8, 92, 3, 14, 5, 62, 4, 98, 6, 76, 1, 69, 0, 17, 2, 83, 7, 36, 
    5, 70, 8,  8, 6, 71, 2, 51, 1, 70, 4, 82, 7, 15, 3, 13, 0,  4, 
    1, 15, 3, 77, 5, 24, 6, 48, 0, 82, 7, 94, 4, 47, 2, 69, 8, 71, 
    5, 15, 4, 55, 7, 15, 8, 21, 0, 93, 3, 62, 6, 27, 1, 24, 2, 74, 
    3, 92, 4, 88, 2, 93, 1,  5, 0, 83, 7, 17, 6, 52, 5, 39, 8, 39, 
    3, 50, 8, 29, 1, 10, 5, 33, 0, 88, 2, 52, 6, 82, 4, 13, 7, 95, 
    7, 38, 8, 43, 6, 86, 0, 31, 5, 96, 4, 69, 2, 98, 1, 58, 3, 74, 
    6, 54, 2, 44, 4, 61, 5, 55, 1, 57, 3, 20, 0, 28, 7, 96, 8, 23
  };
  const int q2963[] = {
    9, 9, // Number of jobs and machines
    1, 82, 0, 18, 5, 33, 3, 84, 6, 46, 2, 59, 8, 75, 7, 18, 4, 35, 
    6, 18, 2, 48, 7, 74, 8, 57, 5, 83, 0, 63, 3, 27, 1, 51, 4, 64, 
    4, 82, 1, 27, 7, 27, 3, 40, 5, 29, 6, 75, 0, 82, 2,  6, 8, 79, 
    8, 19, 3, 52, 2, 36, 6,  7, 5, 85, 4, 41, 0, 18, 1, 99, 7, 75, 
    5, 61, 7, 49, 8, 30, 0, 44, 2, 80, 6, 86, 3, 36, 1, 82, 4, 38, 
    6, 13, 0, 36, 7, 33, 4, 40, 2, 55, 3, 22, 5, 50, 8, 66, 1, 92, 
    4, 63, 3, 21, 1,  1, 8, 18, 6,  7, 2,  9, 5, 88, 0, 53, 7, 20, 
    5,  2, 4, 43, 8, 12, 2, 17, 7, 19, 0,  7, 6, 21, 1, 40, 3, 89, 
    4, 81, 1, 93, 2, 89, 5,  2, 7, 61, 3, 12, 6, 57, 8, 33, 0, 18
  };
  const int q2964[] = {
    9, 9, // Number of jobs and machines
    7, 58, 8, 71, 2,  6, 1, 90, 4, 48, 6, 61, 5, 21, 3, 96, 0, 57, 
    5, 85, 8, 11, 4, 55, 1, 48, 6, 86, 0, 69, 7,  1, 2, 48, 3, 70, 
    6,  8, 4, 61, 8,  4, 5, 71, 1, 67, 3, 60, 2, 90, 0, 19, 7, 14, 
    7, 37, 8, 84, 2, 33, 6, 46, 5, 45, 0, 34, 1, 82, 3, 37, 4, 70, 
    4,  2, 1, 84, 8, 97, 3, 37, 0, 31, 2, 13, 5, 75, 6, 26, 7, 38, 
    2, 21, 7, 15, 4, 78, 3,  6, 1, 55, 8, 99, 5, 12, 6, 34, 0, 94, 
    5, 98, 0, 60, 1, 82, 4, 40, 7, 83, 2,  3, 8, 18, 6, 72, 3, 88, 
    1, 15, 7, 48, 3, 12, 8, 97, 5,  6, 2, 39, 4, 67, 6, 64, 0, 58, 
    2, 27, 3, 16, 1, 61, 6, 99, 5, 53, 7, 95, 8, 47, 0, 25, 4, 52
  };
  const int q2965[] = {
    9, 9, // Number of jobs and machines
    4, 26, 2, 63, 1, 26, 7, 19, 8, 70, 6, 17, 0, 22, 5, 95, 3, 92, 
    6, 65, 4,  2, 8, 41, 5, 46, 1, 76, 0, 57, 7, 38, 3, 75, 2, 49, 
    7,  9, 8, 92, 1, 25, 4, 58, 2, 42, 5, 71, 3, 36, 6, 80, 0, 15, 
    0, 46, 1, 16, 4, 23, 8, 57, 5,  9, 6, 70, 2,  1, 7, 31, 3, 81, 
    1, 91, 5, 81, 7, 80, 8, 29, 2, 57, 4, 84, 0,  7, 3, 50, 6, 24, 
    8, 74, 6, 54, 3,  4, 7, 13, 4, 47, 0, 89, 5, 45, 2, 99, 1, 19, 
    0, 21, 7, 59, 4, 64, 2, 84, 8, 50, 6, 76, 5, 84, 1, 34, 3, 75, 
    4, 84, 8, 25, 7, 97, 6, 51, 2,  8, 1, 86, 5,  4, 3, 26, 0,  7, 
    0, 73, 8, 18, 4, 71, 2, 68, 3, 12, 6, 60, 5, 22, 7, 20, 1, 41
  };
  const int q2966[] = {
    9, 9, // Number of jobs and machines
    3, 30, 2,  1, 4, 81, 1, 24, 8, 21, 5, 30, 0, 95, 6, 78, 7, 52, 
    7, 67, 5, 84, 0, 34, 1, 65, 8, 43, 4, 57, 2, 91, 3, 50, 6, 78, 
    3, 35, 2, 10, 1, 70, 4, 67, 8, 67, 6, 44, 0, 11, 5, 23, 7, 35, 
    1, 34, 7, 29, 8, 95, 4,  1, 2,  2, 6, 92, 5,  2, 0, 11, 3, 84, 
    2, 22, 6, 13, 1, 82, 5, 29, 7, 30, 3, 19, 8, 34, 0, 76, 4, 14, 
    2, 67, 5, 79, 6, 10, 1, 92, 0, 22, 4, 67, 8, 33, 7, 36, 3, 56, 
    6, 80, 1, 74, 8, 21, 0, 52, 4,  9, 7, 98, 3,  9, 2, 86, 5, 24, 
    6, 83, 8,  1, 4, 13, 0, 85, 1, 57, 5, 92, 7,  3, 2,  1, 3, 89, 
    6, 86, 5, 63, 2, 46, 7, 15, 1, 95, 8, 76, 3, 51, 0, 74, 4, 73
  };
  const int q2967[] = {
    9, 9, // Number of jobs and machines
    6, 30, 4,  2, 0, 48, 7,  7, 3, 66, 1, 23, 8, 35, 2,  9, 5, 53, 
    4,  5, 3, 72, 0, 99, 5, 30, 8, 57, 2, 67, 1,  2, 6, 77, 7,  7, 
    6, 35, 7, 36, 3, 78, 1, 41, 0,  6, 8, 30, 4, 73, 2, 24, 5, 47, 
    8, 14, 7, 31, 0, 56, 1, 30, 5, 16, 3, 59, 2, 16, 4, 67, 6, 82, 
    7, 41, 0, 86, 1, 16, 3, 22, 8,  8, 4, 63, 2, 57, 5,  6, 6, 19, 
    2, 72, 8, 24, 5, 63, 3, 46, 7, 79, 6, 30, 1, 84, 0, 27, 4, 80, 
    7, 71, 0, 70, 8, 97, 4,  3, 3, 13, 6, 69, 1, 26, 5, 54, 2, 79, 
    6,  7, 0, 84, 7, 40, 4, 18, 3, 33, 2, 19, 5, 61, 1, 25, 8, 31, 
    3, 55, 6, 45, 1, 37, 5, 35, 8, 84, 4, 26, 0, 69, 7, 92, 2, 57
  };
  const int q2968[] = {
    9, 9, // Number of jobs and machines
    0, 70, 3, 39, 1, 88, 6, 90, 8, 45, 2, 89, 4, 44, 7, 63, 5, 58, 
    1, 60, 3, 99, 0, 64, 4, 90, 8, 18, 7, 79, 2, 97, 5, 58, 6, 31, 
    2, 12, 0, 30, 1, 87, 3, 77, 4, 64, 7, 75, 5, 99, 6, 73, 8, 63, 
    0, 39, 3, 45, 4, 30, 8, 58, 2, 89, 5, 77, 7, 57, 6,  1, 1, 60, 
    6, 15, 7, 19, 1, 86, 0, 46, 4, 85, 8, 46, 5, 83, 3, 38, 2, 57, 
    4, 85, 5,  1, 3, 90, 7, 84, 1, 80, 8, 72, 2, 51, 0,  5, 6, 26, 
    0, 50, 8, 92, 4, 14, 2, 52, 7, 35, 6, 79, 5, 82, 3, 95, 1, 83, 
    8, 98, 2, 87, 4, 22, 1, 95, 6, 57, 7, 10, 5, 23, 0, 15, 3, 17, 
    0, 58, 6, 57, 8, 15, 3, 61, 4, 97, 1, 33, 7, 78, 2, 84, 5, 24
  };
  const int q2969[] = {
    9, 9, // Number of jobs and machines
    2, 23, 7, 36, 4, 64, 0, 55, 1, 37, 6, 39, 8, 23, 5, 55, 3, 38, 
    5, 44, 7, 36, 8, 41, 2, 70, 3, 16, 4, 18, 1, 61, 0, 27, 6, 60, 
    2, 76, 0, 13, 8, 47, 7, 78, 1, 72, 6, 27, 4, 12, 5, 51, 3, 29, 
    7,  4, 6, 16, 3, 24, 8, 25, 0, 99, 1, 56, 2,  5, 4, 24, 5,  3, 
    2, 32, 0, 49, 5, 18, 7, 66, 1,  8, 8,  1, 3, 89, 6, 26, 4, 63, 
    0,  4, 6, 53, 2, 54, 3, 45, 8,  6, 7, 83, 1, 30, 5, 80, 4, 16, 
    6, 12, 7, 21, 1, 63, 8, 18, 0, 63, 5, 13, 3, 13, 4, 13, 2, 99, 
    6,  5, 1, 26, 4, 56, 0, 86, 3, 34, 7, 34, 5, 53, 2, 48, 8, 90, 
    1, 73, 0, 88, 8, 74, 7, 52, 3, 79, 6, 17, 5, 29, 2, 76, 4, 54
  };
  const int q2970[] = {
    9, 9, // Number of jobs and machines
    0, 37, 1, 28, 3, 70, 6, 59, 8, 82, 7, 42, 5, 30, 2, 73, 4, 64, 
    6, 41, 3, 56, 5, 76, 1, 54, 4, 50, 0, 32, 2, 80, 7, 73, 8, 54, 
    8, 65, 2, 14, 1, 36, 3, 62, 6, 81, 0, 36, 5, 39, 4, 37, 7, 25, 
    3, 69, 7, 78, 1, 73, 8, 79, 6, 55, 0, 68, 2, 74, 4, 21, 5,  1, 
    0, 55, 4, 47, 5,  2, 3, 46, 6, 37, 8, 94, 7, 16, 1, 44, 2, 61, 
    6, 25, 4, 13, 2, 80, 8, 73, 1, 57, 5, 86, 3, 36, 7,  3, 0, 40, 
    6, 73, 3, 79, 5, 44, 7, 38, 1, 72, 8, 69, 0,  9, 2, 66, 4, 69, 
    2, 86, 1, 65, 0, 29, 4, 99, 5, 94, 8, 32, 7, 28, 6, 42, 3, 86, 
    7, 32, 5,  8, 1, 39, 0, 52, 8, 60, 2, 30, 3, 42, 6, 10, 4, 30
  };
  const int q2971[] = {
    9, 9, // Number of jobs and machines
    2, 22, 8, 38, 5, 72, 4, 81, 3, 91, 1, 50, 7, 79, 0,  1, 6, 89, 
    7, 58, 5, 66, 0, 57, 2, 83, 4, 86, 1, 12, 6, 82, 3, 29, 8, 88, 
    3, 39, 6,  4, 8, 40, 1, 23, 7, 57, 5,  6, 4, 64, 2, 69, 0, 79, 
    8, 41, 2, 29, 3, 87, 7, 65, 5, 54, 6, 29, 1, 89, 4, 80, 0, 95, 
    8, 79, 1, 99, 7, 82, 4, 65, 2, 69, 3, 34, 0, 66, 6,  1, 5, 66, 
    6, 65, 5,  3, 0, 78, 3, 72, 7,  6, 1, 87, 2, 19, 8, 99, 4, 60, 
    4,  2, 1, 55, 2, 37, 5, 95, 7, 59, 3, 48, 0, 18, 8, 65, 6, 21, 
    2,  4, 7, 30, 8, 64, 6, 72, 3, 85, 4, 95, 0, 52, 1, 35, 5, 15, 
    8, 23, 5, 97, 0, 44, 1,  8, 4, 96, 7, 95, 3, 43, 2, 17, 6, 28
  };
  const int q2972[] = {
    9, 9, // Number of jobs and machines
    4, 19, 6, 94, 8, 50, 7, 76, 1,  4, 0, 43, 2, 93, 3, 91, 5, 56, 
    4, 97, 1, 82, 6, 40, 0, 57, 7,  8, 2, 52, 5, 44, 8, 53, 3, 70, 
    3, 95, 8, 12, 5, 37, 4, 18, 1, 86, 2, 78, 6, 17, 7,  3, 0,  2, 
    7, 72, 4, 62, 2, 10, 3, 92, 8, 44, 0, 91, 6, 63, 1, 88, 5,  8, 
    7, 18, 1, 51, 5, 89, 8, 32, 3, 47, 0, 81, 2, 93, 6, 72, 4, 17, 
    8, 63, 2, 73, 5, 26, 6, 53, 4, 49, 3,  5, 0, 47, 1,  4, 7, 93, 
    3, 27, 0, 98, 1, 54, 7, 20, 8, 44, 4, 58, 6, 14, 5, 25, 2, 87, 
    5, 98, 8, 97, 2, 84, 4, 80, 0, 36, 7, 72, 1, 54, 6, 89, 3, 61, 
    8, 31, 3, 38, 7, 14, 6,  3, 1, 68, 2, 48, 0, 68, 4, 66, 5, 35
  };
  const int q2973[] = {
    9, 9, // Number of jobs and machines
    6, 62, 3, 75, 1,  2, 8, 61, 5, 57, 2, 73, 4, 50, 7, 45, 0, 24, 
    3, 45, 8, 80, 4, 31, 1, 14, 7, 54, 5, 80, 2, 18, 0, 41, 6, 42, 
    6, 13, 8, 66, 0, 77, 1, 26, 4, 55, 2, 49, 7, 58, 3, 81, 5, 83, 
    0, 58, 1, 71, 3, 59, 8, 64, 7, 33, 5, 42, 2, 81, 4, 19, 6, 86, 
    5, 89, 2, 48, 3, 96, 6, 90, 0, 20, 4, 80, 1, 25, 8,  9, 7, 42, 
    1, 48, 8, 17, 4, 29, 5, 26, 2,  5, 6, 64, 0, 62, 3, 45, 7,  9, 
    3, 92, 4, 18, 0, 45, 1, 15, 6, 28, 2,  9, 8, 96, 7, 40, 5, 64, 
    2, 72, 1,  8, 5,  9, 7, 51, 8, 55, 4, 74, 3, 30, 0, 22, 6, 74, 
    1, 76, 7, 86, 8, 71, 4, 47, 6, 69, 2, 33, 5, 84, 3,  1, 0, 45
  };
  const int q2974[] = {
    9, 9, // Number of jobs and machines
    1, 96, 7, 14, 0, 32, 5, 31, 3, 99, 8, 35, 4,  7, 2,  7, 6, 69, 
    0, 89, 3, 30, 8, 75, 2, 17, 1, 66, 7, 79, 5, 91, 4,  5, 6, 95, 
    0, 73, 8, 78, 1, 35, 5, 75, 3, 59, 4, 45, 7, 56, 6, 73, 2, 70, 
    5, 80, 0, 87, 4, 53, 2, 60, 1, 49, 3, 91, 6, 47, 7, 36, 8, 99, 
    4, 58, 0, 57, 6, 75, 3, 29, 5,  5, 7,  9, 8, 65, 2, 42, 1, 80, 
    3, 83, 1, 64, 5, 42, 8, 61, 4,  3, 7, 37, 2, 25, 6, 91, 0, 22, 
    0,  7, 8, 61, 2, 53, 1,  3, 6, 53, 5, 66, 3, 94, 7, 94, 4, 60, 
    5, 13, 6, 17, 1, 99, 7, 27, 3, 22, 4, 85, 2, 26, 0, 33, 8, 49, 
    5, 62, 3, 57, 4, 55, 1, 26, 7, 62, 8, 47, 2, 32, 6,  5, 0, 85
  };
  const int q2975[] = {
    9, 9, // Number of jobs and machines
    2,  9, 1, 22, 3, 73, 5,  9, 6, 54, 8, 63, 0, 63, 7,  1, 4,  8, 
    4, 62, 7, 44, 8, 64, 6, 66, 2, 43, 5,  4, 1, 52, 0, 81, 3, 46, 
    5, 11, 0, 93, 3, 42, 7,  9, 2, 17, 1, 49, 8, 26, 4, 83, 6, 18, 
    5,  6, 3, 87, 7, 24, 0, 47, 4, 71, 1, 42, 6, 87, 2, 29, 8, 24, 
    7, 27, 1, 95, 5, 74, 4, 80, 2, 60, 3, 87, 0, 42, 6, 69, 8, 68, 
    0, 95, 8, 14, 4, 32, 3, 57, 2, 11, 7, 94, 6,  1, 5, 14, 1, 34, 
    5, 47, 8,  2, 2, 92, 3, 25, 7, 50, 1, 19, 4, 66, 0, 45, 6, 88, 
    0, 42, 5,  4, 8, 10, 7, 82, 4, 60, 3, 63, 2, 47, 6, 17, 1, 44, 
    7, 66, 8, 29, 0, 36, 4, 40, 2, 75, 5, 50, 1, 19, 6, 97, 3, 67
  };
  const int q2976[] = {
    9, 9, // Number of jobs and machines
    1, 84, 5, 74, 4, 47, 7, 49, 8, 24, 6, 55, 2, 69, 0,  5, 3, 68, 
    4, 41, 6, 95, 1, 81, 2, 75, 7, 41, 8, 51, 3, 86, 5, 24, 0, 82, 
    6, 84, 0, 82, 2,  2, 3, 80, 8, 31, 5, 84, 1, 51, 7, 38, 4, 83, 
    5, 51, 2, 88, 7, 77, 3, 87, 6, 93, 1, 74, 4, 71, 8, 33, 0, 31, 
    3, 68, 8, 20, 1, 86, 7, 97, 6, 40, 0, 89, 5, 15, 2, 33, 4, 61, 
    2,  8, 8, 64, 4, 59, 1, 49, 0, 60, 6, 23, 3, 54, 5, 49, 7, 58, 
    8, 22, 4, 39, 7, 79, 2,  3, 5, 75, 6, 29, 0, 92, 1, 49, 3, 88, 
    3, 57, 6,  3, 0, 32, 1, 84, 2, 90, 8, 35, 5, 99, 7, 80, 4, 49, 
    2, 79, 3, 32, 1, 23, 4, 99, 6, 92, 8, 62, 5, 85, 7, 89, 0, 43
  };
  const int q2977[] = {
    9, 9, // Number of jobs and machines
    3, 79, 4, 50, 6, 34, 8, 16, 2, 72, 7, 33, 1, 26, 5,  1, 0, 18, 
    8, 74, 6, 12, 3, 29, 0, 88, 5, 97, 1, 98, 4, 29, 2, 78, 7, 87, 
    6, 60, 3, 25, 7,  3, 0, 49, 1, 52, 5, 22, 2, 12, 8,  2, 4, 93, 
    2, 82, 1, 62, 7,  6, 3, 36, 6, 12, 4, 77, 5, 71, 0,  5, 8, 82, 
    5, 45, 0,  5, 7, 32, 1, 83, 6, 97, 8, 51, 2, 91, 3, 79, 4, 10, 
    0, 70, 2, 49, 1,  9, 6, 83, 3, 55, 8, 32, 4, 48, 5, 27, 7, 53, 
    7, 73, 4, 76, 0,  7, 5, 40, 1, 17, 2, 28, 3, 11, 8, 59, 6, 57, 
    7, 14, 5, 84, 1, 90, 4, 29, 3, 12, 2,  9, 8, 29, 6, 99, 0, 23, 
    1, 50, 0, 53, 3, 94, 2, 22, 5, 96, 6, 98, 7, 22, 4, 91, 8, 87
  };
  const int q2978[] = {
    9, 9, // Number of jobs and machines
    1, 33, 7, 99, 0, 29, 5, 62, 3, 57, 4, 49, 8, 50, 6,  5, 2, 46, 
    8, 54, 0, 93, 3, 88, 4, 85, 5, 41, 2, 21, 6, 36, 7, 13, 1, 48, 
    1, 54, 6, 44, 3, 20, 2, 39, 5, 70, 0, 12, 8, 51, 7, 19, 4, 85, 
    1,  7, 2, 39, 7, 80, 0, 96, 4, 68, 5, 61, 3, 27, 8, 49, 6, 17, 
    2, 48, 1, 83, 6, 70, 0, 58, 8, 98, 4, 47, 5, 75, 3, 22, 7, 15, 
    8, 71, 4, 70, 7, 94, 6, 43, 0, 77, 1, 86, 2, 49, 5, 13, 3,  8, 
    3, 25, 4, 76, 6, 48, 0,  8, 5, 41, 1, 54, 8, 97, 7, 20, 2, 26, 
    7, 52, 8, 22, 6, 40, 0, 39, 5,  8, 4, 13, 2, 39, 3, 42, 1, 25, 
    0, 47, 3, 68, 6, 51, 8, 18, 5, 13, 2, 36, 7, 34, 4, 32, 1, 69
  };
  const int q2979[] = {
    9, 9, // Number of jobs and machines
    5, 71, 3, 88, 8,  6, 4, 29, 6, 97, 0, 39, 7, 56, 1, 74, 2,  6, 
    2,  9, 6, 82, 3, 74, 5, 49, 7, 36, 4, 79, 1, 53, 8, 73, 0, 84, 
    3, 53, 4, 58, 8,  8, 1, 99, 7, 70, 6, 32, 2, 79, 5, 43, 0, 37, 
    4, 62, 0,  8, 3, 55, 1, 33, 2, 91, 5, 38, 8, 67, 7, 37, 6, 91, 
    6, 74, 3, 63, 2, 35, 4, 36, 0, 49, 7, 13, 1, 84, 8, 71, 5, 57, 
    1,  8, 8, 65, 3, 72, 0, 42, 5, 90, 4, 42, 7, 83, 6, 75, 2, 45, 
    3, 50, 8, 11, 2, 26, 1, 98, 7, 83, 5, 19, 0, 43, 6,  7, 4, 10, 
    7, 72, 2, 40, 1, 90, 6, 88, 5, 89, 3, 85, 4, 14, 8, 29, 0, 61, 
    4, 25, 2, 63, 1, 11, 3, 84, 5, 39, 7, 54, 6, 60, 8, 64, 0, 41
  };
  const int q2980[] = {
    9, 9, // Number of jobs and machines
    6, 25, 1, 26, 8, 64, 7, 28, 2, 10, 4, 91, 5, 35, 0, 81, 3, 47, 
    4, 37, 8, 99, 5, 98, 3, 10, 2, 74, 6, 53, 1, 46, 0, 79, 7, 10, 
    2, 93, 4, 44, 6, 74, 5, 83, 8, 69, 3, 99, 0, 61, 1, 56, 7, 11, 
    2, 24, 7, 39, 5, 90, 0, 98, 8, 68, 6, 70, 4, 56, 1, 48, 3,  4, 
    8, 86, 2, 42, 6, 43, 4, 53, 3, 67, 7, 94, 0, 20, 5, 41, 1, 23, 
    1, 96, 5, 25, 8, 50, 4, 31, 6, 46, 0, 31, 7,  7, 2, 27, 3, 80, 
    5, 39, 2, 65, 0, 28, 3, 23, 6, 30, 7, 39, 8, 29, 1, 81, 4, 33, 
    6, 50, 8, 75, 4, 97, 1, 88, 3, 60, 0, 98, 2, 42, 7, 41, 5, 70, 
    6, 11, 4, 66, 0, 36, 3, 85, 1, 48, 7, 17, 5, 28, 2, 88, 8, 15
  };
  const int q2981[] = {
    9, 9, // Number of jobs and machines
    6, 84, 8, 28, 7, 60, 5, 80, 4, 95, 3, 64, 0, 29, 2, 73, 1, 39, 
    4, 53, 2, 20, 1, 22, 6, 88, 5, 12, 8,  2, 3, 72, 7, 95, 0, 21, 
    6, 82, 7, 56, 2, 96, 8, 24, 4, 72, 3, 65, 0, 95, 5, 51, 1, 58, 
    5, 54, 4, 36, 7, 49, 3, 12, 0, 28, 6,  9, 1,  4, 8, 13, 2, 49, 
    6, 57, 0, 61, 8, 35, 2, 85, 1, 16, 5, 22, 4, 63, 3, 28, 7,  5, 
    7, 28, 2, 82, 5, 40, 0, 88, 3, 66, 8, 80, 6,  6, 1, 59, 4, 35, 
    1, 14, 7, 11, 0, 45, 2, 50, 4, 23, 6, 77, 8, 79, 3, 85, 5, 49, 
    2, 71, 8, 95, 4,  5, 0, 38, 7, 13, 3, 39, 1, 23, 6, 24, 5,  4, 
    2, 21, 5, 28, 4, 69, 6, 58, 3, 68, 0, 17, 8, 23, 7, 10, 1, 49
  };
  const int q2982[] = {
    9, 9, // Number of jobs and machines
    0,  2, 8,  5, 4, 68, 5,  2, 3, 38, 2, 42, 6, 37, 7, 66, 1, 76, 
    1, 73, 5, 92, 3, 86, 8, 73, 0, 21, 4,  8, 2, 51, 7, 46, 6, 18, 
    7, 75, 0, 76, 6, 98, 3,  6, 5, 60, 8, 41, 2, 99, 4, 25, 1, 88, 
    0,  9, 7, 34, 3, 81, 8, 62, 2, 33, 1, 94, 6, 14, 5,  7, 4, 14, 
    7, 42, 2, 99, 0, 18, 4, 70, 5, 48, 6, 39, 1, 33, 3, 48, 8, 48, 
    1, 77, 2, 46, 0, 85, 7,  4, 5, 47, 6, 44, 3, 42, 8, 71, 4, 55, 
    4, 56, 6,  5, 1, 43, 8, 49, 3, 87, 5, 41, 0, 16, 7, 12, 2, 10, 
    8,  5, 5, 34, 4, 21, 0, 70, 2, 85, 3, 14, 6, 69, 1, 38, 7, 94, 
    0, 20, 5, 33, 4, 50, 6, 66, 7, 90, 8, 38, 3, 16, 1, 89, 2, 45
  };
  const int q2983[] = {
    9, 9, // Number of jobs and machines
    0, 48, 8, 90, 1, 33, 7, 69, 4, 90, 6, 31, 2, 15, 5, 23, 3, 64, 
    3, 46, 4, 46, 7, 57, 1, 89, 8, 15, 6, 21, 5, 88, 2, 25, 0, 91, 
    0, 49, 4, 41, 5, 31, 1, 99, 7,  4, 6, 30, 8, 82, 2, 47, 3, 70, 
    4, 93, 3,  6, 6, 32, 1, 12, 2, 69, 8, 13, 5, 91, 7, 21, 0, 58, 
    3, 14, 4, 91, 6, 62, 5,  3, 0, 44, 1, 21, 7, 63, 8, 36, 2, 30, 
    8, 24, 6, 75, 1, 39, 7,  8, 2, 21, 3, 24, 4, 92, 0,  5, 5, 94, 
    2, 33, 3, 65, 7, 82, 1, 18, 0, 93, 8, 94, 5, 89, 4, 45, 6, 66, 
    7, 42, 2,  1, 3, 37, 1,  9, 8, 89, 4, 48, 0, 87, 5, 62, 6, 18, 
    3,  7, 8, 45, 1, 69, 6, 75, 7, 32, 0, 96, 4, 61, 2, 22, 5, 82
  };
  const int q2984[] = {
    9, 9, // Number of jobs and machines
    4, 90, 6, 56, 0, 50, 7, 64, 2, 57, 3, 91, 8, 25, 5, 78, 1, 68, 
    6, 21, 7, 89, 0,  5, 8, 34, 2, 93, 1, 56, 3, 36, 5, 23, 4, 43, 
    0, 23, 7, 66, 4, 80, 8, 24, 5, 69, 6, 83, 3, 16, 2, 79, 1, 33, 
    0, 78, 6, 71, 5, 76, 3, 62, 7, 18, 4, 73, 8, 60, 1, 41, 2, 31, 
    8, 78, 2, 21, 6, 75, 3, 91, 5, 85, 0, 96, 7, 57, 4, 35, 1, 27, 
    0, 39, 5, 47, 3, 73, 6, 61, 8, 35, 1,  7, 2, 37, 4, 93, 7, 34, 
    6, 43, 7,  6, 4, 91, 3, 27, 1,  9, 2, 33, 0, 89, 5, 47, 8, 21, 
    3, 89, 7, 94, 4, 90, 6, 30, 8, 41, 1, 95, 0, 45, 2, 92, 5, 89, 
    7, 95, 3,  7, 8, 57, 0, 53, 6, 38, 4, 53, 2, 55, 1, 24, 5, 45
  };
  const int q2985[] = {
    9, 9, // Number of jobs and machines
    6, 62, 2, 92, 8, 99, 0, 83, 4, 99, 5, 53, 1, 55, 7, 98, 3, 33, 
    7, 93, 6, 44, 0, 46, 5, 36, 1,  2, 4, 24, 8, 21, 3, 82, 2, 64, 
    4, 50, 0, 99, 1,  4, 8, 28, 7, 94, 5, 58, 2, 11, 6, 73, 3, 12, 
    2, 93, 7, 46, 0,  9, 3, 20, 4, 86, 6, 31, 8, 72, 1,  6, 5, 38, 
    8,  6, 6, 85, 4,  9, 5, 36, 1, 76, 0,  8, 3, 51, 7, 44, 2, 86, 
    6, 28, 7, 39, 0,  7, 5, 60, 4, 47, 1, 61, 2, 92, 3, 94, 8, 71, 
    1,  1, 7, 18, 0, 55, 8, 62, 6, 13, 3, 88, 5, 56, 4, 11, 2,  9, 
    4, 14, 3, 83, 6, 29, 5, 84, 7, 59, 0, 89, 1, 51, 2, 94, 8, 75, 
    3, 56, 8, 16, 0, 71, 4, 96, 7, 60, 5, 28, 2, 29, 1, 67, 6, 11
  };
  const int q2986[] = {
    9, 9, // Number of jobs and machines
    8, 38, 3, 24, 5, 33, 6, 47, 7, 21, 1, 96, 0, 84, 4,  3, 2,  1, 
    0, 69, 2, 29, 1, 32, 7, 51, 4, 90, 3, 37, 5, 20, 6, 36, 8, 65, 
    3, 22, 1, 66, 6,  6, 0, 70, 2, 84, 7, 72, 4, 91, 8, 48, 5, 62, 
    1, 43, 3, 90, 0, 60, 8, 20, 2,  8, 4, 83, 5, 73, 6, 44, 7, 44, 
    2, 30, 4, 81, 1, 36, 0, 70, 7, 57, 5, 54, 8,  2, 6, 12, 3, 50, 
    4, 67, 5, 71, 7,  2, 1, 36, 3, 61, 6, 15, 0, 16, 8, 28, 2, 44, 
    8, 43, 4, 36, 0, 57, 3, 26, 2, 53, 6, 61, 5, 57, 7, 36, 1, 49, 
    5, 73, 4, 96, 6, 55, 8, 54, 1, 78, 3, 56, 2, 32, 0, 42, 7, 85, 
    2, 21, 5, 47, 3,  3, 8, 41, 4, 98, 0, 91, 7, 64, 1, 74, 6, 73
  };
  const int q2987[] = {
    9, 9, // Number of jobs and machines
    2, 34, 3, 90, 1, 40, 0, 71, 8,  4, 7, 33, 6, 22, 5, 37, 4, 50, 
    7, 71, 6, 35, 2, 52, 8, 86, 5, 47, 0,  6, 4, 13, 1, 14, 3, 66, 
    6, 59, 4, 53, 7, 83, 1, 74, 2, 78, 0, 15, 8,  2, 5, 48, 3, 28, 
    8, 47, 1, 77, 7, 36, 2,  2, 3,  1, 4, 47, 0, 26, 5, 49, 6,  5, 
    7, 54, 6, 58, 2, 71, 5, 22, 8, 73, 1, 71, 0, 43, 4,  2, 3, 46, 
    3, 78, 7, 37, 8, 60, 2, 99, 1, 92, 6,  6, 0, 64, 4, 85, 5,  9, 
    1, 24, 0, 29, 6, 86, 4, 91, 7, 65, 2, 12, 3, 91, 8, 79, 5,  3, 
    3, 28, 6, 78, 0, 35, 7, 48, 2, 56, 1, 90, 5, 37, 8,  3, 4, 31, 
    1,  2, 8, 18, 3, 85, 5,  4, 6, 96, 7, 64, 4, 62, 0, 72, 2, 31
  };
  const int q2988[] = {
    9, 9, // Number of jobs and machines
    2, 35, 4, 80, 6, 83, 3, 21, 0, 67, 8, 95, 1, 82, 7, 52, 5, 96, 
    5, 91, 0, 58, 4, 20, 7, 48, 8, 31, 2, 18, 6, 23, 3, 28, 1, 34, 
    5, 59, 1, 36, 8, 55, 3, 54, 2, 14, 4, 26, 7,  7, 0, 30, 6, 92, 
    7, 84, 4, 46, 5, 96, 6, 63, 0, 43, 3, 73, 8, 22, 2, 91, 1, 18, 
    7, 70, 5, 75, 8, 24, 3, 50, 2, 70, 1, 14, 0, 57, 6, 34, 4, 28, 
    6, 58, 4, 12, 5, 83, 3, 17, 2, 24, 0, 63, 8, 10, 7, 98, 1, 38, 
    8, 24, 4, 87, 2, 68, 5, 93, 6,  8, 7, 87, 3, 18, 0,  6, 1, 53, 
    8, 58, 2, 83, 3, 96, 5, 81, 7, 56, 1, 30, 0, 71, 6, 39, 4, 32, 
    4,  3, 3, 99, 5, 95, 7, 67, 6, 98, 1, 12, 2,  2, 8, 23, 0, 69
  };
  const int q2989[] = {
    9, 9, // Number of jobs and machines
    1,  9, 5,  3, 7, 77, 8,  7, 4, 11, 3, 33, 6, 83, 0, 59, 2, 31, 
    3, 92, 0, 26, 6, 33, 8, 75, 2,  4, 4, 95, 1, 64, 7, 63, 5, 94, 
    3, 87, 8, 19, 4, 30, 1, 60, 7, 70, 2,  9, 6, 25, 5, 20, 0, 51, 
    3, 41, 1,  7, 6, 53, 5, 86, 7, 73, 8,  1, 4, 13, 2, 11, 0, 37, 
    5, 21, 8, 71, 3, 56, 6, 10, 4, 82, 7, 54, 0, 59, 2,  2, 1, 68, 
    6, 42, 0, 34, 4, 37, 8, 36, 7, 42, 1,  4, 2, 19, 5, 77, 3, 29, 
    6, 22, 4, 99, 1, 85, 8, 38, 5, 11, 0, 47, 2,  3, 3, 68, 7, 68, 
    0, 12, 3, 52, 6, 66, 2, 99, 4, 51, 5,  8, 7,  8, 1, 73, 8, 23, 
    1, 44, 8, 30, 7, 87, 2, 55, 3, 38, 6, 12, 4,  8, 0, 20, 5, 83
  };
  const int q2990[] = {
    9, 9, // Number of jobs and machines
    6, 75, 3, 65, 1, 87, 0, 41, 4, 11, 7, 21, 5, 60, 8, 17, 2, 56, 
    5, 21, 1, 96, 6, 70, 0, 72, 4, 68, 8, 24, 7,  2, 2,  8, 3, 66, 
    5, 54, 6, 31, 3, 69, 8, 77, 2, 81, 7, 48, 0, 46, 1, 14, 4, 94, 
    4, 86, 3, 65, 0, 18, 6, 65, 5, 21, 7, 91, 8, 33, 1, 90, 2, 74, 
    8, 92, 2, 24, 3,  2, 7, 68, 0, 72, 5, 73, 1, 66, 6, 42, 4, 29, 
    5,  5, 4, 17, 2, 99, 3, 72, 1, 51, 8, 78, 6, 59, 7, 95, 0, 53, 
    2, 72, 4, 68, 5, 79, 3, 91, 6, 24, 1, 15, 8, 17, 0, 87, 7, 12, 
    6, 92, 2, 16, 1, 88, 4, 88, 5, 59, 7, 10, 3, 14, 8, 12, 0, 35, 
    7, 21, 4, 46, 3,  1, 2, 78, 6, 30, 0, 65, 1, 58, 8, 28, 5, 59
  };
  const int q2991[] = {
    9, 9, // Number of jobs and machines
    5, 42, 7, 56, 4, 87, 3, 31, 2, 34, 1, 46, 6, 44, 0, 36, 8, 20, 
    4, 31, 7,  6, 2, 26, 0, 15, 6, 51, 8, 50, 5, 78, 3, 30, 1, 51, 
    1, 25, 6,  1, 4, 41, 7, 27, 5, 52, 2, 72, 3, 46, 8, 78, 0, 11, 
    7, 53, 2, 81, 8, 55, 6, 56, 0, 91, 1, 11, 3, 10, 4,  6, 5, 10, 
    6, 95, 1, 72, 4, 77, 7, 87, 0, 82, 3, 67, 8, 67, 5,  3, 2, 41, 
    0, 55, 1, 27, 3, 30, 2, 60, 8, 98, 5, 42, 4,  7, 7, 92, 6, 52, 
    1, 62, 3, 61, 4,  3, 7, 11, 8, 56, 0, 38, 2,  7, 5, 72, 6, 13, 
    5, 18, 3, 22, 8, 79, 0, 89, 2, 67, 4, 70, 7, 52, 1,  1, 6, 73, 
    3,  3, 5, 96, 7, 38, 4, 27, 0, 23, 6, 14, 8, 74, 2, 59, 1,  2
  };
  const int q2992[] = {
    9, 9, // Number of jobs and machines
    0,  9, 1, 73, 3, 70, 8, 21, 6, 91, 2, 26, 4, 70, 5, 22, 7, 39, 
    3, 13, 8,  5, 5, 76, 2, 13, 1, 64, 7, 52, 0, 69, 6, 48, 4,  3, 
    3, 97, 0, 20, 8,  3, 4, 60, 5, 79, 7, 86, 2, 92, 1, 10, 6, 45, 
    1, 62, 4, 26, 3,  6, 8, 78, 7, 93, 5, 83, 6, 89, 2, 32, 0,  4, 
    8, 28, 0, 78, 4, 41, 3, 50, 2, 35, 7, 48, 6, 62, 5, 71, 1,  9, 
    2, 86, 7, 45, 3, 30, 0, 31, 1, 58, 5, 42, 8, 18, 4, 18, 6,  1, 
    2, 90, 3, 93, 1, 65, 6, 34, 4, 41, 8, 36, 5, 18, 0, 81, 7, 16, 
    6, 64, 0, 65, 2, 12, 4, 51, 3, 55, 7,  3, 8, 50, 5, 40, 1, 47, 
    6, 47, 5,  2, 4, 65, 8, 81, 3, 59, 7, 44, 2, 46, 1, 76, 0, 71
  };
  const int q2993[] = {
    9, 9, // Number of jobs and machines
    5, 94, 8,  2, 4, 85, 1, 84, 7, 32, 0, 34, 6, 86, 2, 86, 3, 82, 
    5, 41, 8, 83, 7, 51, 3, 46, 6, 94, 2, 86, 0, 86, 1, 46, 4, 78, 
    7, 43, 4, 52, 6, 28, 2, 94, 3, 65, 0, 98, 8, 79, 1, 91, 5, 54, 
    2, 72, 8,  6, 7, 75, 4, 56, 5, 15, 6, 78, 0, 78, 3, 78, 1, 26, 
    4, 74, 3, 30, 0, 72, 2, 23, 1, 13, 5, 23, 8, 53, 6, 17, 7, 38, 
    7, 88, 1, 92, 2, 80, 3, 45, 6, 11, 5, 32, 8, 83, 4, 30, 0, 63, 
    0, 89, 7, 17, 6, 38, 4, 76, 1, 76, 5, 31, 2, 65, 8, 99, 3, 93, 
    5, 11, 1, 66, 3, 52, 4,  9, 2, 61, 8, 15, 7, 63, 6,  4, 0, 88, 
    1, 45, 4, 40, 6, 85, 3, 25, 0, 43, 5, 61, 2, 44, 8, 80, 7,  8
  };
  const int q2994[] = {
    9, 9, // Number of jobs and machines
    8, 97, 7, 79, 6, 80, 4, 58, 2,  2, 5, 91, 0, 62, 3,  1, 1, 46, 
    5, 68, 0, 94, 1, 38, 8,  5, 4, 71, 6, 36, 7, 18, 3, 44, 2, 75, 
    7, 35, 4, 73, 3, 13, 2, 50, 5, 42, 6, 86, 1, 74, 8, 92, 0, 54, 
    1, 14, 6, 51, 8,  3, 2, 66, 4, 72, 7, 49, 3, 29, 0, 94, 5, 77, 
    5, 68, 4, 53, 0, 77, 8, 11, 2,  1, 1,  4, 6, 99, 3, 54, 7, 21, 
    4, 52, 5, 10, 6, 19, 7, 58, 1, 93, 2, 55, 0, 14, 3, 26, 8, 23, 
    3, 18, 4,  9, 5,  1, 1,  1, 6, 79, 8, 91, 0, 47, 2, 54, 7, 81, 
    2, 48, 0, 42, 1, 43, 5, 11, 7, 22, 4, 47, 3, 27, 8, 71, 6, 25, 
    2, 62, 0, 47, 5,  7, 1, 78, 8, 21, 6, 31, 4, 96, 3, 28, 7, 11
  };
  const int q2995[] = {
    9, 9, // Number of jobs and machines
    3, 34, 0, 70, 2, 34, 8, 56, 5, 19, 1, 53, 7, 88, 6, 51, 4, 53, 
    0, 33, 7, 43, 1, 29, 4, 39, 3, 92, 8, 21, 2, 73, 5, 89, 6, 97, 
    4, 27, 6, 13, 8, 10, 3, 29, 5, 51, 2, 83, 1, 50, 7, 21, 0, 13, 
    3, 39, 2,  2, 4, 45, 7, 16, 1, 31, 5, 12, 8, 89, 0, 10, 6, 97, 
    3, 60, 5, 46, 7, 57, 6, 40, 0, 10, 1, 41, 2, 77, 4, 65, 8, 76, 
    7, 45, 8, 85, 6, 85, 4, 70, 1, 49, 3, 11, 2, 98, 0, 82, 5, 93, 
    3,  2, 7, 78, 8, 78, 1, 40, 2, 87, 0, 79, 5, 43, 4, 37, 6, 38, 
    1, 64, 3, 73, 2, 54, 6, 92, 0, 45, 7, 28, 4, 10, 8, 78, 5, 95, 
    0,  3, 6, 94, 1, 11, 5, 12, 4, 22, 2, 78, 3, 39, 8, 37, 7, 53
  };
  const int q2996[] = {
    9, 9, // Number of jobs and machines
    2, 36, 5, 11, 3, 90, 6, 31, 4, 91, 1, 10, 0, 79, 7, 97, 8, 70, 
    0,  7, 7, 72, 6, 32, 8, 29, 3,  4, 2,  6, 4, 58, 1, 16, 5, 17, 
    0, 65, 4, 73, 7,  8, 6, 33, 1, 30, 2, 12, 3, 11, 8, 49, 5, 22, 
    8, 17, 0, 38, 4, 27, 7, 73, 1,  4, 2, 62, 6, 63, 3, 51, 5, 65, 
    7,  4, 6, 31, 3, 13, 1, 91, 0, 76, 2, 45, 4, 88, 8,  1, 5, 19, 
    5, 68, 2, 82, 4, 96, 3, 22, 6, 73, 7, 56, 8, 47, 0, 70, 1, 15, 
    3, 23, 5,  7, 2, 83, 0, 69, 6, 96, 8, 47, 1,  5, 4, 70, 7, 38, 
    7,  9, 5, 38, 2, 93, 0, 23, 4, 46, 6,  8, 8, 89, 3, 44, 1, 48, 
    3, 55, 5, 30, 4, 93, 6, 93, 2, 73, 8, 68, 0,  6, 1,  3, 7, 24
  };
  const int q2997[] = {
    9, 9, // Number of jobs and machines
    5, 27, 0, 36, 3, 54, 8, 15, 6, 57, 7, 42, 2, 39, 4, 97, 1, 88, 
    8, 34, 1, 59, 2, 75, 3, 58, 4, 59, 7, 16, 6, 80, 0, 11, 5, 13, 
    0, 60, 8, 42, 3, 63, 7, 65, 1, 18, 2, 29, 6, 17, 5, 87, 4, 32, 
    6, 73, 5, 46, 4, 79, 7,  5, 2, 86, 1, 48, 0, 26, 3, 33, 8, 28, 
    4, 48, 8, 13, 7, 24, 1, 93, 5,  8, 0, 15, 6, 34, 2, 54, 3, 27, 
    1, 32, 6, 34, 8, 88, 0, 21, 5, 47, 2, 18, 3, 17, 7, 50, 4, 17, 
    6, 30, 4, 36, 5, 36, 8, 93, 3, 66, 7, 32, 2, 91, 1, 63, 0,  7, 
    2, 85, 0, 98, 8, 49, 4, 73, 1, 70, 7,  1, 6, 29, 3, 35, 5,  2, 
    0,  5, 6,  3, 8, 17, 5, 96, 7, 44, 2, 79, 3, 73, 4, 56, 1, 65
  };
  const int q2998[] = {
    9, 9, // Number of jobs and machines
    8, 80, 0, 29, 5, 22, 4, 10, 3, 39, 1, 51, 2, 72, 7, 66, 6, 55, 
    2, 15, 7, 98, 3, 23, 1, 38, 0, 84, 5,  8, 8, 16, 6, 61, 4, 87, 
    4, 46, 2, 18, 6, 44, 0, 29, 8, 69, 1, 96, 7, 12, 3, 68, 5, 22, 
    4,  3, 6, 38, 2, 31, 0, 90, 1, 94, 8, 45, 3, 22, 5,  9, 7, 59, 
    8,  4, 5, 27, 2,  3, 7, 25, 1, 11, 4, 33, 3, 70, 0, 44, 6, 70, 
    8, 49, 6, 83, 7, 30, 5, 57, 2, 51, 0, 43, 4, 35, 1, 18, 3, 15, 
    1, 88, 2, 85, 6, 77, 4, 78, 8, 12, 5, 85, 0, 99, 7, 42, 3, 73, 
    5, 30, 0, 55, 1,  1, 4,  2, 3, 44, 6, 13, 2, 85, 7, 67, 8, 81, 
    1, 69, 6, 18, 8, 81, 7,  2, 4, 91, 5, 15, 3, 32, 0, 13, 2, 24
  };
  const int q2999[] = {
    9, 9, // Number of jobs and machines
    2, 18, 7, 69, 4, 21, 8, 98, 1, 74, 5, 90, 3, 57, 6, 94, 0, 18, 
    8, 30, 1, 99, 0, 98, 4, 74, 6, 42, 7,  8, 5, 60, 3, 92, 2, 98, 
    4, 76, 1, 70, 0, 18, 6, 41, 2, 90, 8,  8, 5, 42, 3, 43, 7, 15, 
    4, 65, 2, 21, 1, 27, 0, 22, 6, 30, 5, 15, 8, 33, 7, 84, 3, 19, 
    2, 79, 8, 11, 4, 40, 3, 18, 0, 25, 1, 24, 6, 28, 5, 24, 7, 26, 
    0,  9, 4,  8, 2, 26, 5, 14, 6, 12, 8, 33, 3, 72, 1, 59, 7, 95, 
    1, 23, 0, 13, 2, 88, 8, 18, 4, 42, 7,  2, 5, 95, 6, 28, 3, 84, 
    2, 92, 7, 93, 3, 77, 0, 80, 1, 35, 5, 56, 8, 63, 6, 51, 4, 46, 
    8, 30, 6, 20, 5,  7, 4, 21, 0, 44, 2,  1, 3, 62, 7, 77, 1, 31
  };
  const int q3000[] = {
    9, 9, // Number of jobs and machines
    8, 52, 5, 31, 6,  8, 1, 10, 3, 60, 4, 42, 7, 48, 0, 25, 2, 45, 
    2, 22, 0, 76, 3, 71, 7, 66, 6, 34, 8, 84, 4, 78, 1, 87, 5, 74, 
    1, 77, 0, 42, 6, 47, 3, 45, 8, 97, 5, 80, 2, 63, 7,  8, 4, 49, 
    4, 86, 8, 98, 1, 24, 0, 19, 3, 80, 6, 93, 2, 99, 7, 40, 5, 68, 
    8, 33, 3, 64, 6, 39, 2, 99, 0, 29, 1, 15, 7, 48, 4, 82, 5, 50, 
    7, 89, 6,  8, 1, 67, 8, 23, 4, 28, 0, 29, 3, 84, 5, 58, 2, 25, 
    4, 87, 2, 23, 6, 22, 8,  4, 7, 15, 1, 24, 3,  1, 5, 83, 0, 41, 
    6, 61, 1, 71, 5, 10, 8,  2, 4, 14, 3, 81, 2, 27, 0, 70, 7, 42, 
    3, 37, 2, 75, 6, 14, 4, 31, 5, 10, 8,  5, 0, 59, 7, 84, 1, 31
  };
  const int q3001[] = {
    9, 9, // Number of jobs and machines
    7,  7, 0, 34, 5, 78, 1,  9, 8, 41, 4, 14, 3, 94, 6, 68, 2,  1, 
    7, 62, 2,  8, 8,  4, 3, 93, 0, 43, 4, 24, 5, 40, 1, 30, 6, 78, 
    8, 86, 1, 55, 5, 82, 2, 87, 0, 87, 4, 71, 6, 22, 3,  9, 7, 81, 
    3, 90, 6, 50, 8, 31, 5, 94, 7, 29, 0, 25, 4, 17, 1, 45, 2, 49, 
    5, 46, 4, 16, 7, 74, 1, 79, 0,  8, 2,  9, 6, 36, 3, 61, 8,  9, 
    6, 76, 4, 59, 8, 16, 2, 74, 7, 44, 1, 43, 0, 31, 3, 65, 5, 57, 
    4, 73, 1, 18, 6,  7, 5,  7, 8, 98, 2, 45, 7, 69, 0,  1, 3,  7, 
    6, 88, 7, 73, 3, 61, 2, 83, 0, 74, 4, 85, 5, 78, 1, 16, 8, 25, 
    2, 23, 4, 44, 6, 41, 7, 69, 1, 71, 3, 80, 0, 19, 8, 54, 5, 34
  };
  const int q3002[] = {
    9, 9, // Number of jobs and machines
    2, 22, 8, 50, 0, 96, 7, 45, 5, 50, 1, 23, 4, 73, 6, 55, 3, 14, 
    2, 81, 8, 15, 0, 19, 6, 24, 7,  6, 1, 69, 4, 96, 5, 99, 3, 36, 
    5, 26, 4, 26, 6, 36, 7, 88, 3, 43, 1, 84, 0, 29, 8, 50, 2, 79, 
    8, 60, 2, 99, 7, 98, 4, 30, 1, 15, 5, 46, 0, 27, 6, 54, 3, 97, 
    3, 85, 0,  5, 4, 24, 5, 73, 2, 10, 1, 94, 7,  7, 6, 14, 8, 47, 
    8, 87, 6, 68, 0, 51, 3, 67, 2, 95, 4, 75, 1, 35, 5, 15, 7, 45, 
    1, 84, 8, 25, 3, 26, 2,  5, 0, 59, 6, 63, 5, 58, 4, 52, 7, 74, 
    2, 99, 4, 61, 0,  9, 6, 10, 8, 59, 1,  2, 5, 16, 3, 73, 7, 51, 
    8, 28, 6, 71, 1, 49, 7, 21, 4, 50, 0, 26, 5,  9, 3, 50, 2, 37
  };
  const int q3003[] = {
    9, 9, // Number of jobs and machines
    4, 43, 3, 57, 5, 66, 2, 98, 8, 71, 7, 78, 6, 37, 1, 87, 0, 19, 
    3, 44, 6, 93, 8, 10, 2, 42, 5, 49, 7, 95, 0, 93, 4, 44, 1, 36, 
    0, 70, 6, 33, 3,  6, 1, 10, 8, 28, 7, 67, 4, 24, 5, 22, 2, 68, 
    4, 98, 0, 38, 7, 52, 6, 48, 8, 76, 3, 23, 2,  5, 1, 68, 5, 93, 
    4, 26, 6, 46, 3, 89, 1,  4, 2, 33, 7, 95, 0, 24, 5,  4, 8, 96, 
    8, 24, 4, 20, 7, 45, 5, 57, 2, 79, 0,  6, 6, 57, 3, 57, 1, 36, 
    6, 11, 4, 92, 8, 23, 7, 86, 3, 44, 5, 81, 2, 98, 1, 27, 0, 65, 
    7, 78, 5, 45, 8,  4, 2, 70, 3,  1, 1, 94, 6, 93, 0, 23, 4, 20, 
    8, 75, 2, 26, 1, 13, 3, 71, 0, 41, 7, 89, 4, 46, 5, 11, 6,  7
  };
  const int q3004[] = {
    9, 9, // Number of jobs and machines
    7, 76, 6, 64, 3, 31, 4, 97, 1, 36, 2, 52, 5, 31, 0, 55, 8, 32, 
    3, 64, 6, 43, 7, 25, 2, 55, 1, 26, 8, 58, 4, 52, 5, 51, 0, 97, 
    1, 24, 6, 62, 4, 80, 5, 48, 3, 65, 0, 94, 2, 31, 8, 52, 7, 79, 
    1,  3, 4, 52, 3, 56, 8, 35, 2, 84, 7, 90, 5, 90, 6, 89, 0, 76, 
    0,  8, 5, 43, 6, 65, 3, 91, 1, 80, 2, 33, 7, 95, 4, 21, 8, 10, 
    3, 89, 2, 91, 1, 63, 7, 52, 8, 16, 0, 14, 6, 77, 5, 36, 4, 13, 
    7, 63, 1, 34, 0, 64, 4, 19, 8, 21, 5, 46, 6, 33, 3, 80, 2, 79, 
    6, 17, 0, 94, 1,  7, 3, 49, 4, 55, 8, 18, 7, 83, 5, 73, 2, 88, 
    5, 74, 7, 86, 6,  9, 8, 39, 2, 72, 0, 66, 3, 68, 4, 18, 1, 65
  };
  const int q3005[] = {
    9, 9, // Number of jobs and machines
    8, 93, 5,  4, 6, 95, 7, 98, 4, 10, 0,  9, 1, 90, 3,  3, 2, 21, 
    5, 28, 2, 67, 1, 96, 0, 55, 3,  3, 8, 90, 7, 44, 6, 32, 4, 61, 
    3,  9, 8, 56, 2, 75, 7, 26, 4, 26, 5,  2, 6, 71, 0, 45, 1, 19, 
    4, 20, 0, 60, 6, 70, 7, 89, 5, 19, 1,  5, 2, 70, 3, 60, 8, 61, 
    3, 81, 1, 37, 5, 97, 6, 92, 2, 84, 4, 44, 8,  8, 7, 84, 0, 56, 
    8, 28, 0,  6, 2, 36, 3,  7, 1, 96, 7, 35, 4, 29, 5, 48, 6, 59, 
    7, 50, 4, 95, 1, 31, 5, 94, 2, 98, 8, 21, 3, 27, 6, 56, 0, 55, 
    7, 19, 0, 66, 2,  3, 4, 80, 6, 57, 1, 23, 3, 32, 8, 29, 5, 21, 
    3, 33, 8, 30, 4, 55, 1, 87, 5, 26, 2, 28, 7, 77, 6, 25, 0, 40
  };
  const int q3006[] = {
    9, 9, // Number of jobs and machines
    2,  1, 1, 31, 0, 42, 3, 77, 5, 93, 6, 41, 7, 17, 4, 44, 8, 58, 
    0, 28, 7, 68, 4, 62, 2, 75, 6, 78, 3, 34, 8, 59, 1, 75, 5, 32, 
    5, 66, 8, 83, 0, 87, 4, 84, 2, 23, 6, 57, 1, 49, 3, 93, 7, 70, 
    0, 39, 1, 98, 8, 81, 5, 61, 3, 38, 6, 45, 7,  8, 2, 65, 4, 65, 
    2, 69, 4, 63, 8,  4, 7, 75, 5, 66, 6, 95, 3, 77, 0, 48, 1, 20, 
    6, 45, 8, 19, 5, 22, 2, 71, 7, 32, 4,  3, 0, 44, 1, 33, 3, 83, 
    6, 47, 1, 32, 7, 16, 4, 41, 8, 64, 0, 22, 3, 32, 2, 22, 5, 87, 
    0, 83, 3, 90, 5, 51, 1, 71, 4, 25, 7, 44, 8, 51, 2, 72, 6, 77, 
    5, 99, 1, 70, 2, 84, 8, 74, 4, 82, 7, 81, 0, 79, 6, 67, 3, 73
  };
  const int q3007[] = {
    9, 9, // Number of jobs and machines
    1, 22, 7, 31, 0, 19, 8, 67, 3, 77, 6, 75, 4, 22, 5, 73, 2, 85, 
    1, 65, 5,  6, 7, 53, 0, 75, 6, 73, 4, 85, 2, 13, 8, 90, 3, 39, 
    3, 25, 4, 35, 7, 24, 8, 62, 5, 24, 0, 83, 6, 53, 1, 29, 2, 47, 
    0, 37, 4, 86, 6, 13, 5, 54, 2, 43, 1, 49, 7, 65, 8, 30, 3, 38, 
    7, 35, 5,  6, 1, 35, 6,  2, 3, 92, 0, 47, 8, 65, 2, 23, 4, 58, 
    7, 23, 0, 66, 1, 15, 4,  4, 6, 97, 5, 81, 3, 65, 2, 49, 8, 28, 
    1, 78, 7, 16, 5, 74, 2, 40, 3, 66, 4, 14, 0, 68, 6, 36, 8, 99, 
    3, 47, 4, 59, 2, 11, 0, 96, 7, 56, 6, 38, 1, 71, 5,  7, 8, 57, 
    2, 68, 3, 95, 6, 52, 1, 33, 0, 83, 7, 26, 5, 78, 8, 43, 4, 20
  };
  const int q3008[] = {
    9, 9, // Number of jobs and machines
    1, 53, 4, 67, 2,  1, 3, 86, 0, 51, 7, 19, 5, 24, 8,  9, 6,  5, 
    8, 59, 6, 29, 7, 47, 4, 83, 1, 67, 3, 84, 2, 73, 0, 67, 5, 93, 
    1, 68, 8, 63, 2, 17, 3, 36, 7, 18, 0, 57, 6, 73, 4, 32, 5, 44, 
    3, 58, 8, 28, 4, 70, 0, 29, 5, 11, 2, 78, 6, 85, 7, 63, 1, 11, 
    3, 71, 8, 82, 5, 98, 0, 44, 6,  5, 7, 80, 1, 11, 4, 43, 2, 81, 
    3, 82, 5, 94, 7, 30, 6, 43, 4, 13, 8, 86, 2, 54, 1,  6, 0, 13, 
    5, 17, 6, 29, 2, 55, 3, 76, 8, 69, 7, 80, 0, 37, 4, 40, 1, 15, 
    2, 63, 4, 73, 8, 41, 1,  6, 7, 68, 0, 56, 6, 30, 5, 38, 3,  1, 
    6, 96, 5, 21, 0, 74, 4, 53, 1, 70, 7, 50, 8, 45, 3, 10, 2, 57
  };
  const int q3009[] = {
    9, 9, // Number of jobs and machines
    1, 24, 4, 24, 5, 13, 0, 51, 7,  9, 3, 45, 2, 87, 6, 37, 8, 47, 
    7, 25, 2, 46, 5, 46, 0,  2, 3, 61, 1, 27, 8, 69, 6, 25, 4, 69, 
    0, 70, 7, 47, 1, 41, 8, 13, 4, 25, 2, 40, 5, 32, 3, 81, 6, 31, 
    2, 94, 1, 71, 8, 91, 3,  5, 7, 18, 4, 39, 0, 44, 5, 70, 6, 11, 
    7, 58, 0, 89, 1,  8, 3, 32, 2, 44, 6, 39, 8, 26, 5, 17, 4, 81, 
    3, 66, 7, 32, 4, 15, 1, 58, 0, 54, 2, 70, 6, 67, 8, 34, 5, 55, 
    2, 99, 0, 28, 5, 40, 4, 13, 1, 88, 6, 43, 3, 92, 7, 57, 8, 69, 
    6, 82, 5, 25, 7, 95, 1, 50, 4, 30, 0, 31, 3,  4, 8, 84, 2, 64, 
    6, 75, 7, 42, 4, 15, 3,  5, 5, 28, 8, 69, 1, 34, 0, 81, 2, 58
  };
  const int q3010[] = {
    9, 9, // Number of jobs and machines
    6, 96, 7,  2, 4, 74, 8, 19, 2, 26, 0, 40, 5, 38, 3, 58, 1, 31, 
    3, 38, 5, 19, 6, 80, 1, 67, 2, 40, 0,  3, 4, 79, 8, 71, 7, 40, 
    2, 11, 7, 49, 4, 21, 3, 62, 6, 55, 5, 93, 0, 13, 1, 66, 8, 11, 
    8, 69, 6, 73, 1, 57, 2, 99, 0, 86, 5, 38, 4, 30, 7, 26, 3, 21, 
    1, 98, 4, 25, 8, 67, 0, 19, 2, 41, 7, 17, 6, 25, 3, 42, 5,  8, 
    6, 23, 8, 40, 5, 20, 7, 19, 0, 42, 4, 64, 1, 31, 2, 77, 3, 32, 
    8, 27, 1, 37, 0, 51, 6, 16, 7, 52, 3, 39, 5, 29, 4,  8, 2, 32, 
    0, 60, 5, 44, 3, 35, 2, 51, 7, 46, 4,  3, 8,  6, 6, 15, 1, 75, 
    7, 46, 2,  1, 5, 26, 1, 95, 3, 45, 6, 67, 8, 55, 0, 89, 4, 54
  };
  const int q3011[] = {
    9, 9, // Number of jobs and machines
    2, 85, 8,  8, 3, 58, 1, 80, 6, 71, 0, 55, 7, 61, 4, 40, 5, 39, 
    1, 52, 0, 54, 2, 20, 4, 44, 5, 17, 6, 41, 8, 66, 7, 28, 3, 94, 
    1, 58, 2, 81, 6, 81, 8, 49, 7, 81, 0, 55, 3, 77, 4, 27, 5, 18, 
    6, 32, 3, 79, 8, 43, 4, 77, 5, 34, 2, 14, 0, 62, 7, 42, 1, 96, 
    1, 31, 0, 49, 2, 31, 7, 75, 5,  8, 6, 43, 3, 60, 4, 28, 8, 90, 
    1, 76, 2, 27, 7,  7, 8, 51, 0, 80, 5, 40, 4, 39, 3, 76, 6, 40, 
    2, 81, 5, 70, 3, 26, 7, 55, 4, 11, 1, 67, 6, 56, 8, 13, 0, 62, 
    2, 93, 4, 74, 7, 86, 6, 65, 8, 53, 5, 85, 1, 15, 3, 66, 0, 34, 
    5, 89, 2, 83, 3, 80, 0, 58, 4,  4, 8, 36, 7, 81, 1, 52, 6, 49
  };
  const int q3012[] = {
    9, 9, // Number of jobs and machines
    6,  5, 0, 53, 5, 90, 4, 38, 8, 58, 7, 84, 1, 37, 2, 37, 3, 63, 
    5, 45, 6, 21, 2, 15, 0, 28, 1, 88, 8, 13, 7, 95, 3, 66, 4, 72, 
    3, 38, 4, 45, 0, 13, 8, 18, 5, 34, 7, 91, 1, 79, 6, 68, 2, 85, 
    2, 85, 4,  8, 5, 99, 0, 81, 1, 70, 3, 63, 8, 99, 7, 62, 6, 48, 
    6, 94, 2, 50, 8, 90, 7, 10, 3, 71, 1, 79, 4, 69, 5, 69, 0, 52, 
    4, 16, 2, 99, 3, 42, 1, 21, 8, 90, 0, 36, 5,  8, 6, 71, 7,  9, 
    2, 62, 0, 45, 5, 46, 8, 50, 4, 42, 6, 75, 1, 98, 7, 83, 3, 45, 
    3, 30, 0, 15, 4, 18, 8, 87, 6, 90, 5, 20, 7, 38, 2, 79, 1, 90, 
    4, 58, 5,  8, 3, 66, 8, 28, 1,  5, 6, 31, 0, 61, 2, 44, 7, 40
  };
  const int q3013[] = {
    9, 9, // Number of jobs and machines
    2, 59, 1, 94, 6, 49, 0, 28, 8, 79, 5, 26, 3, 60, 7, 44, 4, 68, 
    3, 12, 4, 91, 2, 58, 8, 84, 1, 76, 0, 54, 5, 85, 6,  8, 7, 17, 
    0, 14, 7, 32, 6, 19, 3, 37, 1,  6, 8, 89, 5, 19, 4,  5, 2, 61, 
    3, 30, 4, 89, 1, 90, 5, 94, 0,  9, 7, 19, 8, 86, 6, 98, 2, 38, 
    1, 24, 3, 80, 2, 98, 4, 65, 7, 48, 6, 28, 5, 55, 0, 17, 8, 53, 
    2, 19, 6, 32, 1, 13, 4, 77, 8, 55, 0, 79, 5, 31, 7, 30, 3, 81, 
    4, 96, 7, 32, 5, 35, 1, 77, 6, 98, 3, 36, 8, 79, 2, 50, 0, 96, 
    3, 86, 6, 56, 2, 49, 1, 95, 0, 15, 8, 41, 7, 31, 5, 38, 4, 52, 
    8, 64, 3, 76, 0,  5, 5,  7, 4, 54, 7, 16, 2, 61, 6, 20, 1, 62
  };
  const int q3014[] = {
    9, 9, // Number of jobs and machines
    4, 17, 8, 22, 7, 34, 3, 39, 2, 67, 1, 84, 5, 60, 6, 12, 0, 37, 
    4, 39, 2, 66, 0, 28, 1, 47, 6,  8, 3, 91, 7, 53, 8, 20, 5, 13, 
    6, 30, 0, 91, 4, 48, 8, 19, 5, 65, 7, 60, 1, 54, 2, 67, 3, 14, 
    6, 68, 1, 34, 8, 65, 4, 39, 3, 50, 0, 71, 2, 48, 5, 42, 7, 43, 
    1, 10, 4, 33, 6, 47, 7, 22, 3, 24, 0, 44, 8, 92, 2, 48, 5,  3, 
    0, 40, 3, 39, 2, 54, 1, 34, 7, 26, 8, 49, 5, 64, 4, 40, 6, 42, 
    3,  5, 1, 33, 4,  6, 6, 17, 8, 36, 5, 19, 2, 24, 7, 27, 0,  5, 
    1, 75, 8, 28, 0, 82, 6,  1, 4, 93, 5, 75, 3, 69, 7, 83, 2, 40, 
    6, 93, 1,  7, 4, 97, 3, 55, 2, 13, 7, 19, 5, 37, 8, 40, 0, 79
  };
  const int q3015[] = {
    9, 9, // Number of jobs and machines
    4, 57, 2, 22, 3, 12, 5, 51, 7, 20, 1, 96, 8, 66, 0, 61, 6, 20, 
    6, 53, 5, 13, 8, 47, 4,  5, 3, 92, 2, 71, 1, 25, 0, 30, 7, 39, 
    4, 44, 2, 42, 8, 15, 7, 29, 1, 99, 6, 65, 5, 76, 3, 84, 0, 33, 
    3, 18, 4, 82, 6, 64, 1, 92, 5, 14, 8, 81, 0,  9, 7, 43, 2, 64, 
    5, 71, 1, 44, 6, 99, 8, 35, 3, 17, 0, 47, 7, 86, 2, 83, 4, 13, 
    5, 30, 6, 42, 3, 27, 4, 96, 1, 92, 8, 83, 7, 78, 0, 66, 2, 53, 
    1, 46, 4, 33, 5, 87, 3, 94, 2, 12, 7, 59, 8, 51, 6, 22, 0, 34, 
    2, 37, 7, 76, 3, 32, 6, 46, 0,  5, 8, 28, 1, 68, 4, 75, 5, 67, 
    7, 82, 8, 38, 2, 78, 5, 66, 0, 78, 3, 43, 6, 91, 1, 13, 4, 87
  };
  const int q3016[] = {
    9, 9, // Number of jobs and machines
    3, 20, 4, 56, 0, 43, 8, 97, 2,  8, 6, 85, 5, 38, 1, 69, 7, 95, 
    7, 88, 4,  9, 2, 72, 1, 84, 3, 20, 5,  2, 6, 98, 0, 83, 8, 27, 
    5, 97, 3, 81, 1, 72, 7, 96, 0,  5, 6, 90, 2, 45, 4, 75, 8, 52, 
    5, 34, 3,  2, 7, 69, 8, 76, 6, 42, 0, 91, 2, 27, 4,  9, 1, 85, 
    6,  4, 2, 58, 5, 28, 4, 14, 1, 94, 8,  6, 3, 35, 0, 42, 7, 94, 
    5, 20, 3,  4, 6,  8, 8, 86, 7, 58, 4, 73, 0, 34, 1, 31, 2, 77, 
    6,  1, 5, 75, 1, 90, 0, 28, 2, 96, 8, 18, 4, 72, 3, 89, 7, 54, 
    4, 48, 2, 78, 6,  4, 8, 65, 3, 51, 5, 33, 0, 89, 7, 53, 1, 14, 
    0, 78, 7, 51, 4, 95, 5, 29, 6, 18, 2, 34, 8, 91, 3, 99, 1, 85
  };
  const int q3017[] = {
    9, 9, // Number of jobs and machines
    7, 82, 8, 68, 4, 59, 6, 13, 3, 59, 5, 68, 0, 32, 1, 41, 2, 92, 
    4, 37, 7, 79, 0,  8, 6, 63, 3, 16, 5, 58, 2, 57, 1, 88, 8, 25, 
    1, 91, 4, 38, 2, 67, 8, 36, 5,  2, 3, 91, 7, 93, 6, 59, 0, 19, 
    8, 17, 5, 71, 7, 66, 0,  3, 4, 44, 2, 31, 1,  3, 6, 94, 3, 43, 
    6, 46, 1, 69, 0, 64, 2,  1, 8, 46, 7, 32, 3, 59, 5, 60, 4, 87, 
    3, 91, 0, 69, 8, 96, 1, 97, 5, 95, 2, 24, 4, 92, 7, 23, 6,  2, 
    5, 32, 6, 75, 4, 27, 1, 49, 0, 21, 8, 47, 2, 23, 3, 89, 7, 46, 
    6, 53, 7,  8, 4, 11, 5, 12, 1, 61, 2, 17, 0, 24, 8, 81, 3, 41, 
    0, 75, 5, 20, 3, 26, 7,  5, 4,  4, 6, 74, 1, 79, 8, 74, 2, 97
  };
  const int q3018[] = {
    9, 9, // Number of jobs and machines
    5, 97, 2, 72, 0, 30, 4, 45, 8, 67, 3,  5, 6, 89, 7, 57, 1, 87, 
    4, 55, 0,  8, 2, 61, 1,  4, 5,  7, 3, 57, 6, 68, 8, 48, 7, 87, 
    2, 54, 1, 91, 4, 48, 6, 67, 0, 48, 8, 98, 3, 94, 5, 63, 7, 94, 
    1, 55, 3, 36, 6, 72, 2, 72, 5, 85, 8, 32, 0,  1, 4, 30, 7, 13, 
    2, 89, 4, 83, 6, 46, 0, 60, 8, 96, 7, 20, 3, 84, 5, 88, 1, 60, 
    0, 14, 2,  1, 3, 24, 7, 90, 5, 67, 1, 92, 4, 77, 8, 68, 6, 84, 
    4, 95, 6, 10, 1, 14, 0, 82, 7, 36, 8, 57, 2, 10, 5, 26, 3, 73, 
    7, 25, 6, 18, 0,  2, 5, 67, 4,  8, 3, 84, 2, 57, 1, 10, 8, 85, 
    4, 71, 2, 25, 6, 20, 0, 60, 1, 85, 8,  2, 3, 36, 5, 31, 7, 69
  };
  const int q3019[] = {
    9, 9, // Number of jobs and machines
    0,  2, 1, 50, 8, 12, 2, 37, 6, 28, 7, 98, 4, 88, 3, 91, 5, 45, 
    2,  4, 5, 18, 7, 64, 8,  7, 0, 54, 3, 55, 1, 94, 6, 78, 4, 79, 
    0, 58, 1,  7, 7, 67, 8, 17, 5, 97, 6,  9, 2, 90, 4, 35, 3, 93, 
    0, 16, 3, 27, 1, 20, 7, 92, 5, 65, 2, 33, 6, 72, 8, 22, 4, 26, 
    5, 65, 2, 44, 3, 74, 1, 62, 6, 49, 0, 35, 7, 35, 4, 46, 8, 23, 
    4, 58, 3, 71, 5, 54, 1, 33, 6, 12, 2, 17, 8, 96, 7, 30, 0, 90, 
    8, 84, 2, 48, 1, 74, 5, 31, 6,  5, 0, 89, 4, 49, 3, 61, 7, 66, 
    8, 12, 3, 63, 0, 66, 2, 10, 6, 12, 4, 29, 7, 11, 1, 43, 5, 62, 
    1, 24, 4, 20, 6, 16, 7, 43, 8, 81, 5, 47, 3,  9, 2, 49, 0, 65
  };
  const int q3020[] = {
    9, 9, // Number of jobs and machines
    0, 23, 6, 71, 5, 55, 7, 82, 3, 98, 1, 47, 2, 25, 4, 86, 8, 15, 
    7, 99, 8, 19, 4, 62, 0, 57, 2, 67, 6, 92, 1, 77, 3,  7, 5, 34, 
    0, 97, 7, 23, 4, 10, 2, 71, 8, 75, 5,  4, 3, 60, 1, 98, 6, 70, 
    6, 73, 3, 48, 2, 25, 0, 31, 4, 42, 8, 65, 5, 23, 1, 48, 7, 58, 
    6, 74, 5, 20, 8, 36, 2, 79, 4, 45, 7, 14, 0, 99, 3, 91, 1, 37, 
    7, 30, 8, 51, 2, 32, 1, 86, 0, 98, 5, 51, 4, 25, 3, 13, 6,  9, 
    4, 76, 1, 31, 5, 74, 7, 57, 6, 24, 3, 66, 8,  7, 0, 98, 2, 78, 
    8, 91, 4, 22, 5, 97, 1, 25, 6, 26, 7, 61, 2, 17, 3, 84, 0, 94, 
    0, 91, 2, 12, 4, 77, 7,  7, 3, 28, 6, 74, 5, 60, 8, 15, 1, 61
  };
  const int q3021[] = {
    9, 9, // Number of jobs and machines
    1, 36, 2, 36, 3, 66, 7, 76, 6, 64, 5,  5, 4, 28, 8, 89, 0, 35, 
    2, 18, 1,  6, 6, 90, 5, 65, 0, 75, 8, 30, 4, 92, 7, 55, 3, 51, 
    0, 92, 5, 51, 6, 21, 1, 48, 2, 36, 7, 76, 3, 77, 4, 59, 8, 55, 
    6, 61, 2, 72, 5, 82, 1, 86, 8,  5, 7, 65, 0, 18, 4, 61, 3, 15, 
    1, 86, 5, 67, 0, 13, 3, 12, 6,  1, 2, 44, 4, 43, 7, 35, 8,  9, 
    5, 12, 6, 27, 4, 56, 8, 39, 0, 27, 7, 76, 1, 74, 3, 45, 2, 20, 
    3, 31, 1, 15, 5, 51, 0, 69, 4, 36, 6, 23, 8, 94, 7, 19, 2, 63, 
    1, 26, 0, 58, 8, 61, 5, 71, 7, 46, 3, 72, 4, 26, 6, 69, 2, 48, 
    3,  6, 6, 62, 4, 30, 7, 20, 0, 14, 8, 91, 2, 82, 1,  9, 5, 98
  };
  const int q3022[] = {
    9, 9, // Number of jobs and machines
    3, 10, 1, 52, 2, 84, 6, 69, 0, 77, 7, 73, 8, 53, 5, 40, 4, 40, 
    7,  2, 3, 42, 5, 86, 0, 19, 4, 16, 2, 12, 6, 45, 1, 65, 8, 20, 
    2, 60, 0, 57, 4, 21, 3, 15, 7, 11, 6, 87, 5, 23, 8, 22, 1, 62, 
    3,  5, 8, 46, 1, 58, 4,  3, 6, 54, 0, 72, 5, 39, 2, 63, 7, 50, 
    3, 26, 5, 22, 7, 42, 8, 48, 0, 57, 6, 38, 4, 53, 2, 18, 1, 60, 
    8, 17, 5, 40, 0, 25, 6, 91, 3, 70, 4, 73, 1, 31, 2, 97, 7,  3, 
    6, 81, 1, 11, 4, 17, 3, 39, 2, 42, 5, 75, 0, 44, 7, 74, 8, 91, 
    0,  7, 3,  6, 6, 17, 5, 26, 2, 41, 8, 87, 7, 65, 4, 84, 1, 82, 
    6,  2, 2, 69, 3, 38, 4, 68, 1, 45, 7, 79, 5,  3, 0, 80, 8, 96
  };
  const int q3023[] = {
    9, 9, // Number of jobs and machines
    1, 12, 8, 26, 5, 77, 2, 51, 7, 19, 4, 71, 3, 76, 6, 24, 0, 77, 
    2, 93, 8, 92, 3, 97, 4, 62, 5, 15, 6, 49, 7,  9, 0, 52, 1, 72, 
    3, 42, 0, 26, 6, 57, 4, 75, 5, 84, 2, 37, 1, 93, 7,  8, 8, 84, 
    4, 87, 1, 58, 5, 68, 8,  4, 2, 33, 7, 28, 3, 53, 0, 46, 6, 20, 
    7, 95, 2, 41, 1, 60, 8, 65, 6, 54, 5, 37, 0, 16, 4,  1, 3, 12, 
    5, 16, 1, 44, 0, 99, 2, 39, 8, 91, 6, 47, 7, 81, 3, 78, 4,  2, 
    5, 59, 6, 30, 8, 24, 2, 54, 4, 62, 1, 50, 3, 26, 7, 26, 0, 64, 
    6, 35, 8, 88, 7, 63, 4, 57, 2, 23, 5, 23, 1, 55, 0, 45, 3, 29, 
    0, 99, 3, 70, 1, 73, 7, 12, 2, 20, 5, 69, 6, 65, 4,  3, 8, 13
  };
  const int q3024[] = {
    9, 9, // Number of jobs and machines
    4, 54, 6, 99, 1, 13, 3, 94, 2, 56, 8, 22, 5, 17, 0, 79, 7, 26, 
    3, 37, 1,  6, 8, 98, 2, 39, 0, 61, 4, 59, 5,  8, 6, 19, 7, 72, 
    0, 76, 6, 41, 8, 17, 4, 40, 1, 75, 2, 46, 3, 26, 7, 80, 5, 63, 
    0,  3, 8, 50, 5, 14, 2, 95, 6, 83, 1, 21, 3, 91, 4, 44, 7, 31, 
    1, 52, 6, 56, 3,  3, 5, 93, 4, 41, 8, 21, 0, 97, 7, 43, 2, 87, 
    3,  5, 6, 58, 8, 34, 0, 48, 1, 24, 4, 90, 2, 78, 5, 94, 7, 70, 
    1, 62, 7, 78, 3, 92, 2, 28, 4, 68, 8, 63, 5, 48, 6, 69, 0, 64, 
    2, 74, 4, 82, 3, 96, 8,  7, 7,  1, 6, 40, 0, 46, 1, 56, 5, 90, 
    2, 67, 8, 81, 3, 14, 7, 30, 4, 90, 5, 66, 6, 55, 1, 88, 0, 55
  };
  const int q3025[] = {
    9, 9, // Number of jobs and machines
    5, 86, 0, 46, 3, 11, 8, 62, 6, 35, 7, 46, 1, 96, 2,  7, 4, 86, 
    2, 55, 8, 77, 6, 27, 0, 77, 5, 25, 7, 89, 4, 39, 1, 35, 3, 51, 
    0, 81, 5, 17, 3, 82, 4, 17, 1,  6, 2, 21, 6, 49, 8, 70, 7, 13, 
    8, 29, 7, 22, 4, 85, 1, 16, 5, 67, 2, 35, 0, 45, 3, 15, 6, 77, 
    0, 40, 7,  5, 4, 49, 5, 75, 8, 52, 1, 86, 2, 49, 6, 24, 3, 35, 
    8, 21, 1, 48, 2, 95, 6, 38, 7, 96, 4, 77, 3,  6, 0, 75, 5, 94, 
    5, 11, 0, 90, 1, 87, 8, 53, 4,  1, 7, 56, 6, 21, 3, 35, 2, 90, 
    1, 29, 8, 26, 0, 10, 7, 18, 2, 45, 3,  4, 6, 53, 4, 83, 5, 95, 
    1, 14, 0, 83, 7, 27, 6, 30, 8,  6, 5, 29, 4, 44, 3,  5, 2, 45
  };
  const int q3026[] = {
    9, 9, // Number of jobs and machines
    5, 88, 0, 12, 7, 74, 4, 72, 3, 57, 2, 44, 1, 73, 6, 42, 8, 46, 
    0, 83, 3, 17, 5, 37, 6,  9, 8, 75, 2, 25, 7, 67, 4,  1, 1, 95, 
    6, 58, 4, 61, 7, 59, 0, 90, 3, 12, 8, 91, 5, 60, 1, 69, 2,  6, 
    6, 71, 7, 86, 5, 50, 2, 64, 1, 47, 8, 82, 0, 94, 3, 36, 4, 92, 
    5,  8, 6, 69, 0, 81, 1, 12, 7, 19, 2, 70, 3, 78, 4, 12, 8, 33, 
    8, 21, 6, 30, 2, 49, 4, 10, 0, 56, 1, 88, 7, 44, 3, 38, 5, 49, 
    1, 63, 8, 97, 5, 86, 6, 66, 2, 73, 4, 15, 3,  1, 7, 87, 0, 16, 
    5, 32, 1, 63, 8, 45, 0, 27, 3, 77, 4, 12, 2, 85, 7, 88, 6, 62, 
    3, 16, 5, 50, 1, 69, 8, 50, 4, 16, 0, 51, 2, 47, 6, 65, 7, 78
  };
  const int q3027[] = {
    9, 9, // Number of jobs and machines
    1, 82, 7, 96, 5, 87, 0,  7, 4, 30, 3,  2, 8,  2, 2, 40, 6, 11, 
    4, 19, 2, 28, 3, 51, 5, 71, 8, 57, 6, 37, 0, 27, 1, 19, 7, 70, 
    6, 46, 5, 36, 7, 36, 3,  8, 0, 58, 2, 76, 1, 28, 4, 99, 8, 62, 
    8, 36, 7, 41, 4,  1, 3, 13, 5, 82, 0,  5, 2, 20, 6, 35, 1, 92, 
    7, 61, 0, 39, 3, 32, 6, 71, 4, 82, 8, 90, 2, 41, 5, 48, 1, 61, 
    4, 33, 2, 10, 8,  6, 3, 32, 6,  6, 1, 30, 7, 21, 0, 48, 5,  3, 
    0, 69, 6, 30, 4, 37, 5, 36, 2, 13, 7, 95, 1, 72, 3, 52, 8, 45, 
    8, 54, 3, 12, 2, 57, 5,  4, 0, 47, 1, 35, 6, 60, 4, 12, 7, 81, 
    4, 80, 2, 44, 0, 78, 6, 27, 5, 73, 7, 87, 1, 56, 8, 31, 3, 16
  };
  const int q3028[] = {
    9, 9, // Number of jobs and machines
    7, 20, 4, 34, 8, 47, 2,  2, 0, 92, 5, 38, 1,  8, 3, 11, 6, 15, 
    2, 91, 0, 36, 4, 49, 8, 25, 7, 51, 1, 91, 5, 35, 6, 82, 3, 46, 
    5, 20, 7, 91, 4, 93, 2, 18, 0, 69, 1, 78, 3, 52, 8, 43, 6, 69, 
    4, 69, 1, 55, 2, 34, 0, 70, 5, 32, 7, 44, 6, 88, 8,  1, 3,  2, 
    1,  3, 7, 19, 6, 14, 2, 65, 0, 99, 8, 51, 3,  3, 5, 50, 4,  1, 
    7, 87, 3, 26, 5, 59, 2, 22, 0, 44, 1, 14, 6, 81, 8, 36, 4, 70, 
    8, 50, 1, 26, 4, 37, 5, 27, 3, 32, 7, 87, 6, 63, 2, 62, 0, 73, 
    3, 12, 4,  9, 0, 77, 5,  9, 8, 76, 7, 58, 1, 60, 2, 66, 6, 12, 
    7, 19, 4, 83, 1,  6, 5, 43, 6, 36, 2, 46, 0, 61, 8, 26, 3, 72
  };
  const int q3029[] = {
    9, 9, // Number of jobs and machines
    7, 32, 3, 18, 5, 65, 8, 77, 1, 85, 0, 28, 6, 52, 4, 23, 2, 11, 
    6, 36, 2, 16, 3, 23, 5, 27, 1, 35, 0, 77, 7, 89, 4, 65, 8,  8, 
    5, 83, 6, 96, 8, 76, 0, 66, 3, 29, 1, 71, 7, 40, 4, 36, 2, 25, 
    5, 84, 1,  9, 8, 47, 4, 70, 3, 32, 2, 64, 7, 84, 6, 38, 0,  7, 
    1, 65, 5, 73, 2, 90, 4, 74, 0, 38, 7, 75, 6, 90, 8, 30, 3, 45, 
    7, 12, 6, 26, 8, 97, 5, 44, 3, 50, 0, 58, 2, 10, 4, 32, 1, 92, 
    8, 88, 7, 68, 1,  3, 0, 71, 6, 13, 5, 67, 4, 11, 3, 87, 2, 18, 
    7, 44, 1, 87, 5, 10, 4, 44, 8, 65, 3, 96, 0, 29, 2, 94, 6,  8, 
    3, 12, 2, 33, 6, 28, 0, 13, 1, 63, 8, 60, 5, 20, 7, 99, 4, 52
  };
  const int q3030[] = {
    9, 9, // Number of jobs and machines
    8, 66, 7, 41, 3, 19, 2, 47, 6, 73, 4, 48, 0, 70, 5, 45, 1, 42, 
    6, 47, 5, 28, 4, 93, 0, 16, 1, 38, 7,  8, 8, 94, 2, 96, 3, 36, 
    0, 50, 2, 92, 1,  1, 4, 49, 6, 44, 3, 86, 5, 29, 8, 93, 7, 78, 
    2, 19, 8, 19, 1, 96, 5, 73, 4, 62, 0, 36, 6,  8, 3, 89, 7, 93, 
    6, 60, 0, 74, 5,  4, 8, 34, 1, 57, 4, 97, 7, 22, 2, 46, 3, 37, 
    8, 11, 5, 90, 6, 91, 2, 14, 3,  9, 0, 57, 1, 39, 4, 51, 7, 19, 
    4,  6, 3, 47, 1, 83, 5, 34, 2, 37, 6, 28, 0, 78, 7, 60, 8, 76, 
    5, 13, 7, 32, 2, 46, 1, 71, 6, 84, 3, 26, 8, 71, 4, 17, 0, 32, 
    7, 85, 5, 13, 2, 24, 4, 37, 6, 32, 3, 68, 0,  6, 8, 61, 1, 65
  };
  const int q3031[] = {
    9, 9, // Number of jobs and machines
    7, 36, 0, 55, 3, 97, 6, 44, 5, 63, 4, 92, 8, 27, 1, 48, 2, 49, 
    4, 35, 6, 31, 2, 65, 7, 98, 5, 52, 8, 44, 3, 26, 0, 95, 1, 68, 
    7, 99, 8, 39, 5, 21, 6, 40, 1, 75, 4, 56, 2, 72, 3, 42, 0, 15, 
    6, 70, 1, 27, 2, 25, 0,  9, 7, 15, 4, 64, 8, 30, 5, 88, 3, 51, 
    5, 38, 4, 54, 1, 12, 6, 66, 2,  4, 0, 17, 8, 65, 3, 46, 7, 83, 
    7, 35, 1,  4, 8, 73, 5, 91, 4, 82, 6, 70, 0, 95, 2, 48, 3, 95, 
    3, 91, 4, 90, 1,  4, 2, 59, 8, 92, 0, 52, 5, 96, 6, 54, 7, 43, 
    1, 88, 8, 78, 6, 88, 0, 52, 3, 63, 5, 44, 2, 27, 7, 78, 4, 49, 
    6, 50, 1, 39, 8, 92, 3,  7, 4, 78, 2,  4, 0, 43, 5, 45, 7, 35
  };
  const int q3032[] = {
    9, 9, // Number of jobs and machines
    0, 69, 1, 42, 4, 83, 7, 38, 6, 17, 2, 35, 8, 45, 5, 95, 3, 74, 
    2, 96, 1, 12, 0, 41, 8, 30, 4, 31, 6, 42, 3, 50, 7, 90, 5, 71, 
    2, 19, 8, 28, 0, 40, 6, 24, 7, 59, 1, 67, 4, 97, 3, 45, 5, 74, 
    3, 74, 7, 93, 2, 55, 0, 81, 8, 22, 5, 75, 6, 61, 4, 67, 1, 65, 
    3, 93, 4, 99, 6, 16, 2, 95, 1,  6, 7, 31, 8, 68, 0, 10, 5, 98, 
    6,  1, 7, 60, 0, 40, 1, 41, 3, 25, 8, 42, 2, 37, 4, 74, 5, 21, 
    1, 73, 7, 22, 6,  7, 8, 47, 3, 49, 5, 33, 2, 38, 4, 24, 0, 30, 
    4,  5, 1, 84, 0,  6, 8, 32, 7,  3, 6, 10, 2, 49, 5, 64, 3,  8, 
    3, 60, 6, 16, 7, 23, 2,  7, 5, 34, 4, 84, 1, 76, 8, 20, 0, 47
  };
  const int q3033[] = {
    9, 9, // Number of jobs and machines
    5, 16, 2, 95, 0,  2, 4,  3, 3, 47, 1, 11, 6, 68, 8, 57, 7, 55, 
    0, 26, 8, 86, 1, 10, 2, 18, 6, 17, 5, 99, 3, 65, 4, 55, 7, 88, 
    3,  4, 0, 81, 6,  8, 2, 18, 7, 61, 1, 19, 4, 62, 5, 41, 8, 64, 
    8, 42, 2, 19, 4, 20, 0, 48, 5, 63, 6, 69, 1, 94, 7, 18, 3, 12, 
    6, 87, 1, 13, 7,  7, 0, 48, 4, 79, 5, 13, 2, 89, 3, 79, 8, 42, 
    7, 19, 3, 85, 0, 97, 5,  2, 4, 86, 6, 88, 2, 12, 8, 62, 1, 20, 
    2,  6, 3, 34, 7, 26, 4, 68, 8, 70, 6, 65, 0, 53, 5, 47, 1, 58, 
    2, 73, 4, 85, 5, 23, 3, 73, 1, 10, 8, 97, 6, 49, 7, 64, 0, 23, 
    0, 31, 8, 73, 4, 72, 3, 11, 1, 45, 7, 64, 2, 31, 6, 74, 5, 89
  };
  const int q3034[] = {
    9, 9, // Number of jobs and machines
    8, 51, 6, 19, 0, 19, 2, 29, 5,  6, 3, 27, 1, 25, 4, 24, 7, 61, 
    0, 12, 6, 44, 4, 24, 2, 25, 3, 43, 1,  5, 8, 14, 5, 10, 7, 14, 
    7, 41, 2, 82, 3, 80, 8, 61, 6, 64, 4, 69, 0, 29, 1, 27, 5, 48, 
    0, 54, 2, 95, 7,  8, 6, 80, 4, 82, 8, 32, 3, 85, 1, 95, 5, 69, 
    8, 23, 7, 88, 6, 42, 2, 35, 5, 73, 4, 59, 1, 92, 0, 34, 3, 98, 
    1, 46, 5, 72, 4, 74, 8,  1, 0, 93, 3, 94, 6, 23, 7, 28, 2, 97, 
    3, 81, 7, 36, 2, 71, 8, 19, 4, 15, 0, 34, 6, 94, 1, 63, 5, 47, 
    1, 49, 2,  5, 8,  7, 4, 77, 0, 56, 3, 19, 7, 53, 5, 87, 6, 25, 
    1, 15, 7, 97, 3, 46, 6, 34, 5, 91, 4, 45, 2, 64, 0, 44, 8,  4
  };
  const int q3035[] = {
    9, 9, // Number of jobs and machines
    7,  8, 4, 56, 1, 91, 8, 93, 0, 12, 5, 35, 3,  5, 2, 52, 6, 87, 
    7, 75, 3, 52, 2,  8, 5, 63, 6, 33, 8, 32, 0, 55, 1, 87, 4, 52, 
    1, 20, 7,  1, 6, 68, 3, 29, 4, 38, 2, 52, 0, 57, 5, 53, 8, 78, 
    0, 38, 4, 88, 7, 69, 3, 35, 5, 94, 6, 29, 1, 90, 8, 53, 2, 28, 
    1, 24, 6, 25, 5, 83, 8, 93, 2, 47, 4, 27, 3, 33, 7,  2, 0, 19, 
    7, 25, 6, 66, 2, 69, 1, 85, 0, 75, 8, 54, 5, 18, 4, 69, 3, 49, 
    8, 35, 3, 38, 6, 70, 0, 19, 7, 89, 1,  9, 5, 97, 4, 63, 2, 65, 
    1, 46, 3, 96, 4, 11, 5, 61, 2, 24, 0, 68, 7, 20, 6, 21, 8, 76, 
    0, 61, 5, 31, 1,  5, 4, 62, 3, 66, 8, 84, 6, 18, 7, 37, 2,  1
  };
  const int q3036[] = {
    9, 9, // Number of jobs and machines
    6, 95, 3,  8, 7, 80, 5, 62, 0, 16, 1, 18, 2, 28, 8, 81, 4, 60, 
    5, 65, 6, 42, 1, 23, 8, 34, 0, 61, 4, 97, 7, 54, 2, 50, 3, 66, 
    1, 27, 4, 77, 5, 31, 2, 58, 7, 45, 0, 17, 6, 44, 3, 65, 8, 75, 
    8, 77, 4, 79, 6, 58, 5, 68, 7, 26, 3, 93, 0, 81, 2, 40, 1, 57, 
    5, 33, 4, 99, 1, 15, 0, 29, 7, 71, 8, 18, 2, 50, 3, 14, 6, 57, 
    0, 73, 5,  3, 4, 26, 8, 32, 3, 58, 7, 17, 2, 66, 6,  7, 1, 89, 
    0, 50, 1, 98, 6, 33, 2, 64, 8, 31, 5,  2, 4, 36, 3, 73, 7, 87, 
    3, 49, 0, 13, 8, 35, 4, 18, 5, 32, 2, 94, 1, 87, 6, 85, 7, 37, 
    4, 42, 1, 37, 2, 54, 5, 45, 7, 35, 3, 43, 8, 43, 6, 14, 0, 18
  };
  const int q3037[] = {
    9, 9, // Number of jobs and machines
    7, 64, 5, 34, 0, 20, 2, 50, 4, 90, 8, 55, 1, 67, 3, 36, 6, 97, 
    1, 63, 0, 76, 8, 29, 5, 15, 6,  7, 2, 88, 4, 64, 3, 95, 7, 96, 
    8, 85, 2, 18, 5, 15, 0, 63, 1, 35, 7, 21, 4, 13, 3, 20, 6, 45, 
    6, 18, 5, 38, 0, 52, 1, 64, 3, 32, 2, 11, 8, 23, 7, 80, 4, 10, 
    0, 98, 2, 43, 1, 93, 5, 91, 8, 52, 3, 75, 6, 92, 7, 65, 4,  2, 
    0, 16, 8,  2, 4, 26, 3, 49, 2, 14, 7, 87, 6, 28, 5, 32, 1, 82, 
    7,  2, 8, 63, 2, 73, 5, 13, 3, 14, 4, 48, 0, 97, 1, 18, 6, 39, 
    3, 89, 1, 42, 2, 14, 0,  5, 7, 29, 6, 70, 8, 92, 4, 66, 5, 89, 
    2, 23, 8, 71, 7, 10, 5, 85, 4, 53, 6, 34, 3, 32, 1, 16, 0, 18
  };
  const int q3038[] = {
    9, 9, // Number of jobs and machines
    2, 66, 5, 37, 3, 63, 0, 70, 4, 64, 1, 87, 7, 81, 6, 72, 8, 25, 
    2, 23, 3, 88, 7, 32, 8, 76, 4, 33, 6, 65, 0, 73, 5, 88, 1, 16, 
    4, 19, 6, 98, 0, 30, 1, 52, 8, 52, 3, 92, 5, 11, 2, 33, 7,  5, 
    2, 27, 3, 35, 8, 44, 4, 99, 6, 49, 0, 98, 1, 46, 5, 96, 7, 59, 
    8, 54, 6, 35, 2, 31, 5, 93, 7, 16, 1, 14, 3, 53, 0, 78, 4, 71, 
    0, 58, 1, 38, 3,  4, 7, 67, 2,  1, 8, 78, 4, 75, 5, 64, 6, 81, 
    3, 86, 4, 27, 1, 37, 2, 10, 8, 65, 7, 38, 0,  1, 5, 34, 6, 89, 
    6,  8, 3, 53, 1, 10, 2, 31, 0, 46, 4, 51, 8, 52, 5,  6, 7, 36, 
    7, 16, 8, 21, 1, 10, 0, 47, 4, 45, 3, 16, 5, 97, 2, 63, 6, 59
  };
  const int q3039[] = {
    9, 9, // Number of jobs and machines
    2, 35, 4, 17, 3,  7, 8, 94, 5, 66, 7,  8, 0, 14, 6, 75, 1, 92, 
    3, 43, 4,  2, 5, 51, 1, 87, 2, 16, 8, 80, 7, 63, 6, 74, 0, 90, 
    4, 77, 5, 89, 0, 24, 7, 40, 3, 55, 6, 91, 8, 60, 1, 32, 2, 55, 
    3, 67, 4, 59, 5, 49, 2, 75, 0, 32, 6, 57, 8, 52, 1, 16, 7, 92, 
    5, 65, 7, 30, 0, 27, 4, 13, 1, 88, 6, 19, 3, 53, 8, 31, 2, 79, 
    4, 58, 2, 68, 1, 32, 5, 37, 0, 65, 7, 97, 6, 70, 8, 77, 3, 25, 
    3, 75, 4, 21, 6, 35, 0, 25, 2, 87, 1, 10, 5, 89, 7, 93, 8, 80, 
    8, 44, 1, 89, 3, 15, 6, 20, 0, 51, 2, 47, 7, 21, 4, 44, 5, 34, 
    2, 72, 7, 18, 3, 32, 1, 61, 4, 74, 8,  2, 6, 96, 0, 31, 5, 88
  };
  const int q3040[] = {
    9, 9, // Number of jobs and machines
    5, 70, 0, 65, 1, 53, 3, 91, 7, 19, 4, 27, 6, 19, 2, 54, 8, 61, 
    4, 67, 5, 18, 1, 67, 2, 28, 0, 83, 3, 59, 6, 53, 8, 82, 7, 89, 
    2, 61, 7, 35, 0, 94, 4, 44, 5, 81, 3, 47, 6,  7, 8, 35, 1, 63, 
    7,  7, 4, 44, 6, 11, 5, 60, 8, 26, 2, 88, 1, 76, 3, 41, 0, 29, 
    0,  5, 8, 66, 4, 30, 5, 76, 1, 85, 6, 22, 7, 18, 2, 46, 3, 34, 
    3, 14, 4, 82, 2, 60, 7, 66, 6, 58, 5, 48, 0, 44, 1, 59, 8, 95, 
    4, 33, 7, 85, 5, 97, 1, 27, 2, 57, 8, 88, 3, 84, 6, 22, 0, 51, 
    1, 82, 6, 50, 8, 79, 7, 91, 3, 50, 2, 34, 0, 92, 5, 19, 4, 19, 
    6, 36, 8, 71, 7, 97, 5, 36, 4, 72, 2, 18, 1, 48, 0, 18, 3, 11
  };
  const int q3041[] = {
    9, 9, // Number of jobs and machines
    6, 19, 8, 29, 2, 65, 3, 56, 4, 88, 7, 21, 5, 11, 1, 41, 0, 93, 
    0, 39, 8, 92, 1, 25, 2, 92, 3, 93, 7, 72, 5, 15, 6, 42, 4, 93, 
    3, 73, 4, 44, 7, 67, 0,  4, 6, 13, 8,  7, 2, 80, 5, 26, 1, 57, 
    8, 87, 7, 38, 2, 52, 6, 99, 3, 50, 0, 64, 1, 51, 4, 61, 5, 61, 
    1, 22, 8, 95, 0, 80, 6, 47, 4, 82, 2, 37, 5, 85, 3, 38, 7, 98, 
    8, 74, 4,  3, 7, 11, 6, 98, 0, 38, 3, 33, 2, 80, 5, 11, 1, 49, 
    7, 19, 6, 11, 5, 77, 8, 38, 4, 72, 2,  8, 1, 87, 3, 41, 0, 88, 
    5, 94, 3, 84, 4, 28, 7, 97, 6, 70, 8, 59, 0, 86, 2, 57, 1, 20, 
    6, 37, 4, 56, 3, 30, 0,  1, 5, 65, 8, 43, 2, 31, 1, 70, 7,  8
  };
  const int q3042[] = {
    9, 9, // Number of jobs and machines
    1, 88, 0, 40, 8, 55, 6, 26, 4, 56, 2, 85, 3, 32, 7, 55, 5, 93, 
    2, 97, 1, 56, 5, 84, 8, 38, 0, 42, 7, 91, 6, 19, 3, 64, 4, 13, 
    6, 86, 7, 47, 0, 20, 5, 82, 4, 85, 2, 63, 8, 40, 1, 14, 3, 69, 
    6, 68, 8, 93, 0, 20, 2, 20, 4, 14, 1,  8, 7, 54, 5, 89, 3, 77, 
    8, 77, 6, 13, 0,  2, 2, 91, 5, 50, 3, 67, 1, 45, 4, 71, 7, 42, 
    1, 56, 7, 71, 6, 19, 4,  7, 5, 96, 8, 47, 2, 72, 3, 71, 0, 33, 
    4, 82, 8, 87, 2, 66, 6, 93, 0, 13, 1, 81, 7, 81, 5, 79, 3, 73, 
    8, 14, 4, 73, 2, 80, 0, 61, 3, 20, 1, 63, 6, 11, 5, 78, 7, 58, 
    6, 48, 5, 84, 0, 64, 2, 97, 3, 95, 8, 51, 7, 42, 1, 65, 4,  2
  };
  const int q3043[] = {
    9, 9, // Number of jobs and machines
    4, 24, 0, 37, 5, 39, 2, 41, 8, 55, 3, 85, 7, 51, 6, 70, 1, 67, 
    8, 63, 5, 59, 6, 52, 7, 53, 0, 67, 4,  3, 3, 99, 1, 16, 2, 18, 
    8, 88, 1, 14, 7, 38, 5, 34, 0, 54, 3, 66, 2, 84, 6, 17, 4, 16, 
    6, 96, 1, 51, 3, 24, 5,  6, 0, 43, 8, 35, 2, 43, 4, 14, 7, 95, 
    6, 55, 3, 20, 5, 74, 4, 78, 0, 53, 7, 50, 2, 63, 8,  5, 1, 91, 
    1, 24, 5, 20, 7, 83, 2,  3, 3, 56, 6,  8, 8, 47, 0, 32, 4, 75, 
    1, 60, 6, 74, 0, 59, 7, 76, 8, 46, 5, 82, 3, 18, 4,  7, 2,  7, 
    4, 45, 5, 65, 3, 88, 2, 10, 6, 71, 1, 52, 8, 35, 0, 16, 7, 84, 
    3, 83, 6, 26, 7, 15, 2, 11, 4, 48, 5, 43, 1,  3, 8, 68, 0, 70
  };
  const int q3044[] = {
    9, 9, // Number of jobs and machines
    3, 25, 5, 10, 6, 82, 2, 38, 0, 35, 7, 90, 8, 74, 4, 92, 1, 73, 
    7, 18, 3,  1, 0, 79, 1, 82, 8, 16, 2, 35, 6, 79, 4, 68, 5, 88, 
    4, 20, 3, 19, 7, 31, 8, 58, 2,  4, 1,  7, 6, 66, 0, 58, 5, 22, 
    3, 10, 6, 17, 8, 76, 4, 64, 0, 32, 5, 85, 1, 78, 7, 93, 2, 39, 
    0, 12, 8,  4, 6, 18, 2, 77, 7, 69, 1, 92, 4, 97, 3, 82, 5, 45, 
    8, 19, 4, 58, 7, 15, 6, 32, 1, 53, 2, 20, 3, 24, 0, 87, 5, 31, 
    4, 41, 2,  7, 3, 96, 6, 66, 5, 21, 7, 35, 8, 14, 1, 98, 0, 33, 
    2, 84, 6, 93, 0, 22, 1, 53, 8, 27, 7, 25, 3, 27, 5, 25, 4, 95, 
    6, 91, 3, 11, 7, 43, 5, 43, 2, 85, 8,  5, 1, 75, 4,  4, 0,  7
  };
  const int q3045[] = {
    9, 9, // Number of jobs and machines
    6, 28, 1, 89, 2, 79, 8,  1, 0, 32, 4, 84, 7, 51, 5, 50, 3, 71, 
    8, 73, 7, 18, 3, 47, 2, 89, 6, 11, 5, 64, 0,  3, 4, 35, 1, 90, 
    0, 75, 3,  8, 4, 96, 8, 21, 5, 50, 2, 91, 6, 96, 7, 81, 1, 41, 
    6, 64, 2, 76, 1, 53, 5,  6, 8, 17, 0, 21, 4, 12, 7, 12, 3, 63, 
    7, 68, 5, 52, 2, 84, 0, 40, 8, 56, 3, 18, 6, 54, 4, 55, 1, 57, 
    2, 59, 0, 12, 1, 58, 5, 92, 7, 98, 8, 72, 4,  4, 3, 54, 6, 42, 
    3, 64, 1, 71, 4, 83, 7, 38, 2, 64, 5, 81, 0, 42, 8, 95, 6, 19, 
    7, 70, 4, 78, 5, 40, 3,  9, 0, 60, 6,  2, 2, 29, 8, 33, 1, 90, 
    0, 27, 7, 35, 1, 42, 5, 25, 2, 19, 6, 28, 4, 16, 8, 67, 3, 69
  };
  const int q3046[] = {
    9, 9, // Number of jobs and machines
    4,  5, 3, 66, 2,  7, 5, 33, 0, 22, 6, 69, 8, 10, 7, 27, 1, 98, 
    2, 29, 4, 31, 1, 19, 6, 43, 7, 52, 3, 96, 5, 55, 8, 54, 0, 21, 
    3, 86, 2, 48, 8, 44, 5, 38, 6, 35, 1, 49, 7, 43, 4, 11, 0, 12, 
    6, 79, 7, 59, 3, 81, 4, 54, 5,  2, 0, 83, 1, 81, 2, 72, 8, 43, 
    6,  5, 5, 63, 1, 85, 4, 11, 2,  9, 3, 17, 0, 35, 8, 48, 7, 82, 
    3, 68, 4,  1, 6, 97, 8, 17, 7, 95, 1, 66, 5, 25, 2, 64, 0, 25, 
    5, 46, 3,  2, 1, 31, 0, 84, 6, 88, 2, 10, 4, 95, 7, 78, 8, 57, 
    4, 76, 7, 47, 8, 61, 5, 90, 1, 88, 2, 55, 3, 77, 0, 54, 6, 27, 
    0, 51, 4, 30, 6, 55, 1,  9, 8, 70, 2, 10, 7, 41, 5, 71, 3, 28
  };
  const int q3047[] = {
    9, 9, // Number of jobs and machines
    8, 52, 4, 90, 2, 15, 7, 57, 0, 58, 3,  5, 1, 45, 6, 85, 5, 65, 
    3, 52, 0, 38, 1, 42, 7, 69, 4, 11, 6, 21, 8, 28, 2, 97, 5, 71, 
    2, 41, 6, 12, 3, 68, 0, 75, 7,  4, 4,  1, 1, 83, 5,  8, 8, 85, 
    7, 40, 0, 25, 5, 27, 8, 75, 4, 55, 1, 53, 3, 38, 6, 44, 2, 66, 
    4, 57, 2, 16, 0, 88, 1, 15, 7,  8, 3,  4, 6, 19, 8, 90, 5, 86, 
    0, 83, 3, 88, 5, 43, 1, 59, 7, 86, 6, 60, 2, 10, 8, 37, 4, 33, 
    0, 50, 2, 25, 4, 57, 3,  8, 6, 10, 5, 81, 1, 39, 8,  1, 7, 59, 
    8, 18, 1, 85, 2, 33, 4, 83, 6, 67, 5, 24, 0, 43, 7, 56, 3, 16, 
    8, 66, 6, 88, 3, 23, 5,  2, 1, 10, 2,  8, 4, 88, 0, 35, 7, 87
  };
  const int q3048[] = {
    9, 9, // Number of jobs and machines
    4,  1, 5, 42, 8, 30, 6, 32, 1, 10, 3, 46, 0, 65, 7, 36, 2, 82, 
    2, 48, 5, 26, 8, 51, 1,  3, 7, 18, 0, 82, 3, 30, 6, 19, 4, 57, 
    6, 15, 0, 78, 4, 88, 8, 42, 1, 26, 3, 40, 5, 52, 7, 27, 2, 65, 
    2, 87, 4, 50, 7, 85, 1, 10, 3, 64, 0, 48, 5, 38, 8, 72, 6, 72, 
    8, 92, 0, 58, 1, 90, 7,  1, 5, 10, 2, 31, 4, 64, 6, 93, 3, 52, 
    5, 33, 7, 54, 2, 95, 0, 17, 3, 13, 1, 44, 6,  4, 8, 51, 4, 15, 
    4, 41, 2, 89, 8, 71, 7, 96, 0, 66, 1, 34, 3, 55, 6, 95, 5, 78, 
    8, 50, 3, 82, 1, 67, 4, 26, 5, 50, 7,  1, 0,  5, 2, 74, 6, 92, 
    4, 15, 1, 97, 5, 98, 3, 60, 7, 86, 0, 89, 8, 52, 2, 15, 6, 72
  };
  const int q3049[] = {
    9, 9, // Number of jobs and machines
    0, 25, 6, 78, 3, 99, 8,  9, 1, 95, 2, 74, 4, 98, 7,  7, 5, 29, 
    3, 36, 4, 94, 5, 57, 6, 87, 1, 71, 7, 87, 2, 69, 0, 36, 8, 71, 
    8,  3, 3, 40, 7, 72, 1, 59, 2, 96, 5,  7, 4, 58, 6, 78, 0,  9, 
    0, 16, 6, 23, 2, 61, 8, 67, 4, 52, 3, 84, 1, 48, 5, 84, 7, 26, 
    1, 98, 3,  7, 0, 35, 8, 73, 5, 44, 4, 56, 7,  2, 2, 86, 6, 67, 
    5, 75, 0, 10, 8, 65, 6, 22, 4, 69, 2, 22, 1,  6, 7, 99, 3, 79, 
    0, 28, 5, 70, 3, 46, 4, 67, 8, 98, 2,  9, 6, 84, 7, 27, 1, 30, 
    0, 84, 8, 73, 6, 55, 1, 13, 4, 89, 5, 75, 3, 51, 2, 69, 7, 37, 
    3, 33, 6, 66, 5, 50, 1, 44, 4, 86, 7, 56, 8, 81, 0, 90, 2, 36
  };
  const int q3050[] = {
    9, 9, // Number of jobs and machines
    2,  7, 3, 40, 5, 85, 7, 45, 1, 31, 6, 66, 4, 62, 8, 83, 0, 88, 
    1, 64, 4, 17, 0, 65, 5,  4, 7, 68, 2, 72, 8, 76, 6, 63, 3, 75, 
    0, 43, 1, 31, 8, 43, 7, 77, 3, 72, 4, 83, 5, 50, 2, 82, 6, 91, 
    7, 65, 8, 87, 2, 20, 1,  1, 0, 73, 3, 13, 4, 76, 5, 44, 6, 21, 
    7, 69, 1, 30, 8, 42, 0, 87, 3, 41, 6, 16, 4, 97, 2, 60, 5, 95, 
    5, 89, 2, 76, 0, 50, 6, 45, 7, 24, 4, 34, 1, 72, 8,  7, 3, 87, 
    1, 77, 5, 68, 0, 84, 3, 46, 4, 64, 7, 91, 8, 59, 6, 70, 2, 10, 
    1,  3, 4, 95, 2, 19, 0, 32, 6, 61, 3, 63, 8, 21, 5, 15, 7, 39, 
    0, 97, 2, 12, 7, 13, 3, 39, 4, 94, 8, 65, 5, 61, 6, 92, 1, 86
  };
  const int q3051[] = {
    9, 9, // Number of jobs and machines
    6, 96, 2, 24, 0, 61, 1, 65, 5, 32, 4, 37, 7, 68, 8, 16, 3, 52, 
    8, 89, 2, 87, 1, 72, 6, 93, 7, 63, 4, 88, 5, 13, 0,  5, 3, 79, 
    0, 74, 2, 46, 8, 64, 3, 44, 5, 15, 7, 51, 1, 89, 4, 64, 6, 69, 
    6, 16, 0, 88, 1, 86, 2, 88, 7, 75, 8, 94, 3,  3, 4,  9, 5, 93, 
    7, 40, 3, 15, 8, 28, 4, 48, 0, 54, 2, 18, 5, 50, 6,  6, 1, 47, 
    1, 44, 4, 82, 3, 87, 0, 37, 8, 16, 6, 76, 5, 69, 7,  5, 2, 68, 
    3, 41, 1, 15, 8, 31, 0, 91, 5, 13, 6,  3, 2, 35, 7, 27, 4, 71, 
    4, 75, 8, 77, 5, 57, 7,  7, 2, 25, 1,  9, 6, 73, 0, 25, 3, 13, 
    3, 57, 6, 57, 5, 93, 8,  2, 2, 24, 4, 95, 1, 66, 7, 45, 0, 42
  };
  const int q3052[] = {
    9, 9, // Number of jobs and machines
    7, 22, 2, 41, 3, 47, 1, 90, 6, 95, 5, 70, 8, 12, 0, 46, 4, 98, 
    2, 31, 1, 90, 8, 51, 7, 75, 5, 37, 4, 22, 0, 65, 6, 64, 3, 21, 
    1, 89, 6,  5, 5, 76, 2, 46, 8, 59, 3, 22, 4,  8, 0, 13, 7, 26, 
    7, 41, 3, 37, 2, 88, 1, 94, 0, 98, 5, 24, 8, 68, 6, 35, 4, 39, 
    1, 15, 4, 53, 0, 62, 7, 18, 3, 60, 6, 90, 2, 88, 5,  3, 8, 53, 
    3, 61, 1, 82, 7,  5, 2, 25, 8, 98, 5, 86, 4, 22, 0, 87, 6, 79, 
    7, 31, 5, 33, 3, 85, 4, 75, 8,  6, 1, 98, 2, 85, 0, 75, 6, 55, 
    7, 78, 6, 22, 5, 79, 4, 29, 3, 15, 1, 10, 2, 16, 8,  6, 0, 23, 
    6, 78, 0, 19, 2, 75, 5, 42, 8, 44, 4, 20, 1, 67, 7, 79, 3, 88
  };
  const int q3053[] = {
    9, 9, // Number of jobs and machines
    3, 53, 5, 52, 6, 34, 2, 66, 4, 14, 1, 78, 7, 26, 8, 78, 0, 69, 
    5, 52, 0, 99, 2, 17, 4, 79, 7, 83, 8,  6, 1, 62, 6, 72, 3, 96, 
    3, 77, 5, 38, 2, 10, 0, 67, 7, 64, 1,  9, 6, 93, 4,  8, 8, 53, 
    1, 78, 0, 69, 2, 77, 4, 68, 3, 33, 5, 90, 8, 45, 6, 39, 7, 31, 
    6, 90, 7, 16, 2, 28, 8, 26, 3, 25, 0, 25, 5, 65, 4, 86, 1, 52, 
    0, 98, 2, 45, 4, 33, 6, 66, 3, 98, 1, 82, 7, 84, 5, 37, 8, 16, 
    0, 72, 3, 90, 8, 57, 6, 54, 2, 83, 4, 71, 1, 70, 5, 61, 7, 32, 
    1, 92, 4, 31, 8,  9, 5, 19, 7, 55, 0, 95, 6, 71, 3, 21, 2, 50, 
    5, 46, 2, 74, 3, 16, 0, 64, 8, 15, 7, 67, 4,  5, 1, 98, 6, 49
  };
  const int q3054[] = {
    9, 9, // Number of jobs and machines
    1, 92, 2, 78, 6, 66, 5, 92, 0, 12, 4, 31, 8, 59, 7, 78, 3,  7, 
    1, 33, 0,  2, 8,  1, 4, 59, 5, 71, 7, 21, 2, 14, 6, 65, 3, 20, 
    6, 30, 2, 25, 0, 35, 4, 70, 3, 78, 8, 86, 1, 40, 7, 44, 5, 86, 
    3,  9, 1, 85, 0, 81, 2, 34, 5, 82, 7, 27, 6, 33, 8, 94, 4,  4, 
    8, 86, 2, 50, 0, 47, 1, 77, 6, 61, 7, 62, 3,  5, 4, 56, 5, 50, 
    2, 40, 4, 34, 6, 55, 1, 51, 7, 44, 3, 16, 0, 89, 8,  3, 5, 10, 
    7, 92, 2, 36, 5, 23, 6, 28, 4, 67, 3, 11, 1,  1, 8, 54, 0, 63, 
    0, 22, 3,  6, 4,  9, 2, 24, 8, 18, 6, 79, 5, 44, 7, 92, 1, 87, 
    4, 66, 3,  7, 7, 37, 2, 54, 8, 26, 6, 79, 1, 82, 0,  3, 5, 12
  };
  const int q3055[] = {
    9, 9, // Number of jobs and machines
    7, 95, 0, 51, 2, 65, 3,  9, 4, 82, 6, 11, 5, 97, 1, 56, 8, 93, 
    8, 73, 0, 15, 4,  3, 2, 83, 7, 53, 5, 22, 1, 57, 6, 75, 3,  5, 
    8, 52, 3, 62, 1, 24, 6, 40, 7,  5, 5, 53, 4, 89, 0, 62, 2, 98, 
    6, 23, 4, 42, 0, 14, 2, 27, 8,  7, 1,  3, 7, 97, 5, 96, 3, 73, 
    6, 17, 7, 48, 4, 29, 0, 43, 3,  8, 8, 70, 2, 57, 5, 26, 1, 34, 
    0,  2, 5, 40, 2, 15, 8, 10, 1, 49, 3, 64, 4,  7, 7, 59, 6, 83, 
    5, 62, 0,  7, 7, 40, 6, 12, 8, 44, 4, 48, 1, 28, 2,  2, 3, 91, 
    6, 30, 7, 99, 8, 89, 5, 70, 0, 50, 1, 82, 4, 67, 3, 31, 2, 13, 
    7,  3, 8,  2, 0, 22, 4, 12, 6, 69, 3, 68, 2, 92, 1, 69, 5, 21
  };
  const int q3056[] = {
    9, 9, // Number of jobs and machines
    7,  9, 8, 17, 6, 64, 1, 54, 5, 85, 0, 94, 4,  2, 2, 93, 3, 74, 
    7, 98, 2, 26, 5,  7, 1, 36, 3, 96, 4, 30, 8, 48, 6, 36, 0, 37, 
    6, 92, 7, 35, 5,  7, 8, 87, 3,  3, 4,  2, 2, 55, 1, 71, 0, 56, 
    0, 63, 1, 83, 6, 47, 4, 86, 7, 86, 3, 13, 5, 14, 2, 57, 8, 68, 
    4, 92, 1, 55, 5, 48, 2, 88, 8, 53, 0, 91, 3, 33, 7, 55, 6, 90, 
    0,  7, 5, 68, 7, 96, 8, 75, 1, 47, 6, 83, 2, 57, 3, 31, 4, 95, 
    2, 47, 7, 71, 8, 77, 5, 49, 0, 54, 1, 24, 4, 75, 6, 42, 3, 17, 
    1, 20, 5, 83, 3, 71, 0, 44, 6, 68, 2, 60, 7, 55, 4, 50, 8, 80, 
    8, 59, 0,  6, 7, 47, 1,  7, 5, 47, 3, 29, 6, 54, 2, 48, 4, 58
  };
  const int q3057[] = {
    9, 9, // Number of jobs and machines
    4, 33, 6, 91, 8,  9, 0, 49, 2, 22, 1, 58, 5, 34, 7, 73, 3, 26, 
    8, 99, 4, 47, 1, 17, 5, 10, 6, 68, 7, 92, 0,  8, 2, 13, 3, 32, 
    5, 78, 1, 28, 7, 57, 0, 74, 4, 75, 6, 95, 3, 96, 2,  8, 8, 21, 
    6, 32, 0, 45, 1,  1, 5, 28, 2, 35, 8, 62, 7, 91, 4,  4, 3, 77, 
    6, 84, 1, 99, 8, 36, 7, 40, 2, 14, 4, 76, 5,  1, 0, 68, 3, 95, 
    1,  9, 4,  7, 7, 31, 6, 37, 5, 80, 2, 23, 0, 94, 3, 54, 8, 56, 
    4, 55, 0, 44, 2, 22, 8, 92, 1, 78, 3, 17, 7, 92, 5, 15, 6, 43, 
    2, 12, 3, 88, 4, 78, 0, 99, 8,  8, 1,  4, 6, 25, 7, 59, 5, 59, 
    5, 78, 2, 69, 7, 22, 1, 68, 4, 99, 0, 71, 8, 47, 3, 42, 6, 24
  };
  const int q3058[] = {
    9, 9, // Number of jobs and machines
    1, 84, 3, 20, 0, 66, 7,  4, 5, 18, 2, 78, 8, 76, 6, 95, 4,  4, 
    3,  5, 8, 68, 0, 86, 5, 50, 4, 96, 7, 87, 2,  1, 6, 81, 1, 86, 
    7, 87, 5, 57, 6, 97, 2, 91, 8,  8, 1, 61, 3, 22, 4,  7, 0, 53, 
    0, 52, 7, 90, 6, 97, 3,  8, 8, 32, 4,  1, 5, 84, 1, 86, 2, 70, 
    3, 96, 1, 85, 7, 37, 0, 34, 5, 53, 8, 36, 4, 83, 6,  1, 2, 29, 
    7, 22, 5, 14, 6, 49, 8, 12, 0, 12, 3, 19, 4, 98, 2, 81, 1,  2, 
    7, 55, 2, 49, 8,  5, 5, 93, 3, 20, 4, 11, 1, 96, 6, 58, 0, 97, 
    2, 91, 4, 28, 0, 96, 3, 28, 1, 88, 7, 34, 5, 17, 6, 30, 8, 96, 
    8, 70, 4, 97, 3, 52, 5, 33, 1, 89, 0, 66, 2, 47, 6, 55, 7, 78
  };
  const int q3059[] = {
    9, 9, // Number of jobs and machines
    7, 20, 1, 64, 0, 12, 2, 42, 4, 10, 5, 77, 6, 53, 3, 80, 8, 90, 
    2, 31, 1, 65, 4, 35, 5, 68, 8, 48, 6, 92, 0, 12, 7, 22, 3, 15, 
    0, 27, 7, 41, 6, 41, 3, 98, 1, 99, 4, 61, 5, 50, 2, 61, 8, 23, 
    5, 87, 0,  3, 7, 96, 3, 26, 8, 71, 6, 45, 4, 40, 2, 38, 1, 54, 
    3, 57, 2, 25, 8, 32, 6, 64, 1, 25, 7, 77, 0, 78, 5, 88, 4, 47, 
    7, 12, 1, 79, 6, 36, 2, 32, 4, 93, 3, 34, 5, 73, 8, 86, 0, 32, 
    7,  8, 4, 76, 8, 45, 1, 64, 2, 81, 5, 96, 6,  1, 0, 40, 3, 84, 
    8, 25, 6, 88, 3, 65, 2, 76, 0, 56, 7, 47, 1, 62, 4, 37, 5, 88, 
    0, 92, 5, 63, 7, 35, 4, 67, 2, 78, 1, 81, 8, 31, 6, 45, 3, 93
  };
  const int q3060[] = {
    9, 9, // Number of jobs and machines
    8, 96, 1, 62, 6, 61, 2, 56, 7, 30, 0, 75, 4, 18, 5,  6, 3, 23, 
    8, 33, 1,  1, 2, 32, 5,  3, 7, 23, 4,  8, 6, 88, 0, 12, 3, 62, 
    8, 80, 6, 23, 2, 14, 3, 53, 7, 95, 1,  1, 4, 10, 0, 98, 5, 92, 
    4,  9, 5, 21, 2, 22, 6, 66, 1, 61, 0, 79, 3, 78, 7, 30, 8, 39, 
    6, 73, 5, 30, 7, 44, 3,  4, 8, 66, 1, 68, 0,  4, 2, 78, 4, 41, 
    1, 46, 7, 43, 6, 64, 0, 12, 3, 54, 4, 99, 2, 75, 8, 57, 5, 54, 
    2, 48, 6, 79, 7, 16, 5,  9, 1, 76, 3, 34, 8, 30, 4, 95, 0,  5, 
    6, 50, 5, 33, 0, 57, 2, 77, 1, 28, 3, 19, 7, 80, 8, 71, 4, 71, 
    3, 72, 8, 56, 2,  9, 6,  2, 0, 43, 1, 79, 4, 29, 5,  4, 7, 77
  };
  const int q3061[] = {
    9, 9, // Number of jobs and machines
    1, 91, 8, 79, 0, 74, 4, 62, 7, 51, 6, 41, 5, 57, 2, 48, 3, 36, 
    1, 58, 7, 57, 8, 28, 2, 44, 6, 82, 4, 28, 5, 41, 3, 92, 0,  5, 
    7, 40, 1, 22, 6, 10, 0, 19, 8, 53, 4, 56, 2, 58, 3, 27, 5, 93, 
    1, 80, 2, 54, 5, 48, 0, 75, 7, 84, 4, 65, 3, 24, 6, 25, 8, 52, 
    5, 73, 2, 26, 4, 63, 3, 61, 1, 42, 8, 49, 6, 31, 0, 50, 7, 69, 
    5, 34, 8, 68, 2, 38, 7, 54, 1, 15, 0, 13, 4, 81, 3, 39, 6, 97, 
    2, 42, 1, 26, 0, 55, 6, 65, 5,  4, 8, 75, 3, 94, 4,  8, 7, 67, 
    3, 28, 0, 49, 6, 77, 1, 11, 4, 93, 2, 20, 8, 26, 7, 75, 5, 99, 
    3, 92, 0, 44, 6, 36, 4, 24, 5, 58, 8, 86, 1, 22, 7, 91, 2, 56
  };
  const int q3062[] = {
    9, 9, // Number of jobs and machines
    2, 75, 1, 84, 8, 30, 0, 44, 7, 57, 3, 41, 6, 36, 5, 88, 4, 85, 
    4, 45, 1,  7, 7, 75, 5, 82, 2, 32, 0,  8, 6, 38, 8, 31, 3, 93, 
    0, 76, 6, 75, 4,  3, 7, 99, 5, 83, 1, 29, 8, 41, 3, 14, 2, 33, 
    2, 88, 3, 20, 4, 79, 1, 12, 0, 74, 5, 36, 7, 84, 8, 37, 6, 95, 
    0,  7, 5, 26, 7,  1, 2, 40, 4, 68, 1, 16, 8, 63, 3, 13, 6, 75, 
    4,  7, 6, 90, 5, 11, 0, 50, 1, 46, 7, 34, 2, 59, 3, 71, 8,  5, 
    6, 70, 3, 40, 8, 46, 1, 71, 4, 80, 5, 16, 7, 41, 0, 96, 2, 62, 
    2,  8, 5, 36, 6, 40, 4, 45, 1, 94, 8, 42, 0, 85, 7, 34, 3,  6, 
    0, 26, 3, 85, 8,  1, 5, 33, 2, 76, 6, 96, 1, 38, 7, 86, 4, 82
  };
  const int q3063[] = {
    9, 9, // Number of jobs and machines
    1, 20, 0, 66, 4, 95, 2, 93, 5, 39, 6, 40, 8, 28, 7, 77, 3,  4, 
    4, 10, 1, 50, 0, 41, 2, 41, 5, 75, 6, 50, 8, 65, 7, 48, 3, 90, 
    5, 93, 7, 90, 4, 66, 0, 12, 3, 59, 1, 96, 2, 38, 8, 21, 6,  9, 
    0, 66, 8, 71, 3, 24, 7, 35, 6, 34, 2, 57, 4, 11, 1, 58, 5, 56, 
    3, 38, 7,  7, 2, 41, 4, 14, 8,  4, 5, 21, 6, 75, 0, 10, 1, 66, 
    3, 62, 7,  8, 2, 24, 5, 39, 4, 38, 0, 93, 8, 64, 1, 50, 6, 60, 
    7, 81, 2, 78, 6, 47, 5, 91, 0, 53, 8, 28, 3, 58, 1, 96, 4,  6, 
    2, 52, 0, 58, 1, 20, 5, 39, 6,  7, 3, 58, 4,  8, 7, 70, 8, 91, 
    7, 42, 2, 24, 5, 50, 6, 69, 1, 51, 4, 21, 3, 77, 8, 56, 0, 86
  };
  const int q3064[] = {
    9, 9, // Number of jobs and machines
    8, 46, 4, 21, 6,  6, 3, 89, 2, 28, 1, 32, 5, 78, 0, 66, 7, 48, 
    6, 20, 4, 97, 3, 77, 5, 73, 0, 96, 7, 90, 8, 53, 1, 84, 2, 91, 
    5, 70, 0,  2, 8, 24, 1, 89, 6, 91, 2, 11, 4, 13, 3, 19, 7,  2, 
    8, 24, 0, 22, 1, 77, 3, 38, 4, 17, 2, 62, 5, 76, 7, 39, 6, 50, 
    8,  3, 7, 34, 1, 74, 5, 88, 4, 63, 3, 66, 2, 32, 6, 30, 0, 31, 
    5, 95, 0, 33, 7, 87, 4, 61, 1, 69, 2, 84, 3, 79, 6, 36, 8,  4, 
    7, 31, 1, 38, 8, 27, 5, 57, 6, 69, 4, 99, 3, 73, 2, 20, 0, 27, 
    2, 71, 5, 58, 3, 69, 8, 66, 7, 82, 1, 33, 0, 37, 6, 37, 4, 79, 
    7, 15, 2, 36, 1, 44, 6, 95, 5, 98, 4, 89, 8, 68, 3, 38, 0, 73
  };
  const int q3065[] = {
    9, 9, // Number of jobs and machines
    4, 59, 6, 53, 1, 56, 0, 49, 2,  4, 3,  3, 7, 98, 5, 59, 8, 90, 
    3, 43, 8, 82, 5, 28, 0, 88, 2, 16, 7, 28, 1, 17, 4, 14, 6, 80, 
    6, 47, 7,  8, 3,  6, 4, 39, 0, 48, 5, 19, 8,  5, 1, 38, 2, 94, 
    5, 74, 4,  5, 0, 44, 7, 94, 2, 18, 1, 96, 8, 37, 3, 59, 6, 51, 
    2, 41, 0, 77, 5, 79, 6, 82, 3, 70, 1, 97, 8, 71, 7, 62, 4,  3, 
    4, 98, 3, 99, 5, 79, 2, 39, 1,  6, 6, 62, 7, 98, 8, 42, 0, 32, 
    4, 89, 1,  3, 2, 36, 7, 58, 0, 64, 6, 60, 5, 61, 8, 98, 3, 44, 
    1, 60, 6,  7, 3, 19, 8, 84, 5, 65, 4, 55, 2, 97, 7, 39, 0, 27, 
    7, 74, 0,  8, 5, 90, 6, 24, 8, 98, 4,  7, 2, 85, 3, 22, 1, 19
  };
  const int q3066[] = {
    9, 9, // Number of jobs and machines
    6,  7, 4, 71, 2, 71, 1, 14, 5, 61, 0, 82, 8, 89, 3,  5, 7, 89, 
    7, 96, 2, 88, 5, 71, 8, 45, 6, 56, 1, 23, 3, 92, 4, 99, 0, 51, 
    0,  2, 4, 76, 1, 42, 8, 62, 3, 18, 7,  3, 6, 15, 5, 32, 2, 73, 
    2, 34, 4, 94, 8, 37, 7,  3, 5, 51, 1, 74, 6, 28, 3, 73, 0, 99, 
    0, 32, 6, 34, 2, 51, 8, 75, 5, 86, 3, 26, 7, 52, 4,  3, 1, 68, 
    6, 91, 1, 87, 8,  2, 7,  4, 5, 34, 3, 37, 2, 72, 4, 73, 0, 43, 
    2, 55, 1, 84, 3, 29, 0,  6, 5, 85, 8, 61, 7, 53, 6, 92, 4, 87, 
    4, 54, 7, 85, 3, 11, 6, 67, 8, 33, 5, 89, 1, 13, 2, 58, 0, 26, 
    3, 58, 5, 40, 2, 44, 4, 80, 1, 68, 0, 72, 8, 74, 6, 39, 7, 53
  };
  const int q3067[] = {
    9, 9, // Number of jobs and machines
    5, 39, 2,  5, 3, 20, 1, 28, 4, 71, 7, 16, 6,  2, 0,  7, 8, 69, 
    7, 88, 3, 91, 0, 46, 6,  2, 4, 34, 8, 68, 1, 49, 5, 81, 2, 79, 
    5, 67, 8, 81, 3, 54, 0, 45, 4, 17, 1,  7, 7, 39, 2, 33, 6, 74, 
    3, 31, 5, 59, 0, 58, 6, 13, 4,  9, 2, 25, 7, 96, 1,  7, 8, 42, 
    0, 87, 6, 37, 2, 77, 8, 47, 5, 89, 4, 85, 7, 55, 3,  5, 1, 31, 
    6, 82, 3, 44, 4, 79, 7, 12, 5, 51, 1, 39, 2, 10, 8, 67, 0, 32, 
    7, 10, 2, 57, 5, 50, 6, 14, 8, 94, 3, 21, 4, 25, 1, 32, 0, 83, 
    5, 23, 7, 82, 6, 53, 2, 99, 0,  6, 4, 37, 3, 67, 1, 44, 8, 68, 
    3, 73, 1, 32, 6,  3, 2, 93, 7, 46, 8, 29, 0, 65, 5, 21, 4, 34
  };
  const int q3068[] = {
    9, 9, // Number of jobs and machines
    5, 90, 7, 47, 1, 87, 0, 59, 4, 50, 2, 64, 8, 83, 6, 79, 3, 42, 
    1, 30, 2, 19, 3, 14, 4, 15, 5, 69, 7,  2, 8, 31, 0, 40, 6, 86, 
    1, 41, 4, 10, 8, 46, 7, 26, 6, 93, 0,  5, 3, 91, 5, 92, 2, 31, 
    1,  3, 8, 28, 2, 74, 7, 32, 6, 90, 5, 38, 4, 48, 3,  4, 0, 32, 
    6, 40, 4, 59, 8, 17, 5, 78, 2, 58, 0,  2, 3, 57, 1, 62, 7, 10, 
    1, 62, 6, 92, 3, 60, 5, 40, 4, 80, 7, 73, 0, 43, 2, 29, 8,  4, 
    2, 53, 8, 25, 7, 40, 3, 74, 5, 99, 4, 62, 0, 15, 1, 19, 6, 24, 
    8, 24, 2, 72, 3,  9, 7, 17, 0, 13, 5, 67, 6, 97, 1,  1, 4, 30, 
    0, 48, 5, 63, 3, 49, 4, 87, 7, 82, 8, 15, 6, 72, 2, 17, 1, 88
  };
  const int q3069[] = {
    9, 9, // Number of jobs and machines
    3, 80, 8, 39, 1, 37, 0, 10, 6, 88, 4, 85, 7, 57, 5,  8, 2, 73, 
    1, 82, 7, 16, 6, 64, 3, 87, 0, 51, 2, 59, 8, 86, 4, 62, 5, 24, 
    4, 47, 1, 96, 2,  6, 7, 46, 0, 57, 8, 11, 3, 34, 6, 56, 5, 15, 
    2, 99, 7, 20, 5, 18, 1, 14, 0, 43, 4, 29, 8,  2, 6, 59, 3, 69, 
    8, 21, 4, 31, 0,  6, 2, 18, 7, 83, 3, 37, 1, 73, 5, 75, 6, 53, 
    1, 69, 5, 15, 0, 21, 6, 68, 3, 49, 7, 33, 8, 26, 4, 10, 2, 80, 
    5, 94, 1,  9, 2, 66, 8, 64, 6, 23, 0, 57, 7, 27, 3, 60, 4, 60, 
    6,  5, 1, 73, 5, 74, 3, 41, 8, 26, 2, 89, 4,  6, 7,  1, 0,  8, 
    3, 35, 2, 61, 4, 36, 6, 63, 1, 32, 5, 97, 7, 23, 0,  9, 8, 85
  };
  const int q3070[] = {
    9, 9, // Number of jobs and machines
    4, 30, 7, 46, 1, 55, 2, 12, 6, 25, 5, 73, 0, 46, 3, 20, 8,  5, 
    7, 50, 0, 58, 1, 22, 5, 73, 4, 87, 3, 77, 2,  6, 8, 36, 6, 35, 
    2, 18, 1, 94, 5, 60, 3, 38, 0, 33, 7, 21, 6, 71, 8, 80, 4,  7, 
    7, 60, 0, 42, 3, 57, 1, 37, 5,  2, 6, 23, 2, 77, 4, 86, 8, 51, 
    0, 86, 8, 68, 7, 58, 2, 43, 3, 88, 5, 50, 6, 96, 1, 19, 4, 26, 
    1, 39, 6, 15, 5, 87, 0, 48, 4, 35, 7, 78, 3, 73, 8, 15, 2, 27, 
    1,  9, 6, 64, 5, 55, 3, 15, 0, 60, 4, 82, 2, 30, 8, 55, 7, 86, 
    6, 15, 3, 15, 1, 92, 0, 84, 2,  3, 8,  4, 5, 30, 4, 54, 7, 30, 
    5, 34, 0, 16, 8, 38, 4, 44, 3, 23, 7,  4, 2, 30, 6, 69, 1, 55
  };
  const int q3071[] = {
    9, 9, // Number of jobs and machines
    8, 47, 6, 32, 3, 46, 4, 44, 5, 54, 0, 20, 1, 40, 7, 87, 2, 24, 
    2, 82, 1, 28, 0, 82, 4, 80, 8, 71, 3, 12, 6, 13, 7, 11, 5, 10, 
    5, 37, 4, 68, 6,  7, 8,  2, 2,  7, 1, 64, 7, 73, 0, 54, 3, 63, 
    5, 34, 2, 40, 7, 58, 0, 47, 1, 26, 6,  5, 8, 55, 3, 87, 4,  7, 
    6, 99, 7,  4, 4, 15, 2,  2, 5, 39, 0, 16, 3, 89, 1, 71, 8, 11, 
    2, 53, 0, 55, 6, 94, 8, 77, 7, 29, 3, 38, 5, 68, 1, 75, 4, 68, 
    4, 31, 5, 96, 1, 10, 2, 33, 8, 88, 6, 61, 7, 23, 3, 27, 0, 51, 
    0, 57, 2, 91, 4,  2, 7, 82, 1, 84, 6, 37, 3, 78, 5, 79, 8, 80, 
    6, 70, 0, 93, 4, 63, 2, 23, 3, 62, 8, 86, 5,  5, 7, 70, 1, 92
  };
  const int q3072[] = {
    9, 9, // Number of jobs and machines
    0, 68, 3, 49, 8, 91, 7, 90, 5, 96, 1,  9, 6, 75, 4,  8, 2, 85, 
    5, 53, 6, 25, 4, 89, 7, 50, 1, 96, 8,  9, 2, 40, 3, 15, 0,  5, 
    1, 14, 4, 44, 5, 21, 3, 23, 6, 79, 0, 96, 8, 99, 2,  8, 7, 69, 
    5, 58, 0, 27, 4, 22, 8, 99, 6, 38, 2, 82, 1, 61, 7, 31, 3, 81, 
    7,  9, 1, 53, 3, 49, 4, 51, 8, 88, 6, 44, 2, 16, 0, 58, 5, 51, 
    5, 32, 1, 87, 8, 36, 7, 25, 0, 21, 3, 78, 2, 87, 6, 73, 4, 24, 
    3, 84, 8, 63, 1, 45, 4, 80, 6, 15, 7, 78, 2, 78, 0, 34, 5, 36, 
    4, 79, 0, 91, 1, 21, 7, 48, 6, 65, 8, 53, 5, 38, 3, 18, 2, 78, 
    0, 91, 6,  8, 8, 42, 5, 93, 3, 46, 1, 88, 4, 14, 2,  7, 7, 60
  };
  const int q3073[] = {
    9, 9, // Number of jobs and machines
    3, 10, 5, 63, 4, 51, 8, 68, 7, 29, 1,  3, 0, 51, 6, 69, 2, 18, 
    8,  6, 6, 26, 1, 74, 0, 97, 4, 18, 5, 13, 7,  1, 2, 27, 3, 88, 
    3, 20, 7, 81, 6, 72, 5,  3, 8, 95, 0, 93, 1, 66, 2, 10, 4, 95, 
    2, 69, 6, 31, 0, 58, 4, 70, 8, 22, 7, 86, 5, 13, 3, 64, 1, 89, 
    8, 43, 6, 46, 0, 80, 4,  3, 5, 74, 1, 32, 2, 61, 7, 33, 3, 30, 
    0, 28, 8, 87, 5, 48, 4, 63, 6, 23, 3, 40, 2, 57, 7, 44, 1, 14, 
    8, 14, 5,  7, 7, 72, 3, 51, 0, 13, 1, 60, 6, 21, 2, 18, 4, 20, 
    8, 37, 6, 48, 7,  3, 1, 23, 5, 31, 0,  7, 2, 93, 3,  9, 4, 90, 
    8, 77, 2, 83, 0, 88, 3, 39, 5, 84, 1, 93, 4, 25, 7, 75, 6, 33
  };
  const int q3074[] = {
    9, 9, // Number of jobs and machines
    5, 88, 2, 51, 1, 54, 7, 57, 0, 62, 4, 30, 8, 78, 6, 71, 3,  6, 
    7, 58, 6, 15, 0, 39, 5, 39, 4, 61, 2, 54, 8, 57, 3, 71, 1, 78, 
    8, 66, 1, 79, 4, 93, 5, 74, 2, 51, 3, 11, 6, 97, 7, 25, 0, 44, 
    7, 34, 4,  8, 8, 61, 3, 43, 5, 63, 2, 34, 1, 21, 6, 25, 0, 77, 
    7, 59, 8, 17, 0, 66, 6, 21, 3, 21, 4, 69, 1, 53, 2, 20, 5, 22, 
    3, 34, 4, 85, 8, 77, 2, 83, 6, 69, 7, 44, 5, 59, 0, 72, 1, 15, 
    8, 88, 2,  7, 6, 30, 5, 25, 1, 71, 0, 18, 3, 29, 7, 58, 4, 11, 
    5, 56, 0, 12, 2, 10, 1, 10, 7,  2, 6, 24, 3, 41, 4,  7, 8, 93, 
    0,  2, 8, 34, 4,  2, 1, 27, 7,  4, 3, 95, 2, 39, 5, 33, 6, 56
  };
  const int q3075[] = {
    9, 9, // Number of jobs and machines
    5, 58, 3, 45, 4, 23, 7, 83, 2,  2, 1, 22, 8, 97, 0, 38, 6, 39, 
    1, 18, 8, 71, 3, 94, 4,  9, 6, 89, 2, 56, 0, 88, 5, 78, 7, 88, 
    6,  1, 3, 84, 0,  3, 4, 22, 2, 52, 8,  9, 7, 83, 5, 36, 1, 24, 
    2, 90, 1, 58, 5, 58, 3, 74, 0,  5, 7, 85, 8, 55, 6, 42, 4, 79, 
    4, 53, 1, 17, 3, 70, 2, 59, 0, 11, 7, 16, 6, 67, 5, 16, 8, 78, 
    8, 57, 2, 29, 7, 82, 6, 68, 4, 67, 1, 53, 5, 72, 3, 63, 0, 98, 
    3, 96, 4, 42, 7, 10, 2, 96, 1, 93, 0, 45, 5, 90, 8, 38, 6, 23, 
    4, 25, 8, 81, 0, 99, 6, 44, 7, 62, 1, 27, 2, 42, 3, 95, 5, 19, 
    8, 97, 1,  7, 2, 82, 6, 77, 0, 43, 5, 40, 4,  8, 7,  6, 3, 31
  };
  const int q3076[] = {
    9, 9, // Number of jobs and machines
    5, 18, 4, 64, 1, 45, 7, 47, 3, 61, 0, 59, 8, 42, 6, 81, 2, 65, 
    7,  6, 3, 25, 2, 81, 4, 24, 6, 33, 1, 44, 5, 24, 8, 89, 0, 32, 
    6, 69, 4, 12, 3, 91, 2, 57, 5, 32, 1,  7, 7,  5, 8,  3, 0, 63, 
    5, 45, 7, 39, 2, 24, 6, 31, 4, 45, 8, 14, 1, 20, 3, 10, 0, 10, 
    4, 10, 1,  7, 2, 23, 5, 58, 0, 24, 8, 10, 6, 55, 3,  5, 7, 32, 
    7,  3, 2, 11, 5, 25, 4, 63, 3, 96, 0, 95, 6, 40, 1, 75, 8, 97, 
    2, 79, 4, 43, 0, 21, 1, 66, 5, 70, 8, 96, 7, 34, 6, 83, 3, 42, 
    7, 89, 4,  6, 0, 34, 8, 99, 5, 82, 1, 24, 3, 51, 2, 83, 6, 31, 
    2, 69, 0, 56, 1, 77, 7,  1, 6, 55, 8, 28, 4, 75, 5, 34, 3, 98
  };
  const int q3077[] = {
    9, 9, // Number of jobs and machines
    2, 39, 3, 64, 1, 69, 8,  1, 5, 58, 4, 12, 0, 51, 7, 14, 6, 99, 
    8, 32, 7, 49, 0, 90, 6,  2, 5, 94, 2, 18, 3,  9, 4, 85, 1, 41, 
    7, 18, 4, 24, 2, 36, 6,  6, 0, 19, 8, 39, 3, 77, 1, 40, 5, 64, 
    3, 11, 1, 34, 6, 37, 4, 33, 8, 60, 2, 53, 7, 75, 5,  5, 0, 53, 
    3, 58, 4, 26, 6, 82, 5, 25, 7, 74, 8, 97, 1, 19, 0, 76, 2, 95, 
    0, 75, 2, 65, 4, 58, 3, 77, 8, 21, 6, 75, 1, 92, 5, 81, 7, 35, 
    8, 93, 3, 13, 4,  6, 1, 69, 6, 91, 2,  9, 7, 12, 5,  6, 0, 45, 
    1,  3, 4, 91, 8, 92, 2, 36, 6, 51, 0, 77, 5, 16, 3, 56, 7, 85, 
    1, 49, 5, 88, 0, 31, 8, 63, 4, 46, 2, 46, 6,  2, 7, 88, 3, 10
  };
  const int q3078[] = {
    9, 9, // Number of jobs and machines
    2, 46, 4,  8, 7, 37, 8, 12, 3, 56, 0, 53, 5, 97, 1, 73, 6, 19, 
    3,  1, 5, 44, 2, 25, 4, 60, 7, 31, 1, 94, 0, 83, 8, 14, 6, 26, 
    2, 16, 5, 23, 4, 65, 6, 39, 0, 37, 7, 79, 8, 72, 3, 78, 1, 82, 
    7,  1, 8, 80, 1, 27, 5, 94, 6, 74, 2, 52, 4, 59, 0, 32, 3, 65, 
    7, 16, 0, 74, 5, 48, 4, 15, 2, 16, 6, 23, 8, 39, 3, 70, 1, 95, 
    4, 80, 3,  5, 2, 99, 7, 32, 6, 84, 8, 93, 1, 29, 0, 34, 5, 29, 
    6,  5, 7, 86, 1, 34, 4, 26, 8, 77, 0, 20, 3, 44, 2, 42, 5, 68, 
    3, 63, 0, 95, 8, 40, 2, 23, 1, 56, 5, 29, 4, 90, 6, 16, 7, 96, 
    2, 36, 5, 87, 8, 43, 1, 75, 3, 53, 4, 56, 6, 87, 7, 94, 0, 34
  };
  const int q3079[] = {
    9, 9, // Number of jobs and machines
    2, 54, 3, 86, 0, 53, 1, 79, 7,  5, 5, 86, 6, 68, 8, 26, 4, 45, 
    1, 64, 7, 12, 8, 97, 2,  8, 5, 84, 3, 83, 4, 95, 6,  7, 0, 13, 
    6, 79, 8, 46, 3, 15, 7, 19, 4, 44, 2, 87, 5, 73, 0, 60, 1, 22, 
    6, 16, 7, 25, 5, 52, 3, 48, 8, 66, 1, 74, 0, 71, 2, 85, 4, 39, 
    7, 74, 4, 51, 5, 38, 8, 59, 3, 72, 0, 40, 6,  5, 2, 52, 1, 54, 
    6, 74, 1, 17, 5, 20, 3, 53, 4, 56, 0, 18, 8, 76, 2, 90, 7, 43, 
    2, 33, 6, 43, 7, 54, 0, 70, 1, 27, 8, 24, 3, 39, 5,  6, 4, 34, 
    2, 59, 6, 18, 4, 60, 8, 36, 7, 12, 0, 29, 3, 54, 5, 87, 1, 83, 
    4, 42, 8, 66, 3, 70, 6, 28, 7, 17, 0, 87, 1, 55, 2, 56, 5, 90
  };
  const int q3080[] = {
    9, 9, // Number of jobs and machines
    8, 26, 6, 52, 1, 97, 7, 52, 0, 91, 4, 10, 3, 42, 2, 72, 5, 84, 
    5, 14, 8,  6, 0, 66, 3, 14, 2, 83, 7, 73, 6, 22, 1, 88, 4, 24, 
    8,  3, 5,  7, 7,  7, 2, 11, 0,  3, 4, 42, 1,  3, 6, 61, 3, 51, 
    7, 85, 1, 96, 0, 34, 4, 57, 2, 91, 8, 51, 5, 40, 6, 92, 3, 73, 
    2, 72, 8, 69, 6, 52, 1, 89, 5, 94, 4, 75, 7, 22, 3, 28, 0, 42, 
    4, 89, 7, 94, 2, 19, 6, 67, 8, 26, 0, 13, 5, 14, 1, 64, 3,  5, 
    0, 78, 8, 85, 7, 45, 1, 50, 3, 79, 4, 81, 6, 51, 2,  3, 5, 62, 
    8, 70, 4, 13, 2, 28, 1, 63, 5,  2, 6, 76, 0, 54, 3, 95, 7,  7, 
    8, 16, 2, 49, 5, 76, 1, 65, 0, 13, 7, 54, 4, 50, 3, 82, 6, 30
  };
  const int q3081[] = {
    9, 9, // Number of jobs and machines
    1, 18, 0, 58, 8, 22, 5, 91, 3, 65, 4, 11, 6, 88, 2, 20, 7,  5, 
    5, 27, 6, 58, 2, 13, 4, 62, 7, 60, 1,  2, 3, 36, 0, 64, 8,  2, 
    0, 73, 5, 84, 1, 54, 2, 41, 8, 55, 4, 72, 3, 84, 6, 89, 7, 89, 
    6, 64, 4, 95, 7, 28, 0, 19, 1, 62, 2, 24, 3, 96, 8, 14, 5, 76, 
    5, 50, 2, 97, 3, 92, 7, 92, 0, 62, 4, 87, 6, 70, 1, 63, 8, 89, 
    2,  9, 1, 87, 6, 23, 0, 80, 5,  2, 8, 68, 3, 55, 4,  7, 7, 32, 
    8, 22, 7, 71, 5, 49, 0,  2, 1, 85, 4, 72, 3, 74, 6, 38, 2, 45, 
    3, 41, 5, 30, 1,  5, 4, 50, 7, 96, 0,  6, 8, 24, 6, 15, 2,  4, 
    7, 74, 3, 91, 8,  9, 4, 31, 0, 28, 1, 95, 6, 25, 5, 35, 2, 14
  };
  const int q3082[] = {
    9, 9, // Number of jobs and machines
    7,  2, 4,  9, 8, 54, 3, 88, 1, 14, 5, 36, 2, 20, 6, 38, 0, 52, 
    5, 40, 8, 64, 7, 47, 1, 16, 0, 75, 2, 81, 6, 81, 3, 82, 4, 62, 
    5, 77, 3, 48, 4, 39, 0, 88, 1, 26, 2, 25, 7, 96, 8, 25, 6, 68, 
    0, 49, 6, 70, 7, 83, 2, 59, 8,  1, 1, 29, 4, 60, 3, 86, 5, 80, 
    2, 11, 1, 78, 3, 46, 0, 99, 8, 73, 4, 93, 6, 40, 7, 99, 5, 32, 
    4, 36, 0, 32, 1, 65, 7, 83, 3, 82, 2, 80, 6, 88, 5, 63, 8, 34, 
    6, 42, 8, 17, 7, 49, 2, 19, 3, 87, 5, 87, 4, 25, 0, 75, 1, 42, 
    4, 73, 5, 21, 1, 56, 8, 99, 7, 64, 6, 89, 0, 99, 3, 34, 2, 24, 
    7, 60, 4, 11, 8, 56, 1, 80, 6, 38, 5, 30, 0, 14, 3, 99, 2, 83
  };
  const int q3083[] = {
    9, 9, // Number of jobs and machines
    7, 77, 3, 69, 6, 47, 5, 63, 1, 81, 8, 35, 4, 70, 0, 79, 2, 78, 
    7, 14, 5, 54, 8, 67, 6, 98, 4, 56, 1, 57, 2, 72, 3, 85, 0, 35, 
    7, 22, 4, 47, 0, 96, 2, 92, 1, 14, 3, 95, 6, 36, 5, 20, 8, 81, 
    0, 68, 8, 11, 4, 61, 6, 31, 2, 19, 7, 75, 5, 13, 3, 55, 1, 22, 
    8, 27, 6, 48, 3, 79, 4, 82, 5, 22, 2, 14, 7, 86, 0, 24, 1, 98, 
    4, 60, 2, 50, 7, 91, 8, 26, 0, 37, 6, 35, 3, 83, 5, 61, 1, 44, 
    7, 21, 6, 28, 0, 49, 1, 81, 5, 84, 2, 80, 3, 67, 8, 86, 4, 86, 
    2, 34, 4, 76, 0, 39, 5, 32, 6, 19, 3, 39, 1, 99, 7, 14, 8, 15, 
    0, 25, 3, 73, 4, 19, 2, 80, 6, 72, 8, 19, 5, 53, 1, 66, 7, 55
  };
  const int q3084[] = {
    9, 9, // Number of jobs and machines
    8, 74, 2, 52, 1, 83, 5,  8, 4, 57, 3, 38, 7, 52, 6,  1, 0, 94, 
    5, 24, 4, 97, 2, 86, 0, 86, 1, 35, 3, 22, 8, 82, 7, 94, 6, 93, 
    8, 60, 3, 55, 5, 81, 0, 32, 2,  9, 1, 19, 6, 18, 4, 51, 7, 80, 
    6, 34, 3, 72, 4, 36, 0, 89, 1,  4, 8, 86, 7, 41, 2, 54, 5, 49, 
    2, 58, 8, 51, 7, 87, 4,  9, 1, 43, 6, 73, 3,  3, 5, 54, 0, 65, 
    0, 19, 8, 79, 6, 78, 7,  8, 1, 53, 2, 74, 4, 13, 5, 36, 3, 79, 
    6, 26, 7, 57, 0, 56, 3, 31, 2, 60, 1, 58, 4, 51, 8, 27, 5, 15, 
    1, 17, 3, 99, 7, 81, 5, 74, 4, 11, 0, 49, 8, 68, 2, 28, 6, 98, 
    7, 67, 2, 83, 4, 77, 0, 96, 6, 50, 3, 16, 1,  1, 5, 77, 8, 47
  };
  const int q3085[] = {
    9, 9, // Number of jobs and machines
    4, 23, 7, 22, 6, 59, 3, 40, 0,  5, 2, 56, 8, 86, 1, 35, 5, 48, 
    6, 69, 2, 67, 5, 23, 4, 30, 3, 51, 0, 23, 8, 61, 7, 11, 1, 81, 
    6,  5, 0, 95, 5, 34, 8, 81, 1, 60, 4, 64, 2, 14, 3, 32, 7, 41, 
    7, 89, 3, 88, 8, 92, 2, 50, 1, 78, 5, 13, 0, 89, 4, 52, 6, 55, 
    5, 46, 4, 67, 0, 48, 8, 39, 2, 10, 3,  3, 6, 17, 7, 51, 1, 26, 
    3, 99, 7,  5, 8, 87, 5, 67, 6, 47, 1, 36, 2,  3, 4, 83, 0, 47, 
    6, 10, 8, 46, 4, 38, 5, 27, 2, 23, 7, 51, 3, 64, 0, 61, 1, 94, 
    8, 40, 1, 54, 2, 57, 5,  5, 3,  6, 6, 62, 4, 67, 7, 64, 0, 59, 
    2, 57, 6, 35, 4, 67, 7, 86, 0, 58, 3, 69, 8, 77, 1, 83, 5, 73
  };
  const int q3086[] = {
    9, 9, // Number of jobs and machines
    4, 29, 2,  7, 0, 70, 7, 23, 3, 80, 6, 88, 8, 52, 1, 18, 5, 33, 
    3,  9, 8, 13, 6, 80, 4, 37, 7, 12, 2, 15, 5, 39, 0, 66, 1, 56, 
    5, 25, 7, 29, 6, 79, 1, 32, 8, 87, 2, 89, 4, 80, 0, 51, 3, 59, 
    5, 15, 1, 51, 0, 93, 3, 13, 2, 36, 4, 39, 6, 48, 8,  1, 7, 29, 
    1, 18, 5, 32, 8, 20, 4,  2, 3, 82, 7, 25, 2, 76, 6, 76, 0, 18, 
    8, 85, 4, 46, 5, 64, 7, 93, 2, 43, 1, 11, 3, 20, 6, 49, 0, 21, 
    1, 38, 8, 20, 0, 65, 2, 52, 5, 50, 7, 68, 6, 58, 3, 94, 4, 92, 
    0, 90, 5, 89, 8, 50, 6, 60, 1, 20, 3, 11, 4, 55, 2, 46, 7, 38, 
    8, 61, 7, 12, 4, 27, 0, 83, 6, 57, 3, 92, 2,  1, 1, 90, 5, 94
  };
  const int q3087[] = {
    9, 9, // Number of jobs and machines
    7, 56, 4,  8, 6, 24, 1, 45, 5, 17, 0, 30, 8, 61, 3, 81, 2, 67, 
    2, 48, 5, 65, 8, 64, 4, 34, 1, 98, 7,  4, 3, 68, 6, 25, 0,  2, 
    0, 77, 3, 14, 6, 74, 7, 64, 8, 79, 1, 91, 5, 50, 2, 22, 4, 48, 
    2, 13, 6, 83, 5, 71, 4, 10, 7, 43, 3, 96, 1, 97, 8, 90, 0,  8, 
    2, 68, 5, 83, 3, 56, 4, 18, 7, 95, 8, 15, 6, 71, 1, 78, 0, 90, 
    2, 14, 4, 79, 8, 94, 5, 42, 7, 59, 3, 11, 1, 35, 6, 78, 0, 14, 
    7, 68, 6, 45, 3, 74, 2, 15, 0, 87, 8, 90, 5, 94, 1, 52, 4,  8, 
    1, 21, 4, 14, 8, 39, 3, 27, 6, 78, 2, 76, 5, 35, 7, 86, 0, 94, 
    6, 63, 4, 80, 5, 83, 2, 39, 7, 19, 3, 74, 8, 46, 1, 66, 0, 14
  };
  const int q3088[] = {
    9, 9, // Number of jobs and machines
    0, 21, 8, 14, 2, 91, 3, 45, 4, 91, 5, 26, 7, 10, 6, 14, 1, 14, 
    2, 24, 0, 43, 4, 47, 7, 39, 3, 64, 5, 47, 6, 94, 8, 97, 1, 72, 
    8, 55, 7,  9, 2, 67, 5,  4, 4, 51, 3, 35, 0, 82, 6, 22, 1, 77, 
    6, 41, 4, 18, 8, 15, 3, 96, 2, 32, 0, 67, 1, 56, 5, 14, 7, 74, 
    0, 70, 6,  5, 7, 16, 3,  2, 5, 12, 1, 20, 4, 37, 2, 71, 8, 63, 
    4,  1, 0,  9, 5, 14, 3, 27, 6, 52, 1, 89, 7, 89, 8, 90, 2, 20, 
    2, 85, 5, 55, 7, 30, 1, 81, 6,  4, 0, 51, 4, 85, 8, 78, 3, 32, 
    2, 33, 6, 29, 0, 15, 1, 36, 4, 94, 8, 35, 5, 24, 7, 46, 3, 75, 
    0,  2, 3, 89, 1, 99, 8, 24, 2, 94, 6,  3, 7, 43, 5, 18, 4, 74
  };
  const int q3089[] = {
    9, 9, // Number of jobs and machines
    3, 37, 6,  5, 1, 20, 7, 69, 0, 43, 8, 98, 4, 82, 5, 37, 2, 13, 
    5, 87, 4, 83, 2, 76, 1, 22, 6, 78, 3, 34, 7, 53, 8, 54, 0, 89, 
    5, 93, 3, 77, 2, 96, 1, 85, 7, 72, 4, 54, 6, 64, 8, 23, 0, 33, 
    6, 80, 3, 64, 5,  4, 2, 97, 8, 21, 0,  4, 1, 35, 7, 34, 4, 94, 
    8, 50, 6, 98, 0, 32, 4,  8, 7, 96, 3, 33, 2, 98, 1, 79, 5, 11, 
    0, 62, 6, 91, 3, 85, 2, 27, 4, 54, 5,  7, 8, 20, 7, 46, 1, 69, 
    2, 51, 8, 48, 0, 81, 1,  8, 7, 71, 4, 59, 3, 30, 5, 22, 6, 58, 
    2, 54, 6, 84, 4, 45, 3, 92, 0, 82, 1, 75, 7, 71, 5, 44, 8, 35, 
    2,  5, 4, 24, 3, 38, 6, 30, 5, 64, 8, 45, 1, 23, 0, 76, 7, 86
  };
  const int q3090[] = {
    9, 9, // Number of jobs and machines
    2, 90, 1,  8, 3, 65, 6, 25, 0, 35, 8,  7, 7,  9, 4,  4, 5, 32, 
    6, 76, 3, 62, 0, 73, 8, 59, 7, 99, 1, 41, 4, 96, 2, 49, 5, 26, 
    1, 45, 0, 78, 8, 59, 5, 68, 6, 74, 7, 38, 2, 57, 4, 98, 3, 88, 
    3, 80, 6, 53, 7, 44, 1,  2, 8, 51, 2, 53, 0, 57, 4, 33, 5, 97, 
    2, 83, 0, 45, 3, 25, 5, 61, 1, 49, 8, 69, 6, 95, 4, 95, 7, 72, 
    7, 69, 4, 50, 8,  9, 0, 43, 5, 75, 3, 17, 6, 17, 2, 49, 1, 90, 
    8, 50, 3, 75, 5, 41, 0, 55, 6, 16, 2, 88, 1, 67, 7,  3, 4, 75, 
    8, 47, 7, 68, 3, 86, 6, 61, 1, 23, 2, 33, 0, 49, 5, 68, 4, 94, 
    2, 58, 7, 38, 5, 13, 6, 38, 3, 46, 1, 67, 8, 82, 0, 11, 4, 37
  };
  const int q3091[] = {
    9, 9, // Number of jobs and machines
    7, 28, 1, 50, 3, 89, 6, 91, 8, 47, 2, 93, 5, 73, 0, 31, 4, 13, 
    8, 90, 2, 86, 4, 20, 7, 66, 6, 45, 0, 15, 5, 63, 3, 79, 1, 62, 
    4, 70, 6, 21, 1, 40, 2,  2, 5, 58, 8, 83, 7, 70, 0, 60, 3, 23, 
    8, 38, 7, 14, 4, 14, 5, 75, 2, 58, 3, 59, 0, 91, 1, 82, 6, 42, 
    5, 80, 2, 71, 0, 65, 6, 36, 8, 53, 3, 19, 1, 39, 4, 94, 7, 32, 
    8, 36, 0, 97, 7, 12, 4, 61, 3, 84, 6, 60, 1, 79, 2, 23, 5, 86, 
    5, 65, 0, 28, 4, 49, 8, 83, 2, 49, 6, 39, 1,  8, 3, 34, 7, 92, 
    2, 15, 8, 35, 7, 34, 0,  5, 6, 54, 3,  8, 4, 20, 5, 96, 1, 75, 
    8, 24, 4, 16, 7, 48, 2, 61, 5, 62, 6, 98, 0, 69, 3, 78, 1, 93
  };
  const int q3092[] = {
    9, 9, // Number of jobs and machines
    5, 67, 4, 18, 2, 75, 3, 84, 8, 44, 6, 57, 7, 93, 0, 85, 1, 34, 
    6, 41, 4, 20, 5,  7, 1, 18, 7, 71, 2, 69, 0, 70, 8, 12, 3, 40, 
    4, 14, 0, 89, 2, 91, 3, 85, 6,  7, 8, 55, 5, 38, 1, 62, 7, 87, 
    5, 16, 4, 71, 7, 41, 2,  7, 0, 24, 8, 61, 1, 67, 3, 30, 6,  8, 
    8, 66, 1, 64, 3, 34, 7, 59, 4, 78, 5, 77, 2, 67, 6, 58, 0, 44, 
    0, 64, 8, 77, 3, 54, 5, 26, 7, 60, 6, 30, 4, 79, 1, 35, 2, 39, 
    5, 97, 8, 33, 7, 95, 2, 72, 4, 84, 1,  1, 6, 90, 0, 15, 3, 32, 
    1, 18, 0, 52, 3, 67, 5, 97, 6, 77, 7, 38, 8, 30, 2, 35, 4,  3, 
    1, 70, 8, 81, 3, 67, 7, 74, 2, 91, 0, 32, 5, 44, 4, 38, 6, 57
  };
  const int q3093[] = {
    9, 9, // Number of jobs and machines
    5, 23, 4, 10, 3, 31, 2, 55, 0, 84, 7, 42, 8, 39, 1,  6, 6,  1, 
    3, 85, 4, 39, 6, 79, 2, 74, 0, 94, 8, 91, 7, 71, 5, 32, 1, 79, 
    7, 56, 2, 35, 0, 88, 1, 59, 5, 29, 8, 79, 3, 36, 4, 79, 6, 18, 
    0, 83, 2,  1, 5, 88, 4, 48, 7,  3, 3, 42, 1, 38, 8, 11, 6, 73, 
    6,  2, 8, 61, 0, 64, 2, 76, 4, 91, 7, 35, 3, 46, 1, 40, 5, 51, 
    5, 67, 0, 57, 1, 88, 4,  1, 8, 39, 2, 46, 3,  6, 7, 86, 6, 70, 
    7, 77, 1, 76, 5, 65, 6, 86, 2,  3, 4, 66, 3, 40, 8, 79, 0, 90, 
    6, 97, 8, 17, 1, 20, 7, 24, 0, 41, 2, 81, 5, 62, 3, 47, 4, 61, 
    1, 12, 6, 35, 2, 13, 5, 85, 4, 31, 8, 38, 0, 53, 3, 13, 7, 18
  };
  const int q3094[] = {
    9, 9, // Number of jobs and machines
    6,  1, 5, 64, 0, 79, 2, 79, 3, 26, 1, 42, 4, 42, 7, 58, 8, 91, 
    3, 17, 1, 44, 8,  4, 5, 22, 2, 38, 6, 15, 0, 54, 7, 66, 4, 12, 
    2, 88, 1, 64, 5, 26, 3, 26, 4, 45, 6, 81, 0, 65, 8, 54, 7, 78, 
    5, 13, 4, 62, 0, 84, 3, 24, 8, 70, 7, 21, 2, 59, 6, 36, 1,  2, 
    1, 83, 6, 76, 2,  8, 3, 38, 8,  8, 5, 25, 4, 51, 7, 31, 0,  8, 
    2, 11, 4, 77, 5, 17, 1, 26, 3,  6, 0, 53, 8, 94, 6, 70, 7, 82, 
    5, 44, 7, 14, 2,  4, 6, 54, 8,  8, 1, 18, 4, 59, 3, 25, 0, 50, 
    3,  7, 1, 44, 5, 85, 0, 93, 4, 26, 7, 34, 2, 89, 8, 60, 6,  6, 
    3,  6, 5, 26, 6,  8, 4, 23, 0, 44, 2, 21, 7, 29, 1, 91, 8, 72
  };
  const int q3095[] = {
    9, 9, // Number of jobs and machines
    8,  8, 2, 66, 3, 57, 0, 61, 5, 52, 6, 28, 1, 93, 4, 25, 7, 48, 
    3, 25, 4, 76, 0, 10, 2, 87, 1,  5, 6, 26, 5,  8, 8,  8, 7, 27, 
    3, 24, 8, 90, 7, 39, 5, 12, 4, 85, 1, 24, 2, 79, 6, 64, 0, 99, 
    0, 17, 1, 52, 4, 10, 7,  1, 5, 67, 8, 41, 6,  8, 3, 83, 2, 55, 
    4, 43, 1, 37, 3, 18, 2, 30, 5, 59, 8, 87, 6, 93, 0, 35, 7, 65, 
    3, 83, 6, 37, 2, 21, 8, 68, 1, 23, 5, 15, 0, 58, 4, 18, 7, 58, 
    7, 41, 3, 61, 4, 78, 0, 76, 6, 53, 2, 79, 5, 51, 1, 23, 8, 67, 
    7, 41, 8, 49, 4, 31, 6, 34, 5, 16, 3, 66, 2, 13, 0, 26, 1, 48, 
    7, 26, 5, 68, 2, 14, 6, 27, 8, 46, 0, 81, 1,  5, 3, 61, 4, 69
  };
  const int q3096[] = {
    9, 9, // Number of jobs and machines
    4, 50, 0,  9, 3, 25, 5, 70, 1, 41, 8, 49, 6, 26, 7, 43, 2, 35, 
    3, 79, 5, 12, 0, 55, 6, 42, 2, 33, 7, 97, 4,  8, 1, 69, 8, 66, 
    2, 36, 7, 55, 1, 11, 6, 56, 8, 85, 3, 24, 5, 57, 0, 88, 4, 58, 
    5, 45, 8,  7, 4, 75, 0, 76, 1, 11, 3, 51, 2,  5, 7, 26, 6, 16, 
    0, 93, 2, 45, 8, 89, 4, 45, 6, 93, 7, 32, 5, 20, 1, 76, 3, 91, 
    6, 63, 1, 72, 2,  3, 0, 81, 3, 38, 5,  5, 8, 52, 4, 10, 7, 91, 
    3, 68, 6, 51, 7, 92, 8, 35, 0, 27, 2, 86, 1, 13, 4, 25, 5, 24, 
    2, 75, 5, 97, 0, 75, 3, 32, 4,  5, 7, 95, 6, 86, 1, 54, 8, 51, 
    4, 85, 6, 46, 8, 66, 7, 87, 1, 98, 2, 27, 5,  1, 3, 28, 0, 79
  };
  const int q3097[] = {
    9, 9, // Number of jobs and machines
    0,  3, 6, 52, 2, 31, 3, 16, 7, 16, 5, 38, 1, 20, 8, 17, 4, 19, 
    0,  8, 8, 21, 4, 86, 6, 13, 1,  7, 7, 54, 5, 26, 2, 36, 3, 77, 
    1, 44, 2, 46, 3, 10, 4, 32, 8, 17, 7, 97, 5, 56, 6, 90, 0, 87, 
    7, 67, 5, 13, 1, 31, 6, 96, 4, 60, 0, 89, 8, 17, 2, 17, 3, 72, 
    5, 37, 1, 91, 0, 65, 2, 48, 8, 60, 6, 15, 3, 52, 7, 34, 4, 53, 
    1, 43, 3, 57, 5, 93, 8,  9, 0, 54, 2, 90, 4, 83, 6,  4, 7, 85, 
    0,  3, 5,  7, 1, 94, 6, 60, 7, 13, 2, 88, 4, 72, 3, 12, 8, 98, 
    7,  4, 3, 79, 8, 64, 1, 44, 4, 18, 6, 29, 0, 53, 5, 49, 2,  1, 
    0, 18, 8, 91, 3, 18, 4, 80, 6, 85, 1, 61, 2, 21, 7,  5, 5, 84
  };
  const int q3098[] = {
    9, 9, // Number of jobs and machines
    8, 13, 5, 25, 6, 43, 2, 67, 3, 78, 4, 92, 1, 56, 7, 87, 0, 98, 
    7, 50, 1, 81, 2, 58, 5, 27, 3, 35, 6, 64, 0, 23, 4, 38, 8, 70, 
    0, 29, 8, 38, 7, 43, 3, 45, 6, 92, 5, 37, 2, 85, 1, 76, 4, 16, 
    7, 49, 8, 74, 4, 90, 1, 96, 3, 58, 6, 56, 2, 10, 5, 42, 0, 99, 
    8, 93, 5, 22, 2, 71, 0, 20, 6, 70, 3, 25, 4, 51, 1, 24, 7, 24, 
    5, 45, 8, 37, 3, 60, 7, 68, 1, 18, 6, 98, 0, 23, 2, 97, 4, 52, 
    7, 40, 2, 78, 4, 69, 0, 93, 6, 53, 1, 98, 5, 22, 8, 32, 3, 12, 
    1, 24, 5, 26, 8, 69, 2, 83, 4,  7, 0, 39, 7, 38, 6, 87, 3, 70, 
    7, 80, 6, 31, 1, 82, 3, 37, 2, 44, 8, 25, 5, 52, 0, 93, 4, 28
  };
  const int q3099[] = {
    9, 9, // Number of jobs and machines
    5,  9, 3, 27, 2, 99, 6, 10, 1, 51, 8, 31, 4, 85, 0, 95, 7, 20, 
    0, 71, 6, 70, 5, 99, 2, 91, 3, 38, 8, 77, 4, 15, 1, 64, 7, 76, 
    5, 25, 4, 33, 0, 32, 1, 55, 7, 70, 2, 95, 3, 25, 8, 82, 6, 28, 
    8, 61, 1,  3, 2, 27, 0, 35, 7, 58, 3, 18, 6, 49, 4, 70, 5, 76, 
    1,  3, 4, 56, 3, 59, 6, 63, 8, 48, 2, 22, 7,  2, 0, 65, 5, 92, 
    7, 28, 0, 47, 8, 34, 3, 52, 2, 10, 5, 62, 4, 76, 6, 81, 1, 29, 
    7, 24, 0,  6, 2, 40, 8, 72, 4, 79, 6, 73, 3, 58, 1, 85, 5, 98, 
    3, 22, 5, 95, 4, 83, 7, 92, 2, 92, 8, 16, 1, 38, 0, 39, 6, 51, 
    8, 27, 0, 60, 5, 77, 1, 58, 2, 88, 6, 60, 7, 88, 3, 65, 4, 90
  };
  const int q3100[] = {
    9, 9, // Number of jobs and machines
    6, 47, 3, 27, 8, 29, 5, 16, 0, 86, 7, 25, 4, 51, 2, 14, 1, 23, 
    6, 93, 5, 46, 2, 58, 1, 47, 7, 94, 0, 80, 3, 34, 4, 12, 8,  8, 
    8, 55, 3, 92, 0, 32, 1, 58, 5, 32, 7, 82, 2, 95, 4, 46, 6, 33, 
    7, 90, 4,  2, 6, 39, 8, 51, 2,  9, 3, 63, 1, 50, 5, 61, 0, 94, 
    6, 88, 5, 34, 4, 68, 0, 93, 2, 41, 1, 46, 8, 27, 7, 21, 3, 61, 
    6, 51, 0, 29, 8, 62, 2, 18, 5,  2, 1, 55, 7, 15, 3, 43, 4, 36, 
    0, 67, 7, 19, 4, 98, 5, 13, 1, 94, 2, 40, 3, 84, 6,  9, 8, 77, 
    4, 43, 8, 53, 5, 82, 0, 54, 1, 59, 3, 44, 6,  2, 2, 22, 7,  9, 
    2, 61, 4, 24, 6, 65, 5, 46, 3, 76, 0, 55, 7, 56, 1, 22, 8, 82
  };
  const int q3101[] = {
    9, 9, // Number of jobs and machines
    3, 69, 8, 30, 0, 18, 4, 68, 1, 85, 7, 52, 2, 67, 5,  8, 6, 68, 
    0, 88, 4, 52, 8, 17, 2,  3, 6, 46, 3, 40, 5, 64, 7, 99, 1, 55, 
    7, 45, 4,  2, 8, 96, 1, 64, 2,  8, 5, 35, 6, 34, 0, 30, 3, 78, 
    0,  2, 2, 10, 6, 78, 5, 56, 7, 52, 1, 45, 3, 81, 8, 28, 4, 18, 
    3, 51, 7, 76, 5,  6, 4, 24, 6, 69, 8, 58, 2, 64, 1, 22, 0, 25, 
    1, 89, 7, 92, 3,  7, 8, 89, 4, 58, 6, 47, 5, 98, 2, 31, 0, 90, 
    2, 63, 1, 70, 8, 68, 0, 90, 6, 63, 4, 32, 3, 20, 7, 90, 5, 28, 
    2, 49, 4, 84, 3, 69, 8, 75, 0, 29, 6, 90, 5, 34, 1, 10, 7, 44, 
    1, 11, 5, 93, 3, 62, 7, 70, 6, 70, 8, 80, 2,  2, 4, 29, 0, 86
  };
  const int q3102[] = {
    9, 9, // Number of jobs and machines
    3, 39, 8, 54, 7, 15, 1, 48, 4, 18, 2, 97, 0, 34, 6, 15, 5, 86, 
    6, 98, 7, 47, 3, 41, 0, 78, 4, 47, 2, 95, 8, 21, 5, 52, 1, 68, 
    7, 70, 4, 64, 8, 86, 0, 42, 6, 96, 3, 36, 1, 10, 2, 19, 5, 83, 
    1, 87, 3, 74, 4, 85, 2, 52, 0, 80, 8, 20, 7, 66, 6, 96, 5, 38, 
    4, 17, 7, 55, 1, 26, 8, 30, 2, 77, 5,  5, 6, 92, 0, 39, 3, 57, 
    6,  6, 7, 22, 8, 33, 2, 42, 5, 97, 0, 98, 1, 84, 3, 30, 4, 44, 
    5, 77, 7, 46, 2, 32, 6, 49, 0,  1, 4, 84, 1, 26, 3, 88, 8, 80, 
    6, 93, 8, 34, 2, 53, 0, 99, 7, 52, 4,  6, 1, 12, 3, 69, 5, 92, 
    0, 37, 3, 76, 8, 73, 1, 66, 2, 48, 6, 85, 7, 85, 4, 88, 5, 25
  };
  const int q3103[] = {
    9, 9, // Number of jobs and machines
    8, 49, 3, 76, 7, 58, 5, 53, 6, 49, 0,  8, 2, 41, 1, 80, 4, 89, 
    3, 40, 8, 49, 1, 61, 5, 95, 7, 29, 6, 33, 0, 52, 4, 80, 2, 10, 
    3, 36, 5, 36, 8, 65, 1, 60, 4, 13, 2,  4, 7, 45, 0, 98, 6, 73, 
    0, 37, 7, 23, 3, 22, 2, 60, 8, 85, 1, 93, 4, 38, 6,  9, 5,  5, 
    8, 86, 3, 12, 4, 68, 6, 85, 2, 64, 7, 65, 1, 51, 0, 89, 5, 52, 
    1, 83, 4, 14, 2, 42, 8, 61, 3, 75, 7, 77, 0, 32, 5, 76, 6, 17, 
    7, 10, 2, 37, 8, 13, 5, 67, 3, 21, 4,  2, 6, 59, 1, 79, 0, 61, 
    3, 73, 8, 31, 6, 74, 0, 39, 1, 51, 7, 76, 5,  9, 2, 96, 4, 66, 
    7,  9, 3, 19, 4, 57, 8, 56, 5, 60, 2, 68, 1,  9, 6, 13, 0, 25
  };
  const int q3104[] = {
    9, 9, // Number of jobs and machines
    8, 40, 5,  3, 3,  7, 4, 83, 2,  1, 0, 15, 7, 47, 6, 30, 1, 52, 
    1, 97, 4, 22, 7, 24, 2, 11, 6, 56, 3, 76, 5, 49, 8, 87, 0, 51, 
    0, 73, 7, 84, 3,  4, 4, 92, 8, 50, 1, 41, 6, 68, 5, 89, 2, 34, 
    5, 41, 7, 15, 6, 43, 4, 89, 3, 96, 0, 99, 1, 45, 2, 68, 8, 68, 
    7, 41, 1, 75, 6, 67, 8, 69, 5, 20, 2, 65, 0, 33, 3, 49, 4, 86, 
    4, 81, 5, 28, 2, 91, 6, 15, 0, 64, 7, 48, 1, 55, 8, 59, 3,  9, 
    8, 86, 1, 61, 4, 94, 2, 47, 0, 61, 7,  8, 5, 19, 3, 12, 6, 88, 
    1, 75, 2, 32, 8, 47, 0, 60, 3, 41, 7, 90, 5, 54, 6,  3, 4, 28, 
    4, 76, 0, 42, 6, 46, 3, 62, 1, 88, 8,  9, 2, 88, 5, 82, 7, 67
  };
  const int q3105[] = {
    9, 9, // Number of jobs and machines
    6, 98, 1, 10, 4,  2, 7, 24, 0, 77, 2, 59, 3, 68, 8, 94, 5, 24, 
    6, 69, 0, 80, 7, 32, 3, 37, 5, 83, 2,  9, 1, 95, 4, 66, 8, 47, 
    6,  7, 8, 30, 5, 68, 7, 16, 2, 72, 4, 76, 0, 47, 1, 98, 3, 55, 
    6, 13, 1, 29, 8, 97, 5, 73, 4, 33, 3, 58, 0, 94, 2, 96, 7, 21, 
    5,  6, 4, 66, 6, 26, 8, 29, 0, 23, 3, 31, 7, 73, 1, 87, 2, 64, 
    5, 75, 4, 47, 7, 14, 8,  7, 6, 95, 3, 34, 1,  8, 2, 74, 0, 25, 
    3, 18, 0, 71, 2, 68, 7, 35, 4, 26, 1, 77, 6, 33, 5, 78, 8, 15, 
    2, 52, 4,  2, 5,  8, 0, 35, 8, 53, 6, 68, 1, 21, 3, 49, 7, 50, 
    2, 11, 7, 75, 8, 73, 0, 28, 3, 45, 5, 11, 1, 29, 4, 78, 6, 44
  };
  const int q3106[] = {
    9, 9, // Number of jobs and machines
    3, 11, 5, 31, 6, 28, 4, 98, 7, 62, 1, 22, 0, 24, 2, 18, 8, 19, 
    7, 87, 5, 37, 8, 40, 2, 23, 4,  6, 3, 28, 6, 82, 0, 99, 1, 24, 
    5, 43, 0, 71, 6, 29, 8, 57, 3, 37, 1, 91, 2, 93, 7, 48, 4, 51, 
    4, 80, 6,  2, 2, 93, 5, 76, 0, 60, 8,  8, 7, 85, 3, 68, 1, 16, 
    3, 55, 8, 56, 5, 32, 2, 20, 4, 99, 6, 64, 0, 51, 7, 36, 1, 45, 
    8, 31, 1, 88, 2, 30, 3, 86, 0, 53, 6, 79, 7, 14, 5, 49, 4, 36, 
    2, 29, 7, 86, 1, 99, 6, 57, 3, 91, 4, 75, 0, 81, 5, 48, 8, 54, 
    4, 88, 0, 52, 8, 56, 5, 75, 1, 42, 7, 72, 2,  5, 6, 47, 3, 47, 
    7, 27, 0, 48, 8, 84, 6, 29, 1, 48, 5, 65, 3, 60, 4, 90, 2, 95
  };
  const int q3107[] = {
    9, 9, // Number of jobs and machines
    0, 43, 4, 19, 5, 69, 1, 56, 2, 24, 8, 46, 3, 93, 7,  7, 6, 72, 
    4, 75, 0, 67, 5, 16, 8, 42, 3, 79, 7, 41, 6, 44, 1, 67, 2, 39, 
    8, 59, 4, 51, 1, 70, 0, 25, 7, 40, 5, 44, 6, 30, 2,  2, 3, 91, 
    1, 84, 4,  3, 0, 68, 7, 43, 3, 19, 2, 42, 5, 36, 8, 13, 6, 40, 
    3, 29, 4, 16, 6, 11, 1, 56, 8, 12, 7, 33, 0, 89, 5, 19, 2, 37, 
    3, 41, 2, 17, 6, 86, 5, 60, 4, 33, 0, 49, 8, 19, 7, 67, 1, 86, 
    1, 75, 6, 73, 2, 72, 5,  3, 8, 69, 4, 24, 0, 57, 7, 63, 3, 65, 
    0, 51, 1, 84, 2, 85, 4, 32, 5, 37, 3, 60, 6, 82, 8, 34, 7, 69, 
    6, 67, 7, 86, 5, 30, 0, 29, 4, 43, 2,  7, 3,  5, 1, 57, 8, 51
  };
  const int q3108[] = {
    9, 9, // Number of jobs and machines
    0, 69, 7,  3, 3, 73, 1, 46, 8,  6, 6, 19, 2, 15, 4, 22, 5, 51, 
    0, 80, 3, 98, 8, 61, 2, 74, 4, 32, 1, 74, 7, 80, 5, 42, 6, 29, 
    1,  7, 5, 42, 4, 64, 8, 30, 2, 27, 6, 99, 3, 85, 7, 90, 0, 73, 
    1, 61, 6, 38, 5, 73, 2, 50, 3, 58, 8,  1, 7, 48, 0,  9, 4, 11, 
    8, 84, 1, 96, 4, 27, 2, 32, 0,  4, 3, 20, 5, 53, 6, 56, 7, 35, 
    1, 23, 6, 51, 4, 87, 0, 77, 2, 69, 5, 35, 3, 86, 8, 70, 7, 99, 
    8,  2, 6, 57, 7, 48, 5,  2, 1, 61, 0, 61, 4, 75, 2, 82, 3, 86, 
    5, 20, 8, 41, 4, 15, 0, 44, 2, 65, 3, 97, 6, 17, 1, 73, 7, 54, 
    8, 65, 5, 40, 6, 59, 0, 22, 3, 67, 4, 79, 7, 30, 1, 43, 2, 13
  };
  const int q3109[] = {
    9, 9, // Number of jobs and machines
    1, 35, 7, 30, 3, 64, 5, 63, 4, 40, 2, 11, 0, 57, 6, 81, 8, 60, 
    2, 20, 5, 32, 4, 17, 1, 84, 7, 73, 3, 72, 8, 47, 0, 12, 6, 25, 
    6, 73, 0, 51, 5,  4, 2, 59, 4, 29, 3, 22, 7, 50, 1, 58, 8, 94, 
    0, 23, 6, 58, 5, 78, 4, 87, 1, 84, 2, 91, 8, 34, 7, 57, 3, 31, 
    1, 91, 6,  2, 8, 11, 3, 55, 7, 45, 4, 48, 5, 69, 0, 91, 2, 70, 
    5, 46, 3, 88, 8,  6, 1, 62, 7, 36, 2, 24, 4, 60, 0, 40, 6, 59, 
    4, 68, 7, 54, 6, 13, 0, 88, 2, 96, 3, 42, 1, 95, 8, 94, 5, 76, 
    4, 39, 6, 84, 7, 49, 1, 59, 3, 38, 2, 94, 8, 10, 5, 52, 0, 73, 
    2, 20, 4, 28, 0, 34, 5, 75, 7, 90, 1, 83, 8, 37, 3,  2, 6, 31
  };
  const int q3110[] = {
    9, 9, // Number of jobs and machines
    8, 41, 1, 82, 0, 40, 4, 63, 2, 22, 7,  3, 3, 88, 5, 17, 6, 68, 
    0, 80, 5, 59, 8, 78, 7, 53, 3, 87, 1, 72, 6, 45, 2, 29, 4, 38, 
    5, 99, 7, 88, 8, 38, 4, 41, 3, 40, 2,  8, 1,  4, 0, 90, 6, 55, 
    8, 20, 3, 44, 7, 12, 1,  2, 2, 58, 6, 93, 0, 15, 5, 36, 4, 97, 
    1, 23, 7, 19, 6,  4, 2, 73, 5, 76, 3, 97, 8, 54, 4, 46, 0, 15, 
    1, 23, 8, 45, 5, 81, 0, 35, 4, 83, 2, 23, 7, 43, 3, 81, 6, 69, 
    6, 46, 4, 92, 1, 40, 8, 33, 0,  6, 7,  4, 3, 21, 5, 78, 2, 87, 
    2, 14, 3, 52, 8, 35, 5, 38, 6, 72, 4, 24, 7, 69, 0, 14, 1, 91, 
    5, 45, 6, 47, 1, 62, 2, 59, 3, 42, 0, 23, 4, 60, 8, 16, 7, 93
  };
  const int q3111[] = {
    9, 9, // Number of jobs and machines
    3, 56, 8, 26, 2, 32, 4, 22, 0, 59, 1,  8, 6, 90, 7, 82, 5, 28, 
    6, 44, 0, 62, 5, 23, 4, 19, 8, 56, 3,  5, 2, 22, 1,  9, 7, 82, 
    6, 95, 3, 65, 0, 96, 8, 24, 1, 72, 5,  2, 4, 82, 7, 51, 2, 78, 
    7, 82, 0, 51, 6, 77, 5, 95, 3, 37, 2, 88, 4, 40, 8, 73, 1, 94, 
    4,  4, 5, 79, 7, 96, 8,  2, 3, 98, 2, 76, 0,  1, 6, 63, 1, 39, 
    5, 58, 0, 13, 8, 90, 2, 18, 1, 45, 7, 20, 4, 52, 3, 20, 6, 83, 
    8, 73, 2, 40, 0,  4, 5, 45, 3, 21, 4, 76, 6, 96, 1, 26, 7, 89, 
    3, 28, 1, 12, 7, 21, 6,  1, 0, 88, 2,  7, 8, 52, 5, 58, 4,  9, 
    8, 12, 2, 84, 5, 41, 6, 45, 7, 85, 4, 58, 0, 29, 1, 82, 3, 50
  };
  const int q3112[] = {
    9, 9, // Number of jobs and machines
    6, 21, 4, 29, 0, 27, 5, 67, 2, 73, 7,  9, 1, 45, 8, 66, 3, 64, 
    2, 39, 4, 40, 1, 15, 7, 35, 5,  8, 8, 68, 3, 66, 6, 15, 0, 94, 
    1, 42, 4, 22, 6, 33, 7, 98, 8, 87, 0, 12, 2, 71, 3, 10, 5, 96, 
    2, 68, 1, 32, 3, 81, 4, 19, 5, 35, 7, 47, 0, 26, 6, 17, 8, 61, 
    1, 95, 3, 35, 8, 19, 0, 74, 7,  3, 2, 60, 5, 23, 4, 43, 6, 70, 
    5, 63, 4, 46, 6,  1, 0, 42, 3, 79, 2, 40, 7, 89, 1,  2, 8, 76, 
    0, 45, 7, 94, 3, 99, 2, 65, 5, 67, 4, 47, 6, 94, 8, 53, 1, 21, 
    8, 68, 5, 42, 7, 37, 4, 14, 6, 18, 0, 26, 2, 72, 1,  3, 3, 37, 
    6, 57, 2, 24, 5, 27, 4, 97, 3, 49, 1, 35, 7, 90, 0, 16, 8, 48
  };
  const int q3113[] = {
    9, 9, // Number of jobs and machines
    2, 82, 8, 34, 6, 69, 4, 95, 1, 45, 0, 19, 5, 14, 7, 39, 3, 45, 
    2, 28, 0, 50, 3, 45, 6, 31, 8, 10, 4, 64, 7, 97, 5, 63, 1, 16, 
    8, 89, 0, 68, 6, 70, 7, 32, 1, 12, 5, 93, 4, 26, 2,  1, 3, 63, 
    7, 58, 1, 92, 2,  4, 3, 90, 0, 96, 4, 25, 5, 27, 8, 40, 6, 10, 
    6, 42, 5, 24, 7, 58, 2, 65, 8, 23, 3, 32, 4, 81, 1,  3, 0, 99, 
    3, 71, 2, 64, 6, 46, 7, 34, 0, 69, 1, 93, 4, 64, 5, 89, 8, 36, 
    7, 36, 8, 29, 3, 43, 4, 20, 0, 88, 6, 68, 2, 35, 5, 92, 1, 47, 
    7, 96, 4, 35, 2, 53, 6, 70, 0, 47, 1, 30, 8, 30, 5,  9, 3, 91, 
    7, 17, 2, 69, 5, 55, 1, 19, 0, 97, 6, 11, 8, 51, 3, 56, 4, 81
  };
  const int q3114[] = {
    9, 9, // Number of jobs and machines
    3, 25, 4, 75, 0, 56, 7, 93, 1, 55, 5, 41, 6, 20, 8, 95, 2, 38, 
    6, 22, 5, 97, 3, 55, 1, 21, 7,  9, 4, 75, 2, 36, 0, 74, 8, 34, 
    2, 73, 4, 32, 3, 52, 7, 59, 8, 16, 6, 80, 1, 71, 5, 42, 0, 90, 
    7, 30, 5, 50, 8,  1, 4, 91, 0, 67, 6, 11, 1, 15, 3, 28, 2, 49, 
    1, 40, 7, 94, 2, 80, 5,  4, 6, 72, 4, 31, 8, 22, 0, 26, 3, 31, 
    1, 34, 7, 49, 6, 74, 0, 66, 5, 21, 2, 95, 4, 81, 3, 16, 8, 57, 
    8, 48, 2,  8, 6, 83, 0, 44, 4, 11, 5, 25, 3,  5, 1, 96, 7, 88, 
    7, 68, 4, 15, 8, 98, 2, 45, 0, 18, 1, 75, 5, 51, 6,  2, 3, 76, 
    1, 43, 5, 90, 2, 96, 8, 20, 7, 77, 0,  9, 3,  3, 6,  8, 4, 32
  };
  const int q3115[] = {
    9, 9, // Number of jobs and machines
    6, 25, 1, 26, 3, 31, 5, 94, 8,  2, 7, 30, 0, 16, 2, 82, 4, 46, 
    5, 64, 0, 50, 6, 50, 2,  1, 8, 56, 7, 20, 4, 54, 1, 20, 3, 83, 
    5, 54, 6, 69, 4, 72, 1, 28, 2, 26, 3, 52, 8, 20, 7, 11, 0, 41, 
    7, 75, 0, 87, 6, 31, 5, 36, 1,  9, 4, 66, 8, 80, 3, 15, 2, 20, 
    1, 81, 5, 67, 3, 35, 6, 19, 4, 66, 2, 95, 8, 95, 0,  7, 7, 52, 
    6, 40, 5, 79, 3, 47, 0, 59, 4,  8, 1,  2, 8, 95, 2, 83, 7, 78, 
    4, 57, 1, 16, 3,  9, 2, 41, 0, 21, 8, 54, 6, 17, 7, 98, 5, 66, 
    1, 57, 5, 98, 6, 88, 7, 41, 8, 69, 0, 29, 2, 73, 4, 38, 3, 74, 
    5, 46, 7, 42, 1,  3, 8, 24, 4, 96, 0, 30, 2, 48, 6, 10, 3,  2
  };
  const int q3116[] = {
    9, 9, // Number of jobs and machines
    6, 68, 3, 90, 2, 81, 1,  7, 0, 92, 8, 93, 7, 74, 4, 23, 5, 56, 
    3,  2, 1, 33, 0,  9, 2, 26, 5, 32, 4, 22, 7, 97, 6, 19, 8, 83, 
    1, 27, 2, 93, 7, 10, 8, 24, 4, 38, 5, 87, 6, 31, 3, 31, 0, 81, 
    3, 28, 4, 53, 6, 10, 8,  4, 7, 91, 2, 89, 0, 68, 5,  2, 1, 17, 
    4, 66, 5,  6, 3, 54, 6,  7, 2, 45, 7, 52, 8,  9, 0, 56, 1, 85, 
    1, 94, 5, 40, 3, 88, 7, 26, 8, 32, 6, 62, 4, 17, 0, 27, 2, 16, 
    1, 24, 4, 21, 3, 42, 5, 93, 0, 31, 8, 21, 7,  8, 2,  1, 6, 78, 
    3, 46, 5, 22, 6, 87, 2, 81, 8, 89, 4, 77, 7, 80, 0, 63, 1, 21, 
    1, 44, 5, 76, 4,  6, 6, 63, 0, 83, 2,  3, 3, 66, 7, 45, 8,  2
  };
  const int q3117[] = {
    9, 9, // Number of jobs and machines
    0, 63, 5, 86, 2, 61, 7, 39, 8, 65, 6, 17, 3, 47, 1, 59, 4, 25, 
    7, 17, 1, 55, 4, 40, 3, 26, 5, 80, 2, 60, 8, 47, 0, 54, 6, 22, 
    8, 97, 1, 64, 7, 42, 2, 42, 5,  3, 4, 51, 3, 92, 0, 71, 6, 15, 
    8, 22, 0, 44, 4, 40, 6, 25, 3, 83, 5, 78, 1, 98, 2, 90, 7, 55, 
    8, 99, 3, 14, 4, 97, 0, 76, 5, 63, 2, 45, 6, 25, 1,  4, 7, 40, 
    2, 15, 0, 15, 4,  2, 7, 49, 1,  6, 3, 33, 6, 92, 5, 10, 8, 93, 
    3, 84, 2, 86, 5, 66, 7, 40, 0, 51, 1, 19, 6, 62, 4, 72, 8, 44, 
    1, 23, 8, 26, 2, 22, 0, 86, 3, 53, 6, 94, 4, 93, 5, 75, 7, 69, 
    4, 14, 5, 69, 0, 30, 8, 10, 7, 56, 2, 40, 3,  5, 1, 44, 6, 99
  };
  const int q3118[] = {
    9, 9, // Number of jobs and machines
    0,  7, 1, 67, 4, 80, 7, 65, 6, 80, 3,  9, 5, 36, 8, 26, 2,  9, 
    7, 78, 6, 87, 4, 34, 1, 18, 8, 54, 0, 40, 5, 13, 3, 88, 2, 26, 
    6, 83, 8, 26, 3, 52, 2, 89, 0, 59, 1, 19, 4, 24, 5, 31, 7, 82, 
    0, 21, 6, 81, 2, 49, 1, 16, 4, 61, 7, 14, 5,  9, 3, 39, 8, 52, 
    2, 12, 8, 28, 6, 59, 0, 69, 5, 80, 3, 36, 1, 77, 7, 95, 4, 55, 
    1, 72, 4, 56, 5, 51, 8, 57, 2, 47, 6, 99, 3, 15, 0, 98, 7, 57, 
    0, 55, 1, 57, 7, 42, 8,  5, 4, 38, 5, 75, 6, 73, 3,  1, 2, 14, 
    1, 20, 0,  9, 4, 57, 6, 32, 3, 48, 7, 99, 5, 54, 2, 40, 8, 42, 
    2, 92, 6, 50, 0, 79, 7, 64, 5, 19, 4, 32, 3, 38, 1,  1, 8, 76
  };
  const int q3119[] = {
    9, 9, // Number of jobs and machines
    0, 75, 4, 61, 3, 61, 1, 34, 7, 54, 2, 62, 5,  7, 6, 72, 8, 65, 
    6, 28, 8, 26, 0, 27, 5, 53, 2, 49, 7, 84, 1, 96, 3, 29, 4, 29, 
    2,  3, 1, 22, 3, 78, 0, 75, 8,  9, 6,  2, 5, 81, 7,  3, 4, 90, 
    2, 40, 4, 26, 5, 11, 6, 39, 8, 13, 3, 42, 1, 47, 7, 44, 0,  1, 
    4, 70, 1, 72, 7, 21, 6, 89, 0, 27, 2, 76, 8, 20, 3, 60, 5, 12, 
    1, 96, 8, 57, 4, 59, 3, 90, 6, 70, 7, 65, 0, 49, 2, 31, 5, 42, 
    7, 78, 3, 21, 6,  8, 8, 39, 5, 27, 2,  3, 0, 10, 4, 35, 1, 54, 
    5, 94, 7, 75, 0, 13, 1, 67, 8, 91, 6, 96, 4,  1, 2, 61, 3, 49, 
    0, 88, 6, 36, 2, 60, 1, 32, 8, 23, 4, 92, 3, 16, 5, 44, 7, 54
  };
  const int q3120[] = {
    9, 9, // Number of jobs and machines
    3, 89, 6,  2, 4, 17, 7, 90, 5, 28, 0, 31, 8, 52, 2, 46, 1, 91, 
    2,  9, 5, 18, 1,  8, 4, 78, 0, 36, 7, 65, 3, 32, 6, 94, 8, 81, 
    7, 47, 4, 73, 6, 93, 2, 10, 0, 28, 3, 83, 8, 33, 5, 97, 1, 28, 
    4, 32, 8, 22, 3, 49, 1, 67, 5, 89, 6, 17, 2,  5, 7, 29, 0, 94, 
    7, 83, 1, 80, 4, 69, 2, 49, 5, 92, 6, 84, 0, 23, 8, 59, 3, 54, 
    1, 37, 7,  3, 5, 25, 4, 67, 2, 73, 6, 65, 0, 36, 3, 11, 8, 37, 
    7, 23, 8, 29, 3, 66, 6, 14, 0, 31, 1, 69, 4, 21, 5,  9, 2, 97, 
    8, 57, 4, 41, 6, 13, 1, 22, 5, 35, 7, 41, 0, 19, 3, 22, 2, 69, 
    4, 89, 8, 59, 0, 41, 3,  2, 1,  3, 2, 81, 6, 56, 5, 20, 7, 87
  };
  const int q3121[] = {
    9, 9, // Number of jobs and machines
    3, 93, 2, 84, 5, 51, 6,  9, 4,  6, 0, 55, 1,  6, 8,  1, 7, 66, 
    7, 95, 6, 51, 1, 29, 5, 16, 8, 97, 4, 38, 3,  2, 0,  6, 2, 90, 
    4, 23, 5, 38, 6, 24, 0, 73, 7,  6, 3, 29, 8,  8, 2, 95, 1,  9, 
    3, 17, 6, 16, 1, 81, 2,  1, 7, 39, 8, 49, 0, 48, 4, 91, 5, 93, 
    5, 11, 1, 12, 7,  7, 2, 65, 8, 24, 0, 35, 3,  8, 6, 11, 4,  3, 
    2, 68, 4, 42, 8, 65, 1, 23, 7, 72, 5, 56, 6, 40, 0, 97, 3, 88, 
    8, 67, 2, 37, 6, 78, 5, 66, 0, 28, 7, 57, 1, 26, 3, 76, 4, 98, 
    5, 76, 7, 68, 8, 47, 2, 52, 0, 70, 6, 74, 3, 88, 1, 86, 4, 79, 
    4, 88, 3, 58, 0, 49, 6,  2, 1, 53, 7, 45, 8, 99, 5, 56, 2, 17
  };
  const int q3122[] = {
    9, 9, // Number of jobs and machines
    6, 73, 5, 70, 8, 52, 7, 43, 4, 45, 0,  8, 3, 55, 2, 32, 1, 15, 
    1, 35, 3, 33, 4, 13, 7,  5, 5, 69, 8, 51, 0, 78, 2, 91, 6,  8, 
    6, 58, 3, 15, 0, 94, 8, 60, 5, 38, 4, 74, 2, 62, 7, 44, 1, 73, 
    4, 85, 5, 56, 8, 99, 2,  4, 6, 25, 0,  3, 7, 74, 1, 39, 3, 72, 
    7, 29, 8, 68, 5, 43, 1, 44, 2,  7, 4,  6, 6, 58, 3, 93, 0, 47, 
    5, 29, 0,  3, 2, 92, 1, 18, 6, 65, 8, 26, 7, 34, 4, 36, 3, 90, 
    7, 58, 2, 98, 4, 45, 5, 89, 3, 94, 0, 59, 8, 57, 1, 70, 6, 62, 
    5, 99, 3, 31, 6, 68, 0, 77, 7, 72, 8, 62, 4, 86, 1, 58, 2, 28, 
    3, 94, 0, 90, 5,  2, 1, 11, 4, 26, 8, 95, 2, 93, 6, 60, 7,  8
  };
  const int q3123[] = {
    9, 9, // Number of jobs and machines
    5, 50, 1, 82, 3, 75, 2, 44, 6, 64, 0, 29, 7, 29, 8, 91, 4, 31, 
    0, 98, 3, 62, 8, 29, 6, 71, 5, 49, 2, 14, 4,  4, 1, 23, 7, 89, 
    3, 34, 4,  6, 8, 46, 6, 89, 1, 90, 2, 38, 0, 54, 5, 37, 7, 57, 
    8, 28, 3, 53, 6, 21, 5, 63, 1, 97, 2, 93, 0, 24, 4, 83, 7, 88, 
    4, 30, 7, 24, 1, 20, 0, 14, 2, 29, 3, 36, 6, 72, 8, 13, 5,  7, 
    6, 50, 1, 71, 5, 51, 7, 49, 3, 79, 2, 13, 8, 53, 4, 36, 0, 14, 
    8, 48, 4, 21, 0, 78, 3,  8, 5, 90, 6, 70, 1, 50, 7, 25, 2,  6, 
    1, 15, 7, 42, 8, 15, 2, 22, 4, 14, 5, 14, 3, 55, 0,  3, 6, 80, 
    4, 29, 8, 90, 0,  5, 3, 22, 2, 19, 1, 50, 6, 87, 5, 29, 7, 98
  };
  const int q3124[] = {
    9, 9, // Number of jobs and machines
    0, 88, 5, 58, 7, 90, 1,  2, 4, 27, 3, 32, 8, 56, 2,  9, 6, 65, 
    5, 70, 3, 33, 0,  6, 1, 26, 4, 95, 2, 14, 8, 63, 7, 75, 6,  5, 
    8, 39, 3,  7, 4, 65, 1, 45, 7, 80, 2, 33, 0, 26, 5,  8, 6, 88, 
    1, 45, 6, 20, 8,  1, 0, 91, 7, 67, 3, 60, 5,  2, 4, 20, 2, 64, 
    6, 35, 1, 56, 2, 49, 5, 72, 8, 23, 3, 66, 0, 46, 7, 57, 4, 48, 
    4, 67, 6, 82, 2, 97, 1, 88, 3, 98, 5, 38, 7, 47, 8, 79, 0,  2, 
    6, 22, 2, 22, 0, 29, 8, 95, 7, 44, 5, 32, 1,  6, 4, 49, 3, 16, 
    3, 15, 2,  8, 1, 65, 0, 26, 8, 85, 5, 15, 6, 75, 4, 71, 7, 83, 
    5, 62, 4, 17, 6, 80, 7, 67, 3, 62, 1, 23, 0, 74, 8, 96, 2, 50
  };
  const int q3125[] = {
    9, 9, // Number of jobs and machines
    4,  2, 8, 73, 0, 12, 6, 10, 7, 17, 1, 17, 3,  8, 2, 15, 5, 55, 
    8, 98, 4,  2, 3, 78, 5, 31, 6, 87, 0, 15, 1, 39, 7, 58, 2, 12, 
    2, 77, 1, 51, 0,  6, 5,  2, 6, 79, 4, 91, 3, 38, 7, 97, 8, 57, 
    8,  2, 3, 82, 2, 55, 5, 70, 4, 53, 0, 51, 7, 65, 6, 24, 1, 82, 
    2, 94, 4, 92, 6, 80, 5, 73, 1, 18, 3, 38, 0, 96, 7, 42, 8, 11, 
    4, 20, 7,  1, 8, 78, 6, 84, 1, 82, 5, 59, 0, 39, 2, 74, 3, 53, 
    1, 80, 7, 11, 6, 98, 8, 55, 2, 97, 4,  6, 3, 22, 0, 28, 5, 67, 
    0, 99, 3, 70, 7, 97, 8, 67, 6, 24, 5,  4, 2, 23, 1, 80, 4, 31, 
    4,  1, 3, 74, 5, 49, 0, 12, 2, 56, 8, 33, 7, 20, 6, 86, 1, 30
  };
  const int q3126[] = {
    9, 9, // Number of jobs and machines
    5, 63, 0, 21, 8, 21, 3, 77, 2, 92, 7,  5, 6, 63, 1, 18, 4, 83, 
    0, 10, 1, 66, 2, 13, 7, 49, 3, 13, 5, 53, 8, 91, 6, 20, 4, 53, 
    0, 17, 7,  6, 2, 86, 1, 13, 6, 26, 3, 58, 5, 17, 4, 45, 8, 31, 
    4, 90, 7,  6, 3, 18, 2, 15, 6, 81, 8, 81, 0, 42, 5, 14, 1, 32, 
    5, 20, 0, 82, 4, 89, 1, 34, 6, 31, 7, 94, 2, 75, 8, 24, 3, 58, 
    2, 13, 7, 68, 6, 88, 3, 80, 8, 10, 4,  9, 1, 55, 5, 47, 0,  4, 
    0, 17, 7, 88, 1, 14, 6, 64, 4, 18, 8, 54, 3, 33, 5, 29, 2, 35, 
    4, 63, 6, 36, 0, 26, 8, 92, 2, 61, 7, 55, 1, 68, 3, 88, 5, 67, 
    7, 67, 5, 96, 4, 79, 8, 40, 6, 53, 0, 11, 3, 52, 2, 20, 1, 88
  };
  const int q3127[] = {
    9, 9, // Number of jobs and machines
    8, 64, 1, 60, 2, 75, 7, 26, 0, 48, 3, 84, 4, 77, 5, 73, 6, 72, 
    4, 69, 7, 77, 2, 62, 6, 56, 3, 17, 5, 72, 1, 14, 8, 71, 0, 37, 
    0, 52, 8, 61, 2, 33, 5, 99, 3, 10, 6, 44, 7, 49, 1,  3, 4, 62, 
    5, 93, 6, 82, 1, 45, 8, 95, 2, 58, 3, 80, 0, 18, 4, 29, 7, 54, 
    4, 58, 2, 76, 6, 53, 8, 68, 7,  7, 3, 16, 0, 45, 1, 84, 5, 42, 
    8, 27, 7, 10, 6, 49, 1, 49, 3, 36, 4, 75, 2,  2, 0, 39, 5, 36, 
    2, 87, 1, 73, 8, 91, 6, 26, 0,  7, 4, 17, 3, 92, 7, 45, 5, 69, 
    1, 66, 2,  8, 4, 29, 0, 92, 6, 32, 7,  1, 3, 14, 8,  5, 5, 67, 
    8, 12, 3, 13, 7, 11, 0,  4, 5, 63, 6, 23, 4, 26, 1, 38, 2, 80
  };
  const int q3128[] = {
    9, 9, // Number of jobs and machines
    2, 57, 5, 22, 6, 41, 1,  9, 7, 38, 3, 59, 0, 78, 4, 90, 8, 22, 
    3, 26, 7, 58, 5, 61, 4, 38, 1, 72, 0, 92, 2, 93, 6, 79, 8, 76, 
    1, 28, 7, 49, 5, 16, 4, 18, 0, 74, 2, 98, 8, 17, 3, 58, 6, 57, 
    5, 11, 8, 36, 0, 38, 4, 60, 1, 72, 3, 22, 2, 83, 7, 37, 6, 49, 
    6, 21, 5, 50, 3, 82, 8, 12, 2, 84, 0, 89, 7,  1, 1, 18, 4,  5, 
    4, 92, 0, 67, 1,  8, 2, 86, 7, 39, 3, 61, 6, 35, 8, 16, 5, 37, 
    4, 19, 2, 11, 0,  3, 7, 35, 3, 42, 8, 43, 5, 19, 6, 92, 1, 82, 
    5, 76, 2, 85, 8, 33, 1,  7, 6,  4, 0, 30, 7, 42, 4, 13, 3, 63, 
    4, 61, 8, 93, 1, 88, 5, 84, 2, 48, 7, 13, 6, 91, 3, 80, 0, 19
  };
  const int q3129[] = {
    9, 9, // Number of jobs and machines
    2, 78, 7, 46, 4, 62, 3, 51, 5, 86, 1, 43, 0, 46, 6, 49, 8,  7, 
    6, 58, 8, 22, 1, 92, 0, 90, 2,  9, 7, 18, 4, 19, 3, 31, 5, 56, 
    8, 72, 5, 12, 7, 76, 3, 21, 0, 29, 4,  3, 6, 44, 2, 12, 1, 13, 
    2, 64, 7, 75, 5, 62, 4, 73, 8, 91, 6, 33, 3, 26, 1, 67, 0, 45, 
    8, 63, 7, 27, 0, 76, 3, 67, 6, 55, 1, 32, 4, 98, 2,  6, 5, 54, 
    5, 92, 8, 78, 0, 26, 7, 12, 1, 30, 6, 72, 2, 47, 3, 86, 4, 17, 
    6,  7, 1, 43, 3, 81, 7, 69, 4,  6, 0, 64, 2, 44, 5, 88, 8, 58, 
    7, 57, 4, 65, 8, 87, 3, 99, 1,  6, 5, 75, 6, 89, 0, 98, 2, 47, 
    7, 31, 0,  9, 2, 88, 8,  8, 1, 41, 4, 95, 5, 47, 6, 13, 3, 29
  };
  const int q3130[] = {
    9, 9, // Number of jobs and machines
    4, 99, 1, 84, 6, 45, 0, 88, 3, 69, 8, 69, 2, 14, 5, 23, 7, 51, 
    1, 82, 7,  5, 5, 61, 4, 86, 6, 98, 0, 86, 8, 74, 3,  1, 2, 67, 
    5, 41, 0, 90, 3, 42, 2, 22, 7, 70, 8,  3, 6, 50, 4, 42, 1, 70, 
    4, 38, 7, 15, 8, 43, 1, 96, 6, 63, 2, 22, 3, 21, 0, 15, 5, 40, 
    3, 16, 5, 96, 7, 23, 6, 10, 0,  5, 1,  5, 2, 70, 8, 68, 4, 69, 
    5, 61, 1,  7, 6, 82, 8, 80, 7, 33, 3,  6, 2, 25, 0, 45, 4, 80, 
    5, 37, 6, 54, 4, 64, 1, 68, 8, 35, 7, 23, 0, 65, 3, 65, 2, 13, 
    8, 89, 6, 54, 2, 21, 5, 15, 4,  7, 7,  1, 3, 15, 0, 84, 1, 83, 
    6, 60, 4,  9, 5, 14, 8,  5, 2, 63, 3, 21, 1, 99, 7, 95, 0, 31
  };
  const int q3131[] = {
    9, 9, // Number of jobs and machines
    7, 26, 6, 52, 3, 66, 0, 50, 1, 51, 5, 21, 8, 89, 2, 45, 4, 97, 
    3, 27, 6, 23, 0, 39, 1, 95, 5, 65, 8, 31, 4, 42, 7, 58, 2, 62, 
    1, 72, 0, 56, 3, 72, 8, 71, 5, 35, 2, 59, 7, 82, 6, 17, 4, 33, 
    6, 95, 8, 78, 2, 31, 3, 98, 7,  5, 1, 19, 0, 89, 5, 57, 4, 44, 
    6, 46, 0, 32, 8, 12, 3, 53, 5, 57, 4, 84, 2, 19, 1,  2, 7, 23, 
    1, 74, 4,  7, 3, 34, 5, 95, 2, 50, 0, 61, 7, 54, 6, 44, 8, 44, 
    6, 24, 4, 25, 8, 94, 3, 52, 0, 86, 1, 20, 7, 38, 2, 16, 5, 73, 
    0, 52, 1, 49, 6, 67, 2, 42, 8, 55, 4, 39, 7, 78, 3, 42, 5, 10, 
    0, 98, 5, 83, 8, 50, 2, 47, 6, 18, 4, 94, 1, 79, 3, 86, 7, 54
  };
  const int q3132[] = {
    9, 9, // Number of jobs and machines
    0, 61, 7,  7, 2, 77, 1, 68, 5, 85, 6, 73, 3, 65, 4, 86, 8, 58, 
    1, 45, 2, 94, 8, 26, 0, 64, 5,  9, 6, 50, 7, 78, 3, 43, 4,  5, 
    2, 80, 8, 42, 7, 56, 1, 91, 6, 29, 0, 69, 5, 54, 4,  2, 3, 95, 
    3, 79, 6, 84, 8, 38, 2,  5, 1, 52, 5, 42, 4, 62, 7, 39, 0, 42, 
    4, 51, 3, 20, 5, 49, 8, 31, 1,  4, 7, 30, 2, 59, 0, 45, 6, 57, 
    8,  5, 3, 31, 6, 61, 4, 85, 1, 86, 5, 24, 0, 74, 2, 48, 7, 23, 
    8, 46, 4, 26, 3, 80, 5, 49, 0, 58, 1, 94, 2,  6, 6,  8, 7,  6, 
    6, 61, 1, 23, 4, 75, 0, 67, 7, 79, 3, 71, 5, 79, 2,  5, 8, 55, 
    8, 86, 6, 16, 7, 99, 1, 17, 0,  5, 5, 11, 3, 28, 4, 18, 2, 58
  };
  const int q3133[] = {
    9, 9, // Number of jobs and machines
    4, 87, 6,  8, 3, 45, 8, 39, 5, 36, 2, 61, 1, 48, 0, 86, 7,  4, 
    5, 57, 2, 97, 8, 99, 0, 56, 4, 81, 1, 22, 6, 20, 7,  7, 3, 37, 
    4,  5, 0, 89, 3, 96, 6, 59, 1, 99, 2, 74, 7, 93, 5, 15, 8, 67, 
    8, 24, 6, 17, 4, 58, 7, 40, 1, 50, 5,  5, 3, 63, 0, 32, 2, 27, 
    4, 33, 7, 40, 8, 46, 3, 54, 0, 61, 5,  5, 6, 75, 2, 84, 1, 63, 
    4, 31, 8, 80, 5, 53, 1, 61, 3, 31, 0,  6, 7, 58, 6,  7, 2,  3, 
    6, 94, 8, 12, 1, 66, 7, 32, 4, 73, 5, 21, 3,  2, 2, 77, 0, 79, 
    2, 98, 0, 10, 3, 61, 1, 38, 5, 54, 8,  1, 6, 50, 4,  1, 7, 82, 
    4, 65, 8, 67, 6,  5, 2, 41, 7, 52, 1, 42, 3, 73, 5,  9, 0, 52
  };
  const int q3134[] = {
    9, 9, // Number of jobs and machines
    4, 93, 3, 54, 7, 14, 6,  4, 1, 63, 5, 65, 0, 57, 2, 17, 8, 97, 
    7, 25, 8,  2, 4, 20, 2,  9, 0, 95, 5,  6, 1, 12, 3, 47, 6, 53, 
    4, 12, 7, 32, 8, 43, 3, 10, 2, 33, 6, 40, 5, 34, 0, 76, 1, 84, 
    0, 70, 6, 33, 2, 50, 4, 95, 1, 41, 5, 69, 3, 65, 7, 20, 8, 90, 
    8,  7, 1, 84, 4, 75, 5, 88, 7, 34, 2, 37, 0, 11, 3, 66, 6, 61, 
    3, 12, 7, 95, 5, 46, 0,  7, 6, 34, 1, 91, 8, 39, 4, 84, 2, 60, 
    2, 42, 6, 90, 3, 65, 8, 48, 7, 65, 1, 26, 4, 15, 0, 57, 5, 29, 
    8, 70, 2, 15, 1, 10, 3, 16, 6, 74, 5, 48, 7,  3, 0, 78, 4, 63, 
    3, 51, 2, 53, 7, 31, 1, 54, 6, 19, 5,  5, 8, 28, 4, 33, 0, 42
  };
  const int q3135[] = {
    9, 9, // Number of jobs and machines
    1,  7, 4, 97, 0, 95, 3, 88, 2, 73, 6, 90, 8, 94, 5, 88, 7, 17, 
    4, 11, 1, 58, 6, 75, 7, 43, 5, 75, 2, 33, 3, 91, 0, 27, 8,  8, 
    5, 19, 4, 31, 7, 63, 8, 97, 0, 57, 2, 41, 6, 83, 3, 56, 1,  8, 
    4,  3, 5,  6, 7, 33, 8, 38, 6, 64, 0, 48, 2, 98, 3, 51, 1,  9, 
    5, 91, 3, 35, 4, 77, 6, 32, 2, 83, 1, 85, 0, 32, 7, 64, 8, 42, 
    2, 82, 3, 80, 4, 61, 0, 31, 5, 95, 7, 47, 1, 81, 6, 87, 8, 11, 
    0, 48, 2,  2, 6, 87, 4, 36, 1, 32, 5, 32, 8, 17, 7, 51, 3, 35, 
    4, 37, 3, 42, 6, 24, 0, 30, 1, 51, 7, 23, 8, 39, 5, 91, 2, 58, 
    7, 98, 6, 18, 1, 13, 0, 79, 2, 52, 3, 71, 8, 64, 5, 58, 4, 75
  };
  const int q3136[] = {
    9, 9, // Number of jobs and machines
    0, 75, 4, 13, 3, 54, 6, 69, 2,  8, 1, 98, 5, 70, 7, 35, 8, 87, 
    3, 99, 8, 80, 0,  3, 2,  9, 6, 23, 1, 95, 5, 49, 4, 97, 7,  6, 
    3, 16, 0, 80, 6, 86, 2, 89, 5, 84, 4, 12, 8, 11, 1, 72, 7, 42, 
    5, 83, 0, 42, 4, 16, 1, 25, 8, 28, 3, 52, 6, 46, 7, 71, 2, 14, 
    1, 90, 7, 51, 2, 88, 6, 79, 0, 27, 3, 10, 8, 89, 5, 45, 4, 14, 
    6, 62, 4, 73, 8, 43, 3, 29, 0, 28, 5, 92, 7, 25, 2,  4, 1, 72, 
    0, 38, 4, 44, 3, 24, 5, 89, 2, 77, 6, 23, 1, 22, 7, 52, 8, 31, 
    3, 46, 7, 16, 1, 54, 5, 58, 4, 62, 2, 79, 6, 18, 0,  4, 8, 41, 
    1, 36, 4, 82, 8, 64, 3, 52, 7, 89, 5, 19, 2, 47, 6, 71, 0, 79
  };
  const int q3137[] = {
    9, 9, // Number of jobs and machines
    4, 17, 2, 16, 5, 56, 8, 86, 0, 50, 6, 24, 3, 31, 1, 79, 7, 64, 
    0, 52, 5, 82, 3, 79, 7, 80, 4, 77, 2, 29, 1, 47, 6, 15, 8, 35, 
    2, 94, 4, 12, 7, 92, 3, 52, 0, 90, 1, 39, 6, 44, 5, 99, 8, 11, 
    1, 34, 6, 45, 7, 13, 4, 68, 8, 71, 2, 56, 3, 80, 0, 15, 5, 15, 
    8, 78, 4, 95, 7, 33, 5, 56, 6, 68, 0, 29, 1, 42, 3, 32, 2, 89, 
    4, 57, 3, 12, 6, 41, 5, 38, 0, 15, 7, 57, 1, 42, 2, 97, 8, 81, 
    6, 70, 8, 13, 2, 81, 7, 22, 5,  1, 3, 84, 0, 21, 4, 22, 1, 17, 
    7, 91, 5, 31, 8, 16, 2, 83, 0, 56, 1, 84, 4, 62, 6, 44, 3, 28, 
    0, 71, 7, 51, 3, 46, 4, 75, 1, 87, 6, 42, 2, 82, 5, 13, 8, 38
  };
  const int q3138[] = {
    9, 9, // Number of jobs and machines
    6, 20, 7, 15, 3, 96, 2, 93, 8, 83, 1, 54, 5, 27, 4, 27, 0, 62, 
    8,  4, 2, 26, 7, 66, 4, 87, 0, 35, 6, 33, 5, 14, 3,  1, 1, 13, 
    8, 49, 2, 68, 6, 31, 0, 53, 7, 72, 4, 24, 5, 40, 1, 24, 3, 20, 
    3, 42, 1, 74, 5, 75, 0, 70, 6, 43, 4, 18, 7, 92, 2, 39, 8, 10, 
    5, 44, 3, 94, 0, 57, 1, 33, 4, 68, 6, 64, 8, 37, 2,  4, 7, 55, 
    4, 34, 5, 38, 7, 78, 2, 99, 1, 47, 8, 84, 6,  8, 3, 99, 0, 94, 
    8, 35, 5, 57, 3, 56, 1, 82, 7, 32, 0, 32, 2, 47, 4,  3, 6, 46, 
    3, 94, 4, 63, 7, 23, 0, 46, 6, 96, 8, 18, 5, 96, 1, 41, 2, 59, 
    5, 68, 1, 65, 0, 95, 4, 84, 8, 24, 6, 82, 3, 97, 2, 75, 7, 85
  };
  const int q3139[] = {
    9, 9, // Number of jobs and machines
    8, 80, 3, 12, 5, 53, 1, 35, 6, 13, 4, 10, 7, 32, 0, 65, 2, 56, 
    0, 63, 3, 73, 1, 73, 7, 75, 2, 48, 5, 96, 4, 76, 6, 85, 8, 36, 
    0, 38, 7, 90, 6, 58, 1, 30, 3, 67, 5, 18, 4, 11, 8, 87, 2, 63, 
    3, 88, 1, 61, 4, 86, 5, 64, 2, 64, 0, 54, 8, 51, 7, 91, 6, 36, 
    3, 70, 8, 55, 1, 28, 7, 36, 2, 22, 0, 69, 4,  2, 6, 43, 5, 12, 
    5, 59, 3, 12, 8, 80, 7, 94, 0, 82, 2, 19, 6,  6, 1, 54, 4, 44, 
    2, 34, 4, 62, 6, 48, 8, 53, 1, 61, 7, 90, 3, 18, 5, 49, 0, 89, 
    3, 63, 8, 89, 5, 78, 4, 18, 0, 45, 6, 96, 7, 90, 2, 80, 1, 21, 
    8,  3, 7, 64, 5, 72, 2, 54, 4, 99, 0, 32, 6, 81, 1, 75, 3, 50
  };
  const int q3140[] = {
    9, 9, // Number of jobs and machines
    4, 33, 6, 35, 7, 73, 1, 55, 8, 59, 5, 77, 3, 23, 2, 69, 0, 85, 
    0, 34, 7, 69, 5, 59, 2, 88, 3, 41, 8,  2, 4, 99, 1, 41, 6, 48, 
    4, 91, 6,  5, 5, 21, 8, 91, 3, 52, 2, 70, 7,  6, 0, 91, 1, 35, 
    5, 56, 3,  4, 4, 41, 8, 91, 1, 91, 6,  2, 2,  1, 7, 55, 0, 11, 
    1, 25, 2, 52, 4, 55, 8, 34, 5, 65, 6, 38, 0,  4, 3,  6, 7, 87, 
    6, 80, 4, 99, 8, 81, 2, 51, 0, 61, 3, 63, 1, 14, 7, 34, 5, 46, 
    7, 79, 2, 88, 1, 58, 3, 87, 5, 21, 0, 64, 4, 72, 6, 79, 8, 70, 
    7, 82, 8, 24, 3, 47, 1, 77, 2, 32, 4, 56, 0, 69, 5, 96, 6, 30, 
    7, 49, 5, 98, 0, 38, 4, 56, 8, 66, 1, 44, 2,  9, 3, 80, 6,  8
  };
  const int q3141[] = {
    9, 9, // Number of jobs and machines
    0, 53, 2, 78, 3, 27, 1, 10, 6, 21, 7, 74, 5, 12, 4, 48, 8, 24, 
    0, 76, 1, 16, 3, 33, 5, 51, 8, 37, 4, 63, 2, 57, 6, 32, 7, 90, 
    5, 10, 4, 88, 7, 78, 1, 48, 2, 62, 3, 13, 6, 89, 8, 87, 0, 59, 
    1,  6, 2, 53, 8,  9, 5, 48, 7, 64, 4, 88, 6, 80, 3, 63, 0, 27, 
    0, 40, 7, 13, 6, 49, 3, 50, 8, 72, 2, 56, 4, 33, 1, 19, 5, 83, 
    1, 35, 5, 51, 8, 39, 2, 94, 4, 54, 6, 10, 3, 11, 7, 44, 0, 66, 
    3,  5, 5,  2, 6, 41, 7, 13, 0, 11, 4, 97, 2, 22, 8, 49, 1, 86, 
    5,  2, 6, 75, 8, 86, 2, 37, 1, 18, 3, 71, 4,  2, 0, 27, 7, 92, 
    6, 30, 8, 44, 7, 92, 3, 43, 0, 82, 4, 67, 5, 89, 2, 25, 1,  5
  };
  const int q3142[] = {
    9, 9, // Number of jobs and machines
    2, 31, 0, 36, 5, 62, 4, 10, 1, 42, 3, 28, 8, 91, 7, 10, 6,  2, 
    1, 41, 6, 78, 4, 89, 7, 71, 8, 25, 2, 32, 3, 54, 0, 92, 5, 63, 
    2, 36, 6, 33, 7, 37, 3, 33, 5, 31, 8, 28, 1, 26, 0, 98, 4, 85, 
    3, 26, 5, 75, 7, 12, 1, 33, 8, 13, 6,  6, 4, 57, 0, 41, 2,  1, 
    2, 30, 6, 16, 7, 72, 0, 53, 1, 96, 3, 85, 4, 92, 5, 15, 8, 66, 
    0,  1, 1, 63, 6, 72, 2, 74, 4, 20, 7, 91, 5, 17, 8, 43, 3, 32, 
    4, 92, 6, 32, 1, 98, 7, 71, 3, 65, 0, 95, 2, 82, 8, 59, 5, 70, 
    0, 54, 2, 81, 6, 69, 8, 60, 3, 58, 4, 55, 5, 21, 1, 55, 7,  5, 
    7, 87, 8, 57, 4, 76, 3, 20, 2, 53, 1, 87, 5, 94, 6, 70, 0, 28
  };
  const int q3143[] = {
    9, 9, // Number of jobs and machines
    7, 66, 2, 11, 3, 91, 1,  8, 8, 30, 6, 13, 4,  5, 0, 48, 5, 88, 
    2, 96, 3, 79, 6, 78, 0, 48, 5, 65, 8, 55, 7, 56, 1, 51, 4, 70, 
    5,  1, 8, 53, 6,  8, 4, 23, 2, 25, 3, 11, 7, 26, 1, 32, 0, 85, 
    8, 27, 5, 50, 0, 88, 6, 25, 1, 18, 4, 15, 7, 50, 3,  4, 2, 91, 
    7, 30, 8, 96, 6,  5, 0, 24, 4, 48, 2, 73, 3, 40, 1, 81, 5,  1, 
    2, 84, 4, 73, 6, 42, 8, 67, 0, 29, 3, 91, 5, 87, 1, 63, 7, 46, 
    7, 76, 8, 22, 5, 86, 3, 18, 1, 88, 0, 62, 2, 17, 4, 73, 6, 57, 
    4, 80, 7, 17, 1, 10, 3, 14, 5, 90, 2, 27, 6, 81, 0, 94, 8,  7, 
    0, 48, 6, 77, 3,  9, 2, 28, 8, 96, 5, 80, 4, 80, 1, 82, 7, 45
  };
  const int q3144[] = {
    9, 9, // Number of jobs and machines
    3, 18, 4, 15, 2,  8, 1, 22, 8,  1, 5, 43, 6, 46, 7, 37, 0, 70, 
    1, 57, 8, 52, 2, 32, 7, 23, 6, 14, 4, 59, 5, 44, 0, 13, 3, 43, 
    8, 78, 3,  6, 5, 78, 2, 45, 0, 56, 4, 87, 1, 46, 7, 79, 6, 41, 
    4, 22, 7, 53, 2, 95, 0, 28, 3, 33, 1, 53, 5, 87, 6, 73, 8, 76, 
    1, 31, 2, 44, 5, 34, 7, 36, 3, 25, 6, 64, 4, 83, 8, 67, 0, 56, 
    0, 79, 2,  6, 8, 35, 4, 70, 7, 15, 3, 34, 5, 38, 6, 94, 1, 20, 
    5, 37, 3, 49, 1, 32, 6, 84, 8, 93, 7, 17, 0, 77, 4, 72, 2, 22, 
    6, 18, 5, 92, 2, 66, 4, 89, 7, 64, 3, 32, 1, 77, 8, 20, 0, 16, 
    8, 88, 6, 49, 7, 64, 2, 12, 3, 72, 1, 97, 0,  7, 4, 79, 5, 87
  };
  const int q3145[] = {
    9, 9, // Number of jobs and machines
    8, 39, 7, 32, 0, 42, 2, 12, 1, 24, 5, 73, 6, 65, 4, 22, 3, 20, 
    6, 32, 4, 58, 3, 20, 1, 47, 5,  1, 8, 89, 0, 17, 2, 31, 7, 59, 
    1, 15, 5, 59, 6, 31, 2, 92, 4, 47, 7, 80, 3, 79, 8, 63, 0, 50, 
    5, 77, 0, 18, 7, 39, 4,  3, 8, 99, 1, 52, 2, 71, 6, 28, 3, 57, 
    5, 84, 1, 98, 2, 76, 4, 45, 7,  7, 3, 67, 8,  1, 0, 66, 6, 69, 
    6, 76, 5, 91, 8, 43, 2, 66, 7, 95, 1, 47, 0, 51, 3, 53, 4, 57, 
    4, 37, 8, 18, 7,  9, 6, 93, 0, 81, 5, 62, 2, 45, 3, 36, 1,  6, 
    5, 97, 4, 85, 1,  7, 0, 78, 7,  4, 3, 70, 6, 74, 2, 40, 8, 91, 
    2, 82, 3, 96, 5, 18, 6, 50, 1, 58, 4, 86, 0, 88, 7, 37, 8, 93
  };
  const int q3146[] = {
    9, 9, // Number of jobs and machines
    0, 61, 1, 93, 6, 81, 4, 87, 3, 45, 8, 82, 5, 45, 7, 27, 2,  3, 
    8, 79, 2, 26, 7, 25, 1, 87, 6, 18, 4, 46, 5, 27, 3, 37, 0, 34, 
    4, 45, 1, 39, 5, 30, 0, 57, 8, 67, 3,  8, 6, 85, 2,  9, 7, 99, 
    5, 76, 1, 46, 2, 45, 8, 12, 4, 37, 3, 17, 7, 59, 0, 45, 6,  9, 
    4, 58, 0, 64, 6, 72, 1, 11, 2, 19, 5, 34, 3, 48, 7, 54, 8, 51, 
    6, 80, 1, 47, 5, 22, 4, 12, 3, 11, 2, 66, 0, 93, 7, 21, 8, 12, 
    3, 89, 8, 31, 0,  7, 7, 35, 4, 90, 2, 90, 6, 63, 1, 19, 5, 54, 
    3,  5, 6, 38, 8, 92, 7, 33, 5, 23, 1,  5, 2, 14, 0, 60, 4, 13, 
    2, 86, 0, 58, 7, 46, 6, 53, 1, 15, 4, 40, 3, 69, 5, 25, 8, 41
  };
  const int q3147[] = {
    9, 9, // Number of jobs and machines
    5, 67, 4, 61, 2, 47, 7,  8, 3, 52, 8, 17, 6, 32, 1, 62, 0, 42, 
    8, 31, 4, 28, 6, 21, 2, 59, 7, 69, 5,  5, 3, 32, 1, 13, 0, 86, 
    4, 76, 8,  6, 0, 47, 5, 75, 1, 21, 2, 25, 6, 69, 7,  6, 3, 85, 
    8, 78, 2, 54, 1, 24, 4, 28, 5, 66, 7, 66, 6,  7, 3, 18, 0, 21, 
    3, 68, 7, 73, 4, 90, 8, 75, 1, 96, 5, 74, 2, 51, 0, 14, 6, 93, 
    8,  9, 0, 16, 1, 12, 7, 74, 3, 63, 5,  6, 2, 99, 4, 90, 6, 40, 
    7, 74, 1,  4, 8, 48, 4, 13, 5, 10, 2, 65, 3, 42, 6,  9, 0, 96, 
    1,  7, 4, 22, 7,  3, 0, 19, 2, 85, 3, 55, 5, 98, 8, 75, 6, 49, 
    1, 83, 3, 95, 5, 30, 7, 52, 8, 51, 6, 89, 0, 55, 4, 28, 2, 72
  };
  const int q3148[] = {
    9, 9, // Number of jobs and machines
    6, 50, 5, 62, 0, 29, 7, 34, 4, 67, 1, 43, 8, 19, 3, 81, 2, 74, 
    1, 36, 2, 29, 3, 71, 4,  6, 6, 49, 8, 30, 5, 25, 0, 67, 7, 67, 
    3, 92, 8, 86, 7, 48, 5, 15, 4, 46, 2, 71, 6, 76, 1, 87, 0, 42, 
    6, 81, 3, 38, 5,  9, 8,  6, 1, 31, 4, 81, 0, 77, 7,  2, 2, 57, 
    0, 82, 5, 34, 4, 56, 7,  2, 8, 57, 3, 72, 6, 14, 1,  7, 2, 12, 
    1, 43, 4, 18, 3, 13, 2, 90, 7, 42, 8,  6, 6, 20, 5, 91, 0, 98, 
    6, 75, 8, 22, 3, 69, 0, 28, 4, 94, 1, 81, 7, 38, 5, 94, 2, 74, 
    8, 78, 1, 12, 0, 21, 4, 49, 5, 47, 3,  7, 6, 22, 2, 83, 7, 66, 
    7, 16, 3, 78, 6, 20, 4, 45, 1, 61, 2, 22, 0, 68, 8, 37, 5, 92
  };
  const int q3149[] = {
    9, 9, // Number of jobs and machines
    7, 77, 5,  9, 8, 62, 1, 84, 0, 84, 6, 98, 2, 69, 4,  2, 3, 11, 
    1, 92, 0, 56, 7, 16, 5, 69, 2, 12, 8, 32, 4, 87, 3,  4, 6, 61, 
    4, 11, 5, 89, 6, 81, 3, 59, 7, 12, 0, 87, 8, 54, 2, 49, 1, 69, 
    6, 12, 2, 95, 0, 58, 1, 90, 4, 72, 7, 61, 5, 33, 3, 53, 8, 84, 
    0, 13, 1, 76, 6, 55, 3, 19, 8, 12, 4, 38, 2, 45, 7, 68, 5,  6, 
    8, 23, 2,  1, 1,  4, 0,  3, 6, 78, 7, 89, 5, 27, 3, 38, 4, 51, 
    2,  5, 6, 68, 4, 27, 8, 41, 5, 63, 1, 49, 7, 18, 3, 99, 0, 33, 
    2, 87, 3, 14, 4, 21, 8, 59, 1, 19, 5, 12, 0, 54, 6,  4, 7,  8, 
    7, 82, 4,  6, 1, 42, 5, 59, 0,  5, 2, 15, 8, 12, 6, 54, 3, 74
  };
  const int q3150[] = {
    9, 9, // Number of jobs and machines
    7, 58, 1, 45, 3, 37, 5, 62, 8,  3, 6, 48, 4, 49, 2, 60, 0, 25, 
    8,  5, 6, 57, 2, 71, 0, 80, 7, 85, 5, 81, 4, 92, 1, 74, 3, 88, 
    3, 63, 0, 32, 1, 25, 7, 82, 8, 95, 4, 45, 6, 43, 5, 51, 2, 80, 
    8, 27, 4, 35, 6, 81, 5, 98, 7, 29, 3,  4, 1, 16, 2, 49, 0, 41, 
    8, 61, 6, 46, 5, 11, 2, 58, 1,  7, 4, 69, 3,  3, 7, 63, 0, 59, 
    3, 11, 8, 41, 2, 63, 1, 75, 7, 75, 4, 97, 5, 38, 6, 98, 0,  5, 
    2, 97, 0, 78, 5, 83, 7, 14, 6, 94, 8, 58, 1, 89, 3, 44, 4, 75, 
    8, 41, 3, 39, 7, 26, 1, 23, 2, 85, 4, 76, 0, 63, 6, 91, 5, 99, 
    6, 80, 1, 51, 0,  1, 7, 75, 3, 76, 2, 26, 4, 41, 8, 16, 5,  5
  };
  const int q3151[] = {
    9, 9, // Number of jobs and machines
    8, 91, 3, 54, 5, 52, 7, 93, 6, 24, 1, 28, 4, 49, 2, 48, 0, 43, 
    4, 20, 3, 18, 2, 23, 8, 24, 5, 24, 1, 63, 7, 66, 0, 65, 6, 62, 
    2, 47, 6, 14, 0, 74, 1, 54, 4, 21, 8, 34, 3, 24, 7, 62, 5, 16, 
    4, 72, 8, 30, 1, 63, 7, 52, 5, 16, 6, 98, 0, 41, 2, 63, 3, 56, 
    6,  4, 0, 99, 1, 32, 2, 46, 8, 58, 5, 33, 7, 38, 3,  8, 4, 90, 
    6, 17, 7, 76, 3, 88, 4, 63, 1, 87, 5, 69, 0, 17, 2, 47, 8, 96, 
    5, 93, 2, 91, 1, 15, 8, 69, 7, 40, 0, 15, 4, 66, 3, 31, 6, 18, 
    3, 61, 6, 86, 5, 85, 4, 24, 8, 35, 7, 77, 0, 95, 1, 58, 2,  5, 
    7, 29, 1, 92, 3, 39, 2, 41, 5, 76, 0, 19, 8, 84, 4, 20, 6, 98
  };
  const int q3152[] = {
    9, 9, // Number of jobs and machines
    0, 70, 3, 46, 5, 16, 7, 95, 1, 31, 6, 31, 8, 10, 4, 40, 2, 61, 
    0, 69, 4, 42, 5, 73, 8, 63, 3, 35, 7, 30, 2, 47, 1, 29, 6, 20, 
    3, 59, 0, 19, 6, 22, 8, 60, 2,  8, 7, 95, 4, 93, 1, 18, 5, 78, 
    3,  8, 2,  9, 7, 51, 5, 94, 4, 81, 8, 61, 1, 18, 6, 82, 0, 45, 
    8, 91, 5, 50, 6, 92, 2, 29, 3,  8, 4, 55, 7, 91, 1, 55, 0, 81, 
    3, 56, 5, 30, 8, 93, 0, 43, 7, 30, 4, 45, 2, 97, 6, 98, 1, 37, 
    3, 23, 7, 67, 5, 95, 1, 29, 4,  3, 0,  2, 6, 87, 8, 33, 2, 94, 
    2, 87, 7, 59, 5, 86, 6, 14, 1, 91, 4, 37, 8, 86, 3, 86, 0, 69, 
    0, 22, 7, 25, 3,  3, 1, 47, 5, 44, 4,  5, 8, 73, 2, 25, 6, 44
  };
  const int q3153[] = {
    9, 9, // Number of jobs and machines
    4, 18, 5, 11, 2, 32, 3, 69, 6, 51, 8, 33, 7, 95, 1, 20, 0, 22, 
    3,  5, 4, 51, 1, 79, 7,  2, 8, 58, 0, 60, 5,  5, 2, 44, 6, 25, 
    1, 33, 0,  5, 6, 79, 8, 79, 4, 87, 7, 29, 5, 54, 3, 91, 2, 22, 
    4,  9, 3,  4, 7, 56, 0, 12, 1, 15, 8, 42, 5, 41, 2,  4, 6, 85, 
    4, 10, 2, 44, 1, 18, 5, 99, 8, 12, 6, 27, 3, 33, 0, 19, 7, 52, 
    0, 10, 7, 26, 2, 41, 5, 63, 8, 79, 4, 84, 6, 49, 1, 91, 3, 48, 
    6, 96, 7, 47, 3, 19, 0, 87, 8, 63, 4, 69, 1, 15, 5, 91, 2, 74, 
    2, 17, 6,  4, 5, 59, 4, 74, 8, 12, 3, 72, 7, 87, 1, 97, 0, 89, 
    6, 25, 1, 15, 8,  1, 2, 38, 5, 69, 4, 67, 3, 85, 0,  1, 7, 40
  };
  const int q3154[] = {
    9, 9, // Number of jobs and machines
    2, 99, 7, 37, 0, 17, 6, 13, 8, 28, 3,  3, 4, 96, 1, 14, 5, 46, 
    4, 18, 1, 96, 2, 29, 8, 29, 7, 72, 5, 91, 3, 67, 0, 78, 6,  4, 
    3, 19, 5, 86, 2, 44, 0, 91, 6, 40, 7, 84, 1, 91, 8, 12, 4, 93, 
    5,  8, 0, 42, 7, 12, 8, 33, 1, 31, 6, 80, 2, 19, 4,  2, 3, 17, 
    5, 71, 2, 47, 7, 88, 6, 48, 8, 49, 3, 23, 0, 73, 1, 35, 4, 91, 
    7, 70, 3, 76, 6, 83, 5, 35, 1, 65, 0, 24, 4, 41, 2, 29, 8, 51, 
    0, 45, 4, 77, 1, 90, 8, 78, 3, 35, 7, 11, 2, 68, 6, 82, 5, 55, 
    3, 50, 2, 33, 1, 58, 7, 40, 4, 97, 6, 64, 8,  3, 5, 85, 0, 66, 
    0, 88, 8, 96, 4, 96, 7, 92, 2, 64, 1, 29, 3, 71, 5, 60, 6, 56
  };
  const int q3155[] = {
    9, 9, // Number of jobs and machines
    4, 38, 1,  6, 5, 17, 0, 20, 2, 80, 3, 23, 7, 69, 6, 75, 8, 98, 
    2, 40, 8, 53, 1,  6, 7, 43, 0, 18, 6, 15, 3, 22, 5, 75, 4, 50, 
    3, 65, 8, 77, 7, 10, 2, 59, 0, 99, 1, 70, 4, 30, 6, 82, 5, 15, 
    5, 14, 0, 45, 3, 89, 6, 60, 1, 17, 8, 91, 7, 53, 2,  3, 4, 23, 
    3, 17, 0, 22, 7,  6, 6, 87, 5, 84, 8, 28, 4, 17, 2, 56, 1, 78, 
    7, 60, 0, 52, 2, 71, 5, 89, 4, 62, 6, 81, 3, 26, 1, 27, 8, 15, 
    1, 32, 2, 73, 6, 63, 5, 45, 4, 27, 0, 64, 7, 50, 8, 86, 3, 94, 
    6, 50, 8, 68, 1, 73, 0, 70, 2, 25, 7, 38, 3, 24, 5, 76, 4, 67, 
    7, 51, 6, 43, 5, 64, 0, 56, 4, 68, 8, 54, 2, 32, 1, 75, 3, 74
  };
  const int q3156[] = {
    9, 9, // Number of jobs and machines
    8,  5, 3, 52, 0, 87, 4, 53, 1, 15, 6, 66, 7, 18, 5, 91, 2, 46, 
    4, 82, 2, 13, 3, 95, 1,  1, 7,  9, 5, 38, 6, 98, 0, 80, 8, 25, 
    6, 51, 5, 27, 4, 47, 0, 97, 1, 88, 7, 46, 3, 80, 2, 26, 8, 67, 
    6, 35, 1,  9, 5, 22, 4, 97, 2, 38, 0, 69, 3,  1, 7, 27, 8, 92, 
    3, 84, 6, 59, 5, 25, 2, 59, 4, 91, 0, 42, 8, 85, 7, 43, 1, 94, 
    3, 13, 4, 53, 2, 19, 6, 69, 0, 13, 8, 24, 1, 69, 5, 83, 7, 68, 
    8, 16, 1, 56, 2, 46, 6,  3, 3, 23, 4, 36, 0, 25, 7,  2, 5, 51, 
    6, 89, 7, 28, 2, 39, 5, 59, 8,  2, 0, 67, 3, 14, 1, 85, 4, 23, 
    2, 96, 8, 15, 6, 67, 1, 27, 5, 46, 0, 51, 4, 26, 3, 32, 7, 30
  };
  const int q3157[] = {
    9, 9, // Number of jobs and machines
    4, 17, 7, 51, 2, 36, 1, 77, 3, 81, 5, 90, 0, 84, 6, 21, 8, 39, 
    4, 11, 3, 76, 7, 69, 6,  8, 0, 79, 8, 48, 2, 45, 5, 34, 1, 48, 
    8, 92, 0,  9, 6,  7, 7,  1, 4, 92, 1, 39, 2, 76, 5, 14, 3, 46, 
    3, 48, 7,  4, 6, 17, 5, 72, 8, 74, 1, 30, 4, 90, 2, 86, 0,  9, 
    6, 36, 1, 69, 7, 24, 2, 25, 0, 48, 3,  8, 4, 32, 8, 36, 5, 17, 
    4, 46, 6, 95, 5, 97, 3, 56, 0, 49, 1, 54, 7, 92, 2, 61, 8, 54, 
    7, 55, 5, 73, 6, 83, 2, 19, 4, 47, 8, 38, 1, 60, 3, 27, 0,  1, 
    0,  3, 8, 37, 5, 27, 7, 85, 6, 92, 2, 91, 1, 79, 3, 84, 4, 35, 
    6, 79, 8, 30, 2, 13, 1, 43, 7, 36, 0, 49, 4, 72, 5, 30, 3, 49
  };
  const int q3158[] = {
    9, 9, // Number of jobs and machines
    1, 65, 8, 27, 5,  2, 6, 43, 7, 80, 3,  8, 2, 83, 0, 93, 4, 78, 
    0, 60, 6, 12, 5, 91, 1, 43, 7, 66, 8,  8, 3, 81, 4, 50, 2, 91, 
    3, 78, 0, 41, 5, 91, 1, 30, 8, 31, 7, 45, 2, 37, 4, 56, 6, 55, 
    0, 68, 4, 80, 2, 26, 1,  5, 5, 71, 8, 55, 3, 85, 7, 89, 6,  4, 
    5, 95, 1, 58, 2, 18, 4, 15, 3, 10, 8, 16, 7, 46, 6, 79, 0, 95, 
    4, 11, 7, 26, 5, 60, 6, 79, 2, 37, 3, 20, 0, 56, 1, 84, 8, 55, 
    2, 46, 3, 73, 5, 27, 1, 21, 6, 64, 4, 63, 7,  3, 0, 31, 8, 62, 
    8, 73, 1, 44, 3, 46, 5, 56, 7, 32, 4, 92, 0, 46, 2, 10, 6, 10, 
    4, 96, 8, 17, 5, 24, 6, 64, 3, 32, 1, 24, 2, 86, 7,  5, 0, 76
  };
  const int q3159[] = {
    9, 9, // Number of jobs and machines
    7, 98, 6, 20, 2, 58, 0, 71, 5, 29, 1, 56, 8, 22, 4, 95, 3, 96, 
    8, 18, 1, 88, 7, 93, 6, 15, 5, 26, 0, 30, 3, 43, 4, 20, 2, 76, 
    7, 13, 2, 20, 4, 89, 0, 96, 3, 64, 5, 53, 8, 33, 6, 13, 1, 66, 
    4, 68, 6, 67, 2, 91, 1, 62, 7, 70, 8, 37, 0, 95, 3, 52, 5, 69, 
    3, 40, 4, 16, 8, 99, 7, 51, 6, 65, 0, 90, 5,  4, 2, 98, 1, 51, 
    4, 30, 8, 28, 1, 88, 5, 10, 7, 14, 6, 53, 3, 17, 2, 85, 0, 75, 
    6, 77, 4, 88, 2, 64, 5, 33, 7, 21, 1, 76, 8, 34, 3, 87, 0, 17, 
    3, 21, 2, 55, 4, 40, 7, 20, 6,  5, 5,  8, 8, 26, 0, 79, 1, 22, 
    3, 30, 8, 42, 1, 62, 6, 80, 4,  4, 7,  6, 2, 55, 5, 51, 0, 37
  };
  const int q3160[] = {
    9, 9, // Number of jobs and machines
    6, 17, 8, 37, 1, 58, 0, 12, 3, 88, 2, 82, 7, 65, 5, 18, 4, 12, 
    1, 20, 8, 17, 3, 25, 0, 24, 2, 99, 7, 26, 6, 99, 4, 31, 5, 98, 
    8, 51, 5,  6, 6, 31, 2,  2, 3, 18, 1, 91, 7, 55, 4, 23, 0, 64, 
    1, 89, 5, 90, 6, 86, 2, 91, 0, 67, 8, 76, 4, 21, 7, 24, 3, 28, 
    4, 96, 5, 84, 8,  5, 6, 43, 3,  3, 0, 29, 2, 65, 7, 65, 1, 71, 
    7, 43, 2, 30, 1, 39, 8, 49, 4, 86, 3, 99, 0, 43, 6, 29, 5, 93, 
    5,  6, 7, 47, 3,  7, 4, 84, 8,  6, 2, 67, 0, 96, 6, 77, 1, 80, 
    0, 76, 5, 83, 1, 33, 7, 70, 8,  9, 4, 50, 3,  7, 2, 77, 6, 93, 
    8, 82, 1,  5, 6, 25, 3, 91, 2, 91, 4,  3, 7, 36, 5, 29, 0, 44
  };
  const int q3161[] = {
    9, 9, // Number of jobs and machines
    6, 55, 3, 78, 4, 34, 5, 78, 0, 27, 7, 73, 1, 57, 8, 76, 2, 59, 
    0,  5, 3, 72, 8, 50, 2,  5, 7, 13, 4,  7, 1, 18, 5, 74, 6, 26, 
    2, 40, 1, 87, 8,  2, 7, 41, 0, 48, 4, 54, 5,  5, 6, 69, 3, 44, 
    4, 54, 2, 30, 6, 84, 7, 69, 1, 17, 5, 42, 0, 45, 8, 16, 3,  2, 
    5, 14, 8, 15, 3, 97, 0, 59, 7, 25, 4, 11, 2, 97, 6, 41, 1, 14, 
    6,  4, 2, 32, 8, 96, 4, 94, 7,  1, 5, 42, 3, 17, 1, 95, 0, 36, 
    4, 23, 7,  9, 8, 11, 1, 75, 0, 84, 6, 10, 5, 16, 2, 15, 3, 71, 
    1, 99, 2, 86, 0, 47, 5, 48, 6, 34, 7, 44, 8, 27, 4, 25, 3, 91, 
    6,  2, 8,  6, 2, 71, 3, 54, 7, 87, 0, 33, 5, 14, 1, 56, 4, 63
  };
  const int q3162[] = {
    9, 9, // Number of jobs and machines
    2, 45, 4, 63, 0, 59, 1, 76, 6,  8, 3, 31, 8, 14, 5, 39, 7, 66, 
    1, 95, 8, 15, 4, 99, 6, 64, 2,  3, 7, 17, 5, 27, 0, 60, 3, 69, 
    6, 20, 4, 49, 0, 78, 2, 79, 5, 23, 1, 17, 3, 41, 8, 22, 7, 15, 
    8, 21, 7, 78, 2, 43, 0, 97, 6, 39, 1, 73, 4, 66, 3,  7, 5, 55, 
    2, 86, 1, 45, 7,  4, 4, 60, 3, 76, 8, 70, 6,  4, 5, 34, 0, 74, 
    6, 78, 5, 92, 7, 32, 0, 44, 2, 38, 3,  2, 8, 74, 4, 46, 1, 29, 
    4, 62, 0, 20, 6, 87, 5, 27, 2, 70, 7, 35, 3,  9, 1, 57, 8, 96, 
    0, 21, 8, 83, 1, 28, 3,  6, 4, 95, 7, 39, 2, 83, 6, 89, 5, 22, 
    6, 16, 7, 91, 1, 13, 2, 65, 8, 68, 5, 92, 3, 75, 0, 72, 4, 65
  };
  const int q3163[] = {
    9, 9, // Number of jobs and machines
    4, 49, 8, 20, 7, 68, 6, 80, 2, 21, 1, 25, 5, 18, 3, 10, 0, 25, 
    7, 10, 0, 16, 4, 54, 5, 28, 8, 14, 2, 93, 1, 39, 6, 63, 3, 31, 
    3, 53, 7, 12, 6,  1, 5, 82, 4, 15, 2, 92, 1, 90, 0, 89, 8, 24, 
    8, 19, 4, 17, 6, 20, 0,  2, 3, 49, 5, 58, 2, 12, 7, 66, 1,  6, 
    5,  5, 2, 18, 3, 95, 4, 33, 7, 78, 0, 13, 8, 85, 1, 45, 6, 35, 
    5,  9, 3, 37, 1,  3, 4, 32, 0, 46, 8,  6, 7, 21, 2, 43, 6, 61, 
    4, 93, 1, 80, 8, 88, 2, 39, 7, 41, 5, 46, 3, 46, 6, 19, 0, 17, 
    7, 65, 4, 53, 8,  4, 1, 13, 0,  6, 2, 35, 6, 64, 5, 98, 3, 10, 
    1,  8, 0, 96, 7, 74, 5,  4, 2,  6, 3, 50, 4, 44, 8, 97, 6, 21
  };
  const int q3164[] = {
    9, 9, // Number of jobs and machines
    1, 49, 7, 15, 3, 10, 4, 80, 2, 40, 0, 30, 6, 25, 5, 92, 8,  6, 
    4, 26, 3, 98, 5, 87, 7, 18, 8, 84, 1, 43, 2, 64, 6, 56, 0, 42, 
    1, 48, 6, 49, 2, 56, 4, 27, 3, 92, 5, 76, 0, 44, 8, 99, 7, 62, 
    4, 92, 2, 13, 1, 23, 6, 40, 8, 80, 7, 77, 0, 14, 5, 97, 3, 27, 
    5,  3, 6, 35, 2, 51, 4, 36, 3, 39, 1, 90, 7, 52, 0,  4, 8, 43, 
    5, 89, 3,  3, 8,  4, 7, 73, 0,  3, 6, 93, 2, 62, 4, 45, 1, 47, 
    7, 63, 4, 10, 2, 78, 1, 82, 3, 51, 6, 72, 0, 43, 8, 98, 5, 31, 
    0, 71, 2, 50, 1, 19, 7,  3, 6,  8, 8, 76, 4, 29, 3,  4, 5, 73, 
    4, 53, 6, 34, 2, 32, 8, 56, 0, 65, 3, 28, 7, 81, 5, 90, 1, 36
  };
  const int q3165[] = {
    9, 9, // Number of jobs and machines
    3, 98, 4,  6, 0, 59, 7, 99, 5, 69, 8, 69, 2,  2, 6, 87, 1, 79, 
    0, 59, 3, 19, 2, 76, 8, 38, 5, 74, 4, 56, 7,  6, 1, 21, 6,  3, 
    4, 26, 8, 37, 7, 25, 6, 93, 5, 19, 1, 75, 3, 43, 0, 15, 2, 60, 
    0, 14, 8,  2, 1, 70, 5, 95, 2,  3, 4, 93, 7, 83, 3, 40, 6, 42, 
    1, 76, 7, 56, 3, 41, 5,  7, 2, 45, 6, 29, 8, 63, 4, 66, 0, 62, 
    4, 79, 2, 62, 5, 28, 7, 64, 3, 84, 0,  9, 8, 84, 1, 79, 6, 23, 
    2, 28, 5, 86, 7, 41, 3, 97, 1, 46, 0, 15, 8, 60, 6, 88, 4, 71, 
    2, 91, 8,  6, 1,  1, 0, 85, 4,  4, 6, 52, 7, 32, 3, 98, 5,  7, 
    4, 81, 8, 51, 7, 59, 3, 53, 5, 46, 0, 24, 6, 16, 2, 16, 1, 27
  };
  const int q3166[] = {
    9, 9, // Number of jobs and machines
    0, 12, 6, 19, 7, 68, 2, 22, 5, 54, 4, 17, 1, 42, 8, 78, 3, 41, 
    3, 19, 1, 62, 0, 88, 5, 96, 8, 42, 2, 34, 4, 74, 6, 66, 7, 33, 
    5,  5, 4, 69, 1, 52, 2, 19, 6, 54, 3,  2, 8, 64, 7, 87, 0, 39, 
    1, 51, 4, 73, 5, 92, 3,  3, 6, 61, 2, 37, 8, 73, 0,  2, 7, 60, 
    0, 51, 7, 91, 4, 15, 6, 95, 8, 19, 1, 43, 2, 28, 5, 46, 3, 70, 
    7, 86, 3, 58, 5, 59, 4, 63, 8, 11, 2, 17, 0, 89, 1, 72, 6, 37, 
    0, 72, 5, 34, 3, 60, 7,  9, 8, 63, 6, 42, 4,  3, 1, 32, 2, 64, 
    7, 12, 6,  7, 4, 61, 0, 78, 8, 61, 2, 15, 5, 79, 3, 61, 1, 82, 
    2, 76, 8, 94, 6, 62, 4, 38, 5, 18, 0,  3, 3, 35, 1, 53, 7, 98
  };
  const int q3167[] = {
    9, 9, // Number of jobs and machines
    1, 10, 8,  2, 7, 43, 5, 18, 0, 21, 4, 10, 2, 74, 6, 21, 3, 65, 
    7,  3, 4, 55, 2, 25, 1, 42, 6, 73, 0, 74, 3, 62, 5,  1, 8, 35, 
    3, 32, 4, 12, 7, 68, 0, 35, 6, 58, 5, 77, 2,  7, 8,  4, 1, 35, 
    2, 75, 1, 58, 8, 82, 3, 16, 6, 63, 0, 12, 5, 53, 7, 86, 4,  5, 
    4, 79, 8, 67, 2, 60, 5, 21, 0,  1, 6, 48, 7, 67, 3, 48, 1, 99, 
    2, 97, 0, 91, 7, 96, 8, 66, 1, 26, 3, 16, 5, 39, 4, 86, 6, 24, 
    0, 74, 2, 18, 6, 75, 1, 43, 3, 61, 5, 58, 4, 21, 8, 36, 7, 62, 
    1, 77, 5, 40, 2, 14, 3, 25, 4, 11, 7, 30, 0, 33, 6, 95, 8, 82, 
    1, 87, 4, 12, 2,  7, 8, 78, 5, 87, 0, 31, 6, 44, 3, 60, 7,  4
  };
  const int q3168[] = {
    9, 9, // Number of jobs and machines
    0, 98, 8, 50, 5, 58, 7, 53, 2, 48, 1, 63, 3, 45, 6, 19, 4, 32, 
    7, 86, 1, 86, 6, 93, 4, 72, 5, 17, 3, 92, 0, 91, 8, 54, 2, 65, 
    8, 35, 3, 42, 1, 26, 0, 75, 2, 83, 6, 25, 4, 87, 7, 93, 5, 23, 
    1, 28, 3,  8, 5, 93, 2, 65, 8, 79, 7,  7, 6, 39, 4, 58, 0,  3, 
    3, 10, 7, 62, 5, 67, 6, 91, 4, 82, 1, 53, 2, 68, 0, 45, 8, 59, 
    4, 80, 3, 65, 1, 23, 0, 20, 2, 42, 8, 15, 5, 18, 7, 60, 6, 17, 
    5, 65, 0, 74, 4,  1, 7, 85, 6, 56, 8, 26, 2, 20, 3, 45, 1, 14, 
    6, 82, 5, 39, 8, 65, 3, 94, 2, 62, 1, 20, 4, 57, 7, 42, 0, 86, 
    7, 17, 6,  7, 2, 34, 1, 49, 5, 48, 8, 99, 0, 99, 4, 34, 3, 73
  };
  const int q3169[] = {
    9, 9, // Number of jobs and machines
    7, 94, 3, 52, 5, 27, 2,  8, 1, 37, 0, 70, 6, 44, 4,  7, 8, 41, 
    8, 73, 0, 62, 4,  8, 3, 69, 5, 99, 7,  9, 1, 74, 2, 84, 6, 78, 
    5, 90, 7, 90, 6, 56, 2, 91, 1, 18, 0,  9, 8, 68, 4,  3, 3, 62, 
    7, 85, 8, 22, 5, 78, 3, 95, 0, 77, 1, 35, 6, 40, 4, 26, 2, 13, 
    6, 80, 1, 81, 8, 47, 7, 72, 4, 45, 0, 48, 2, 51, 3, 44, 5, 50, 
    1, 48, 3, 15, 4, 24, 0, 41, 7, 81, 8, 41, 5, 34, 6, 14, 2, 57, 
    8, 19, 6, 14, 5, 16, 3, 37, 2, 61, 1, 97, 4, 47, 7, 86, 0, 87, 
    2, 16, 8, 71, 5, 41, 4, 10, 0, 51, 7, 37, 6, 40, 3, 14, 1, 39, 
    0, 15, 6, 10, 3, 91, 5, 35, 1, 92, 7,  8, 8, 40, 2, 34, 4, 66
  };
  const int q3170[] = {
    9, 9, // Number of jobs and machines
    0, 45, 5, 48, 2, 37, 7, 46, 4, 72, 6, 24, 8, 23, 1, 89, 3, 57, 
    2, 73, 0, 73, 1, 79, 8, 78, 4, 24, 5, 43, 6, 37, 7, 53, 3, 56, 
    7, 73, 5, 48, 0, 31, 3, 42, 6, 32, 2, 65, 1, 16, 8, 26, 4, 61, 
    5, 41, 1, 41, 8, 24, 2, 64, 0, 63, 3, 61, 4, 26, 6,  9, 7, 22, 
    4, 46, 3, 16, 6, 77, 7, 84, 2, 15, 5, 67, 1, 91, 0, 24, 8, 86, 
    1, 33, 5, 48, 8, 35, 6, 10, 2, 55, 0, 73, 4, 84, 3, 77, 7, 40, 
    8, 32, 1, 83, 4,  6, 2, 33, 0, 10, 7, 58, 3, 14, 5, 36, 6, 58, 
    0, 61, 8, 30, 2, 25, 3, 74, 7, 12, 6,  3, 1, 63, 5, 90, 4, 64, 
    0, 18, 3, 48, 4, 86, 5,  6, 7, 79, 1, 95, 8,  5, 6, 67, 2, 66
  };
  const int q3171[] = {
    9, 9, // Number of jobs and machines
    8, 44, 2, 18, 4, 77, 6, 53, 5, 89, 1, 24, 3,  8, 7,  1, 0, 98, 
    6, 96, 1, 35, 8, 49, 4, 52, 5,  6, 0, 65, 7, 22, 3, 36, 2, 58, 
    1, 19, 8, 51, 3, 11, 2, 28, 6,  4, 5, 56, 4, 62, 7, 86, 0, 13, 
    8, 14, 4, 70, 5, 28, 1, 99, 0, 11, 6, 59, 7, 73, 2, 75, 3, 70, 
    7, 46, 0, 86, 4, 67, 3, 31, 6, 36, 8, 46, 5, 24, 1, 78, 2, 62, 
    5, 29, 1, 13, 2, 16, 0, 20, 4, 29, 3, 92, 6, 78, 8, 17, 7, 75, 
    7, 74, 1, 19, 8, 79, 5, 18, 6, 33, 4, 56, 2, 82, 0, 64, 3,  6, 
    2, 13, 1,  9, 5, 48, 7, 77, 4, 11, 3, 75, 6, 29, 0, 71, 8, 85, 
    1,  6, 0, 36, 3, 43, 7, 75, 5,  6, 2,  2, 8, 16, 6, 45, 4, 79
  };
  const int q3172[] = {
    9, 9, // Number of jobs and machines
    2, 35, 4, 39, 1, 68, 8, 45, 7, 23, 5, 14, 6, 21, 0, 12, 3, 91, 
    3, 66, 1, 50, 2, 66, 6,  5, 8, 96, 4, 54, 7, 23, 0, 68, 5, 29, 
    2, 14, 6, 53, 8, 42, 0, 21, 3, 35, 5, 22, 7,  5, 1, 65, 4, 78, 
    6, 84, 5, 33, 2, 70, 0, 51, 1, 56, 3, 30, 7, 33, 8, 91, 4, 35, 
    0, 53, 6, 88, 8, 79, 1, 29, 2, 47, 5, 83, 3, 14, 7, 50, 4, 16, 
    0, 54, 7, 56, 2,  3, 3, 14, 6, 12, 5, 38, 4, 47, 1, 39, 8, 11, 
    2, 36, 3, 91, 8, 59, 4, 65, 1, 14, 5, 89, 7, 93, 6, 37, 0, 49, 
    3, 19, 8, 50, 2, 72, 6, 67, 5, 58, 7, 77, 1, 52, 0, 71, 4, 50, 
    7, 34, 3, 91, 1, 30, 4, 41, 8, 59, 5, 50, 2, 81, 0, 55, 6, 32
  };
  const int q3173[] = {
    9, 9, // Number of jobs and machines
    6, 82, 8, 36, 2,  3, 3, 16, 7,  3, 4,  7, 5, 27, 0, 98, 1, 25, 
    2, 84, 7, 55, 5, 82, 0, 35, 1, 54, 4, 57, 3, 82, 6, 20, 8, 98, 
    7, 42, 0, 68, 5, 84, 4, 29, 6, 13, 3, 86, 1, 15, 8, 16, 2,  7, 
    7, 22, 5, 18, 4, 49, 3, 38, 1, 48, 0, 50, 6, 64, 2, 71, 8, 12, 
    3, 32, 0, 83, 6, 54, 5, 86, 2, 80, 7, 17, 8, 39, 1, 93, 4, 51, 
    2, 25, 1, 29, 0, 35, 7,  3, 3, 35, 4, 60, 8, 40, 5, 87, 6, 77, 
    6, 71, 2, 13, 3, 89, 8, 48, 4, 79, 5, 84, 0,  6, 7, 20, 1, 69, 
    1, 12, 4, 35, 8, 85, 2, 34, 5, 28, 6, 34, 7, 29, 3, 31, 0, 16, 
    1, 91, 2, 99, 4, 93, 8, 76, 0, 19, 3, 29, 7, 27, 5, 83, 6, 63
  };
  const int q3174[] = {
    9, 9, // Number of jobs and machines
    0, 42, 7,  7, 4, 18, 2, 20, 3, 45, 8, 44, 1, 96, 5, 55, 6, 25, 
    0, 91, 1, 31, 4, 54, 3, 33, 6, 32, 2, 52, 7, 30, 5, 25, 8, 78, 
    3, 23, 2, 47, 7, 10, 6, 23, 5, 92, 8, 58, 4, 55, 0, 11, 1, 29, 
    3, 59, 1, 19, 7, 12, 0, 94, 6, 43, 2, 24, 4, 46, 8, 96, 5, 55, 
    3,  1, 2, 77, 0,  4, 1, 59, 7, 29, 5, 28, 8, 17, 4, 52, 6, 32, 
    3, 20, 0, 26, 6, 83, 2, 79, 4, 17, 5, 48, 8, 96, 1, 18, 7, 18, 
    8, 45, 2,  8, 0,  1, 7,  3, 3, 29, 4, 40, 1, 66, 6, 83, 5, 65, 
    2, 57, 6, 81, 5, 88, 8,  2, 1, 48, 7, 25, 0, 31, 3, 45, 4, 21, 
    3, 94, 4, 93, 2, 42, 6, 10, 5, 55, 7, 54, 8, 19, 1, 95, 0, 67
  };
  const int q3175[] = {
    9, 9, // Number of jobs and machines
    1, 51, 2, 16, 6, 63, 4, 12, 7,  7, 3, 69, 8, 61, 5, 35, 0, 79, 
    0, 98, 1, 22, 2, 78, 8, 98, 6, 71, 5,  7, 7, 42, 3, 36, 4, 99, 
    8, 38, 3, 76, 4, 88, 2, 29, 5, 45, 0,  8, 7, 33, 1, 30, 6, 65, 
    4, 33, 6, 79, 0, 88, 8, 26, 2, 90, 5, 32, 7, 84, 3, 68, 1, 50, 
    0, 32, 7, 18, 4, 83, 3,  6, 8, 38, 1, 64, 5, 40, 2, 30, 6, 15, 
    7, 83, 2, 62, 4, 98, 6, 51, 0, 37, 8, 34, 3, 83, 5, 53, 1, 17, 
    1, 62, 8, 14, 5, 89, 3, 61, 6,  4, 2, 94, 0, 95, 7, 25, 4, 78, 
    7, 98, 8, 89, 0, 42, 6, 13, 4, 53, 3, 10, 2, 57, 5, 55, 1, 24, 
    1, 73, 3, 89, 0, 46, 5, 62, 8, 73, 7, 65, 2, 47, 4,  9, 6, 97
  };
  const int q3176[] = {
    9, 9, // Number of jobs and machines
    3, 88, 7,  2, 4, 79, 1, 85, 6, 52, 5, 61, 8, 53, 2, 75, 0, 80, 
    6, 51, 5, 12, 4, 14, 3, 45, 7, 62, 2, 86, 0, 58, 1, 17, 8,  6, 
    1,  9, 7, 89, 8, 25, 2, 34, 3, 43, 6, 65, 0,  6, 5, 24, 4, 36, 
    3, 72, 1, 54, 8, 88, 0, 41, 4, 78, 7, 10, 5, 36, 6, 94, 2, 17, 
    3, 86, 0,  8, 1, 96, 7, 81, 2, 46, 8, 59, 5, 15, 4,  4, 6, 57, 
    6, 28, 3, 90, 2, 92, 0, 81, 7, 17, 5, 24, 4, 25, 1, 19, 8, 90, 
    8, 81, 5, 40, 2, 62, 1, 28, 6, 42, 0, 40, 3, 23, 4, 25, 7,  4, 
    5, 87, 7, 55, 3, 38, 8,  5, 1, 26, 2, 92, 0, 37, 6, 75, 4, 30, 
    0, 10, 5, 48, 2, 27, 3, 10, 8, 51, 7, 98, 4, 26, 1, 46, 6, 73
  };
  const int q3177[] = {
    9, 9, // Number of jobs and machines
    7, 52, 0, 65, 5, 49, 6, 48, 8, 42, 4, 13, 1, 56, 2, 12, 3, 82, 
    4, 45, 6, 80, 0, 59, 7,  4, 5, 58, 8, 26, 1, 17, 3, 77, 2, 27, 
    0, 77, 3, 13, 8, 47, 5, 50, 6, 14, 4, 45, 2, 42, 1, 46, 7, 33, 
    6, 96, 0,  6, 3, 26, 4, 93, 2,  2, 8, 97, 7, 49, 5, 83, 1, 43, 
    3, 89, 2, 81, 7, 25, 8, 90, 1,  5, 6, 85, 5, 66, 0, 82, 4, 51, 
    2, 48, 6, 89, 5, 82, 3, 43, 0, 87, 7,  4, 1, 83, 8,  7, 4, 95, 
    6, 80, 2, 80, 3, 27, 1, 39, 4, 46, 0, 68, 8, 67, 5, 48, 7, 59, 
    5, 30, 8, 86, 4, 95, 0, 82, 1, 25, 2, 19, 6, 54, 7, 33, 3, 28, 
    7,  9, 1, 60, 6, 65, 2, 65, 3, 81, 5, 17, 8, 17, 4,  5, 0, 63
  };
  const int q3178[] = {
    9, 9, // Number of jobs and machines
    5, 23, 6, 30, 1, 66, 0,  4, 3, 78, 2, 14, 4, 55, 8, 23, 7, 64, 
    7, 54, 3, 43, 5, 29, 1, 42, 4, 27, 6, 93, 0, 41, 8, 68, 2, 52, 
    1, 23, 4, 53, 0, 76, 7,  3, 6, 42, 3, 38, 2,  4, 8, 30, 5, 80, 
    1, 58, 6,  1, 3, 93, 7, 33, 8, 51, 0, 72, 2, 73, 4, 69, 5, 24, 
    0, 27, 1, 26, 6, 93, 5, 24, 4, 67, 2, 97, 8, 88, 7, 15, 3, 25, 
    2, 41, 8, 41, 5, 79, 4, 97, 1, 13, 7, 87, 0, 42, 3, 97, 6,  8, 
    3, 10, 2, 85, 5, 26, 7,  7, 1, 71, 4,  8, 6, 58, 8, 31, 0, 28, 
    4, 87, 1, 75, 2, 65, 5, 63, 3, 52, 6, 59, 0, 86, 7, 46, 8, 13, 
    0, 46, 1, 78, 5, 46, 3, 11, 2, 67, 6, 32, 4, 88, 8, 39, 7, 22
  };
  const int q3179[] = {
    9, 9, // Number of jobs and machines
    6, 30, 4,  6, 1, 87, 2, 81, 5, 33, 7, 50, 8,  9, 0, 39, 3, 82, 
    3, 62, 5, 59, 7, 78, 4, 99, 1, 91, 8, 83, 6, 46, 2, 56, 0, 39, 
    0, 74, 2, 64, 8, 54, 3, 32, 5, 43, 4,  5, 1, 31, 6, 81, 7, 15, 
    8, 64, 3, 79, 4, 86, 7, 92, 6, 34, 5, 33, 2, 10, 1, 27, 0, 55, 
    5, 84, 8, 32, 3, 65, 2, 69, 0, 81, 4, 46, 6, 63, 1, 36, 7, 13, 
    6, 84, 3, 53, 2, 83, 4, 54, 8, 19, 5, 40, 7, 60, 1, 78, 0, 12, 
    7, 95, 0, 73, 4, 86, 2, 62, 1, 58, 8, 91, 6, 30, 3, 59, 5,  8, 
    6, 25, 2, 77, 8, 94, 3, 83, 5, 88, 1, 68, 0, 61, 7, 95, 4, 45, 
    7, 64, 4, 97, 5,  4, 3, 25, 2, 62, 6, 48, 0, 64, 8, 10, 1, 44
  };
  const int q3180[] = {
    9, 9, // Number of jobs and machines
    7, 18, 5, 22, 6, 77, 0, 96, 4,  8, 1, 58, 3, 72, 2, 47, 8, 12, 
    0, 24, 3, 10, 7,  1, 4, 22, 2, 78, 6, 28, 8, 19, 5, 28, 1, 49, 
    5, 33, 0, 93, 6,  6, 2, 84, 4, 48, 1, 57, 8, 68, 7, 37, 3,  8, 
    6,  9, 2, 62, 1, 64, 3, 19, 7, 19, 4, 72, 5, 93, 8,  4, 0, 97, 
    1, 71, 3, 42, 0, 35, 6,  5, 2,  2, 4, 52, 5, 88, 8, 55, 7, 93, 
    1, 74, 7, 41, 4, 10, 2, 62, 0, 20, 6, 14, 3, 37, 8, 33, 5, 48, 
    8,  5, 7, 91, 6, 48, 4, 33, 3, 75, 0, 70, 2, 19, 5, 35, 1, 55, 
    2, 80, 0, 60, 8, 70, 5, 93, 7, 25, 6, 24, 4, 10, 3, 35, 1, 52, 
    6, 81, 5, 18, 2, 40, 7, 80, 8, 27, 4, 99, 3, 79, 0, 60, 1, 94
  };
  const int q3181[] = {
    9, 9, // Number of jobs and machines
    0, 27, 4, 66, 8, 29, 7, 50, 1,  5, 3, 89, 5, 80, 6, 87, 2, 51, 
    4, 90, 0,  3, 5,  4, 6, 37, 8, 11, 7,  6, 2,  6, 3,  9, 1, 68, 
    1,  8, 5, 75, 8, 68, 2, 27, 0, 24, 7, 61, 6, 93, 3, 17, 4, 30, 
    5, 98, 7, 81, 3, 51, 6, 89, 0, 77, 4, 57, 8, 69, 2, 61, 1, 71, 
    1, 96, 8,  2, 4, 26, 0, 45, 3, 43, 7,  2, 6, 75, 2,  2, 5, 33, 
    4,  6, 1, 93, 7,  9, 5,  3, 6, 36, 0,  3, 3, 20, 8, 61, 2, 21, 
    3, 10, 2, 93, 7, 29, 8, 60, 0, 81, 6, 31, 4, 48, 1, 27, 5, 21, 
    1,  2, 7,  6, 2, 90, 4, 79, 5,  6, 6, 34, 3, 88, 8, 46, 0, 42, 
    1, 69, 0, 12, 2, 28, 3, 87, 8, 23, 7, 16, 6,  4, 5, 75, 4, 87
  };
  const int q3182[] = {
    9, 9, // Number of jobs and machines
    8, 94, 6, 19, 5,  7, 4, 24, 0, 63, 2, 69, 7, 74, 3, 98, 1, 38, 
    1, 94, 0, 69, 7, 99, 3, 64, 6, 13, 8, 31, 4, 74, 2, 27, 5, 83, 
    2, 47, 3, 23, 0, 51, 1, 22, 7, 60, 8, 70, 5, 28, 4, 78, 6, 15, 
    5, 49, 4, 86, 6, 90, 3, 77, 2,  5, 8, 32, 0, 68, 7, 53, 1, 21, 
    0, 40, 8, 86, 1,  4, 7, 50, 5, 12, 2, 25, 6, 27, 3, 49, 4, 64, 
    0, 18, 4, 95, 2,  7, 6, 82, 3, 61, 5, 30, 7, 70, 8, 61, 1, 80, 
    3,  5, 0, 59, 1, 25, 5, 84, 7, 52, 8, 25, 6, 14, 2, 48, 4, 88, 
    3, 87, 0, 33, 7, 83, 8, 48, 1, 48, 6, 64, 5, 12, 2, 98, 4, 54, 
    6, 51, 1, 78, 8, 22, 5, 24, 0,  8, 7, 33, 2, 55, 4, 59, 3, 78
  };
  const int q3183[] = {
    9, 9, // Number of jobs and machines
    8, 12, 3, 51, 1, 15, 6, 12, 5, 34, 7, 97, 4, 65, 2, 68, 0, 12, 
    3, 84, 7, 64, 8,  4, 1, 31, 5, 15, 0, 11, 2,  3, 6, 49, 4,  6, 
    7, 23, 6, 41, 5, 85, 4, 18, 8, 93, 3, 49, 1, 51, 0, 55, 2, 45, 
    6, 90, 1, 92, 0, 23, 8, 98, 3, 35, 2, 21, 7, 53, 5, 21, 4,  8, 
    5, 43, 7, 22, 4, 51, 6, 96, 8,  9, 3, 19, 2, 46, 0, 18, 1, 80, 
    0, 49, 7, 12, 3, 93, 2, 50, 1, 95, 5, 43, 4, 42, 8,  2, 6, 75, 
    2, 75, 4, 42, 0, 45, 5, 76, 1, 14, 8, 58, 3, 49, 6, 43, 7, 70, 
    1,  9, 8, 33, 6, 18, 3, 30, 7, 49, 2, 50, 4, 53, 5, 59, 0, 75, 
    0, 28, 1, 68, 5, 66, 3, 49, 7, 14, 6, 61, 4, 75, 2, 88, 8, 91
  };
  const int q3184[] = {
    9, 9, // Number of jobs and machines
    7, 54, 1,  9, 3, 97, 4, 35, 2, 45, 6, 20, 8, 72, 0, 16, 5, 32, 
    1, 38, 8, 98, 6,  4, 4, 82, 3, 33, 7,  6, 5, 88, 2, 94, 0, 83, 
    8, 67, 0, 72, 7, 86, 4, 52, 2, 68, 1, 57, 3, 28, 6, 13, 5, 62, 
    7, 87, 4, 75, 2, 35, 0, 28, 5, 36, 3,  7, 8, 16, 6, 54, 1,  6, 
    0,  8, 5, 23, 2, 10, 4, 89, 3, 87, 1, 90, 8, 22, 6,  4, 7, 17, 
    5, 61, 7, 91, 8, 72, 1, 52, 6, 76, 2, 46, 0, 51, 4, 46, 3, 96, 
    8, 85, 4, 61, 3, 39, 5, 42, 7, 84, 2, 62, 6,  7, 0, 16, 1, 79, 
    3, 70, 1, 91, 6, 91, 0, 35, 2, 33, 5, 76, 8, 58, 4,  9, 7,  8, 
    5, 70, 0, 86, 4, 42, 6, 13, 7, 48, 1, 21, 8, 90, 2, 64, 3, 52
  };
  const int q3185[] = {
    9, 9, // Number of jobs and machines
    1, 26, 4, 89, 8, 54, 5, 19, 6, 58, 7, 23, 2, 11, 0, 50, 3,  6, 
    0, 91, 3, 52, 1, 91, 2, 16, 7, 85, 6, 89, 4, 66, 5, 33, 8, 32, 
    7, 56, 1, 94, 2,  3, 6, 53, 0, 47, 5, 42, 4, 86, 8, 97, 3, 19, 
    5, 21, 7, 30, 6, 75, 8, 51, 1, 88, 2, 52, 0, 45, 3,  5, 4, 79, 
    0, 38, 6, 33, 8, 80, 3, 89, 5, 72, 7, 16, 4,  2, 1, 29, 2, 33, 
    1, 87, 5, 66, 8, 23, 2,  7, 4, 50, 3, 36, 6, 71, 7, 79, 0, 42, 
    0, 20, 2, 16, 8, 63, 3,  7, 4, 56, 1, 77, 5, 50, 7, 76, 6, 84, 
    3, 70, 4, 62, 2, 25, 1, 84, 7, 74, 5, 96, 6,  6, 8, 89, 0, 61, 
    8, 15, 5, 10, 0, 28, 1, 42, 4, 76, 7,  5, 3, 61, 6, 83, 2, 98
  };
  const int q3186[] = {
    9, 9, // Number of jobs and machines
    8, 51, 0,  3, 5, 11, 6,  2, 3, 80, 1, 35, 7, 41, 4, 24, 2, 60, 
    2, 33, 3, 35, 1, 74, 0, 61, 5, 80, 8, 43, 4, 27, 6, 23, 7, 66, 
    8, 42, 6, 61, 2, 38, 7, 44, 4, 32, 0, 10, 3, 11, 1, 63, 5, 30, 
    1, 66, 4, 74, 2, 33, 5, 85, 6, 57, 7, 22, 3, 72, 0, 69, 8, 27, 
    0, 38, 7, 77, 3, 72, 4, 51, 1, 44, 5, 69, 6, 53, 2, 85, 8, 15, 
    7, 21, 4, 77, 2, 72, 8, 21, 3, 78, 5, 75, 0, 13, 6, 31, 1, 77, 
    7,  1, 8, 33, 4, 42, 3, 44, 6,  4, 2, 41, 0, 68, 1, 47, 5, 60, 
    5, 87, 3, 52, 8, 70, 7, 71, 2, 10, 4, 99, 1, 23, 6, 71, 0, 94, 
    6, 58, 0, 53, 1, 13, 3, 28, 7, 26, 4, 91, 2, 75, 8, 12, 5, 38
  };
  const int q3187[] = {
    9, 9, // Number of jobs and machines
    8, 92, 0, 97, 1, 91, 4, 63, 6, 26, 2, 40, 5, 79, 3, 48, 7, 48, 
    8, 94, 1, 71, 3, 61, 2, 61, 5, 49, 6,  4, 0, 95, 4, 95, 7, 33, 
    2, 34, 8, 78, 0, 74, 4, 94, 6, 74, 7, 63, 3, 43, 5,  3, 1, 52, 
    7, 71, 1,  6, 2,  3, 4, 77, 0,  5, 8, 48, 5, 15, 3, 26, 6, 12, 
    1, 64, 5, 33, 0, 52, 6, 52, 7,  4, 2, 85, 8, 62, 3, 73, 4, 76, 
    4,  1, 5, 81, 8, 20, 7,  5, 0, 52, 2, 30, 1, 45, 6, 56, 3, 34, 
    2, 95, 0, 17, 6, 46, 4, 86, 7, 44, 3, 96, 8, 98, 5, 20, 1,  3, 
    2, 70, 7, 29, 3, 39, 4, 48, 6, 87, 1, 43, 8, 96, 0, 62, 5, 45, 
    5, 64, 6, 25, 0, 17, 3, 22, 8, 62, 2, 51, 4, 81, 7, 83, 1, 90
  };
  const int q3188[] = {
    9, 9, // Number of jobs and machines
    8, 98, 2, 96, 6,  5, 5, 64, 3, 12, 4, 13, 7, 98, 1, 84, 0, 99, 
    3, 62, 8, 49, 5, 92, 4,  3, 7,  8, 6, 22, 1, 21, 2,  6, 0, 63, 
    2, 31, 6, 45, 8, 53, 3, 19, 5, 87, 7, 23, 4, 38, 1, 78, 0, 22, 
    1, 89, 0, 19, 4, 76, 5, 60, 3, 30, 8,  2, 7, 90, 6, 40, 2, 58, 
    5, 65, 6, 59, 8, 86, 2,  8, 0, 88, 1, 57, 7, 30, 3, 43, 4, 23, 
    6, 84, 7, 36, 5, 95, 2, 67, 8, 66, 1, 88, 0, 40, 3,  4, 4, 17, 
    4, 36, 6, 83, 3, 22, 8, 51, 0, 13, 7, 53, 5, 64, 2, 58, 1, 47, 
    7, 87, 5,  4, 2, 97, 3,  7, 0, 69, 8, 11, 6, 73, 4, 60, 1, 83, 
    5, 41, 0, 26, 6,  1, 3, 50, 2, 88, 8, 52, 7, 82, 1, 76, 4, 30
  };
  const int q3189[] = {
    9, 9, // Number of jobs and machines
    4, 44, 1, 41, 0, 85, 6, 29, 5, 37, 8, 29, 2, 94, 7, 99, 3, 58, 
    1, 66, 7,  8, 3, 43, 2, 24, 6, 14, 8, 86, 4, 74, 5, 29, 0,  7, 
    0, 90, 3, 36, 7, 29, 6, 15, 5, 73, 8, 79, 1, 14, 4, 62, 2, 70, 
    2, 66, 4, 42, 3, 67, 5,  4, 7, 12, 6, 78, 8, 63, 1,  4, 0, 32, 
    6, 50, 8, 47, 3, 62, 1, 27, 0, 30, 7, 48, 4, 74, 2, 85, 5, 37, 
    0,  1, 8, 23, 1, 55, 5, 21, 4, 67, 7, 82, 3, 25, 2, 60, 6, 61, 
    3, 36, 1, 12, 0, 89, 8, 79, 2, 58, 7, 48, 5, 18, 4, 48, 6, 41, 
    4,  8, 5, 32, 7, 98, 2, 17, 6, 80, 0, 84, 1,  7, 8, 62, 3, 70, 
    8, 61, 1, 63, 7, 48, 5, 56, 3, 93, 2, 31, 6, 11, 4, 16, 0, 22
  };
  const int q3190[] = {
    9, 9, // Number of jobs and machines
    4, 27, 1, 48, 2, 32, 5,  4, 7, 48, 8, 14, 6,  9, 3, 98, 0, 31, 
    4, 15, 7, 53, 8, 39, 6, 25, 5, 30, 0, 62, 3, 33, 1, 88, 2,  5, 
    0, 56, 5,  5, 4, 79, 2, 62, 3, 53, 1, 90, 8, 62, 6, 24, 7, 74, 
    2, 64, 3, 74, 8, 49, 6, 23, 4, 15, 1, 15, 5, 98, 0, 66, 7, 44, 
    8, 44, 7, 99, 5, 41, 4, 86, 2, 25, 1, 62, 6, 39, 3, 60, 0, 27, 
    2, 58, 3, 75, 8,  7, 1, 68, 7, 66, 5, 13, 6, 67, 0, 83, 4, 56, 
    0, 81, 7,  6, 5, 73, 8, 24, 6, 68, 2, 22, 1, 86, 3, 18, 4, 21, 
    4, 43, 0, 49, 8, 43, 1, 15, 6, 69, 5, 14, 3, 62, 7, 84, 2, 40, 
    3, 36, 2, 34, 4, 91, 0, 73, 5, 26, 1, 52, 7, 80, 8, 19, 6, 95
  };
  const int q3191[] = {
    9, 9, // Number of jobs and machines
    4, 78, 7, 99, 3, 56, 8, 56, 1, 86, 0, 53, 5, 94, 6, 12, 2, 12, 
    8, 47, 3, 78, 7, 17, 2, 82, 5, 69, 1, 52, 4, 39, 6, 41, 0, 93, 
    1, 47, 2, 60, 6, 31, 3, 47, 5, 74, 0, 63, 7, 87, 8, 41, 4, 43, 
    2, 91, 4, 35, 5, 34, 8, 41, 0,  8, 6, 55, 1, 19, 7, 58, 3, 11, 
    7, 94, 4, 24, 2, 75, 0, 94, 8,  1, 1, 88, 3, 65, 6, 68, 5, 11, 
    5, 43, 3, 49, 8, 85, 0, 43, 4, 53, 1, 41, 6,  9, 7, 24, 2, 11, 
    8, 94, 6, 31, 3, 40, 0, 88, 1, 41, 2, 57, 5, 84, 4, 77, 7, 64, 
    1, 13, 8, 20, 3, 75, 5, 40, 0, 44, 4,  9, 2, 97, 7,  8, 6, 59, 
    0, 78, 2, 43, 4, 94, 1, 68, 6, 28, 5, 48, 7,  7, 3, 28, 8, 20
  };
  const int q3192[] = {
    9, 9, // Number of jobs and machines
    2, 41, 5, 86, 8, 61, 0, 39, 1, 43, 4, 41, 6, 37, 7, 11, 3, 17, 
    8, 28, 0, 83, 4, 53, 5, 19, 2,  2, 1, 44, 3, 55, 7, 64, 6, 49, 
    0, 47, 4, 31, 8, 50, 7, 34, 2, 37, 3, 29, 6, 70, 5, 95, 1, 12, 
    7, 31, 5, 35, 0, 95, 3, 36, 4, 36, 6, 95, 1, 18, 8, 44, 2, 75, 
    8, 75, 5, 58, 0, 99, 4,  4, 7, 95, 6, 52, 1, 83, 3, 48, 2, 94, 
    6, 86, 1, 90, 4, 99, 7, 72, 2,  7, 5, 52, 3, 56, 0, 53, 8, 55, 
    0,  5, 2, 51, 5, 20, 8, 94, 6, 76, 4, 97, 3, 78, 7, 14, 1,  7, 
    8,  4, 5, 58, 1, 15, 4, 94, 2, 44, 6, 14, 7, 91, 0, 47, 3, 95, 
    6, 40, 5, 28, 2, 34, 0, 67, 7, 64, 3, 82, 8, 45, 4, 79, 1, 79
  };
  const int q3193[] = {
    9, 9, // Number of jobs and machines
    7, 23, 1, 20, 2, 76, 0, 39, 6, 84, 3,  3, 5, 16, 4, 63, 8, 47, 
    0,  1, 6, 52, 2, 60, 7,  9, 1, 93, 4, 46, 8, 81, 5, 22, 3, 66, 
    5, 73, 7, 24, 8, 26, 0, 11, 6, 11, 4, 69, 1,  7, 3, 54, 2, 73, 
    4, 90, 3,  1, 0, 99, 7, 55, 5, 66, 2, 81, 6, 96, 1,  2, 8,  5, 
    4, 86, 5, 79, 2, 29, 1, 99, 8, 98, 0, 72, 7, 81, 6,  7, 3, 19, 
    3,  3, 5, 98, 2, 49, 4, 68, 8, 54, 0, 21, 7, 82, 1, 21, 6, 78, 
    4, 57, 2, 18, 3, 20, 8, 64, 6, 87, 1, 70, 7, 24, 5, 90, 0, 44, 
    6, 27, 7, 63, 8, 36, 0, 17, 2, 83, 1, 52, 3, 29, 4, 15, 5, 78, 
    6, 52, 4, 78, 1, 31, 2, 15, 0, 14, 3, 41, 5, 89, 7, 66, 8, 65
  };
  const int q3194[] = {
    9, 9, // Number of jobs and machines
    2, 12, 3,  2, 4, 92, 7, 22, 1, 53, 0, 65, 6, 38, 8, 66, 5, 33, 
    8, 93, 5, 86, 3, 98, 4, 15, 1, 26, 7, 57, 0, 13, 2, 76, 6, 83, 
    1, 15, 4, 64, 5, 24, 0, 65, 8, 32, 3, 17, 2, 75, 7, 30, 6, 89, 
    3, 93, 4, 30, 0,  6, 1,  9, 6, 81, 5, 17, 8, 80, 2, 99, 7, 50, 
    1, 16, 6, 61, 0, 18, 3, 42, 4, 62, 5, 14, 7, 16, 8, 64, 2, 39, 
    7, 74, 1, 36, 8, 53, 0, 23, 4, 32, 5, 15, 3, 31, 6, 94, 2, 31, 
    5, 73, 1, 11, 2, 95, 3,  6, 8, 20, 7, 35, 4, 92, 0, 12, 6, 23, 
    4, 29, 1, 58, 3, 49, 5, 90, 2, 58, 6, 46, 8, 42, 7, 14, 0, 98, 
    6, 15, 5, 97, 0, 68, 3, 34, 7, 78, 2, 75, 8, 40, 1, 94, 4, 11
  };
  const int q3195[] = {
    9, 9, // Number of jobs and machines
    4,  3, 1, 70, 5, 25, 8, 64, 2, 27, 0, 13, 3, 92, 6, 33, 7, 54, 
    1, 83, 5, 63, 4, 47, 0,  4, 8,  4, 2, 37, 7, 79, 6, 35, 3, 83, 
    4, 85, 8, 20, 7, 25, 2, 14, 1, 36, 3, 68, 0, 28, 5, 93, 6, 59, 
    2, 58, 4, 62, 3, 63, 0, 36, 5, 78, 7, 58, 1, 64, 6, 51, 8, 74, 
    7, 51, 6, 45, 8, 48, 3, 82, 2,  5, 5, 95, 1, 49, 0, 56, 4, 51, 
    5,  6, 2, 51, 7, 97, 3, 94, 0, 67, 1, 36, 4, 30, 6, 69, 8, 84, 
    5, 98, 6, 82, 1, 52, 3, 55, 0, 95, 4, 97, 8, 22, 2, 14, 7, 13, 
    0, 69, 7, 87, 1, 90, 3, 98, 5,  3, 2, 56, 6, 16, 8, 58, 4,  7, 
    8, 44, 1, 55, 2, 38, 3, 42, 7, 26, 5, 18, 0, 86, 4, 58, 6, 75
  };
  const int q3196[] = {
    9, 9, // Number of jobs and machines
    3,  1, 1, 68, 6, 83, 7, 19, 4, 91, 8, 44, 5,  9, 2, 40, 0, 82, 
    8, 79, 5, 34, 6,  9, 2, 78, 7, 71, 4, 57, 1, 84, 3, 77, 0, 95, 
    8, 56, 2, 71, 3, 85, 0, 91, 6,  7, 4, 66, 7, 22, 5, 41, 1, 83, 
    6, 90, 7, 69, 4, 63, 2, 71, 0, 60, 1, 35, 3, 61, 5, 63, 8, 67, 
    3, 19, 7, 45, 8, 10, 5, 40, 0,  7, 2, 84, 1, 11, 4, 55, 6, 76, 
    8, 73, 5, 17, 3, 96, 6, 68, 1, 52, 0, 56, 2, 15, 4, 93, 7, 21, 
    8, 53, 6, 50, 7, 32, 4, 28, 1, 43, 0, 93, 5, 24, 2, 16, 3, 75, 
    0, 91, 5, 35, 8, 42, 3,  3, 4, 74, 2, 23, 6, 93, 1,  6, 7, 28, 
    2, 22, 7, 67, 5, 85, 8, 80, 1,  7, 0, 61, 6, 83, 3, 12, 4, 12
  };
  const int q3197[] = {
    9, 9, // Number of jobs and machines
    1, 73, 3, 15, 8, 28, 0, 54, 4, 15, 5, 64, 6, 10, 2, 99, 7, 85, 
    5, 77, 0, 76, 1, 31, 4, 73, 3, 86, 6, 86, 2, 71, 8, 23, 7, 87, 
    2, 70, 1, 27, 3, 54, 0, 49, 7, 67, 5, 85, 4, 81, 6, 16, 8, 66, 
    5, 68, 8, 30, 1, 38, 0, 86, 7, 22, 4, 44, 3, 20, 2, 93, 6, 13, 
    1, 86, 3, 86, 0, 11, 8,  6, 7, 59, 2, 37, 6,  5, 4, 88, 5, 26, 
    5, 13, 7, 16, 0, 29, 2, 78, 4, 24, 1,  7, 6, 85, 3, 65, 8, 21, 
    3, 99, 8, 67, 6, 26, 4, 67, 0, 69, 7, 40, 2, 83, 1,  4, 5, 59, 
    2, 33, 5, 12, 6, 78, 7, 87, 1, 22, 0, 65, 3, 86, 8, 50, 4, 79, 
    4, 22, 6, 76, 7, 45, 3, 61, 1, 46, 0, 12, 8, 27, 5, 60, 2, 85
  };
  const int q3198[] = {
    9, 9, // Number of jobs and machines
    3, 48, 6,  9, 8, 90, 2,  5, 7, 74, 1, 51, 0, 15, 4, 31, 5, 39, 
    3, 65, 1, 88, 5, 73, 7, 56, 4, 66, 8, 36, 0, 95, 6, 90, 2,  5, 
    5, 76, 7, 45, 2, 13, 4,  6, 1, 73, 8, 94, 0, 18, 3, 41, 6, 46, 
    4, 94, 8, 59, 2, 50, 5, 97, 6,  2, 3, 62, 1, 75, 0, 19, 7, 15, 
    4,  6, 7, 55, 8, 99, 0, 41, 1, 47, 3, 47, 5, 48, 6, 25, 2, 61, 
    8, 46, 2, 13, 0, 59, 1, 99, 5, 93, 7,  3, 4, 99, 3, 19, 6, 66, 
    8, 53, 1, 16, 2, 40, 5, 10, 7, 98, 4, 45, 6, 50, 3, 69, 0, 51, 
    2, 17, 8, 37, 4, 64, 1, 34, 5, 68, 0, 53, 7, 83, 6, 32, 3, 44, 
    2, 88, 5, 27, 1, 97, 8,  8, 4, 37, 7, 22, 0, 25, 6, 48, 3, 72
  };
  const int q3199[] = {
    9, 9, // Number of jobs and machines
    1, 47, 0, 66, 8, 83, 7, 73, 3,  1, 6, 58, 5, 53, 4, 68, 2, 20, 
    6, 98, 3, 38, 0,  3, 1, 12, 5, 74, 2, 41, 8, 16, 7, 18, 4, 89, 
    1, 91, 5, 75, 7, 13, 8, 91, 0,  8, 3, 38, 4, 59, 2, 19, 6, 47, 
    3,  5, 0, 23, 5, 71, 6, 99, 1, 61, 8, 39, 2,  9, 4,  2, 7, 42, 
    3, 40, 8, 18, 2, 93, 5, 58, 7, 15, 6, 73, 1,  1, 4, 71, 0, 40, 
    5, 43, 1, 69, 3, 36, 4, 92, 7, 27, 8, 15, 6, 39, 2, 54, 0,  1, 
    8,  3, 7, 25, 1, 77, 5, 80, 0, 89, 6, 33, 2, 37, 4, 89, 3, 88, 
    5, 24, 2, 16, 7, 69, 3, 37, 1,  2, 8, 73, 0, 32, 6, 60, 4, 48, 
    2, 12, 3, 22, 0, 79, 4, 18, 8,  7, 1, 78, 7, 19, 5, 74, 6, 60
  };
  const int q3200[] = {
    9, 9, // Number of jobs and machines
    2, 27, 8,  6, 1, 73, 5, 78, 0, 88, 3,  5, 7, 23, 4, 38, 6, 84, 
    4, 17, 0, 95, 3, 24, 1, 42, 2, 97, 8, 59, 6, 60, 5, 44, 7, 28, 
    7, 31, 5, 45, 8, 17, 3, 72, 6, 36, 1, 43, 2,  5, 0, 57, 4,  7, 
    1, 45, 8,  3, 7, 40, 0, 48, 6, 69, 4, 53, 2,  9, 3, 39, 5, 71, 
    6, 11, 5, 11, 7, 58, 2, 96, 0, 87, 8, 41, 1,  9, 4, 92, 3, 16, 
    5, 32, 8, 91, 6, 17, 2, 65, 4,  5, 3, 29, 1, 25, 0, 74, 7, 82, 
    2, 42, 6, 43, 0, 69, 1, 16, 8, 15, 4, 52, 3, 86, 7, 77, 5, 80, 
    4, 29, 1, 11, 3, 33, 7, 63, 5, 16, 8, 90, 2, 62, 0, 20, 6, 44, 
    6, 34, 7, 60, 3, 67, 2,  4, 0, 85, 8, 29, 5, 48, 1, 82, 4, 32
  };
  const int q3201[] = {
    9, 9, // Number of jobs and machines
    5, 40, 3, 32, 8, 69, 6, 20, 2, 62, 7, 68, 1, 62, 4, 30, 0, 21, 
    5, 89, 4, 28, 3, 38, 0, 10, 2, 15, 8, 92, 1, 25, 6, 50, 7, 93, 
    6,  3, 7, 58, 1, 98, 2, 45, 8, 49, 4, 49, 3,  3, 5, 30, 0,  6, 
    3, 37, 1, 75, 7, 77, 8, 14, 5, 74, 0, 31, 2, 84, 6, 48, 4, 18, 
    2, 83, 6, 51, 3, 84, 5, 97, 4, 19, 7, 97, 8, 61, 1, 29, 0, 46, 
    3,  2, 0, 65, 4, 20, 2, 16, 6, 45, 7, 18, 5, 49, 1, 23, 8, 42, 
    8, 97, 1,  7, 5, 50, 2, 80, 7, 63, 4,  1, 3,  9, 0, 28, 6, 79, 
    1, 62, 6, 34, 4, 96, 5, 77, 0, 31, 8, 63, 2, 92, 7, 31, 3, 23, 
    0, 12, 7, 28, 1, 14, 8, 47, 5,  7, 3, 81, 4, 33, 2,  1, 6, 61
  };
  const int q3202[] = {
    9, 9, // Number of jobs and machines
    8, 71, 5, 44, 6, 77, 7, 91, 4, 88, 2, 24, 3, 41, 0, 93, 1, 67, 
    4, 97, 6, 47, 7, 11, 5, 31, 0, 90, 8, 42, 3, 52, 2, 88, 1, 66, 
    5, 96, 2, 20, 7, 81, 1, 24, 0, 12, 6, 22, 4, 43, 8, 64, 3, 30, 
    1, 66, 7,  7, 6, 14, 0, 61, 8, 52, 3, 61, 5, 77, 2, 70, 4, 31, 
    8, 90, 1, 36, 0, 93, 3, 27, 5, 75, 4, 98, 6, 97, 2, 25, 7, 95, 
    6, 54, 3, 26, 1, 45, 4, 96, 8, 36, 2, 94, 0, 65, 7, 49, 5, 93, 
    1, 11, 8, 99, 7, 55, 3, 49, 6, 72, 4, 66, 2, 37, 0, 24, 5, 81, 
    3, 54, 2, 94, 8, 49, 4, 98, 1, 58, 0, 60, 5, 42, 6, 25, 7, 24, 
    6,  5, 3, 12, 5, 23, 4, 36, 1, 56, 8, 85, 7, 23, 0, 17, 2,  4
  };
  const int q3203[] = {
    9, 9, // Number of jobs and machines
    3, 35, 5, 19, 6, 93, 0, 25, 1, 47, 2, 60, 7,  9, 4, 77, 8, 56, 
    0,  5, 7, 49, 1, 66, 2, 62, 4, 87, 6,  4, 5, 37, 8, 67, 3, 71, 
    4, 95, 2, 75, 1, 40, 5, 52, 7, 12, 8, 52, 0,  8, 3, 20, 6, 46, 
    6,  5, 0, 98, 2, 32, 8, 51, 4, 81, 7, 58, 3, 25, 1, 47, 5, 96, 
    1, 96, 6, 92, 8, 39, 7, 79, 2, 80, 4, 43, 3, 19, 5, 97, 0, 24, 
    3, 86, 8,  5, 1, 79, 5, 90, 4, 87, 6, 75, 0, 52, 2, 32, 7,  2, 
    1, 71, 4, 24, 0, 44, 2, 85, 8, 95, 7, 63, 6, 51, 5, 14, 3,  9, 
    2, 28, 7, 54, 1, 44, 5, 67, 4, 46, 8, 27, 6, 97, 0, 10, 3, 63, 
    8, 68, 7, 24, 5, 48, 0, 72, 6, 74, 1, 40, 2, 70, 4, 15, 3,  3
  };
  const int q3204[] = {
    9, 9, // Number of jobs and machines
    4, 69, 0, 71, 3, 90, 7, 23, 8, 39, 5, 48, 6, 43, 2, 35, 1, 32, 
    1, 94, 8, 20, 4, 72, 0, 21, 5,  6, 6, 22, 3, 69, 7, 72, 2, 16, 
    6,  6, 0, 40, 3, 92, 5, 44, 2, 41, 4, 40, 8, 46, 7, 19, 1, 24, 
    3,  9, 7, 31, 2, 21, 5, 83, 6, 41, 8, 14, 1, 24, 0, 19, 4, 59, 
    2, 48, 8, 62, 4, 51, 3, 91, 6, 89, 0, 27, 5, 25, 1, 67, 7, 46, 
    3, 83, 2, 95, 4, 90, 7, 83, 5, 48, 8, 67, 1, 75, 6,  5, 0,  3, 
    5, 63, 2, 29, 8, 96, 1, 86, 3,  9, 7, 34, 6, 15, 4, 26, 0, 33, 
    4, 69, 2,  7, 1, 11, 0, 12, 6, 44, 7, 84, 3, 24, 5, 36, 8, 95, 
    6, 75, 7, 46, 2,  7, 0, 11, 1, 87, 4, 16, 3, 71, 8, 16, 5, 26
  };
  const int q3205[] = {
    9, 9, // Number of jobs and machines
    4, 29, 0, 80, 7, 82, 1, 17, 2, 66, 8, 83, 5, 34, 3, 98, 6, 37, 
    3, 77, 2, 20, 0, 98, 4, 66, 7, 51, 1, 18, 6, 35, 8, 17, 5, 58, 
    8,  4, 3, 92, 1, 37, 7, 53, 4, 32, 6, 89, 0, 26, 2, 36, 5, 47, 
    1,  2, 3, 22, 5, 95, 2, 60, 6, 92, 4, 33, 0, 23, 8, 60, 7, 40, 
    6, 84, 0, 95, 5, 83, 7, 47, 4, 30, 8, 77, 2,  8, 3, 55, 1, 86, 
    3, 75, 8, 22, 4, 69, 0, 40, 2, 84, 5, 25, 6, 56, 1, 71, 7, 97, 
    5,  3, 4, 16, 3, 80, 6, 87, 0,  7, 7, 26, 1, 62, 8, 93, 2, 36, 
    7, 19, 5, 90, 8, 43, 4, 24, 1,  8, 2, 65, 3, 10, 6, 88, 0, 91, 
    6, 84, 8, 84, 2, 68, 4, 10, 3, 60, 0, 44, 5, 31, 7, 92, 1, 60
  };
  const int q3206[] = {
    9, 9, // Number of jobs and machines
    8, 50, 2, 54, 5, 50, 1,  1, 4, 28, 0, 86, 3, 63, 6, 40, 7, 45, 
    4,  2, 2,  4, 1, 35, 6, 39, 3, 21, 7, 43, 0, 63, 8, 41, 5, 29, 
    5, 31, 7, 26, 0, 46, 4, 34, 2, 17, 8, 46, 1, 63, 3, 61, 6, 31, 
    2, 57, 8,  8, 0, 98, 7, 61, 3, 13, 5, 60, 4,  4, 6, 16, 1, 15, 
    1, 57, 7, 91, 3, 64, 0, 55, 4, 33, 8, 51, 6, 50, 2, 68, 5,  3, 
    1, 31, 6, 31, 7, 68, 0,  6, 3, 62, 2, 21, 8,  2, 4, 42, 5, 98, 
    0, 74, 5, 13, 2, 39, 6, 48, 4, 84, 8, 11, 1, 96, 7,  2, 3, 85, 
    1, 75, 2, 72, 5, 49, 3,  1, 4, 19, 0,  4, 8, 97, 7, 27, 6, 29, 
    1, 61, 8, 81, 2, 59, 6,  5, 5, 86, 3, 93, 0, 59, 7, 37, 4, 60
  };
  const int q3207[] = {
    9, 9, // Number of jobs and machines
    4, 87, 6, 48, 8, 98, 7,  4, 5, 26, 3, 17, 0, 44, 1, 28, 2,  5, 
    8, 16, 0, 48, 4, 21, 6, 79, 7,  7, 1, 42, 5, 92, 2, 65, 3, 91, 
    1, 61, 0, 15, 4, 14, 2, 79, 8, 23, 3, 72, 7, 82, 6,  4, 5, 52, 
    3, 49, 7, 98, 8, 75, 4, 68, 1, 27, 2, 18, 6, 95, 0, 17, 5, 71, 
    0, 90, 8, 28, 7, 74, 5, 67, 6, 27, 4, 69, 2, 32, 1, 43, 3, 97, 
    7, 29, 4, 64, 2, 41, 5, 31, 1, 70, 8, 64, 6, 17, 3,  3, 0, 24, 
    6, 78, 4, 17, 1, 25, 3, 68, 8, 54, 5, 91, 7, 29, 0, 43, 2, 11, 
    8, 69, 5, 73, 0, 87, 1, 17, 6, 99, 7, 45, 3, 63, 4, 31, 2, 44, 
    2, 41, 5, 70, 6, 61, 0, 54, 8, 42, 4, 11, 1, 88, 3,  3, 7, 53
  };
  const int q3208[] = {
    9, 9, // Number of jobs and machines
    0, 31, 3, 93, 2, 20, 4, 26, 8, 61, 7, 90, 5, 24, 6, 37, 1, 26, 
    6, 53, 4, 85, 1, 42, 5, 49, 2, 48, 7, 29, 0,  1, 3, 67, 8, 68, 
    1, 40, 8, 67, 2, 91, 0, 92, 6, 31, 4, 53, 5, 26, 3, 87, 7, 21, 
    5, 50, 3, 48, 2, 84, 4,  9, 1, 21, 7, 22, 8,  6, 6, 80, 0,  1, 
    4, 74, 5, 82, 0, 82, 8, 63, 7, 29, 1,  4, 2,  6, 3, 17, 6, 16, 
    3, 73, 1, 83, 7, 60, 6, 32, 8, 67, 0, 47, 5, 89, 2, 36, 4, 25, 
    2, 96, 7, 15, 4, 77, 1, 89, 0, 56, 8, 92, 3, 36, 6, 36, 5, 12, 
    1, 13, 6, 11, 4, 57, 0, 19, 2, 14, 7, 96, 3, 46, 8, 81, 5, 67, 
    4, 52, 7, 33, 1, 57, 6, 33, 5, 54, 3,  1, 2, 73, 0, 83, 8, 83
  };
  const int q3209[] = {
    9, 9, // Number of jobs and machines
    3, 78, 6, 20, 2, 91, 8, 67, 7, 63, 5, 39, 1, 18, 4, 53, 0, 77, 
    7, 68, 5, 91, 2, 42, 4, 61, 6, 20, 8, 73, 1, 63, 3, 39, 0, 62, 
    3, 10, 8, 61, 7, 65, 0, 18, 2, 78, 6, 62, 4, 26, 1, 59, 5, 84, 
    6, 37, 8, 17, 4, 90, 5, 67, 0, 35, 2, 44, 3, 15, 7, 95, 1,  4, 
    1, 61, 2, 81, 0, 34, 3, 52, 8, 83, 6, 30, 4, 57, 5, 12, 7, 92, 
    5, 60, 1, 16, 7,  6, 3, 84, 2, 57, 4, 84, 6, 76, 8, 37, 0, 68, 
    8, 87, 6, 25, 4, 71, 7,  4, 2, 65, 5, 75, 1, 57, 0,  5, 3, 32, 
    4, 70, 8, 70, 5, 24, 0, 59, 6, 57, 2, 70, 1, 20, 3, 85, 7,  4, 
    8, 94, 5, 95, 6, 56, 1, 70, 2, 13, 0, 98, 7,  1, 3, 69, 4, 93
  };
  const int q3210[] = {
    9, 9, // Number of jobs and machines
    5, 23, 2, 75, 0, 35, 6, 86, 1, 11, 3, 88, 7, 98, 8, 36, 4, 12, 
    0, 87, 4, 86, 5, 14, 2, 22, 6, 36, 8, 31, 1, 30, 3, 47, 7, 20, 
    2, 49, 3, 51, 8, 31, 0, 39, 5, 89, 1, 78, 4, 41, 6, 80, 7, 83, 
    7, 35, 1, 79, 6, 38, 4, 60, 0, 79, 2, 64, 5, 85, 3, 19, 8, 85, 
    3,  6, 5, 77, 4, 56, 0, 43, 1, 73, 2, 47, 7, 23, 8, 81, 6, 10, 
    0, 34, 3,  5, 8, 53, 6, 44, 2, 61, 4,  4, 5,  1, 7, 59, 1,  3, 
    1, 28, 0, 23, 6, 87, 8, 71, 4, 18, 3, 28, 7,  9, 2, 96, 5, 27, 
    0, 48, 6,  3, 1,  9, 8, 59, 7, 10, 3, 23, 5, 53, 4, 22, 2, 93, 
    5, 42, 4, 52, 6, 98, 0, 89, 2, 62, 8, 23, 3, 71, 1, 26, 7, 31
  };
  const int q3211[] = {
    9, 9, // Number of jobs and machines
    4, 65, 3, 14, 5, 66, 7, 83, 2, 80, 8, 90, 0, 66, 1, 27, 6, 12, 
    1, 28, 0, 42, 4, 25, 5, 53, 6, 98, 8, 86, 2,  1, 7, 23, 3, 54, 
    8, 91, 0, 70, 6, 48, 7, 97, 4,  9, 5, 80, 2,  1, 3, 96, 1,  8, 
    3, 70, 1, 47, 0,  4, 2, 83, 4, 75, 6,  4, 7, 58, 5,  3, 8, 61, 
    0, 37, 5, 40, 4,  2, 3, 38, 7, 85, 2, 44, 6, 71, 8, 31, 1, 81, 
    4, 59, 3,  6, 6, 82, 5, 24, 2, 26, 7, 95, 8, 27, 1, 66, 0, 25, 
    0, 41, 5, 43, 3, 42, 4, 91, 2, 96, 7, 87, 6, 72, 8, 24, 1, 77, 
    4, 36, 7, 65, 0, 78, 3, 26, 8, 52, 2, 75, 6, 30, 1, 73, 5, 27, 
    2, 64, 4, 34, 3, 89, 0, 57, 6, 77, 7, 42, 8, 53, 1, 69, 5, 24
  };
  const int q3212[] = {
    9, 9, // Number of jobs and machines
    7, 97, 5, 63, 3, 31, 8, 24, 0, 45, 4, 67, 6, 48, 2, 66, 1, 91, 
    2, 44, 3, 43, 8, 20, 0, 90, 5, 11, 4,  9, 1, 10, 6, 35, 7, 60, 
    3, 42, 0, 25, 7, 80, 6, 24, 8, 86, 5, 44, 1, 96, 4, 99, 2, 43, 
    2, 77, 7, 42, 3,  7, 4, 23, 6, 56, 8,  9, 0, 69, 1, 89, 5, 57, 
    8, 56, 0, 93, 6, 19, 4, 18, 7, 15, 1, 20, 5, 30, 2, 33, 3, 77, 
    0, 93, 1, 41, 7, 30, 2, 15, 3, 77, 5, 17, 4, 55, 8, 90, 6, 44, 
    1, 76, 7, 50, 0, 15, 4, 73, 3,  4, 6, 20, 5, 50, 2, 10, 8, 53, 
    2, 72, 3, 46, 7, 12, 6,  8, 0, 96, 4, 97, 8, 42, 1, 61, 5,  8, 
    6, 46, 4,  1, 8, 70, 2, 67, 3, 40, 7, 25, 5,  1, 1, 94, 0, 93
  };
  const int q3213[] = {
    9, 9, // Number of jobs and machines
    0, 40, 3, 32, 8, 36, 5, 59, 1, 67, 2,  9, 4, 12, 7, 95, 6, 79, 
    1,  1, 6, 39, 7, 57, 3, 22, 5, 26, 4,  6, 2, 30, 0, 51, 8, 33, 
    7, 91, 6, 38, 2, 87, 4,  8, 5, 63, 3, 55, 1, 73, 0, 76, 8, 57, 
    0, 28, 2,  1, 5, 33, 1, 29, 6, 94, 3, 11, 7, 24, 8, 13, 4, 95, 
    7, 68, 8, 21, 6, 17, 5, 43, 3, 16, 4, 49, 0, 84, 2, 88, 1,  2, 
    6, 86, 2,  2, 0, 36, 8,  4, 7, 47, 1,  9, 5, 74, 4, 53, 3, 96, 
    2, 93, 6, 23, 7, 19, 4, 64, 0, 56, 1, 37, 3, 40, 8, 71, 5, 73, 
    5, 31, 1, 78, 3, 69, 7, 19, 8, 44, 2, 22, 0, 27, 6,  7, 4, 53, 
    6, 28, 3, 11, 1, 26, 4, 49, 2, 95, 5, 15, 8, 35, 0, 46, 7, 39
  };
  const int q3214[] = {
    9, 9, // Number of jobs and machines
    6, 84, 5, 74, 4, 39, 1, 12, 3, 49, 7, 82, 8, 53, 2, 83, 0, 87, 
    8, 43, 2, 13, 4, 28, 0, 78, 7, 66, 6, 72, 5, 59, 3, 61, 1, 48, 
    8, 42, 7,  7, 0, 65, 2, 99, 1, 18, 5, 23, 3, 60, 6, 73, 4, 60, 
    8, 62, 1,  4, 6, 74, 4, 49, 5, 86, 0, 89, 3, 85, 2, 39, 7, 68, 
    0, 96, 7, 61, 6, 90, 5, 34, 2, 47, 1, 43, 3, 92, 8, 84, 4, 53, 
    2, 50, 1, 37, 3,  8, 6, 20, 8, 93, 5, 23, 7, 20, 0, 21, 4, 41, 
    4, 97, 0, 99, 5, 19, 6, 59, 8, 41, 2, 80, 7, 21, 1, 62, 3, 56, 
    4, 96, 2, 18, 0, 60, 6, 36, 3, 61, 7, 84, 8, 61, 1, 90, 5, 56, 
    7,  4, 8, 35, 3,  7, 0, 24, 6, 81, 1, 63, 5, 70, 2, 95, 4, 45
  };
  const int q3215[] = {
    9, 9, // Number of jobs and machines
    8, 15, 5, 68, 6,  2, 0, 98, 3, 33, 4, 61, 1, 62, 2, 84, 7, 34, 
    3,  7, 4, 26, 5, 67, 0, 25, 8, 86, 6, 80, 2, 85, 1, 16, 7, 52, 
    0, 91, 5, 17, 8,  5, 1, 15, 6, 20, 7, 80, 3, 63, 2, 84, 4, 19, 
    6, 40, 1, 98, 4, 24, 7, 74, 5, 78, 2, 79, 8, 39, 0,  5, 3, 94, 
    3, 74, 1, 55, 4, 95, 6, 10, 5, 35, 0, 82, 2, 37, 8, 61, 7, 97, 
    3, 74, 7, 88, 4, 45, 6, 94, 5, 18, 1, 17, 0, 59, 2, 97, 8, 32, 
    5, 25, 6, 31, 2, 15, 7, 68, 0, 96, 8, 60, 1, 60, 4, 33, 3, 20, 
    6, 75, 2, 84, 1, 85, 0, 55, 3, 45, 7,  6, 8, 65, 4, 44, 5, 73, 
    6, 99, 7, 61, 4, 99, 2,  2, 8, 48, 1, 71, 3,  7, 0, 67, 5,  8
  };
  const int q3216[] = {
    9, 9, // Number of jobs and machines
    2, 47, 3, 58, 7, 14, 8, 12, 1, 66, 6, 35, 4, 60, 0, 62, 5, 47, 
    5,  1, 1, 56, 0, 56, 7, 17, 8, 25, 2, 59, 4, 14, 3, 72, 6, 11, 
    4, 59, 6, 60, 5, 69, 8, 64, 2, 34, 1, 28, 0, 47, 7, 42, 3, 86, 
    6, 38, 8, 32, 1, 77, 2, 34, 3, 14, 0, 93, 4, 13, 5, 39, 7, 63, 
    3,  1, 6, 93, 5, 32, 0, 32, 2, 76, 1, 84, 7,  2, 8,  3, 4, 77, 
    0, 59, 7, 80, 5, 52, 3, 43, 2, 95, 1, 90, 4, 38, 6, 69, 8, 42, 
    6, 20, 5,  4, 3, 90, 4,  5, 7,  7, 2, 16, 1, 98, 0, 89, 8, 53, 
    4, 85, 5, 35, 2, 53, 0, 38, 8, 20, 1, 10, 6, 15, 3, 42, 7,  1, 
    2, 87, 6, 97, 3, 61, 0, 68, 5,  9, 7, 59, 8,  1, 4, 87, 1, 35
  };
  const int q3217[] = {
    9, 9, // Number of jobs and machines
    5, 93, 8, 85, 1, 49, 7, 53, 2, 27, 4, 71, 3,  8, 0, 37, 6, 42, 
    6, 75, 4, 80, 2, 47, 7, 40, 1, 92, 5, 28, 8, 31, 3, 41, 0, 66, 
    2, 91, 8, 29, 3, 21, 7, 39, 6, 86, 1, 32, 0, 68, 5, 57, 4, 46, 
    0, 53, 1, 89, 5, 71, 6, 54, 4, 72, 3, 12, 2, 96, 7, 31, 8, 23, 
    5, 10, 3, 71, 2, 27, 7, 95, 4, 83, 8, 49, 6, 93, 1, 49, 0, 55, 
    7, 84, 1, 97, 2, 39, 5, 60, 8,  2, 0, 96, 3, 95, 4, 89, 6, 30, 
    6, 77, 2, 77, 0, 69, 5, 83, 1, 16, 8, 26, 7, 51, 3, 58, 4, 16, 
    8, 84, 5, 30, 4, 81, 1, 63, 7, 29, 0, 39, 3, 45, 6, 85, 2, 23, 
    2, 92, 1, 61, 8, 72, 7, 51, 3, 35, 5, 66, 6, 25, 4, 87, 0, 34
  };
  const int q3218[] = {
    9, 9, // Number of jobs and machines
    7, 28, 4, 97, 8, 71, 2, 88, 3, 24, 1, 94, 5, 89, 0, 20, 6, 74, 
    0, 35, 8, 85, 4, 89, 6, 40, 5,  5, 3, 62, 7, 46, 1, 60, 2, 46, 
    3, 66, 6, 30, 7, 55, 4, 14, 2, 93, 0, 83, 1, 65, 8, 86, 5, 71, 
    6, 41, 8, 45, 0, 48, 7, 13, 5, 86, 4, 12, 3,  4, 2,  4, 1, 33, 
    7, 48, 4,  1, 2, 87, 0, 37, 3, 41, 1, 68, 6, 48, 5, 16, 8, 98, 
    2, 13, 0, 49, 3, 36, 1, 84, 7, 36, 4, 46, 8, 24, 6, 37, 5, 76, 
    5, 62, 7, 40, 8, 27, 3, 68, 1, 70, 2, 69, 0,  5, 4, 35, 6, 44, 
    7, 40, 2, 39, 0, 67, 6, 69, 5, 52, 1, 68, 3, 37, 8, 70, 4, 61, 
    4,  1, 2, 61, 3, 76, 6, 97, 5, 82, 1, 60, 0, 26, 7,  3, 8, 51
  };
  const int q3219[] = {
    9, 9, // Number of jobs and machines
    5, 85, 6, 70, 4, 41, 2, 84, 8, 47, 3, 79, 1, 62, 0, 80, 7, 80, 
    4, 25, 7, 94, 6, 58, 5, 73, 8, 89, 0, 67, 2, 15, 3, 88, 1, 16, 
    0, 17, 5, 36, 2, 92, 7, 26, 8, 91, 1, 97, 6, 56, 4, 96, 3, 96, 
    4, 63, 5, 99, 8, 80, 3,  9, 2, 71, 1,  7, 0, 10, 6, 38, 7, 98, 
    3,  1, 5, 51, 2, 41, 7, 62, 0, 18, 8, 71, 4, 65, 6, 71, 1, 98, 
    4, 18, 3, 20, 0, 46, 2, 93, 6, 44, 5, 65, 8, 77, 7, 45, 1, 71, 
    7, 38, 6, 79, 4, 76, 5, 28, 0, 87, 3, 90, 8,  7, 2, 90, 1, 38, 
    4, 38, 5, 69, 6, 61, 2, 69, 3, 35, 1, 35, 7, 95, 0, 46, 8, 73, 
    0, 16, 4, 14, 5, 95, 3, 67, 2, 35, 7, 44, 8, 41, 6, 24, 1, 42
  };
  const int q3220[] = {
    9, 9, // Number of jobs and machines
    3, 91, 6, 20, 8,  3, 5, 71, 2, 92, 7, 85, 0,  1, 1, 54, 4, 32, 
    3, 35, 1, 34, 2, 30, 6,  2, 7, 61, 5, 56, 0, 59, 4, 42, 8, 15, 
    1, 93, 4, 81, 2, 49, 3, 30, 5, 81, 0, 54, 6, 54, 8, 57, 7, 40, 
    8, 33, 1, 47, 4, 39, 5, 86, 0, 25, 7, 44, 6, 76, 2, 59, 3, 72, 
    4, 54, 3, 21, 7, 13, 5, 54, 0, 72, 1, 17, 6, 56, 2, 29, 8, 78, 
    7, 56, 3, 54, 6, 14, 8, 42, 1, 36, 0, 12, 2, 51, 4, 99, 5, 90, 
    0, 79, 1, 27, 3, 62, 7, 43, 5, 64, 8,  1, 2, 10, 4, 75, 6, 20, 
    5, 46, 0, 73, 6, 98, 4, 98, 1, 86, 2, 41, 7, 22, 3, 96, 8, 78, 
    1, 65, 0, 59, 4, 16, 6,  4, 8, 31, 3, 47, 5, 92, 7, 98, 2, 55
  };
  const int q3221[] = {
    9, 9, // Number of jobs and machines
    8, 33, 4, 42, 7, 44, 5, 95, 6, 29, 3, 60, 0, 77, 1, 62, 2,  1, 
    2, 28, 5, 74, 6, 61, 8, 69, 1, 14, 7, 46, 3, 67, 4, 35, 0, 61, 
    2, 51, 0,  4, 6, 66, 3, 60, 5, 81, 8, 59, 7, 31, 4, 43, 1, 95, 
    2, 90, 8, 96, 0, 56, 7, 92, 6, 96, 5,  3, 3, 26, 4, 21, 1, 28, 
    2, 35, 1, 42, 0, 61, 8, 84, 3, 37, 6, 35, 5, 37, 7, 97, 4, 58, 
    5, 71, 2, 22, 3, 23, 8, 16, 0, 37, 4, 87, 6, 84, 7, 93, 1, 99, 
    6, 89, 7, 78, 0, 56, 8, 86, 2, 33, 1, 66, 5, 47, 4,  7, 3, 34, 
    7, 82, 8, 25, 1, 27, 6, 29, 3, 87, 4, 36, 2, 22, 0, 63, 5,  8, 
    4, 99, 3, 71, 5, 95, 7, 25, 0, 44, 1, 15, 2, 48, 8, 51, 6, 28
  };
  const int q3222[] = {
    9, 9, // Number of jobs and machines
    6, 64, 1,  7, 8, 26, 4,  1, 7, 83, 3, 78, 5, 98, 0, 71, 2, 37, 
    2, 15, 4, 23, 7, 34, 1, 69, 3, 11, 0, 95, 6, 92, 8, 29, 5, 14, 
    2, 89, 4, 53, 8, 42, 3, 47, 1, 74, 7,  1, 6,  8, 0, 42, 5, 81, 
    2, 79, 1, 76, 3, 61, 4, 91, 5, 64, 8,  3, 0, 91, 6, 15, 7, 89, 
    6, 13, 8, 60, 3, 82, 5, 54, 2, 99, 7, 49, 0, 60, 4, 54, 1, 89, 
    4,  6, 8, 23, 2, 39, 5, 21, 7, 72, 6, 49, 1, 88, 3, 44, 0, 52, 
    0, 98, 4, 55, 5, 74, 7, 19, 6, 87, 3, 58, 2, 31, 8,  2, 1, 97, 
    6, 77, 8, 90, 4, 96, 1, 54, 3, 11, 0, 97, 2, 60, 7, 69, 5, 84, 
    4, 27, 1, 17, 7, 29, 3, 80, 5, 27, 0, 96, 8, 87, 6, 16, 2, 98
  };
  const int q3223[] = {
    9, 9, // Number of jobs and machines
    0, 41, 7, 93, 4, 20, 6, 33, 1, 23, 3, 57, 5, 87, 8, 72, 2, 36, 
    2, 66, 8, 31, 1, 94, 5, 53, 3, 12, 4, 13, 7, 20, 6, 64, 0, 85, 
    4,  4, 3, 15, 1, 51, 5, 69, 2, 64, 6,  6, 0, 33, 7, 77, 8, 89, 
    6, 31, 8, 58, 2, 65, 3, 54, 7, 47, 5, 81, 4, 53, 0, 18, 1, 81, 
    7, 60, 6, 23, 1, 69, 0, 76, 5, 81, 2, 11, 3, 82, 8, 56, 4, 38, 
    2, 57, 3, 37, 7, 56, 8, 68, 5, 16, 0, 79, 4, 86, 1,  2, 6, 59, 
    1,  7, 8, 78, 0, 18, 3, 40, 6, 26, 2, 37, 5, 16, 7, 20, 4,  8, 
    7, 75, 8, 38, 6, 92, 1, 68, 2, 95, 4, 70, 0, 67, 3, 44, 5, 51, 
    5, 42, 4,  1, 2, 36, 7, 58, 1, 54, 3, 58, 6, 12, 0, 70, 8, 17
  };
  const int q3224[] = {
    9, 9, // Number of jobs and machines
    5, 25, 1, 44, 4, 73, 3, 30, 6, 98, 2,  1, 0, 61, 8, 40, 7, 99, 
    8, 80, 7, 41, 0, 51, 4, 19, 2, 19, 1, 73, 6,  9, 3, 44, 5, 51, 
    0, 97, 3, 73, 8, 89, 4, 88, 2, 72, 1,  6, 5, 42, 7, 95, 6, 11, 
    3, 20, 0, 98, 8, 21, 5, 24, 1, 97, 6, 40, 7, 12, 2, 97, 4, 63, 
    8, 50, 3, 20, 0, 57, 6, 62, 7, 91, 4, 89, 1, 11, 2, 22, 5, 43, 
    6, 53, 3, 25, 0, 12, 4, 90, 2, 18, 7, 72, 5, 33, 8, 60, 1, 65, 
    0, 58, 3, 32, 2, 91, 5, 70, 8, 26, 7, 19, 4, 10, 1, 89, 6, 87, 
    2, 37, 1, 95, 0, 22, 7,  8, 6, 42, 5, 44, 4, 44, 3, 98, 8, 75, 
    1, 27, 3, 21, 7, 70, 8,  5, 2, 58, 6, 35, 0, 88, 5, 69, 4, 68
  };
  const int q3225[] = {
    9, 9, // Number of jobs and machines
    0, 40, 1, 10, 8,  4, 4, 58, 2, 20, 3, 36, 5, 71, 7, 17, 6, 48, 
    1,  4, 0, 88, 5, 45, 7, 73, 6,  7, 2, 55, 3, 82, 4,  5, 8, 42, 
    0, 86, 8, 55, 5, 35, 6, 45, 3, 60, 7, 62, 1, 96, 2, 76, 4, 75, 
    8,  7, 7, 56, 0, 48, 6, 75, 3, 67, 4, 96, 5, 85, 1, 33, 2, 77, 
    2, 53, 4, 25, 7, 17, 8, 10, 6, 15, 0, 85, 1, 82, 3, 78, 5, 77, 
    3, 74, 6, 88, 4,  1, 8, 41, 0, 67, 2, 18, 5, 87, 7, 28, 1,  5, 
    4, 66, 0, 40, 2, 67, 8, 95, 3, 62, 6, 39, 5, 14, 1, 36, 7, 30, 
    6, 24, 3, 87, 0, 45, 4, 70, 1, 99, 8, 64, 7, 38, 5, 89, 2, 88, 
    0, 73, 3, 92, 2, 28, 4, 42, 1, 65, 6, 76, 7, 94, 8, 36, 5, 24
  };
  const int q3226[] = {
    9, 9, // Number of jobs and machines
    3, 48, 5, 62, 8, 34, 7, 84, 6, 86, 0, 81, 4, 14, 2, 46, 1, 61, 
    3, 54, 6,  3, 1, 73, 4, 39, 5, 52, 7,  8, 0, 72, 2, 52, 8, 59, 
    0, 85, 7, 84, 1, 20, 8, 71, 5, 51, 2, 85, 3, 59, 4, 15, 6, 90, 
    8, 57, 4, 98, 6, 37, 7, 38, 1, 37, 2, 68, 0, 12, 3, 93, 5, 31, 
    1, 22, 4, 48, 7, 79, 8, 15, 5, 53, 3, 88, 2, 29, 0, 63, 6, 87, 
    1, 35, 3, 35, 8, 84, 5, 70, 2, 57, 7, 32, 6, 66, 4, 47, 0, 79, 
    8, 66, 5, 83, 6, 18, 3, 39, 7, 44, 1,  1, 2, 40, 4, 67, 0, 46, 
    4, 27, 3, 27, 0, 55, 1, 61, 7, 67, 6, 52, 8, 13, 5, 41, 2, 75, 
    4, 79, 1, 47, 6, 98, 5, 72, 2, 82, 3, 35, 7, 98, 0, 41, 8, 83
  };
  const int q3227[] = {
    9, 9, // Number of jobs and machines
    2, 52, 5, 81, 8, 55, 0, 13, 7, 13, 6, 93, 4, 74, 1, 26, 3, 42, 
    6, 56, 0, 69, 4, 22, 3, 59, 8, 21, 5, 99, 1, 94, 7, 64, 2,  1, 
    8, 65, 7, 45, 0, 20, 3, 18, 2, 36, 1, 41, 6, 54, 4, 70, 5, 59, 
    7, 50, 0, 90, 1,  5, 5, 79, 3, 79, 4, 53, 8, 74, 6, 74, 2, 70, 
    3, 94, 8, 24, 4, 36, 0, 85, 1, 82, 5, 50, 7, 46, 6, 60, 2, 67, 
    0, 69, 2, 75, 7,  4, 6, 11, 5, 73, 3, 72, 8, 61, 1, 38, 4, 62, 
    5, 39, 0, 40, 2, 80, 6, 87, 7, 48, 3, 47, 4, 28, 8, 27, 1, 31, 
    3, 10, 1, 22, 4, 19, 0, 20, 7, 45, 5, 89, 6, 38, 2, 23, 8, 86, 
    0, 49, 3, 74, 1, 36, 4, 75, 6, 80, 2, 53, 7, 45, 8, 95, 5, 31
  };
  const int q3228[] = {
    9, 9, // Number of jobs and machines
    8, 34, 0, 34, 5, 11, 6, 93, 3, 58, 4, 91, 2, 32, 7, 84, 1, 34, 
    6, 72, 4, 59, 8, 63, 5, 98, 2,  5, 7, 32, 0, 75, 3, 37, 1, 21, 
    6, 15, 3,  4, 0, 67, 1, 86, 8, 49, 5, 19, 7, 27, 4, 23, 2, 85, 
    8, 27, 3, 80, 5, 31, 1, 62, 4, 77, 7, 57, 0, 12, 2, 35, 6,  8, 
    2, 56, 0, 84, 5, 87, 7, 98, 8, 55, 4, 82, 1, 34, 6, 66, 3, 37, 
    5, 70, 0, 68, 4, 69, 7, 31, 1, 12, 6, 74, 3, 48, 2, 77, 8, 80, 
    2, 41, 7, 20, 8, 70, 1, 58, 6, 22, 0, 66, 4, 13, 3, 91, 5, 95, 
    0,  9, 8, 44, 2, 50, 3, 19, 4, 53, 5, 23, 1, 78, 6, 31, 7,  6, 
    5, 43, 0,  5, 8, 51, 2, 16, 4, 17, 3, 59, 6,  1, 7, 49, 1, 95
  };
  const int q3229[] = {
    9, 9, // Number of jobs and machines
    2, 97, 7, 19, 5, 54, 4,  6, 3, 26, 1, 27, 6, 24, 0, 47, 8, 45, 
    5, 22, 6, 78, 2, 51, 3, 91, 0, 63, 7, 80, 1, 40, 4, 89, 8, 46, 
    7, 29, 8, 62, 0, 36, 4, 70, 6, 25, 3, 49, 2, 21, 5, 49, 1, 36, 
    1, 96, 7, 90, 2, 39, 6,  1, 5, 77, 0, 44, 3, 40, 8, 94, 4, 22, 
    7, 23, 2, 33, 8, 45, 1, 33, 5, 72, 4, 37, 6,  4, 0, 29, 3, 56, 
    3, 48, 6, 56, 5, 43, 1, 15, 0, 47, 8, 54, 2, 60, 7, 32, 4, 97, 
    8, 62, 4, 47, 2, 16, 7, 32, 0,  2, 3, 88, 1, 68, 5, 46, 6,  2, 
    2, 14, 4, 33, 0, 79, 6, 35, 1, 43, 5, 36, 7, 55, 3, 94, 8,  7, 
    5, 76, 1, 38, 3, 77, 0, 22, 4, 65, 8, 53, 6, 37, 7,  8, 2, 45
  };
  const int q3230[] = {
    9, 9, // Number of jobs and machines
    6, 54, 2, 12, 1, 71, 5,  5, 0, 66, 3, 31, 7, 66, 8, 61, 4,  5, 
    7, 59, 1, 83, 5, 90, 8, 13, 0, 43, 2, 93, 4, 57, 3, 64, 6, 46, 
    2, 65, 1, 92, 7, 98, 8, 17, 0, 99, 3, 66, 5, 52, 6, 46, 4, 68, 
    1, 74, 3, 20, 4, 81, 0, 79, 5, 89, 2, 38, 8, 66, 7, 96, 6, 78, 
    4, 70, 7, 33, 6, 52, 3, 85, 1, 13, 0, 71, 5, 64, 8, 72, 2,  3, 
    5, 84, 0, 50, 4, 52, 8, 62, 2, 32, 6, 21, 3, 84, 7,  5, 1, 86, 
    4, 49, 2, 21, 7,  1, 1, 89, 6, 88, 5, 71, 0, 79, 3, 77, 8, 14, 
    8, 70, 2, 28, 6, 33, 5, 11, 1, 87, 0, 60, 7, 40, 3, 66, 4, 90, 
    3, 26, 6, 31, 8, 14, 5, 55, 1, 11, 0, 32, 2, 19, 7, 94, 4, 48
  };
  const int q3231[] = {
    9, 9, // Number of jobs and machines
    2, 42, 7, 59, 4,  2, 3, 79, 8, 54, 1, 87, 6,  5, 5, 26, 0,  9, 
    1, 27, 2, 93, 0,  7, 5, 42, 8,  2, 6, 15, 3, 58, 4, 49, 7, 51, 
    8, 38, 0, 55, 5, 81, 1, 93, 3, 88, 4, 77, 2, 43, 7, 80, 6, 77, 
    8, 49, 4, 47, 5, 76, 3, 63, 7, 45, 2, 70, 0, 10, 6, 56, 1, 31, 
    3, 25, 2, 62, 8, 11, 6,  2, 4, 55, 5, 63, 0, 31, 7, 75, 1, 59, 
    2, 14, 4, 81, 5,  3, 0, 92, 3, 21, 8, 82, 6, 59, 1, 38, 7, 88, 
    2, 84, 1, 59, 3, 45, 4, 83, 0, 96, 5, 12, 8, 80, 6, 55, 7, 86, 
    8, 45, 1, 34, 5, 32, 2, 33, 7, 68, 3, 66, 6, 99, 4, 42, 0, 98, 
    1, 52, 7, 90, 5, 29, 3,  6, 6, 32, 0, 53, 8, 42, 2, 57, 4, 24
  };
  const int q3232[] = {
    9, 9, // Number of jobs and machines
    3, 43, 7, 94, 4, 84, 2,  8, 1, 60, 5, 85, 8, 39, 6, 62, 0, 41, 
    8, 86, 5, 91, 2, 39, 1, 10, 6, 35, 3,  6, 4,  7, 7, 45, 0, 57, 
    5, 68, 2, 21, 8, 16, 3, 41, 0, 29, 6,  4, 7, 74, 1, 91, 4, 39, 
    6,  1, 0, 13, 4, 10, 1, 52, 3, 94, 8, 27, 7, 30, 5, 81, 2, 94, 
    0, 92, 2, 88, 6, 62, 5, 32, 8, 79, 3, 43, 4, 11, 1,  1, 7, 45, 
    7, 11, 4, 52, 3,  7, 2, 83, 8, 89, 6, 13, 1, 64, 5, 85, 0, 40, 
    7, 33, 0, 48, 2, 17, 3, 10, 8,  6, 6, 71, 5, 18, 4, 76, 1, 84, 
    4, 70, 1, 54, 3, 57, 2, 19, 6, 71, 5,  8, 7, 62, 0, 20, 8, 90, 
    2, 90, 6, 85, 8, 80, 3, 76, 4,  7, 0, 41, 5, 40, 7, 70, 1, 88
  };
  const int q3233[] = {
    9, 9, // Number of jobs and machines
    5, 32, 7, 83, 6, 94, 1, 66, 2, 98, 4, 67, 3, 21, 8, 86, 0, 65, 
    4, 99, 7, 44, 0, 94, 1, 70, 8, 61, 3, 34, 6, 10, 2, 36, 5, 12, 
    0, 65, 8, 12, 3, 50, 7, 72, 2, 56, 6, 32, 1, 99, 5, 46, 4, 85, 
    7, 20, 6, 50, 4, 24, 2,  1, 8, 26, 1, 40, 3, 31, 0, 61, 5, 72, 
    4, 26, 3, 24, 2, 97, 0, 66, 6, 47, 7, 30, 5, 69, 1, 78, 8, 15, 
    4, 77, 3, 48, 7, 68, 8, 62, 1, 58, 2, 39, 5, 60, 0, 31, 6,  3, 
    3, 57, 4, 19, 7, 61, 6, 55, 2, 46, 0, 92, 5, 86, 1, 26, 8, 22, 
    4, 46, 7, 11, 2,  6, 5, 54, 0, 80, 6, 99, 8, 40, 1, 23, 3, 59, 
    0, 74, 3, 61, 7, 69, 6, 37, 1, 44, 4, 60, 8, 69, 5, 65, 2, 50
  };
  const int q3234[] = {
    9, 9, // Number of jobs and machines
    0, 65, 6, 67, 3, 73, 7, 32, 5,  6, 2, 79, 1, 56, 4, 53, 8, 21, 
    3,  9, 7,  4, 4, 91, 2, 89, 6, 29, 1, 73, 8, 50, 0, 18, 5, 86, 
    7, 41, 3, 44, 2, 98, 5, 10, 0, 29, 1, 81, 8, 78, 6, 70, 4, 76, 
    5, 76, 4, 78, 8, 89, 2, 26, 1, 15, 0, 93, 6, 20, 7, 88, 3, 81, 
    1, 93, 5, 71, 4, 61, 0, 57, 3, 63, 8, 98, 6, 72, 7, 82, 2, 37, 
    7, 63, 3, 21, 2, 26, 8, 21, 0, 94, 4, 17, 5, 75, 6, 49, 1,  9, 
    6, 25, 8, 31, 0, 24, 4, 23, 2, 89, 5, 24, 1, 10, 7, 84, 3, 26, 
    4, 96, 6, 56, 7, 10, 5,  1, 2, 87, 3, 86, 1, 50, 8, 48, 0, 60, 
    4, 40, 7, 42, 6, 49, 8, 13, 0, 67, 2, 56, 5, 13, 3, 37, 1, 25
  };
  const int q3235[] = {
    9, 9, // Number of jobs and machines
    1, 31, 2, 36, 3, 47, 4, 58, 7, 49, 6, 65, 0,  3, 8, 38, 5, 21, 
    8, 51, 2,  3, 6, 99, 7, 30, 0, 62, 1, 68, 3, 85, 4, 34, 5, 64, 
    1, 54, 0, 62, 2,  6, 8, 37, 5, 29, 6, 12, 7, 77, 4, 33, 3, 56, 
    1, 29, 2, 13, 3,  1, 8, 86, 5, 77, 4, 66, 0, 18, 6, 94, 7, 67, 
    7, 98, 2, 91, 4, 84, 8, 59, 3, 19, 5, 98, 1, 76, 0,  5, 6, 33, 
    4, 15, 2, 80, 5, 28, 1, 18, 7, 55, 3, 32, 0, 72, 8, 52, 6, 22, 
    7, 24, 4, 23, 8, 50, 2, 65, 0, 99, 5, 28, 3, 66, 6, 95, 1, 78, 
    7, 34, 2, 18, 0, 34, 1, 74, 8, 61, 3,  5, 5, 19, 6,  1, 4, 78, 
    6, 79, 0, 97, 4, 35, 3, 78, 5, 26, 8, 63, 1, 70, 7, 87, 2, 33
  };
  const int q3236[] = {
    9, 9, // Number of jobs and machines
    4, 57, 3, 38, 1, 86, 8, 73, 6, 60, 7, 69, 5, 39, 0,  4, 2, 83, 
    1,  4, 0, 32, 2, 51, 8, 16, 7, 57, 4, 28, 5, 60, 6, 33, 3, 35, 
    5, 40, 6,  4, 7, 81, 1, 43, 2, 49, 8, 68, 4, 14, 3, 71, 0, 62, 
    6, 10, 5, 33, 8, 63, 1, 57, 3, 37, 4, 75, 2,  7, 0, 81, 7,  2, 
    7, 77, 0, 95, 4, 51, 1, 97, 2, 56, 3, 46, 5, 11, 8, 13, 6, 56, 
    3,  5, 7, 18, 0, 38, 2,  6, 6, 51, 4,  7, 5, 52, 1, 19, 8,  1, 
    5, 99, 4, 62, 1, 22, 0, 81, 8, 49, 2, 25, 3, 48, 7, 59, 6, 97, 
    6, 55, 0, 69, 1, 43, 3, 46, 2, 46, 4, 37, 8, 49, 7, 95, 5, 96, 
    6, 21, 0, 13, 7, 99, 2, 43, 3, 54, 5, 71, 8, 86, 1, 15, 4, 80
  };
  const int q3237[] = {
    9, 9, // Number of jobs and machines
    4, 52, 8, 83, 3,  4, 2, 36, 6, 17, 1, 33, 0, 75, 7, 41, 5, 95, 
    4, 73, 3, 24, 0, 34, 5, 11, 1, 22, 2, 78, 6, 40, 8, 26, 7, 63, 
    0, 52, 3, 30, 1, 59, 4, 71, 2, 48, 6, 32, 8, 96, 7, 36, 5,  6, 
    7, 40, 4, 58, 8, 33, 2, 46, 3, 70, 6, 94, 5, 87, 0, 39, 1,  5, 
    2, 15, 3, 19, 7, 97, 8, 35, 5, 96, 1, 80, 4, 52, 0, 87, 6, 51, 
    7, 30, 5, 98, 4, 14, 3, 12, 8, 84, 6, 73, 2, 40, 0, 56, 1, 38, 
    7, 76, 8, 92, 5, 44, 0, 15, 3,  9, 2, 83, 4,  1, 1,  2, 6, 96, 
    8, 19, 4,  6, 1, 20, 0, 40, 7, 80, 6, 17, 3, 21, 5, 56, 2,  7, 
    8, 75, 7, 35, 4, 77, 5, 11, 0,  4, 3, 49, 2,  9, 6, 93, 1,  5
  };
  const int q3238[] = {
    9, 9, // Number of jobs and machines
    4, 69, 6, 23, 1, 65, 8, 87, 3,  2, 0, 47, 5, 16, 7, 79, 2, 27, 
    6,  2, 0, 46, 5, 44, 1, 48, 8, 94, 7, 81, 3, 60, 4, 92, 2, 33, 
    0, 72, 4, 23, 1, 15, 3,  4, 5, 50, 6,  4, 8, 69, 7, 30, 2, 71, 
    8, 65, 2, 89, 0, 33, 1, 79, 6, 98, 3,  1, 7, 62, 4, 71, 5, 14, 
    1, 67, 4,  8, 6, 67, 2, 99, 7, 40, 3,  1, 0, 65, 5, 69, 8, 31, 
    3, 72, 7, 42, 5, 72, 6, 56, 2, 93, 0, 85, 8, 69, 1, 77, 4,  2, 
    0, 72, 5, 61, 8, 69, 3, 67, 2, 92, 4,  1, 7, 41, 1, 78, 6, 67, 
    8, 35, 2, 83, 6, 30, 1, 93, 0, 59, 7, 72, 4, 27, 3, 67, 5, 29, 
    3, 12, 8, 23, 5,  3, 7, 82, 4, 97, 2, 21, 1, 74, 0,  2, 6,  3
  };
  const int q3239[] = {
    9, 9, // Number of jobs and machines
    7, 84, 4,  5, 3, 38, 2, 90, 5, 59, 1, 97, 0, 69, 8, 78, 6, 87, 
    0, 55, 2, 77, 8, 63, 4, 66, 1, 96, 3,  2, 5,  7, 6, 70, 7, 64, 
    6, 25, 5, 64, 3, 90, 1, 32, 4, 48, 0, 24, 7, 78, 2, 54, 8, 69, 
    3, 76, 7, 17, 1, 76, 8, 33, 2, 19, 0, 58, 6, 39, 5, 65, 4, 23, 
    6, 19, 7, 13, 2, 23, 1, 14, 3, 75, 5,  7, 4, 46, 0, 62, 8, 61, 
    6, 23, 3, 71, 5, 73, 0,  5, 8, 32, 4, 84, 7, 83, 1, 74, 2,  6, 
    4, 79, 8, 98, 3, 23, 2, 73, 7, 38, 5,  3, 6, 92, 0, 63, 1, 67, 
    7, 21, 8, 69, 6, 65, 1,  9, 0, 14, 4, 80, 2, 19, 3, 53, 5, 50, 
    0, 57, 2, 73, 5, 45, 3, 43, 1, 45, 8, 25, 6, 12, 7, 52, 4, 79
  };
  const int q3240[] = {
    9, 9, // Number of jobs and machines
    7,  9, 8, 36, 6, 99, 1, 28, 0, 85, 3,  6, 4, 26, 2, 60, 5,  7, 
    2, 36, 3, 82, 5, 82, 7, 50, 1,  5, 6, 18, 4, 87, 8, 17, 0, 35, 
    1, 59, 5, 41, 2, 99, 6, 18, 8, 96, 3, 72, 0, 20, 4,  3, 7, 41, 
    4, 84, 3, 74, 2,  7, 6, 45, 1, 70, 8, 72, 0, 84, 5,  2, 7, 92, 
    3, 68, 4, 38, 8, 23, 5,  4, 1, 93, 0,  5, 7, 44, 2, 33, 6, 60, 
    6, 83, 5,  6, 1, 60, 7,  9, 8, 61, 2, 64, 3, 66, 0, 29, 4, 10, 
    0, 98, 8, 17, 7,  7, 3, 78, 6, 83, 5, 25, 1, 66, 2, 70, 4, 91, 
    7, 27, 2, 22, 8,  3, 6, 73, 5, 88, 1, 62, 4, 88, 0, 79, 3, 10, 
    3, 70, 1, 14, 6, 26, 0, 63, 7, 96, 5, 92, 4, 95, 8, 31, 2, 49
  };
  const int q3241[] = {
    9, 9, // Number of jobs and machines
    6, 86, 8, 24, 3, 91, 0, 17, 5, 13, 1,  8, 7, 16, 4, 36, 2, 32, 
    3, 66, 7, 88, 0, 39, 8, 52, 2, 14, 5, 15, 4,  2, 6,  7, 1, 86, 
    7, 28, 1, 92, 6, 52, 5, 12, 3, 60, 2,  1, 4, 98, 8, 69, 0, 66, 
    6, 12, 8, 46, 0, 52, 2, 39, 4, 82, 3, 52, 7, 53, 5,  7, 1, 23, 
    6, 71, 5, 13, 4, 96, 2, 91, 3, 67, 7, 91, 1, 38, 8, 24, 0, 65, 
    5, 46, 7, 39, 6, 19, 1, 26, 4, 56, 3, 31, 0, 13, 8, 56, 2, 50, 
    7, 44, 3, 39, 8, 53, 2, 44, 6, 78, 4, 32, 5, 40, 1, 48, 0, 46, 
    4, 62, 8, 56, 3, 98, 5,  1, 1, 10, 7, 17, 6, 66, 0, 40, 2,  7, 
    1, 34, 8, 78, 5,  7, 3, 50, 0, 66, 4,  7, 2, 83, 7, 29, 6, 52
  };
  const int q3242[] = {
    9, 9, // Number of jobs and machines
    1, 18, 2, 24, 6, 99, 7, 87, 4, 28, 3,  3, 0, 79, 8, 70, 5, 47, 
    4, 28, 0, 52, 8, 65, 3,  4, 7, 69, 2, 22, 1, 35, 6, 90, 5, 49, 
    3, 89, 7, 30, 8, 98, 0, 89, 5, 33, 6, 71, 2, 30, 4, 29, 1,  8, 
    5, 93, 1, 26, 4, 54, 8, 74, 0, 20, 2, 35, 7,  4, 6, 34, 3, 66, 
    1, 45, 0, 34, 2, 63, 6, 78, 7, 44, 3, 61, 5, 39, 4, 59, 8, 21, 
    3, 50, 5, 84, 7, 91, 4,  2, 2, 11, 8, 95, 1, 73, 0, 73, 6, 12, 
    8, 25, 6, 91, 7, 68, 3, 32, 4, 53, 2, 77, 5, 59, 0,  2, 1,  9, 
    4, 60, 3, 43, 5,  2, 8, 42, 2, 60, 1, 45, 6,  8, 7, 52, 0, 26, 
    5, 80, 0, 82, 3, 60, 8, 57, 2, 12, 4, 84, 1, 43, 6, 50, 7,  1
  };
  const int q3243[] = {
    9, 9, // Number of jobs and machines
    7, 43, 6, 92, 0, 20, 2, 85, 1, 41, 3, 29, 4,  5, 8,  1, 5, 38, 
    5, 56, 0, 29, 3,  4, 8, 45, 4, 69, 2, 76, 7, 63, 6, 87, 1, 77, 
    0, 22, 3, 52, 1, 88, 6, 83, 8, 24, 2, 32, 4, 16, 7, 27, 5, 35, 
    4, 33, 6, 64, 8, 46, 2, 76, 0,  6, 5, 95, 3, 33, 1, 48, 7, 39, 
    2, 85, 1, 44, 5, 36, 3, 85, 0, 79, 6, 71, 4, 89, 8,  1, 7,  9, 
    2, 58, 8, 32, 7,  3, 1, 77, 5,  1, 0, 65, 6, 58, 4, 20, 3, 77, 
    0, 88, 4, 69, 5, 52, 3,  3, 8, 35, 6, 21, 2, 75, 1, 67, 7, 72, 
    7, 10, 2, 62, 1,  4, 0, 93, 8, 33, 6, 96, 3, 43, 4, 16, 5,  3, 
    8,  4, 2, 66, 3, 58, 4, 22, 7, 86, 0, 22, 1, 56, 5, 10, 6, 73
  };
  const int q3244[] = {
    9, 9, // Number of jobs and machines
    7, 52, 3, 84, 4, 68, 6, 39, 0,  5, 8, 51, 5, 48, 2,  8, 1, 77, 
    2, 60, 0, 92, 5, 52, 3,  9, 1,  3, 8, 91, 7, 66, 4, 32, 6, 29, 
    5, 67, 6, 38, 8, 48, 4, 74, 7, 92, 2,  4, 3, 90, 1, 43, 0, 44, 
    5, 64, 4, 46, 1, 53, 0, 62, 8, 35, 3, 23, 2, 10, 6, 18, 7, 22, 
    0, 79, 7, 66, 4, 72, 8, 40, 1,  7, 6, 69, 3, 31, 5, 28, 2, 43, 
    2, 66, 1, 89, 4, 28, 3, 96, 5, 93, 7, 51, 8, 10, 0, 16, 6, 70, 
    0, 81, 6, 99, 1, 96, 2,  4, 4,  6, 7, 94, 8, 57, 5, 53, 3, 45, 
    8, 32, 3, 65, 5, 89, 0, 56, 2, 74, 1, 72, 7, 34, 4, 98, 6, 38, 
    5, 61, 7, 24, 6, 95, 2,  5, 8, 90, 0, 95, 4, 21, 3, 42, 1, 62
  };
  const int q3245[] = {
    9, 9, // Number of jobs and machines
    2, 16, 5, 77, 1, 17, 8, 72, 4, 92, 3, 63, 6, 85, 0,  5, 7, 45, 
    6, 36, 5, 77, 3, 55, 2, 97, 8, 99, 0, 51, 7, 78, 4, 56, 1, 66, 
    6, 67, 1, 14, 8, 80, 5, 44, 7, 33, 4, 85, 3, 26, 0, 16, 2, 30, 
    4, 88, 3, 41, 6, 52, 5, 50, 1, 26, 2, 93, 8, 79, 0, 63, 7, 60, 
    0, 43, 5, 72, 6, 68, 8,  5, 2, 51, 4, 56, 3,  6, 7, 14, 1, 60, 
    8, 55, 2, 99, 0, 28, 3, 92, 1, 32, 7, 87, 6, 41, 4, 30, 5, 73, 
    3, 30, 2, 75, 7, 97, 8, 27, 6, 76, 0, 60, 4,  2, 1, 89, 5, 52, 
    2,  8, 7, 66, 3, 25, 0,  6, 4, 40, 6,  6, 5, 14, 8, 95, 1, 38, 
    1, 75, 2, 41, 3, 70, 7, 65, 5, 15, 8, 93, 0, 26, 6, 64, 4, 61
  };
  const int q3246[] = {
    9, 9, // Number of jobs and machines
    7, 12, 2,  9, 6, 18, 8, 62, 5, 54, 4,  4, 0, 68, 1, 32, 3, 50, 
    3, 36, 8, 21, 5, 10, 2, 29, 7, 69, 6, 16, 4, 78, 1, 32, 0, 82, 
    2, 54, 6, 34, 7, 11, 4, 14, 5, 70, 1, 27, 8, 93, 0, 77, 3, 56, 
    4, 80, 8, 69, 6, 50, 2, 94, 7, 44, 1, 25, 0, 22, 5, 88, 3, 44, 
    8, 34, 3, 69, 2, 52, 1, 18, 0, 19, 5, 70, 4,  7, 6, 47, 7, 38, 
    3, 85, 7, 36, 2, 14, 6, 48, 5, 82, 1, 29, 4, 92, 8, 69, 0, 13, 
    5, 18, 1, 99, 0, 53, 2,  9, 6, 16, 3, 84, 7, 15, 4, 67, 8, 36, 
    3, 50, 2,  6, 5, 49, 4, 60, 6, 91, 8, 76, 0, 39, 7, 12, 1, 47, 
    0, 15, 6, 10, 7, 65, 3, 77, 5, 88, 8, 57, 2, 47, 4,  7, 1, 41
  };
  const int q3247[] = {
    9, 9, // Number of jobs and machines
    1, 48, 7, 63, 8, 73, 2, 70, 3, 46, 5, 72, 0, 49, 4, 78, 6, 20, 
    7, 48, 3, 82, 5, 56, 6, 70, 0, 35, 1, 43, 8, 51, 2, 65, 4, 84, 
    3, 85, 2, 43, 1, 16, 7, 83, 8,  1, 5, 49, 6, 39, 4, 20, 0, 30, 
    3, 85, 8, 27, 6, 78, 1, 62, 7, 93, 0, 64, 5, 91, 4, 39, 2,  9, 
    1,  9, 2, 80, 8, 30, 7, 91, 5, 16, 3, 78, 4, 22, 6, 35, 0, 11, 
    0, 42, 6, 90, 5, 90, 8, 10, 7,  2, 4, 93, 3, 22, 1, 85, 2, 77, 
    0, 57, 7, 74, 6, 49, 8, 52, 3, 48, 4, 26, 1, 10, 2, 32, 5, 11, 
    7, 38, 0, 43, 3,  1, 1, 95, 4, 57, 5, 82, 2, 57, 6, 71, 8, 54, 
    8, 68, 6, 30, 7, 28, 2,  3, 5,  6, 3, 45, 0, 83, 1, 17, 4, 64
  };
  const int q3248[] = {
    9, 9, // Number of jobs and machines
    2, 14, 5, 12, 7, 63, 8, 19, 4, 39, 0, 45, 6, 56, 3, 88, 1, 33, 
    3, 74, 0, 69, 1, 48, 2, 74, 6, 15, 4, 62, 5, 14, 7, 49, 8, 69, 
    7, 19, 0, 79, 8, 29, 5, 41, 6, 27, 2, 44, 1, 21, 4, 22, 3, 98, 
    4, 73, 1, 28, 3,  7, 2, 28, 0, 32, 6,  9, 7, 61, 8, 16, 5, 19, 
    0, 91, 2, 94, 5, 26, 4, 92, 6, 36, 1, 44, 8, 51, 7, 16, 3, 58, 
    6, 66, 4, 17, 3, 62, 1, 24, 0, 72, 2, 86, 5, 99, 7, 59, 8, 60, 
    6, 15, 2, 28, 5,  2, 7, 91, 1, 19, 0, 15, 4,  8, 3, 22, 8, 43, 
    1, 16, 7, 22, 6, 47, 3, 40, 2, 58, 8, 30, 5, 82, 0, 32, 4,  9, 
    2, 95, 4, 17, 6, 85, 0, 60, 1, 21, 8, 40, 5, 59, 3, 22, 7, 75
  };
  const int q3249[] = {
    9, 9, // Number of jobs and machines
    3,  1, 7, 50, 4, 70, 6, 59, 2, 73, 1, 40, 0, 53, 8, 53, 5, 54, 
    6, 31, 1, 96, 8, 85, 7, 67, 2, 53, 4, 66, 3, 30, 5, 69, 0, 15, 
    4, 89, 6, 84, 8, 76, 5,  1, 0, 46, 7, 94, 1, 12, 2, 25, 3, 85, 
    5, 37, 6, 21, 1, 48, 3, 83, 4, 42, 2, 66, 7, 60, 0, 32, 8,  2, 
    5, 59, 7, 58, 4, 12, 0, 55, 6, 36, 1, 41, 2, 59, 8, 35, 3, 47, 
    4, 53, 2, 90, 0, 88, 6, 92, 1, 95, 5,  3, 8, 99, 3, 62, 7, 96, 
    3, 43, 2, 40, 7, 95, 6, 62, 5, 18, 1, 98, 4, 75, 0, 12, 8, 12, 
    6, 95, 4, 60, 1, 55, 8, 97, 3, 11, 5, 50, 2, 46, 7, 16, 0, 11, 
    1, 56, 3, 49, 5,  7, 8, 52, 0, 71, 6, 29, 7, 22, 2, 31, 4, 50
  };
  const int q3250[] = {
    9, 9, // Number of jobs and machines
    7, 76, 6, 52, 5, 28, 4, 46, 1, 20, 0, 27, 8,  1, 2, 93, 3, 82, 
    6, 98, 1, 95, 5, 80, 4, 53, 0, 15, 7, 54, 3, 19, 2, 34, 8, 71, 
    8, 75, 2, 52, 5, 29, 6, 10, 4, 32, 1, 43, 0,  5, 7, 60, 3, 62, 
    0, 80, 5, 85, 1, 60, 4, 70, 7, 72, 6, 48, 8, 84, 3, 58, 2, 26, 
    4, 39, 6, 53, 3,  2, 1, 66, 0, 13, 8, 84, 5, 44, 2,  8, 7, 15, 
    4, 33, 1, 70, 5, 65, 6, 94, 0, 71, 2, 73, 7, 91, 8, 79, 3, 92, 
    7, 23, 3, 91, 6, 90, 1, 55, 4, 50, 0,  5, 5, 43, 8, 79, 2, 39, 
    5, 65, 3, 33, 0, 33, 2, 87, 6, 63, 1, 66, 8, 25, 4, 26, 7, 98, 
    5, 43, 4, 62, 3, 20, 2, 54, 0,  4, 8, 37, 7, 61, 1, 62, 6, 55
  };
  const int q3251[] = {
    9, 9, // Number of jobs and machines
    4,  9, 0, 88, 7, 88, 1, 14, 8, 26, 2, 90, 3, 61, 6, 28, 5, 67, 
    8, 31, 0, 82, 3,  9, 6, 35, 4, 63, 2, 19, 5, 79, 7, 93, 1, 66, 
    6, 29, 0, 30, 8, 61, 4, 38, 3, 72, 5, 20, 1, 51, 7, 98, 2,  3, 
    7, 34, 2, 56, 1, 96, 5, 27, 4, 96, 6, 99, 0, 62, 8, 59, 3,  7, 
    0, 52, 3, 42, 2, 29, 7, 73, 1, 92, 5,  1, 8, 17, 4, 36, 6, 56, 
    6, 62, 8, 69, 4, 25, 5, 52, 0, 59, 1, 95, 7,  3, 2, 14, 3, 80, 
    8, 40, 4, 70, 6, 44, 0, 33, 1, 72, 7, 24, 2, 51, 5, 60, 3, 82, 
    3, 85, 5,  3, 1, 32, 4,  4, 2, 23, 7, 90, 8, 72, 6, 37, 0, 12, 
    5, 90, 6, 47, 8, 67, 3, 51, 7, 16, 2, 43, 0, 40, 1, 63, 4, 20
  };
  const int q3252[] = {
    9, 9, // Number of jobs and machines
    3, 12, 6, 43, 4, 40, 1, 77, 5, 20, 2,  4, 8, 84, 7, 90, 0, 24, 
    7, 60, 1,  5, 0, 45, 3, 20, 2,  6, 5, 59, 8, 22, 4,  1, 6, 23, 
    0,  2, 1, 36, 6, 72, 8, 82, 2,  1, 7, 76, 3, 83, 4,  5, 5, 37, 
    7, 34, 6, 88, 0, 43, 8, 10, 4, 14, 3, 23, 1, 57, 5,  9, 2, 67, 
    7,  4, 3, 84, 2, 77, 0, 50, 5, 75, 8, 49, 4, 15, 1,  1, 6, 17, 
    6,  5, 0, 74, 4, 41, 5, 62, 7,  2, 8, 81, 3, 60, 1, 97, 2, 76, 
    8, 44, 2, 91, 4, 80, 3, 46, 1, 85, 0, 45, 7, 37, 5, 77, 6, 62, 
    1, 66, 7, 50, 0, 49, 8,  1, 4, 50, 5,  3, 3, 92, 6, 90, 2, 29, 
    8, 99, 4, 95, 3, 12, 1,  7, 6,  6, 0, 75, 5, 22, 7, 83, 2, 59
  };
  const int q3253[] = {
    9, 9, // Number of jobs and machines
    2, 40, 6, 81, 7, 85, 3, 45, 0, 70, 5, 75, 1, 43, 8, 95, 4, 92, 
    8, 96, 1, 77, 2,  9, 7,  8, 6, 57, 3, 68, 0,  1, 5, 98, 4, 82, 
    0, 59, 5, 67, 1, 95, 2, 15, 7, 94, 3, 86, 6, 81, 8, 35, 4, 67, 
    0, 17, 2, 43, 8, 80, 6, 71, 5, 34, 3, 91, 1, 69, 7,  4, 4, 39, 
    6, 86, 4, 33, 7, 91, 3, 70, 2, 54, 0, 36, 1, 51, 8, 86, 5,  6, 
    2, 11, 7, 28, 3, 18, 8, 36, 1, 36, 6, 35, 0, 12, 4, 95, 5, 60, 
    4,  3, 0, 68, 6, 96, 2, 55, 3, 90, 8, 17, 7, 92, 1,  7, 5, 73, 
    3, 15, 7, 47, 6, 65, 8, 72, 4, 15, 2, 96, 5, 30, 1, 39, 0, 39, 
    2, 16, 4, 75, 0, 59, 5, 27, 8, 76, 6, 26, 3, 27, 7, 58, 1, 81
  };
  const int q3254[] = {
    9, 9, // Number of jobs and machines
    1, 43, 3, 47, 6, 87, 5, 45, 7, 55, 2, 93, 8, 74, 0, 28, 4, 11, 
    7, 14, 8, 73, 0, 95, 3, 85, 6, 18, 2,  6, 1, 48, 5, 94, 4, 51, 
    0, 13, 8, 81, 7, 91, 4, 24, 6, 26, 1, 13, 2, 46, 5, 37, 3, 22, 
    1, 36, 5, 95, 3, 98, 7, 51, 4,  9, 8, 80, 6, 39, 0, 23, 2, 48, 
    1, 77, 8, 60, 4, 36, 3, 40, 2, 24, 5, 92, 6, 37, 7, 82, 0, 90, 
    5, 41, 0, 52, 3, 26, 6, 70, 4, 30, 1, 54, 8, 81, 7,  9, 2, 65, 
    4, 80, 0,  2, 5, 16, 6, 16, 8, 52, 1, 72, 3, 52, 7, 37, 2, 20, 
    7, 32, 8, 89, 1, 96, 3, 11, 5, 60, 6, 60, 2, 64, 0, 81, 4, 31, 
    7, 13, 2, 56, 8, 89, 3, 29, 5, 76, 0, 28, 6, 88, 1, 79, 4, 18
  };
  const int q3255[] = {
    9, 9, // Number of jobs and machines
    1, 53, 8, 53, 2, 67, 3,  5, 6, 70, 4,  7, 5, 20, 0, 73, 7, 87, 
    6, 13, 2, 99, 5, 64, 3, 78, 8, 41, 7, 70, 0, 92, 1, 86, 4, 79, 
    0, 13, 7,  4, 6, 41, 2, 64, 1, 49, 4, 90, 5, 29, 8, 84, 3, 50, 
    5, 92, 6, 82, 1, 71, 2, 60, 7,  6, 3, 19, 4, 11, 0, 97, 8, 48, 
    7, 17, 8, 46, 2, 57, 4, 19, 5, 53, 0, 48, 6, 22, 3, 50, 1, 81, 
    2, 41, 6, 29, 5, 40, 4, 30, 7, 77, 1, 24, 3,  6, 8, 92, 0, 33, 
    2, 76, 3, 25, 4, 39, 5, 47, 0, 24, 7, 57, 6, 91, 1, 31, 8,  3, 
    5, 16, 6, 57, 2, 36, 0,  5, 7,  9, 3, 77, 4, 37, 1, 68, 8, 88, 
    8, 83, 6, 38, 2, 78, 5, 49, 3,  4, 1,  4, 7, 15, 0, 73, 4, 19
  };
  const int q3256[] = {
    9, 9, // Number of jobs and machines
    1, 16, 6, 25, 8, 48, 2, 83, 7, 14, 0, 94, 4, 43, 5, 21, 3, 97, 
    5, 38, 1,  3, 6, 74, 2, 75, 7, 80, 8, 18, 3,  1, 0, 57, 4, 56, 
    2, 83, 1, 41, 0, 78, 8, 85, 7, 16, 3, 71, 5, 21, 6, 59, 4, 44, 
    7, 27, 8, 63, 3, 87, 2, 92, 6, 76, 0, 73, 1, 19, 5, 94, 4, 93, 
    7, 57, 6,  7, 2, 26, 0, 13, 3, 36, 1, 79, 4, 96, 5, 71, 8, 78, 
    4, 45, 0, 56, 7, 42, 3, 87, 6, 90, 8, 30, 2, 62, 5, 88, 1, 41, 
    4, 13, 1, 44, 8, 20, 3, 11, 2, 62, 5, 29, 0, 12, 6, 57, 7, 62, 
    4,  9, 0, 53, 6, 99, 1, 25, 8, 76, 2, 81, 7, 50, 5, 51, 3, 93, 
    3, 72, 0, 46, 6, 91, 5, 49, 4, 57, 1, 15, 8, 63, 2, 85, 7, 81
  };
  const int q3257[] = {
    9, 9, // Number of jobs and machines
    7, 23, 1, 83, 2, 19, 3, 36, 8, 92, 5, 83, 6, 51, 0, 81, 4, 31, 
    6, 61, 7, 18, 5, 21, 1, 28, 8, 62, 0, 14, 3, 53, 4, 62, 2, 47, 
    3,  9, 8,  4, 1, 52, 0, 83, 2, 19, 7, 51, 6, 46, 5, 64, 4, 69, 
    8, 42, 2, 62, 0, 10, 6, 84, 5, 26, 3, 81, 4, 96, 7, 27, 1, 32, 
    5, 74, 4, 21, 0, 88, 2, 60, 1, 75, 6, 95, 3, 47, 8, 42, 7, 38, 
    2, 66, 5, 59, 0,  9, 4, 22, 1, 78, 7, 55, 6, 39, 8,  3, 3, 64, 
    7, 90, 3, 81, 1, 55, 4, 85, 5, 98, 0, 82, 6, 11, 8, 59, 2, 62, 
    8, 86, 1, 71, 4, 31, 2,  4, 3, 67, 6, 46, 7, 37, 5, 89, 0,  5, 
    0, 73, 2, 40, 8, 63, 4, 44, 7, 14, 3, 80, 6, 20, 5, 60, 1, 72
  };
  const int q3258[] = {
    9, 9, // Number of jobs and machines
    5, 46, 0, 58, 3, 39, 1, 48, 7, 29, 8, 64, 6, 67, 4, 31, 2, 21, 
    2, 42, 6, 55, 0, 47, 7, 81, 4, 66, 5, 11, 8, 50, 3, 94, 1, 35, 
    8, 46, 5, 65, 3, 48, 1, 89, 0, 33, 4, 98, 6, 91, 7,  5, 2, 27, 
    6, 91, 7, 99, 4, 78, 8, 36, 0, 44, 2, 82, 3, 64, 5, 91, 1, 85, 
    4, 26, 7, 35, 8, 59, 6, 25, 3, 56, 0, 24, 2, 83, 1, 21, 5, 74, 
    6, 91, 2, 22, 5, 15, 3, 60, 4, 32, 8, 10, 0, 14, 1, 34, 7, 42, 
    8, 80, 5, 30, 4, 66, 7,  3, 0, 33, 6, 73, 1, 53, 2, 51, 3,  4, 
    4,  2, 1, 94, 5, 15, 0, 53, 7, 46, 6,  4, 8, 48, 3, 64, 2, 13, 
    2, 95, 4, 62, 7, 98, 3, 62, 6, 92, 5, 11, 8, 19, 0, 26, 1, 14
  };
  const int q3259[] = {
    9, 9, // Number of jobs and machines
    7, 56, 3, 79, 4, 46, 6, 67, 8,  2, 1, 79, 5, 24, 2, 81, 0, 58, 
    4, 71, 2, 57, 8, 74, 5, 49, 0, 51, 7, 49, 1, 10, 6, 95, 3, 38, 
    6, 47, 0, 77, 3, 57, 5, 27, 2,  9, 7, 85, 4, 29, 1,  8, 8, 47, 
    7, 65, 6, 59, 5, 28, 3, 55, 1, 95, 8, 51, 2, 57, 0, 61, 4, 43, 
    5, 35, 7, 89, 3, 39, 4,  7, 6, 11, 1, 71, 0, 64, 2, 85, 8, 88, 
    1, 82, 8, 72, 7, 83, 0, 61, 3, 33, 2, 62, 5, 84, 6, 13, 4, 26, 
    4, 63, 3, 67, 7, 89, 5, 16, 0, 33, 1, 94, 6, 91, 8, 56, 2, 28, 
    5, 39, 8, 25, 1,  9, 7, 53, 0, 89, 3, 31, 4, 75, 6, 62, 2, 76, 
    2, 50, 8, 65, 5, 74, 6, 80, 0,  6, 4, 64, 3, 51, 1, 42, 7, 33
  };
  const int q3260[] = {
    9, 9, // Number of jobs and machines
    7, 74, 3, 27, 0, 88, 4, 47, 6, 57, 5, 37, 2, 59, 1, 24, 8, 89, 
    0, 63, 4, 54, 8, 87, 1, 82, 5, 90, 6, 58, 7, 32, 2, 89, 3, 54, 
    5, 51, 8, 11, 1, 61, 3, 23, 2, 87, 6, 94, 7, 33, 4, 12, 0, 24, 
    8, 68, 7, 15, 2, 96, 0, 73, 6, 76, 5, 13, 3,  5, 1, 26, 4, 38, 
    2,  3, 3,  4, 5, 33, 0, 64, 6, 60, 8, 20, 4, 95, 1, 26, 7, 45, 
    3, 45, 8, 79, 7, 80, 2, 38, 5, 71, 4, 17, 0, 53, 6, 66, 1, 51, 
    3, 67, 1, 23, 4, 98, 5, 88, 7, 22, 0, 45, 2, 88, 6, 94, 8, 62, 
    8, 26, 3, 26, 6, 25, 2, 39, 7, 57, 5, 71, 4, 50, 0, 84, 1, 45, 
    2, 50, 1, 99, 4, 62, 0, 24, 3, 17, 6, 77, 8, 43, 7,  3, 5,  2
  };
  const int q3261[] = {
    9, 9, // Number of jobs and machines
    8, 58, 7, 17, 4,  9, 2, 17, 3,  6, 1, 59, 5, 33, 0, 38, 6, 63, 
    1, 66, 0, 50, 6, 97, 5, 85, 4, 77, 2, 71, 8, 93, 3, 64, 7, 90, 
    3, 38, 5,  5, 1, 49, 4, 83, 0, 70, 2,  9, 6, 23, 7, 44, 8,  4, 
    8, 60, 6, 67, 2, 82, 1, 58, 4, 21, 5, 42, 0,  8, 7, 39, 3, 37, 
    7, 64, 4, 46, 3, 99, 1, 82, 8, 67, 5, 90, 2, 47, 6, 92, 0, 13, 
    8, 17, 1, 21, 7, 62, 6, 79, 5, 92, 0, 63, 4, 74, 3, 24, 2, 50, 
    2, 18, 6, 17, 8, 84, 4, 98, 3, 53, 5, 80, 1, 97, 7, 15, 0, 42, 
    4, 44, 3, 47, 6,  1, 7, 65, 2, 25, 1, 84, 8, 98, 5, 74, 0, 39, 
    1, 47, 5, 77, 0, 17, 7, 31, 2, 80, 4, 23, 3, 61, 8, 52, 6, 68
  };
  const int q3262[] = {
    9, 9, // Number of jobs and machines
    8, 84, 2,  9, 1, 50, 6, 96, 3, 39, 7, 74, 5, 65, 0, 23, 4,  4, 
    1, 86, 8, 83, 3, 78, 4, 97, 6, 17, 7, 20, 5,  3, 0, 21, 2, 62, 
    7, 18, 6, 91, 3, 34, 5, 57, 0, 51, 2, 59, 1, 85, 8, 62, 4, 74, 
    4, 83, 0, 80, 5, 64, 8, 47, 2, 80, 3, 57, 7, 22, 6, 31, 1, 77, 
    2,  1, 1, 47, 0, 46, 8, 23, 7,  6, 6, 35, 3, 12, 4, 31, 5, 42, 
    6, 99, 3,  9, 4,  4, 8, 96, 0, 13, 5, 51, 7, 16, 2,  1, 1, 55, 
    3, 26, 5, 83, 4, 36, 1, 60, 2,  2, 0,  8, 6, 34, 7, 23, 8, 69, 
    4, 85, 6, 90, 3, 70, 5, 28, 8, 19, 1, 62, 2, 56, 0, 19, 7, 67, 
    2, 32, 1, 16, 8, 42, 6, 64, 3, 97, 4, 82, 0, 61, 5, 35, 7, 34
  };
  const int q3263[] = {
    9, 9, // Number of jobs and machines
    1, 35, 8,  9, 7, 13, 2, 29, 6, 68, 5, 21, 4, 76, 0, 32, 3, 63, 
    5, 74, 8, 82, 4, 84, 3, 24, 0,  6, 7, 53, 2, 73, 1, 75, 6, 32, 
    4, 10, 2, 28, 8, 21, 6, 61, 1, 29, 3, 14, 5, 73, 7, 31, 0,  5, 
    4, 30, 5, 39, 0, 49, 6, 82, 8, 61, 3, 63, 2, 54, 1, 50, 7, 48, 
    6, 35, 0, 96, 8, 54, 1, 76, 7, 23, 4,  5, 3, 58, 2, 93, 5, 55, 
    7, 75, 6, 47, 4, 95, 0, 40, 3, 53, 5, 16, 1,  5, 8, 52, 2, 46, 
    5, 15, 8, 93, 7, 34, 0, 23, 3, 27, 1, 14, 2, 64, 6, 18, 4, 25, 
    0, 56, 4, 58, 6, 82, 7, 10, 5, 57, 1, 85, 2,  4, 8, 20, 3, 72, 
    0, 53, 5, 32, 4, 35, 7, 28, 6, 73, 8, 21, 2, 98, 1, 40, 3, 25
  };
  const int q3264[] = {
    9, 9, // Number of jobs and machines
    8, 32, 0, 65, 5, 75, 2, 23, 4, 12, 6, 96, 7, 22, 3, 29, 1, 13, 
    1, 99, 4, 47, 7, 83, 6, 18, 5, 87, 3,  1, 8, 12, 0, 25, 2, 91, 
    8, 80, 1, 61, 5, 17, 4, 65, 6, 42, 7, 15, 3, 85, 2, 97, 0, 20, 
    2, 76, 1, 90, 0, 60, 7, 50, 8, 34, 5, 35, 6, 23, 3, 85, 4, 49, 
    7, 77, 6, 25, 1, 36, 5,  2, 3, 23, 0, 21, 8, 12, 2, 27, 4, 62, 
    0, 86, 3, 39, 6, 22, 7, 88, 8, 43, 1, 63, 2, 66, 5,  5, 4, 13, 
    5, 74, 7, 88, 1, 69, 6, 88, 2, 51, 4, 24, 8, 23, 0, 26, 3, 77, 
    3, 45, 5, 58, 6,  2, 2,  8, 4, 41, 0, 84, 8, 84, 7, 78, 1, 30, 
    0,  2, 3, 66, 2, 49, 1, 29, 7, 47, 8, 72, 4, 85, 5, 51, 6,  2
  };
  const int q3265[] = {
    9, 9, // Number of jobs and machines
    3,  2, 5, 80, 4, 57, 0, 58, 8, 20, 1, 61, 6,  8, 2, 47, 7, 29, 
    3, 10, 6, 35, 8, 63, 2, 37, 0, 46, 5,  2, 7, 78, 1, 14, 4, 18, 
    8, 11, 6, 82, 1, 70, 0, 60, 3, 34, 7, 13, 4,  5, 5, 17, 2, 93, 
    3, 45, 1, 38, 8, 65, 4, 47, 7, 22, 6,  6, 2, 36, 0, 72, 5, 37, 
    5,  7, 4, 92, 3, 33, 0, 57, 2, 26, 7, 21, 6,  1, 8, 32, 1, 56, 
    6, 29, 5, 72, 4, 41, 3, 12, 1, 55, 7, 90, 8, 31, 0, 43, 2, 21, 
    5, 51, 8, 69, 6, 77, 3, 60, 0, 12, 4, 51, 7, 26, 2, 81, 1, 94, 
    8, 97, 5, 84, 0, 45, 4, 41, 3, 87, 7, 67, 1, 61, 6, 76, 2, 21, 
    3, 99, 1, 36, 2, 56, 0, 73, 4, 93, 7, 75, 6, 98, 8, 22, 5, 67
  };
  const int q3266[] = {
    9, 9, // Number of jobs and machines
    6, 89, 0, 34, 1, 94, 4, 58, 8,  5, 3, 27, 7, 21, 2, 96, 5, 51, 
    1, 77, 3,  5, 8, 71, 2, 87, 4, 59, 6, 68, 5, 44, 7, 52, 0,  8, 
    0, 32, 2, 79, 6, 99, 3,  2, 7, 12, 4, 51, 8, 79, 1,  5, 5, 56, 
    2, 48, 3, 97, 5, 42, 1, 26, 6, 73, 0, 36, 4, 14, 8, 38, 7, 76, 
    6, 10, 2, 48, 3, 17, 8, 76, 0, 69, 1, 12, 5, 53, 7, 85, 4, 19, 
    5, 76, 6, 13, 1, 32, 8, 43, 4, 14, 3, 23, 7, 83, 2, 17, 0, 60, 
    3,  5, 6, 74, 2, 52, 1,  3, 4, 47, 7, 21, 8, 25, 0, 48, 5, 53, 
    1, 98, 2, 62, 0, 89, 8, 40, 4, 68, 7, 67, 6, 49, 5, 42, 3, 85, 
    7, 34, 2, 68, 6, 78, 8, 18, 3, 61, 5,  9, 4, 48, 1, 40, 0, 90
  };
  const int q3267[] = {
    9, 9, // Number of jobs and machines
    7, 36, 4, 48, 0, 31, 2, 96, 1, 13, 5, 63, 6, 31, 3, 62, 8, 48, 
    6,  6, 3, 86, 7, 48, 5,  4, 1, 44, 8,  9, 2, 90, 0, 97, 4, 29, 
    7,  6, 1, 35, 6, 48, 3,  8, 2, 96, 8, 70, 4, 29, 0, 95, 5, 21, 
    7, 13, 3, 54, 5, 13, 6, 87, 8, 36, 1, 78, 2, 89, 4,  9, 0, 39, 
    5, 94, 7, 82, 0, 21, 8, 88, 4, 50, 1, 62, 3, 31, 2, 46, 6, 41, 
    2, 36, 8, 46, 5, 66, 6, 10, 4, 58, 1, 41, 0, 44, 7, 53, 3, 14, 
    4, 50, 3,  4, 8, 12, 6, 61, 5, 53, 0, 31, 7, 96, 1, 59, 2, 68, 
    0, 90, 3, 15, 2, 85, 4, 95, 5,  8, 8, 53, 6, 36, 7, 49, 1,  4, 
    1, 59, 7, 35, 0, 83, 2, 29, 6, 98, 3, 78, 5, 35, 8, 51, 4, 66
  };
  const int q3268[] = {
    9, 9, // Number of jobs and machines
    1, 73, 3,  1, 6, 54, 4, 50, 8, 45, 2, 67, 0, 19, 5, 25, 7, 33, 
    1, 11, 0, 55, 4, 41, 8, 37, 6, 66, 2, 33, 7, 24, 3,  8, 5, 34, 
    0,  2, 5, 32, 2,  6, 3, 81, 7, 83, 6,  6, 8, 68, 4, 34, 1, 86, 
    2, 49, 1, 29, 6, 99, 3, 78, 0, 36, 8, 27, 5,  7, 7, 24, 4, 79, 
    0, 44, 1,  5, 4, 39, 8, 56, 2, 64, 3, 31, 7, 59, 6, 87, 5, 46, 
    6, 69, 7, 96, 5, 41, 3, 75, 0, 44, 8, 35, 4, 51, 1, 39, 2, 59, 
    4, 69, 2, 88, 0, 58, 8, 35, 3, 45, 6, 37, 1, 84, 7, 22, 5, 20, 
    3, 58, 2, 70, 4, 29, 8, 49, 7, 14, 6, 72, 0, 73, 1, 14, 5, 89, 
    2,  3, 6, 62, 5,  8, 4, 76, 3, 51, 8, 50, 7, 84, 1, 33, 0, 66
  };
  const int q3269[] = {
    9, 9, // Number of jobs and machines
    1, 35, 6, 68, 4,  3, 8, 61, 7, 36, 2, 49, 5, 77, 0, 59, 3, 41, 
    2, 18, 3, 65, 0, 13, 1, 97, 6, 67, 4, 40, 5,  5, 8, 50, 7, 44, 
    3, 91, 2, 85, 1, 18, 6, 55, 7, 87, 0, 43, 8, 68, 4, 94, 5,  5, 
    0, 18, 6, 28, 8, 33, 7, 23, 2, 49, 1, 65, 3, 57, 5, 14, 4, 93, 
    2, 82, 7, 40, 6, 61, 5,  3, 3, 13, 8, 42, 4, 89, 0,  2, 1, 41, 
    0, 13, 6, 37, 3, 46, 8, 70, 1, 71, 4, 94, 2, 32, 7, 36, 5, 61, 
    2, 51, 4, 20, 6, 54, 1,  2, 5, 55, 7, 52, 3, 25, 0, 47, 8, 10, 
    4, 17, 6, 52, 2, 22, 8, 38, 7, 13, 3, 51, 1, 11, 5, 65, 0, 89, 
    4, 20, 6, 45, 1, 83, 3, 29, 0,  1, 2, 99, 5, 45, 7, 67, 8, 84
  };
  const int q3270[] = {
    9, 9, // Number of jobs and machines
    6, 45, 4, 57, 8, 86, 7, 24, 5, 96, 1,  7, 2, 75, 3,  4, 0, 99, 
    8, 93, 0, 31, 4, 73, 5, 59, 1, 83, 2, 70, 7, 30, 3, 42, 6, 64, 
    3, 87, 4, 75, 5, 22, 1, 39, 8, 55, 2, 52, 0, 97, 7,  2, 6, 78, 
    7, 77, 1, 94, 2, 96, 3,  9, 0, 11, 6, 92, 4, 77, 8, 79, 5, 52, 
    2, 66, 8, 12, 4,  4, 3, 34, 6, 28, 1, 31, 7, 43, 0, 98, 5, 61, 
    3,  4, 1, 51, 4,  6, 8, 82, 0, 90, 2, 50, 7, 93, 6, 42, 5, 45, 
    8, 21, 5, 78, 1, 54, 6, 75, 4, 41, 0, 25, 2, 81, 7,  5, 3, 35, 
    6,  1, 4, 79, 3, 68, 0, 56, 5, 38, 7, 23, 8, 85, 2, 98, 1,  1, 
    4, 86, 0, 31, 5, 52, 1, 18, 6,  1, 2, 57, 3, 23, 7, 10, 8, 86
  };
  const int q3271[] = {
    9, 9, // Number of jobs and machines
    1, 92, 6, 66, 7, 58, 8, 39, 0, 75, 5, 34, 4, 18, 2, 28, 3, 51, 
    6,  9, 3, 99, 5, 52, 8, 12, 0,  9, 4, 55, 2, 80, 7, 35, 1, 70, 
    8, 51, 5, 86, 4, 55, 6,  8, 1, 19, 2, 40, 0, 25, 3, 76, 7, 34, 
    6, 76, 7, 84, 2, 32, 0, 53, 1, 70, 8, 28, 4, 97, 5, 33, 3, 16, 
    7,  2, 8, 12, 2, 51, 5, 64, 6, 99, 0, 87, 4, 80, 1, 40, 3, 16, 
    8, 14, 6, 88, 3,  6, 7, 86, 4, 63, 2, 11, 0, 60, 5, 61, 1, 86, 
    7, 99, 5, 73, 8, 47, 1, 34, 3, 40, 0, 50, 4, 85, 2, 75, 6, 58, 
    8, 27, 5, 80, 1, 81, 6, 15, 4, 82, 3, 21, 0, 93, 7, 31, 2, 69, 
    7, 73, 5, 80, 0, 99, 6, 32, 2, 63, 1, 49, 8, 79, 4, 75, 3, 47
  };
  const int q3272[] = {
    9, 9, // Number of jobs and machines
    1, 55, 3, 27, 7, 81, 0, 44, 6, 21, 2, 55, 4, 79, 8, 99, 5, 80, 
    2, 40, 0, 17, 7, 81, 5, 65, 3, 95, 4, 10, 8, 74, 1, 13, 6, 86, 
    1, 95, 4, 27, 8, 12, 0, 75, 5, 35, 2, 12, 7, 76, 3, 45, 6, 50, 
    5, 66, 7, 93, 4, 10, 3, 45, 2,  9, 0, 87, 1,  3, 6, 84, 8, 22, 
    1, 87, 3, 96, 2,  9, 0, 41, 8, 93, 6, 74, 7, 22, 4, 87, 5, 14, 
    8, 58, 0, 51, 3,  5, 1, 29, 7, 56, 5, 71, 6,  1, 2,  5, 4, 22, 
    6, 61, 1,  8, 0,  6, 3, 50, 4, 14, 7,  6, 5, 92, 2, 31, 8, 49, 
    1, 23, 8, 90, 3, 53, 7, 67, 0, 84, 2, 35, 4, 85, 6, 24, 5, 55, 
    3, 11, 7, 19, 4, 33, 6, 92, 2, 79, 8, 46, 5, 24, 1,  4, 0, 46
  };
  const int q3273[] = {
    9, 9, // Number of jobs and machines
    1, 28, 4, 27, 2, 46, 5, 34, 6, 83, 0, 63, 8, 93, 3, 60, 7, 80, 
    2, 78, 7, 48, 6, 62, 3, 11, 4, 74, 1, 73, 8, 51, 5, 96, 0, 95, 
    3, 23, 6, 23, 4, 73, 1, 88, 7, 17, 8, 73, 0, 54, 2, 31, 5, 49, 
    4, 86, 0, 31, 3, 59, 2, 77, 5, 12, 8, 83, 7, 98, 1, 64, 6, 56, 
    4, 29, 1, 40, 0, 29, 2, 59, 7,  8, 5, 66, 3, 15, 6, 61, 8, 65, 
    2, 92, 7,  6, 3, 81, 1, 12, 4, 68, 5, 86, 6, 53, 8,  3, 0, 49, 
    2, 15, 7, 89, 5, 74, 8, 21, 1, 63, 4, 92, 0, 79, 6, 95, 3, 16, 
    0, 81, 8, 65, 1,  8, 3, 82, 7, 52, 5, 38, 4,  5, 6, 24, 2, 18, 
    6, 20, 3, 67, 0, 50, 1, 68, 2, 55, 4, 67, 7, 67, 8, 36, 5, 56
  };
  const int q3274[] = {
    9, 9, // Number of jobs and machines
    1, 75, 0, 17, 7, 65, 6, 18, 3, 43, 8, 80, 5, 46, 4, 10, 2,  7, 
    3, 32, 0, 33, 4, 61, 5, 72, 7, 34, 2, 35, 1,  2, 8, 56, 6, 50, 
    8, 10, 3, 36, 5, 63, 2, 67, 7, 73, 0, 14, 1, 44, 4, 59, 6, 85, 
    0, 37, 7, 80, 2, 90, 8, 88, 4, 14, 3, 91, 6,  7, 5, 46, 1, 73, 
    0, 89, 7,  4, 8, 17, 3, 15, 5, 97, 1, 47, 4, 33, 6, 45, 2, 43, 
    4, 62, 5, 33, 8, 73, 3, 96, 0, 26, 1, 65, 7, 94, 2, 32, 6, 69, 
    7, 94, 1, 48, 2, 21, 3, 43, 8, 92, 0, 38, 5, 25, 6, 16, 4, 18, 
    1, 80, 6, 45, 2, 92, 8,  9, 3, 12, 5, 80, 7, 78, 4, 85, 0,  5, 
    5, 33, 6, 26, 2, 32, 8, 16, 3, 43, 1,  3, 7, 76, 0, 46, 4, 49
  };
  const int q3275[] = {
    9, 9, // Number of jobs and machines
    8, 50, 1, 99, 4, 96, 5, 10, 0, 76, 2,  7, 3, 93, 6, 45, 7, 66, 
    1, 41, 0, 26, 8, 13, 5, 16, 7, 88, 6, 78, 2, 11, 4, 89, 3, 14, 
    8,  3, 5, 98, 2, 32, 1, 32, 7, 18, 3,  6, 0, 43, 4, 92, 6, 83, 
    5, 47, 3,  5, 8, 39, 7, 58, 2, 14, 6, 90, 4, 99, 1, 50, 0, 29, 
    7, 26, 1, 96, 3, 95, 2, 62, 0, 94, 5, 65, 6, 60, 4, 54, 8, 88, 
    5, 98, 6, 37, 3, 53, 0, 15, 8, 91, 7, 97, 1,  3, 4, 86, 2,  2, 
    2, 66, 6, 39, 7, 64, 0, 95, 1, 58, 5, 19, 8, 60, 3, 86, 4, 30, 
    2, 52, 0, 85, 6, 87, 3, 46, 7, 52, 1, 63, 4, 45, 8, 98, 5,  4, 
    1, 20, 6, 11, 4, 92, 8, 47, 0, 99, 2, 14, 3, 89, 7, 71, 5, 81
  };
  const int q3276[] = {
    9, 9, // Number of jobs and machines
    6, 90, 1,  8, 5, 95, 7, 98, 8, 65, 3,  6, 4,  2, 0,  1, 2, 36, 
    8, 56, 1, 10, 4, 35, 7, 25, 6,  6, 2, 80, 3, 74, 0, 63, 5, 79, 
    0, 43, 7, 81, 3, 79, 1, 93, 8, 13, 4, 85, 2, 93, 5, 69, 6, 39, 
    1, 59, 6, 47, 5, 16, 3, 28, 8, 23, 2,  2, 7, 47, 4, 97, 0, 33, 
    2, 59, 7, 93, 5, 64, 1, 84, 4, 55, 0, 76, 6, 58, 3, 76, 8, 49, 
    7, 77, 8, 74, 5, 40, 2, 65, 3, 58, 0, 69, 1, 34, 6, 21, 4, 57, 
    5, 18, 1, 17, 3, 14, 6, 11, 4, 53, 8, 21, 2, 86, 7, 45, 0, 90, 
    2, 15, 5, 25, 4, 20, 6, 16, 7,  5, 3, 49, 8, 39, 1, 69, 0, 44, 
    5, 38, 7, 23, 0, 79, 8, 55, 3,  3, 2, 88, 1,  2, 6, 79, 4, 39
  };
  const int q3277[] = {
    9, 9, // Number of jobs and machines
    7, 14, 3, 74, 1, 94, 4, 53, 6, 47, 5, 28, 2, 51, 0, 19, 8, 19, 
    1,  7, 0, 12, 5, 58, 7, 13, 2, 16, 4, 53, 8, 92, 6, 17, 3, 54, 
    4, 48, 5, 44, 7, 77, 6,  9, 8, 17, 3, 55, 2, 21, 0, 69, 1, 17, 
    0, 58, 1, 83, 8, 75, 4, 56, 5, 47, 7, 31, 3,  8, 6, 80, 2, 15, 
    2, 63, 4, 28, 6, 54, 0, 67, 7, 54, 5, 59, 3, 95, 1, 85, 8, 88, 
    3, 73, 1, 74, 5, 41, 0, 18, 4,  2, 8, 14, 2, 17, 6, 52, 7, 68, 
    0, 41, 5, 97, 2, 10, 8, 19, 1, 67, 7, 20, 6, 15, 3, 20, 4, 85, 
    3, 46, 6, 29, 0, 99, 7, 82, 8, 79, 4, 78, 2, 27, 5,  5, 1, 19, 
    6, 17, 8, 97, 2, 58, 5, 67, 7, 84, 4, 40, 1, 57, 3, 39, 0, 77
  };
  const int q3278[] = {
    9, 9, // Number of jobs and machines
    1, 74, 8, 94, 2, 97, 0, 97, 4, 24, 6, 56, 3, 76, 7, 93, 5, 76, 
    0, 68, 5, 20, 4, 53, 2, 61, 6, 92, 7, 87, 1,  2, 3, 68, 8, 64, 
    0, 97, 6, 69, 8, 10, 4, 71, 7, 66, 5, 52, 2, 19, 3, 49, 1, 86, 
    3, 56, 0, 37, 1, 28, 5, 28, 8, 76, 6, 60, 2, 25, 7, 97, 4, 53, 
    8, 84, 5, 91, 2, 80, 1, 55, 6, 31, 4, 46, 0, 19, 7, 91, 3,  8, 
    7, 91, 6, 28, 2,  9, 0, 45, 3, 41, 1, 59, 8,  7, 4, 86, 5, 56, 
    1, 77, 7, 52, 6, 38, 5, 23, 8, 64, 4, 38, 0, 13, 2, 14, 3, 75, 
    8,  9, 4, 23, 2, 96, 7, 72, 3, 12, 6, 24, 5, 13, 0, 48, 1, 28, 
    1, 56, 2, 30, 3, 78, 4, 18, 8, 11, 7, 15, 6, 20, 5, 51, 0, 11
  };
  const int q3279[] = {
    9, 9, // Number of jobs and machines
    7, 44, 4, 53, 5, 75, 1, 78, 0, 76, 2, 54, 3, 98, 6, 43, 8, 88, 
    5, 46, 7, 36, 0, 59, 2, 10, 4, 96, 6, 20, 8, 97, 3, 32, 1, 68, 
    4, 76, 3, 38, 8, 10, 0, 43, 5, 76, 1, 36, 6, 72, 7, 29, 2, 56, 
    2, 78, 0, 77, 1, 80, 8, 60, 4, 56, 7, 18, 5, 78, 6,  8, 3, 38, 
    0, 69, 4, 30, 3, 45, 5, 57, 7,  7, 2, 13, 8, 73, 6, 60, 1, 77, 
    6, 23, 3, 34, 2, 48, 5, 30, 1, 99, 8, 85, 4, 95, 0, 43, 7, 37, 
    0, 53, 7, 32, 1, 70, 5, 60, 3, 90, 4, 24, 8, 68, 6, 35, 2, 78, 
    4, 66, 8, 77, 6, 31, 5, 84, 7, 87, 2,  2, 3, 34, 1, 96, 0, 34, 
    8, 31, 2, 70, 3, 30, 1, 39, 7, 87, 6, 40, 5, 31, 0,  7, 4, 41
  };
  const int q3280[] = {
    9, 9, // Number of jobs and machines
    8, 71, 6, 51, 2,  4, 4, 24, 5, 11, 0, 17, 3, 86, 7, 32, 1, 42, 
    1,  2, 0, 12, 3, 69, 4, 89, 6, 64, 2, 42, 7, 76, 5, 83, 8, 26, 
    0, 15, 2, 44, 7, 89, 8, 74, 1, 85, 4, 88, 3, 90, 6, 47, 5, 16, 
    7, 44, 4, 17, 2, 79, 3, 78, 8, 25, 0, 50, 6, 12, 5, 73, 1, 87, 
    8, 60, 2, 25, 5,  5, 0, 25, 1, 53, 4, 53, 6, 12, 3, 93, 7, 65, 
    1, 54, 6, 57, 3, 74, 7, 72, 8, 94, 5, 48, 0, 70, 4, 24, 2, 74, 
    2, 28, 3, 67, 7, 69, 4, 67, 8, 57, 0, 79, 1, 33, 6, 17, 5, 52, 
    3, 73, 2, 47, 8, 97, 4, 30, 5, 65, 1, 37, 7, 13, 6, 93, 0,  3, 
    8, 52, 0, 89, 7, 61, 5, 67, 2, 47, 3, 79, 6, 63, 1, 62, 4, 40
  };
  const int q3281[] = {
    9, 9, // Number of jobs and machines
    2, 59, 1, 32, 7, 53, 5, 14, 6,  3, 3, 87, 8, 21, 0,  7, 4, 46, 
    7, 32, 4, 36, 0, 50, 3, 58, 1, 48, 6,  3, 2, 19, 5, 79, 8, 10, 
    8, 87, 5, 36, 3, 94, 2, 22, 7, 12, 4,  6, 6, 55, 1, 52, 0, 77, 
    6, 88, 0, 56, 3, 57, 7, 76, 5, 71, 2, 86, 4, 31, 8, 18, 1, 74, 
    8, 84, 1, 97, 3,  6, 7, 33, 5, 34, 0, 21, 2, 95, 6, 20, 4, 58, 
    0, 61, 7, 12, 4, 10, 8, 33, 5, 36, 6, 21, 3, 35, 2, 83, 1, 37, 
    2, 82, 0, 79, 8, 13, 5, 63, 4, 23, 3, 82, 6,  6, 1, 79, 7, 55, 
    5, 60, 7, 88, 1, 72, 4, 74, 3, 94, 0, 66, 2, 14, 8, 23, 6, 49, 
    1, 67, 6, 68, 8, 65, 2, 54, 3, 80, 4,  2, 0, 67, 7,  9, 5, 82
  };
  const int q3282[] = {
    9, 9, // Number of jobs and machines
    0, 26, 2, 92, 8, 90, 7, 39, 3, 96, 6, 75, 5, 61, 1, 16, 4, 30, 
    5, 65, 0, 67, 3,  9, 8,  3, 4, 89, 7,  4, 6, 33, 1, 38, 2, 14, 
    3, 54, 1, 55, 2, 35, 4, 59, 0, 75, 5, 24, 7, 59, 6, 31, 8, 11, 
    4, 20, 3, 27, 0, 40, 2, 90, 1, 67, 5, 72, 6, 64, 7, 13, 8, 92, 
    3, 86, 1, 37, 5, 73, 4, 27, 8, 38, 0, 16, 6, 15, 2, 53, 7, 96, 
    8, 16, 0, 68, 1, 55, 3, 78, 2,  7, 7, 38, 4, 44, 5, 19, 6, 53, 
    6,  8, 7, 79, 4, 22, 3, 23, 0, 18, 1, 55, 5, 94, 2, 43, 8, 91, 
    4, 98, 8, 43, 6, 61, 0, 89, 7, 10, 3, 21, 2, 13, 5, 72, 1, 68, 
    4, 57, 2, 85, 0,  4, 6, 55, 5, 36, 8, 14, 1, 53, 7, 93, 3, 52
  };
  const int q3283[] = {
    9, 9, // Number of jobs and machines
    4, 38, 1, 39, 3,  3, 5, 56, 6, 92, 7, 36, 8, 29, 0, 94, 2, 57, 
    6, 31, 0,  2, 8,  4, 2, 61, 3,  8, 1, 55, 7, 80, 4, 98, 5, 14, 
    7, 66, 0, 69, 8, 70, 5, 70, 6,  8, 2, 28, 3, 50, 1, 57, 4, 17, 
    4, 39, 3, 95, 6,  3, 8, 57, 7, 13, 0, 80, 2, 62, 5, 82, 1, 22, 
    2,  1, 0, 52, 4, 31, 7, 19, 1, 24, 3, 60, 6, 72, 5, 28, 8, 24, 
    4, 81, 0, 95, 7, 53, 1, 51, 6, 20, 8, 90, 3, 10, 5, 78, 2, 11, 
    5, 96, 8, 12, 3,  9, 4, 44, 7, 99, 0, 78, 2, 57, 6, 70, 1, 15, 
    4, 82, 1, 67, 6, 27, 8, 22, 3, 57, 2, 51, 0, 50, 5, 35, 7, 20, 
    6, 31, 8, 36, 3, 70, 1, 41, 4, 36, 7, 77, 5, 91, 2, 49, 0, 49
  };
  const int q3284[] = {
    9, 9, // Number of jobs and machines
    4, 95, 8, 32, 3, 38, 1, 72, 2, 27, 6,  5, 7, 89, 5, 29, 0, 24, 
    3, 94, 0, 95, 8,  1, 6, 81, 5, 79, 1, 15, 4, 10, 2, 43, 7, 33, 
    2, 31, 4, 19, 1, 50, 7, 41, 8, 35, 6, 14, 3, 93, 5, 49, 0, 24, 
    4, 94, 7,  5, 1, 45, 6, 89, 2, 78, 5, 29, 8, 30, 0, 57, 3, 37, 
    7, 59, 2, 45, 0, 28, 1, 41, 3, 49, 4, 49, 6, 85, 8, 48, 5, 92, 
    0, 68, 5, 70, 2, 17, 3,  4, 7, 45, 4, 65, 1, 66, 8, 77, 6, 11, 
    3, 51, 6, 92, 5, 24, 2, 54, 1, 15, 8,  5, 0, 67, 4, 37, 7,  7, 
    2,  1, 3, 57, 4, 57, 5, 44, 0, 53, 7, 57, 1, 30, 6, 43, 8, 81, 
    7, 68, 1, 44, 4, 31, 3, 10, 8, 69, 5, 23, 2, 34, 6, 51, 0, 86
  };
  const int q3285[] = {
    9, 9, // Number of jobs and machines
    2, 97, 5, 72, 7, 22, 6, 87, 4, 46, 0, 44, 3, 69, 1, 37, 8, 75, 
    7, 75, 0,  1, 1, 64, 2, 33, 6, 71, 8, 47, 4, 28, 5,  2, 3, 18, 
    1,  1, 4, 85, 6, 48, 8, 74, 3, 46, 0, 30, 2, 57, 7, 87, 5, 92, 
    2, 81, 5, 77, 1, 69, 4, 18, 0, 39, 6, 53, 3, 43, 7, 72, 8, 86, 
    3, 65, 2, 31, 1, 78, 0, 98, 7, 35, 6, 80, 8, 69, 4, 94, 5, 31, 
    2, 97, 8, 47, 4, 60, 7, 27, 0, 12, 6, 21, 3, 36, 5, 94, 1,  7, 
    2, 59, 0, 69, 1, 59, 6, 24, 7, 54, 5, 45, 4,  4, 3, 40, 8, 79, 
    3,  3, 0, 75, 8, 67, 6, 41, 2, 13, 4, 10, 1, 61, 7, 69, 5, 56, 
    1, 44, 3, 40, 5, 26, 6, 28, 4, 69, 8, 66, 2, 74, 0, 71, 7, 55
  };
  const int q3286[] = {
    9, 9, // Number of jobs and machines
    1, 17, 2, 35, 5, 38, 8,  5, 0, 92, 7, 94, 3, 83, 6, 42, 4, 53, 
    2, 57, 4, 38, 7, 47, 6, 92, 0, 27, 5, 75, 3, 82, 1, 74, 8, 24, 
    6, 66, 3, 36, 0, 90, 7, 31, 8, 79, 1, 84, 4, 93, 5, 47, 2, 77, 
    4, 94, 8, 90, 3, 66, 1, 90, 0, 24, 7, 97, 5, 59, 6,  1, 2,  8, 
    2, 36, 0, 85, 5, 55, 1, 36, 3, 67, 8, 61, 4, 92, 7, 24, 6, 30, 
    0, 99, 8, 83, 7, 93, 4, 22, 6, 84, 5, 35, 2, 58, 3, 80, 1, 80, 
    1, 83, 0, 41, 8, 36, 4, 67, 2,  8, 6, 93, 7, 77, 3, 97, 5, 71, 
    4,  1, 8, 51, 1, 60, 7, 36, 6, 56, 5, 51, 0, 14, 2, 31, 3, 67, 
    6, 63, 3, 92, 8,  3, 1, 47, 2, 65, 4, 91, 0, 86, 5, 92, 7, 39
  };
  const int q3287[] = {
    9, 9, // Number of jobs and machines
    1, 58, 2,  4, 5, 68, 6, 88, 8,  9, 3,  4, 0, 14, 4,  1, 7, 63, 
    6, 20, 8, 33, 5, 24, 0, 27, 4, 36, 7, 32, 2, 32, 1,  5, 3,  9, 
    2, 46, 0, 53, 7, 44, 6, 52, 4, 56, 3, 63, 1, 63, 8, 56, 5, 40, 
    2, 51, 0, 80, 8, 87, 5, 18, 4, 20, 1, 34, 3, 97, 7, 40, 6, 42, 
    3, 58, 0, 26, 7, 72, 6, 97, 1, 24, 8, 43, 5,  9, 4, 66, 2, 74, 
    2, 48, 0, 58, 6, 19, 7, 10, 3, 80, 8, 29, 4, 47, 5, 35, 1, 76, 
    0, 60, 3, 16, 1, 63, 4, 61, 2, 26, 7, 35, 5, 99, 6, 36, 8, 75, 
    3, 41, 2, 23, 8, 97, 5, 12, 4,  6, 6, 73, 0, 54, 1, 28, 7, 68, 
    8, 40, 2, 78, 5, 65, 3, 13, 6, 34, 0, 36, 7, 35, 1,  1, 4, 56
  };
  const int q3288[] = {
    9, 9, // Number of jobs and machines
    5, 94, 2, 11, 0, 59, 6, 67, 1, 19, 4, 31, 7, 42, 3, 93, 8, 36, 
    4, 34, 3, 75, 8, 86, 0, 55, 1, 24, 7, 78, 6, 53, 2, 95, 5, 51, 
    5, 77, 6, 97, 4, 76, 3, 26, 2, 71, 8, 18, 1, 25, 7, 35, 0, 23, 
    5, 54, 4, 46, 8, 70, 7, 82, 6, 34, 0, 40, 2, 31, 1, 79, 3, 97, 
    0, 36, 6, 99, 1, 36, 4, 13, 7, 91, 5, 90, 2, 18, 8, 10, 3, 12, 
    4, 44, 1, 30, 7, 60, 6, 37, 8, 93, 3, 67, 2, 31, 5, 45, 0, 49, 
    6, 58, 3, 33, 1, 74, 2,  3, 5, 42, 4, 71, 0, 94, 8, 33, 7, 19, 
    0, 59, 7, 93, 2, 99, 1, 65, 5, 33, 4, 71, 8, 34, 3, 74, 6, 29, 
    0, 14, 3,  1, 8, 80, 6,  8, 7, 95, 5, 58, 1, 72, 4,  8, 2, 42
  };
  const int q3289[] = {
    9, 9, // Number of jobs and machines
    7,  7, 8, 41, 3, 80, 5, 79, 2, 73, 4, 98, 0, 84, 6, 42, 1, 41, 
    5, 47, 0, 47, 7, 70, 4, 50, 1, 73, 2, 44, 3, 53, 8, 95, 6, 55, 
    5, 61, 1, 52, 8, 76, 0, 93, 3, 46, 7, 77, 2,  7, 6, 54, 4, 32, 
    7, 24, 8, 40, 2, 83, 3, 44, 0, 70, 5, 60, 1, 78, 6,  3, 4, 54, 
    6, 29, 2, 18, 0, 57, 3, 75, 1, 28, 4, 51, 7, 59, 8, 16, 5, 68, 
    4, 37, 3, 93, 2,  6, 5, 74, 1, 42, 6, 28, 8, 77, 7,  2, 0, 47, 
    4, 99, 5, 20, 3, 59, 7, 97, 1, 68, 2, 76, 6, 44, 8, 14, 0, 87, 
    7, 28, 6, 90, 3, 38, 2, 11, 0, 78, 1, 73, 5, 39, 8,  2, 4, 53, 
    0,  1, 3, 61, 1,  9, 4,  8, 2, 33, 7, 82, 5, 24, 6, 40, 8, 35
  };
  const int q3290[] = {
    9, 9, // Number of jobs and machines
    5, 62, 6,  3, 0, 98, 3, 42, 8, 13, 2, 64, 1, 36, 4, 70, 7, 67, 
    7, 99, 2, 65, 1, 95, 4, 88, 0, 76, 6, 69, 8, 39, 5, 58, 3, 24, 
    7, 16, 3, 61, 5, 51, 8, 44, 6, 60, 0, 34, 2, 78, 4, 73, 1, 54, 
    8, 78, 2, 48, 1, 72, 4, 10, 6, 76, 0, 77, 7, 40, 3, 76, 5, 71, 
    7, 12, 5, 41, 8,  2, 0, 91, 2, 37, 3, 29, 6,  2, 4, 63, 1, 19, 
    5, 52, 1, 80, 2, 16, 8, 58, 4, 80, 6, 13, 0, 69, 7, 77, 3, 48, 
    3, 72, 8, 84, 0, 50, 1, 99, 2, 27, 4, 36, 6, 40, 5, 39, 7, 17, 
    2, 58, 7, 11, 8, 79, 0, 82, 1, 37, 3, 14, 4, 31, 5,  3, 6, 74, 
    6, 30, 7, 33, 2, 92, 8, 90, 0, 85, 3, 83, 4, 19, 1, 96, 5, 92
  };
  const int q3291[] = {
    9, 9, // Number of jobs and machines
    1, 11, 5, 20, 3, 92, 7, 26, 2, 98, 4, 16, 6, 29, 8, 34, 0, 42, 
    7, 33, 2, 96, 1, 90, 6, 73, 4,  2, 5, 87, 8, 97, 0, 18, 3, 38, 
    6, 33, 1, 37, 3, 50, 0, 58, 7,  2, 2, 43, 4,  2, 8, 37, 5,  8, 
    0, 40, 5, 40, 2,  5, 1, 86, 6, 99, 3, 15, 4,  8, 8,  3, 7, 98, 
    6, 77, 3, 59, 0, 68, 4, 17, 2, 37, 5, 84, 8, 34, 7, 43, 1, 96, 
    5, 82, 3, 37, 1, 86, 2, 37, 0, 37, 8, 62, 7, 31, 4, 97, 6, 19, 
    5, 62, 3, 98, 2, 68, 6, 41, 0, 30, 1, 40, 7, 14, 4, 19, 8, 76, 
    7, 73, 1, 15, 4, 23, 0, 65, 3, 73, 5, 85, 2, 78, 8, 62, 6, 24, 
    5, 12, 6, 14, 2, 20, 8, 10, 3, 58, 7, 18, 0, 31, 4,  4, 1, 39
  };
  const int q3292[] = {
    9, 9, // Number of jobs and machines
    2, 46, 0, 65, 3, 66, 8, 88, 6, 68, 4, 12, 1, 68, 5, 74, 7, 47, 
    8, 94, 5, 15, 1, 17, 2, 28, 0, 88, 4, 56, 6, 27, 7, 60, 3, 21, 
    2, 76, 8, 82, 0, 80, 4, 18, 7, 58, 3, 29, 1, 40, 6, 23, 5, 27, 
    6, 24, 8, 37, 5, 99, 2, 44, 4, 62, 1, 16, 7, 90, 3, 43, 0, 19, 
    4, 99, 5, 93, 7, 76, 2, 56, 0, 68, 1, 10, 6, 22, 3, 86, 8, 98, 
    6,  8, 8, 36, 5, 54, 1, 54, 7, 38, 0, 59, 2, 91, 3, 85, 4, 47, 
    1, 59, 5, 76, 3,  9, 6, 87, 7, 85, 4, 64, 0, 17, 8, 36, 2,  3, 
    2, 58, 8, 75, 7, 30, 4, 10, 6, 10, 3, 70, 0,  6, 1, 45, 5, 86, 
    5, 46, 8, 77, 3, 90, 1, 84, 0, 96, 4, 64, 7, 75, 2, 47, 6, 39
  };
  const int q3293[] = {
    9, 9, // Number of jobs and machines
    4, 36, 7, 49, 2, 81, 6, 73, 8, 20, 3, 55, 1, 22, 0, 97, 5, 40, 
    0, 71, 3, 65, 8, 15, 4,  7, 2, 60, 6, 17, 7,  5, 5, 31, 1, 74, 
    3, 24, 0, 99, 5, 50, 4, 83, 7,  2, 8, 17, 1,  8, 2, 18, 6, 96, 
    6, 83, 4, 16, 1, 82, 7, 80, 3, 11, 8, 87, 5, 43, 0, 83, 2, 56, 
    6, 80, 4, 84, 8, 92, 1, 12, 0, 39, 7,  7, 5, 39, 2, 52, 3, 13, 
    4, 72, 8, 25, 1, 47, 0, 22, 5, 57, 2, 53, 6, 11, 3, 55, 7, 90, 
    8, 28, 7,  5, 4,  6, 3, 18, 0, 73, 1, 22, 5, 88, 2, 16, 6, 74, 
    7, 92, 4,  6, 2, 47, 1, 79, 8, 96, 3, 21, 5,  7, 0,  1, 6, 20, 
    7, 74, 0, 59, 8, 69, 5, 81, 4, 64, 6, 99, 2, 55, 1, 23, 3, 85
  };
  const int q3294[] = {
    9, 9, // Number of jobs and machines
    3, 96, 6,  1, 7, 97, 0, 86, 5, 19, 1, 24, 2, 20, 4, 52, 8, 52, 
    4, 95, 2, 13, 3, 58, 1, 20, 8,  9, 5, 57, 0, 11, 6, 89, 7,  6, 
    0, 71, 1,  3, 2, 59, 6, 63, 4, 54, 8, 68, 7, 82, 5, 58, 3, 42, 
    4, 34, 1, 89, 6, 43, 7, 91, 8, 26, 0, 21, 5, 70, 3, 26, 2, 86, 
    6, 32, 2, 13, 3, 74, 1, 11, 5, 96, 7, 66, 4, 99, 8, 27, 0, 66, 
    6, 82, 8, 29, 1, 22, 3, 91, 0, 17, 4, 91, 5, 95, 2, 61, 7, 78, 
    7,  8, 6, 58, 4, 63, 0, 46, 8, 36, 3,  3, 1, 73, 5, 97, 2, 59, 
    3, 54, 8, 64, 4, 25, 0, 17, 2, 45, 7, 13, 5, 33, 6, 85, 1,  4, 
    1, 91, 5, 64, 3, 73, 7, 54, 0, 12, 8, 12, 2, 58, 6, 84, 4, 25
  };
  const int q3295[] = {
    9, 9, // Number of jobs and machines
    5, 28, 1,  2, 4, 70, 6, 13, 8, 89, 0, 76, 2, 90, 7,  8, 3,  6, 
    5, 56, 2, 35, 7, 54, 4, 31, 8, 19, 1, 89, 0, 21, 3, 43, 6, 79, 
    8, 18, 0, 62, 4,  3, 2, 28, 6, 43, 5, 95, 1, 64, 3, 38, 7, 42, 
    2, 26, 0, 78, 6, 70, 1, 10, 5, 74, 7, 26, 8, 58, 3, 16, 4, 66, 
    3,  4, 0, 85, 7, 13, 2, 80, 1, 39, 4, 96, 6, 27, 5, 66, 8, 74, 
    2, 55, 5, 12, 0, 26, 4, 54, 1, 28, 6, 51, 3, 48, 8, 31, 7, 73, 
    6, 76, 5,  9, 1, 98, 0,  2, 7, 35, 2, 87, 8, 64, 4, 93, 3, 58, 
    5, 74, 4, 55, 0,  2, 1, 89, 8, 14, 2, 19, 3, 21, 6, 12, 7, 32, 
    7, 45, 2, 15, 8, 34, 6,  9, 1, 61, 3, 74, 0, 43, 5,  3, 4, 30
  };
  const int q3296[] = {
    9, 9, // Number of jobs and machines
    8, 75, 7, 77, 5, 70, 0, 78, 1, 61, 3, 81, 2, 68, 6, 12, 4, 82, 
    1, 59, 3, 33, 5, 81, 0, 13, 7, 74, 6,  9, 2, 52, 4, 10, 8, 87, 
    5, 84, 4, 14, 8, 84, 2, 93, 1, 99, 7, 62, 6, 40, 0, 50, 3, 10, 
    6, 35, 3, 70, 0, 28, 8, 25, 7, 72, 5, 92, 2, 21, 1, 14, 4,  4, 
    5, 62, 1, 44, 2, 91, 7,  2, 6, 38, 3, 62, 8, 32, 0, 64, 4, 30, 
    2, 26, 4, 70, 0, 73, 3, 83, 6, 97, 5, 79, 8, 41, 1, 61, 7, 99, 
    7, 95, 3, 53, 1, 27, 0, 59, 2, 98, 8, 38, 4,  2, 5, 20, 6, 25, 
    6, 53, 4, 72, 5, 68, 1, 55, 8, 72, 0, 19, 2, 28, 3, 68, 7, 18, 
    5, 92, 3, 13, 1, 12, 8, 66, 2, 40, 6, 84, 4, 68, 0, 15, 7, 88
  };
  const int q3297[] = {
    9, 9, // Number of jobs and machines
    7, 33, 3, 13, 5, 95, 6, 32, 2, 74, 8, 21, 4,  8, 0, 53, 1,  5, 
    8, 70, 2, 20, 4, 53, 7, 70, 0, 74, 3, 28, 1, 74, 6, 66, 5, 46, 
    5, 41, 4,  9, 7, 50, 6, 61, 3,  3, 1, 64, 2, 98, 0, 10, 8, 91, 
    3, 92, 6, 49, 2, 95, 0,  5, 7, 45, 8, 20, 1, 75, 4, 37, 5, 77, 
    2, 73, 8, 34, 0,  6, 6, 76, 1, 44, 5, 93, 4, 76, 3, 25, 7, 22, 
    0, 21, 4, 57, 2, 54, 1,  5, 8, 39, 7, 74, 3, 67, 5, 69, 6, 46, 
    7, 67, 6, 88, 2, 18, 5, 51, 0, 66, 4, 13, 3, 29, 1, 42, 8, 28, 
    4, 30, 8, 86, 2, 30, 0, 26, 5, 41, 1, 36, 7,  1, 3, 47, 6, 96, 
    3, 29, 4, 48, 0, 88, 1, 15, 8, 81, 6, 21, 2,  7, 5, 33, 7, 22
  };
  const int q3298[] = {
    9, 9, // Number of jobs and machines
    5, 69, 8, 47, 4, 38, 0, 43, 3, 51, 7, 66, 2, 58, 1, 36, 6,  1, 
    2, 18, 8, 89, 5, 77, 7, 49, 3,  1, 4, 86, 1, 14, 0, 53, 6, 80, 
    8,  3, 7, 22, 6, 25, 3, 33, 4, 94, 0, 63, 2, 72, 1, 89, 5, 13, 
    8, 93, 5, 13, 7,  2, 6, 21, 1, 53, 2, 80, 0, 13, 4, 19, 3, 31, 
    5, 18, 4, 26, 3, 47, 6, 85, 0,  6, 8, 62, 2, 34, 1, 37, 7, 36, 
    0, 83, 2, 78, 5, 45, 7, 49, 1, 42, 3, 15, 4,  2, 6, 52, 8, 92, 
    2, 54, 1, 50, 3, 93, 5, 24, 7, 96, 4, 21, 0, 12, 6, 80, 8, 84, 
    6, 17, 1, 74, 8, 38, 4, 92, 0, 85, 3, 68, 2, 44, 5, 29, 7, 49, 
    2, 56, 7, 39, 1, 35, 8, 50, 3, 70, 4, 49, 5, 29, 6, 42, 0, 89
  };
  const int q3299[] = {
    9, 9, // Number of jobs and machines
    5, 49, 3, 79, 4, 32, 1, 41, 7, 98, 8, 15, 2, 68, 0, 19, 6, 42, 
    0, 36, 4, 38, 6, 74, 7, 10, 2, 29, 5, 21, 1, 55, 3, 89, 8, 77, 
    7, 58, 1, 57, 0, 79, 4, 83, 6, 22, 8, 55, 2, 78, 3, 60, 5, 93, 
    5, 91, 6,  1, 3, 52, 7, 48, 1,  5, 4, 77, 8, 42, 2, 13, 0,  5, 
    0, 16, 4, 65, 3, 54, 5, 45, 1,  7, 7, 88, 8, 59, 6, 86, 2, 33, 
    2, 74, 1, 73, 5, 26, 6,  4, 4, 22, 8, 80, 7, 23, 0, 57, 3,  6, 
    7, 74, 2, 82, 5, 85, 4, 51, 3, 24, 6, 63, 8, 38, 0, 95, 1,  8, 
    5, 75, 3, 65, 8,  4, 6, 39, 0, 52, 7, 23, 4, 36, 2, 54, 1, 53, 
    5, 57, 3, 13, 7, 40, 4, 23, 2, 20, 0, 98, 1, 17, 6, 99, 8, 94
  };
  const int q3300[] = {
    9, 9, // Number of jobs and machines
    3, 63, 0, 32, 5, 15, 6, 62, 8, 82, 2, 38, 4, 93, 7,  3, 1, 48, 
    8, 97, 1, 65, 3, 28, 4, 69, 6, 14, 0, 84, 7, 32, 5, 76, 2, 98, 
    4, 35, 6,  3, 5, 98, 8, 88, 7, 60, 1,  3, 2, 49, 3, 53, 0, 82, 
    5, 60, 0, 98, 4, 67, 3, 56, 6, 72, 8, 81, 1,  8, 2, 86, 7, 68, 
    0, 53, 6, 82, 5, 93, 3, 66, 7, 52, 4, 44, 2, 53, 1, 22, 8, 55, 
    7, 43, 1, 64, 2, 22, 8,  7, 0, 24, 3, 11, 6, 38, 5, 32, 4, 10, 
    7, 51, 2, 42, 4, 69, 1, 41, 5, 39, 6, 23, 8, 45, 0, 87, 3, 21, 
    3, 43, 5, 30, 1, 82, 6, 83, 2,  1, 0, 78, 8, 22, 4, 80, 7, 11, 
    3, 59, 7, 96, 2, 20, 6,  3, 1, 31, 8, 48, 4, 37, 0, 39, 5,  5
  };
  const int q3301[] = {
    9, 9, // Number of jobs and machines
    2, 97, 4, 59, 7, 98, 1, 41, 8,  6, 6, 62, 5, 14, 0, 96, 3, 13, 
    5, 49, 2,  3, 6, 19, 0, 22, 4, 62, 7, 37, 3, 21, 1, 26, 8, 46, 
    7, 27, 5,  8, 6, 74, 0, 77, 8, 21, 2, 96, 1, 35, 3, 88, 4, 42, 
    1, 81, 5, 40, 8, 36, 2, 19, 7, 35, 4, 40, 3, 67, 0, 48, 6,  7, 
    2, 18, 5, 26, 0, 18, 1, 56, 3,  9, 6, 28, 7, 78, 4, 67, 8, 78, 
    8, 14, 2, 13, 4, 23, 0, 10, 7, 89, 3, 98, 5, 26, 1, 63, 6, 36, 
    3, 64, 5, 99, 6, 57, 2, 88, 1, 84, 4, 84, 0, 50, 8, 57, 7, 68, 
    1, 20, 8, 37, 2, 63, 4,  1, 7, 72, 0, 72, 6, 99, 3, 61, 5, 51, 
    0, 52, 2, 42, 4, 15, 3, 32, 8, 57, 1, 29, 6, 76, 7, 10, 5, 90
  };
  const int q3302[] = {
    9, 9, // Number of jobs and machines
    6, 67, 3, 75, 8, 98, 7, 19, 5, 76, 1, 79, 2, 37, 0,  1, 4, 57, 
    1, 88, 8, 89, 3, 92, 0, 53, 2, 54, 7, 18, 6,  1, 4,  9, 5, 38, 
    7, 93, 6, 23, 0, 16, 1, 38, 3, 60, 5,  1, 8, 94, 2, 76, 4,  3, 
    2, 44, 4, 13, 6, 66, 3, 18, 1, 86, 7, 12, 8, 13, 0, 74, 5, 74, 
    0, 78, 4, 40, 5, 31, 1,  6, 7, 43, 3, 43, 6, 61, 8, 94, 2, 36, 
    1, 63, 2, 79, 3,  3, 7, 53, 0, 92, 6, 20, 5, 13, 8, 22, 4, 84, 
    1, 89, 6, 41, 8, 75, 2, 18, 5, 67, 3, 59, 4, 88, 0, 59, 7, 69, 
    4, 46, 7, 17, 6, 28, 5, 43, 1, 29, 0, 25, 8, 11, 3, 39, 2, 29, 
    5, 24, 0, 15, 3, 54, 4, 77, 6,  1, 2, 32, 7, 13, 8, 29, 1, 69
  };
  const int q3303[] = {
    9, 9, // Number of jobs and machines
    0, 50, 5, 61, 8, 94, 4, 42, 6, 95, 2, 29, 1, 19, 7, 86, 3, 13, 
    6,  2, 1, 40, 8, 62, 5, 43, 7, 99, 0, 91, 4, 12, 3, 85, 2, 63, 
    7, 82, 0, 66, 4, 59, 6, 72, 8, 45, 1, 20, 2, 39, 3, 90, 5, 15, 
    5, 68, 8, 14, 6, 13, 3, 49, 0, 93, 7, 76, 2, 11, 1, 71, 4,  2, 
    0, 98, 6, 31, 2, 82, 7, 47, 5,  1, 4, 83, 1,  7, 8, 38, 3, 65, 
    4, 70, 5, 17, 8, 30, 6, 76, 3, 45, 7, 25, 0,  1, 2, 28, 1, 10, 
    8,  3, 0, 39, 7, 52, 6, 96, 3, 84, 1, 28, 2, 75, 5, 52, 4, 57, 
    5, 53, 4, 23, 6, 18, 2, 78, 1, 53, 8, 49, 3, 37, 0, 38, 7,  3, 
    7,  2, 1, 34, 5, 38, 4, 21, 8, 18, 0, 48, 6, 93, 3, 63, 2, 72
  };
  const int q3304[] = {
    9, 9, // Number of jobs and machines
    5, 16, 6,  3, 2, 34, 3, 76, 8, 30, 4,  9, 1, 27, 0, 81, 7,  5, 
    6, 92, 0, 85, 2, 66, 5, 57, 7, 68, 3, 89, 8, 12, 1, 49, 4, 64, 
    1, 62, 8,  5, 5, 28, 4, 87, 2, 91, 6, 99, 3, 38, 0, 55, 7, 31, 
    1, 13, 3, 33, 5,  7, 7, 92, 2, 60, 0, 96, 8, 85, 6, 45, 4, 59, 
    4, 55, 7, 49, 8, 87, 3, 41, 2, 99, 5, 57, 0, 33, 6, 45, 1, 40, 
    1, 42, 7, 54, 8, 17, 3, 68, 0, 31, 6, 57, 5, 65, 4, 68, 2, 95, 
    4, 55, 1, 29, 6, 85, 7, 17, 8, 18, 3, 98, 5, 50, 0, 75, 2, 70, 
    1,  7, 6,  9, 8, 72, 7, 57, 5, 90, 2, 27, 4, 82, 3, 29, 0, 14, 
    0, 81, 8, 17, 2, 92, 7, 33, 6, 24, 4, 59, 5, 92, 1, 72, 3,  4
  };
  const int q3305[] = {
    9, 9, // Number of jobs and machines
    0, 72, 6, 82, 7, 98, 2, 77, 3, 91, 4, 66, 5, 47, 1, 32, 8, 46, 
    6, 62, 1, 28, 7, 12, 4, 97, 5, 56, 8, 26, 2, 28, 0, 16, 3, 62, 
    2, 30, 3, 50, 8, 91, 7, 30, 6, 42, 1, 67, 5, 57, 0, 28, 4,  4, 
    8, 54, 5, 20, 2, 50, 7, 50, 4, 77, 6, 38, 0, 50, 1, 95, 3,  8, 
    0, 80, 2, 64, 7, 19, 8, 44, 6, 74, 1, 97, 5, 89, 4, 46, 3,  9, 
    3, 32, 5, 88, 6, 92, 8, 98, 7, 44, 4, 50, 0, 43, 1, 36, 2, 90, 
    1, 88, 6, 13, 2, 70, 4, 88, 8, 89, 3, 15, 5, 51, 7, 94, 0, 90, 
    3, 39, 0, 68, 7, 88, 8, 17, 2,  6, 1, 59, 4, 52, 6, 48, 5, 16, 
    4, 23, 0, 56, 5, 12, 3, 41, 6, 43, 8, 56, 7, 20, 2, 73, 1, 41
  };
  const int q3306[] = {
    9, 9, // Number of jobs and machines
    6, 63, 2, 46, 4,  3, 7, 52, 3, 23, 1,  9, 5, 87, 8, 50, 0, 65, 
    1, 89, 0,  5, 4, 21, 2, 56, 7, 57, 8, 85, 3, 19, 6, 63, 5, 49, 
    7, 60, 6, 64, 5, 63, 1, 45, 0, 97, 2, 47, 4,  8, 3, 86, 8, 97, 
    4,  9, 6, 78, 0, 71, 2, 38, 7, 13, 3, 30, 1, 34, 8,  8, 5, 63, 
    7, 73, 6, 36, 2, 17, 0, 20, 8, 35, 5, 58, 3, 64, 4, 45, 1, 53, 
    3, 23, 5, 48, 2, 56, 6, 46, 7, 12, 4, 58, 0, 11, 8, 82, 1, 85, 
    3, 85, 4, 91, 0, 37, 1, 84, 7, 18, 5, 80, 8, 20, 6, 63, 2, 86, 
    6, 88, 3, 31, 1, 71, 0, 76, 5, 66, 2, 22, 8, 44, 4, 86, 7, 95, 
    7, 55, 8, 21, 0, 85, 3, 64, 5, 44, 4,  3, 2, 86, 1, 41, 6, 58
  };
  const int q3307[] = {
    9, 9, // Number of jobs and machines
    8,  1, 1, 30, 6, 58, 0, 86, 2,  7, 7, 45, 4, 58, 3, 67, 5, 19, 
    5, 71, 7, 60, 0, 44, 4, 21, 1, 28, 6, 17, 3, 68, 8, 26, 2, 18, 
    3, 77, 1, 75, 8, 20, 2, 32, 7, 86, 5, 37, 0, 48, 6,  3, 4, 48, 
    5, 27, 1, 31, 4, 25, 2, 55, 0, 16, 6, 64, 3, 47, 8, 19, 7, 32, 
    1, 14, 0, 27, 6,  8, 4, 48, 3, 76, 7, 30, 8, 19, 2, 40, 5, 99, 
    4, 31, 8, 79, 5, 12, 0, 54, 3, 66, 1, 52, 2, 16, 6, 98, 7, 90, 
    1, 79, 5, 82, 7, 70, 2, 14, 4, 52, 3, 77, 0, 55, 6, 70, 8, 27, 
    4, 68, 8, 28, 6, 28, 7, 96, 1, 96, 0, 94, 2, 17, 3, 99, 5, 62, 
    3, 51, 4, 26, 1, 43, 2, 30, 8, 44, 6, 49, 5, 70, 0, 97, 7, 40
  };
  const int q3308[] = {
    9, 9, // Number of jobs and machines
    4, 43, 7, 17, 3, 34, 1, 73, 6, 55, 5, 79, 2, 69, 0, 50, 8, 74, 
    5, 14, 7, 37, 8, 88, 1, 61, 2, 76, 0,  8, 6, 60, 4, 60, 3, 60, 
    7,  4, 6, 28, 0,  9, 1, 52, 4, 56, 2, 58, 5, 11, 3, 41, 8, 72, 
    2, 62, 5, 19, 7, 65, 4, 84, 8, 98, 6, 74, 0, 31, 3, 77, 1, 93, 
    5, 97, 7, 69, 1, 14, 0, 96, 3, 35, 4, 46, 2, 97, 6, 40, 8, 36, 
    6, 36, 2, 94, 7, 11, 3, 33, 1, 65, 4, 90, 5, 69, 0, 85, 8, 27, 
    8, 72, 5,  4, 1, 14, 0, 12, 6, 73, 7, 58, 2,  1, 4, 80, 3, 75, 
    5, 14, 0, 80, 3, 50, 7, 49, 8, 28, 4, 42, 1,  1, 6, 55, 2, 77, 
    3, 46, 4, 46, 6, 45, 0, 72, 7, 31, 1, 54, 5, 78, 2, 41, 8, 48
  };
  const int q3309[] = {
    9, 9, // Number of jobs and machines
    2,  6, 4, 17, 7, 83, 3, 56, 0, 15, 5, 41, 1, 33, 6, 36, 8, 12, 
    2, 72, 5, 63, 0, 39, 4, 61, 1, 34, 3, 45, 8, 73, 7, 46, 6, 76, 
    5, 94, 1, 45, 4,  9, 2, 21, 8, 31, 3, 82, 7, 28, 6, 97, 0, 77, 
    5, 97, 6, 17, 3, 88, 7, 27, 8, 31, 1, 51, 0, 90, 2, 27, 4, 53, 
    1, 81, 0, 80, 2, 74, 4, 67, 5, 19, 6, 85, 8, 69, 3, 91, 7, 39, 
    4, 96, 2, 48, 5, 81, 8, 80, 0, 88, 6, 94, 7, 44, 3, 60, 1, 11, 
    6, 68, 3, 21, 7, 88, 2, 96, 4, 14, 1, 12, 0, 32, 8, 56, 5, 32, 
    1, 45, 6, 94, 7, 84, 5, 24, 0, 27, 8, 16, 2, 85, 4, 19, 3, 73, 
    2, 90, 3, 75, 5, 16, 4, 40, 0, 81, 8, 45, 1, 40, 7, 35, 6, 84
  };
  const int q3310[] = {
    9, 9, // Number of jobs and machines
    8, 69, 1, 62, 4, 53, 3, 59, 5, 88, 7, 83, 6, 13, 2, 63, 0, 92, 
    2, 87, 6, 83, 7, 15, 3, 22, 4, 17, 5, 33, 1, 44, 8, 54, 0, 58, 
    0, 39, 6, 94, 2, 75, 3, 43, 5, 63, 7, 10, 4, 28, 1, 98, 8, 54, 
    5, 15, 6, 46, 8, 42, 1, 84, 7, 33, 3, 53, 4, 67, 2, 71, 0, 51, 
    8,  2, 1, 86, 3, 48, 6,  9, 0, 69, 7, 85, 2, 51, 4, 93, 5, 53, 
    1, 79, 6,  7, 7, 58, 8, 72, 5, 73, 3, 11, 2, 43, 4, 22, 0, 86, 
    7,  9, 1, 85, 0, 21, 3, 59, 2, 30, 5, 12, 6, 26, 8,  5, 4, 43, 
    6, 23, 0, 84, 7, 30, 1, 32, 3, 49, 2, 34, 5, 58, 8, 55, 4, 62, 
    8, 63, 2, 94, 6, 91, 1, 92, 5, 28, 0, 51, 4, 75, 3, 35, 7, 45
  };
  const int q3311[] = {
    9, 9, // Number of jobs and machines
    7, 88, 8, 80, 4,  5, 2, 45, 5, 44, 1, 91, 3, 65, 6, 84, 0,  5, 
    4, 99, 2, 85, 0, 94, 1, 29, 8, 66, 7, 26, 3, 52, 5, 41, 6, 30, 
    5,  8, 1, 96, 8, 68, 2, 31, 3, 42, 6, 13, 0, 65, 4, 58, 7, 57, 
    7, 25, 0,  2, 2, 11, 1, 18, 4, 87, 6, 96, 5, 35, 3, 46, 8, 55, 
    0,  8, 1, 85, 7, 46, 2, 58, 8, 51, 3, 98, 6, 14, 4, 53, 5, 63, 
    1, 28, 2, 57, 4, 61, 5, 74, 7,  9, 6, 86, 8, 93, 0,  3, 3,  1, 
    5, 47, 3, 32, 0, 59, 1, 51, 4, 89, 7, 96, 8, 14, 6, 67, 2, 37, 
    2, 91, 5, 24, 6, 81, 7, 99, 3, 54, 4, 84, 0, 74, 8, 81, 1,  9, 
    8, 52, 0,  2, 4, 85, 5, 24, 1, 59, 6, 36, 2, 90, 3, 77, 7, 11
  };
  const int q3312[] = {
    9, 9, // Number of jobs and machines
    3, 87, 1, 78, 8, 65, 7, 60, 2, 93, 6, 45, 0, 88, 5, 68, 4, 10, 
    3, 20, 2, 96, 8, 37, 6, 86, 1,  2, 0, 53, 4, 89, 7, 28, 5, 70, 
    6, 64, 1, 58, 2, 69, 8, 38, 0, 41, 4,  5, 3, 68, 7, 84, 5, 32, 
    0,  1, 8, 54, 4, 90, 2, 73, 3, 59, 5, 50, 1, 61, 7, 49, 6, 54, 
    7, 33, 6, 54, 2, 59, 1,  9, 4,  5, 0,  8, 5, 89, 8, 35, 3, 40, 
    7, 90, 6, 78, 0, 55, 3, 10, 2, 49, 4,  2, 8, 19, 5, 87, 1, 92, 
    4, 98, 8, 29, 5, 16, 7, 87, 2, 93, 0,  8, 6, 34, 3, 18, 1, 91, 
    1, 32, 6, 19, 0, 92, 8, 96, 4, 16, 2, 52, 3, 93, 7, 23, 5, 33, 
    3, 33, 2,  5, 8, 82, 4, 53, 7, 82, 0, 29, 5, 45, 1, 65, 6, 52
  };
  const int q3313[] = {
    9, 9, // Number of jobs and machines
    6, 91, 1, 40, 2, 45, 7,  6, 8, 45, 3, 17, 5, 34, 0, 58, 4, 35, 
    4, 93, 1, 97, 0, 20, 7, 20, 6, 78, 5, 91, 3, 18, 8, 51, 2, 87, 
    4, 39, 2, 89, 7, 94, 3, 52, 8, 72, 5, 94, 6,  9, 1, 91, 0, 44, 
    8, 69, 0, 98, 7, 16, 1, 32, 3, 67, 5, 93, 2, 75, 4, 32, 6, 93, 
    5, 52, 1, 88, 7, 90, 8, 48, 2,  2, 6, 48, 4, 99, 3, 83, 0, 52, 
    3, 55, 2, 66, 5, 48, 4, 40, 6, 53, 7, 18, 8, 25, 1, 11, 0, 68, 
    1, 65, 6, 18, 3, 22, 4, 19, 2, 24, 0, 97, 7, 90, 8, 18, 5, 84, 
    4, 93, 2, 98, 6, 26, 3, 36, 8, 73, 7, 49, 1, 25, 0, 44, 5, 75, 
    5, 36, 0,  7, 7, 83, 1, 80, 3, 46, 4, 28, 6, 73, 8, 94, 2, 83
  };
  const int q3314[] = {
    9, 9, // Number of jobs and machines
    6, 78, 0,  5, 5, 14, 2, 10, 7, 79, 8, 76, 4, 58, 1, 22, 3, 45, 
    1,  3, 0, 47, 2, 66, 8, 40, 7, 49, 6, 26, 4, 57, 5,  7, 3, 66, 
    4, 75, 5, 54, 6, 19, 2, 55, 0, 69, 1, 47, 8, 46, 3, 83, 7, 87, 
    7, 86, 4,  3, 6, 72, 5, 59, 3, 32, 1, 70, 2, 93, 8,  4, 0,  1, 
    5, 30, 7, 27, 4, 36, 0, 67, 8, 66, 6, 66, 2, 71, 1, 73, 3, 12, 
    5, 95, 6, 19, 0, 12, 4, 32, 3, 58, 1, 65, 7, 72, 8, 84, 2,  7, 
    4, 32, 0, 19, 1, 30, 3, 84, 5, 40, 7, 69, 2, 12, 8, 46, 6, 27, 
    0, 68, 6, 64, 8, 16, 3, 82, 4, 85, 1,  1, 5, 49, 7, 39, 2, 36, 
    8, 17, 5, 69, 1, 11, 6, 43, 4, 92, 7, 58, 3, 53, 0, 70, 2, 17
  };
  const int q3315[] = {
    9, 9, // Number of jobs and machines
    3,  3, 6, 68, 7, 95, 2, 63, 0, 66, 8, 98, 4, 37, 5, 33, 1, 99, 
    7, 81, 2, 69, 1, 24, 3, 49, 6, 74, 0, 13, 8, 58, 5, 17, 4, 39, 
    3, 54, 0, 75, 5,  2, 6, 83, 1, 77, 8, 85, 4, 38, 2, 56, 7, 61, 
    2, 70, 8,  8, 7, 87, 6, 69, 0, 57, 3, 34, 1, 32, 4, 68, 5, 60, 
    2, 94, 4, 54, 5,  6, 0, 53, 1, 15, 7, 62, 6, 14, 3, 36, 8, 69, 
    1, 14, 3,  1, 8, 55, 6, 53, 7, 27, 4, 50, 5, 68, 2, 61, 0, 12, 
    1, 11, 5, 91, 7, 11, 3, 48, 2, 45, 4,  9, 0, 99, 6, 22, 8, 29, 
    0, 77, 2, 28, 6, 64, 8, 20, 5, 55, 4, 48, 7, 18, 3, 30, 1, 92, 
    6, 71, 8, 63, 1, 86, 3, 93, 7, 37, 0, 98, 2, 90, 5, 75, 4, 74
  };
  const int q3316[] = {
    9, 9, // Number of jobs and machines
    8, 25, 3, 22, 2, 59, 0, 26, 5, 21, 6, 35, 7, 45, 1, 19, 4, 43, 
    8, 81, 0, 79, 5, 55, 3, 83, 6, 71, 4,  3, 1, 99, 2,  6, 7, 87, 
    0,  7, 2, 84, 7, 83, 4, 56, 8,  6, 5, 13, 3, 22, 6, 15, 1,  5, 
    3, 40, 2, 35, 1, 53, 4,  1, 6, 61, 7, 66, 0, 89, 8,  6, 5, 96, 
    7, 59, 5, 11, 4, 23, 1, 19, 0, 52, 3,  8, 6, 17, 8, 89, 2, 45, 
    1, 30, 7, 92, 6, 27, 0, 90, 8, 17, 3, 10, 4, 54, 2, 73, 5, 94, 
    5, 84, 6, 44, 3, 77, 7,  2, 0,  6, 2,  3, 4, 43, 8, 29, 1, 38, 
    1, 97, 7, 77, 6, 73, 0, 15, 4, 23, 2, 17, 8, 19, 3, 15, 5, 80, 
    8, 25, 3, 54, 4, 20, 7, 87, 5, 36, 0, 34, 2, 63, 1, 17, 6, 79
  };
  const int q3317[] = {
    9, 9, // Number of jobs and machines
    3, 60, 2, 28, 7, 20, 4, 24, 8, 39, 1, 14, 6,  9, 0, 58, 5, 93, 
    8, 43, 5, 83, 0, 79, 4, 22, 6, 63, 2, 81, 1,  9, 3, 55, 7, 29, 
    2, 17, 6, 15, 5, 32, 7,  6, 1,  4, 0, 98, 4, 58, 3, 46, 8, 88, 
    7, 36, 3, 13, 5, 62, 0, 61, 2, 54, 1, 65, 6,  3, 8, 92, 4, 72, 
    5, 48, 8,  7, 6, 18, 4, 10, 3, 38, 0, 94, 1, 73, 2, 72, 7,  6, 
    1, 15, 3, 83, 5, 20, 6, 85, 0,  3, 4, 68, 2,  7, 7, 62, 8, 57, 
    4, 89, 2, 27, 1, 12, 8, 88, 0, 81, 5, 86, 6, 72, 7,  3, 3, 68, 
    4, 32, 1, 87, 7, 76, 0, 34, 2, 30, 8, 72, 5, 93, 6, 61, 3, 41, 
    5, 41, 8, 91, 3, 22, 7, 37, 6, 61, 4, 82, 0, 53, 1, 34, 2, 67
  };
  const int q3318[] = {
    9, 9, // Number of jobs and machines
    7, 20, 8, 98, 6, 56, 3, 31, 1, 77, 5, 75, 4, 70, 2,  5, 0, 76, 
    5,  9, 6, 62, 1, 83, 3, 87, 0, 53, 4, 87, 2, 23, 7, 20, 8,  7, 
    2, 59, 0, 47, 3, 85, 6, 40, 5, 78, 7, 70, 8, 16, 1,  1, 4,  3, 
    3, 27, 2, 59, 8, 53, 1, 84, 5, 81, 0, 66, 4,  7, 6, 68, 7, 64, 
    6, 99, 1, 53, 5, 85, 8, 98, 3, 27, 4,  3, 7, 35, 2, 52, 0, 59, 
    7, 36, 5,  2, 2, 70, 1, 33, 8, 94, 6, 34, 0,  8, 4, 48, 3, 45, 
    5, 41, 7, 47, 4, 41, 3, 68, 0, 52, 1, 90, 2, 45, 8, 50, 6, 17, 
    8, 99, 5, 71, 1, 56, 6, 24, 7, 43, 0, 65, 3, 37, 4, 65, 2, 17, 
    0, 20, 7, 95, 2,  8, 4, 74, 3, 47, 5, 70, 1, 58, 8, 20, 6, 58
  };
  const int q3319[] = {
    9, 9, // Number of jobs and machines
    3, 26, 7, 46, 5, 29, 2, 22, 6, 54, 1, 74, 0, 49, 4,  9, 8, 15, 
    4, 21, 2, 85, 8, 48, 6,  4, 1, 42, 5, 12, 7, 79, 3, 22, 0, 89, 
    5, 85, 1, 38, 7, 95, 0, 13, 8, 93, 2, 35, 4, 97, 3, 40, 6, 88, 
    4, 39, 6, 76, 2, 18, 0, 27, 3, 86, 1, 35, 7, 81, 8, 30, 5,  2, 
    1, 97, 5, 33, 8, 51, 7, 41, 2, 33, 0, 24, 4, 58, 6, 90, 3, 48, 
    0,  4, 7, 88, 5, 92, 8, 19, 3, 14, 4,  3, 1, 10, 6, 22, 2, 90, 
    8, 67, 4, 91, 0, 11, 1, 16, 5, 99, 6, 26, 3, 74, 7, 35, 2, 40, 
    6,  4, 4, 94, 3, 33, 1, 60, 0, 12, 2, 39, 7, 46, 8, 86, 5, 28, 
    0,  5, 5, 77, 2, 16, 1, 54, 7, 71, 8, 71, 6, 75, 4, 47, 3, 79
  };
  const int q3320[] = {
    9, 9, // Number of jobs and machines
    1, 25, 3, 93, 2, 51, 4, 45, 6, 90, 0, 92, 5,  4, 8, 40, 7, 72, 
    3, 95, 1, 77, 5, 65, 6, 41, 7, 30, 8, 40, 0, 39, 4, 67, 2, 52, 
    4, 88, 6, 32, 2, 19, 1,  5, 0, 97, 5, 55, 8, 44, 3, 48, 7, 70, 
    7, 34, 0, 24, 2, 24, 5, 29, 3, 18, 8, 45, 6, 36, 1, 64, 4, 73, 
    4, 96, 1, 97, 0, 78, 5, 12, 8, 48, 2, 71, 3, 43, 7, 94, 6, 98, 
    7, 81, 1, 31, 5, 76, 3,  2, 2, 47, 0, 88, 6, 62, 8, 42, 4, 37, 
    5, 92, 7, 79, 8, 67, 2, 20, 6, 78, 1, 80, 0, 46, 3, 76, 4, 59, 
    8, 29, 4, 98, 2, 30, 6, 97, 5, 52, 3, 26, 7, 12, 0, 36, 1, 24, 
    5, 89, 4, 86, 2, 37, 1, 57, 6, 40, 0, 65, 7,  3, 8,  2, 3, 30
  };
  const int q3321[] = {
    9, 9, // Number of jobs and machines
    4,  9, 6, 64, 5, 13, 0, 14, 1,  9, 8, 14, 3, 47, 2, 54, 7, 72, 
    1, 96, 3, 96, 7, 55, 4, 12, 2, 19, 6, 82, 8, 76, 0,  1, 5, 30, 
    5, 45, 0, 78, 4, 42, 3, 96, 8, 62, 2, 42, 1, 41, 6, 88, 7, 82, 
    8, 89, 3, 69, 7,  7, 2, 17, 1, 89, 0, 41, 4, 34, 6, 69, 5, 63, 
    5, 57, 0, 51, 7, 20, 6, 54, 8, 29, 2, 34, 1,  2, 4, 27, 3, 60, 
    5, 98, 4, 10, 8, 78, 6, 56, 2, 12, 0, 82, 3, 40, 7, 92, 1, 64, 
    6, 86, 2, 56, 7, 25, 4, 66, 8, 34, 3, 68, 0, 14, 1, 78, 5, 58, 
    0, 82, 6, 96, 5, 35, 4, 73, 3, 36, 1, 15, 2, 90, 8, 56, 7, 73, 
    1,  9, 7, 41, 6, 80, 4, 13, 3, 71, 5, 92, 2, 12, 0, 61, 8, 51
  };
  const int q3322[] = {
    9, 9, // Number of jobs and machines
    5, 88, 6, 15, 4, 19, 1, 22, 7,  2, 0, 36, 8,  1, 3, 58, 2,  7, 
    4, 34, 0, 28, 6, 30, 5,  3, 3, 57, 8,  5, 7, 61, 2, 67, 1, 71, 
    4, 77, 2, 18, 5, 83, 0, 91, 3,  6, 8, 15, 1, 56, 7, 58, 6, 61, 
    4, 12, 0, 12, 7, 93, 3, 48, 1, 90, 6,  5, 5, 43, 8, 34, 2, 87, 
    2, 58, 0, 96, 1, 52, 5, 17, 4, 29, 3, 36, 6, 26, 8, 64, 7, 32, 
    8, 62, 6, 91, 2, 55, 4, 14, 7, 29, 1, 15, 5, 32, 3, 50, 0, 91, 
    1, 27, 3, 15, 5, 71, 7, 22, 2, 10, 8, 10, 4, 80, 6, 32, 0, 99, 
    2, 86, 5, 81, 6, 13, 4,  9, 1, 13, 3,  1, 8, 48, 7, 22, 0, 99, 
    6, 32, 0, 75, 3, 22, 2, 85, 4, 21, 7, 17, 8, 83, 1, 84, 5, 48
  };
  const int q3323[] = {
    9, 9, // Number of jobs and machines
    2, 66, 4, 12, 1, 21, 3, 84, 8, 59, 0, 59, 6, 61, 7, 95, 5,  7, 
    6, 61, 1, 87, 2, 93, 5, 65, 4,  8, 3, 90, 8, 58, 7, 30, 0, 59, 
    8, 34, 7, 46, 4, 97, 6, 34, 0, 55, 5, 23, 3, 84, 1, 43, 2, 25, 
    8, 81, 7, 58, 0, 67, 5, 75, 6, 71, 1,  2, 3, 52, 4, 89, 2, 24, 
    3, 93, 2, 42, 7, 29, 8, 14, 4, 92, 0, 79, 6, 69, 5, 97, 1,  1, 
    8, 21, 2, 20, 1, 90, 6, 40, 7, 41, 3, 92, 4, 50, 0, 55, 5, 64, 
    8, 26, 1, 31, 4, 79, 2, 81, 6, 52, 5, 25, 7, 17, 3, 66, 0, 21, 
    2, 23, 3,  6, 0, 94, 4, 53, 1,  9, 5, 13, 6,  1, 8, 96, 7, 84, 
    6, 68, 3, 54, 5,  1, 7, 85, 8, 61, 1, 38, 4, 82, 0, 48, 2, 73
  };
  const int q3324[] = {
    9, 9, // Number of jobs and machines
    7, 30, 4, 28, 5, 84, 3, 97, 0, 23, 6, 88, 8, 16, 1, 94, 2,  9, 
    8, 95, 6, 94, 5, 25, 1, 51, 7, 79, 4, 10, 3, 51, 0, 20, 2, 59, 
    6, 55, 0, 65, 7, 61, 4, 54, 2, 85, 1, 88, 5, 86, 8, 80, 3, 17, 
    7,  5, 5, 87, 8, 61, 2,  6, 4, 51, 0, 74, 1, 60, 3, 72, 6, 16, 
    0, 94, 8, 48, 1,  9, 3, 98, 2, 74, 6, 62, 7, 29, 4, 10, 5, 62, 
    3, 27, 8, 36, 6, 87, 0, 25, 2, 13, 1, 52, 4,  1, 5, 16, 7, 79, 
    1, 79, 5, 84, 4, 91, 6, 84, 7,  3, 8, 84, 0, 21, 3, 57, 2, 49, 
    1, 10, 7, 72, 4, 31, 5,  9, 3, 96, 6, 66, 8, 22, 0, 82, 2, 20, 
    2, 62, 5, 30, 0, 23, 7, 89, 4, 76, 3, 50, 8, 37, 1, 98, 6, 73
  };
  const int q3325[] = {
    9, 9, // Number of jobs and machines
    4, 31, 7,  9, 1, 18, 8, 60, 0, 87, 5, 53, 2,  5, 3,  9, 6, 95, 
    5, 23, 7, 73, 6, 33, 2, 42, 1, 94, 8, 18, 0, 74, 4, 34, 3, 73, 
    0, 39, 3, 25, 5, 34, 7, 56, 2, 89, 1,  7, 8,  8, 6, 23, 4, 44, 
    3, 99, 0, 20, 1, 26, 4, 16, 5, 80, 6, 17, 7, 50, 2, 19, 8, 99, 
    0, 75, 5, 35, 8, 28, 2, 22, 3, 53, 4, 33, 1, 78, 6, 20, 7, 70, 
    0,  2, 6, 49, 2, 79, 3, 39, 5, 76, 7, 79, 8, 96, 1, 53, 4, 33, 
    3, 40, 6, 88, 4,  5, 5, 78, 1,  8, 8, 18, 2, 83, 7, 70, 0, 36, 
    1, 46, 8, 55, 2,  5, 3,  8, 7, 15, 5, 73, 0, 42, 4, 96, 6, 31, 
    5, 81, 1, 15, 6, 14, 7, 73, 2, 60, 8, 54, 0, 17, 3, 74, 4, 80
  };
  const int q3326[] = {
    9, 9, // Number of jobs and machines
    0, 46, 2, 18, 8, 58, 3, 79, 6, 77, 5, 24, 1,  1, 4, 85, 7, 89, 
    4,  9, 1, 72, 6, 67, 5,  1, 3,  1, 8, 61, 7, 49, 0,  5, 2, 91, 
    8, 60, 6, 49, 0, 54, 3, 34, 7,  6, 1, 61, 5, 19, 2, 71, 4, 78, 
    6, 94, 7, 73, 5, 23, 2, 77, 1, 56, 4, 57, 0, 54, 8, 38, 3,  9, 
    1, 95, 0, 15, 8, 51, 7, 41, 5, 39, 3, 31, 6, 69, 2, 63, 4, 29, 
    1, 69, 4, 48, 3, 10, 8,  2, 6, 56, 0, 48, 5, 30, 7, 20, 2, 37, 
    5, 55, 7, 55, 1, 26, 3, 55, 6, 96, 4, 31, 2, 63, 0, 39, 8, 41, 
    6, 98, 8, 90, 1, 36, 5, 13, 3, 11, 7, 77, 4, 63, 2, 99, 0, 85, 
    8, 23, 5, 81, 2, 72, 0, 75, 1, 97, 4,  2, 7, 64, 6, 71, 3, 33
  };
  const int q3327[] = {
    9, 9, // Number of jobs and machines
    8, 25, 2, 68, 6, 18, 7, 73, 1, 95, 3, 29, 5, 11, 4, 66, 0, 85, 
    8, 37, 6, 61, 2, 72, 0,  4, 5, 10, 3, 67, 4, 24, 7,  5, 1, 62, 
    0, 77, 4, 93, 7, 75, 1, 42, 6, 91, 3, 30, 8, 97, 2, 48, 5, 67, 
    2, 44, 7, 76, 6, 34, 0, 79, 5, 91, 1, 16, 3,  2, 8,  5, 4, 77, 
    6, 77, 1, 95, 2, 47, 5, 75, 0,  9, 3, 21, 8, 38, 7,  9, 4, 85, 
    3, 87, 8,  8, 0, 41, 2, 66, 1, 60, 4, 29, 5, 41, 7, 43, 6, 31, 
    0, 29, 8, 86, 5,  4, 7, 26, 1, 39, 3, 48, 6, 32, 2, 94, 4, 38, 
    7, 46, 3,  8, 6, 50, 1, 66, 0,  8, 8,  4, 4,  2, 5, 83, 2, 67, 
    2, 66, 0, 30, 1, 28, 5, 23, 7, 47, 6, 41, 4, 11, 8, 47, 3, 27
  };
  const int q3328[] = {
    9, 9, // Number of jobs and machines
    8, 46, 5,  4, 1,  2, 2, 78, 4, 43, 6,  8, 7, 90, 3, 22, 0, 94, 
    3, 36, 1, 13, 2, 16, 4,  4, 6, 12, 0, 57, 7, 40, 5, 41, 8, 93, 
    7, 77, 8, 10, 3, 82, 5, 78, 4, 86, 2, 96, 6, 98, 1,  8, 0, 33, 
    1,  1, 2, 64, 8, 57, 5, 96, 3, 97, 7, 88, 0, 21, 4, 53, 6, 96, 
    5, 62, 8, 69, 4, 78, 3, 95, 6, 32, 0, 57, 7, 49, 2, 12, 1, 91, 
    8, 11, 2, 52, 1, 79, 7, 90, 5, 82, 0, 84, 6, 88, 4, 38, 3, 55, 
    8,  7, 1, 70, 2, 80, 3, 44, 7,  5, 0, 44, 5, 72, 4, 85, 6, 83, 
    8, 38, 0, 56, 7, 24, 2, 17, 3, 16, 1, 40, 6,  3, 4, 59, 5, 50, 
    8, 61, 0, 28, 7, 41, 5, 59, 4, 69, 1, 80, 6, 78, 3,  4, 2,  6
  };
  const int q3329[] = {
    9, 9, // Number of jobs and machines
    6, 44, 7, 85, 2, 14, 0, 44, 8, 99, 5, 23, 3, 37, 4, 14, 1, 45, 
    8, 65, 5,  8, 0, 13, 4, 83, 2, 44, 7, 84, 1, 97, 6, 17, 3, 26, 
    3, 69, 8, 79, 6,  2, 2, 20, 5, 54, 7, 80, 0, 45, 1, 74, 4, 63, 
    8, 31, 3,  2, 1, 60, 4, 41, 5, 37, 2, 47, 7, 39, 6, 63, 0, 99, 
    6, 35, 3, 45, 5, 49, 4,  5, 0, 40, 1, 88, 7, 16, 2, 67, 8, 53, 
    5, 61, 4, 19, 2, 17, 1, 16, 3, 10, 0, 88, 8, 92, 7, 59, 6, 20, 
    1, 15, 5, 61, 8, 32, 4, 19, 7, 89, 2, 34, 0, 79, 3, 55, 6,  5, 
    2, 48, 7, 15, 4, 87, 3, 13, 1, 52, 8, 61, 0, 79, 5, 31, 6, 21, 
    3, 49, 2, 95, 8, 23, 4, 60, 5,  9, 7, 73, 0,  7, 1, 10, 6, 73
  };
  const int q3330[] = {
    9, 9, // Number of jobs and machines
    5,  1, 3,  8, 0, 83, 7, 20, 1, 86, 4,  5, 6, 80, 8, 95, 2, 50, 
    7,  9, 0,  7, 3, 89, 8, 41, 4, 17, 6, 42, 1, 94, 5, 11, 2, 18, 
    0, 62, 2, 12, 6, 78, 8, 70, 5, 20, 1, 79, 4, 39, 7, 76, 3, 52, 
    3, 28, 5, 18, 1, 47, 0, 12, 2,  8, 7, 88, 6, 34, 8, 26, 4, 81, 
    6, 76, 8, 17, 7, 21, 1,  6, 5, 58, 2, 92, 3, 23, 0, 89, 4, 74, 
    1, 73, 0, 14, 7, 60, 6, 47, 3, 68, 5,  9, 2, 36, 4, 26, 8, 34, 
    1, 98, 3, 25, 0, 50, 6, 83, 2, 77, 4, 26, 8, 77, 7, 25, 5, 70, 
    4, 78, 2, 52, 1,  9, 5, 79, 6, 80, 3, 64, 8, 39, 7, 81, 0, 66, 
    2,  6, 4,  4, 3, 77, 1, 95, 7, 92, 6, 31, 0, 64, 5, 42, 8,  7
  };
  const int q3331[] = {
    9, 9, // Number of jobs and machines
    2, 42, 5, 64, 8, 44, 0, 88, 7,  2, 3, 92, 6, 91, 1, 81, 4, 71, 
    0, 18, 6, 26, 3, 28, 4, 15, 1, 35, 8, 11, 7, 45, 2, 34, 5, 50, 
    7, 46, 4, 68, 0,  5, 6, 81, 2, 76, 1, 43, 3, 72, 5, 46, 8, 53, 
    5, 22, 4, 52, 8, 33, 2, 17, 0, 75, 6, 22, 7, 85, 1, 99, 3, 73, 
    1, 71, 6, 94, 8, 47, 3, 41, 2, 80, 5, 93, 0, 39, 7, 48, 4, 91, 
    6, 24, 5, 89, 2, 11, 4,  7, 8, 64, 3, 31, 7, 28, 0,  7, 1,  7, 
    4, 92, 5, 39, 6, 33, 8, 77, 2, 51, 3, 44, 7,  1, 1, 86, 0, 47, 
    2, 47, 7, 29, 1,  1, 6, 92, 5, 28, 4, 91, 8, 42, 3, 90, 0, 59, 
    6, 78, 0, 50, 1, 98, 4,  4, 5, 62, 3, 90, 7, 73, 8, 79, 2, 34
  };
  const int q3332[] = {
    9, 9, // Number of jobs and machines
    2, 22, 1, 42, 0, 12, 8, 27, 4, 48, 5, 70, 7, 33, 6, 64, 3, 49, 
    4, 59, 3, 26, 0, 25, 7, 21, 6, 63, 8, 64, 2, 64, 5, 34, 1, 36, 
    8, 50, 4, 30, 6, 27, 2, 74, 7, 13, 3,  4, 0, 93, 5, 79, 1, 12, 
    3,  2, 1, 68, 2, 96, 4, 90, 5, 99, 0, 38, 7, 32, 6, 61, 8, 33, 
    1, 99, 0, 99, 8, 89, 3, 95, 4, 33, 2, 76, 5, 91, 6, 92, 7, 99, 
    3, 31, 2, 66, 1, 43, 8, 47, 6, 63, 4, 60, 0, 92, 7, 23, 5, 41, 
    6, 61, 3, 68, 7, 62, 0, 93, 8, 36, 2, 45, 1, 27, 5, 11, 4, 48, 
    8, 37, 2, 10, 5, 33, 4, 57, 0, 87, 7, 52, 1, 61, 6, 71, 3, 75, 
    7, 40, 6, 63, 5, 55, 2, 86, 8, 96, 4, 69, 3, 29, 1, 98, 0, 31
  };
  const int q3333[] = {
    9, 9, // Number of jobs and machines
    7, 17, 5, 69, 4, 94, 3, 69, 6, 33, 0, 47, 1, 74, 8, 27, 2, 22, 
    2, 24, 7, 58, 3, 63, 5, 26, 6, 80, 4, 73, 8, 20, 1, 67, 0, 95, 
    0, 65, 4, 75, 6, 33, 7, 54, 5,  8, 2,  8, 1, 72, 3, 93, 8, 33, 
    0, 95, 6, 17, 7, 19, 3, 71, 4, 91, 2, 76, 5,  3, 8, 20, 1, 20, 
    8, 77, 2, 37, 7,  9, 5, 57, 3, 21, 4, 95, 0, 27, 1, 27, 6, 17, 
    5, 76, 4, 89, 8, 21, 2, 16, 6, 15, 3, 17, 1, 30, 0, 61, 7, 83, 
    3, 20, 0, 98, 4,  5, 1, 29, 6, 36, 7, 89, 8, 36, 2, 83, 5, 75, 
    0, 65, 7, 65, 3, 27, 6, 42, 2, 41, 1, 53, 8, 41, 4, 24, 5, 10, 
    6,  7, 1, 31, 4, 67, 8, 37, 3, 49, 7,  5, 0, 47, 2, 74, 5, 65
  };
  const int q3334[] = {
    9, 9, // Number of jobs and machines
    7, 11, 2, 30, 8, 51, 5, 46, 0, 32, 6, 19, 1, 63, 4, 75, 3, 68, 
    7, 31, 0, 22, 2, 35, 3, 86, 8, 56, 5,  3, 6, 99, 4, 52, 1, 60, 
    0, 22, 3, 26, 1, 47, 6, 10, 4, 39, 8,  2, 7, 49, 2, 91, 5, 94, 
    5, 30, 0, 29, 1, 16, 4, 10, 3, 70, 2, 45, 8, 66, 7, 57, 6, 58, 
    7, 78, 3, 98, 6, 31, 1, 95, 2, 34, 8, 66, 5, 28, 4, 86, 0, 78, 
    5, 30, 8, 24, 0,  6, 1, 39, 7, 94, 3, 67, 6, 48, 2, 51, 4, 26, 
    1, 74, 8, 88, 3, 77, 4, 72, 7, 92, 0, 39, 5, 61, 6, 32, 2, 38, 
    2,  3, 4, 57, 5, 54, 0, 16, 1, 37, 6, 26, 7, 15, 8, 96, 3, 56, 
    0, 70, 5, 73, 2, 84, 7, 38, 1, 47, 4, 58, 8, 79, 3, 16, 6, 47
  };
  const int q3335[] = {
    9, 9, // Number of jobs and machines
    2, 56, 0, 65, 1,  4, 4, 22, 6, 40, 3, 94, 5, 25, 7, 99, 8, 38, 
    3, 74, 2, 98, 7, 35, 0, 49, 5, 23, 1, 83, 6, 88, 4, 77, 8,  1, 
    5, 99, 0, 21, 6, 81, 2, 76, 1, 57, 3, 20, 8, 14, 7, 24, 4, 29, 
    5, 33, 6, 35, 2, 63, 3, 26, 1, 76, 7, 82, 8,  7, 4, 73, 0, 94, 
    8, 47, 2, 68, 6, 86, 0, 71, 3, 34, 7,  9, 4, 75, 1, 42, 5, 57, 
    3, 78, 0, 49, 1, 72, 5, 59, 4, 77, 8, 40, 6, 56, 2, 18, 7, 70, 
    5, 64, 6, 53, 1, 26, 2, 28, 7, 50, 4, 79, 8, 84, 0, 44, 3, 83, 
    0, 46, 2, 49, 3, 93, 4, 26, 7, 76, 6, 93, 1,  1, 8, 25, 5, 84, 
    2,  3, 8, 29, 6, 89, 7, 97, 5, 35, 1, 13, 3, 26, 4, 30, 0, 81
  };
  const int q3336[] = {
    9, 9, // Number of jobs and machines
    7, 46, 0,  4, 2, 68, 5, 24, 8, 98, 4, 59, 1, 32, 6, 21, 3, 98, 
    2,  1, 6, 43, 5, 71, 4, 92, 7,  8, 8, 48, 3, 87, 0, 12, 1, 74, 
    6, 39, 1, 23, 2, 42, 8, 84, 7, 89, 3, 98, 4,  1, 5, 54, 0, 81, 
    8, 40, 6, 96, 2, 60, 4, 24, 0,  8, 5, 48, 1, 66, 7, 16, 3, 35, 
    1, 63, 5, 89, 3, 52, 8, 44, 2, 46, 4, 90, 0, 98, 6, 88, 7, 85, 
    1, 42, 5, 95, 7, 24, 3, 43, 2, 66, 0, 36, 6, 77, 8, 84, 4, 87, 
    3, 51, 4, 97, 8, 24, 6, 88, 0, 67, 7, 61, 1, 53, 2, 64, 5, 21, 
    1, 96, 5, 93, 2, 69, 3,  6, 6, 56, 0, 43, 8, 20, 4, 57, 7, 56, 
    3, 69, 0, 87, 8, 14, 1, 12, 7,  3, 5,  9, 4, 65, 6, 39, 2, 72
  };
  const int q3337[] = {
    9, 9, // Number of jobs and machines
    0, 94, 2, 84, 6, 32, 1, 32, 5, 67, 4, 50, 7, 45, 3, 33, 8, 39, 
    4, 21, 6, 60, 7, 62, 5, 49, 3, 90, 2, 34, 1,  3, 0, 20, 8, 16, 
    0,  7, 3, 30, 8, 64, 1, 12, 7, 80, 2, 50, 5, 82, 6, 15, 4, 14, 
    6, 21, 8, 12, 1, 15, 0, 89, 3, 64, 7, 20, 2, 92, 5, 14, 4, 53, 
    6, 20, 3, 88, 0, 12, 8, 89, 7, 30, 2, 73, 1, 66, 5, 65, 4,  7, 
    7, 23, 6,  6, 0, 93, 4, 13, 2,  6, 3, 66, 1, 20, 5, 52, 8, 31, 
    4, 33, 3, 93, 5, 49, 1, 73, 2, 11, 6, 83, 8,  9, 0, 88, 7, 38, 
    1, 66, 4,  9, 7,  3, 2, 70, 5, 95, 8, 92, 3, 83, 0, 63, 6, 10, 
    1, 37, 3, 30, 2,  6, 6, 10, 0, 69, 8, 27, 4, 78, 5, 90, 7, 73
  };
  const int q3338[] = {
    9, 9, // Number of jobs and machines
    6, 98, 7, 28, 5, 69, 3, 60, 8, 19, 2, 60, 0, 97, 1, 18, 4, 41, 
    7, 93, 1, 38, 5, 31, 3, 18, 2,  6, 0, 46, 4, 22, 6, 41, 8, 38, 
    3, 91, 5, 49, 4, 61, 2, 94, 1, 21, 7, 59, 6, 44, 8, 35, 0, 52, 
    6, 57, 3, 43, 5, 93, 4, 93, 7, 91, 8, 33, 1, 63, 0, 96, 2, 17, 
    8, 56, 2, 82, 6, 39, 3, 98, 0, 84, 5, 17, 7, 36, 1, 97, 4, 22, 
    3,  9, 8, 46, 4, 17, 5, 10, 2, 91, 0, 11, 7, 11, 1, 37, 6, 36, 
    4, 34, 7, 80, 8,  9, 3, 43, 0, 62, 2, 62, 5, 49, 6, 26, 1, 17, 
    1, 62, 7, 10, 2,  7, 4,  1, 8, 57, 3, 40, 5, 37, 0,  4, 6, 66, 
    2, 46, 7, 56, 6, 53, 8, 49, 3,  7, 4, 62, 1, 28, 5, 22, 0, 41
  };
  const int q3339[] = {
    9, 9, // Number of jobs and machines
    7, 50, 4, 73, 3, 55, 1, 10, 2,  6, 0, 30, 6, 97, 8, 77, 5, 80, 
    1, 85, 6, 66, 2, 26, 0, 49, 4, 76, 8, 12, 7, 61, 3, 40, 5, 70, 
    3, 19, 5, 28, 6, 81, 1, 17, 7, 99, 0, 23, 2, 92, 8, 59, 4, 71, 
    3, 78, 8, 39, 2, 48, 7, 77, 0, 92, 1, 13, 6, 75, 4, 97, 5, 59, 
    5, 90, 3, 85, 6, 98, 8, 84, 2, 35, 7, 70, 4, 39, 0, 53, 1,  2, 
    2, 31, 0, 43, 4,  6, 8, 22, 3, 73, 7, 51, 1, 61, 6, 16, 5, 16, 
    4, 45, 2,  5, 7, 48, 5, 50, 0, 64, 8, 24, 1, 36, 6, 96, 3, 78, 
    3, 88, 8, 10, 5, 46, 4, 13, 2, 71, 6, 49, 7, 82, 1, 67, 0, 96, 
    1, 84, 2, 54, 8, 73, 3, 11, 6, 35, 4, 96, 7, 65, 5, 60, 0, 90
  };
  const int q3340[] = {
    9, 9, // Number of jobs and machines
    8, 60, 7, 98, 3, 49, 2, 96, 1, 74, 5, 40, 4, 53, 0, 60, 6, 78, 
    4, 23, 6,  5, 5, 40, 2, 57, 8,  3, 3, 89, 1, 55, 7, 90, 0, 76, 
    3, 54, 1, 40, 7, 43, 2, 24, 6, 50, 8, 82, 0, 72, 4,  6, 5, 75, 
    0, 93, 7, 70, 4, 84, 6, 40, 5, 56, 2, 44, 3, 96, 1, 47, 8, 94, 
    2, 28, 7, 50, 8, 29, 5,  1, 3,  4, 1, 66, 6, 89, 0, 90, 4, 15, 
    7, 69, 4, 87, 1, 28, 3, 63, 8, 54, 6, 86, 5, 33, 0, 46, 2,  1, 
    7, 64, 2, 37, 8, 85, 1, 82, 4, 42, 3, 55, 0,  1, 5, 27, 6, 80, 
    1, 22, 3, 70, 2, 98, 4,  8, 8, 35, 5, 84, 7, 89, 6,  8, 0, 54, 
    2, 74, 3, 80, 7, 58, 0, 80, 6, 13, 5, 40, 8, 47, 4, 63, 1, 72
  };
  const int q3341[] = {
    9, 9, // Number of jobs and machines
    5, 16, 8, 71, 0, 52, 3, 35, 6, 73, 1, 34, 2, 85, 7, 90, 4, 64, 
    2, 77, 7,  1, 5, 19, 1, 46, 3, 71, 0, 71, 4, 73, 6,  6, 8, 31, 
    5, 88, 8,  7, 1, 31, 0, 77, 3, 72, 7, 51, 6, 26, 2, 79, 4, 87, 
    7, 76, 8, 65, 3, 39, 4,  4, 2, 93, 5, 40, 1, 87, 6, 30, 0, 29, 
    6, 10, 3,  6, 4,  3, 5, 89, 1, 88, 2, 90, 7, 98, 8, 14, 0, 22, 
    5, 57, 2, 67, 7, 46, 3, 51, 8, 42, 1, 95, 6, 35, 4,  9, 0, 40, 
    1, 51, 8, 85, 2, 76, 3, 63, 6, 41, 4, 26, 0, 58, 5, 43, 7,  9, 
    6,  3, 7, 44, 3,  2, 8, 27, 0, 22, 1, 61, 5, 86, 2, 94, 4, 86, 
    7, 67, 5,  9, 4, 39, 6, 55, 2, 86, 3, 63, 8, 99, 1, 71, 0, 17
  };
  const int q3342[] = {
    9, 9, // Number of jobs and machines
    2, 74, 4, 63, 7, 23, 3, 37, 0, 37, 5, 78, 6,  9, 1, 21, 8, 15, 
    6, 48, 8, 82, 1, 97, 4, 89, 0, 43, 3, 32, 7, 57, 2, 11, 5, 92, 
    5, 91, 7, 43, 6, 15, 2, 43, 8, 94, 0,  6, 4, 89, 1, 96, 3, 38, 
    7, 50, 8, 35, 2, 99, 4, 87, 1, 85, 5, 51, 0, 55, 3, 66, 6, 83, 
    6, 66, 3, 55, 8, 75, 2, 85, 1, 99, 0, 11, 4, 96, 5,  9, 7,  9, 
    3, 85, 5, 72, 6, 53, 8, 35, 4, 68, 7, 21, 0, 46, 2, 44, 1, 75, 
    8, 16, 6, 46, 2, 70, 4, 81, 1, 69, 0, 14, 3,  6, 7, 27, 5, 54, 
    0, 35, 5, 44, 4, 19, 1, 25, 6, 71, 2, 38, 8, 25, 7, 24, 3, 96, 
    8, 95, 2, 47, 6, 51, 1, 88, 0, 87, 3, 95, 5, 84, 7, 69, 4, 44
  };
  const int q3343[] = {
    9, 9, // Number of jobs and machines
    0,  4, 5, 25, 3, 66, 4, 27, 2, 19, 6, 27, 8, 28, 7, 28, 1, 85, 
    3, 45, 4, 72, 8, 59, 2, 41, 6, 93, 1, 76, 0, 77, 5, 95, 7, 29, 
    1,  6, 4, 98, 3, 32, 0, 66, 2, 28, 6, 35, 8, 38, 7, 79, 5,  8, 
    0, 50, 5, 34, 2, 96, 4, 73, 1, 60, 6, 23, 8, 11, 3, 62, 7, 59, 
    6, 75, 8, 58, 2, 17, 3, 12, 7, 21, 5, 96, 4, 43, 0,  4, 1, 39, 
    0, 68, 1, 89, 8,  7, 4, 42, 2, 68, 7, 47, 6, 32, 3, 77, 5, 24, 
    1, 59, 5, 94, 0, 18, 4, 85, 6, 19, 2, 37, 8, 75, 7, 98, 3, 59, 
    2, 90, 5, 67, 8, 55, 1, 46, 7, 24, 6,  1, 3, 70, 4, 75, 0, 79, 
    7, 95, 5, 43, 4, 29, 2, 98, 8, 62, 6, 38, 0, 82, 1, 62, 3, 95
  };
  const int q3344[] = {
    9, 9, // Number of jobs and machines
    4, 81, 8, 27, 0, 16, 5, 80, 2, 10, 7, 51, 6, 55, 1, 85, 3, 21, 
    3, 75, 7, 60, 1, 46, 4, 10, 6, 60, 8, 55, 2, 83, 0, 16, 5, 30, 
    6, 23, 2, 31, 5, 85, 3, 78, 4, 17, 1, 88, 0, 82, 8, 23, 7, 28, 
    2, 46, 8,  9, 5, 55, 1, 84, 4, 21, 3, 54, 7, 98, 0, 73, 6, 14, 
    1, 92, 3, 53, 7, 39, 5, 71, 4, 92, 2, 10, 8, 12, 0, 44, 6, 19, 
    4, 96, 7, 39, 3, 36, 0, 96, 2, 34, 6, 46, 1, 84, 8, 60, 5, 24, 
    0, 44, 8, 40, 7, 65, 2, 26, 6, 59, 1, 12, 3, 82, 5,  7, 4, 77, 
    2, 24, 8, 65, 3, 61, 7, 46, 5, 59, 0, 97, 4, 34, 1, 27, 6, 90, 
    1, 52, 7, 68, 6,  3, 0, 55, 3, 48, 5, 53, 8, 72, 4, 58, 2, 41
  };
  const int q3345[] = {
    9, 9, // Number of jobs and machines
    4, 74, 0,  9, 6,  8, 7, 17, 2,  2, 3, 23, 8, 84, 1, 89, 5, 70, 
    3, 77, 4, 39, 1, 42, 8, 62, 5, 25, 6, 44, 7, 85, 0, 11, 2, 43, 
    2, 26, 4, 49, 0, 31, 6, 89, 8, 79, 7, 95, 5, 73, 1, 63, 3, 12, 
    2, 87, 7, 31, 8, 57, 1,  2, 5, 66, 3, 65, 0, 55, 6, 39, 4, 87, 
    5, 26, 0, 57, 7,  7, 1, 89, 2, 13, 8, 50, 4, 88, 3, 46, 6, 34, 
    4, 22, 0, 96, 3, 74, 1, 12, 7, 78, 2, 19, 8, 65, 5, 35, 6, 24, 
    6,  9, 8, 25, 5, 27, 2, 83, 3, 26, 7, 19, 0, 27, 1, 21, 4, 65, 
    1, 49, 2, 28, 3, 97, 6, 74, 4, 61, 7, 94, 5, 40, 0, 53, 8, 15, 
    0,  6, 8, 17, 7, 62, 3, 92, 4,  3, 6, 90, 2, 69, 1, 43, 5, 48
  };
  const int q3346[] = {
    9, 9, // Number of jobs and machines
    2, 23, 7, 33, 5, 41, 3, 32, 0,  4, 1, 75, 6, 81, 4, 64, 8, 27, 
    2, 57, 3, 78, 8, 78, 1, 18, 4, 74, 6, 79, 7, 71, 0, 70, 5, 89, 
    6, 46, 1, 36, 7, 45, 8, 65, 0, 74, 4, 93, 2, 26, 3, 12, 5, 26, 
    3, 69, 6, 53, 0, 69, 5, 91, 4, 53, 1,  9, 2,  5, 8, 91, 7, 26, 
    3, 73, 1, 58, 4,  7, 5, 47, 2, 58, 0, 37, 6, 77, 7, 64, 8, 22, 
    3,  1, 1, 86, 6, 40, 5, 79, 4, 47, 7, 15, 0,  6, 2, 87, 8, 50, 
    5, 78, 7, 64, 3, 61, 4, 36, 1, 48, 2, 49, 8, 44, 6, 56, 0,  9, 
    1, 46, 2, 19, 6, 74, 5, 81, 0, 37, 8, 90, 7, 88, 4, 95, 3, 23, 
    0, 49, 7, 54, 3, 45, 4, 16, 6, 95, 8, 86, 2, 35, 5, 38, 1, 14
  };
  const int q3347[] = {
    9, 9, // Number of jobs and machines
    8, 60, 2, 37, 6, 18, 0, 58, 4,  1, 7, 75, 1, 11, 3, 99, 5,  3, 
    3,  8, 0, 83, 1, 79, 5, 80, 2, 26, 6, 45, 8, 60, 4, 37, 7, 42, 
    4, 43, 7,  7, 6, 62, 1, 95, 8, 22, 3, 94, 5, 23, 2, 53, 0, 44, 
    8, 23, 6, 86, 2, 88, 3, 89, 7, 89, 0, 47, 5, 38, 1, 86, 4, 96, 
    6, 95, 5, 31, 4, 54, 0, 85, 1, 95, 8, 88, 3, 76, 2, 72, 7, 97, 
    3,  9, 2, 34, 8, 34, 6, 57, 0, 19, 7, 47, 4, 71, 1, 81, 5,  1, 
    3, 66, 1,  9, 7, 98, 6, 54, 5, 89, 4, 66, 2,  9, 0, 55, 8, 25, 
    1, 64, 2, 33, 3, 44, 5, 28, 7, 53, 8, 81, 4,  2, 0, 74, 6, 93, 
    6, 76, 8, 38, 7, 28, 5, 74, 2, 10, 3, 25, 4, 43, 1,  5, 0, 74
  };
  const int q3348[] = {
    9, 9, // Number of jobs and machines
    5, 73, 8, 65, 7,  9, 2, 83, 0, 79, 6, 42, 3, 88, 4, 82, 1, 73, 
    5, 18, 6, 61, 8, 65, 0,  7, 7, 81, 2, 56, 3, 97, 4, 82, 1, 27, 
    2, 71, 8, 48, 5, 24, 4, 58, 3, 32, 1, 11, 6, 26, 0, 18, 7,  6, 
    6, 12, 1, 70, 5, 31, 8, 68, 0, 17, 4, 75, 2, 72, 7, 18, 3, 95, 
    5, 80, 8, 88, 7, 86, 1, 83, 6, 62, 4,  7, 2, 76, 0, 36, 3, 72, 
    1, 43, 4, 66, 7, 41, 8, 62, 5, 61, 0, 33, 2, 95, 3, 54, 6, 78, 
    8, 43, 5, 32, 7, 17, 6, 70, 4, 42, 2, 31, 0, 29, 1, 66, 3, 65, 
    3, 54, 6, 98, 5, 14, 0,  9, 1, 46, 4, 99, 2, 91, 7, 22, 8, 15, 
    8, 37, 5,  6, 4, 83, 2, 85, 3, 21, 1, 93, 7, 90, 6, 69, 0, 75
  };
  const int q3349[] = {
    9, 9, // Number of jobs and machines
    5, 82, 2,  5, 0, 11, 8, 31, 4, 66, 1, 25, 6, 10, 3, 36, 7, 42, 
    2, 51, 8, 15, 0, 46, 1, 60, 6, 31, 5, 55, 7, 62, 4, 31, 3, 61, 
    6, 34, 8, 74, 3, 98, 4,  4, 1, 89, 7, 27, 5, 76, 0,  3, 2,  4, 
    0, 13, 6, 47, 4,  9, 7, 19, 8, 62, 3, 37, 5, 50, 2, 47, 1, 79, 
    6, 90, 1, 52, 0, 89, 2, 32, 8, 42, 3, 97, 7, 57, 4, 84, 5,  9, 
    5, 21, 4, 85, 1, 75, 7, 74, 3, 46, 8, 31, 0, 50, 6, 99, 2, 98, 
    7, 25, 5, 82, 8, 83, 2,  2, 3, 18, 1, 11, 4, 26, 6, 57, 0,  5, 
    7, 96, 3, 70, 8,  1, 6, 61, 2, 74, 5, 65, 0, 29, 4, 92, 1, 22, 
    7, 88, 8, 89, 6,  1, 3,  2, 1, 48, 5, 47, 2, 67, 4, 29, 0, 46
  };
  const int q3350[] = {
    9, 9, // Number of jobs and machines
    4, 52, 6, 11, 0, 97, 3, 41, 1, 90, 2, 51, 8, 22, 7, 82, 5, 19, 
    5, 38, 6, 54, 1, 85, 4, 41, 0, 26, 7, 61, 8, 38, 3,  4, 2, 60, 
    8,  4, 7, 95, 2, 44, 0, 50, 6, 59, 1, 23, 3, 11, 5, 28, 4, 63, 
    2, 15, 0, 20, 8, 19, 1,  1, 5, 45, 7, 29, 6, 15, 3, 31, 4, 87, 
    4, 73, 8, 69, 2, 28, 7,  4, 6, 97, 1, 17, 5, 21, 3, 99, 0, 82, 
    8, 47, 5, 98, 0,  6, 3, 71, 2, 87, 6, 89, 4, 61, 1, 98, 7, 14, 
    6, 54, 3, 99, 1, 82, 5, 54, 0, 34, 8, 14, 4, 22, 7, 55, 2, 55, 
    3, 47, 5, 50, 8, 20, 6, 14, 7, 61, 0, 15, 2, 43, 1, 43, 4, 77, 
    8, 10, 1, 96, 0,  8, 2, 74, 7, 73, 3, 98, 5, 51, 4, 29, 6, 35
  };
  const int q3351[] = {
    9, 9, // Number of jobs and machines
    1, 40, 5, 21, 2, 21, 8, 39, 0, 56, 6, 50, 7, 34, 4, 78, 3, 71, 
    1, 65, 2, 13, 6, 90, 7, 34, 3, 41, 0, 42, 5, 24, 4,  8, 8, 71, 
    0, 12, 4, 46, 8,  1, 7, 62, 5, 20, 3, 77, 6, 66, 1, 85, 2, 51, 
    5, 11, 2, 53, 6, 42, 0, 26, 8, 33, 3, 92, 1, 34, 4, 66, 7, 64, 
    4, 99, 8, 65, 7, 16, 0,  1, 2, 54, 6,  3, 3, 88, 5, 80, 1, 14, 
    6, 15, 8, 45, 1, 14, 7, 68, 2, 18, 4, 51, 0, 18, 5, 21, 3, 54, 
    8, 17, 6,  5, 7, 56, 1, 64, 4, 75, 5, 44, 3,  7, 0, 49, 2, 20, 
    6, 68, 1, 75, 4, 84, 2, 30, 3, 79, 7, 69, 0, 29, 5,  4, 8, 38, 
    1, 87, 5, 77, 3, 54, 2, 53, 7, 15, 4, 58, 0, 74, 8, 88, 6, 26
  };
  const int q3352[] = {
    9, 9, // Number of jobs and machines
    1, 35, 7, 23, 5, 14, 6, 81, 0,  5, 8, 83, 2, 77, 4, 44, 3, 46, 
    2, 32, 8, 40, 3, 79, 6, 12, 5, 93, 4, 60, 0, 35, 1, 21, 7, 72, 
    1, 37, 8,  1, 7, 97, 4, 49, 6, 19, 0, 45, 3, 10, 5, 69, 2, 75, 
    7, 77, 8,  7, 5, 55, 0, 84, 1, 55, 6, 69, 3, 73, 2, 82, 4, 64, 
    4, 39, 6, 12, 2, 95, 7, 35, 1, 12, 8, 94, 5, 63, 3, 97, 0, 23, 
    7, 21, 5, 15, 1, 71, 3, 19, 2, 80, 4, 39, 0, 73, 8,  5, 6, 14, 
    0, 73, 4, 75, 6, 71, 1, 27, 5, 62, 3, 89, 2, 27, 8, 55, 7, 33, 
    4, 49, 5, 70, 3,  6, 0, 92, 2, 11, 7, 36, 1, 74, 8, 11, 6, 64, 
    6, 26, 1, 59, 2, 51, 3, 47, 0, 45, 7, 45, 5, 19, 8, 92, 4, 48
  };
  const int q3353[] = {
    9, 9, // Number of jobs and machines
    8, 84, 5, 53, 6, 94, 4, 96, 1, 89, 2, 56, 0, 27, 7, 14, 3, 53, 
    2, 65, 3, 20, 1, 97, 6, 38, 0, 83, 7, 55, 8,  6, 5, 21, 4, 11, 
    7, 12, 3,  6, 4, 59, 5, 53, 2, 73, 0, 45, 8, 87, 1, 27, 6,  3, 
    1, 62, 8, 40, 0, 13, 5,  6, 7, 70, 2, 57, 6, 26, 3, 96, 4, 58, 
    1, 97, 3, 94, 2, 80, 4, 87, 8, 43, 7, 39, 5, 15, 0, 35, 6, 81, 
    3, 15, 4, 66, 2, 48, 0, 30, 8, 95, 5, 83, 1, 94, 6, 65, 7, 90, 
    0, 51, 4, 55, 8, 49, 2,  5, 1, 67, 3, 46, 6, 94, 5, 78, 7, 53, 
    1, 39, 8, 74, 5, 63, 7, 49, 3, 41, 2, 33, 0, 68, 4, 25, 6, 44, 
    3, 59, 2, 87, 5, 13, 6, 40, 1, 69, 8, 36, 4, 73, 0, 87, 7, 95
  };
  const int q3354[] = {
    9, 9, // Number of jobs and machines
    4, 95, 5, 73, 8, 71, 3, 44, 2, 59, 1, 15, 6, 82, 0, 39, 7, 10, 
    5, 58, 2, 13, 0, 10, 4, 17, 3, 74, 7,  9, 6, 15, 8,  6, 1, 62, 
    4, 47, 0, 16, 6, 65, 1, 55, 7, 44, 5, 51, 3, 30, 2, 54, 8, 88, 
    0, 24, 3,  3, 8, 75, 7, 68, 2, 31, 4, 64, 5, 84, 1,  9, 6, 82, 
    2, 30, 8,  1, 4, 27, 1, 19, 5, 17, 6, 67, 0, 35, 7, 95, 3, 64, 
    2,  2, 5, 83, 1, 57, 4, 77, 6, 97, 0, 98, 7, 95, 3, 37, 8, 47, 
    8, 65, 2, 16, 1,  8, 6, 30, 0,  5, 4, 27, 3, 33, 5, 81, 7, 32, 
    8, 21, 7, 29, 4, 94, 6, 40, 2, 57, 3, 59, 1, 42, 5, 57, 0, 14, 
    2, 43, 4,  8, 1, 20, 0,  9, 8, 72, 5, 18, 6,  9, 7, 25, 3, 11
  };
  const int q3355[] = {
    9, 9, // Number of jobs and machines
    1,  3, 2,  4, 3, 38, 4, 16, 0, 57, 5, 75, 8, 24, 7, 21, 6, 62, 
    5, 69, 8, 42, 6, 71, 1, 92, 2, 68, 3, 86, 7, 58, 0,  7, 4, 22, 
    4,  6, 2, 76, 1, 28, 3, 49, 0, 11, 8, 94, 5, 67, 6, 87, 7, 33, 
    3, 65, 6, 38, 4, 70, 1, 75, 2, 68, 0, 45, 7, 40, 8, 72, 5,  6, 
    5, 22, 7, 38, 1, 71, 0, 53, 4, 42, 3, 78, 2, 94, 8, 24, 6, 60, 
    4, 43, 6,  2, 2, 29, 8, 18, 7, 42, 0,  5, 1, 99, 5, 92, 3, 29, 
    4, 89, 3, 88, 8, 35, 6, 70, 1, 89, 2, 77, 5, 88, 7, 72, 0, 52, 
    5, 94, 4, 30, 2, 72, 7, 24, 1, 89, 3, 37, 8, 39, 0,  6, 6, 18, 
    7, 27, 3, 47, 1, 95, 2, 87, 6, 30, 5, 24, 4, 76, 0,  4, 8, 50
  };
  const int q3356[] = {
    9, 9, // Number of jobs and machines
    7, 60, 4, 90, 3, 54, 2, 31, 8, 80, 6, 76, 0, 41, 5,  4, 1, 88, 
    7, 97, 5, 64, 8, 53, 2, 16, 6,  7, 0, 79, 1, 72, 3, 52, 4, 16, 
    3, 98, 7,  3, 5, 19, 0, 24, 2, 39, 4, 45, 6, 43, 8, 60, 1, 69, 
    7, 29, 8, 78, 0, 91, 3, 39, 6, 95, 2, 43, 1, 20, 4, 63, 5, 31, 
    5, 13, 8, 71, 2, 17, 4, 77, 0, 86, 7, 25, 1, 30, 3, 16, 6, 77, 
    7, 35, 0, 29, 1, 93, 3, 95, 6, 89, 8, 99, 5, 91, 4, 61, 2,  7, 
    1, 42, 7, 97, 6, 36, 0, 33, 3, 65, 8, 46, 2, 36, 5, 32, 4, 94, 
    7, 26, 1, 26, 4, 39, 0, 82, 2, 13, 5, 36, 3, 24, 6, 47, 8,  5, 
    4, 57, 0,  1, 3, 72, 5, 15, 7, 87, 2, 25, 6, 59, 8,  3, 1, 77
  };
  const int q3357[] = {
    9, 9, // Number of jobs and machines
    3, 76, 6,  7, 4, 77, 8, 40, 2, 69, 0, 96, 5, 76, 7, 62, 1, 23, 
    0, 64, 6, 44, 5, 54, 8, 90, 2, 27, 1, 25, 7, 71, 3,  3, 4, 91, 
    0, 56, 7, 59, 2, 11, 6, 48, 8, 74, 3, 93, 4, 30, 1, 90, 5, 21, 
    2, 16, 8, 35, 3,  3, 4, 97, 6, 65, 7, 64, 5, 59, 1, 27, 0,  9, 
    4, 54, 3, 68, 1, 62, 6, 29, 7, 42, 8, 76, 5, 42, 0,  1, 2, 88, 
    4, 24, 5, 55, 6,  1, 8, 41, 3, 53, 1, 90, 0, 12, 7, 10, 2, 90, 
    5, 91, 7, 41, 6, 15, 3, 89, 8, 72, 1, 93, 2, 64, 4, 95, 0, 19, 
    0, 10, 3, 94, 8, 26, 2, 38, 7, 49, 4, 66, 5, 85, 1, 68, 6, 19, 
    8, 65, 6, 55, 4, 98, 5, 96, 7, 15, 1, 24, 0, 56, 3, 48, 2, 45
  };
  const int q3358[] = {
    9, 9, // Number of jobs and machines
    5, 25, 2, 81, 6, 65, 8, 54, 0, 22, 4, 64, 3,  9, 1, 58, 7, 26, 
    8, 44, 2, 98, 6, 64, 5, 48, 4, 94, 0, 55, 7, 48, 1,  2, 3, 24, 
    0, 23, 3, 68, 8,  1, 7, 43, 1, 61, 5, 45, 2,  2, 6, 57, 4, 29, 
    6, 98, 0, 29, 2, 11, 3, 54, 5, 74, 7, 11, 1, 68, 8,  1, 4, 61, 
    7, 99, 6, 14, 4, 23, 1, 74, 0, 35, 2, 93, 8, 43, 3, 96, 5, 91, 
    4,  4, 0, 94, 2, 92, 6, 60, 7, 32, 8, 25, 5, 57, 3, 22, 1, 91, 
    2,  2, 7, 63, 4, 25, 0, 58, 8, 72, 6, 57, 3, 74, 5, 52, 1, 94, 
    4, 90, 7, 81, 6, 17, 1, 73, 2, 66, 5, 18, 0, 69, 3, 36, 8, 32, 
    1, 72, 8, 83, 2, 37, 6, 38, 4, 19, 5, 13, 0, 93, 3,  7, 7, 35
  };
  const int q3359[] = {
    9, 9, // Number of jobs and machines
    3, 95, 7, 63, 4, 97, 6, 79, 0, 43, 1, 50, 8, 46, 5, 65, 2, 96, 
    4,  6, 2, 45, 5, 84, 1, 66, 0,  2, 8, 19, 3, 68, 7, 23, 6, 75, 
    7, 66, 0, 79, 2, 79, 5, 35, 1, 60, 3, 86, 8, 42, 4, 80, 6, 35, 
    4, 76, 8, 36, 6, 71, 2, 67, 7, 22, 3, 64, 1, 78, 0, 58, 5,  9, 
    8, 59, 2, 82, 7, 26, 6, 88, 3, 91, 1, 75, 5, 48, 4, 85, 0, 23, 
    6, 73, 4, 23, 7, 37, 2,  8, 0, 48, 8, 93, 5, 35, 1, 62, 3, 64, 
    4, 60, 8, 27, 3, 88, 2, 24, 1, 24, 6, 20, 5, 12, 7, 99, 0, 72, 
    4, 79, 7, 64, 1, 39, 2, 97, 6, 95, 8, 34, 3, 61, 0, 19, 5, 95, 
    6, 33, 4, 18, 5, 24, 7,  2, 3, 26, 1, 10, 2, 77, 0, 93, 8, 77
  };
  const int q3360[] = {
    9, 9, // Number of jobs and machines
    2, 27, 4, 13, 8, 17, 6, 32, 7, 59, 0, 88, 3, 87, 5, 30, 1, 33, 
    0, 31, 2, 88, 4, 47, 6, 24, 3, 31, 1, 46, 8, 48, 5, 96, 7, 77, 
    0,  7, 4, 21, 7, 13, 3, 18, 8, 44, 1, 86, 2, 72, 5, 85, 6, 83, 
    3, 28, 6, 24, 7, 33, 8, 42, 0,  1, 4, 74, 1, 14, 5, 91, 2, 25, 
    4, 33, 5, 11, 0, 28, 8, 30, 3, 48, 6, 73, 7, 39, 1, 18, 2,  8, 
    4, 54, 7, 46, 3, 41, 6, 59, 5, 62, 0, 55, 8, 36, 1, 49, 2, 50, 
    1, 85, 6, 94, 4, 46, 3, 54, 7, 26, 2, 23, 8, 93, 5, 10, 0,  2, 
    7, 32, 6, 62, 5, 32, 8, 65, 0, 73, 1, 14, 4, 90, 3, 80, 2, 54, 
    5, 96, 7, 51, 0, 10, 3, 22, 1, 81, 8, 23, 6, 47, 2, 85, 4, 69
  };
  const int q3361[] = {
    9, 9, // Number of jobs and machines
    6, 70, 1, 64, 0, 21, 2, 37, 4, 83, 7, 75, 8, 84, 3, 62, 5, 23, 
    6, 91, 3, 38, 0, 93, 8, 79, 2, 39, 4, 16, 7, 74, 1,  4, 5, 31, 
    3, 90, 8, 27, 5, 20, 4, 72, 1, 68, 2, 78, 7, 39, 6, 99, 0, 85, 
    0,  8, 2, 50, 4, 36, 7, 57, 6, 95, 5, 68, 3, 50, 8, 60, 1, 62, 
    5, 23, 8, 36, 1, 68, 3, 53, 0, 78, 6, 75, 4,  6, 7, 93, 2, 53, 
    4, 26, 7, 35, 3, 16, 6,  2, 5, 63, 2, 76, 8, 12, 0, 85, 1, 88, 
    5, 20, 3, 47, 1, 59, 0, 77, 7, 81, 6, 58, 2, 68, 8, 90, 4, 87, 
    3,  8, 1, 47, 6,  6, 5, 79, 2, 36, 8, 86, 7, 48, 4, 33, 0, 77, 
    8, 66, 6, 21, 4, 12, 7, 76, 5, 99, 0, 59, 2, 90, 1, 32, 3,  5
  };
  const int q3362[] = {
    9, 9, // Number of jobs and machines
    2, 58, 8,  4, 6, 78, 3, 13, 4, 97, 5, 82, 7, 61, 0, 74, 1, 59, 
    0, 11, 5, 20, 4, 40, 8, 84, 6, 34, 1, 13, 2, 90, 7, 81, 3, 86, 
    6, 65, 3, 78, 2,  5, 4, 24, 1,  2, 7, 74, 0, 23, 5, 90, 8, 83, 
    5, 70, 3, 98, 1, 36, 7, 41, 6,  4, 8, 11, 4, 50, 0,  5, 2, 20, 
    0, 10, 1,  5, 5, 55, 6, 52, 4, 80, 2, 53, 8, 72, 3, 77, 7, 31, 
    7, 27, 3, 83, 0, 66, 1, 29, 6, 33, 2, 71, 8, 38, 5, 37, 4, 81, 
    4, 99, 5, 91, 6,  4, 2,  6, 8, 21, 3, 75, 1, 17, 0, 94, 7, 43, 
    8, 47, 5, 32, 2, 17, 7, 87, 3, 99, 6, 50, 1,  9, 4, 35, 0, 47, 
    6, 96, 7, 48, 3, 63, 0, 22, 4, 25, 5, 87, 2, 83, 1, 88, 8, 12
  };
  const int q3363[] = {
    9, 9, // Number of jobs and machines
    3, 70, 8, 76, 7,  1, 5, 99, 4, 60, 0, 85, 2, 38, 6, 75, 1, 80, 
    7, 65, 2, 41, 3, 83, 8,  4, 4, 89, 1, 46, 5, 34, 6, 36, 0, 94, 
    8, 45, 0, 18, 3, 27, 1, 94, 6, 83, 7, 87, 2, 82, 5, 68, 4, 18, 
    5, 92, 1,  9, 7, 29, 8, 12, 4, 45, 0, 42, 3, 24, 6, 18, 2, 93, 
    6, 70, 1, 99, 3, 12, 0, 73, 8, 61, 2, 73, 5, 16, 4, 68, 7,  3, 
    8, 63, 5, 66, 4, 55, 0, 49, 1, 22, 6, 93, 7, 72, 2, 36, 3, 72, 
    4, 77, 3, 39, 8, 25, 6, 43, 1, 66, 2, 13, 0, 24, 5, 78, 7, 93, 
    2, 88, 0, 97, 3, 30, 5, 49, 4, 83, 7, 56, 8, 58, 6, 36, 1, 25, 
    4, 89, 1, 41, 6, 39, 2, 71, 5, 95, 7, 27, 0, 23, 3, 13, 8, 39
  };
  const int q3364[] = {
    9, 9, // Number of jobs and machines
    6, 12, 0, 61, 3, 13, 4, 21, 7, 26, 2, 80, 5, 87, 1,  1, 8, 52, 
    1, 18, 5, 14, 0, 13, 6, 47, 3, 35, 8, 75, 2, 30, 4, 80, 7,  6, 
    0,  3, 8, 47, 6, 44, 5, 25, 3, 82, 4, 86, 7, 47, 2, 80, 1, 66, 
    5, 61, 4, 77, 6, 31, 1,  1, 2, 78, 8, 66, 7, 13, 3, 39, 0, 25, 
    5, 84, 2, 88, 3,  7, 7,  5, 4, 57, 6, 96, 1, 53, 0, 29, 8, 83, 
    2, 51, 7, 92, 5,  9, 0, 43, 3, 61, 6, 66, 1, 22, 4, 44, 8, 55, 
    0, 85, 6, 25, 5, 66, 7, 60, 2, 80, 8, 49, 3, 57, 4, 89, 1,  6, 
    2,  6, 1, 28, 7,  3, 3, 35, 8, 60, 6, 45, 0, 41, 4, 89, 5, 16, 
    6, 94, 3, 99, 8, 67, 2,  7, 0, 55, 5, 43, 4, 98, 1, 46, 7, 22
  };
  const int q3365[] = {
    9, 9, // Number of jobs and machines
    1, 94, 3, 23, 8, 98, 5, 35, 4, 31, 0, 92, 6, 92, 2, 22, 7, 55, 
    8, 13, 2, 81, 7, 72, 5, 55, 1, 37, 0, 81, 6, 17, 4, 12, 3, 68, 
    4, 76, 1, 79, 6,  8, 7, 55, 5, 70, 3, 54, 2, 59, 8, 41, 0, 65, 
    1, 36, 3, 46, 6, 40, 5, 63, 0, 17, 7, 84, 8, 47, 4, 66, 2, 34, 
    8, 30, 2, 43, 7, 37, 5, 89, 6, 62, 4, 29, 0, 23, 1, 66, 3,  3, 
    0, 75, 5, 76, 3, 40, 1, 25, 8, 17, 6,  9, 2, 73, 7, 62, 4, 62, 
    6, 86, 2, 47, 5, 23, 1, 29, 8, 46, 4, 20, 0, 54, 7, 48, 3, 46, 
    4, 83, 7, 26, 8, 41, 0, 12, 2, 76, 6, 89, 1, 45, 5, 40, 3,  4, 
    1, 34, 2, 93, 7,  2, 6, 63, 8, 57, 4, 13, 0,  2, 5, 75, 3, 46
  };
  const int q3366[] = {
    9, 9, // Number of jobs and machines
    5, 39, 6, 87, 4, 59, 8, 58, 2, 51, 0, 12, 7, 97, 1,  2, 3,  3, 
    7, 31, 2, 97, 5, 22, 3, 82, 4, 46, 0, 27, 1, 56, 6, 61, 8, 94, 
    4, 66, 1, 27, 3, 31, 2, 63, 5, 60, 6, 49, 0, 84, 7, 28, 8, 52, 
    0, 41, 8, 83, 4, 41, 5, 31, 6, 90, 3, 56, 2, 99, 7, 32, 1, 91, 
    7, 63, 1, 35, 2, 95, 6, 77, 8, 41, 4, 89, 3, 26, 5, 37, 0, 24, 
    1, 75, 2, 79, 6, 13, 7, 98, 3, 86, 4,  5, 8, 16, 0, 49, 5,  4, 
    5, 12, 0, 16, 8, 13, 6, 74, 3,  2, 2, 98, 1, 88, 4, 52, 7, 18, 
    8, 14, 3, 36, 7, 41, 1, 45, 2, 92, 6, 83, 0, 38, 4, 49, 5, 37, 
    5, 69, 0, 44, 6, 76, 4, 76, 8, 42, 3, 38, 7, 57, 1,  8, 2, 39
  };
  const int q3367[] = {
    9, 9, // Number of jobs and machines
    8, 12, 7, 83, 1, 70, 0, 30, 2, 49, 6, 77, 4, 10, 5, 14, 3, 76, 
    4, 25, 8, 58, 5, 98, 1, 22, 3,  2, 6, 23, 2, 90, 0, 87, 7,  7, 
    4, 68, 1, 48, 8, 68, 7, 24, 6, 96, 2, 23, 5, 28, 3, 43, 0, 34, 
    8, 97, 3, 11, 4, 18, 6, 64, 1, 39, 2, 28, 5, 73, 7, 57, 0, 61, 
    6, 53, 5, 62, 7, 26, 0, 97, 1, 47, 4,  9, 2,  7, 8, 95, 3, 23, 
    1, 89, 5, 11, 8, 57, 7, 88, 2, 24, 3, 95, 6,  2, 0, 38, 4, 99, 
    6, 78, 4, 51, 0, 63, 1, 86, 3, 48, 7, 72, 5, 91, 8, 61, 2, 50, 
    0,  7, 4, 75, 6, 91, 8, 29, 5, 55, 7, 70, 1, 73, 2, 74, 3,  1, 
    7, 27, 1, 46, 8, 61, 4, 28, 3, 52, 5,  5, 2, 58, 0, 24, 6, 42
  };
  const int q3368[] = {
    9, 9, // Number of jobs and machines
    7, 87, 1, 29, 3, 46, 4, 10, 5, 53, 0, 90, 2, 39, 6, 75, 8, 28, 
    1, 72, 7, 98, 8, 18, 3, 70, 5, 68, 6, 66, 4, 66, 2, 14, 0, 46, 
    6, 55, 8, 51, 1, 89, 2, 93, 7, 98, 0,  5, 5,  8, 4,  1, 3, 18, 
    7, 23, 2, 26, 4, 74, 3, 98, 8, 13, 6, 10, 1, 31, 5, 99, 0,  6, 
    3, 71, 1, 46, 2,  1, 0, 54, 8, 39, 4, 21, 7, 54, 5, 63, 6, 92, 
    2, 18, 8,  9, 7, 97, 1, 12, 6, 61, 0, 50, 3, 36, 5, 20, 4, 27, 
    0, 59, 6, 99, 4, 66, 2, 98, 3, 34, 1, 31, 7, 26, 5,  5, 8, 91, 
    0, 71, 8,  2, 1, 91, 3, 34, 2, 72, 5, 98, 7, 40, 6, 69, 4, 89, 
    4, 33, 7, 10, 8, 34, 0, 79, 5,  5, 2, 98, 3,  5, 6, 68, 1, 34
  };
  const int q3369[] = {
    9, 9, // Number of jobs and machines
    6, 99, 5, 60, 2, 13, 3, 77, 0, 30, 8, 45, 7, 24, 1, 81, 4, 82, 
    0, 52, 4, 32, 3, 42, 7, 33, 2, 64, 8, 85, 5, 99, 6, 55, 1, 27, 
    4, 17, 3, 86, 8, 49, 1, 34, 5, 75, 6, 84, 0, 76, 2, 27, 7, 91, 
    3, 85, 5, 95, 4, 90, 6, 27, 1, 18, 2, 57, 7, 85, 0, 24, 8, 22, 
    7, 76, 4, 86, 0, 95, 2, 38, 8, 46, 5, 60, 3, 30, 6, 62, 1, 83, 
    8, 90, 3, 54, 2, 48, 1, 36, 4, 67, 6, 45, 7, 98, 5, 23, 0, 54, 
    4, 38, 6, 47, 3, 70, 1, 96, 2, 87, 8, 46, 5, 87, 7, 38, 0,  3, 
    2, 90, 6, 70, 7, 62, 3, 19, 8, 55, 0, 37, 1, 98, 4, 28, 5, 97, 
    8, 43, 3,  6, 2, 55, 5, 97, 0, 33, 1, 93, 6, 32, 7, 77, 4, 62
  };
  const int q3370[] = {
    9, 9, // Number of jobs and machines
    7, 66, 6,  2, 5, 82, 2, 24, 4, 69, 0, 90, 3,  8, 1, 89, 8, 43, 
    6, 71, 4, 12, 5, 23, 2, 98, 0, 29, 7, 45, 3, 39, 8, 88, 1, 65, 
    5, 29, 1, 53, 3, 84, 8, 10, 7, 27, 4, 53, 6, 25, 0, 64, 2, 14, 
    7, 42, 5, 54, 6, 35, 1, 41, 4, 21, 2, 39, 0, 53, 3, 85, 8, 64, 
    8, 98, 6, 82, 3, 79, 5,  1, 0, 89, 7, 69, 1, 53, 4, 62, 2, 82, 
    1, 18, 2, 58, 3, 87, 4, 90, 0, 87, 5, 81, 8, 90, 7, 71, 6, 64, 
    5, 60, 4, 60, 2, 77, 6, 61, 1, 33, 3, 30, 7,  8, 8, 80, 0, 81, 
    2, 77, 5, 81, 4, 28, 7, 58, 6, 67, 3, 67, 1, 74, 8, 55, 0, 28, 
    7, 10, 0, 48, 1, 84, 3, 47, 8, 41, 4, 33, 6, 63, 5, 22, 2, 39
  };
  const int q3371[] = {
    9, 9, // Number of jobs and machines
    1, 72, 7, 61, 5, 95, 6, 33, 8, 83, 4, 62, 2, 16, 3, 88, 0, 14, 
    8, 61, 2, 81, 3, 97, 6, 95, 0, 49, 4, 13, 7, 29, 5, 82, 1, 67, 
    8, 72, 0, 31, 6, 68, 4, 16, 7, 23, 1, 32, 5,  8, 2, 23, 3, 39, 
    5,  3, 7, 25, 3, 44, 2, 87, 4, 84, 6, 44, 0, 46, 1, 35, 8, 94, 
    0, 51, 1, 64, 6, 96, 2, 89, 7, 72, 8,  8, 3, 47, 5, 68, 4, 74, 
    6, 36, 8, 96, 4,  7, 5, 90, 3, 50, 0, 40, 7, 66, 1, 82, 2, 55, 
    3, 87, 4, 23, 1,  1, 6, 48, 8, 83, 5, 66, 0, 14, 2, 25, 7, 54, 
    3, 18, 8, 97, 2,  6, 5, 59, 1, 79, 4, 61, 0, 62, 7, 79, 6, 71, 
    6, 67, 7, 64, 8, 54, 0, 98, 5, 75, 4,  4, 2, 47, 1, 83, 3, 89
  };
  const int q3372[] = {
    9, 9, // Number of jobs and machines
    4,  8, 8,  8, 3, 92, 0, 59, 5, 43, 2, 34, 7, 91, 1, 25, 6, 75, 
    3, 40, 0,  2, 5, 22, 4, 76, 7, 41, 6, 68, 8, 73, 2, 85, 1,  8, 
    2, 98, 4, 95, 6, 67, 3, 21, 5, 53, 7, 39, 0, 71, 8, 88, 1, 25, 
    2,  3, 7, 82, 5, 59, 6, 94, 0,  4, 4, 20, 8, 17, 1, 10, 3, 68, 
    2, 80, 6, 57, 7, 77, 1, 78, 4, 45, 3, 29, 8, 36, 0, 86, 5, 83, 
    7, 59, 0, 22, 4, 99, 3, 51, 8, 25, 1, 33, 6, 49, 5, 28, 2, 70, 
    3,  9, 4, 90, 8, 17, 7, 46, 1, 96, 2, 98, 5, 59, 6,  8, 0, 80, 
    5, 87, 6, 29, 0, 99, 7, 37, 2, 46, 3, 37, 1, 71, 4, 97, 8, 68, 
    8, 87, 2, 99, 6, 34, 1, 68, 4, 92, 0, 25, 3, 93, 7, 62, 5, 50
  };
  const int q3373[] = {
    9, 9, // Number of jobs and machines
    4, 25, 5, 29, 2, 69, 1, 80, 8, 62, 3, 50, 6, 28, 0, 59, 7,  8, 
    0,  3, 8, 58, 3, 53, 1, 78, 5, 47, 6, 64, 2, 85, 7, 92, 4, 63, 
    7, 71, 1, 62, 2, 89, 3, 92, 6, 62, 4, 25, 8, 60, 5, 55, 0, 75, 
    8,  1, 3, 42, 2, 10, 0,  6, 1,  4, 5, 58, 4, 16, 6, 29, 7, 80, 
    8,  4, 7, 40, 4, 17, 1, 20, 0, 89, 5, 49, 3, 21, 6, 43, 2, 59, 
    4, 65, 5, 30, 1, 93, 0, 65, 3, 58, 8, 72, 6, 90, 7, 24, 2, 44, 
    6,  9, 5, 87, 4, 85, 2, 93, 1, 73, 0, 56, 8, 61, 7, 92, 3, 59, 
    7, 15, 6, 32, 3, 17, 0, 55, 2, 73, 4, 15, 1, 87, 5, 70, 8, 58, 
    6, 63, 2, 86, 8, 86, 0, 32, 3, 36, 5, 33, 4, 55, 7, 10, 1, 81
  };
  const int q3374[] = {
    9, 9, // Number of jobs and machines
    0, 85, 4,  3, 7, 95, 6, 16, 1, 15, 8, 30, 2, 41, 5, 74, 3, 50, 
    6, 97, 5, 28, 4, 80, 1, 75, 2,  7, 3, 59, 7,  2, 0, 53, 8, 94, 
    5,  8, 7, 71, 2, 29, 0, 82, 1, 99, 4, 57, 3, 99, 6, 20, 8,  6, 
    7, 29, 5, 56, 4, 34, 6, 67, 8, 71, 2, 67, 0, 93, 1, 74, 3, 68, 
    5, 22, 1, 79, 2, 40, 0, 46, 4, 57, 8, 50, 6, 26, 7,  1, 3, 55, 
    3, 82, 7, 38, 5, 23, 1, 82, 2, 58, 0, 87, 6, 82, 8, 37, 4, 98, 
    5, 48, 6, 88, 7, 21, 2, 85, 1, 90, 3, 11, 0, 19, 4,  6, 8,  3, 
    7, 23, 5, 20, 3, 11, 1, 62, 8, 29, 0, 90, 6, 85, 2, 49, 4, 91, 
    5, 99, 1, 28, 2,  9, 3,  5, 7, 40, 4, 38, 6,  5, 0, 22, 8, 45
  };
  const int q3375[] = {
    9, 9, // Number of jobs and machines
    5,  5, 2, 27, 6, 11, 7, 93, 4, 88, 8, 81, 1, 77, 3, 95, 0, 66, 
    3, 49, 8, 67, 1, 48, 4, 29, 7, 63, 6, 44, 5, 59, 2, 82, 0, 85, 
    8, 70, 1, 63, 0, 40, 3, 76, 7,  3, 4, 69, 6, 34, 2, 86, 5, 37, 
    2, 58, 3,  2, 6,  3, 4, 99, 0, 66, 8, 29, 7, 84, 1, 65, 5, 37, 
    8, 79, 6, 42, 2, 15, 1, 88, 7, 53, 3, 33, 5, 81, 4, 87, 0,  9, 
    0, 20, 4, 50, 8, 92, 1, 25, 6, 59, 2, 83, 7, 50, 3, 38, 5, 83, 
    7, 60, 6, 97, 2, 27, 1, 33, 4, 61, 5, 77, 0, 63, 8, 82, 3, 30, 
    8, 67, 4, 32, 3, 57, 0, 32, 5, 27, 2, 47, 7, 59, 1, 52, 6, 64, 
    4, 29, 2, 43, 8, 99, 0, 80, 5, 61, 1, 85, 6, 82, 3, 89, 7, 30
  };
  const int q3376[] = {
    9, 9, // Number of jobs and machines
    1, 46, 2, 77, 8, 25, 3, 26, 7,  6, 6, 47, 0, 40, 4, 47, 5, 59, 
    8, 22, 5, 27, 1, 97, 0, 23, 2, 43, 3, 26, 7, 20, 6, 15, 4, 90, 
    8, 91, 6, 10, 2, 65, 4, 65, 1, 87, 7, 91, 0, 95, 3, 96, 5, 48, 
    3, 51, 7, 94, 5,  8, 2, 53, 0, 91, 1, 68, 8, 47, 4, 99, 6, 31, 
    8, 30, 6, 31, 0, 92, 5, 73, 3, 84, 7, 23, 2, 14, 1, 18, 4,  6, 
    7, 27, 6, 26, 3, 41, 2, 50, 5, 21, 1,  8, 4, 66, 0, 79, 8, 82, 
    6, 80, 4, 94, 2, 62, 1, 45, 5,  2, 3, 64, 0, 22, 8, 41, 7, 96, 
    6, 63, 8, 45, 4, 85, 7, 15, 5, 41, 2, 90, 1, 40, 3, 14, 0, 10, 
    7, 34, 2, 21, 8,  5, 6, 10, 0, 86, 4, 48, 1, 35, 5, 30, 3, 15
  };
  const int q3377[] = {
    9, 9, // Number of jobs and machines
    1, 18, 2, 27, 3, 33, 0, 29, 8,  4, 4, 73, 6, 57, 7, 93, 5, 34, 
    6, 85, 5, 23, 7, 23, 2, 37, 8, 97, 1, 33, 4, 36, 0, 84, 3, 43, 
    3, 41, 7, 39, 8, 29, 1, 94, 4,  7, 5, 20, 2, 16, 0, 50, 6, 87, 
    2, 14, 0, 60, 1, 15, 7, 65, 4, 36, 6, 77, 5, 34, 8, 74, 3, 88, 
    0, 36, 4, 68, 5, 71, 6, 34, 3, 41, 7, 69, 2, 21, 8, 42, 1, 93, 
    6, 73, 2, 15, 4,  9, 5, 79, 1, 32, 3, 51, 7, 97, 8, 96, 0, 19, 
    6, 97, 5, 66, 3, 78, 0, 84, 4, 42, 7, 50, 2, 86, 1, 25, 8, 67, 
    8, 73, 7, 13, 0, 50, 3, 87, 1, 83, 4, 21, 6, 27, 2, 43, 5, 81, 
    0, 86, 7, 74, 8, 94, 6, 42, 3, 31, 2,  5, 5, 41, 1, 10, 4, 76
  };
  const int q3378[] = {
    9, 9, // Number of jobs and machines
    7, 64, 3, 29, 8, 77, 6, 75, 5, 75, 4, 89, 2, 15, 0, 53, 1, 89, 
    2,  2, 6, 38, 4, 24, 1, 27, 0, 88, 3, 74, 5, 17, 7, 93, 8, 91, 
    3, 85, 4, 45, 8, 41, 0, 17, 7, 94, 5, 49, 1, 67, 6, 84, 2, 33, 
    0, 38, 6, 31, 8, 89, 7, 63, 5, 10, 2, 88, 4, 99, 3, 90, 1, 62, 
    3, 65, 4, 63, 0, 96, 1,  7, 6, 63, 7, 27, 2, 67, 5, 38, 8, 95, 
    8, 49, 0, 51, 3, 83, 4, 51, 5, 74, 2, 47, 6, 77, 1, 96, 7, 71, 
    0, 85, 8, 97, 6, 81, 2, 80, 1, 67, 4, 27, 7, 99, 5,  8, 3, 96, 
    3, 26, 8,  5, 7, 70, 4, 12, 2, 16, 0, 86, 5, 87, 6, 66, 1, 68, 
    6, 22, 5, 79, 0, 82, 7, 39, 1, 74, 8, 11, 2,  2, 3, 57, 4, 29
  };
  const int q3379[] = {
    9, 9, // Number of jobs and machines
    8, 57, 5, 85, 3,  1, 7, 99, 0, 90, 1, 90, 6,  9, 4, 27, 2, 45, 
    7, 83, 1, 50, 2, 11, 4, 81, 0, 14, 3, 95, 6, 82, 8, 72, 5, 57, 
    6, 25, 4,  1, 8,  5, 7, 12, 1, 47, 5, 96, 3, 71, 2,  1, 0, 99, 
    2, 16, 3, 74, 4, 85, 8, 59, 0, 69, 7, 49, 6, 91, 5, 31, 1, 87, 
    3, 13, 6, 44, 8, 10, 7,  4, 5, 54, 0, 80, 2, 11, 1, 12, 4, 17, 
    0, 83, 5, 65, 6, 89, 4, 23, 1, 62, 2, 69, 7, 93, 3, 73, 8, 72, 
    6, 36, 0, 82, 4, 60, 8, 59, 2, 54, 1, 53, 7, 94, 5, 20, 3, 34, 
    3, 15, 7, 12, 6, 59, 0, 20, 1, 20, 4, 81, 2,  7, 5,  7, 8, 47, 
    5, 23, 0, 27, 4, 19, 6, 61, 1, 53, 3, 61, 8, 38, 2, 87, 7, 19
  };
  const int q3380[] = {
    9, 9, // Number of jobs and machines
    0,  8, 6, 80, 7, 71, 4, 15, 1, 47, 5, 37, 8, 10, 3, 48, 2, 88, 
    7, 30, 0, 11, 3, 14, 6, 91, 5, 64, 1, 60, 2, 63, 4,  7, 8, 75, 
    7, 94, 6, 52, 3,  8, 0,  1, 2, 34, 1, 43, 8, 60, 4, 67, 5, 24, 
    1,  9, 5, 13, 4, 29, 8, 58, 3, 91, 2, 56, 6, 82, 0, 78, 7, 96, 
    2, 62, 7, 43, 5, 64, 8, 97, 3, 18, 1, 87, 6, 68, 4,  5, 0, 64, 
    5, 45, 2, 24, 0,  9, 6, 88, 8,  2, 7, 59, 1, 59, 4, 55, 3, 21, 
    5, 95, 7, 99, 0, 26, 2, 62, 1, 92, 3,  2, 6, 23, 8, 10, 4,  9, 
    2, 85, 4, 27, 5, 32, 0, 28, 7, 73, 6, 70, 1, 38, 8, 61, 3, 56, 
    4, 24, 5, 68, 3, 36, 1, 95, 8, 15, 0, 80, 2, 22, 7, 44, 6, 28
  };
  const int q3381[] = {
    9, 9, // Number of jobs and machines
    0, 10, 5, 95, 2, 85, 8, 54, 1, 27, 3, 39, 6, 60, 4, 49, 7, 76, 
    0, 95, 3, 30, 8, 78, 1, 68, 5, 19, 7, 51, 4, 21, 6, 46, 2, 11, 
    0, 78, 2, 31, 6, 86, 3, 92, 8, 82, 1, 26, 7, 18, 4, 51, 5, 19, 
    7, 98, 6, 36, 3, 41, 2, 62, 4, 60, 5, 11, 0, 25, 8, 47, 1, 10, 
    8,  9, 5, 80, 4, 91, 7, 14, 1,  3, 6, 56, 2, 85, 0, 90, 3, 31, 
    7, 20, 3, 18, 2,  1, 8, 15, 6, 56, 5, 27, 0, 53, 1, 45, 4, 68, 
    5, 64, 8, 56, 7, 61, 1, 34, 6, 80, 4, 44, 2, 19, 3, 32, 0, 13, 
    6, 21, 5, 59, 0, 38, 7, 68, 8, 11, 3, 56, 1, 66, 4, 98, 2, 55, 
    2, 58, 0,  6, 3, 92, 8, 77, 6, 62, 4, 81, 1, 84, 5, 10, 7, 23
  };
  const int q3382[] = {
    9, 9, // Number of jobs and machines
    6, 68, 2, 78, 0, 78, 7,  2, 1, 19, 8, 70, 4, 92, 5, 14, 3, 53, 
    5, 33, 8, 25, 3, 48, 0,  9, 7, 51, 4, 27, 6, 63, 2, 42, 1, 49, 
    5, 73, 7,  3, 2, 22, 0, 77, 6, 36, 3, 29, 1, 13, 8, 34, 4, 56, 
    5, 73, 3, 77, 8, 70, 0, 76, 1, 61, 7, 12, 6, 27, 4, 91, 2, 93, 
    4, 12, 2, 24, 6, 33, 3, 84, 5, 82, 0, 34, 7, 54, 8, 69, 1, 45, 
    5, 86, 3, 16, 8, 59, 4, 62, 6, 61, 7, 59, 2, 50, 0, 36, 1, 70, 
    8, 98, 1, 83, 5, 56, 6, 59, 7, 27, 4, 95, 0, 84, 3, 48, 2, 47, 
    4, 41, 0, 95, 5,  5, 2, 47, 8, 72, 6,  9, 1, 56, 7, 83, 3, 86, 
    3, 13, 6, 84, 7, 24, 8, 73, 0, 74, 5, 55, 4, 69, 2, 68, 1, 86
  };
  const int q3383[] = {
    9, 9, // Number of jobs and machines
    5, 57, 3, 26, 7,  9, 4, 19, 1, 36, 6, 11, 2, 59, 8, 72, 0, 80, 
    5, 54, 0,  1, 6, 19, 2, 94, 4, 33, 1, 85, 7,  9, 3, 19, 8, 42, 
    4, 17, 3, 10, 0,  6, 6, 11, 7, 29, 8, 34, 5, 25, 1, 64, 2, 30, 
    8, 11, 2, 73, 6,  9, 0, 98, 1, 62, 4, 81, 5,  5, 3, 99, 7, 65, 
    1,  2, 3, 69, 7, 93, 4,  6, 8, 42, 5, 59, 6, 70, 2, 22, 0, 20, 
    5, 77, 0,  2, 8, 61, 3, 28, 7, 83, 4,  4, 2, 16, 6, 37, 1, 62, 
    4, 53, 8, 92, 7, 91, 5, 91, 3, 32, 1, 40, 0, 80, 6, 43, 2, 67, 
    2, 35, 1, 76, 8, 11, 4, 13, 0, 28, 5, 89, 3, 11, 7, 72, 6, 75, 
    4, 49, 8, 37, 0, 88, 7, 40, 6, 73, 5, 11, 1, 63, 3, 70, 2, 61
  };
  const int q3384[] = {
    9, 9, // Number of jobs and machines
    3, 47, 4, 60, 6, 24, 8, 74, 1, 87, 2, 25, 0,  2, 5, 76, 7, 64, 
    5, 77, 8, 43, 6, 61, 0, 12, 1, 98, 2,  5, 7, 68, 4,  3, 3, 91, 
    7, 63, 8, 68, 6, 44, 0, 88, 4, 20, 1, 37, 2,  2, 3, 86, 5, 63, 
    3, 43, 8, 63, 2, 62, 0, 80, 6,  4, 5,  5, 1, 83, 4, 14, 7, 49, 
    4, 75, 6, 40, 1,  4, 2, 29, 8, 55, 3, 32, 7, 87, 0, 44, 5, 54, 
    6, 33, 4, 22, 7, 60, 8, 33, 0, 84, 3, 54, 1, 92, 2,  9, 5, 25, 
    3, 25, 2, 64, 5, 49, 0,  1, 1, 25, 6, 49, 8, 99, 7, 33, 4, 59, 
    0,  3, 8, 67, 1, 61, 4, 43, 6, 35, 5, 84, 7, 31, 2, 24, 3, 47, 
    1, 32, 2, 25, 4, 88, 8, 10, 5, 49, 7, 53, 0, 18, 3, 13, 6, 56
  };
  const int q3385[] = {
    9, 9, // Number of jobs and machines
    8,  9, 2, 70, 7, 46, 1, 50, 3, 17, 0, 79, 6, 35, 5, 41, 4, 91, 
    1, 81, 6, 61, 5, 78, 3, 93, 8, 74, 7, 65, 0, 10, 4, 84, 2, 63, 
    2, 94, 6, 53, 8, 14, 7, 53, 3, 61, 5, 75, 1, 63, 4, 96, 0, 37, 
    2, 22, 5, 55, 1, 69, 3, 40, 8, 62, 6,  6, 0, 44, 4, 10, 7, 90, 
    7, 36, 6, 91, 8, 31, 0, 79, 2, 78, 5, 41, 4, 88, 3, 62, 1, 11, 
    8, 87, 3, 79, 2,  9, 5, 83, 6, 20, 0, 80, 1, 11, 7, 99, 4, 88, 
    7, 80, 5, 45, 3, 49, 2, 15, 0, 31, 8, 57, 6, 93, 1, 47, 4, 82, 
    6, 90, 1, 95, 4, 49, 0, 88, 2, 89, 8,  5, 5, 57, 7, 31, 3, 36, 
    2, 54, 4, 65, 3, 18, 0, 41, 8,  9, 1, 92, 5, 58, 7, 16, 6, 33
  };
  const int q3386[] = {
    9, 9, // Number of jobs and machines
    8,  4, 1, 61, 7, 63, 4, 82, 0, 44, 5, 68, 3, 84, 2, 51, 6, 63, 
    6,  7, 1, 47, 7, 18, 5, 66, 0, 96, 4, 23, 8, 15, 2, 15, 3, 59, 
    7, 94, 3, 53, 6, 32, 4, 66, 5, 77, 8, 65, 1, 96, 2, 79, 0, 85, 
    5, 83, 4,  6, 1, 58, 3, 72, 2, 63, 0, 54, 7, 82, 6, 28, 8, 94, 
    0, 84, 8, 51, 5, 23, 4,  9, 2,  2, 7, 61, 6, 60, 3, 84, 1, 57, 
    2, 19, 3, 74, 1,  4, 7, 54, 6, 56, 4, 84, 8, 66, 5, 38, 0, 39, 
    4, 68, 5, 22, 3, 27, 1, 18, 0,  2, 6, 38, 2, 84, 8, 90, 7, 59, 
    0, 42, 7,  5, 8, 37, 5, 88, 3, 71, 2,  7, 4, 46, 1, 60, 6, 12, 
    5, 14, 6, 70, 7, 46, 4, 74, 2, 79, 3, 87, 1, 95, 8, 30, 0, 65
  };
  const int q3387[] = {
    9, 9, // Number of jobs and machines
    5, 62, 8, 40, 6, 39, 2,  5, 4, 27, 0, 68, 1, 50, 3, 42, 7, 87, 
    3,  5, 8, 36, 1, 79, 6, 39, 5, 58, 7, 21, 2,  3, 0, 94, 4, 17, 
    0, 39, 4, 32, 3,  3, 1, 63, 7, 87, 6, 69, 2, 14, 5, 13, 8, 76, 
    5, 36, 8, 72, 0, 29, 6, 47, 1, 43, 7, 14, 2, 73, 3,  7, 4, 80, 
    5, 19, 7, 82, 4, 30, 8, 45, 3, 38, 6, 63, 1, 85, 2, 33, 0, 79, 
    6, 40, 5, 59, 8,  9, 4, 63, 3, 95, 0, 83, 2, 12, 7, 52, 1, 24, 
    7, 72, 4, 58, 5, 65, 0, 76, 3, 78, 2,  4, 8, 20, 1, 73, 6, 57, 
    0, 39, 4, 75, 5, 14, 1, 40, 2, 30, 8, 74, 7, 65, 6, 35, 3, 43, 
    3, 52, 5, 52, 6, 60, 1, 87, 8, 51, 7, 71, 2, 29, 4, 36, 0, 61
  };
  const int q3388[] = {
    9, 9, // Number of jobs and machines
    5, 28, 4, 25, 3, 80, 7, 49, 1, 69, 0,  2, 2, 46, 8, 90, 6, 77, 
    5, 70, 6, 79, 7, 19, 8, 44, 1, 11, 0, 27, 2, 32, 3, 35, 4,  7, 
    4, 47, 3, 91, 0, 82, 8,  1, 7, 91, 1, 14, 2, 71, 6,  2, 5, 23, 
    5, 91, 7, 71, 0, 13, 6, 65, 3, 46, 1, 66, 8, 54, 4, 83, 2, 24, 
    7, 28, 6, 80, 3, 34, 2, 45, 8, 49, 0, 53, 4, 39, 1, 52, 5, 60, 
    4, 13, 1, 50, 0, 57, 3, 90, 6, 38, 2, 99, 7, 24, 5, 51, 8, 70, 
    2, 28, 5, 89, 7, 59, 8, 49, 6, 36, 4, 88, 1, 69, 0, 76, 3, 85, 
    3, 19, 0, 30, 5, 40, 8, 96, 4, 36, 6, 99, 2, 95, 7, 72, 1, 80, 
    4, 97, 5, 70, 2, 30, 6, 18, 8, 82, 1, 80, 3, 10, 0, 48, 7, 32
  };
  const int q3389[] = {
    9, 9, // Number of jobs and machines
    4, 25, 1, 14, 0, 13, 2, 68, 6, 15, 5, 53, 3, 88, 8, 97, 7, 26, 
    3, 14, 2, 53, 0, 32, 5, 86, 7, 60, 8, 80, 6, 39, 1, 25, 4, 23, 
    1, 71, 0, 16, 7, 58, 5, 28, 2, 46, 3,  3, 6, 93, 8, 64, 4, 41, 
    8, 80, 7, 47, 1, 31, 5, 72, 4, 44, 0,  5, 6,  5, 2, 80, 3,  8, 
    1, 50, 8, 56, 5, 17, 7, 37, 4, 61, 6, 73, 0, 96, 3, 99, 2, 96, 
    2, 46, 6, 53, 1, 55, 5, 48, 8,  7, 3, 83, 4, 11, 7, 85, 0, 96, 
    1,  2, 2, 88, 0, 12, 7, 14, 3, 53, 5, 71, 8, 31, 4, 47, 6, 35, 
    1, 71, 5, 42, 0, 85, 3, 97, 7, 11, 2, 64, 8, 15, 4, 70, 6, 12, 
    6, 43, 8, 23, 5, 11, 2, 48, 3, 59, 1, 85, 0, 40, 7, 92, 4, 79
  };
  const int q3390[] = {
    9, 9, // Number of jobs and machines
    2, 45, 0,  2, 5, 88, 3, 89, 8,  4, 1, 28, 4, 56, 7, 91, 6, 71, 
    1,  6, 4, 46, 7, 52, 2, 75, 8, 95, 5, 48, 6, 65, 0, 73, 3, 60, 
    7,  1, 4, 83, 0,  4, 8, 30, 3, 47, 5, 55, 2, 71, 1, 74, 6, 14, 
    4,  2, 1, 57, 2, 45, 3, 44, 7, 59, 0, 56, 5, 19, 6, 28, 8, 62, 
    5, 47, 7,  6, 1, 11, 0, 85, 2, 99, 4, 74, 6, 79, 3, 29, 8, 32, 
    7,  8, 4, 33, 1, 41, 2, 46, 6, 89, 3, 33, 5, 39, 8, 55, 0, 23, 
    1,  6, 5, 28, 2, 33, 4, 62, 8, 99, 6, 85, 7, 16, 0, 28, 3, 45, 
    8, 86, 5, 25, 6, 25, 3, 17, 2, 88, 0, 36, 7, 16, 4, 89, 1, 50, 
    5, 23, 1,  3, 4, 21, 6, 90, 3, 14, 7,  4, 8, 67, 0, 92, 2, 31
  };
  const int q3391[] = {
    9, 9, // Number of jobs and machines
    6, 75, 2,  2, 1, 48, 7,  6, 0, 47, 3, 90, 8, 74, 5, 33, 4, 31, 
    4, 19, 1, 46, 5, 67, 3, 34, 0, 75, 6, 27, 8, 80, 7, 42, 2, 18, 
    2, 16, 6, 87, 1, 24, 8, 47, 4, 72, 0, 80, 5, 37, 7, 14, 3, 92, 
    8, 32, 6, 34, 4, 73, 2, 74, 3, 51, 0, 57, 1,  4, 5, 44, 7, 16, 
    7, 56, 4, 71, 5, 41, 1, 60, 6, 65, 2, 39, 0, 59, 8, 10, 3, 79, 
    6, 19, 7, 31, 1, 88, 8, 18, 4, 65, 0, 81, 5, 71, 2,  2, 3, 66, 
    3, 95, 2,  7, 8, 99, 6, 61, 0, 45, 1, 46, 4,  5, 5, 58, 7, 83, 
    5, 47, 7, 97, 3, 70, 8, 45, 0,  1, 4, 21, 2, 34, 6, 96, 1, 42, 
    2, 81, 8, 97, 1, 86, 5, 99, 4, 77, 3, 74, 7, 74, 0, 58, 6, 17
  };
  const int q3392[] = {
    9, 9, // Number of jobs and machines
    6, 12, 1, 75, 2, 96, 7, 25, 5,  7, 0, 30, 8, 43, 3, 61, 4,  7, 
    7, 12, 6, 42, 4, 16, 8,  5, 2, 95, 3, 14, 5, 49, 0, 76, 1, 91, 
    3, 40, 8, 49, 6, 13, 7, 73, 2, 88, 5, 68, 4,  6, 1, 98, 0, 25, 
    4, 97, 5, 28, 6, 70, 3, 35, 1, 30, 8, 33, 2, 65, 0, 62, 7, 57, 
    8, 48, 2, 97, 7, 73, 5, 79, 0, 80, 4, 80, 6, 20, 3, 73, 1, 30, 
    6, 67, 2, 15, 8, 59, 3,  5, 0, 49, 1, 90, 4, 35, 7, 56, 5,  6, 
    3, 72, 5, 33, 7, 64, 4, 43, 6,  7, 1, 13, 2, 90, 8, 72, 0, 76, 
    4, 68, 1,  6, 8, 62, 5, 98, 0, 89, 7, 45, 6,  3, 3, 34, 2,  2, 
    5, 92, 1, 89, 2, 66, 7, 11, 3, 26, 6, 12, 4, 72, 0, 22, 8, 35
  };
  const int q3393[] = {
    9, 9, // Number of jobs and machines
    4, 39, 2, 13, 0, 59, 5, 40, 1, 48, 6, 15, 8, 95, 3, 20, 7, 74, 
    5, 35, 6, 59, 1, 40, 2,  7, 7, 66, 0, 20, 4, 75, 3, 86, 8, 18, 
    3, 13, 5, 59, 1, 54, 2, 34, 6, 18, 8, 26, 0, 62, 4, 52, 7,  6, 
    2, 94, 0, 28, 8, 90, 1, 23, 6, 47, 7, 83, 3, 36, 4, 60, 5, 44, 
    3, 15, 0, 12, 5, 42, 4, 92, 2, 77, 1, 32, 8,  3, 7, 99, 6, 69, 
    3, 22, 8, 78, 7, 83, 4, 83, 2, 51, 5, 64, 6, 92, 1, 21, 0,  2, 
    0, 66, 5, 40, 1, 49, 2, 82, 8, 42, 7, 89, 4, 39, 3, 16, 6, 26, 
    4, 89, 0, 61, 5, 98, 6, 88, 8, 55, 7, 48, 3, 68, 2, 98, 1, 74, 
    5, 61, 6, 40, 4, 89, 2, 57, 8, 82, 0, 53, 1, 34, 7, 89, 3, 34
  };
  const int q3394[] = {
    9, 9, // Number of jobs and machines
    3, 69, 5, 72, 7, 99, 2, 73, 0, 32, 4, 43, 8, 88, 1, 17, 6, 84, 
    7, 31, 2, 70, 1, 82, 4, 57, 5, 40, 6, 48, 8,  1, 0, 19, 3,  6, 
    4, 46, 3, 79, 8, 68, 0, 22, 7, 75, 1, 16, 5,  5, 2, 36, 6, 84, 
    6, 15, 7, 40, 5, 35, 2, 99, 3, 53, 0, 42, 1, 53, 8, 71, 4, 82, 
    7, 72, 1, 31, 5, 11, 4,  4, 6, 33, 0, 79, 2, 46, 3, 50, 8, 67, 
    3, 78, 2, 85, 7, 97, 1, 59, 0, 93, 4, 96, 6, 40, 5,  9, 8, 51, 
    7, 76, 0, 45, 3, 90, 8, 80, 4, 69, 1, 80, 2, 34, 6, 18, 5, 33, 
    4, 91, 5, 64, 6, 57, 7, 72, 8,  8, 2, 99, 3, 81, 0, 27, 1,  7, 
    8,  3, 2, 74, 5,  3, 3,  2, 7,  9, 1, 28, 4, 63, 6, 22, 0, 79
  };
  const int q3395[] = {
    9, 9, // Number of jobs and machines
    5, 76, 1, 65, 6,  9, 8, 15, 4, 23, 0, 12, 3, 82, 2,  3, 7, 42, 
    7,  2, 6, 43, 8, 34, 1, 15, 4,  9, 2, 62, 0, 50, 3, 15, 5, 60, 
    8, 61, 7, 71, 2, 65, 4, 13, 1,  1, 6, 52, 5, 83, 0, 52, 3, 53, 
    4,  8, 3, 57, 6, 87, 5, 35, 0,  7, 2, 60, 7, 52, 8, 28, 1, 56, 
    5, 84, 1, 95, 6, 69, 3, 97, 2, 17, 8, 22, 0, 47, 7, 50, 4, 28, 
    2, 77, 7, 89, 6, 16, 8, 12, 1, 92, 0,  8, 3, 29, 4, 42, 5, 34, 
    1, 39, 5, 62, 8, 68, 0, 60, 2, 65, 3, 31, 6, 83, 7, 88, 4, 44, 
    6,  2, 3, 22, 5, 84, 0, 85, 1, 91, 4, 25, 8, 60, 7, 15, 2, 16, 
    1, 96, 6, 82, 0, 25, 8, 50, 4, 52, 2, 73, 5, 33, 7, 25, 3, 89
  };
  const int q3396[] = {
    9, 9, // Number of jobs and machines
    8, 61, 1, 46, 5, 80, 3, 19, 2, 65, 0, 44, 6, 57, 7, 93, 4, 58, 
    3, 35, 5, 27, 1, 42, 4, 41, 8, 84, 0, 30, 6, 39, 2, 34, 7, 92, 
    8, 57, 0, 84, 4,  4, 7, 56, 2, 45, 6, 18, 1, 56, 5, 89, 3, 91, 
    0, 91, 8, 41, 3, 99, 2, 71, 7, 16, 5, 44, 4, 79, 6, 19, 1, 45, 
    4, 31, 2, 66, 1, 80, 0, 45, 6, 60, 3, 39, 7, 85, 8, 85, 5, 82, 
    4, 98, 7, 40, 3, 39, 5, 36, 0, 45, 8, 49, 6, 36, 2, 17, 1,  4, 
    4, 37, 2, 83, 8, 27, 0, 60, 1, 78, 7,  2, 6,  8, 3,  2, 5, 89, 
    1,  2, 0, 35, 5, 72, 3, 12, 4, 78, 2, 68, 7, 40, 6, 58, 8, 50, 
    8, 76, 5, 13, 6, 97, 1, 11, 3, 17, 0, 52, 4, 73, 2, 16, 7, 63
  };
  const int q3397[] = {
    9, 9, // Number of jobs and machines
    4, 67, 7, 56, 1, 96, 8, 73, 2, 91, 6, 64, 3, 31, 5, 63, 0, 40, 
    2, 11, 0, 91, 1, 60, 4, 50, 3, 97, 8, 17, 6, 99, 7, 68, 5, 44, 
    1,  6, 5, 71, 8, 12, 7,  4, 4, 74, 0, 68, 6, 93, 2,  4, 3, 15, 
    7, 12, 1, 59, 4, 46, 0, 20, 6, 96, 3, 81, 5, 20, 8, 33, 2, 19, 
    7, 17, 6,  5, 1, 71, 4, 33, 2,  6, 8, 70, 3, 65, 0, 47, 5, 51, 
    2, 58, 8, 33, 4, 29, 1,  5, 6, 99, 5,  4, 0, 48, 7, 32, 3, 21, 
    8, 98, 4, 79, 6,  6, 0, 52, 3, 89, 1,  8, 5, 94, 7, 65, 2, 39, 
    0, 21, 5, 77, 8, 19, 6, 36, 7, 67, 3, 99, 2, 19, 4, 10, 1, 20, 
    3,  7, 5, 23, 8, 30, 4, 14, 0, 33, 2,  5, 1, 33, 6, 74, 7, 32
  };
  const int q3398[] = {
    9, 9, // Number of jobs and machines
    7, 72, 5, 28, 8, 16, 0, 49, 2, 94, 6, 10, 4, 27, 1,  1, 3,  7, 
    2, 70, 4, 73, 1,  1, 5, 59, 0, 27, 6, 73, 8, 20, 7, 89, 3, 98, 
    4, 89, 7, 46, 3, 74, 8, 74, 2, 80, 1, 99, 6, 70, 0, 78, 5, 66, 
    5, 12, 6, 68, 2, 82, 0, 64, 4, 75, 1, 79, 8, 45, 7, 76, 3, 58, 
    0, 59, 3, 81, 7, 86, 2, 23, 4, 70, 8, 87, 5, 30, 6, 46, 1, 17, 
    5, 41, 3, 19, 7, 48, 2, 17, 1, 37, 0, 51, 8, 51, 6, 60, 4, 64, 
    6,  8, 7, 98, 2, 61, 4, 63, 8, 66, 5, 37, 1, 59, 0, 33, 3, 35, 
    1, 67, 7, 79, 0, 48, 2,  7, 5, 23, 4, 79, 8, 35, 6,  6, 3, 69, 
    8, 72, 4, 43, 3, 59, 6, 11, 2, 93, 0, 94, 7, 29, 1, 98, 5, 57
  };
  const int q3399[] = {
    9, 9, // Number of jobs and machines
    1, 67, 8, 87, 7, 45, 2, 41, 0, 34, 6, 17, 3,  3, 4, 19, 5, 84, 
    6, 23, 0, 31, 5, 63, 7, 91, 4, 38, 8, 44, 1, 40, 3, 99, 2, 56, 
    7,  5, 5, 22, 3, 53, 4, 70, 6, 32, 1,  3, 8, 37, 0, 58, 2, 62, 
    4,  1, 5, 82, 2, 97, 6, 81, 3, 48, 0, 85, 8, 78, 7,  9, 1, 13, 
    7, 23, 3, 61, 5, 86, 0, 98, 6, 69, 8, 78, 2, 65, 4, 67, 1, 19, 
    8, 25, 0, 46, 2, 12, 3, 68, 4, 69, 1, 56, 5, 84, 7, 83, 6, 68, 
    2, 72, 3, 43, 7, 65, 0, 23, 4, 99, 8, 91, 6, 41, 5, 37, 1,  1, 
    4, 89, 0, 86, 8, 55, 7, 69, 3, 87, 2, 22, 6, 96, 5, 45, 1, 61, 
    4, 75, 0, 68, 6, 18, 2, 59, 1, 10, 5, 47, 7, 77, 3, 64, 8, 16
  };
  const int q3400[] = {
    9, 9, // Number of jobs and machines
    4, 67, 5, 39, 8, 99, 1, 67, 0, 49, 3, 39, 6, 80, 7, 15, 2, 48, 
    4,  6, 0, 45, 2, 55, 7, 54, 6, 22, 8, 20, 5, 21, 3, 97, 1, 39, 
    3, 18, 2, 63, 7,  7, 5, 94, 6,  9, 4, 29, 8, 81, 1, 16, 0,  8, 
    3, 26, 6, 58, 0, 64, 7, 48, 2, 39, 1, 22, 5, 83, 8, 58, 4, 92, 
    4, 24, 5, 63, 3, 65, 2, 25, 8, 33, 0, 44, 6, 21, 1, 84, 7, 13, 
    4, 17, 5, 69, 7, 36, 3,  1, 1, 95, 6, 90, 2, 53, 8, 48, 0,  3, 
    3, 94, 1, 66, 8,  4, 7,  8, 4, 63, 6, 15, 5, 13, 0, 11, 2, 59, 
    3, 78, 8, 36, 2, 36, 5, 61, 1, 48, 4, 23, 6, 94, 7, 21, 0, 36, 
    5, 68, 3, 50, 4, 95, 7, 53, 2, 32, 8, 18, 0, 32, 6,  3, 1, 72
  };
  const int q3401[] = {
    9, 9, // Number of jobs and machines
    0, 93, 7, 42, 1, 53, 6, 52, 2, 51, 3,  6, 8, 78, 5,  1, 4, 49, 
    1, 85, 5, 35, 3, 12, 8, 28, 0, 47, 7, 46, 2, 67, 6,  1, 4, 23, 
    3, 58, 7,  2, 8, 77, 2, 90, 6,  4, 5, 96, 1, 76, 4, 50, 0, 62, 
    4, 43, 7, 13, 0, 61, 6, 34, 5, 58, 3, 96, 2, 12, 8, 75, 1,  1, 
    7, 20, 4, 18, 3, 79, 0, 25, 8, 33, 5, 60, 6, 30, 1, 62, 2, 76, 
    0, 94, 8, 53, 5, 29, 2, 21, 1, 89, 6, 81, 4, 53, 7, 28, 3, 31, 
    2, 22, 6,  8, 3, 55, 7, 58, 4, 11, 0, 74, 1, 73, 8, 99, 5, 35, 
    8, 28, 6, 95, 1, 32, 0, 42, 2, 17, 7, 31, 3,  2, 5, 33, 4, 74, 
    7,  9, 3, 77, 6, 77, 4, 73, 8, 37, 2, 23, 1,  8, 5, 59, 0, 96
  };
  const int q3402[] = {
    9, 9, // Number of jobs and machines
    3, 30, 8, 66, 1, 15, 6, 56, 4,  5, 2,  7, 7, 18, 5, 75, 0, 41, 
    8,  1, 4, 13, 0, 92, 5, 67, 3, 47, 6,  8, 2, 27, 1, 99, 7, 97, 
    4, 62, 5,  8, 3, 45, 1, 36, 6,  3, 0, 55, 7, 12, 8, 13, 2, 17, 
    7, 44, 5,  2, 6, 45, 1, 86, 0,  6, 8, 91, 4, 47, 2,  4, 3, 85, 
    5, 44, 8, 75, 2,  2, 6, 81, 7, 26, 4, 99, 1, 31, 0,  6, 3, 58, 
    6, 57, 7, 75, 1, 15, 3, 86, 4, 30, 0, 40, 5, 35, 8, 95, 2, 42, 
    4, 37, 7, 27, 2,  4, 8, 19, 5, 79, 1, 89, 3, 49, 6, 17, 0, 27, 
    3, 56, 8, 98, 0, 48, 2, 66, 7, 11, 1, 93, 6,  3, 4, 54, 5, 24, 
    1,  5, 5, 67, 3, 15, 6, 77, 7, 44, 0, 49, 8, 60, 2, 33, 4, 75
  };
  const int q3403[] = {
    9, 9, // Number of jobs and machines
    6, 88, 5, 16, 3, 53, 1, 25, 7, 59, 0, 64, 2, 62, 4, 61, 8, 12, 
    7, 83, 1, 54, 6, 18, 8, 13, 2,  4, 3, 76, 4, 37, 0, 26, 5, 22, 
    2, 12, 3, 80, 7, 11, 0, 42, 4, 59, 8, 21, 5, 59, 6, 95, 1, 97, 
    8, 66, 4, 88, 3, 19, 2, 94, 0, 99, 1, 37, 7, 56, 5, 70, 6, 61, 
    4, 58, 8, 87, 7, 60, 3, 43, 5, 95, 6, 63, 0, 10, 1, 35, 2, 78, 
    0, 17, 6, 32, 3, 65, 4, 75, 8, 15, 1,  6, 7, 91, 2, 28, 5, 34, 
    0, 36, 3, 80, 1, 40, 5, 75, 6, 97, 7,  4, 2, 56, 8, 78, 4, 80, 
    8, 42, 6, 65, 3, 94, 5, 90, 1, 93, 7, 62, 2, 94, 4, 25, 0, 21, 
    3,  7, 8, 87, 5, 33, 0, 65, 7, 36, 2, 58, 1, 68, 4, 20, 6, 63
  };
  const int q3404[] = {
    9, 9, // Number of jobs and machines
    4,  6, 3, 91, 7, 82, 2, 49, 1, 18, 5, 49, 8, 25, 0, 79, 6, 39, 
    3, 78, 7, 50, 1, 10, 8, 46, 6, 14, 4, 64, 5, 28, 2, 42, 0, 73, 
    7, 21, 1,  8, 6, 68, 8, 56, 4, 12, 2, 51, 3, 50, 5, 17, 0, 10, 
    6, 57, 1, 73, 0, 71, 7, 53, 8, 64, 4, 19, 2, 17, 5, 25, 3, 81, 
    8, 79, 7, 55, 3, 18, 0, 57, 6, 32, 4, 25, 2, 14, 5, 49, 1, 25, 
    4,  9, 0, 53, 1, 53, 7, 55, 5, 99, 3, 82, 8, 46, 2, 48, 6, 57, 
    4,  7, 7, 23, 6, 19, 8, 81, 3, 54, 5, 46, 0, 76, 1, 79, 2, 75, 
    0, 68, 2, 52, 4, 93, 3, 60, 7, 32, 8, 32, 1, 97, 6, 75, 5, 57, 
    6, 83, 4, 59, 1,  5, 3,  1, 5, 21, 7,  5, 0, 69, 8, 18, 2, 14
  };
  const int q3405[] = {
    9, 9, // Number of jobs and machines
    7,  9, 2, 22, 8, 12, 4, 27, 6, 28, 0, 89, 1, 75, 5, 19, 3, 49, 
    4, 84, 8, 44, 2, 80, 6, 75, 3, 18, 5, 54, 0, 97, 1, 25, 7, 92, 
    1,  5, 3, 42, 2, 19, 0, 30, 4, 36, 8, 14, 7, 58, 6, 93, 5, 57, 
    2,  7, 6, 69, 5, 49, 3, 27, 1, 59, 4, 42, 7,  5, 8, 18, 0,  6, 
    0, 83, 2, 55, 7, 71, 1, 52, 6, 77, 3, 93, 5,  6, 8, 81, 4, 89, 
    7,  7, 1, 57, 8, 53, 0,  8, 2, 42, 4, 99, 6, 98, 5, 21, 3, 69, 
    4, 71, 0, 48, 5, 36, 8, 49, 7, 44, 1, 20, 3, 93, 6, 16, 2, 37, 
    5, 50, 1, 95, 6, 70, 7, 62, 8, 11, 0, 59, 2, 10, 4,  7, 3, 11, 
    5,  7, 6, 45, 0, 13, 1, 34, 3, 76, 4,  4, 2, 82, 7, 66, 8, 55
  };
  const int q3406[] = {
    9, 9, // Number of jobs and machines
    3, 62, 2, 14, 0, 67, 5, 57, 8, 43, 4, 50, 6, 59, 7, 96, 1, 51, 
    6, 33, 1, 17, 0, 99, 8, 15, 2, 21, 4, 43, 5, 86, 3, 48, 7, 71, 
    2, 67, 3, 94, 4, 58, 1, 67, 8, 38, 0, 66, 7, 38, 5, 13, 6, 70, 
    4, 56, 5,  7, 0, 56, 8, 76, 6, 77, 7, 55, 2, 45, 1, 89, 3, 39, 
    3, 10, 5, 67, 7, 29, 4,  5, 2, 72, 8, 12, 1, 64, 6, 59, 0, 51, 
    0, 66, 7, 30, 5, 40, 6, 10, 8, 38, 4, 25, 3, 71, 1, 29, 2,  3, 
    1, 39, 0, 78, 4, 54, 5, 41, 6, 45, 8, 28, 2, 77, 3, 93, 7, 79, 
    2, 44, 6, 43, 0, 23, 1, 65, 3, 56, 5, 66, 7, 44, 8, 37, 4, 21, 
    2, 11, 7, 25, 8, 44, 0, 45, 3, 33, 4, 10, 5, 35, 1, 91, 6, 70
  };
  const int q3407[] = {
    9, 9, // Number of jobs and machines
    0, 34, 3,  5, 6, 66, 8, 19, 1, 49, 4, 39, 2,  7, 7, 78, 5, 93, 
    7, 63, 6, 21, 4,  4, 2, 65, 8, 53, 1, 92, 0, 20, 5, 35, 3, 20, 
    4, 97, 6, 73, 2, 53, 1,  8, 3, 26, 8, 90, 7, 74, 0, 74, 5, 73, 
    4, 86, 1, 97, 8, 44, 7, 34, 0, 61, 6,  3, 5, 60, 3, 79, 2, 37, 
    5,  2, 2, 50, 3, 57, 1, 55, 6, 30, 0, 20, 7, 53, 8, 63, 4,  1, 
    8, 71, 6, 20, 3,  7, 2, 48, 4, 78, 0, 36, 1, 14, 5, 45, 7, 59, 
    8, 32, 1, 72, 7, 37, 5, 74, 0, 39, 4, 15, 3, 68, 2, 28, 6,  5, 
    7, 89, 3, 97, 4, 46, 6,  9, 1, 82, 8, 55, 2, 87, 0,  6, 5, 65, 
    3, 23, 6,  8, 0, 47, 8, 69, 7, 57, 5, 42, 2,  7, 1, 15, 4, 81
  };
  const int q3408[] = {
    9, 9, // Number of jobs and machines
    6, 65, 8, 41, 2, 70, 1, 43, 7, 61, 0, 47, 3, 54, 4,  1, 5, 99, 
    2, 84, 5, 91, 0, 66, 8, 46, 1, 75, 3, 86, 6, 56, 7, 81, 4, 56, 
    7, 42, 0, 67, 5, 93, 4, 83, 8,  5, 1, 89, 3,  3, 6, 23, 2, 91, 
    6, 52, 8, 37, 4, 81, 0, 19, 1, 60, 3, 89, 5,  7, 7, 63, 2,  9, 
    2, 17, 8, 52, 1, 27, 3, 33, 0, 62, 6, 42, 4, 86, 7, 22, 5,  2, 
    8, 33, 7,  3, 4, 78, 3, 40, 2, 24, 6, 91, 0, 32, 5, 26, 1, 83, 
    6, 78, 2, 72, 0,  7, 3,  9, 7, 47, 4, 72, 5, 94, 8, 67, 1, 99, 
    3, 81, 6, 79, 4, 67, 1, 71, 8, 99, 0, 68, 5, 68, 7, 93, 2, 59, 
    0,  8, 1, 59, 5, 54, 8, 34, 3, 56, 7, 89, 2, 53, 4, 53, 6, 25
  };
  const int q3409[] = {
    9, 9, // Number of jobs and machines
    5, 32, 8, 21, 1, 27, 4, 21, 3,  9, 0, 46, 7, 94, 6, 67, 2, 56, 
    3, 63, 4, 81, 6, 42, 2, 54, 1, 30, 8,  3, 7, 93, 5, 68, 0, 44, 
    2, 46, 4,  9, 3, 99, 7, 54, 6, 77, 8, 65, 0, 50, 5, 16, 1, 91, 
    1, 48, 0, 46, 8, 92, 6, 48, 2, 95, 4, 49, 5, 12, 3,  5, 7, 94, 
    6, 62, 8, 83, 4, 95, 3, 95, 2, 88, 5, 23, 0, 78, 7, 69, 1,  9, 
    0, 20, 8, 54, 4, 11, 3, 64, 1, 50, 7,  9, 6, 33, 5, 89, 2, 51, 
    4, 78, 7, 96, 8, 83, 5, 80, 6, 49, 1, 98, 0, 45, 3, 63, 2, 24, 
    3, 75, 6, 90, 0, 82, 1, 79, 7, 85, 4, 39, 8, 20, 5, 36, 2, 76, 
    3, 54, 2, 87, 8, 61, 0, 48, 1, 91, 4, 77, 7, 53, 6, 76, 5, 16
  };
  const int q3410[] = {
    9, 9, // Number of jobs and machines
    1, 97, 0, 11, 2, 28, 4, 14, 3,  1, 5, 71, 7, 68, 8,  1, 6, 74, 
    2, 68, 7,  4, 0, 15, 6,  9, 5, 27, 1, 57, 3, 72, 4, 58, 8, 12, 
    0, 31, 8, 74, 4, 94, 1, 50, 7, 24, 2, 99, 3, 43, 5, 33, 6, 81, 
    2, 81, 0, 33, 3, 61, 8, 15, 1, 40, 6, 30, 5, 73, 4, 38, 7, 76, 
    1, 98, 3,  2, 6, 98, 8, 45, 5, 26, 7, 79, 2,  6, 4, 17, 0, 68, 
    8,  8, 4, 93, 5, 51, 3, 38, 6, 73, 7, 86, 0, 57, 2, 46, 1, 82, 
    2, 74, 6, 33, 7, 53, 1, 74, 4, 62, 0, 37, 8, 86, 3, 46, 5, 48, 
    8, 88, 2,  5, 4, 66, 0, 44, 5, 40, 1,  5, 7, 77, 6, 99, 3, 93, 
    3, 12, 8, 91, 7,  9, 2, 58, 6, 80, 0, 31, 5, 94, 4, 28, 1, 31
  };
  const int q3411[] = {
    9, 9, // Number of jobs and machines
    3, 28, 4, 42, 5, 88, 6, 52, 2, 15, 7, 28, 1, 32, 8, 89, 0,  6, 
    6, 25, 8, 73, 4, 66, 2, 84, 3, 62, 5, 95, 7, 22, 0, 77, 1, 98, 
    4, 98, 7, 75, 5,  2, 2, 88, 1, 83, 8,  8, 3, 81, 0, 87, 6, 42, 
    0, 24, 5, 78, 7, 66, 1, 26, 6, 71, 4, 69, 2, 38, 8, 44, 3, 46, 
    0, 36, 4, 74, 7, 10, 5, 79, 3, 96, 8, 32, 6, 18, 2, 65, 1, 92, 
    7, 87, 4, 10, 0, 61, 8, 41, 6, 89, 3, 45, 1, 82, 5, 50, 2, 68, 
    7, 17, 8, 14, 4, 19, 1,  1, 2, 83, 5,  9, 3, 56, 0, 18, 6, 50, 
    4, 30, 2, 76, 6,  2, 8, 71, 3, 97, 0, 14, 7, 18, 1, 33, 5, 74, 
    1, 11, 4, 23, 7, 63, 5, 86, 6, 73, 3, 99, 0, 62, 8, 75, 2, 41
  };
  const int q3412[] = {
    9, 9, // Number of jobs and machines
    2, 91, 7,  1, 5, 64, 1, 50, 0, 43, 6, 85, 3, 13, 4, 32, 8, 33, 
    3, 29, 6, 41, 4, 22, 0, 97, 2,  8, 8, 78, 5, 49, 7, 33, 1, 22, 
    7, 88, 4, 85, 6, 84, 8, 94, 2, 90, 5, 27, 3, 73, 1, 65, 0,  8, 
    3, 90, 0, 32, 1,  2, 2, 27, 6, 99, 8, 35, 7, 85, 4, 74, 5, 42, 
    1, 91, 3, 28, 5, 52, 2, 78, 6, 41, 8, 66, 0, 53, 4, 69, 7, 73, 
    5,  5, 8, 85, 3, 87, 4, 43, 1, 81, 6, 47, 0, 79, 7, 83, 2, 66, 
    5, 23, 8, 17, 6, 28, 4,  1, 7, 98, 1, 13, 2, 65, 0, 15, 3, 32, 
    5, 41, 3, 82, 4, 23, 0, 11, 1, 68, 2, 62, 8, 56, 7, 31, 6,  1, 
    5, 45, 6, 58, 1, 85, 8, 50, 4, 77, 7, 65, 0,  7, 2, 56, 3, 47
  };
  const int q3413[] = {
    9, 9, // Number of jobs and machines
    4, 65, 7, 86, 2, 97, 0,  4, 8, 28, 1, 94, 6, 95, 5,  6, 3, 94, 
    4, 92, 0, 48, 5, 40, 7, 82, 6, 51, 3, 45, 2, 12, 1,  3, 8, 83, 
    5, 46, 6, 20, 2, 92, 3, 47, 4, 75, 8, 30, 1, 99, 0, 56, 7, 19, 
    8, 74, 1, 53, 2, 82, 7, 82, 0, 99, 4, 91, 5, 79, 6, 91, 3, 62, 
    5, 87, 0, 65, 1, 47, 4, 49, 8,  1, 7, 19, 3, 58, 2, 55, 6, 23, 
    8,  4, 7, 29, 1, 21, 5, 77, 2,  4, 4, 30, 0, 51, 6, 58, 3, 85, 
    0, 88, 4, 93, 7, 57, 1, 20, 6, 72, 5, 99, 3, 14, 8, 84, 2, 99, 
    8, 34, 7, 81, 4, 16, 0, 26, 6, 20, 1, 41, 2, 31, 3, 86, 5, 71, 
    3, 26, 6, 92, 4, 56, 5, 59, 1, 92, 8, 37, 7,  3, 2, 40, 0, 34
  };
  const int q3414[] = {
    9, 9, // Number of jobs and machines
    4, 11, 7, 29, 3, 22, 2, 79, 6, 34, 0, 32, 5, 62, 1, 69, 8, 19, 
    0, 79, 5, 78, 2, 26, 8, 14, 3, 86, 6, 63, 7, 82, 1, 72, 4, 47, 
    0, 45, 5, 73, 1, 42, 6, 87, 4, 84, 8, 35, 7, 69, 2, 39, 3, 71, 
    7, 52, 6, 63, 0, 43, 3, 81, 2, 48, 8, 32, 5,  1, 1, 96, 4, 41, 
    1, 36, 3, 30, 8, 74, 0, 61, 2,  9, 5, 89, 7, 68, 4, 71, 6,  8, 
    3, 51, 4, 47, 5, 76, 2, 29, 0, 26, 1, 91, 7, 82, 6, 37, 8, 48, 
    2, 35, 6, 51, 0, 18, 7, 10, 5, 34, 1, 31, 4, 54, 8, 71, 3,  8, 
    0, 64, 4,  7, 1, 17, 3, 86, 5, 26, 7, 96, 2, 35, 6, 27, 8, 99, 
    7, 80, 2,  6, 3, 68, 8,  8, 0, 12, 6, 42, 1,  8, 5, 68, 4, 43
  };
  const int q3415[] = {
    9, 9, // Number of jobs and machines
    6, 70, 8, 26, 1, 10, 5, 77, 7,  1, 0, 34, 3, 56, 4, 96, 2, 20, 
    6, 40, 7, 39, 8, 54, 4, 77, 1, 38, 3, 86, 5,  8, 2, 17, 0, 86, 
    4, 70, 7,  3, 1, 88, 8, 11, 2, 45, 6, 18, 0, 87, 5, 15, 3, 97, 
    7, 60, 3, 36, 1, 85, 0, 77, 6, 96, 5, 78, 2, 69, 8, 34, 4, 81, 
    8, 44, 7, 62, 0, 67, 3, 14, 5, 98, 2, 97, 4, 48, 1, 88, 6, 15, 
    5, 57, 8, 31, 4, 44, 0, 77, 1, 27, 7, 76, 2, 55, 6,  4, 3,  8, 
    3, 15, 6, 18, 2, 48, 8, 53, 5, 98, 0, 11, 7, 21, 1, 28, 4, 98, 
    8, 83, 1, 35, 2, 19, 0, 90, 7,  9, 5, 50, 4, 43, 3, 24, 6, 36, 
    3, 33, 6, 69, 2, 16, 0, 63, 1, 37, 5, 73, 7, 24, 8, 46, 4, 39
  };
  const int q3416[] = {
    9, 9, // Number of jobs and machines
    4, 85, 3,  2, 6, 91, 2, 23, 7, 92, 1, 92, 0, 43, 8, 38, 5, 67, 
    8, 15, 7, 58, 0, 29, 3, 97, 2, 99, 1, 50, 6, 67, 4, 85, 5, 18, 
    1, 16, 5, 87, 3, 50, 7, 55, 2, 83, 0, 94, 4, 94, 6, 82, 8, 75, 
    6, 20, 4, 65, 7, 70, 0, 45, 8, 77, 1, 49, 2, 32, 5, 28, 3,  1, 
    3, 45, 8, 70, 7, 75, 1, 74, 2, 89, 5, 55, 4, 19, 6,  6, 0, 94, 
    8, 91, 4, 89, 1, 34, 7, 76, 3, 98, 5, 88, 6, 34, 2, 92, 0, 39, 
    0, 16, 6, 98, 1, 47, 3, 85, 4, 20, 2, 24, 8, 27, 5, 69, 7, 70, 
    1, 42, 7, 44, 2, 89, 3, 63, 4, 27, 8, 42, 0, 89, 6, 94, 5, 63, 
    4, 88, 8, 68, 0, 23, 1, 36, 6, 32, 7,  2, 5, 81, 2, 81, 3,  9
  };
  const int q3417[] = {
    9, 9, // Number of jobs and machines
    5, 98, 3, 75, 0,  7, 6, 77, 1, 48, 8,  7, 2, 88, 7, 23, 4, 34, 
    2, 41, 8, 75, 1, 19, 4, 27, 6, 89, 5, 70, 0, 65, 7,  7, 3, 84, 
    2, 63, 6, 63, 3, 29, 5, 52, 7, 86, 8, 57, 1, 46, 0, 56, 4, 16, 
    3, 54, 8, 40, 1, 96, 0, 51, 4, 27, 2, 85, 6, 63, 7, 60, 5, 73, 
    4, 45, 3, 64, 7, 69, 8, 10, 5, 58, 2, 77, 1, 67, 0, 79, 6, 87, 
    5,  5, 2, 67, 6, 65, 4, 26, 1, 27, 3, 18, 8, 25, 7, 11, 0, 27, 
    2,  7, 0, 34, 5,  3, 7, 32, 8,  4, 1, 92, 4,  2, 6, 51, 3, 12, 
    2, 64, 6, 41, 4, 65, 7, 77, 1, 23, 5, 50, 0, 39, 8, 58, 3, 11, 
    6, 28, 8, 27, 3, 32, 2, 75, 1, 15, 4, 87, 0, 68, 7, 50, 5, 44
  };
  const int q3418[] = {
    9, 9, // Number of jobs and machines
    1, 28, 7, 88, 6, 41, 4, 65, 8, 40, 2, 69, 5,  8, 3, 75, 0, 41, 
    4, 92, 5, 55, 2, 77, 6, 58, 1, 73, 7, 16, 3, 41, 0, 31, 8, 87, 
    0, 14, 3, 25, 8, 47, 1, 33, 7, 67, 5, 43, 6, 97, 2, 19, 4, 15, 
    0, 19, 7, 66, 1, 46, 8, 59, 5, 14, 2, 96, 6, 86, 4, 90, 3, 30, 
    8, 51, 1, 48, 2, 52, 6, 21, 7, 62, 5, 36, 0, 63, 3, 26, 4, 64, 
    7, 55, 8,  6, 3, 83, 4, 29, 1, 55, 0, 98, 2, 21, 5, 35, 6, 94, 
    0, 75, 8, 50, 6, 58, 1, 85, 4, 27, 2, 81, 7, 58, 3, 71, 5, 17, 
    8, 99, 4, 93, 1, 59, 5, 21, 6, 62, 0, 47, 2, 18, 3, 68, 7, 91, 
    2, 59, 7, 91, 6, 77, 5, 12, 3, 25, 4,  8, 8, 20, 1, 28, 0, 80
  };
  const int q3419[] = {
    9, 9, // Number of jobs and machines
    8, 26, 1, 84, 4, 19, 7, 49, 6, 81, 3, 96, 5, 47, 0, 79, 2, 79, 
    5, 37, 2, 73, 8,  4, 0, 29, 7, 19, 3, 84, 4, 21, 1,  3, 6, 19, 
    7, 83, 4, 62, 8, 42, 3, 70, 0, 53, 5, 93, 6, 56, 1, 42, 2, 85, 
    8,  2, 5, 93, 2, 80, 7, 49, 3, 95, 6, 23, 4, 70, 1, 24, 0, 61, 
    5, 40, 4, 98, 3, 89, 6,  3, 1,  1, 0,  2, 8, 64, 7, 89, 2, 88, 
    7, 50, 8, 50, 1, 25, 3, 29, 5, 53, 0,  8, 6,  2, 2, 85, 4, 89, 
    7, 10, 8, 47, 6, 46, 4, 12, 2, 94, 0,  4, 5, 31, 1, 47, 3, 12, 
    3, 82, 5, 20, 7, 56, 6, 77, 8, 22, 1,  5, 2, 13, 4, 33, 0, 13, 
    1, 86, 0,  8, 6, 82, 4, 29, 3,  4, 2, 51, 8, 20, 5,  6, 7, 89
  };
  const int q3420[] = {
    9, 9, // Number of jobs and machines
    6, 34, 5,  9, 3, 24, 4, 89, 8, 74, 7,  5, 2, 71, 1, 14, 0, 83, 
    5, 10, 6, 51, 8, 22, 3, 70, 2, 46, 4, 14, 0,  9, 1, 60, 7, 71, 
    4, 42, 3, 62, 8, 11, 2, 52, 5, 90, 7, 70, 1, 65, 6, 42, 0, 45, 
    3, 90, 0,  6, 6, 37, 7, 75, 4, 87, 1, 44, 2, 12, 5, 70, 8, 57, 
    5, 62, 3, 85, 7, 37, 6, 31, 8, 59, 4, 81, 0, 81, 1, 53, 2, 85, 
    1, 49, 3, 64, 5,  3, 7, 43, 8, 13, 2, 85, 4, 53, 0, 78, 6, 94, 
    1, 77, 2, 27, 3, 20, 7, 55, 0, 26, 5, 94, 6, 90, 4, 93, 8, 65, 
    5, 53, 4, 80, 6,  2, 1, 88, 3, 92, 2, 41, 8, 34, 7, 72, 0, 80, 
    0, 17, 4, 90, 5, 51, 1, 12, 2,  4, 6, 72, 8,  2, 3, 81, 7, 16
  };
  const int q3421[] = {
    9, 9, // Number of jobs and machines
    5, 85, 0, 27, 1, 32, 6, 38, 7, 24, 8, 30, 2, 35, 3, 17, 4, 41, 
    3, 96, 8, 44, 4, 45, 7, 93, 0, 75, 6, 84, 2, 64, 5, 98, 1,  1, 
    2,  8, 4, 98, 0, 92, 6,  9, 5, 35, 8,  7, 1, 58, 3, 23, 7,  5, 
    0, 76, 8, 58, 5, 59, 1, 47, 2, 96, 7, 97, 6, 98, 4, 50, 3, 55, 
    0, 87, 7,  3, 1, 12, 8, 28, 3, 61, 4, 58, 2, 31, 5,  7, 6, 37, 
    4, 47, 8, 73, 3, 66, 0, 33, 2, 77, 1, 80, 6, 64, 5, 28, 7, 45, 
    7, 30, 8, 32, 6, 45, 1, 91, 0, 70, 2, 88, 3, 77, 5, 69, 4, 84, 
    0, 52, 4, 41, 7, 97, 2, 11, 8, 54, 5, 32, 3, 85, 1, 22, 6, 21, 
    1, 25, 8, 69, 6, 78, 2, 22, 5, 66, 0, 85, 7, 35, 3, 30, 4, 70
  };
  const int q3422[] = {
    9, 9, // Number of jobs and machines
    0, 71, 7, 24, 2,  4, 1, 10, 4, 62, 3, 52, 6, 26, 5, 13, 8, 11, 
    4, 93, 3, 95, 7, 81, 5, 21, 6, 19, 2, 58, 1,  6, 8, 96, 0, 93, 
    1, 58, 0, 56, 2, 64, 7, 30, 3, 20, 4, 14, 6, 82, 5, 26, 8, 15, 
    4,  6, 7, 20, 5, 62, 6, 48, 0, 81, 1, 33, 2, 13, 3, 47, 8, 27, 
    6, 64, 4, 13, 0, 99, 5, 70, 8, 58, 3, 70, 2, 82, 1, 35, 7, 78, 
    8, 37, 2, 64, 3, 73, 1, 96, 0, 63, 5, 15, 7, 40, 6, 24, 4, 91, 
    2, 40, 0, 58, 3, 32, 6,  2, 4, 34, 7, 13, 8, 99, 5, 48, 1, 39, 
    8,  6, 5, 17, 7,  1, 6, 90, 3, 83, 1, 67, 4, 67, 0, 36, 2, 81, 
    2, 28, 6, 99, 1, 36, 7, 41, 4, 27, 5, 68, 8, 82, 3, 99, 0, 17
  };
  const int q3423[] = {
    9, 9, // Number of jobs and machines
    0, 29, 7, 61, 1,  3, 5, 16, 2, 35, 4, 81, 8, 93, 6, 20, 3, 76, 
    8, 49, 2, 12, 3, 77, 4, 87, 6, 78, 0,  9, 7,  1, 1, 70, 5, 20, 
    4,  7, 1, 60, 6, 13, 2, 60, 0, 94, 7, 72, 5, 27, 8, 51, 3, 13, 
    6,  1, 2, 20, 4,  2, 5, 68, 0, 63, 7, 10, 1, 88, 3, 19, 8, 52, 
    0, 30, 5, 69, 2,  6, 4, 98, 1, 21, 8, 81, 3, 50, 7, 54, 6, 50, 
    4, 33, 5, 90, 6, 44, 0, 95, 2, 16, 7, 10, 3, 24, 8, 95, 1, 11, 
    3, 94, 7, 58, 6, 51, 0, 89, 8, 39, 1, 28, 4,  2, 5, 75, 2, 32, 
    4, 81, 6, 73, 3, 26, 2, 55, 0, 79, 5, 86, 7, 21, 1, 95, 8, 96, 
    5, 14, 6, 28, 1, 67, 0, 34, 7, 69, 2,  9, 4, 89, 3, 96, 8, 87
  };
  const int q3424[] = {
    9, 9, // Number of jobs and machines
    6, 29, 1, 14, 3, 51, 5, 43, 7, 38, 2, 70, 8,  5, 4, 61, 0, 41, 
    2, 52, 1, 89, 3, 65, 8, 87, 6, 81, 5, 22, 4, 62, 0, 75, 7, 82, 
    5, 56, 8, 12, 4, 34, 1, 85, 0, 89, 7, 83, 3, 64, 6, 57, 2, 48, 
    3, 19, 2, 45, 1, 90, 8, 65, 4,  8, 6, 38, 0, 52, 7, 22, 5, 57, 
    6,  6, 5,  8, 8, 69, 4, 24, 7, 15, 3, 41, 0, 43, 2, 90, 1, 43, 
    1, 49, 7, 79, 2, 27, 8, 86, 6, 16, 3, 98, 4, 16, 5, 45, 0,  8, 
    5, 83, 8, 91, 1, 17, 2, 11, 0,  4, 7, 66, 3,  6, 6,  3, 4, 42, 
    3, 88, 7, 61, 4, 69, 0, 57, 1, 78, 2, 97, 5,  8, 6, 85, 8, 38, 
    2, 47, 8, 89, 3,  3, 0, 80, 5, 94, 4,  8, 1, 20, 6, 70, 7, 26
  };
  const int q3425[] = {
    9, 9, // Number of jobs and machines
    8, 95, 4, 30, 6, 99, 1, 78, 3, 92, 7, 93, 0, 62, 5, 98, 2, 28, 
    5, 74, 8, 89, 2, 83, 0, 63, 7, 94, 1, 63, 6, 99, 3, 80, 4, 70, 
    1, 77, 2, 82, 0, 11, 4, 27, 6, 77, 8, 87, 5,  4, 7, 36, 3, 85, 
    6,  2, 3, 93, 8, 66, 0,  6, 1, 89, 7, 78, 5, 64, 2, 83, 4, 24, 
    0, 33, 7, 65, 6, 19, 1, 35, 8,  7, 5, 71, 4,  9, 3, 19, 2, 58, 
    3, 64, 1, 17, 8, 45, 5, 36, 6, 43, 4, 55, 2,  6, 0, 25, 7, 51, 
    6,  7, 4, 96, 5, 39, 2, 86, 1, 95, 7, 77, 0, 25, 8, 92, 3, 55, 
    4, 47, 3, 26, 6, 61, 8, 94, 0, 82, 7, 79, 1,  1, 2,  8, 5, 90, 
    4, 51, 3,  9, 2, 86, 1, 79, 0, 71, 7, 23, 5, 27, 8, 66, 6,  5
  };
  const int q3426[] = {
    9, 9, // Number of jobs and machines
    0, 45, 1, 94, 6, 48, 7, 92, 8, 89, 3, 55, 4, 96, 2, 30, 5,  8, 
    7, 31, 3,  7, 5, 90, 6, 35, 2, 15, 4, 59, 0, 65, 1, 83, 8, 53, 
    6, 74, 2, 39, 3, 48, 5, 62, 8, 50, 4, 22, 7, 21, 1, 83, 0, 25, 
    0, 35, 1, 86, 4, 90, 5, 60, 2,  8, 6,  8, 8, 19, 7, 51, 3, 76, 
    3, 42, 0, 26, 7, 68, 2, 94, 6, 13, 8, 57, 4, 38, 1,  1, 5, 47, 
    0, 52, 5, 91, 6,  6, 2, 20, 8, 23, 7, 73, 4, 81, 3, 69, 1, 50, 
    6, 26, 1,  8, 2, 83, 0, 34, 7, 40, 4,  1, 8, 74, 5,  2, 3, 17, 
    1, 61, 4, 72, 5, 49, 6, 80, 7, 41, 2, 41, 0, 49, 8, 56, 3, 46, 
    1, 37, 7, 92, 0, 81, 6, 14, 3, 34, 5, 81, 4, 22, 2, 42, 8, 66
  };
  const int q3427[] = {
    9, 9, // Number of jobs and machines
    7, 75, 6, 55, 8, 42, 1, 75, 5,  9, 4, 96, 0, 81, 3, 92, 2, 21, 
    6, 76, 0, 88, 3, 82, 5,  6, 8, 88, 1, 52, 2, 15, 4, 89, 7, 22, 
    2,  4, 4, 34, 7, 89, 1, 98, 5, 94, 6, 68, 8,  1, 0, 18, 3, 57, 
    4, 35, 3, 77, 8, 98, 5, 16, 0,  3, 1, 81, 7, 30, 6, 51, 2, 15, 
    0, 57, 5, 51, 1, 89, 7, 95, 2, 87, 6, 34, 8, 72, 3, 71, 4, 65, 
    7, 14, 1, 66, 8, 10, 6,  7, 0, 54, 2, 60, 5, 86, 3, 83, 4, 61, 
    3, 34, 6, 91, 2, 71, 4, 19, 5, 32, 8, 30, 1, 36, 0, 89, 7, 88, 
    0, 50, 6, 28, 4, 15, 3, 89, 8, 65, 7, 65, 1, 49, 5, 91, 2, 11, 
    0, 87, 7, 50, 2, 23, 5,  4, 8,  5, 4, 67, 6, 60, 1, 43, 3, 82
  };
  const int q3428[] = {
    9, 9, // Number of jobs and machines
    2, 16, 3,  8, 4, 99, 1, 15, 5, 97, 8, 96, 7, 51, 6, 28, 0, 62, 
    8, 84, 1, 54, 3, 87, 0, 28, 4, 86, 6, 78, 2, 86, 5, 21, 7, 67, 
    2, 14, 1, 42, 3,  2, 5, 23, 6, 87, 4, 77, 8, 66, 7, 68, 0, 86, 
    1, 63, 6, 28, 8, 36, 5, 17, 7,  5, 2, 45, 0, 38, 4, 58, 3, 75, 
    6, 92, 2, 44, 8, 99, 0, 83, 4, 33, 5, 15, 7, 33, 1, 73, 3, 91, 
    7, 71, 8, 95, 1, 66, 2, 99, 5, 90, 6, 47, 4, 28, 3, 82, 0, 57, 
    8, 22, 1, 47, 3, 13, 5, 43, 7, 80, 0, 54, 2, 49, 4, 90, 6, 69, 
    4, 57, 8, 48, 6, 96, 0, 86, 7, 16, 1, 36, 3, 37, 2, 19, 5,  3, 
    2, 49, 7, 65, 6,  3, 5, 48, 4, 14, 0, 67, 8, 91, 3, 46, 1, 41
  };
  const int q3429[] = {
    9, 9, // Number of jobs and machines
    1, 64, 2, 81, 5, 62, 3, 15, 0, 67, 7, 88, 4, 68, 6, 77, 8, 85, 
    1, 51, 2, 49, 6, 90, 3, 75, 5, 83, 7, 12, 4, 85, 8, 28, 0, 12, 
    2, 26, 4, 34, 8, 65, 5, 63, 6, 11, 3, 48, 0, 59, 1, 34, 7, 80, 
    8, 13, 0, 39, 4, 97, 2, 28, 3, 27, 5, 52, 1, 93, 7, 15, 6, 69, 
    7,  1, 2, 51, 5, 47, 1, 82, 6, 64, 3, 64, 0, 79, 8, 78, 4, 99, 
    0, 15, 4, 38, 6, 24, 7, 37, 8,  8, 1, 56, 5, 58, 2, 84, 3, 64, 
    3, 71, 7, 35, 0, 15, 5, 69, 1, 24, 8, 59, 6, 66, 4, 47, 2, 86, 
    8, 37, 0, 97, 3, 83, 5, 77, 4, 71, 6,  3, 1, 93, 2, 32, 7, 98, 
    7, 26, 8, 61, 4, 54, 3, 50, 2, 38, 5, 58, 1, 36, 0, 77, 6, 43
  };
  const int q3430[] = {
    9, 9, // Number of jobs and machines
    0, 49, 1, 80, 6, 27, 3, 85, 4, 17, 2,  3, 8, 54, 5, 83, 7, 84, 
    2, 85, 6, 77, 7, 12, 5, 53, 8,  6, 4,  5, 1, 85, 0, 16, 3, 19, 
    6, 25, 1, 29, 7, 44, 5, 68, 2,  4, 3, 20, 4, 69, 8, 76, 0, 92, 
    5, 23, 4, 88, 0, 33, 8, 29, 6, 15, 2, 66, 7, 88, 1, 97, 3, 52, 
    4, 98, 8, 40, 0, 95, 6, 30, 3,  2, 7, 79, 5, 93, 2, 12, 1, 55, 
    4, 66, 2, 56, 7, 17, 6,  9, 5, 29, 0, 46, 1, 29, 8, 19, 3, 49, 
    8, 52, 0, 55, 6, 15, 3, 30, 5,  4, 4, 46, 1, 70, 7,  9, 2,  7, 
    7, 77, 5, 54, 2, 24, 1, 32, 3, 25, 6, 44, 0, 71, 4, 81, 8, 64, 
    8, 60, 0, 88, 2, 63, 6, 36, 4, 49, 1, 41, 5, 83, 3, 20, 7, 85
  };
  const int q3431[] = {
    9, 9, // Number of jobs and machines
    3, 79, 4, 30, 1, 41, 2, 34, 6, 28, 8, 52, 5, 25, 0, 72, 7, 68, 
    6, 80, 0, 50, 1, 44, 4, 20, 7, 50, 5,  5, 2, 11, 3, 15, 8, 81, 
    6, 85, 2, 10, 4, 81, 0, 21, 5, 42, 3, 77, 1, 21, 8, 46, 7, 68, 
    8, 72, 0, 46, 4, 61, 2, 52, 5, 53, 1,  6, 3, 21, 6,  1, 7, 41, 
    0, 99, 5, 66, 8, 44, 1, 95, 7,  8, 2,  8, 6, 74, 3, 15, 4, 50, 
    0, 20, 6, 26, 1,  2, 8, 82, 7, 77, 5, 70, 4, 33, 2, 71, 3,  2, 
    2, 81, 6, 65, 8, 67, 5, 47, 3,  1, 0, 60, 7, 15, 4, 97, 1, 52, 
    3, 13, 7,  1, 5, 17, 1,  4, 0,  5, 6, 72, 2, 65, 8, 86, 4, 26, 
    5,  5, 6, 55, 8,  8, 7, 54, 1,  1, 0, 29, 3, 40, 4, 10, 2, 60
  };
  const int q3432[] = {
    9, 9, // Number of jobs and machines
    2, 61, 4, 42, 1, 23, 5, 50, 0,  9, 6, 27, 7, 87, 3, 76, 8, 57, 
    3, 72, 0, 86, 4, 82, 7, 69, 2,  8, 1, 42, 5, 77, 8,  6, 6, 64, 
    7, 79, 6, 43, 5, 46, 2, 35, 4, 89, 0, 53, 1, 97, 3,  9, 8, 72, 
    0, 12, 4, 88, 1, 51, 7, 76, 2, 20, 8, 85, 3, 21, 6, 95, 5, 60, 
    0, 54, 1,  3, 3, 94, 7, 29, 8, 20, 5, 31, 2, 92, 4, 69, 6, 40, 
    5, 67, 2, 80, 6, 47, 8, 59, 4, 71, 3, 83, 1, 28, 0,  4, 7, 84, 
    6, 83, 8, 21, 4, 46, 5, 31, 0, 10, 7, 84, 3, 99, 2, 95, 1, 77, 
    8,  2, 3, 84, 7, 63, 6, 28, 0, 51, 2, 97, 5, 10, 1, 17, 4, 72, 
    2, 84, 0, 47, 6, 68, 1, 85, 8, 23, 4, 65, 7, 46, 5, 97, 3, 78
  };
  const int q3433[] = {
    9, 9, // Number of jobs and machines
    0,  9, 6, 39, 3, 14, 2, 94, 4, 64, 7, 96, 1, 73, 8, 43, 5, 47, 
    0, 74, 3, 70, 7, 42, 8, 40, 5,  4, 6, 75, 2, 16, 4, 91, 1, 15, 
    0,  3, 6, 82, 4, 38, 5,  9, 2, 40, 1, 12, 8, 79, 3, 50, 7, 42, 
    8, 34, 4, 33, 6, 44, 1, 84, 0, 60, 3, 59, 2, 79, 5, 38, 7, 99, 
    5, 23, 6, 99, 1, 34, 4, 89, 2, 98, 8, 21, 0, 80, 3, 65, 7, 67, 
    7,  7, 2, 86, 3, 85, 4, 69, 8, 27, 1, 56, 5,  3, 6, 87, 0, 85, 
    8, 87, 7, 21, 4, 94, 1, 15, 3, 16, 2, 70, 6,  9, 0, 12, 5, 11, 
    8, 25, 1, 59, 4, 92, 6,  3, 3,  1, 0, 50, 7, 59, 2, 87, 5, 53, 
    7, 59, 3, 29, 2, 39, 1, 52, 5, 51, 6,  2, 0, 73, 8, 61, 4, 79
  };
  const int q3434[] = {
    9, 9, // Number of jobs and machines
    7, 86, 1, 75, 3,  2, 2, 19, 4, 14, 8, 76, 0, 32, 5, 35, 6, 39, 
    8, 61, 6, 55, 0, 28, 1, 33, 7, 51, 4, 78, 2, 21, 3, 37, 5, 64, 
    6, 21, 2, 19, 8, 74, 4, 98, 7, 23, 5, 47, 1, 27, 0, 26, 3, 47, 
    8, 61, 6, 56, 2, 56, 3, 97, 4, 52, 0, 71, 5, 36, 1, 41, 7, 89, 
    2, 45, 7,  8, 8, 61, 1, 42, 4, 69, 0, 55, 5, 53, 6, 91, 3, 88, 
    5, 54, 0, 39, 6, 77, 1, 52, 7,  5, 3, 36, 8,  7, 4,  6, 2, 53, 
    1, 17, 5, 92, 8, 69, 6, 62, 7, 42, 4, 93, 3, 86, 0, 75, 2, 25, 
    6, 30, 8, 94, 1, 59, 3, 11, 2, 44, 4,  7, 7, 55, 0, 52, 5, 19, 
    1, 86, 2, 82, 5, 46, 7, 25, 8, 69, 0, 95, 4, 61, 6, 42, 3, 55
  };
  const int q3435[] = {
    9, 9, // Number of jobs and machines
    1, 15, 6, 33, 5, 28, 0, 28, 2, 58, 3,  9, 4, 33, 7, 98, 8, 41, 
    7, 27, 6, 99, 3,  3, 4, 22, 8, 46, 2, 21, 0, 51, 5, 39, 1, 22, 
    7, 71, 0,  7, 1, 80, 3, 81, 5,  8, 2, 57, 4, 46, 6,  2, 8, 52, 
    5, 53, 2, 49, 1, 60, 6, 29, 7, 34, 3, 14, 4, 42, 0, 49, 8, 20, 
    0, 90, 7,  3, 3, 23, 1, 38, 5, 44, 4, 34, 6, 88, 8, 70, 2, 91, 
    8, 25, 5, 38, 2, 64, 7, 82, 3, 18, 4,  1, 1, 10, 6,  8, 0, 64, 
    5, 25, 1, 16, 7, 98, 4, 92, 6, 61, 8, 72, 2, 73, 0, 33, 3, 75, 
    2, 72, 5, 98, 0, 47, 1, 20, 8, 28, 3, 13, 7,  2, 6, 96, 4, 66, 
    5, 37, 2, 72, 0, 59, 1, 76, 4, 10, 8,  3, 7, 25, 6, 19, 3, 37
  };
  const int q3436[] = {
    9, 9, // Number of jobs and machines
    4, 68, 3, 25, 2, 51, 1, 92, 5, 31, 8, 13, 7, 63, 0,  6, 6,  9, 
    8, 82, 3, 73, 1, 76, 4, 55, 5, 48, 2, 48, 0, 65, 7, 63, 6, 61, 
    5, 47, 3, 56, 8, 98, 6, 13, 0, 65, 2, 66, 1, 74, 7, 50, 4, 65, 
    3, 70, 7, 44, 5, 62, 1, 46, 6,  9, 8,  6, 0, 71, 2, 26, 4, 59, 
    7, 87, 6,  6, 8, 27, 4, 59, 5, 39, 2, 48, 0, 95, 3, 64, 1, 26, 
    8, 59, 6,  4, 5, 49, 2, 45, 4, 13, 1, 26, 3, 51, 7, 47, 0, 55, 
    8, 52, 7, 70, 6, 53, 1, 23, 0,  9, 5, 13, 2,  3, 3, 45, 4, 92, 
    1, 30, 5,  6, 6, 44, 7, 45, 0, 59, 8, 61, 2, 77, 4, 85, 3, 66, 
    2, 40, 4, 11, 7, 89, 8, 23, 3, 73, 5, 27, 1, 69, 0, 49, 6, 15
  };
  const int q3437[] = {
    9, 9, // Number of jobs and machines
    5,  6, 0, 78, 7, 10, 3, 37, 2, 25, 4, 55, 6, 91, 1, 49, 8, 99, 
    2, 64, 7, 93, 8, 74, 4, 84, 3, 44, 5, 89, 1, 67, 0,  5, 6, 27, 
    4, 63, 8, 42, 3, 16, 0, 69, 6, 61, 2, 18, 1, 47, 7, 95, 5, 29, 
    4, 66, 5,  9, 6,  3, 3, 53, 8,  5, 7, 82, 2, 89, 1, 72, 0, 70, 
    2, 93, 5, 13, 1, 36, 8, 55, 4, 32, 6, 68, 3, 84, 7, 58, 0, 15, 
    1, 84, 7, 87, 3, 79, 5, 63, 8, 56, 4,  4, 0, 23, 2, 52, 6, 47, 
    1, 32, 7, 20, 2, 46, 5, 75, 4, 87, 8, 33, 3, 78, 0, 39, 6, 25, 
    1, 36, 4, 90, 5, 14, 7, 25, 3, 53, 6, 35, 2, 82, 0, 72, 8, 36, 
    6, 10, 8, 97, 0, 73, 1, 58, 3, 93, 2, 26, 7, 80, 4, 10, 5,  5
  };
  const int q3438[] = {
    9, 9, // Number of jobs and machines
    5, 21, 3,  1, 8, 79, 7, 87, 2, 50, 1, 60, 0, 20, 4, 72, 6, 50, 
    3, 11, 0, 81, 2, 28, 7, 59, 4, 74, 6, 37, 8, 57, 1,  2, 5, 70, 
    3, 15, 8, 38, 2,  3, 0, 93, 4, 77, 6, 50, 5, 53, 1, 83, 7, 17, 
    8, 59, 0,  9, 5, 31, 3, 23, 1, 91, 7, 23, 6, 41, 2, 56, 4, 90, 
    4, 50, 6, 81, 2, 93, 1, 22, 7, 67, 5, 87, 0, 27, 8, 44, 3, 42, 
    8, 80, 1, 69, 0, 16, 2, 20, 4, 10, 6, 51, 3, 50, 7, 28, 5, 81, 
    6, 92, 2, 47, 3,  6, 5, 75, 1, 15, 0,  4, 8,  6, 4, 20, 7, 16, 
    1, 80, 5, 37, 6, 36, 4, 83, 7,  7, 3,  1, 0, 62, 2, 51, 8, 39, 
    2, 47, 0, 26, 5, 98, 4, 89, 7,  6, 8, 18, 6, 40, 1, 62, 3, 88
  };
  const int q3439[] = {
    9, 9, // Number of jobs and machines
    5, 17, 1, 60, 2, 50, 4, 33, 7, 52, 8, 29, 3, 31, 6, 16, 0, 93, 
    2, 91, 1, 65, 0, 94, 4, 81, 3, 49, 7, 34, 8, 90, 6,  8, 5, 94, 
    0, 72, 7, 76, 3,  1, 6,  3, 2, 15, 5, 57, 8, 32, 4, 41, 1, 90, 
    4, 67, 5, 34, 8,  8, 2, 91, 6, 13, 7, 15, 0, 13, 3, 70, 1, 64, 
    8,  1, 4, 99, 6,  1, 5, 75, 2, 24, 0, 90, 1, 49, 7, 94, 3, 98, 
    8,  2, 6, 28, 4, 85, 5, 91, 0, 33, 7, 14, 2, 12, 1, 86, 3, 81, 
    4, 63, 0, 96, 3, 43, 5, 70, 2,  9, 1, 25, 6, 92, 7, 27, 8, 40, 
    5, 14, 1, 89, 3, 80, 0, 74, 8, 74, 4, 95, 7, 52, 6, 59, 2, 10, 
    2, 22, 3, 16, 1, 65, 7, 68, 6, 92, 5, 74, 8, 94, 0, 95, 4, 65
  };
  const int q3440[] = {
    9, 9, // Number of jobs and machines
    7, 44, 8, 43, 4, 76, 0,  9, 6, 71, 5, 86, 2, 57, 3, 95, 1, 82, 
    5, 26, 0, 29, 8, 43, 2, 78, 3, 32, 4, 45, 1, 83, 7, 26, 6,  9, 
    3, 97, 1, 67, 7, 10, 5, 70, 8, 38, 6, 12, 4, 75, 0, 64, 2,  6, 
    5, 25, 0, 71, 4, 11, 6, 57, 7,  1, 3, 96, 8, 82, 2, 20, 1, 32, 
    2, 97, 5, 32, 7, 65, 0, 18, 3, 97, 4, 72, 6, 56, 8, 90, 1, 10, 
    6,  5, 5, 72, 2, 54, 0, 99, 8,  8, 1, 35, 7,  9, 3, 99, 4, 53, 
    8, 58, 0, 23, 1, 23, 4, 25, 2, 43, 6, 21, 5, 54, 7, 81, 3, 37, 
    1, 78, 4, 69, 6, 17, 7, 20, 5, 68, 0, 80, 8, 91, 3, 22, 2, 33, 
    8, 16, 5, 72, 7, 32, 3, 98, 6, 42, 1, 95, 2, 55, 4, 32, 0, 47
  };
  const int q3441[] = {
    9, 9, // Number of jobs and machines
    1, 61, 3, 82, 0, 68, 6, 82, 5, 62, 7, 50, 2, 46, 4, 79, 8, 36, 
    6, 51, 3, 90, 1, 74, 8, 18, 7, 97, 0,  7, 4, 26, 5,  2, 2, 79, 
    5, 53, 1, 87, 2, 65, 0, 67, 6, 15, 3, 11, 7, 72, 4, 69, 8, 25, 
    5,  7, 8, 95, 1, 20, 0, 26, 2, 74, 7, 63, 6, 52, 3, 71, 4, 16, 
    0, 89, 1, 77, 5, 49, 3, 17, 6, 19, 2, 60, 4, 76, 7, 14, 8, 26, 
    8, 56, 5, 49, 0,  6, 4, 96, 7, 10, 6, 13, 2, 84, 3, 63, 1, 69, 
    7, 45, 8, 62, 6, 41, 3, 44, 1, 97, 2, 10, 0, 94, 5, 55, 4, 19, 
    1, 75, 7, 53, 3, 48, 5, 88, 2, 14, 6, 66, 0, 78, 4, 88, 8, 56, 
    8, 91, 7, 99, 1, 30, 4, 76, 6, 71, 0, 11, 5, 10, 3, 22, 2, 33
  };
  const int q3442[] = {
    9, 9, // Number of jobs and machines
    1,  5, 3, 13, 6, 30, 4, 75, 8, 82, 5, 58, 2, 70, 7, 75, 0, 34, 
    8, 20, 5, 26, 6, 26, 7, 46, 2, 30, 1, 66, 0, 66, 3, 78, 4, 53, 
    5, 92, 3, 88, 6, 51, 0,  5, 7, 56, 8, 87, 2, 56, 1, 54, 4, 60, 
    0, 51, 6, 34, 7, 80, 2, 70, 8, 52, 3, 15, 4, 30, 5, 76, 1, 50, 
    3, 65, 1, 13, 6, 84, 7, 45, 0, 36, 4, 10, 5, 45, 8, 29, 2, 81, 
    8, 82, 5, 66, 2, 29, 7, 37, 3, 21, 6, 32, 4, 45, 1, 36, 0,  5, 
    0, 87, 1, 91, 2, 48, 3, 88, 8, 31, 7, 90, 6, 21, 5, 58, 4, 98, 
    4, 39, 0, 66, 7, 79, 2, 72, 6, 27, 1, 59, 8, 28, 5, 18, 3, 73, 
    1, 93, 2, 50, 4, 13, 3, 53, 8, 67, 7, 42, 6, 50, 5, 49, 0, 11
  };
  const int q3443[] = {
    9, 9, // Number of jobs and machines
    2, 92, 3, 63, 4,  2, 6, 14, 5, 36, 1, 88, 7, 50, 0, 49, 8, 89, 
    6, 18, 3, 49, 8, 89, 0, 83, 5, 98, 4, 51, 1, 61, 2, 89, 7, 65, 
    7, 64, 4, 64, 3, 68, 8, 31, 5, 46, 1, 33, 2, 62, 6, 62, 0, 47, 
    5, 45, 0, 30, 3, 46, 1, 18, 2, 21, 8, 79, 7, 28, 6, 35, 4, 43, 
    0, 37, 2, 30, 6, 49, 4, 44, 1, 24, 8, 58, 7, 10, 3, 99, 5,  1, 
    3, 94, 6, 93, 2, 97, 7, 88, 4, 32, 1, 18, 5, 67, 8, 90, 0, 37, 
    7, 74, 1, 17, 0, 78, 4, 90, 6, 43, 2, 69, 5, 87, 8,  4, 3, 10, 
    5, 46, 3, 18, 6, 99, 8, 39, 7, 97, 0, 25, 4, 53, 2, 12, 1, 59, 
    0, 53, 4, 61, 3,  9, 2, 26, 8, 26, 5, 36, 1, 87, 6, 81, 7, 96
  };
  const int q3444[] = {
    9, 9, // Number of jobs and machines
    0, 74, 4, 91, 1, 49, 3, 77, 5, 55, 8, 94, 7, 77, 2, 32, 6, 54, 
    6,  3, 7, 18, 5, 99, 1,  6, 8,  4, 3, 94, 0, 20, 4, 59, 2, 51, 
    0, 92, 6, 53, 5, 54, 8, 49, 7, 32, 3, 86, 2,  1, 4, 10, 1,  6, 
    4, 44, 8, 34, 5, 57, 6, 27, 7, 23, 3, 70, 0, 81, 1, 67, 2, 82, 
    6, 20, 7, 73, 4, 97, 0, 77, 1, 59, 5, 65, 3, 84, 8, 21, 2, 48, 
    5, 32, 0, 21, 2,  4, 1,  3, 4, 93, 3, 83, 6, 81, 7, 80, 8, 91, 
    4, 52, 3, 19, 5, 12, 1, 53, 7, 93, 6, 37, 2,  8, 0, 74, 8, 85, 
    6, 10, 1, 30, 7, 62, 4, 48, 2, 34, 3, 18, 0, 12, 8, 94, 5, 44, 
    8, 66, 6, 54, 2, 10, 1, 71, 4, 43, 0, 58, 3, 63, 5, 36, 7, 61
  };
  const int q3445[] = {
    9, 9, // Number of jobs and machines
    7, 90, 5,  2, 0, 95, 6, 58, 8, 38, 1, 55, 4, 54, 2, 19, 3, 30, 
    4, 70, 0, 76, 3, 59, 1,  7, 7, 25, 2, 72, 8, 82, 5, 17, 6,  4, 
    8, 28, 2, 80, 0, 80, 5, 36, 3, 93, 4, 90, 1, 67, 6, 91, 7, 27, 
    7, 16, 5, 66, 8, 44, 0,  5, 3, 61, 1, 34, 6, 47, 2, 19, 4, 13, 
    5,  4, 3, 40, 1,  9, 8, 71, 7, 29, 2, 31, 6, 71, 0, 94, 4,  9, 
    3,  3, 7, 49, 6, 16, 4, 84, 5, 28, 2, 56, 0, 26, 8, 19, 1, 51, 
    7, 97, 8, 24, 0,  4, 2, 56, 5, 66, 3, 93, 1, 97, 4, 88, 6, 31, 
    7, 98, 0, 27, 1, 60, 8, 59, 4, 29, 5, 87, 6, 41, 3, 63, 2, 90, 
    2, 59, 6, 60, 1, 62, 3, 55, 8, 93, 5, 38, 4, 99, 7, 38, 0, 51
  };
  const int q3446[] = {
    9, 9, // Number of jobs and machines
    2, 46, 6, 64, 0,  6, 1, 24, 5, 10, 8, 88, 3, 19, 4,  1, 7, 15, 
    3, 64, 5, 58, 7, 38, 4, 16, 6, 14, 8, 68, 1,  2, 2, 36, 0, 81, 
    1, 92, 0, 82, 4, 66, 2, 88, 6, 72, 7, 15, 5, 94, 3, 35, 8, 75, 
    2, 34, 8, 88, 7, 39, 1, 46, 0, 99, 4, 68, 3, 37, 5, 76, 6,  4, 
    7, 94, 8, 73, 6, 66, 3, 56, 1, 38, 0, 49, 2, 38, 5, 22, 4, 19, 
    0,  2, 5, 72, 3, 32, 6, 18, 8, 80, 4, 13, 1, 78, 2, 39, 7, 24, 
    3,  7, 5, 70, 4, 46, 6, 98, 7, 60, 2, 29, 0, 41, 8, 92, 1, 38, 
    3, 95, 5, 79, 1, 87, 2, 23, 7,  6, 8, 72, 0, 80, 6, 46, 4, 35, 
    2, 21, 6, 42, 7, 29, 0, 43, 1, 54, 5, 50, 4, 61, 8,  8, 3, 98
  };
  const int q3447[] = {
    9, 9, // Number of jobs and machines
    6, 48, 7, 32, 0, 86, 2, 35, 8, 41, 5, 19, 3, 76, 1, 36, 4, 42, 
    3, 63, 1, 12, 0, 54, 6, 77, 8, 54, 4, 61, 2, 35, 7, 66, 5, 75, 
    3, 50, 5, 11, 7, 50, 2, 84, 6, 11, 4, 52, 1,  9, 8, 35, 0, 25, 
    6,  6, 7, 89, 5, 65, 2, 95, 1, 18, 8, 72, 0, 94, 3, 97, 4, 37, 
    0, 86, 1, 65, 2, 54, 4, 82, 7, 93, 5, 16, 8, 65, 3, 54, 6, 20, 
    3, 33, 0, 90, 1, 46, 8, 82, 2, 79, 7, 72, 4,  1, 6, 59, 5, 16, 
    5, 45, 6, 97, 8, 70, 2, 34, 3, 71, 4,  7, 0, 73, 7,  1, 1, 77, 
    7, 96, 6, 64, 4, 67, 0, 54, 8, 40, 3, 19, 5, 71, 1, 36, 2, 69, 
    1,  1, 6,  9, 5, 85, 8, 75, 3, 53, 2, 50, 7, 10, 0, 41, 4, 57
  };
  const int q3448[] = {
    9, 9, // Number of jobs and machines
    4, 36, 7, 79, 0,  8, 5, 99, 3, 64, 6, 89, 8, 71, 2, 18, 1, 77, 
    5, 33, 2, 83, 8, 32, 7, 93, 3, 63, 1, 78, 0,  7, 6, 91, 4, 81, 
    5, 30, 7,  1, 1, 78, 4, 66, 6, 99, 0, 31, 8, 13, 3, 81, 2, 12, 
    5, 42, 7, 50, 2,  9, 6,  9, 1, 64, 8, 42, 3,  2, 0, 64, 4, 95, 
    2, 98, 7, 19, 0, 95, 1, 79, 3,  9, 5, 60, 4, 76, 6,  3, 8, 86, 
    8, 45, 1, 70, 0, 63, 7, 10, 6, 24, 5, 35, 2, 85, 3, 90, 4, 50, 
    3, 89, 5, 41, 7, 63, 1, 27, 8, 18, 0, 94, 4, 45, 2, 25, 6, 75, 
    3, 85, 7, 34, 4, 45, 2, 98, 8, 86, 6, 34, 1, 40, 5, 65, 0, 12, 
    6,  9, 1,  8, 0, 80, 4,  5, 8, 14, 3,  5, 7, 53, 5, 44, 2, 94
  };
  const int q3449[] = {
    9, 9, // Number of jobs and machines
    3, 46, 2, 44, 4, 10, 8, 69, 7, 15, 0, 80, 6, 80, 1, 89, 5, 74, 
    2, 74, 0, 91, 6, 12, 3, 67, 7, 63, 4, 17, 5,  9, 1, 15, 8, 61, 
    8, 84, 6, 82, 1, 93, 0,  9, 2, 45, 7, 88, 5, 56, 3, 46, 4, 74, 
    4, 64, 2, 80, 7, 24, 6, 66, 3,  1, 5, 99, 0, 25, 8, 10, 1, 83, 
    6, 47, 0, 90, 4, 52, 2, 51, 3, 83, 5, 19, 1, 47, 8, 18, 7, 32, 
    6, 59, 3, 40, 4, 44, 1, 47, 7, 74, 5, 32, 0,  2, 2, 59, 8, 15, 
    0, 32, 4, 64, 3, 42, 7, 20, 2, 56, 1, 72, 5, 17, 6, 23, 8, 57, 
    1,  5, 6, 40, 4, 65, 2, 15, 5, 46, 8, 55, 3, 46, 7, 86, 0, 15, 
    8, 93, 6, 26, 3, 98, 5, 54, 7, 85, 0,  2, 4, 89, 2, 73, 1, 88
  };
  const int q3450[] = {
    9, 9, // Number of jobs and machines
    5, 38, 8, 23, 1, 66, 7, 11, 3, 54, 4, 77, 2, 23, 6, 71, 0, 41, 
    5, 81, 1, 90, 4, 41, 7, 72, 8, 25, 3, 43, 2, 49, 0, 90, 6, 75, 
    6, 17, 2, 96, 3, 17, 0, 79, 8, 29, 1, 76, 7, 75, 5, 42, 4, 28, 
    0, 69, 5,  6, 7, 40, 8,  8, 1, 90, 4, 18, 6, 53, 2, 10, 3,  6, 
    0, 63, 1, 84, 5,  3, 7, 79, 3, 87, 4, 45, 2, 18, 6, 73, 8, 36, 
    8, 89, 6, 32, 4,  8, 2, 57, 7, 79, 3, 96, 1,  8, 0, 71, 5,  2, 
    7,  5, 2, 19, 3, 24, 8, 49, 6, 72, 1, 58, 0, 50, 5,  2, 4, 50, 
    1, 14, 2, 73, 6,  5, 5, 37, 7, 99, 4, 71, 0, 68, 3, 98, 8, 88, 
    1, 44, 2, 29, 6, 49, 3, 80, 7, 96, 8, 91, 5, 50, 4, 86, 0, 16
  };
  const int q3451[] = {
    9, 9, // Number of jobs and machines
    1, 47, 7, 43, 3, 34, 5, 23, 8, 77, 4, 84, 0, 31, 2, 51, 6, 81, 
    8, 39, 3, 74, 1, 51, 2,  5, 6, 76, 4, 44, 7, 12, 5, 11, 0, 52, 
    4, 68, 0, 25, 1, 87, 8, 80, 3,  5, 2, 28, 5, 18, 6, 14, 7, 61, 
    5, 47, 8, 30, 1,  9, 0, 68, 4, 51, 7, 91, 2, 69, 6, 67, 3, 57, 
    8, 55, 4, 95, 2, 83, 0, 96, 3, 93, 1, 53, 7, 68, 6, 59, 5, 12, 
    7, 54, 2, 52, 1, 32, 3,  4, 0, 84, 4, 29, 6, 46, 5, 19, 8, 83, 
    5,  5, 3, 37, 2,  9, 6, 48, 0, 59, 4, 66, 1, 90, 7, 38, 8,  6, 
    3, 44, 2, 56, 8, 48, 1, 86, 4, 36, 7, 79, 5, 30, 6, 38, 0,  9, 
    6, 29, 8,  1, 4, 92, 5, 34, 0, 29, 3, 38, 1, 78, 2, 92, 7, 76
  };
  const int q3452[] = {
    9, 9, // Number of jobs and machines
    3, 15, 1, 59, 8, 29, 7, 78, 0,  5, 6, 36, 4, 50, 2, 25, 5, 38, 
    2, 34, 6, 81, 0, 97, 5, 65, 8, 89, 1, 38, 3, 68, 4, 64, 7, 99, 
    6,  7, 1,  1, 8, 28, 4,  2, 2, 97, 7, 59, 5, 87, 3,  8, 0,  3, 
    3, 21, 4,  5, 0, 87, 1, 82, 2,  1, 8, 59, 6, 18, 5, 40, 7, 80, 
    7, 51, 3, 47, 6, 21, 5, 56, 8, 24, 1, 12, 4,  6, 2, 38, 0, 51, 
    1, 37, 8, 29, 4, 71, 2, 88, 3, 61, 7, 66, 6, 86, 5, 90, 0, 17, 
    0, 57, 1, 25, 4, 85, 8, 26, 6, 46, 7, 38, 3, 93, 5, 74, 2, 22, 
    6, 59, 8, 99, 5, 51, 1, 77, 2,  1, 7, 13, 0, 87, 4, 99, 3, 23, 
    2, 87, 7, 47, 3, 63, 1, 17, 5, 99, 4, 50, 8,  5, 6, 58, 0, 69
  };
  const int q3453[] = {
    9, 9, // Number of jobs and machines
    8, 39, 6, 52, 1, 22, 2, 27, 3, 29, 5, 58, 0, 24, 4, 61, 7, 80, 
    2,  4, 5, 70, 8, 55, 6, 16, 7, 17, 4, 21, 0, 13, 1,  4, 3, 41, 
    8, 48, 5, 32, 4, 32, 0, 24, 1, 16, 3, 52, 2, 97, 6, 35, 7, 29, 
    4, 77, 2, 60, 1, 71, 6, 97, 0, 26, 5, 53, 8, 45, 7, 37, 3, 43, 
    6, 41, 7, 24, 1, 88, 4, 36, 0,  2, 2, 61, 5, 97, 8, 99, 3, 56, 
    5, 33, 8, 64, 0, 51, 4, 58, 7, 48, 3, 42, 2,  4, 6, 12, 1, 98, 
    8, 37, 6,  2, 0, 25, 7, 25, 3, 71, 5, 82, 1, 47, 4, 50, 2, 52, 
    2, 93, 6,  3, 7, 15, 1, 65, 0, 83, 3, 88, 4, 17, 5, 63, 8, 23, 
    8, 98, 4, 94, 1, 28, 3, 99, 7, 60, 0, 10, 5, 47, 2, 87, 6, 70
  };
  const int q3454[] = {
    9, 9, // Number of jobs and machines
    0, 12, 2, 31, 6, 50, 3, 73, 8, 67, 7, 57, 1, 89, 4, 27, 5, 78, 
    5, 83, 0, 24, 2, 65, 7, 47, 6, 62, 4, 76, 3, 68, 8, 17, 1, 96, 
    4, 63, 0, 72, 3, 14, 1, 53, 5, 61, 8, 32, 2, 88, 6, 80, 7, 28, 
    7, 46, 3, 93, 1, 51, 4, 82, 2, 35, 6, 92, 5, 81, 0, 16, 8, 96, 
    2, 50, 5, 30, 7,  5, 0, 19, 1, 64, 3, 50, 8, 52, 4, 67, 6, 55, 
    2, 40, 8, 12, 3, 18, 6, 33, 4, 62, 5, 99, 1, 32, 0, 19, 7,  1, 
    7, 28, 3, 16, 8, 61, 0, 76, 1, 67, 4, 60, 2, 22, 6,  3, 5, 74, 
    5,  7, 4,  6, 3, 25, 6, 39, 1, 83, 0, 12, 8, 35, 2, 69, 7, 48, 
    4, 35, 5,  3, 6, 75, 3, 57, 1, 95, 2, 61, 7, 57, 8, 22, 0, 61
  };
  const int q3455[] = {
    9, 9, // Number of jobs and machines
    2, 37, 8, 25, 1,  4, 6, 54, 7, 14, 5, 10, 3, 75, 4, 77, 0, 61, 
    3, 23, 5, 77, 4, 75, 2, 70, 8, 73, 0,  6, 1, 60, 7, 86, 6, 28, 
    3, 66, 8,  3, 7, 36, 5, 68, 2, 32, 1, 86, 6,  4, 0,  7, 4, 61, 
    7, 78, 6, 85, 8, 16, 3, 13, 0, 31, 1, 27, 4, 20, 2, 77, 5,  4, 
    4, 31, 8, 30, 5,  9, 6, 36, 2,  4, 7,  4, 1, 85, 0, 26, 3, 82, 
    3, 92, 2, 26, 4,  8, 7, 27, 0, 57, 6, 71, 1, 79, 8, 38, 5, 25, 
    0, 51, 5, 63, 1, 97, 4, 89, 2, 19, 7,  6, 8, 54, 6, 87, 3, 67, 
    3, 21, 4,  3, 8, 47, 1, 34, 5, 15, 7, 16, 2, 31, 6, 17, 0, 60, 
    8, 80, 7, 73, 1, 40, 2, 20, 3, 92, 4, 86, 0, 59, 5, 93, 6, 40
  };
  const int q3456[] = {
    9, 9, // Number of jobs and machines
    8, 82, 6, 21, 7, 20, 2, 52, 1, 81, 5, 47, 0, 10, 4, 71, 3, 46, 
    4, 89, 0, 16, 6, 26, 5, 30, 7, 86, 1,  3, 2, 15, 8, 64, 3, 95, 
    5, 62, 2, 53, 1, 59, 4, 47, 3, 45, 0, 19, 6, 50, 8, 12, 7, 42, 
    3, 14, 5,  6, 8,  5, 6, 29, 1, 62, 7, 59, 0, 56, 2, 42, 4, 22, 
    5, 25, 6, 18, 4,  4, 2, 91, 0, 78, 3, 51, 8, 96, 1, 33, 7, 96, 
    6, 53, 0, 48, 1, 29, 7,  6, 8, 21, 3, 69, 4, 91, 5, 24, 2, 60, 
    5, 10, 8, 31, 2, 73, 3, 94, 1, 13, 7, 93, 4, 83, 6, 96, 0, 83, 
    3,  3, 1, 45, 5, 84, 7, 19, 4,  6, 0, 65, 6,  4, 8, 45, 2, 43, 
    7, 77, 4, 45, 2, 92, 6,  3, 1, 94, 0, 29, 8, 50, 5, 50, 3, 33
  };
  const int q3457[] = {
    9, 9, // Number of jobs and machines
    7, 87, 2, 64, 6, 43, 0, 41, 5, 30, 3, 38, 1, 56, 8, 37, 4, 88, 
    6, 58, 4, 70, 3, 18, 0, 69, 8, 16, 7, 66, 2, 74, 5, 28, 1, 42, 
    4, 26, 2, 64, 0, 30, 1, 99, 8, 87, 5, 18, 7, 98, 3,  8, 6, 40, 
    7, 68, 2, 43, 0, 76, 3, 41, 6,  4, 1, 81, 5, 23, 4, 46, 8, 73, 
    5, 94, 6,  3, 7, 94, 2, 65, 0, 90, 4, 21, 8, 67, 3, 63, 1, 19, 
    0, 26, 2, 48, 1, 40, 7, 17, 5, 66, 3, 17, 6, 86, 8, 90, 4, 29, 
    3, 15, 1, 44, 4, 59, 2, 38, 6, 31, 7, 23, 5, 57, 0, 44, 8, 37, 
    4, 42, 8, 76, 5, 38, 6, 62, 1, 63, 2, 87, 0, 71, 3, 28, 7, 46, 
    7, 24, 1, 75, 4, 52, 3, 41, 6, 56, 8, 54, 5, 76, 2, 56, 0, 30
  };
  const int q3458[] = {
    9, 9, // Number of jobs and machines
    4, 10, 2, 77, 8, 23, 0, 28, 6, 47, 3, 29, 7, 14, 5, 34, 1, 38, 
    3, 62, 7, 28, 2, 72, 4, 71, 6, 32, 8, 66, 5, 37, 0,  5, 1, 31, 
    4, 18, 1, 50, 3, 33, 2, 99, 7, 89, 0,  1, 8, 16, 6, 37, 5, 39, 
    8, 25, 1, 78, 4, 28, 0, 62, 3, 29, 6, 59, 5, 91, 2, 50, 7, 65, 
    8, 42, 1,  7, 3, 29, 5, 77, 2, 75, 6, 68, 4, 30, 0, 46, 7, 20, 
    6, 98, 0,  3, 8, 39, 4, 62, 3, 26, 7, 66, 2, 66, 5, 66, 1, 62, 
    4, 75, 3, 49, 1, 93, 8,  7, 2, 89, 6,  8, 5, 78, 0,  3, 7, 70, 
    5, 35, 2, 33, 1, 73, 4, 82, 8, 29, 3, 63, 7, 53, 6, 89, 0, 64, 
    8, 44, 4, 33, 2, 58, 6, 31, 3, 17, 1, 52, 7, 66, 5, 22, 0, 75
  };
  const int q3459[] = {
    9, 9, // Number of jobs and machines
    6, 45, 8, 90, 2, 87, 3, 66, 7, 45, 5, 64, 0,  3, 1, 44, 4, 30, 
    5, 45, 1, 11, 2, 31, 8, 13, 0, 65, 4, 62, 3, 30, 7, 14, 6, 63, 
    3, 97, 1, 57, 2, 45, 6, 41, 0, 76, 5, 25, 7, 74, 4, 64, 8, 99, 
    7, 53, 3, 57, 6, 14, 8, 44, 2, 93, 5, 64, 1, 65, 4, 78, 0, 14, 
    0, 64, 5, 29, 6, 94, 7, 96, 1, 98, 8, 74, 4, 46, 3, 24, 2,  8, 
    7, 87, 8, 56, 5,  1, 4, 74, 3, 99, 0, 15, 6,  8, 1, 77, 2, 63, 
    5, 89, 8, 41, 3, 45, 4, 49, 7, 58, 0, 48, 2, 82, 6, 91, 1,  5, 
    5,  1, 2, 29, 4, 38, 0, 42, 6, 79, 7, 64, 1, 12, 3, 79, 8, 11, 
    0, 26, 2, 65, 8, 31, 6, 91, 7, 58, 5, 15, 4, 44, 1, 55, 3, 69
  };
  const int q3460[] = {
    9, 9, // Number of jobs and machines
    0, 28, 2,  2, 1, 37, 5, 21, 7, 17, 3, 13, 6, 54, 4, 58, 8, 54, 
    4,  1, 6, 19, 0, 79, 2, 63, 7, 51, 1,  7, 8, 29, 5, 40, 3, 26, 
    0, 11, 4,  5, 8, 62, 1, 10, 7, 80, 3, 76, 2, 34, 6, 15, 5,  2, 
    2, 75, 5, 75, 4, 52, 0, 86, 7, 56, 1, 65, 6, 13, 8, 53, 3, 62, 
    7, 37, 1, 27, 2, 26, 5, 23, 6, 50, 4, 81, 0, 62, 3, 51, 8, 17, 
    3, 87, 5, 39, 2, 31, 4, 74, 1, 71, 0, 22, 8, 12, 7, 15, 6, 11, 
    5, 77, 8, 17, 6, 83, 3, 59, 2, 57, 4, 51, 1, 40, 0, 48, 7, 51, 
    0, 72, 8, 11, 5, 14, 7, 22, 3, 69, 4,  1, 6, 51, 1, 69, 2, 48, 
    2, 58, 7, 82, 8, 37, 0,  8, 3, 29, 6, 79, 1, 97, 5, 22, 4, 18
  };
  const int q3461[] = {
    9, 9, // Number of jobs and machines
    6,  2, 4, 22, 7, 81, 1,  2, 2, 72, 5, 33, 3, 62, 8, 69, 0, 35, 
    1, 42, 3, 30, 2, 44, 5, 44, 0, 35, 7, 35, 8, 39, 4, 72, 6, 17, 
    2, 11, 8, 94, 4, 39, 6, 87, 3, 97, 1, 65, 7, 34, 0, 29, 5, 56, 
    1, 14, 4, 23, 8, 15, 5, 56, 0, 14, 6, 18, 7, 81, 2, 40, 3, 14, 
    3, 47, 7,  9, 4, 90, 0, 55, 1,  5, 5, 35, 2, 54, 6, 84, 8, 68, 
    7, 60, 3, 84, 6, 76, 0, 79, 8, 47, 4, 72, 1, 85, 5, 72, 2, 50, 
    4, 75, 1, 76, 8, 32, 7, 45, 2, 61, 3, 90, 5,  3, 0, 84, 6, 59, 
    3, 65, 1, 55, 6, 78, 5, 96, 0, 21, 4, 62, 8, 91, 2, 26, 7, 57, 
    4, 25, 0, 47, 1, 77, 5,  3, 3, 18, 6, 66, 2, 39, 8,  9, 7, 84
  };
  const int q3462[] = {
    9, 9, // Number of jobs and machines
    6, 99, 4, 67, 3, 12, 2, 30, 0, 89, 5,  4, 1, 21, 8, 77, 7, 68, 
    6, 26, 5, 41, 3, 78, 1, 48, 7, 47, 2, 30, 4, 84, 0, 52, 8, 54, 
    0, 24, 6, 66, 8, 48, 4, 75, 7, 48, 3, 15, 5, 64, 1, 69, 2, 56, 
    0,  8, 3, 90, 5, 10, 8, 93, 1, 51, 7, 30, 2, 54, 6, 31, 4, 14, 
    3, 98, 6, 82, 2,  6, 0, 26, 7, 52, 1, 58, 4, 81, 5, 10, 8, 98, 
    3, 68, 4, 53, 8, 63, 7, 47, 1, 72, 5, 12, 2, 63, 6, 35, 0, 22, 
    1,  4, 7, 17, 6, 77, 5, 88, 2, 21, 4, 73, 8, 22, 0, 44, 3,  8, 
    7,  7, 8, 60, 3, 64, 1, 37, 0,  1, 4, 82, 6, 52, 2, 99, 5, 47, 
    7, 97, 6, 65, 0, 72, 8,  2, 5, 29, 4, 55, 2, 21, 1, 33, 3, 18
  };
  const int q3463[] = {
    9, 9, // Number of jobs and machines
    3, 42, 8, 45, 7, 15, 4, 66, 5, 98, 6, 45, 0, 52, 2,  1, 1, 37, 
    6, 57, 7, 36, 1,  8, 2, 32, 4, 44, 5, 27, 0, 55, 3, 17, 8, 36, 
    2,  7, 3, 12, 1, 24, 4,  5, 6,  1, 8, 92, 0, 77, 7, 11, 5,  9, 
    5,  9, 0, 96, 1, 14, 8, 66, 6, 25, 7,  9, 4, 17, 2, 46, 3, 43, 
    1, 20, 7, 24, 6, 18, 3, 31, 2, 84, 5, 43, 8, 26, 4, 32, 0, 47, 
    8,  3, 1, 15, 6, 11, 0, 99, 5, 78, 3, 98, 2, 91, 7,  9, 4, 82, 
    0, 65, 7, 38, 1, 74, 4, 51, 3, 89, 2, 65, 5, 75, 8, 18, 6,  2, 
    0, 87, 8, 17, 7, 67, 4, 21, 5, 20, 2,  8, 6, 46, 3, 79, 1, 73, 
    7, 45, 3, 67, 2, 10, 6, 47, 0, 19, 8, 64, 1,  2, 5, 26, 4, 90
  };
  const int q3464[] = {
    9, 9, // Number of jobs and machines
    0, 95, 6, 44, 3, 99, 8, 84, 1, 34, 2, 10, 5,  5, 7, 69, 4, 59, 
    6, 27, 8, 34, 0, 77, 5, 61, 7, 81, 2, 65, 4,  3, 1,  6, 3, 94, 
    2, 73, 0, 24, 3, 50, 6, 56, 4, 89, 5, 54, 8, 27, 7, 67, 1, 65, 
    7, 37, 5,  1, 2, 79, 4, 68, 0, 42, 3, 84, 1, 55, 8, 93, 6, 56, 
    1, 64, 0, 47, 2,  6, 4, 35, 3, 56, 8, 76, 5, 78, 6, 40, 7, 29, 
    6, 42, 3, 84, 0, 48, 2, 64, 8, 67, 7, 79, 5, 86, 1, 24, 4, 28, 
    7, 54, 6, 30, 2,  5, 0, 65, 4, 21, 5, 39, 8, 74, 3, 77, 1, 93, 
    2, 74, 1, 47, 5, 83, 7, 82, 0, 21, 3, 51, 8, 24, 4, 55, 6, 63, 
    1, 31, 5, 90, 2, 97, 7, 88, 0, 75, 8, 68, 3, 30, 4,  9, 6,  4
  };
  const int q3465[] = {
    9, 9, // Number of jobs and machines
    3, 69, 7, 31, 0,  4, 8, 25, 4, 67, 2, 15, 5, 83, 6, 58, 1, 75, 
    2, 59, 5, 43, 1, 21, 0, 92, 8, 63, 4, 73, 6, 95, 3, 79, 7, 22, 
    1,  9, 2, 84, 7, 99, 0,  9, 8, 25, 3,  2, 6, 97, 4, 50, 5, 58, 
    8, 73, 1, 87, 3, 27, 4, 65, 5, 54, 0, 55, 7, 42, 2, 83, 6, 31, 
    7, 18, 0, 72, 5, 17, 6, 24, 8, 50, 2, 48, 3, 80, 4, 89, 1, 45, 
    1, 56, 5, 21, 8, 83, 3, 32, 7, 37, 4, 51, 2, 93, 6, 54, 0, 64, 
    3, 28, 6, 38, 0, 30, 5, 85, 8,  7, 7, 29, 4, 45, 1, 76, 2, 41, 
    7,  9, 0, 81, 2,  2, 6, 31, 5, 16, 4, 77, 3, 35, 1, 54, 8, 39, 
    2, 48, 0, 99, 8, 75, 4, 75, 3,  5, 1, 52, 6, 18, 7, 35, 5, 75
  };
  const int q3466[] = {
    9, 9, // Number of jobs and machines
    6, 91, 4, 17, 0, 23, 7, 36, 8,  7, 1, 23, 5, 99, 2, 58, 3, 22, 
    0, 76, 8, 92, 3, 12, 2, 87, 7, 70, 5, 73, 4, 77, 6, 60, 1, 31, 
    6, 25, 1, 45, 0, 15, 4,  2, 3, 17, 7, 32, 2,  4, 5, 61, 8, 82, 
    0, 30, 2,  3, 1, 74, 4, 39, 3,  6, 7, 84, 6, 44, 8, 37, 5, 98, 
    3,  1, 2, 64, 7, 56, 8, 33, 0, 23, 6, 46, 5, 11, 4, 50, 1, 38, 
    3, 39, 1, 73, 0, 26, 7, 51, 4,  6, 2, 67, 5, 80, 6, 30, 8, 96, 
    1, 91, 0, 17, 5, 18, 6, 87, 4, 63, 7, 76, 2, 89, 8, 87, 3, 74, 
    5, 47, 3, 32, 4, 59, 8, 60, 7, 48, 6, 40, 1, 12, 2,  5, 0, 89, 
    7, 21, 5, 51, 1, 25, 3,  6, 6, 74, 4, 66, 2, 32, 0, 55, 8, 77
  };
  const int q3467[] = {
    9, 9, // Number of jobs and machines
    6, 36, 3, 69, 2, 93, 5, 29, 7,  8, 8, 73, 0, 85, 4, 24, 1, 73, 
    2, 80, 3, 31, 6, 92, 4, 46, 1, 60, 8, 96, 0, 27, 7, 14, 5, 37, 
    5, 33, 3, 22, 4, 92, 8, 33, 2, 74, 0, 92, 6, 25, 7, 90, 1,  7, 
    7, 14, 1, 34, 4, 39, 5,  9, 3, 95, 6, 70, 8, 38, 0,  8, 2, 25, 
    3, 48, 8, 45, 0, 81, 2, 25, 1, 56, 6, 49, 5, 49, 7, 76, 4, 18, 
    4, 90, 5, 92, 6, 20, 0, 35, 8, 55, 7, 16, 3, 68, 2, 46, 1,  7, 
    5, 53, 8, 91, 2, 24, 7, 13, 1, 99, 6, 60, 3, 98, 0, 97, 4, 67, 
    2, 29, 7,  5, 1, 47, 0, 62, 5, 25, 4, 20, 3, 72, 6, 96, 8, 14, 
    7, 76, 2, 24, 6, 56, 5, 12, 1, 91, 8, 38, 4, 48, 0, 37, 3, 45
  };
  const int q3468[] = {
    9, 9, // Number of jobs and machines
    0, 93, 2, 14, 6, 68, 1, 17, 7, 39, 8, 75, 4, 81, 3, 62, 5, 59, 
    5, 66, 2, 30, 8,  9, 0, 10, 1, 42, 3, 81, 4, 53, 7, 87, 6,  7, 
    8, 21, 1, 27, 5, 65, 6, 48, 7, 71, 3, 42, 2, 52, 0, 89, 4, 94, 
    5, 15, 7, 67, 3, 67, 6,  6, 4, 52, 8, 71, 0, 25, 1, 98, 2, 26, 
    7, 52, 1, 78, 2, 17, 8, 48, 4,  2, 3, 47, 6, 14, 0, 78, 5, 55, 
    1,  8, 2, 10, 4, 66, 6, 67, 3, 18, 0, 42, 5, 43, 7, 92, 8, 52, 
    3, 85, 6, 56, 2, 49, 4, 94, 5,  3, 8, 63, 0, 36, 7, 33, 1, 80, 
    3, 33, 7, 41, 4,  6, 1, 66, 8, 34, 5, 86, 0, 76, 2, 10, 6, 75, 
    0, 45, 2, 89, 4, 75, 3, 90, 7, 59, 1, 75, 6, 48, 5, 54, 8, 74
  };
  const int q3469[] = {
    9, 9, // Number of jobs and machines
    3, 76, 4, 61, 7, 84, 6, 78, 2, 38, 0, 86, 5, 40, 8, 61, 1,  3, 
    5, 36, 7, 98, 3, 76, 1, 42, 8, 32, 4, 79, 6, 30, 2, 82, 0, 17, 
    5, 10, 8,  6, 6, 75, 1, 69, 2, 82, 7, 81, 0, 33, 4, 40, 3, 91, 
    1, 84, 6, 58, 0, 69, 2, 71, 7, 84, 8, 34, 4, 13, 3, 96, 5, 56, 
    5, 66, 3,  7, 6, 55, 1, 32, 4, 80, 8,  1, 2,  6, 7, 16, 0, 85, 
    4,  7, 8, 99, 0, 21, 1, 18, 2, 52, 5, 28, 3, 48, 6, 38, 7, 84, 
    3, 39, 8, 82, 5, 19, 6, 34, 4, 49, 1, 94, 0, 47, 2, 79, 7, 73, 
    0, 91, 4,  9, 1, 42, 8, 16, 6, 73, 3, 20, 7, 54, 2, 76, 5, 30, 
    6,  4, 5, 98, 1, 87, 7, 73, 0, 89, 3, 84, 2, 36, 4, 41, 8, 69
  };
  const int q3470[] = {
    9, 9, // Number of jobs and machines
    7, 12, 8, 23, 1, 60, 2, 29, 4, 23, 6, 20, 3, 78, 0, 94, 5, 76, 
    0, 48, 3, 67, 6, 63, 2, 75, 5, 52, 8, 81, 4, 14, 1, 65, 7, 43, 
    7, 56, 5, 16, 4, 63, 1, 32, 8, 16, 6, 64, 0,  2, 2, 88, 3, 68, 
    5, 64, 6, 44, 7, 33, 3, 82, 4, 13, 1, 51, 8, 89, 2, 19, 0, 85, 
    4, 18, 7, 47, 8, 86, 3, 58, 5, 50, 2, 94, 0, 29, 1, 84, 6, 30, 
    2, 13, 6, 59, 8, 83, 3, 10, 0, 48, 7, 15, 4, 88, 1, 74, 5, 65, 
    5, 45, 6, 51, 2, 41, 1, 32, 4, 92, 7, 70, 0, 37, 8,  7, 3, 34, 
    8, 28, 6,  2, 5, 19, 3, 61, 2, 62, 1,  7, 4, 29, 7, 32, 0, 58, 
    7, 16, 8, 10, 1,  8, 6, 24, 2,  9, 0, 48, 3,  6, 5, 37, 4, 61
  };
  const int q3471[] = {
    9, 9, // Number of jobs and machines
    6, 46, 8, 15, 7, 48, 3, 12, 4, 62, 1, 27, 0, 20, 5, 53, 2, 88, 
    3, 98, 8, 92, 0, 35, 2, 43, 1, 72, 6, 95, 7, 68, 4, 75, 5,  7, 
    2, 57, 8, 89, 1,  4, 6, 43, 0, 62, 3, 28, 7, 50, 4, 64, 5, 89, 
    3,  8, 7, 30, 5, 82, 4,  9, 8, 52, 2, 14, 6, 78, 0, 81, 1, 94, 
    8, 32, 6, 93, 7, 34, 4, 39, 5, 10, 2, 25, 0, 58, 1, 61, 3,  2, 
    8, 20, 3, 57, 1, 17, 7, 24, 0, 45, 6, 24, 2, 52, 4, 64, 5, 53, 
    6, 29, 1, 11, 7, 76, 5, 28, 2, 82, 4, 45, 3, 33, 0, 79, 8, 13, 
    5, 54, 2, 24, 7, 59, 4, 94, 3, 26, 8, 15, 6, 47, 0, 53, 1, 54, 
    4, 23, 1, 16, 8, 76, 0, 25, 2,  3, 6,  7, 7, 41, 3, 57, 5, 59
  };
  const int q3472[] = {
    9, 9, // Number of jobs and machines
    1, 58, 6, 33, 5, 35, 4, 34, 7, 78, 8, 80, 2, 72, 3, 86, 0, 52, 
    1, 32, 2, 51, 3, 40, 7, 17, 0, 58, 4,  5, 6, 23, 5, 33, 8, 25, 
    3, 21, 7,  8, 4, 63, 5, 30, 1,  5, 8, 57, 0, 12, 2, 32, 6, 27, 
    2, 52, 4, 75, 0, 82, 5, 88, 8, 51, 7, 23, 1,  6, 6,  5, 3, 43, 
    8, 68, 5, 94, 3, 46, 2, 23, 4, 38, 1, 48, 0, 18, 6, 73, 7, 41, 
    6, 72, 5, 97, 0, 65, 4, 91, 7, 21, 3, 67, 1, 67, 2, 43, 8, 10, 
    4, 22, 8, 91, 2, 11, 7, 17, 0, 11, 5, 53, 1, 32, 6, 10, 3,  9, 
    5, 61, 7, 11, 4, 42, 6, 54, 0, 48, 2, 32, 8, 46, 3, 43, 1, 29, 
    0, 46, 2, 49, 1, 30, 6, 74, 5, 29, 7, 63, 3, 79, 8, 18, 4, 25
  };
  const int q3473[] = {
    9, 9, // Number of jobs and machines
    6, 56, 0, 13, 8, 80, 2, 93, 4, 81, 3, 89, 5,  5, 1,  1, 7, 40, 
    3,  5, 5, 49, 1, 24, 8,  2, 2, 53, 6, 33, 7, 59, 0, 89, 4, 56, 
    0, 86, 4, 66, 1, 97, 7, 20, 6, 64, 2, 59, 8, 17, 3, 59, 5, 44, 
    2, 79, 5, 77, 3, 21, 8,  4, 1, 61, 4, 25, 0, 67, 6, 66, 7, 23, 
    2, 49, 4, 69, 6, 85, 3, 75, 5,  8, 0, 77, 7, 50, 8, 58, 1,  5, 
    6,  8, 3, 56, 0, 59, 1, 69, 2, 98, 7, 17, 4, 18, 8,  8, 5, 71, 
    0, 88, 3, 79, 5, 61, 4, 85, 6, 95, 1, 84, 8, 17, 7, 76, 2,  5, 
    6, 79, 7, 17, 5, 56, 8,  3, 3, 39, 1, 81, 4, 43, 0,  8, 2,  2, 
    3, 64, 7, 87, 0, 69, 8, 86, 6,  4, 5, 73, 2, 78, 4, 59, 1, 87
  };
  const int q3474[] = {
    9, 9, // Number of jobs and machines
    0, 39, 2, 99, 8, 42, 4, 29, 7, 17, 1, 45, 5, 89, 3, 91, 6,  5, 
    1, 20, 2, 35, 5, 86, 3, 17, 8, 66, 0, 30, 4, 36, 6, 36, 7, 31, 
    7, 11, 5, 53, 4, 54, 3, 33, 8, 12, 6, 83, 2, 32, 0, 48, 1, 81, 
    2, 48, 7,  2, 0, 60, 5, 12, 6, 54, 1, 60, 8, 21, 4, 56, 3, 81, 
    3, 79, 7, 57, 6, 98, 4, 71, 8, 93, 2, 77, 0, 24, 1, 21, 5, 52, 
    5,  8, 6, 19, 2, 65, 0, 89, 7, 31, 3, 47, 4, 19, 1, 73, 8, 95, 
    2, 24, 4, 17, 5, 77, 8, 29, 0, 70, 3, 32, 6, 98, 7, 41, 1,  6, 
    4,  3, 2, 80, 8, 42, 0, 68, 6, 26, 7, 36, 1, 14, 3, 20, 5, 30, 
    4, 86, 1, 77, 2, 97, 7, 19, 0, 59, 5, 44, 8, 44, 6, 31, 3, 78
  };
  const int q3475[] = {
    9, 9, // Number of jobs and machines
    5, 22, 2, 13, 4, 17, 0, 65, 7, 91, 6, 48, 3, 83, 8, 52, 1, 78, 
    2, 42, 6, 95, 7, 23, 1, 21, 4, 26, 5, 59, 8, 65, 3, 32, 0, 85, 
    1, 25, 6, 27, 4, 77, 0, 57, 5, 34, 8,  4, 3, 86, 2,  7, 7, 14, 
    6, 40, 7, 24, 0, 10, 5, 38, 4, 33, 3, 72, 8, 16, 2, 26, 1, 20, 
    3, 14, 8, 86, 2, 27, 4, 77, 1, 28, 7,  5, 6, 88, 5, 58, 0, 79, 
    7, 85, 6, 72, 0, 59, 8, 99, 1, 46, 2, 68, 3, 17, 4, 68, 5, 24, 
    1, 43, 8, 91, 0, 49, 2, 52, 3,  2, 5, 99, 4, 25, 6, 96, 7, 84, 
    6, 29, 8, 37, 2,  5, 7, 28, 5, 25, 0, 94, 3, 26, 4,  5, 1, 49, 
    6, 24, 3,  5, 8, 31, 7, 56, 0, 58, 4, 88, 2, 79, 1, 94, 5, 30
  };
  const int q3476[] = {
    9, 9, // Number of jobs and machines
    6, 84, 2,  5, 5, 42, 3, 19, 8, 81, 1, 49, 7,  8, 4, 35, 0, 16, 
    2, 95, 6, 92, 5, 92, 4, 54, 3, 67, 8, 44, 0, 93, 1, 82, 7, 54, 
    2, 25, 5, 57, 1, 55, 7, 47, 8,  5, 6, 55, 3, 19, 4, 52, 0,  6, 
    8, 77, 7, 45, 4, 43, 5, 48, 3, 38, 6, 27, 1, 91, 0, 78, 2, 49, 
    3, 98, 2, 53, 6, 98, 0, 68, 1, 47, 4, 20, 8, 97, 5, 86, 7, 46, 
    2, 83, 5, 56, 8, 96, 4, 93, 6, 29, 3, 42, 7, 48, 1, 93, 0, 44, 
    1, 53, 4, 59, 8, 29, 2, 96, 7, 48, 6, 66, 5, 62, 0, 15, 3, 80, 
    5, 85, 0, 49, 4, 32, 3, 55, 8, 75, 6,  8, 7, 66, 2, 26, 1, 92, 
    7, 39, 8, 82, 3, 83, 5, 41, 0, 41, 6,  5, 2, 54, 4, 85, 1, 98
  };
  const int q3477[] = {
    9, 9, // Number of jobs and machines
    0, 96, 2, 56, 4, 64, 1, 22, 3, 67, 7,  9, 5, 22, 6, 50, 8, 49, 
    6, 66, 1, 70, 4, 74, 7, 12, 5, 71, 0,  1, 8, 26, 2, 85, 3, 48, 
    1, 49, 7, 66, 5,  8, 8, 96, 0, 27, 2, 37, 6, 81, 4, 97, 3, 28, 
    2, 75, 7, 27, 8,  6, 0, 50, 4, 11, 5, 85, 3, 32, 1, 51, 6, 25, 
    3, 16, 6, 69, 7, 82, 0, 38, 2, 54, 4, 57, 1, 89, 8, 68, 5, 33, 
    2, 39, 6, 12, 4, 52, 1, 44, 0, 53, 8, 53, 5, 59, 3, 77, 7, 30, 
    1, 12, 6, 94, 0, 58, 2, 57, 4, 98, 3,  2, 7, 17, 8, 31, 5, 56, 
    5, 57, 2, 93, 7, 10, 0, 24, 1, 71, 4, 89, 8, 71, 6,  5, 3, 84, 
    7, 33, 1, 79, 8, 51, 4, 29, 2, 99, 5,  3, 3, 94, 6, 73, 0, 26
  };
  const int q3478[] = {
    9, 9, // Number of jobs and machines
    7, 98, 3, 96, 6, 86, 2, 40, 8, 79, 4, 64, 5, 98, 0, 74, 1, 75, 
    0, 71, 1,  2, 8, 77, 4, 88, 2, 10, 5, 94, 3, 19, 6, 68, 7, 25, 
    1, 38, 0, 69, 2, 47, 7, 97, 3, 31, 5, 90, 8, 10, 6, 79, 4, 62, 
    5, 89, 4, 88, 7, 48, 2, 62, 3, 23, 6, 48, 0, 58, 1, 45, 8, 37, 
    0, 65, 1, 64, 5,  1, 3,  1, 7, 88, 2, 24, 4, 46, 8, 56, 6, 26, 
    6, 87, 1, 96, 3,  4, 2, 48, 0, 40, 5, 20, 7, 42, 4, 45, 8, 41, 
    6, 92, 1, 98, 4, 41, 3, 66, 2, 14, 5, 35, 0,  1, 7, 89, 8, 86, 
    0, 36, 5, 68, 7, 34, 4,  7, 6,  7, 2, 58, 1, 43, 3, 68, 8, 56, 
    5, 74, 7, 63, 4, 61, 0, 48, 1, 91, 2, 62, 6, 95, 8, 68, 3, 23
  };
  const int q3479[] = {
    9, 9, // Number of jobs and machines
    2, 88, 0, 10, 4, 55, 5, 75, 7, 64, 3,  7, 8, 84, 1, 74, 6, 88, 
    7, 11, 0, 43, 1,  8, 4, 84, 3, 79, 6,  4, 5, 79, 8, 72, 2, 54, 
    7, 35, 0, 22, 4, 50, 3,  4, 6, 33, 1, 36, 5, 79, 2, 51, 8, 47, 
    3, 28, 5, 44, 6, 79, 0, 88, 8, 96, 1, 12, 4, 72, 2, 43, 7, 45, 
    5,  6, 4, 50, 3, 49, 0, 35, 8, 69, 1, 70, 6,  6, 7,  4, 2, 70, 
    5, 31, 4, 79, 2, 28, 0, 11, 8, 20, 7, 24, 6, 93, 1, 14, 3, 72, 
    4, 69, 5, 20, 2, 17, 0, 60, 6, 82, 3, 92, 1, 75, 7, 41, 8, 97, 
    0,  5, 4, 76, 3, 37, 7, 79, 8, 84, 5, 46, 2, 88, 1,  9, 6, 91, 
    5, 93, 3, 85, 2, 27, 6,  1, 0, 25, 4, 78, 8,  7, 1, 43, 7, 63
  };
  const int q3480[] = {
    9, 9, // Number of jobs and machines
    4, 89, 2,  6, 7, 22, 3, 98, 1, 10, 0, 85, 8, 38, 6, 58, 5, 68, 
    5, 56, 7, 31, 2, 78, 1, 66, 8, 97, 3, 69, 4, 79, 6,  5, 0, 99, 
    1, 74, 0, 24, 4, 92, 5, 28, 7, 28, 2,  1, 3, 38, 8, 64, 6, 54, 
    3, 56, 1, 45, 0, 52, 8, 99, 4,  6, 7, 15, 2, 71, 5, 89, 6, 31, 
    4, 18, 5,  7, 8, 74, 2, 20, 6, 86, 1,  7, 7, 75, 0, 81, 3, 66, 
    7, 90, 4, 90, 3, 60, 1, 76, 2, 97, 5, 58, 0, 80, 6,  2, 8, 91, 
    8, 69, 7, 60, 5,  7, 2, 34, 1, 66, 3, 93, 4, 19, 6, 88, 0, 31, 
    7, 46, 4, 88, 0, 21, 3, 84, 5, 29, 8,  1, 6, 89, 1, 98, 2, 64, 
    8, 84, 2, 80, 5, 60, 1, 62, 4, 73, 3, 46, 0, 46, 6,  1, 7, 73
  };
  const int q3481[] = {
    9, 9, // Number of jobs and machines
    3, 51, 5, 42, 2, 44, 6, 13, 1, 88, 0, 86, 7,  2, 4, 51, 8, 91, 
    1, 19, 8, 81, 0, 61, 5, 61, 7, 75, 6, 20, 4, 59, 2, 44, 3,  8, 
    4, 54, 2,  5, 0, 48, 7, 40, 5, 79, 6, 82, 8, 13, 1, 11, 3, 81, 
    7, 91, 8,  4, 0, 94, 4, 53, 6, 34, 5, 61, 1,  5, 2, 80, 3, 70, 
    7, 24, 4, 95, 2, 55, 0, 38, 1, 21, 8,  2, 5, 54, 6, 68, 3, 68, 
    3,  3, 2, 12, 1, 61, 0, 95, 5, 55, 7, 16, 4, 48, 6, 72, 8, 22, 
    8, 99, 2, 17, 3, 32, 5, 16, 6, 86, 0, 41, 1, 70, 7, 83, 4, 18, 
    0, 34, 4,  4, 8, 60, 5, 75, 6, 84, 2, 10, 3,  5, 7, 95, 1, 24, 
    6, 87, 8, 15, 2, 77, 3, 64, 4, 63, 0, 39, 5, 13, 7, 56, 1, 59
  };
  const int q3482[] = {
    9, 9, // Number of jobs and machines
    7, 45, 2, 72, 8, 92, 6, 40, 4, 59, 1, 96, 5, 15, 0, 38, 3, 17, 
    0, 41, 7, 46, 6, 97, 4, 29, 1, 87, 2, 26, 8, 51, 3, 37, 5, 93, 
    1, 99, 3, 29, 6, 70, 4, 76, 2, 43, 8,  3, 5, 93, 0, 55, 7, 64, 
    7, 54, 5, 30, 4, 47, 2, 19, 6, 44, 8, 76, 1, 10, 0, 13, 3, 53, 
    0, 67, 6, 20, 4, 91, 1, 13, 8, 38, 2, 35, 3, 24, 7, 73, 5, 96, 
    3, 84, 4, 30, 6, 45, 7, 74, 2, 35, 1, 70, 0, 14, 5, 80, 8, 45, 
    2, 55, 8, 44, 0, 45, 1, 80, 6, 80, 3, 70, 7, 57, 5, 10, 4, 84, 
    2, 11, 0, 17, 6, 32, 5, 11, 8, 38, 4, 60, 7, 68, 3, 67, 1, 87, 
    7, 40, 4, 59, 1,  5, 8, 77, 2, 48, 0, 57, 3, 41, 6, 89, 5, 34
  };
  const int q3483[] = {
    9, 9, // Number of jobs and machines
    0, 44, 3, 52, 4, 41, 2, 27, 5, 79, 6, 94, 8, 26, 7, 72, 1, 91, 
    5, 90, 6, 49, 4, 26, 0, 96, 8, 74, 2, 29, 3, 21, 1, 19, 7, 67, 
    0, 81, 3, 20, 8, 37, 6, 92, 1, 21, 7, 86, 5, 16, 4, 37, 2, 60, 
    8, 87, 3,  5, 7, 24, 4, 27, 6,  2, 0, 17, 1, 91, 2, 73, 5,  6, 
    1, 52, 8, 37, 5, 55, 2, 38, 3, 21, 4, 67, 6, 76, 7, 48, 0, 71, 
    2, 28, 8, 30, 0, 24, 7, 35, 3, 59, 6, 21, 4, 22, 5, 94, 1, 87, 
    5, 96, 1,  3, 7, 19, 0, 87, 6, 14, 4, 95, 3, 59, 2, 24, 8,  2, 
    1, 57, 7, 19, 2, 10, 0, 55, 4, 11, 5, 94, 8, 90, 6, 34, 3, 81, 
    4, 94, 6, 69, 0, 23, 3, 34, 1, 27, 2, 20, 7, 93, 8, 82, 5, 63
  };
  const int q3484[] = {
    9, 9, // Number of jobs and machines
    8, 71, 5, 84, 6, 64, 0, 17, 4, 66, 7, 32, 2, 42, 1, 29, 3, 10, 
    0,  3, 1, 26, 3, 18, 4, 24, 5, 42, 8, 83, 6, 17, 7, 51, 2, 95, 
    5, 50, 8, 45, 3, 92, 1, 44, 0, 57, 2, 42, 4, 58, 7,  6, 6, 43, 
    5, 80, 2, 11, 1,  7, 6, 10, 7, 23, 4, 67, 3, 57, 0, 44, 8, 17, 
    6, 26, 2,  3, 5, 17, 8, 41, 3, 48, 4, 11, 7, 76, 0, 36, 1, 97, 
    2, 75, 5,  3, 3, 72, 1, 81, 6, 22, 4, 33, 0, 14, 8, 15, 7, 93, 
    3, 70, 0, 80, 8, 22, 2, 90, 1, 14, 7, 35, 5, 71, 6,  8, 4, 41, 
    1,  8, 7, 40, 2, 68, 8, 75, 6, 50, 0, 23, 3, 29, 4, 78, 5, 88, 
    5, 29, 6, 12, 4, 47, 1, 97, 8, 63, 2, 17, 7, 33, 0, 92, 3, 79
  };
  const int q3485[] = {
    9, 9, // Number of jobs and machines
    2, 86, 5, 41, 8,  3, 1, 14, 6, 82, 0, 54, 4, 20, 3, 73, 7, 12, 
    1, 48, 7, 97, 2, 78, 0, 71, 3, 76, 4, 73, 8, 89, 5, 64, 6, 66, 
    3, 29, 2, 49, 7, 76, 4, 85, 0, 43, 1, 42, 5, 28, 8, 15, 6, 74, 
    2, 88, 5, 32, 7, 97, 0, 69, 4, 69, 8, 92, 6, 45, 3, 93, 1, 45, 
    6, 98, 2, 11, 8, 74, 5, 41, 4, 19, 3,  5, 1, 12, 7, 16, 0, 89, 
    0, 32, 1, 14, 7, 87, 5, 46, 2, 85, 8, 81, 4, 24, 3, 63, 6, 50, 
    3, 31, 6, 68, 7, 23, 5, 96, 0, 80, 2, 60, 4, 84, 1, 25, 8, 33, 
    5, 40, 3, 93, 7, 27, 0, 37, 6, 38, 8, 33, 1, 10, 4,  1, 2, 46, 
    2, 84, 8, 11, 1, 48, 3, 46, 4, 35, 6, 54, 7, 23, 5,  6, 0, 54
  };
  const int q3486[] = {
    9, 9, // Number of jobs and machines
    7, 78, 0, 20, 1, 19, 5, 96, 6, 75, 4, 62, 8, 70, 2, 62, 3, 30, 
    4,  3, 3,  7, 6, 23, 2, 69, 5, 94, 1, 10, 8, 80, 7, 32, 0, 32, 
    6, 36, 2, 19, 3, 25, 4,  4, 8, 50, 1, 21, 5, 24, 7, 10, 0, 88, 
    2, 35, 3, 22, 7,  4, 0, 30, 5, 75, 8, 33, 1, 74, 4, 18, 6, 86, 
    6, 71, 5, 94, 2, 63, 1, 76, 8, 12, 3, 36, 4,  3, 0, 52, 7, 85, 
    4, 10, 6, 75, 5, 17, 7, 30, 3, 95, 2, 76, 8, 90, 0,  6, 1, 39, 
    6, 25, 3, 64, 0, 80, 2, 15, 7, 45, 5, 98, 1, 29, 4, 95, 8, 10, 
    5, 42, 4, 40, 6, 83, 0, 13, 7, 91, 8, 73, 3, 55, 2, 37, 1, 53, 
    8, 17, 1,  5, 7, 41, 6, 86, 0, 23, 5, 46, 3, 59, 2, 51, 4, 43
  };
  const int q3487[] = {
    9, 9, // Number of jobs and machines
    1, 82, 6,  1, 8, 46, 4, 81, 7, 70, 3, 62, 2, 82, 0, 34, 5, 59, 
    3, 22, 7, 62, 2, 36, 5, 80, 8, 22, 0, 60, 1, 37, 6, 86, 4, 63, 
    1, 64, 3, 52, 0, 79, 4, 74, 2, 82, 6, 83, 5, 25, 8, 11, 7,  2, 
    5, 33, 2, 22, 7, 49, 4, 23, 6, 34, 0, 77, 1, 56, 8, 66, 3, 66, 
    0, 54, 2, 87, 6, 16, 5,  9, 1, 67, 4, 44, 8, 40, 3, 97, 7, 92, 
    0, 47, 5,  8, 4, 48, 3, 93, 8, 44, 2,  6, 1, 17, 6, 36, 7, 37, 
    8, 24, 4, 44, 2, 96, 7, 40, 6, 82, 1, 78, 5, 64, 0, 15, 3, 65, 
    0, 90, 1, 61, 6, 56, 5, 34, 8, 70, 2, 80, 7, 15, 3, 90, 4, 82, 
    6, 60, 4, 24, 7, 11, 0,  9, 1, 37, 2, 68, 8, 59, 5, 47, 3, 63
  };
  const int q3488[] = {
    9, 9, // Number of jobs and machines
    3, 51, 5, 65, 6, 88, 2, 34, 0,  3, 4, 44, 8, 95, 1, 74, 7, 57, 
    7, 84, 6, 69, 2, 37, 5, 18, 0, 70, 8, 21, 4, 62, 3, 90, 1, 46, 
    0, 36, 1, 69, 3, 46, 5, 17, 7, 59, 8, 20, 2, 20, 4, 39, 6, 82, 
    2, 14, 6, 79, 4, 31, 5, 71, 8, 68, 3, 75, 1, 53, 0, 86, 7, 76, 
    7, 14, 1, 63, 5, 36, 3, 67, 8, 42, 4, 77, 6, 70, 2, 28, 0,  3, 
    4, 15, 6, 67, 2, 30, 8, 43, 5, 59, 1, 78, 3, 98, 0, 88, 7, 45, 
    6, 51, 2, 51, 1, 10, 0, 37, 4, 33, 7, 41, 8, 40, 3, 62, 5, 81, 
    5,  2, 2, 43, 6, 43, 7, 83, 4, 24, 3, 17, 8, 48, 0, 30, 1, 77, 
    4, 39, 1, 63, 7, 15, 6, 53, 5, 83, 3, 51, 0, 85, 2, 84, 8,  9
  };
  const int q3489[] = {
    9, 9, // Number of jobs and machines
    3, 97, 5, 78, 1, 43, 6, 33, 7, 50, 8, 49, 2, 46, 4, 94, 0, 23, 
    2, 36, 6, 74, 4, 77, 5, 17, 1,  1, 7, 84, 3, 79, 0, 32, 8, 53, 
    5, 59, 6, 70, 0, 41, 8, 13, 7, 80, 1, 93, 4, 75, 3, 87, 2, 10, 
    2, 55, 1, 37, 7, 14, 0, 21, 4, 20, 6, 30, 3, 86, 8, 86, 5, 65, 
    1, 25, 2, 26, 3, 63, 0, 25, 4, 17, 8, 23, 6, 97, 5, 52, 7, 75, 
    2, 59, 3, 30, 1, 63, 0, 96, 7, 66, 6, 39, 5, 22, 8, 34, 4, 10, 
    0, 72, 8, 10, 1, 33, 6, 48, 4, 87, 5, 33, 7,  5, 2, 10, 3, 41, 
    1, 92, 5, 80, 7, 75, 8, 35, 4, 93, 3, 88, 2, 60, 0, 32, 6, 94, 
    4, 93, 6,  6, 3, 87, 8, 79, 2, 25, 1,  9, 7, 37, 0, 36, 5, 56
  };
  const int q3490[] = {
    9, 9, // Number of jobs and machines
    8, 64, 7, 56, 4, 89, 6, 78, 5, 17, 3, 49, 0, 99, 1, 42, 2, 91, 
    3, 28, 1, 46, 6, 75, 7, 37, 8, 73, 2, 57, 5, 68, 4, 90, 0,  5, 
    4,  3, 3, 22, 6, 47, 0, 55, 5, 70, 2, 92, 7, 84, 1, 42, 8, 52, 
    8, 75, 3, 50, 5, 69, 2, 87, 4, 97, 1, 97, 0, 93, 6, 14, 7, 32, 
    0, 84, 6, 82, 7, 72, 1, 97, 4, 64, 3, 65, 8, 83, 5, 61, 2, 39, 
    4, 52, 5, 17, 6, 92, 7, 59, 8, 80, 1, 66, 0,  5, 3, 47, 2, 56, 
    0, 42, 7,  9, 6, 73, 5, 74, 3, 73, 8, 54, 4, 32, 1, 37, 2, 69, 
    1, 13, 5, 58, 3,  3, 0, 72, 2, 41, 6, 43, 8, 85, 7, 95, 4, 31, 
    1, 61, 2, 47, 8, 51, 5, 75, 6, 24, 3,  7, 7, 61, 4, 36, 0,  7
  };
  const int q3491[] = {
    9, 9, // Number of jobs and machines
    6,  3, 0, 33, 2, 81, 3, 27, 1, 63, 5, 52, 4, 75, 7, 62, 8, 84, 
    0, 92, 6, 61, 5, 52, 3, 96, 2, 20, 1, 23, 8, 98, 4, 50, 7, 78, 
    0, 77, 5, 63, 8, 91, 2, 13, 4, 42, 1, 42, 3, 39, 7, 71, 6, 11, 
    5, 16, 7, 39, 3, 42, 8, 19, 0, 78, 4, 19, 1, 17, 2, 54, 6, 41, 
    6, 32, 7, 82, 2, 34, 1, 57, 5, 27, 3, 93, 4, 78, 0, 37, 8, 66, 
    0, 55, 7, 40, 4, 99, 6,  1, 3, 15, 2, 18, 8, 50, 1, 41, 5, 54, 
    3, 33, 7, 76, 2,  6, 4, 15, 5, 13, 1, 94, 8, 45, 6, 99, 0, 54, 
    3, 87, 5, 87, 1, 55, 8, 60, 0, 13, 7,  9, 2, 19, 6, 99, 4, 78, 
    0,  3, 6, 58, 7, 57, 3, 65, 4, 52, 8,  2, 5, 50, 2, 41, 1, 33
  };
  const int q3492[] = {
    9, 9, // Number of jobs and machines
    5, 99, 7,  9, 8, 31, 0, 31, 3, 28, 6, 46, 4, 10, 2, 64, 1, 99, 
    5, 63, 0, 87, 4, 46, 7, 44, 1, 88, 3, 36, 2, 66, 8, 77, 6, 38, 
    0, 85, 3,  3, 8, 46, 2,  9, 5, 50, 6, 78, 4, 88, 7, 99, 1,  2, 
    7, 19, 4, 58, 6, 81, 2, 48, 5, 91, 1, 44, 0, 74, 3, 11, 8, 44, 
    8, 26, 4, 11, 2, 94, 5, 73, 3, 37, 1, 67, 0, 90, 6, 79, 7, 22, 
    5, 17, 7, 37, 6, 93, 4,  1, 2, 40, 3, 97, 1, 13, 8, 18, 0, 51, 
    1,  9, 0, 18, 3, 53, 5, 94, 2,  8, 7, 32, 4, 90, 6, 32, 8, 74, 
    8, 52, 3, 53, 0, 15, 6, 83, 7, 98, 1, 31, 2, 24, 5, 66, 4, 65, 
    3,  2, 6,  4, 2, 23, 8, 55, 5, 42, 7, 48, 0, 68, 4, 83, 1, 23
  };
  const int q3493[] = {
    9, 9, // Number of jobs and machines
    6, 78, 8, 74, 1, 69, 5, 73, 2, 70, 7, 40, 4, 91, 0, 65, 3, 26, 
    6, 93, 7, 15, 5, 70, 3, 35, 0, 85, 8, 93, 1, 28, 2, 42, 4, 94, 
    0, 92, 2, 57, 8, 24, 6, 17, 4, 93, 3, 43, 5, 36, 1, 66, 7,  3, 
    0, 91, 7, 66, 3, 92, 8, 19, 2, 76, 4, 94, 5, 38, 1, 95, 6, 85, 
    0, 17, 4, 31, 2, 59, 5, 95, 7, 12, 8, 73, 3, 53, 6, 56, 1, 94, 
    6, 87, 7, 97, 2, 94, 1, 60, 4, 42, 3, 71, 8, 47, 5, 22, 0, 36, 
    1, 35, 7,  6, 5, 59, 8, 56, 6, 13, 2, 37, 4, 48, 0, 26, 3, 33, 
    7, 44, 3, 80, 6, 55, 4, 65, 8, 46, 0, 92, 1, 86, 2, 93, 5, 96, 
    3,  1, 5, 27, 4, 57, 0, 77, 8, 43, 7, 72, 1,  1, 6, 21, 2, 73
  };
  const int q3494[] = {
    9, 9, // Number of jobs and machines
    3, 62, 7, 29, 0,  6, 1, 56, 2, 80, 6, 69, 5, 56, 4, 50, 8, 53, 
    7, 61, 0, 68, 3, 56, 5, 51, 6, 20, 4, 92, 2, 93, 8, 93, 1, 36, 
    7,  4, 4, 16, 0, 78, 2, 87, 3, 26, 5, 76, 1, 73, 8, 85, 6, 39, 
    7, 13, 8, 66, 4, 99, 5, 65, 1, 28, 3, 17, 2, 73, 6, 44, 0, 13, 
    3, 61, 4,  7, 1, 36, 7, 41, 5, 76, 6, 82, 2, 59, 0, 15, 8, 86, 
    6, 26, 8, 60, 3, 33, 0, 69, 4, 91, 5,  8, 2, 87, 1, 62, 7, 59, 
    1, 19, 8, 17, 6,  7, 4, 47, 7, 19, 3, 63, 5, 66, 0,  9, 2, 20, 
    7, 19, 2, 45, 8, 81, 1, 67, 5, 51, 0, 48, 3, 66, 4, 72, 6, 61, 
    4, 86, 7, 54, 1, 81, 5, 83, 6, 47, 8, 90, 2, 94, 3, 47, 0,  3
  };
  const int q3495[] = {
    9, 9, // Number of jobs and machines
    4, 58, 6, 49, 8, 69, 5, 46, 1, 94, 0, 50, 3, 91, 2,  8, 7, 27, 
    4, 18, 5, 67, 2, 76, 8, 45, 1, 96, 7, 86, 0, 70, 3, 95, 6, 22, 
    6, 62, 5, 15, 3, 94, 1, 35, 7, 36, 8,  5, 2, 86, 4, 39, 0, 52, 
    1, 27, 2, 98, 0, 34, 3, 17, 7, 57, 5, 72, 4, 27, 6, 66, 8, 51, 
    5, 82, 6, 45, 4, 80, 3, 56, 2, 39, 7, 48, 8, 93, 1, 57, 0, 68, 
    3, 92, 5,  8, 0, 88, 6, 69, 4, 49, 2, 57, 7, 32, 1,  6, 8, 87, 
    5, 54, 6, 28, 1, 58, 8, 73, 4, 52, 2, 12, 3,  8, 0, 31, 7, 43, 
    1, 95, 3, 48, 6, 37, 7, 37, 2, 32, 4, 51, 8, 71, 0, 59, 5, 57, 
    4, 63, 1, 47, 0, 30, 7, 85, 5, 39, 6, 67, 8, 31, 3, 68, 2, 14
  };
  const int q3496[] = {
    9, 9, // Number of jobs and machines
    0, 76, 6,  1, 4,  5, 1, 97, 7, 60, 8, 89, 3, 71, 5, 19, 2, 41, 
    3, 43, 2, 42, 1, 25, 4, 82, 8,  8, 6,  6, 0, 98, 5, 96, 7, 16, 
    2,  7, 4,  7, 0, 40, 5, 75, 8, 74, 3,  2, 1, 43, 6, 39, 7, 60, 
    4, 74, 6, 60, 0,  8, 8, 66, 5,  2, 3, 74, 7, 25, 2, 64, 1, 85, 
    3, 68, 7, 14, 6, 55, 2, 30, 1, 41, 5, 16, 4, 54, 0, 78, 8, 71, 
    5, 46, 8, 37, 1, 20, 4, 57, 6, 77, 2, 32, 7, 53, 3, 68, 0, 41, 
    4, 68, 2, 52, 6, 29, 3, 59, 7, 46, 8, 93, 5, 48, 1, 24, 0, 53, 
    6, 54, 8, 92, 0, 11, 4, 33, 1, 95, 5, 10, 3, 51, 7,  4, 2, 96, 
    7, 75, 1, 98, 6, 80, 0, 85, 3, 79, 5, 59, 2, 94, 4, 95, 8, 88
  };
  const int q3497[] = {
    9, 9, // Number of jobs and machines
    5, 97, 2, 21, 3, 12, 1, 37, 7, 52, 4, 86, 0,  1, 8, 43, 6, 47, 
    0, 97, 2, 57, 3, 83, 4, 91, 7, 97, 6, 22, 8, 57, 5, 73, 1, 75, 
    0, 70, 1, 42, 8, 46, 4,  7, 3,  4, 5, 51, 7, 37, 6, 73, 2, 70, 
    3, 10, 5, 73, 6, 85, 0, 47, 7, 13, 2, 21, 4, 17, 1, 76, 8, 96, 
    6, 60, 7, 60, 3, 88, 2, 18, 4, 59, 5, 24, 0, 55, 1, 25, 8,  5, 
    6, 27, 7,  9, 4, 69, 1, 21, 2, 96, 3, 34, 8, 63, 0, 80, 5, 71, 
    7, 73, 4, 69, 3, 86, 8, 21, 5, 86, 6, 60, 0, 89, 1, 91, 2, 64, 
    1, 82, 5, 24, 4, 17, 7, 71, 8, 63, 3, 10, 0, 79, 2, 81, 6, 35, 
    5, 94, 4, 74, 2, 57, 3, 56, 0,  2, 7, 20, 6, 48, 8, 33, 1, 72
  };
  const int q3498[] = {
    9, 9, // Number of jobs and machines
    0, 74, 8, 63, 1,  9, 5, 56, 2, 18, 4, 44, 3, 15, 6, 17, 7,  3, 
    2, 99, 3, 55, 6, 42, 1, 97, 0, 86, 7, 19, 5, 68, 8, 32, 4, 56, 
    4, 94, 8, 23, 7, 41, 2, 79, 0,  2, 1, 38, 5, 41, 3, 29, 6, 98, 
    8, 74, 7, 65, 4, 48, 0, 79, 1, 91, 2, 28, 5, 73, 6, 79, 3, 90, 
    0, 92, 6, 48, 8, 31, 1, 80, 5, 52, 4, 88, 2, 54, 7, 30, 3, 93, 
    0, 19, 2, 89, 6, 12, 1, 32, 8, 35, 3, 40, 5, 13, 7, 94, 4, 25, 
    2, 49, 5, 98, 6, 66, 4, 36, 8, 37, 7, 48, 0, 78, 3, 53, 1, 89, 
    1, 19, 4, 44, 7, 44, 2, 76, 8, 51, 5, 39, 6, 36, 3, 19, 0, 79, 
    1,  2, 2, 68, 5, 89, 4, 29, 3, 75, 0, 88, 8, 72, 6, 18, 7, 66
  };
  const int q3499[] = {
    9, 9, // Number of jobs and machines
    5, 21, 6, 68, 0, 59, 8, 88, 7,  6, 4, 92, 2, 36, 3, 44, 1, 40, 
    8, 88, 3, 88, 1,  9, 2, 58, 4, 65, 5,  7, 6, 37, 7, 38, 0, 75, 
    7,  3, 2, 85, 8, 86, 0, 38, 6, 42, 1, 30, 3, 96, 5, 12, 4, 51, 
    1, 78, 0,  8, 2, 76, 4, 99, 7, 23, 5, 25, 6, 55, 8, 99, 3, 42, 
    4, 87, 1, 64, 3, 83, 0, 33, 2,  2, 5,  5, 8, 26, 6, 46, 7,  6, 
    3, 12, 6, 31, 2, 11, 7, 94, 5, 79, 4, 32, 8, 20, 0,  4, 1, 51, 
    0, 51, 1, 31, 7, 56, 2, 90, 4, 64, 3, 69, 8, 39, 6, 43, 5, 14, 
    1, 63, 5, 18, 4, 29, 8,  5, 3, 55, 6, 37, 7, 68, 0, 95, 2, 34, 
    3,  8, 2, 28, 7, 82, 1, 70, 8, 53, 5, 85, 4, 14, 0, 62, 6, 41
  };
  const int q3500[] = {
    9, 9, // Number of jobs and machines
    6, 38, 4, 59, 8,  2, 0, 25, 5, 72, 7,  2, 3, 98, 2, 92, 1, 50, 
    5, 23, 4, 56, 0, 39, 6, 85, 1, 19, 7, 15, 2, 86, 3, 15, 8,  3, 
    8, 67, 6, 26, 7, 48, 5, 63, 2, 84, 4, 68, 3, 86, 1, 47, 0, 80, 
    7, 75, 2, 10, 3, 56, 8, 78, 6, 23, 4, 48, 5, 46, 1, 38, 0, 24, 
    6, 93, 0, 43, 2, 89, 1, 95, 5, 55, 7, 98, 8, 19, 3, 88, 4, 21, 
    7, 42, 4,  3, 0, 27, 6, 59, 5, 69, 1, 29, 3, 56, 2, 61, 8, 52, 
    4, 31, 2, 29, 7, 65, 3, 15, 1, 52, 5, 26, 6, 14, 8, 15, 0, 94, 
    3, 88, 5, 62, 1, 68, 6, 81, 2, 13, 0, 51, 8, 89, 7,  1, 4, 52, 
    8, 83, 1, 24, 0, 95, 6, 48, 2, 82, 3, 65, 7, 51, 5, 54, 4, 65
  };
  const int q3501[] = {
    9, 9, // Number of jobs and machines
    4, 33, 2, 97, 3, 48, 7, 86, 5, 66, 8, 22, 1, 98, 6, 78, 0, 41, 
    7, 16, 4, 95, 8, 52, 0, 88, 6, 58, 2, 44, 1, 67, 5, 91, 3, 96, 
    6, 71, 7, 57, 3,  4, 4, 58, 1, 48, 5, 71, 0, 72, 8, 58, 2, 37, 
    0, 17, 4, 59, 7, 64, 5, 98, 1, 45, 3, 86, 6, 68, 8, 51, 2, 33, 
    7, 48, 2,  1, 8, 47, 4, 73, 1, 83, 6, 15, 5, 62, 3, 96, 0, 30, 
    7,  9, 0, 34, 3, 20, 5, 12, 6, 34, 1, 94, 4, 52, 2, 81, 8,  7, 
    0, 67, 3, 10, 1, 77, 2, 41, 8, 64, 6, 33, 5, 31, 4, 98, 7, 18, 
    7, 27, 3, 12, 8, 56, 5, 17, 4, 70, 1, 61, 6, 67, 2, 77, 0, 79, 
    4, 51, 6, 96, 3, 71, 7, 82, 5, 60, 2,  9, 8, 31, 1, 59, 0, 85
  };
  const int q3502[] = {
    9, 9, // Number of jobs and machines
    2, 51, 6, 67, 8, 89, 1, 71, 5, 10, 3, 22, 0, 10, 7, 26, 4, 71, 
    3,  3, 1, 36, 8, 76, 7, 30, 5,  2, 4, 10, 0, 76, 2,  6, 6, 56, 
    6, 63, 3, 61, 7, 66, 4, 62, 0,  1, 8, 58, 5,  6, 1, 92, 2, 37, 
    8,  7, 6, 19, 1, 19, 4,  9, 2, 59, 7, 98, 0,  1, 5, 64, 3,  3, 
    8, 28, 5, 68, 0, 28, 2, 15, 6, 21, 4, 68, 1, 91, 3, 11, 7, 75, 
    4, 42, 5, 20, 0, 53, 2, 92, 3, 24, 8, 95, 7, 78, 6, 31, 1, 58, 
    7, 28, 1, 68, 5, 38, 0, 95, 2,  8, 6, 75, 4, 35, 8, 79, 3, 35, 
    6, 31, 8, 24, 7, 68, 1, 39, 3, 99, 2, 19, 5, 73, 4, 31, 0, 24, 
    2, 76, 1, 99, 8, 25, 7, 92, 6, 91, 0, 69, 4, 63, 3, 39, 5, 55
  };
  const int q3503[] = {
    9, 9, // Number of jobs and machines
    8, 47, 5, 36, 7, 52, 4, 40, 6, 38, 0,  5, 1, 26, 2, 90, 3, 10, 
    7, 59, 0, 31, 8, 52, 4, 53, 1, 59, 5, 39, 6, 93, 2, 23, 3, 16, 
    6, 73, 4, 28, 2, 29, 0, 44, 5, 79, 1, 17, 3, 25, 7, 84, 8, 32, 
    6, 72, 3, 19, 8,  7, 2, 68, 7, 60, 5, 42, 1, 50, 0, 38, 4, 99, 
    8, 29, 4, 41, 1, 10, 0, 11, 7, 79, 2, 45, 5, 90, 6, 71, 3, 81, 
    4,  9, 6, 85, 3, 59, 8, 87, 2, 17, 7, 83, 5, 34, 1, 71, 0, 71, 
    1, 34, 5,  5, 4, 48, 2, 34, 0, 15, 6, 13, 3, 66, 7, 58, 8, 59, 
    7,  6, 5,  3, 8, 81, 4, 14, 6, 90, 1, 25, 0, 87, 2, 19, 3, 47, 
    0, 63, 1,  7, 8, 88, 6,  6, 2, 27, 5, 35, 4, 95, 3, 89, 7, 12
  };
  const int q3504[] = {
    9, 9, // Number of jobs and machines
    6, 27, 7, 20, 5, 63, 1, 73, 2, 12, 0, 23, 3, 34, 8,  4, 4, 39, 
    4, 56, 3, 70, 2, 21, 6,  3, 7, 37, 5, 89, 8, 13, 0, 80, 1, 50, 
    3, 64, 2, 82, 0, 22, 4, 48, 5, 80, 8, 82, 7, 76, 1, 34, 6, 52, 
    0,  2, 8, 21, 1, 62, 4, 57, 7,  2, 3, 77, 6, 73, 2, 38, 5, 81, 
    8, 88, 7, 14, 0, 93, 6, 78, 4, 50, 3, 71, 1, 76, 5, 23, 2, 85, 
    5, 99, 0, 32, 1, 11, 3, 51, 4, 38, 7, 90, 8, 34, 6, 94, 2, 27, 
    4, 14, 1, 41, 3, 12, 5, 61, 8, 32, 7, 40, 6, 99, 2, 11, 0, 41, 
    5, 47, 8, 41, 1, 79, 3, 62, 7, 79, 0, 55, 2, 92, 4, 17, 6, 78, 
    7, 91, 4, 64, 0, 38, 8, 44, 6, 82, 3, 45, 5, 91, 2, 32, 1, 56
  };
  const int q3505[] = {
    9, 9, // Number of jobs and machines
    0, 43, 1, 20, 5, 90, 8, 85, 7, 59, 2,  6, 4,  3, 3,  6, 6, 83, 
    8, 64, 0, 36, 1, 21, 2, 86, 3, 68, 7, 94, 5, 53, 6, 88, 4, 34, 
    4, 90, 2, 54, 3, 60, 0, 40, 5, 62, 8, 51, 1, 73, 6,  4, 7, 24, 
    4, 40, 5, 58, 1, 41, 7, 90, 8,  3, 3, 74, 0, 69, 2, 88, 6, 80, 
    0, 12, 7, 17, 8, 10, 6, 45, 1, 28, 5, 31, 4, 42, 2, 77, 3, 22, 
    5, 31, 1, 12, 2, 44, 3, 15, 7, 98, 6, 34, 8, 55, 4, 19, 0, 15, 
    5, 65, 4, 21, 7, 25, 0, 56, 2,  4, 6, 94, 1,  8, 3, 70, 8, 75, 
    0, 95, 2, 73, 6, 28, 4, 23, 3, 76, 1, 31, 8, 19, 7, 44, 5, 58, 
    1, 54, 3, 30, 2, 80, 7, 46, 4,  4, 6,  7, 0, 36, 5, 13, 8, 69
  };
  const int q3506[] = {
    9, 9, // Number of jobs and machines
    2, 30, 8, 75, 5, 12, 1, 61, 7,  1, 0, 40, 6, 52, 3, 34, 4, 97, 
    8, 61, 2, 14, 7, 63, 5, 48, 0, 19, 3, 92, 1, 44, 4, 57, 6, 94, 
    8, 50, 4, 62, 3, 75, 7,  6, 5, 27, 2,  7, 1, 55, 0, 95, 6, 23, 
    2, 60, 6, 91, 3, 29, 1, 31, 7, 33, 0, 95, 5, 58, 8, 56, 4, 16, 
    2, 79, 8, 67, 4, 83, 6, 66, 1, 10, 7, 90, 0, 95, 5, 38, 3,  4, 
    5, 84, 2, 21, 4, 28, 6, 53, 3, 52, 1, 79, 0, 37, 8, 54, 7, 36, 
    7, 85, 6, 69, 8, 32, 5, 83, 2, 93, 3, 55, 0, 43, 4, 90, 1, 69, 
    2, 43, 4, 74, 7, 24, 8, 34, 6,  3, 5, 95, 1, 20, 3, 17, 0, 93, 
    6, 64, 0, 85, 4, 23, 8, 58, 2, 16, 3,  9, 5, 53, 7, 45, 1, 82
  };
  const int q3507[] = {
    9, 9, // Number of jobs and machines
    7, 26, 5, 10, 2, 43, 6, 20, 1, 37, 3, 46, 8, 44, 4, 59, 0, 52, 
    7, 25, 3, 64, 6, 62, 1, 45, 8, 86, 0, 98, 5, 72, 2, 94, 4, 30, 
    3, 27, 4, 32, 5, 36, 0, 98, 8, 67, 2, 44, 7, 48, 1, 46, 6, 14, 
    4, 82, 8, 47, 3, 25, 0, 20, 7, 24, 1, 12, 6, 44, 5, 39, 2, 74, 
    1, 11, 5, 33, 3, 47, 0, 80, 8, 53, 6, 75, 4, 35, 7, 30, 2, 61, 
    3, 65, 4, 71, 7, 35, 1, 61, 8, 86, 2, 74, 6, 11, 5, 91, 0, 90, 
    8, 62, 2, 81, 6, 52, 7, 72, 0, 16, 4, 41, 5, 12, 3, 42, 1, 12, 
    3, 65, 1, 94, 5, 86, 8, 54, 7, 93, 0, 73, 4,  1, 6, 17, 2,  2, 
    2, 17, 0, 78, 3, 72, 8, 95, 7, 10, 5, 29, 1, 14, 6, 19, 4, 89
  };
  const int q3508[] = {
    9, 9, // Number of jobs and machines
    5, 13, 6, 69, 3,  4, 2, 39, 1, 54, 4, 25, 7, 89, 0, 63, 8, 39, 
    0, 59, 8, 70, 1, 26, 3, 31, 6, 26, 7, 27, 4,  4, 2,  4, 5, 82, 
    3, 36, 0, 21, 2, 87, 4, 27, 5, 45, 7, 35, 6,  5, 8, 89, 1, 82, 
    4, 72, 8, 61, 2, 28, 6, 69, 1, 42, 0, 62, 7, 20, 5, 20, 3, 38, 
    6, 96, 1, 60, 2, 91, 8, 10, 4,  5, 5, 39, 7, 23, 3, 14, 0, 50, 
    4, 82, 3, 25, 6, 41, 7, 59, 2, 44, 0, 89, 1, 93, 8, 11, 5, 44, 
    7, 17, 1, 37, 6, 37, 5, 44, 3, 58, 0, 16, 2, 85, 4, 95, 8, 28, 
    7, 64, 2, 11, 0, 15, 6, 93, 5, 62, 1, 60, 3, 51, 8, 89, 4, 11, 
    8, 40, 7, 31, 4, 25, 3, 10, 2, 23, 6, 10, 0, 18, 1, 92, 5, 79
  };
  const int q3509[] = {
    9, 9, // Number of jobs and machines
    7, 20, 8, 13, 0, 93, 2, 60, 3, 76, 4, 10, 6, 41, 5, 91, 1, 18, 
    0, 48, 6, 65, 1, 96, 7, 76, 4, 34, 2, 26, 5, 25, 8, 93, 3, 45, 
    8, 19, 3, 17, 4, 36, 5, 26, 6, 94, 1, 80, 0, 28, 7, 40, 2, 59, 
    4, 37, 0, 21, 5, 20, 2, 18, 1, 76, 7, 66, 3, 51, 6, 56, 8,  9, 
    4, 88, 7, 80, 0, 90, 8, 21, 1, 45, 2,  4, 3, 89, 6, 46, 5,  4, 
    8, 56, 5, 54, 0, 90, 3, 60, 2, 78, 6, 77, 4, 96, 7, 19, 1, 21, 
    4, 60, 6, 58, 3, 75, 1, 89, 7, 99, 2, 78, 5,  5, 8, 16, 0, 41, 
    4, 78, 5, 98, 6, 15, 3, 22, 1, 83, 2, 82, 0, 12, 8, 42, 7, 15, 
    2,  9, 5,  7, 4, 36, 7, 56, 8,  9, 3, 28, 6, 61, 0, 52, 1, 27
  };
  const int q3510[] = {
    9, 9, // Number of jobs and machines
    2, 96, 0, 54, 8, 33, 5, 45, 4, 72, 6, 48, 3, 16, 7, 72, 1, 57, 
    4, 95, 8, 28, 3, 73, 6, 53, 1, 64, 0, 83, 5, 10, 2, 81, 7, 19, 
    7, 83, 2, 31, 1, 46, 6, 54, 3, 39, 0, 27, 5, 45, 8,  2, 4, 28, 
    8, 12, 0, 41, 1, 73, 2,  8, 4, 37, 7, 32, 6, 35, 3, 68, 5, 18, 
    0, 94, 4, 23, 7,  5, 1, 16, 8, 89, 3, 13, 5, 34, 2, 44, 6, 68, 
    3, 45, 0, 45, 7, 81, 5, 77, 1, 54, 4, 70, 6, 80, 8, 62, 2, 27, 
    4, 32, 7, 42, 3, 43, 0, 85, 1, 35, 2, 66, 8, 99, 5, 73, 6, 46, 
    5, 89, 7, 37, 1, 40, 2, 14, 3, 59, 6, 62, 4, 91, 8, 93, 0, 39, 
    5, 49, 6, 87, 4,  6, 1, 95, 0, 99, 3, 30, 8, 19, 7, 25, 2, 91
  };
  const int q3511[] = {
    9, 9, // Number of jobs and machines
    6,  1, 7, 67, 0,  4, 3, 29, 1, 24, 4, 69, 2, 22, 5, 81, 8, 12, 
    6, 16, 3, 91, 0, 95, 5, 51, 8, 12, 7, 43, 1,  9, 4, 97, 2,  8, 
    6, 76, 7, 47, 5, 56, 4, 81, 0, 84, 8, 13, 3, 85, 1, 90, 2, 91, 
    3, 27, 6, 97, 8, 31, 1, 53, 2, 82, 7,  4, 5, 59, 4, 43, 0, 87, 
    0, 59, 7, 46, 5,  8, 6,  6, 8, 27, 3, 94, 4, 60, 1, 58, 2, 61, 
    3, 77, 1, 10, 0, 34, 5, 27, 4, 60, 7, 10, 2, 30, 6, 12, 8, 31, 
    5, 61, 1,  1, 8, 16, 4, 17, 0, 33, 7,  2, 2, 93, 3, 66, 6, 89, 
    0, 49, 2, 45, 5,  2, 8,  8, 1,  7, 6, 14, 7, 78, 3, 37, 4, 56, 
    6, 36, 5, 72, 4, 33, 8,  7, 1, 81, 3, 63, 0, 77, 7, 43, 2, 25
  };
  const int q3512[] = {
    9, 9, // Number of jobs and machines
    6,  1, 2, 96, 7, 21, 4, 30, 8, 15, 3, 38, 0, 95, 5, 97, 1, 69, 
    4, 88, 8, 60, 2, 56, 0, 72, 7, 21, 3, 14, 1, 86, 6, 61, 5,  1, 
    8, 60, 3, 84, 7,  8, 5, 49, 4, 63, 2, 82, 0, 29, 1, 20, 6, 90, 
    1, 29, 0, 35, 2, 62, 5, 64, 7, 88, 8, 20, 6, 14, 4, 21, 3, 88, 
    2, 62, 1,  3, 4, 17, 7, 55, 3, 46, 0, 33, 6, 81, 5, 65, 8, 36, 
    7, 82, 6, 63, 3, 51, 2, 51, 5, 58, 8, 30, 1, 19, 0, 41, 4, 29, 
    0, 14, 5, 29, 8, 76, 1, 79, 2, 28, 3, 92, 6, 30, 4, 51, 7, 18, 
    3, 33, 6, 86, 8, 68, 2, 26, 1, 62, 7, 93, 4, 43, 5, 25, 0, 14, 
    8, 16, 5, 60, 0, 92, 3, 57, 1, 84, 4,  6, 2, 12, 7, 78, 6, 10
  };
  const int q3513[] = {
    9, 9, // Number of jobs and machines
    7, 22, 4,  4, 6, 28, 8, 18, 3, 49, 2, 98, 1, 50, 0, 14, 5, 90, 
    4, 64, 7, 84, 6, 61, 8, 65, 0, 81, 3, 61, 2, 75, 5, 30, 1,  8, 
    4, 39, 7, 34, 6, 85, 8, 45, 1, 46, 3, 59, 5, 76, 2, 13, 0, 55, 
    1, 67, 7, 63, 5, 33, 0, 31, 8, 73, 3,  1, 4, 11, 6, 46, 2, 14, 
    7, 53, 1, 87, 3, 33, 0, 34, 5, 14, 2, 84, 8, 88, 6, 79, 4, 11, 
    0, 94, 4, 48, 5, 50, 6, 66, 3,  6, 7, 25, 2, 94, 8, 28, 1, 62, 
    3, 67, 4, 42, 1, 12, 6, 72, 2, 35, 8, 99, 5,  6, 7, 25, 0,  4, 
    3, 87, 1, 23, 0, 67, 2, 51, 8, 93, 7, 41, 4, 30, 6, 18, 5, 70, 
    7,  9, 4, 14, 5, 73, 1, 54, 2, 35, 6, 32, 3, 50, 8, 74, 0, 46
  };
  const int q3514[] = {
    9, 9, // Number of jobs and machines
    6, 39, 1,  7, 4, 77, 7, 57, 0, 77, 2, 42, 5, 99, 8, 33, 3, 63, 
    4, 85, 6, 94, 8, 84, 7, 63, 3,  8, 1, 69, 2,  1, 0, 64, 5, 95, 
    6, 26, 1, 51, 7, 47, 2, 73, 8, 96, 4, 73, 0, 27, 5, 31, 3,  8, 
    1, 11, 3, 46, 6, 11, 4, 38, 0, 53, 8, 27, 2, 13, 7, 59, 5, 61, 
    4, 37, 1, 12, 5, 15, 6, 11, 8, 78, 2, 53, 3, 88, 0, 60, 7, 96, 
    2, 87, 0, 73, 4, 76, 3, 58, 8, 30, 1, 12, 6, 32, 5, 38, 7, 83, 
    6, 19, 3, 14, 8, 78, 0, 18, 7, 91, 2, 24, 5, 48, 1,  8, 4, 28, 
    0, 41, 1, 41, 5, 12, 6, 58, 3, 54, 2, 84, 4, 94, 8, 68, 7, 19, 
    3, 64, 1,  4, 2, 51, 4, 45, 5, 75, 7,  1, 0, 76, 8, 94, 6,  3
  };
  const int q3515[] = {
    9, 9, // Number of jobs and machines
    6, 18, 0, 39, 4, 96, 3, 43, 2, 64, 8, 54, 1,  2, 5, 51, 7, 60, 
    2,  8, 1, 99, 3, 65, 4, 32, 7, 27, 6, 99, 0, 23, 5, 41, 8, 40, 
    1, 77, 6,  4, 7, 60, 8, 71, 2, 44, 3, 92, 0, 86, 4, 10, 5, 77, 
    2, 79, 6, 68, 1, 18, 5, 22, 4, 70, 3, 75, 0,  8, 7, 85, 8, 23, 
    6, 43, 3, 14, 1, 62, 8, 61, 5, 37, 0, 35, 2, 94, 4,  5, 7, 47, 
    0, 69, 5, 30, 1, 44, 4, 60, 2, 79, 3, 90, 8,  3, 7, 72, 6, 50, 
    4, 90, 6, 60, 1, 23, 8, 82, 5, 98, 0, 39, 3, 84, 2,  3, 7, 64, 
    4, 44, 6, 60, 1,  5, 3, 68, 2, 34, 7, 40, 5, 57, 8, 48, 0, 98, 
    6, 65, 1, 95, 7, 36, 2, 51, 8, 79, 0, 20, 4, 69, 3, 44, 5, 38
  };
  const int q3516[] = {
    9, 9, // Number of jobs and machines
    4, 34, 2, 62, 1, 87, 6, 60, 5, 42, 7, 60, 0,  4, 3, 68, 8, 55, 
    3, 87, 6, 74, 8, 16, 1, 40, 4, 83, 5, 31, 2, 47, 7, 54, 0, 10, 
    7, 41, 2, 42, 0, 84, 1, 90, 4, 29, 3, 45, 8, 72, 5, 77, 6, 94, 
    3, 82, 0, 18, 5,  6, 6, 11, 2, 42, 4, 65, 1, 59, 8,  3, 7,  7, 
    8,  4, 2, 19, 3, 65, 5, 44, 0, 84, 4,  9, 6, 50, 7, 46, 1, 44, 
    1, 60, 6, 79, 2, 53, 0, 30, 5, 25, 4,  1, 7, 75, 3, 23, 8, 61, 
    8, 63, 4, 56, 1, 94, 5, 33, 3, 78, 7, 52, 0,  4, 2, 38, 6, 27, 
    8, 44, 2, 55, 5, 86, 4, 17, 3, 87, 0, 35, 7, 44, 6, 80, 1, 14, 
    1, 73, 5, 59, 4, 95, 6, 79, 7, 57, 2, 64, 8, 94, 3, 19, 0, 55
  };
  const int q3517[] = {
    9, 9, // Number of jobs and machines
    4, 83, 3, 15, 2, 47, 7, 55, 8,  6, 6, 96, 5, 54, 0, 89, 1, 22, 
    1, 72, 5, 69, 3, 95, 6, 17, 7, 67, 2, 37, 4, 15, 8, 85, 0, 45, 
    4, 86, 6,  4, 3, 53, 5, 16, 2, 33, 0, 94, 8, 56, 1, 86, 7, 39, 
    3, 51, 0, 48, 5, 18, 7, 85, 6, 61, 2, 91, 1, 41, 4,  9, 8, 51, 
    5, 20, 7,  9, 8, 36, 2, 77, 3, 59, 0, 75, 6, 38, 4, 56, 1, 50, 
    1, 81, 3, 46, 2, 80, 8, 98, 6, 80, 7,  1, 4, 83, 0, 23, 5, 79, 
    6, 29, 1, 17, 8,  5, 3, 58, 5, 99, 4, 99, 2, 22, 7, 96, 0, 77, 
    4, 26, 8, 71, 5,  7, 6, 16, 1, 33, 7, 31, 0, 27, 3, 88, 2, 40, 
    0, 15, 8, 43, 3, 13, 7, 16, 2, 46, 1, 59, 5, 23, 6, 16, 4, 50
  };
  const int q3518[] = {
    9, 9, // Number of jobs and machines
    8, 19, 7, 96, 1, 15, 6, 88, 2, 47, 3, 24, 0,  3, 4, 29, 5, 42, 
    1,  6, 0, 12, 6, 28, 2, 55, 3, 21, 4, 72, 7, 65, 5,  9, 8, 27, 
    3, 64, 1, 96, 8, 43, 5, 15, 4, 58, 2, 71, 7, 19, 0, 99, 6, 27, 
    2, 81, 1, 12, 0,  6, 6, 36, 5, 59, 7, 55, 3, 11, 8, 18, 4, 91, 
    0, 97, 7, 42, 5, 88, 1, 48, 6, 85, 2, 27, 4, 22, 8, 54, 3, 13, 
    2,  7, 6, 46, 5,  1, 3, 18, 7, 26, 1, 58, 4, 47, 0,  6, 8, 54, 
    8, 93, 2,  7, 5, 32, 3, 40, 6,  6, 0, 36, 1,  7, 4, 38, 7, 99, 
    3, 11, 6, 79, 7, 63, 2, 50, 4, 64, 0, 25, 1, 68, 8, 30, 5, 72, 
    3, 85, 6, 27, 7, 23, 2, 22, 5, 20, 8, 72, 4, 22, 1, 44, 0, 15
  };
  const int q3519[] = {
    9, 9, // Number of jobs and machines
    4, 42, 6, 38, 3, 59, 1, 15, 8, 74, 2,  7, 7, 79, 0, 69, 5, 43, 
    8, 82, 0, 10, 2, 28, 3, 25, 6, 15, 1, 39, 5,  6, 4, 23, 7, 15, 
    1,  4, 2, 27, 6,  5, 7, 44, 0, 19, 8, 11, 3, 54, 5, 82, 4, 86, 
    1, 81, 2, 91, 4, 42, 5, 37, 8, 57, 0, 57, 3, 84, 6, 95, 7, 94, 
    7, 73, 3, 19, 1, 90, 4, 14, 6, 25, 8, 66, 5, 63, 0, 73, 2, 99, 
    1,  3, 8, 40, 3, 87, 2,  3, 0, 16, 4, 66, 6, 55, 5, 77, 7, 38, 
    7, 69, 2, 56, 8, 28, 4, 46, 3, 97, 5, 68, 0, 40, 6,  1, 1, 36, 
    5, 41, 6, 24, 0, 34, 2, 71, 8,  9, 3, 31, 7, 58, 4,  5, 1,  6, 
    1, 86, 8, 76, 7, 93, 2, 44, 4,  1, 5, 55, 0, 13, 6, 81, 3, 60
  };
  const int q3520[] = {
    9, 9, // Number of jobs and machines
    6, 82, 3, 37, 4, 19, 0, 77, 1,  5, 7, 86, 8, 56, 2, 30, 5, 82, 
    1, 23, 7, 40, 0, 93, 4, 48, 8,  6, 3, 46, 2, 98, 5,  1, 6, 55, 
    0, 89, 5, 90, 7, 42, 4, 59, 8,  8, 1, 96, 6, 24, 3, 86, 2, 72, 
    3, 68, 1, 95, 6, 56, 4, 34, 5, 75, 0, 15, 8, 11, 2, 17, 7,  5, 
    6, 13, 7, 66, 5, 85, 8, 92, 4, 12, 3, 95, 1, 44, 0, 51, 2, 26, 
    6, 13, 8, 36, 0, 13, 2,  2, 4,  5, 7, 19, 3,  2, 1, 11, 5, 91, 
    3, 76, 5, 73, 8, 48, 7, 66, 1, 96, 6,  7, 0, 45, 4, 53, 2, 26, 
    1, 62, 7, 33, 2, 76, 4, 99, 0, 75, 6, 58, 5,  6, 8, 31, 3, 71, 
    3, 35, 8,  3, 6, 36, 5, 82, 4, 54, 7, 54, 0,  8, 1, 87, 2,  8
  };
  const int q3521[] = {
    9, 9, // Number of jobs and machines
    7, 98, 4,  7, 5, 42, 3, 43, 1, 47, 8, 89, 6, 77, 0, 72, 2, 11, 
    3, 34, 1, 42, 5, 92, 2, 60, 0, 32, 7, 29, 8, 75, 6, 84, 4, 21, 
    1,  5, 0, 16, 7,  2, 3, 35, 4, 85, 2, 74, 5, 68, 6, 33, 8, 43, 
    8, 36, 1, 28, 2, 75, 7, 53, 0, 87, 5, 96, 6, 25, 3, 30, 4, 92, 
    8,  9, 1, 68, 2, 97, 7, 41, 5,  2, 0,  7, 4, 17, 3, 31, 6, 39, 
    5, 70, 6,  4, 7, 54, 0, 83, 4, 41, 3, 69, 1, 89, 2, 15, 8, 38, 
    5, 81, 8, 94, 2, 88, 4, 36, 7, 88, 0, 78, 1, 35, 6, 86, 3, 84, 
    7, 26, 1, 52, 2, 68, 8, 46, 4, 58, 6, 31, 0, 95, 3, 75, 5, 63, 
    5, 20, 3, 42, 4, 90, 7, 11, 8, 90, 6, 31, 1, 23, 2, 27, 0, 32
  };
  const int q3522[] = {
    9, 9, // Number of jobs and machines
    0, 51, 2, 24, 8, 16, 1, 99, 5, 24, 6, 18, 3, 45, 4,  5, 7, 87, 
    6,  9, 8,  6, 5, 34, 0, 37, 2, 89, 1, 52, 7, 97, 3, 57, 4, 87, 
    5, 72, 3, 46, 0, 34, 7, 13, 2, 52, 8, 35, 4, 66, 6, 60, 1, 11, 
    7, 40, 5, 96, 0, 59, 1, 44, 3, 74, 8, 71, 4, 26, 6, 76, 2, 78, 
    4, 98, 3, 53, 0, 82, 5, 83, 2, 92, 7, 37, 8, 86, 1, 20, 6, 23, 
    8, 26, 0, 62, 6, 30, 5, 31, 2, 45, 4, 69, 3, 33, 1, 34, 7, 84, 
    1, 52, 3, 83, 6, 33, 0, 28, 5, 30, 2, 29, 8, 72, 7, 36, 4, 55, 
    5, 28, 2, 15, 7, 43, 3, 17, 0, 76, 1, 46, 6, 76, 8, 53, 4,  4, 
    1, 56, 0, 88, 8, 66, 5, 40, 3, 71, 6, 18, 7, 91, 2, 61, 4,  7
  };
  const int q3523[] = {
    9, 9, // Number of jobs and machines
    0, 50, 2, 68, 3, 49, 4, 92, 8, 87, 1, 69, 6, 51, 7, 95, 5, 10, 
    1, 39, 7, 28, 2, 15, 8, 94, 4, 89, 5, 74, 6, 61, 3, 29, 0, 50, 
    1, 28, 5, 30, 8, 18, 3, 20, 0, 13, 4, 39, 7, 62, 2, 42, 6, 24, 
    4, 39, 3, 92, 1, 67, 5, 45, 2, 12, 8,  3, 0, 19, 6, 98, 7,  9, 
    8, 31, 1, 23, 7, 56, 0, 68, 5, 39, 4, 18, 3, 93, 6, 71, 2, 67, 
    4, 48, 8, 82, 2, 46, 1, 28, 6, 66, 5, 49, 0, 80, 7, 53, 3, 55, 
    7, 23, 3, 11, 4, 40, 6, 68, 1, 40, 0, 92, 8, 34, 2, 25, 5, 76, 
    4, 73, 5, 42, 6,  2, 1,  2, 0, 95, 8, 19, 7, 35, 2,  3, 3, 72, 
    2, 33, 7, 93, 0, 64, 5, 32, 4, 21, 1, 34, 3, 12, 6, 81, 8, 16
  };
  const int q3524[] = {
    9, 9, // Number of jobs and machines
    6, 58, 5, 38, 3, 98, 0, 70, 4, 90, 7, 78, 1, 43, 2,  6, 8, 69, 
    2, 15, 1, 18, 7, 95, 6, 73, 0, 76, 3, 35, 4, 55, 8, 28, 5, 19, 
    2, 80, 6, 62, 3, 83, 5,  6, 4, 77, 0, 37, 1, 68, 7,  6, 8, 50, 
    1, 74, 2, 15, 4, 83, 7, 91, 0, 97, 8, 89, 6, 43, 5, 66, 3, 24, 
    3, 40, 7, 31, 2, 75, 5, 61, 6,  4, 4,  2, 0, 87, 1, 16, 8, 13, 
    0, 98, 4, 38, 1, 35, 2, 12, 7,  1, 8, 77, 3, 53, 5, 35, 6, 91, 
    0, 64, 8, 62, 5, 67, 3, 27, 4, 66, 7, 76, 1, 71, 6, 10, 2, 93, 
    6, 72, 3, 99, 5, 32, 2,  2, 7, 14, 4, 54, 1, 70, 0, 42, 8, 67, 
    7, 78, 3, 74, 1, 56, 6, 73, 4, 11, 5, 40, 2, 65, 8, 82, 0,  8
  };
  const int q3525[] = {
    9, 9, // Number of jobs and machines
    8, 38, 7, 83, 3, 10, 6, 71, 5, 98, 4, 65, 0, 20, 2,  3, 1, 89, 
    1,  7, 0,  7, 2, 20, 8, 28, 7, 40, 6, 83, 3, 84, 4, 65, 5, 15, 
    0, 38, 2, 81, 6, 67, 3, 57, 8, 62, 5,  1, 7, 84, 1, 60, 4, 35, 
    5, 37, 8, 17, 3, 83, 0, 92, 6, 45, 7, 65, 1,  5, 2, 83, 4, 80, 
    5, 77, 6, 75, 7, 21, 3, 50, 8, 40, 1, 94, 4, 10, 0, 83, 2, 79, 
    1, 98, 0,  6, 5, 42, 2, 40, 7, 64, 6, 14, 4, 83, 8,  2, 3, 14, 
    5, 39, 2, 84, 4, 75, 1, 81, 3, 51, 8, 51, 6, 97, 0,  7, 7, 38, 
    0, 19, 3, 86, 8, 18, 4, 52, 7, 91, 6, 34, 5, 69, 2, 78, 1, 96, 
    0, 76, 2, 94, 3, 12, 8, 77, 6, 53, 7, 99, 1, 45, 4, 32, 5, 10
  };
  const int q3526[] = {
    9, 9, // Number of jobs and machines
    3, 94, 8, 11, 4, 12, 7, 96, 6, 28, 5, 98, 1, 18, 2, 86, 0, 85, 
    7, 63, 1, 39, 8, 69, 4, 44, 6, 35, 3, 44, 0, 59, 2, 69, 5, 86, 
    1, 29, 0, 47, 3, 61, 4, 66, 6,  5, 5, 50, 8,  9, 2, 83, 7, 55, 
    3, 90, 0, 85, 2, 99, 7, 51, 6, 34, 5, 48, 8, 59, 1,  1, 4, 97, 
    1, 61, 2, 67, 6, 68, 0, 27, 7, 36, 3, 45, 5, 90, 8, 34, 4, 83, 
    0, 89, 1, 22, 4, 46, 8, 76, 5, 63, 6, 85, 3, 39, 7, 41, 2, 55, 
    7, 52, 4, 77, 0, 29, 6,  7, 5, 71, 1, 44, 3, 31, 8, 97, 2, 24, 
    0, 29, 7, 17, 1, 55, 8,  2, 3, 64, 6, 35, 5, 84, 2, 96, 4, 76, 
    6, 53, 0, 62, 5, 86, 2, 76, 4, 22, 1, 11, 3, 97, 7, 59, 8, 13
  };
  const int q3527[] = {
    9, 9, // Number of jobs and machines
    6, 93, 5, 16, 1, 10, 3, 10, 8, 76, 4, 14, 0, 86, 2, 43, 7, 60, 
    2, 43, 5, 78, 7,  3, 3, 86, 0, 27, 6, 35, 8, 32, 4, 44, 1, 90, 
    8, 29, 5, 34, 1, 88, 6, 12, 3, 99, 7, 93, 2, 54, 0, 78, 4, 37, 
    2, 81, 4, 75, 5, 20, 8, 41, 7, 99, 6, 76, 1, 68, 3, 17, 0, 36, 
    6, 70, 7, 72, 1, 12, 8, 21, 3, 22, 2, 42, 5, 54, 0, 60, 4, 23, 
    2, 91, 4, 86, 1, 12, 0,  2, 8, 61, 5, 90, 3, 89, 7, 64, 6, 84, 
    7, 57, 0, 12, 3, 85, 8, 24, 1, 51, 2, 10, 4, 89, 5, 57, 6,  3, 
    5, 80, 6, 86, 1, 47, 0, 74, 3,  3, 2, 60, 4, 82, 7, 48, 8, 92, 
    3, 88, 7, 42, 1, 89, 8,  5, 6, 33, 2, 21, 0, 55, 5, 90, 4, 33
  };
  const int q3528[] = {
    9, 9, // Number of jobs and machines
    1, 32, 2, 45, 8, 85, 6, 69, 7, 48, 4, 94, 0, 96, 3, 38, 5,  2, 
    5, 58, 2, 79, 1, 55, 6, 32, 7, 11, 8, 84, 0, 54, 4, 95, 3, 25, 
    7, 62, 2, 36, 3, 56, 1, 92, 8, 41, 6, 47, 5, 94, 4, 31, 0, 13, 
    3, 20, 7, 43, 6, 42, 2, 94, 8,  3, 0, 21, 1, 38, 4, 20, 5, 83, 
    4,  3, 1, 27, 8, 62, 0, 99, 2, 75, 7, 80, 6, 40, 3, 77, 5, 73, 
    4, 32, 6, 99, 3, 13, 8, 78, 5, 34, 7, 51, 1, 68, 2, 93, 0, 63, 
    0, 82, 5,  6, 6, 77, 2, 94, 7, 37, 4, 81, 3, 38, 1, 26, 8, 41, 
    3,  3, 2, 88, 7, 66, 0, 31, 6, 78, 1, 80, 5, 86, 4, 84, 8, 23, 
    6, 31, 8, 50, 4, 56, 7, 51, 3,  3, 1, 99, 5, 79, 2, 13, 0, 42
  };
  const int q3529[] = {
    9, 9, // Number of jobs and machines
    2, 83, 8, 78, 1, 30, 7, 98, 6, 92, 3, 13, 5, 91, 0, 12, 4,  3, 
    1, 62, 2, 90, 5, 83, 8, 91, 3, 77, 7, 70, 4, 69, 0,  9, 6, 25, 
    4, 22, 1, 38, 7, 72, 2, 93, 6, 39, 0, 36, 5, 36, 8, 25, 3, 42, 
    3, 41, 4, 99, 7,  4, 8, 67, 1, 89, 2, 59, 6, 12, 5, 98, 0, 60, 
    2, 42, 4, 52, 7, 21, 6, 81, 8, 17, 1, 12, 3, 12, 5, 51, 0, 92, 
    8, 12, 0, 88, 2, 39, 1, 45, 3, 18, 4, 75, 7, 59, 5, 38, 6,  5, 
    6, 43, 7, 48, 4, 52, 8, 95, 0, 66, 1, 78, 3, 39, 5, 77, 2, 53, 
    4, 81, 7, 84, 2, 72, 5, 46, 1, 15, 0, 97, 6, 34, 3, 33, 8, 98, 
    8, 10, 2, 71, 3, 17, 4, 99, 6, 42, 5,  3, 7, 65, 1, 57, 0, 61
  };
  const int q3530[] = {
    9, 9, // Number of jobs and machines
    6, 40, 7,  6, 5, 52, 3, 55, 0, 80, 8, 42, 4, 62, 2, 17, 1,  9, 
    3, 11, 0, 73, 1, 93, 4, 62, 2, 79, 8, 57, 6, 99, 5, 66, 7, 24, 
    8, 65, 4, 11, 0, 54, 5, 89, 6, 90, 2, 28, 7, 17, 3, 52, 1, 79, 
    8, 55, 4, 38, 3, 75, 0, 62, 6, 33, 5, 95, 2, 18, 7, 99, 1, 98, 
    2, 16, 4, 67, 1, 42, 8, 71, 3, 48, 0, 84, 5, 88, 6, 91, 7,  1, 
    8, 74, 3, 70, 4, 76, 0, 21, 1, 11, 7, 55, 2, 42, 6, 21, 5, 75, 
    1, 71, 8, 13, 6, 66, 3, 35, 5, 79, 4, 64, 2, 99, 0, 17, 7, 27, 
    5, 27, 7, 74, 2, 43, 6, 98, 0, 83, 3, 47, 1, 66, 8, 42, 4, 47, 
    3, 44, 8, 24, 0, 55, 7, 96, 5, 47, 1, 49, 2, 56, 6, 28, 4, 91
  };
  const int q3531[] = {
    9, 9, // Number of jobs and machines
    2, 46, 1, 45, 8, 38, 6, 62, 3, 28, 7, 34, 5, 60, 4, 84, 0, 46, 
    7, 35, 6, 49, 2, 54, 3, 41, 1, 14, 0, 28, 4, 34, 5, 33, 8, 38, 
    8, 13, 7, 20, 5, 24, 4, 73, 0, 15, 3, 55, 2, 30, 1, 52, 6, 36, 
    3, 94, 8, 73, 7, 29, 4, 40, 0, 35, 1, 56, 6, 24, 2, 17, 5, 81, 
    4, 59, 7, 41, 1, 21, 8, 87, 6, 63, 5, 66, 3, 54, 2, 57, 0, 74, 
    8,  9, 4, 64, 1, 35, 3, 86, 6, 39, 7, 49, 5, 63, 0, 24, 2, 62, 
    1,  9, 2, 50, 4, 42, 3, 33, 5, 20, 6, 26, 7, 81, 8, 74, 0, 41, 
    0, 97, 1, 16, 4, 84, 5, 22, 3, 92, 6, 99, 2, 60, 7,  2, 8, 60, 
    4, 71, 6, 73, 8, 66, 0,  2, 2,  2, 3, 35, 7,  1, 1, 92, 5, 19
  };
  const int q3532[] = {
    9, 9, // Number of jobs and machines
    8, 13, 2,  1, 7, 48, 4, 42, 1, 19, 6, 60, 5, 28, 3, 60, 0,  4, 
    4,  8, 8,  8, 3, 50, 1, 61, 0, 20, 2, 91, 5, 58, 6, 53, 7, 80, 
    5,  1, 8, 13, 4, 82, 6, 38, 3, 10, 1,  8, 0, 21, 7, 84, 2, 48, 
    6, 97, 0, 96, 1, 47, 7, 57, 2, 44, 5, 50, 3,  4, 8, 72, 4, 63, 
    1, 55, 7, 48, 0, 49, 5, 39, 8, 86, 2, 42, 6, 87, 4, 46, 3, 32, 
    6, 52, 1, 43, 3, 39, 5, 70, 2, 43, 4, 31, 0, 86, 8, 61, 7, 45, 
    0, 66, 7,  5, 1, 65, 5, 66, 6, 57, 8, 21, 3, 82, 4, 81, 2, 76, 
    7, 13, 3,  5, 1, 62, 0, 53, 2, 67, 5, 78, 8, 93, 6, 44, 4, 80, 
    1, 69, 3, 64, 4, 46, 7, 36, 0, 81, 5, 82, 6, 64, 2, 13, 8,  7
  };
  const int q3533[] = {
    9, 9, // Number of jobs and machines
    6, 79, 3, 23, 7, 19, 1, 79, 2, 81, 8, 65, 5, 39, 4, 78, 0, 22, 
    2, 80, 5, 88, 3, 60, 8, 56, 1, 13, 0, 38, 4, 66, 6, 60, 7, 29, 
    5, 10, 8, 92, 0, 76, 6, 78, 1, 25, 7, 36, 4, 14, 2, 76, 3, 73, 
    5, 88, 7, 73, 4, 78, 0, 21, 3, 86, 8,  8, 2, 36, 6, 21, 1, 49, 
    8, 70, 5, 60, 2, 14, 4, 49, 1, 11, 3, 91, 0,  3, 7, 93, 6, 92, 
    6, 40, 8, 52, 2, 48, 7, 29, 4, 97, 5, 53, 1, 56, 0, 48, 3, 46, 
    5, 17, 3, 41, 1,  5, 4, 38, 2, 44, 6, 90, 7, 51, 8, 26, 0, 28, 
    2, 98, 0, 69, 3,  1, 8, 60, 4, 49, 5, 82, 1,  9, 6, 48, 7, 23, 
    6, 24, 7,  3, 0, 42, 8, 72, 4,  1, 3,  9, 2, 44, 1, 30, 5, 83
  };
  const int q3534[] = {
    9, 9, // Number of jobs and machines
    8, 14, 3, 84, 0, 67, 1, 22, 6, 45, 2, 39, 7, 92, 4, 95, 5, 57, 
    0, 70, 4, 86, 3, 56, 6,  3, 7, 76, 8, 73, 1, 13, 2, 89, 5, 81, 
    2, 83, 8, 99, 0, 60, 6,  4, 3, 65, 1, 94, 7, 73, 4, 96, 5, 51, 
    4, 61, 7, 23, 8, 51, 6, 32, 3, 22, 1, 25, 5, 26, 0, 32, 2, 25, 
    6, 41, 2, 11, 7, 23, 4, 52, 1,  4, 8, 44, 0, 21, 5, 25, 3,  8, 
    3,  3, 0, 25, 8, 94, 2, 98, 6, 23, 4, 93, 5, 11, 1, 21, 7, 80, 
    8, 59, 6, 89, 2, 60, 0, 46, 5, 65, 4, 52, 7,  9, 1, 19, 3, 40, 
    7, 29, 8, 77, 0, 92, 1,  8, 3, 33, 2, 49, 5,  4, 4, 39, 6, 55, 
    6, 35, 8, 73, 3, 30, 5, 87, 0, 64, 2, 98, 4, 98, 7, 13, 1, 38
  };
  const int q3535[] = {
    9, 9, // Number of jobs and machines
    1, 66, 5, 19, 0, 31, 2,  4, 8, 91, 6, 27, 4, 98, 3, 25, 7, 44, 
    2, 77, 0, 48, 6, 76, 1, 93, 7,  4, 4, 62, 8, 66, 5, 29, 3, 16, 
    5, 23, 6, 59, 2, 20, 3, 21, 4,  9, 7, 83, 1, 24, 8, 62, 0, 56, 
    1, 99, 7, 46, 3, 72, 6, 27, 8, 14, 4, 96, 2, 75, 0, 25, 5, 55, 
    0, 95, 5, 56, 7, 10, 1, 59, 3, 34, 2, 26, 6, 19, 4, 31, 8, 55, 
    0, 30, 8, 85, 1, 19, 7, 87, 4, 95, 2, 48, 5, 23, 3, 26, 6, 97, 
    0,  2, 7, 38, 8, 89, 4, 18, 6, 30, 2, 40, 1, 48, 5, 54, 3, 32, 
    4, 83, 3, 35, 0, 18, 5, 55, 6,  2, 1, 13, 7, 80, 2, 22, 8, 29, 
    8, 22, 6, 98, 2, 93, 4, 36, 0, 55, 7, 86, 3, 61, 5, 50, 1, 32
  };
  const int q3536[] = {
    9, 9, // Number of jobs and machines
    6, 92, 5, 45, 8, 40, 3, 62, 4, 29, 0, 25, 7, 44, 2, 11, 1, 34, 
    0, 97, 6, 82, 5, 51, 1, 58, 2, 55, 8, 69, 7, 51, 4, 90, 3, 94, 
    8, 92, 2, 48, 3, 71, 5, 82, 0, 53, 7, 33, 4, 96, 1, 32, 6, 82, 
    8, 86, 2, 68, 6, 76, 7, 25, 1,  9, 0, 56, 3, 11, 4, 97, 5,  1, 
    1, 18, 2, 66, 5, 51, 4, 22, 7,  1, 8, 58, 0, 27, 3, 75, 6, 60, 
    0, 17, 1, 10, 6, 26, 2, 87, 5,  6, 8, 36, 4, 63, 3, 93, 7, 84, 
    5, 26, 8, 33, 3, 94, 6, 93, 0, 21, 1, 94, 7, 25, 2, 63, 4, 10, 
    0, 80, 2, 94, 5, 10, 4, 38, 3, 58, 8, 49, 1, 84, 7, 82, 6, 78, 
    6, 42, 3, 10, 8, 92, 1, 55, 2, 67, 5, 47, 0,  2, 4, 45, 7, 93
  };
  const int q3537[] = {
    9, 9, // Number of jobs and machines
    3, 14, 1, 33, 8, 93, 2, 58, 0, 85, 7, 17, 5,  1, 6, 41, 4, 10, 
    0, 90, 2, 56, 6, 30, 5, 69, 8, 32, 1, 68, 7, 81, 4, 42, 3,  1, 
    4, 14, 2, 29, 1, 27, 7, 13, 0, 24, 8, 75, 6, 32, 5, 37, 3, 81, 
    3, 19, 6, 27, 4, 59, 2, 35, 5, 31, 8, 53, 7, 18, 1, 96, 0, 66, 
    7, 88, 3, 45, 0, 87, 5, 12, 6, 15, 8, 99, 4, 53, 1, 49, 2, 44, 
    8, 34, 0, 62, 2, 88, 4, 59, 6, 54, 7, 57, 5, 18, 3, 46, 1, 79, 
    5,  8, 8, 80, 4, 93, 2,  8, 1,  2, 6, 21, 0, 71, 7, 91, 3, 51, 
    7, 77, 0, 59, 1, 18, 8, 89, 2, 42, 4, 43, 3, 40, 5, 63, 6, 86, 
    3, 49, 1, 97, 7, 72, 4,  8, 8, 70, 5, 24, 2, 63, 6, 56, 0,  7
  };
  const int q3538[] = {
    9, 9, // Number of jobs and machines
    6, 59, 7, 54, 8, 61, 2, 48, 5, 66, 4,  6, 1, 69, 0, 79, 3, 34, 
    2, 90, 6, 91, 4, 28, 0, 23, 8, 12, 7, 91, 3,  4, 1, 91, 5, 60, 
    6, 49, 1, 46, 3, 40, 0, 74, 2, 57, 5, 81, 7, 31, 4, 39, 8, 96, 
    8, 61, 1, 67, 7, 37, 2, 39, 0, 45, 3, 36, 4, 33, 5, 63, 6,  1, 
    8,  7, 5, 18, 3, 20, 2, 87, 6,  2, 7, 81, 1, 42, 0, 40, 4, 56, 
    0, 10, 6, 24, 8, 29, 2, 95, 4,  6, 1, 27, 7, 32, 5, 14, 3, 69, 
    3, 28, 8, 34, 6, 99, 0, 88, 5, 41, 1, 24, 7, 23, 4, 11, 2, 16, 
    7,  7, 5, 77, 3, 89, 1, 56, 2, 67, 0, 54, 8, 91, 6, 87, 4, 98, 
    5, 82, 8, 51, 6, 23, 0, 54, 7, 33, 3, 79, 4, 50, 1, 51, 2, 18
  };
  const int q3539[] = {
    9, 9, // Number of jobs and machines
    0, 75, 4,  6, 1, 74, 6, 87, 5, 72, 3, 41, 2, 12, 7, 15, 8, 19, 
    8, 53, 1, 40, 4, 73, 7, 80, 3, 19, 6, 10, 2, 19, 5, 88, 0, 95, 
    3, 59, 4, 81, 0, 51, 8, 72, 7, 90, 5,  6, 2, 48, 6, 56, 1, 53, 
    0, 14, 4, 49, 8, 87, 2, 44, 1, 20, 3, 76, 5, 78, 6,  5, 7, 96, 
    4, 75, 3, 74, 2, 35, 1, 50, 8, 73, 5, 31, 0, 37, 7, 15, 6,  7, 
    3, 51, 0, 12, 8, 21, 4, 98, 2, 77, 7, 51, 5, 88, 6, 71, 1,  7, 
    3, 66, 7, 25, 0, 42, 4, 62, 5, 22, 6, 79, 8, 17, 2,  1, 1, 39, 
    3, 54, 1, 88, 2, 72, 0, 54, 7, 75, 6, 73, 5, 59, 4, 72, 8, 42, 
    6, 62, 5, 35, 7, 85, 1, 34, 2, 60, 8, 28, 0, 10, 3, 28, 4,  2
  };
  const int q3540[] = {
    9, 9, // Number of jobs and machines
    4, 18, 8, 74, 5, 67, 7, 22, 6, 68, 2, 78, 3, 43, 1, 48, 0, 62, 
    3, 87, 8, 19, 0, 21, 4,  5, 7, 29, 1, 84, 6, 24, 5, 43, 2, 58, 
    2, 73, 3, 27, 8, 27, 6, 37, 4, 79, 0, 73, 1, 44, 5, 34, 7,  9, 
    2, 78, 3,  9, 4, 98, 5, 26, 6,  4, 0, 18, 1, 51, 8, 93, 7, 62, 
    2, 75, 5,  5, 3, 94, 4, 93, 6,  7, 7, 91, 1, 79, 0, 91, 8,  2, 
    6, 49, 4, 97, 8, 35, 3, 11, 5,  2, 2, 51, 7,  9, 0, 60, 1, 96, 
    2,  6, 8, 19, 5, 12, 3, 73, 0, 69, 1, 32, 7, 28, 6, 22, 4, 38, 
    8, 68, 1, 50, 0, 13, 2, 48, 4, 41, 7, 31, 3,  2, 5, 84, 6, 14, 
    6, 79, 7,  1, 8, 75, 5, 97, 2,  5, 0, 89, 1, 11, 4,  6, 3, 66
  };
  const int q3541[] = {
    9, 9, // Number of jobs and machines
    7, 36, 2, 24, 3, 14, 6, 71, 5, 16, 8, 72, 1, 80, 0, 31, 4, 28, 
    1, 72, 5,  2, 4, 37, 3, 20, 8, 97, 0,  1, 6, 10, 2, 50, 7, 12, 
    5, 38, 0, 98, 1, 81, 7, 18, 6, 22, 3, 65, 2,  6, 4, 14, 8, 78, 
    7, 45, 3, 56, 6, 98, 5,  1, 1, 47, 8, 64, 4, 34, 0, 66, 2, 58, 
    6, 89, 3, 76, 0, 62, 4, 14, 8,  5, 5, 38, 7,  6, 2, 52, 1, 61, 
    2, 53, 8, 87, 1,  7, 0, 87, 6, 54, 5, 56, 4, 47, 3, 65, 7, 23, 
    3, 43, 4, 23, 1,  5, 7, 34, 8, 30, 5, 36, 0, 79, 2, 93, 6, 73, 
    2, 22, 4,  4, 6, 57, 7, 53, 1, 12, 8, 10, 3, 50, 5, 97, 0, 77, 
    3, 67, 7, 16, 2, 68, 6,  3, 1, 55, 8, 32, 0,  3, 4, 29, 5, 77
  };
  const int q3542[] = {
    9, 9, // Number of jobs and machines
    4, 44, 0, 89, 2, 27, 8, 97, 3, 87, 5, 92, 6, 38, 7, 85, 1,  6, 
    2, 28, 4, 16, 7, 32, 3, 34, 6,  8, 8, 84, 0, 45, 1, 94, 5, 85, 
    1, 10, 6, 63, 0, 15, 8, 99, 3, 69, 5, 33, 2, 80, 4, 46, 7, 15, 
    5, 70, 8, 80, 1, 24, 6, 29, 2, 61, 3, 86, 0, 41, 4, 59, 7, 58, 
    0, 87, 2, 71, 4, 84, 7, 46, 8, 71, 1, 30, 5, 19, 6, 85, 3, 11, 
    7, 99, 8, 52, 0, 85, 3, 26, 1, 94, 2, 54, 5, 30, 6, 98, 4, 14, 
    5, 92, 1, 89, 8, 20, 2, 41, 3, 87, 0, 38, 6, 94, 4, 90, 7, 47, 
    4, 98, 5, 66, 6, 43, 3, 35, 1, 64, 0, 18, 7, 55, 2, 62, 8, 19, 
    3, 60, 1, 70, 2, 37, 0, 13, 7, 52, 8, 91, 6, 99, 4, 86, 5, 24
  };
  const int q3543[] = {
    9, 9, // Number of jobs and machines
    0, 65, 6, 65, 1, 15, 2, 26, 3, 43, 4, 68, 8, 52, 5, 65, 7, 75, 
    3, 59, 6,  6, 8, 91, 5, 87, 0, 81, 7, 77, 2, 23, 1, 84, 4, 74, 
    1, 28, 2, 95, 7, 94, 5, 26, 8, 90, 4, 74, 6,  9, 0,  3, 3,  2, 
    4, 18, 0, 71, 2, 81, 3, 28, 7, 23, 6, 37, 5, 79, 1, 53, 8, 87, 
    0, 39, 8, 66, 3, 85, 6, 16, 4, 46, 1, 31, 2, 34, 7, 72, 5,  5, 
    3, 76, 0, 66, 4, 38, 8, 32, 7, 95, 2, 91, 1,  9, 6, 81, 5, 28, 
    0, 85, 6, 15, 3, 43, 5,  5, 1, 50, 4,  8, 2,  7, 8, 10, 7,  2, 
    3, 81, 5, 65, 7, 28, 1,  5, 4, 20, 2, 90, 0, 95, 6, 87, 8, 73, 
    3, 58, 0, 10, 1, 66, 7, 79, 5, 64, 2, 36, 6, 30, 4,  1, 8, 97
  };
  const int q3544[] = {
    9, 9, // Number of jobs and machines
    7, 32, 4, 97, 6, 15, 0, 12, 8,  6, 5, 68, 3, 67, 1, 32, 2, 81, 
    2, 98, 7,  2, 6,  4, 4, 10, 8, 49, 0, 40, 3, 98, 1, 55, 5, 53, 
    0, 80, 8, 98, 7, 31, 5, 20, 4, 74, 1, 59, 2, 32, 6, 76, 3, 41, 
    1, 84, 8, 44, 7, 17, 0,  2, 4, 62, 6, 94, 5, 11, 3, 78, 2, 67, 
    0, 82, 4, 77, 6, 36, 8, 18, 3, 71, 2, 90, 7, 61, 5, 97, 1, 82, 
    2, 78, 3, 59, 8, 23, 6, 16, 0, 57, 7, 60, 4, 47, 1, 99, 5, 26, 
    1, 95, 6, 12, 4, 37, 3, 84, 5, 95, 8,  7, 0, 89, 7, 96, 2, 15, 
    4, 50, 5, 79, 1, 77, 3, 91, 2, 29, 0, 34, 6, 10, 8, 20, 7, 26, 
    1, 50, 3, 12, 5,  1, 4, 23, 7,  8, 2, 34, 0, 10, 6, 73, 8, 20
  };
  const int q3545[] = {
    9, 9, // Number of jobs and machines
    7, 47, 4, 76, 5, 99, 2, 23, 8, 47, 3, 85, 6, 84, 1, 98, 0, 58, 
    6,  7, 0, 89, 2, 81, 4, 24, 1, 63, 5, 61, 7, 83, 3, 63, 8, 85, 
    7, 63, 6, 52, 3, 70, 5, 80, 4, 90, 0, 98, 2, 87, 1, 34, 8, 49, 
    4,  2, 8, 85, 7,  1, 5, 13, 6, 27, 3, 29, 1, 33, 2, 16, 0, 25, 
    3, 92, 8, 63, 0, 52, 5,  5, 7, 48, 1, 90, 4,  1, 6, 26, 2, 85, 
    0, 89, 7, 77, 5, 95, 3, 72, 2, 52, 8,  3, 1, 17, 4, 54, 6, 87, 
    6, 52, 4, 73, 2, 12, 0, 16, 8, 11, 3, 78, 5, 53, 1, 43, 7, 95, 
    8, 75, 0, 14, 6, 63, 5, 70, 7, 42, 4, 26, 1, 21, 3, 29, 2, 15, 
    4, 95, 0, 80, 6, 93, 1, 57, 5, 90, 2, 19, 3,  6, 8, 23, 7, 89
  };
  const int q3546[] = {
    9, 9, // Number of jobs and machines
    1, 53, 8, 44, 2, 89, 5,  4, 3, 54, 7, 29, 6, 84, 4, 97, 0, 59, 
    2, 37, 1, 73, 8, 92, 6, 45, 3, 59, 4, 45, 0, 91, 5,  9, 7, 47, 
    7,  3, 1, 88, 4, 58, 6,  7, 3, 12, 2, 64, 8, 59, 0, 97, 5, 47, 
    7, 63, 4,  5, 5, 54, 6, 51, 2, 72, 8, 74, 3, 51, 0, 19, 1, 82, 
    1, 21, 7, 55, 4, 75, 3, 56, 8, 56, 0, 46, 5,  3, 2, 26, 6, 49, 
    2, 73, 5,  6, 6, 76, 7, 22, 1, 91, 8, 28, 3, 32, 4, 70, 0, 43, 
    5, 41, 7, 40, 1, 64, 6,  7, 0, 66, 4, 88, 2, 23, 3, 44, 8, 44, 
    1, 26, 3, 77, 6, 98, 7, 18, 4, 72, 2, 70, 0, 94, 5, 47, 8, 72, 
    2, 78, 7, 11, 0, 28, 1, 20, 8, 71, 5, 74, 6, 22, 3, 58, 4, 12
  };
  const int q3547[] = {
    9, 9, // Number of jobs and machines
    0, 52, 4, 34, 5, 30, 8, 73, 1, 24, 2, 96, 3, 55, 7, 59, 6, 42, 
    4, 81, 0, 74, 7, 93, 2, 76, 8,  8, 6, 52, 5, 85, 3, 28, 1, 97, 
    7, 49, 6, 16, 1, 29, 3, 24, 8,  2, 4,  2, 2,  3, 5,  5, 0, 61, 
    0, 74, 7,  1, 6, 63, 5, 60, 3, 65, 2, 77, 1, 32, 8, 26, 4, 27, 
    4,  2, 3, 87, 1, 30, 0, 74, 8, 58, 2, 34, 6, 72, 5, 65, 7, 32, 
    1, 41, 3, 23, 6, 17, 2, 35, 0, 10, 4, 44, 7, 11, 5, 29, 8, 62, 
    6, 91, 5, 58, 8, 73, 0, 11, 3, 68, 1, 34, 7,  7, 4, 28, 2, 12, 
    6, 12, 5, 11, 4, 88, 8, 90, 0, 31, 2, 53, 3, 49, 7, 31, 1, 94, 
    7, 31, 8, 21, 3,  4, 4, 75, 5,  8, 0, 17, 1, 50, 2, 63, 6, 40
  };
  const int q3548[] = {
    9, 9, // Number of jobs and machines
    1,  6, 2, 62, 3, 24, 0, 37, 8, 57, 5, 75, 6, 47, 7, 32, 4, 96, 
    6, 44, 5, 27, 8, 15, 2, 61, 7, 60, 3, 39, 4, 37, 1, 70, 0, 33, 
    3, 84, 4, 85, 8, 53, 0, 41, 7, 16, 1, 99, 6, 48, 2, 15, 5, 45, 
    3, 22, 1, 52, 8, 99, 6, 43, 4, 12, 0,  3, 7,  8, 2, 74, 5, 83, 
    2, 59, 3, 75, 7, 79, 6, 43, 0, 92, 4,  7, 1, 61, 8, 68, 5, 66, 
    2, 33, 3, 62, 0, 19, 5, 14, 1,  2, 6, 95, 7, 20, 4,  5, 8,  7, 
    2, 43, 4, 51, 7,  2, 6,  8, 8, 62, 1, 80, 5, 66, 3, 77, 0, 78, 
    2, 29, 4, 32, 0, 37, 6, 20, 8, 10, 1, 82, 5,  2, 3, 28, 7, 82, 
    3, 78, 4, 57, 1,  3, 8,  4, 5, 39, 6, 59, 0, 30, 2, 50, 7, 18
  };
  const int q3549[] = {
    9, 9, // Number of jobs and machines
    4, 11, 0, 56, 7, 41, 6, 96, 8,  3, 1, 22, 2, 38, 3, 60, 5, 84, 
    2,  6, 5, 42, 0, 85, 6, 67, 7, 21, 8, 28, 4, 85, 1, 72, 3, 75, 
    0,  4, 8, 13, 6, 73, 1, 57, 5, 50, 4,  2, 3, 43, 2, 81, 7, 75, 
    2, 47, 3, 12, 7, 34, 4, 35, 1, 28, 6, 95, 0, 31, 5, 23, 8, 93, 
    3, 14, 1, 87, 0, 25, 5, 31, 8, 23, 4,  5, 2, 53, 6, 20, 7, 11, 
    4, 30, 2, 80, 0, 32, 1, 52, 5, 54, 6, 16, 7, 53, 3, 88, 8, 98, 
    3, 58, 1, 11, 6, 99, 5, 11, 0,  4, 8, 23, 2, 47, 7, 58, 4, 19, 
    0, 76, 4, 20, 5, 28, 3, 75, 7, 77, 2, 83, 6, 87, 1, 34, 8, 63, 
    8, 95, 5, 25, 6, 53, 2, 39, 3, 91, 4, 70, 0, 54, 1, 63, 7, 99
  };
  const int q3550[] = {
    9, 9, // Number of jobs and machines
    1, 81, 8, 90, 6, 53, 3, 40, 0, 57, 5, 42, 2, 49, 4, 60, 7, 20, 
    2, 72, 4, 22, 0, 55, 3, 89, 5, 10, 8, 10, 7, 43, 1, 60, 6, 23, 
    3, 94, 0, 57, 4, 22, 1, 49, 8, 56, 2, 54, 5, 78, 7, 93, 6, 59, 
    3,  3, 5, 99, 6, 66, 7, 53, 0, 59, 4, 85, 2, 35, 8, 84, 1, 53, 
    3, 55, 4, 88, 5,  4, 7, 47, 2, 20, 6, 44, 8, 74, 1, 16, 0, 76, 
    5, 83, 7, 24, 0, 89, 8, 59, 1, 96, 6, 39, 3, 65, 2, 53, 4, 20, 
    6, 72, 3, 79, 4, 82, 8, 13, 2, 57, 0, 40, 1, 13, 5, 26, 7, 89, 
    8, 43, 2, 33, 0, 12, 1, 13, 4, 99, 5, 36, 7, 75, 6, 83, 3, 82, 
    3, 54, 7, 86, 2, 81, 5, 59, 8, 81, 6,  4, 0, 48, 4, 97, 1, 13
  };
  const int q3551[] = {
    9, 9, // Number of jobs and machines
    4, 75, 2, 30, 1,  6, 7, 97, 8, 56, 5, 43, 0, 21, 6, 29, 3, 74, 
    0, 99, 3, 55, 5, 92, 7,  1, 4, 62, 2, 35, 1,  7, 8, 32, 6, 51, 
    6, 87, 2, 15, 1, 57, 8, 91, 3, 67, 4, 29, 5,  7, 0, 26, 7, 71, 
    5,  9, 4, 88, 8, 71, 6, 64, 1, 31, 0, 72, 3, 87, 7, 64, 2, 90, 
    8, 19, 4, 89, 2, 53, 0, 46, 6, 61, 3, 96, 5, 85, 7, 27, 1, 49, 
    4, 60, 6, 57, 3, 31, 1, 73, 8, 54, 0, 47, 7, 71, 5, 61, 2, 81, 
    3, 43, 5, 73, 4,  6, 0, 67, 7, 99, 6, 73, 2, 20, 1, 27, 8, 22, 
    0, 76, 5, 58, 3,  1, 1,  7, 2, 54, 7, 70, 8, 59, 4, 77, 6, 42, 
    5, 92, 6, 86, 1, 80, 4, 80, 3, 37, 7,  4, 0, 31, 2, 33, 8, 35
  };
  const int q3552[] = {
    9, 9, // Number of jobs and machines
    1,  6, 5, 41, 8, 92, 2, 42, 7,  7, 6, 80, 3, 39, 0, 66, 4, 71, 
    6, 67, 1, 35, 8, 42, 0, 87, 5, 45, 4,  9, 3, 50, 7,  2, 2,  5, 
    8, 20, 7, 66, 1, 40, 5, 93, 2, 17, 3, 95, 0, 36, 6, 86, 4, 96, 
    6, 77, 5,  9, 0, 22, 1, 87, 4, 51, 8, 96, 2, 19, 3, 91, 7, 37, 
    5, 25, 0, 21, 6, 31, 7, 25, 3, 57, 4, 41, 2, 92, 1, 70, 8, 36, 
    0, 72, 3, 96, 6, 95, 5,  5, 7, 13, 2, 37, 8, 61, 1, 38, 4, 38, 
    4, 27, 2, 25, 6, 47, 0, 78, 3, 80, 7, 18, 8, 39, 1, 15, 5,  4, 
    6, 94, 8, 75, 3, 41, 2, 36, 5, 49, 1, 84, 4, 60, 0, 87, 7, 24, 
    3, 13, 0, 88, 1, 22, 6, 95, 8, 84, 4, 39, 2,  1, 7, 67, 5, 69
  };
  const int q3553[] = {
    9, 9, // Number of jobs and machines
    7, 23, 5, 27, 3, 78, 1, 34, 0, 83, 8,  4, 4,  6, 2, 40, 6,  6, 
    8, 47, 1, 97, 2,  2, 3, 34, 6, 59, 5, 41, 7,  7, 4, 14, 0,  2, 
    6, 12, 1, 67, 7, 69, 8, 38, 2, 79, 5, 21, 4, 89, 3, 11, 0, 10, 
    4, 61, 3, 68, 6, 79, 0, 84, 8, 12, 5, 29, 2, 73, 7, 65, 1,  2, 
    7, 40, 3, 91, 6, 70, 5, 83, 0, 16, 2, 22, 1, 97, 4, 72, 8, 86, 
    2, 37, 3, 57, 6, 63, 8, 14, 7, 73, 1, 86, 0, 85, 4, 72, 5, 68, 
    8, 42, 7,  7, 5, 81, 0, 96, 1, 48, 6,  8, 3, 26, 4, 49, 2, 64, 
    7, 37, 3, 67, 0, 10, 8, 92, 5,  7, 4, 45, 2, 62, 6, 11, 1, 14, 
    1, 35, 4, 65, 5, 34, 8, 58, 2, 26, 7, 50, 3, 27, 0, 43, 6, 24
  };
  const int q3554[] = {
    9, 9, // Number of jobs and machines
    2, 75, 1, 98, 7, 57, 5, 63, 3, 49, 4, 52, 6,  8, 8, 61, 0, 81, 
    8, 25, 3, 23, 7, 10, 2, 85, 5, 51, 1, 11, 6, 65, 0, 76, 4, 41, 
    0, 74, 3, 87, 6, 54, 2, 23, 5, 86, 1, 39, 7, 68, 4, 13, 8,  6, 
    1, 41, 5, 94, 7, 21, 6, 66, 8, 71, 3, 99, 2, 69, 4, 98, 0, 19, 
    6, 33, 1, 62, 7, 39, 0, 35, 8, 53, 2,  4, 3, 92, 5, 92, 4, 21, 
    3, 26, 5, 18, 0,  3, 8, 66, 1, 16, 4, 41, 7, 11, 2, 88, 6, 27, 
    4, 94, 0, 73, 7, 39, 5, 91, 2,  8, 8, 54, 1, 91, 6, 68, 3, 74, 
    2,  1, 0, 20, 6, 46, 4, 67, 7, 76, 8,  9, 5, 67, 3, 77, 1, 59, 
    1,  9, 5, 63, 4, 34, 0,  8, 7, 29, 2, 48, 6, 72, 8, 61, 3, 84
  };
  const int q3555[] = {
    9, 9, // Number of jobs and machines
    8,  2, 0, 78, 2,  5, 5, 57, 6, 17, 4, 68, 3, 97, 7, 38, 1, 83, 
    0, 75, 1, 26, 5, 96, 4,  9, 8, 11, 7, 11, 6, 44, 3, 31, 2, 55, 
    2,  6, 5, 87, 3,  2, 8, 45, 1, 93, 0, 81, 7, 99, 6, 87, 4, 53, 
    8, 38, 6, 44, 7, 96, 5, 21, 4, 42, 2, 35, 1, 70, 0, 64, 3,  8, 
    5, 62, 4,  7, 0, 32, 1, 10, 6, 56, 7, 70, 2, 29, 8, 91, 3,  3, 
    4, 31, 2, 39, 0, 89, 7, 70, 6, 55, 3, 31, 1, 66, 8, 19, 5, 57, 
    7, 89, 6, 72, 5, 46, 2,  2, 1,  2, 0, 57, 4, 58, 3, 31, 8, 94, 
    1, 99, 7, 37, 0, 39, 6, 48, 3, 21, 2, 74, 5, 44, 8, 50, 4, 39, 
    6, 86, 8, 16, 4, 38, 5, 18, 0, 21, 1, 49, 7, 44, 2, 81, 3, 94
  };
  const int q3556[] = {
    9, 9, // Number of jobs and machines
    3, 10, 7, 84, 6, 29, 0, 67, 4, 38, 2, 56, 8, 97, 5, 87, 1, 64, 
    4, 35, 1, 38, 5, 60, 6, 95, 0, 50, 7, 24, 2,  8, 8, 24, 3, 55, 
    3, 55, 7, 39, 8, 70, 1, 78, 5, 93, 2, 27, 4, 32, 6, 58, 0, 57, 
    1, 88, 6, 19, 2, 47, 3,  8, 5, 23, 8, 38, 0, 50, 4, 36, 7, 32, 
    0, 72, 8, 83, 2, 25, 4, 43, 6, 86, 3, 72, 5, 64, 1, 33, 7, 94, 
    5, 91, 8, 11, 3, 81, 7, 47, 4, 98, 1, 26, 2, 48, 6, 33, 0, 52, 
    0, 27, 5, 93, 1, 99, 4, 94, 8, 55, 3, 49, 7, 40, 6, 21, 2, 89, 
    2, 32, 3, 40, 4, 42, 0, 79, 6, 52, 1, 58, 5, 80, 7, 19, 8, 40, 
    3, 68, 5, 12, 6, 21, 4, 82, 1, 13, 2, 80, 0, 10, 7, 10, 8, 16
  };
  const int q3557[] = {
    9, 9, // Number of jobs and machines
    5, 26, 2, 71, 8, 65, 3, 62, 7, 87, 1,  3, 4, 85, 0, 11, 6, 32, 
    6, 71, 1, 54, 8, 80, 3, 59, 5, 98, 2, 42, 4, 25, 0, 14, 7, 27, 
    0, 60, 4, 82, 8, 83, 6, 29, 2, 99, 5, 32, 1, 33, 7, 80, 3,  8, 
    3, 39, 5, 23, 1, 84, 4, 32, 7,  8, 6, 48, 2, 97, 0, 17, 8, 66, 
    1, 27, 3,  3, 7, 45, 5, 47, 8, 48, 0, 60, 4, 50, 6, 23, 2, 25, 
    3, 28, 6,  6, 2, 45, 5, 63, 1, 27, 0, 24, 8,  9, 7, 12, 4,  6, 
    2, 29, 4, 95, 0, 53, 3, 98, 5, 46, 8,  3, 1, 26, 6, 45, 7, 52, 
    5, 40, 4, 50, 3, 21, 1, 64, 7,  4, 6, 46, 2, 55, 8,  5, 0, 64, 
    7, 10, 0, 48, 8, 55, 3,  4, 4, 20, 1, 15, 2, 27, 6, 74, 5, 35
  };
  const int q3558[] = {
    9, 9, // Number of jobs and machines
    7, 98, 5,  1, 6, 11, 3, 74, 8, 23, 2, 86, 4, 41, 0, 15, 1, 36, 
    8, 70, 3, 66, 7, 34, 0, 51, 1, 82, 2, 13, 4, 36, 6, 63, 5, 74, 
    0, 95, 6, 10, 5, 31, 4,  6, 8, 69, 3, 90, 7, 83, 2, 80, 1, 54, 
    0, 69, 3, 90, 7, 94, 2, 18, 8, 41, 4, 84, 6, 48, 5, 18, 1,  5, 
    2, 23, 0, 81, 1, 80, 7, 91, 6, 55, 3, 88, 4, 94, 8, 47, 5, 36, 
    3, 53, 4, 48, 5, 17, 2, 52, 7, 64, 6, 68, 8, 83, 0,  4, 1, 79, 
    4,  3, 5, 18, 2, 45, 3, 80, 0, 50, 7, 49, 1, 99, 6, 23, 8, 92, 
    6,  9, 0, 91, 5,  8, 7,  7, 3,  7, 8, 63, 4, 85, 1, 69, 2, 97, 
    1, 72, 0, 85, 4, 43, 6, 83, 7,  2, 8, 53, 3, 79, 5, 42, 2, 52
  };
  const int q3559[] = {
    9, 9, // Number of jobs and machines
    3, 51, 4, 35, 6, 84, 8, 66, 1, 53, 0, 28, 7, 51, 5,  8, 2, 60, 
    3, 86, 2, 70, 5, 52, 7,  3, 6, 15, 8, 88, 4,  6, 0, 43, 1, 45, 
    7, 29, 1, 59, 2, 34, 6, 87, 3, 79, 4, 28, 0, 20, 5, 34, 8, 28, 
    2,  1, 0, 86, 7, 32, 8, 24, 1, 89, 3, 25, 4, 56, 5, 82, 6, 91, 
    7, 35, 1, 88, 4, 72, 8, 68, 0, 44, 2, 16, 3, 72, 5, 91, 6,  6, 
    3, 10, 6, 42, 1, 83, 4, 44, 2,  2, 0, 73, 5, 87, 8,  3, 7, 14, 
    7, 80, 5, 73, 3, 73, 0, 13, 6, 36, 1, 46, 4, 80, 2, 34, 8, 98, 
    0, 54, 8, 60, 6, 24, 5, 62, 2, 25, 7, 48, 1,  8, 3, 98, 4, 83, 
    8, 13, 3, 39, 1, 98, 0, 36, 6, 52, 2, 93, 5, 91, 7, 45, 4, 40
  };
  const int q3560[] = {
    9, 9, // Number of jobs and machines
    3, 50, 7,  1, 1, 98, 0, 50, 8, 31, 5, 15, 6, 45, 2, 51, 4, 61, 
    0, 89, 3, 17, 7, 20, 6, 39, 5, 78, 1, 74, 8, 26, 4, 42, 2, 36, 
    6, 67, 3,  4, 1, 28, 5, 53, 0, 61, 8, 43, 7, 45, 2,  2, 4, 71, 
    1, 81, 6, 19, 3, 47, 8, 36, 5, 37, 0, 12, 2, 38, 4, 66, 7, 68, 
    3, 39, 4, 90, 2, 22, 6, 25, 0,  8, 8, 15, 1, 81, 5, 26, 7,  2, 
    6, 26, 5, 14, 1, 98, 0, 69, 3, 11, 4, 18, 8, 50, 2, 94, 7, 71, 
    3, 18, 4, 40, 7, 75, 8, 76, 0, 85, 1, 31, 6, 36, 5, 78, 2, 58, 
    1, 43, 3, 84, 0, 62, 8, 29, 6, 76, 4, 49, 2, 89, 7, 48, 5, 61, 
    5, 54, 7, 41, 1, 84, 6,  3, 2, 92, 3, 54, 8, 13, 4, 57, 0, 30
  };
  const int q3561[] = {
    9, 9, // Number of jobs and machines
    6, 93, 4, 86, 0, 10, 2, 39, 8, 19, 5, 41, 3, 76, 7, 13, 1, 11, 
    5, 49, 4, 20, 3, 55, 7, 37, 6, 99, 8, 23, 1, 36, 2, 52, 0, 98, 
    8, 39, 0, 56, 6, 31, 1, 39, 2, 50, 4, 15, 5, 93, 7,  9, 3, 21, 
    2, 29, 0, 39, 1, 73, 7, 11, 5, 65, 4, 85, 3, 94, 6, 17, 8, 19, 
    2, 51, 7,  3, 1, 32, 5, 66, 0, 50, 3, 38, 4, 97, 8, 66, 6, 19, 
    0, 38, 5, 38, 4, 65, 2,  9, 7, 10, 3, 63, 8, 44, 6, 31, 1, 87, 
    8, 88, 6, 53, 7, 67, 0, 70, 4, 12, 2, 43, 5, 13, 3, 78, 1, 41, 
    6, 37, 4, 69, 1, 39, 5, 88, 8, 55, 7, 82, 2, 25, 0, 35, 3, 57, 
    3, 52, 8, 69, 1, 89, 7,  7, 6, 91, 2, 93, 5, 12, 4, 15, 0, 37
  };
  const int q3562[] = {
    9, 9, // Number of jobs and machines
    2, 45, 5,  7, 4, 94, 6, 41, 0, 59, 3, 35, 7, 14, 1, 39, 8, 81, 
    3, 20, 4, 16, 6, 84, 5, 62, 2, 69, 7, 40, 8, 64, 1, 78, 0, 45, 
    5, 98, 0,  4, 6, 88, 3, 23, 2,  2, 4, 30, 7, 23, 1, 35, 8, 64, 
    5, 42, 3, 90, 0, 77, 4, 55, 1, 64, 6, 47, 2, 55, 8, 13, 7,  5, 
    1, 48, 6, 31, 0, 70, 2, 24, 3, 93, 8, 64, 5,  8, 7, 39, 4, 20, 
    4, 27, 6, 33, 2, 50, 0, 65, 7, 58, 8, 20, 5, 77, 1, 36, 3, 92, 
    6, 67, 7, 42, 0, 78, 2,  3, 1, 78, 4, 55, 8, 36, 3, 79, 5, 28, 
    7, 38, 4, 90, 6, 36, 0, 39, 1, 17, 5, 27, 8, 29, 3,  8, 2, 18, 
    1, 48, 4, 69, 3, 88, 7, 48, 6, 76, 2, 58, 5, 65, 0, 14, 8, 91
  };
  const int q3563[] = {
    9, 9, // Number of jobs and machines
    6, 93, 5, 47, 7, 28, 3, 35, 2, 99, 0, 32, 4, 42, 8, 19, 1, 83, 
    4, 64, 2, 61, 8, 83, 7, 88, 1, 72, 5, 50, 3, 44, 6,  8, 0, 22, 
    4, 33, 5, 61, 6, 69, 3, 70, 8, 48, 7, 25, 1, 28, 2,  3, 0,  4, 
    5, 63, 8, 54, 0, 19, 1, 60, 2, 39, 7, 36, 6, 72, 3, 90, 4, 81, 
    5, 19, 2, 59, 6, 91, 8, 28, 1, 87, 3, 51, 7, 37, 0, 76, 4,  9, 
    5, 35, 2, 20, 4,  7, 1, 57, 0, 47, 8, 49, 6, 23, 7, 26, 3, 45, 
    4, 62, 8, 84, 5, 43, 3, 63, 6, 31, 1,  6, 2, 49, 7, 53, 0, 66, 
    4, 21, 8, 93, 5, 61, 1, 48, 0, 85, 3,  5, 6, 41, 7, 92, 2, 17, 
    3, 67, 1, 94, 4, 97, 2,  9, 0, 72, 6, 71, 7,  8, 5, 25, 8, 24
  };
  const int q3564[] = {
    9, 9, // Number of jobs and machines
    3, 26, 8, 51, 4, 56, 2,  1, 6, 23, 7, 23, 1, 38, 0, 70, 5, 66, 
    0, 21, 4, 64, 7, 38, 3, 28, 1, 28, 6, 15, 2, 57, 5, 44, 8, 35, 
    2, 65, 6, 11, 4, 95, 1, 40, 5, 56, 8, 58, 0, 90, 7, 58, 3, 71, 
    5, 86, 2, 55, 0, 85, 3, 27, 4, 64, 6, 40, 7, 25, 1, 23, 8, 64, 
    4, 91, 3, 22, 0, 55, 1, 86, 6,  5, 8, 52, 7, 87, 2,  9, 5, 24, 
    0, 81, 6, 51, 5, 95, 1, 48, 7, 99, 8, 25, 3, 35, 2, 96, 4, 11, 
    6,  4, 7, 21, 4, 64, 5, 11, 1, 56, 0, 47, 8, 93, 2, 14, 3, 52, 
    1,  4, 7, 94, 4, 43, 8, 38, 0, 46, 6, 81, 3, 84, 2, 72, 5,  6, 
    3, 78, 7, 43, 8, 80, 4, 58, 1,  2, 6, 55, 2, 95, 0, 18, 5, 29
  };
  const int q3565[] = {
    9, 9, // Number of jobs and machines
    0, 31, 2, 38, 1, 52, 6, 96, 4, 32, 7,  5, 5, 65, 8, 69, 3, 87, 
    2, 78, 7, 24, 6, 11, 5, 52, 4, 47, 0, 69, 1, 94, 8, 38, 3, 19, 
    3, 58, 8, 62, 7, 98, 5, 54, 0, 11, 1, 65, 2, 39, 6, 66, 4, 66, 
    6, 89, 3,  5, 0, 76, 8, 51, 5, 87, 4, 90, 2, 33, 1, 47, 7,  4, 
    6, 97, 4, 10, 0, 10, 8, 81, 1, 82, 3, 69, 2, 82, 7, 54, 5, 59, 
    6, 17, 5, 71, 1,  4, 4, 95, 0, 79, 2, 83, 3, 64, 7, 34, 8, 35, 
    2, 77, 3,  8, 1, 13, 6, 82, 0, 15, 5, 16, 8, 13, 4, 66, 7, 43, 
    4, 87, 0, 23, 3, 22, 2, 96, 1, 48, 5, 79, 6,  1, 7, 16, 8,  7, 
    8, 83, 4, 31, 7, 53, 5, 45, 1, 85, 6, 85, 0, 49, 2, 70, 3, 38
  };
  const int q3566[] = {
    9, 9, // Number of jobs and machines
    2, 77, 5, 38, 0, 61, 8, 84, 4, 59, 6, 91, 7, 78, 1, 22, 3, 14, 
    6, 22, 4, 19, 7, 85, 2, 25, 0, 43, 3, 67, 1, 14, 5, 97, 8, 85, 
    1, 76, 4,  6, 7,  8, 2, 92, 6, 50, 8, 55, 5, 40, 0, 44, 3, 86, 
    6, 81, 1, 83, 2, 53, 4, 51, 5, 18, 8,  3, 3, 33, 7, 27, 0, 92, 
    7, 61, 3, 11, 1, 32, 6, 66, 5, 32, 2, 31, 4, 16, 8, 76, 0, 58, 
    2, 62, 6, 18, 5, 13, 0,  6, 3, 64, 4, 36, 8, 24, 7, 44, 1, 72, 
    1, 79, 6, 34, 5, 50, 8, 18, 0, 16, 3, 65, 2, 82, 4, 66, 7, 66, 
    6, 50, 5, 32, 7, 55, 2,  2, 0, 71, 1, 52, 8,  8, 4, 18, 3, 27, 
    4, 72, 1, 76, 3, 29, 2, 13, 7,  2, 5, 87, 0, 78, 8,  4, 6, 27
  };
  const int q3567[] = {
    9, 9, // Number of jobs and machines
    1, 85, 0, 78, 5, 65, 6, 16, 7, 29, 2, 64, 8, 71, 4, 64, 3, 33, 
    5, 86, 3, 51, 1, 45, 6, 49, 8, 53, 2, 41, 0, 10, 4, 77, 7, 40, 
    5, 11, 4, 58, 7, 52, 8, 30, 1, 66, 6,  1, 2, 60, 0, 57, 3, 50, 
    6, 15, 0, 97, 2, 53, 7, 60, 8, 10, 1, 40, 3, 29, 5,  6, 4, 62, 
    5, 29, 7, 35, 2,  4, 4, 28, 1, 53, 0, 35, 3, 95, 8,  9, 6, 49, 
    0, 46, 3, 80, 1, 35, 4,  1, 5, 43, 6, 75, 8, 82, 2, 19, 7, 43, 
    2, 13, 0, 64, 6, 96, 5, 59, 7, 94, 1,  1, 3, 61, 4,  7, 8, 61, 
    1,  3, 6,  2, 8, 58, 0, 71, 2, 40, 5,  9, 3, 70, 4, 82, 7, 11, 
    7, 67, 8, 49, 1, 67, 2, 91, 4, 90, 5, 97, 3, 91, 0, 60, 6, 56
  };
  const int q3568[] = {
    9, 9, // Number of jobs and machines
    1, 47, 5, 99, 0, 86, 8, 36, 2, 41, 7, 81, 4, 78, 6, 48, 3, 38, 
    8, 93, 6, 51, 7, 56, 5, 52, 1, 47, 2, 76, 0, 13, 3, 98, 4, 98, 
    0, 74, 5, 11, 8, 14, 7, 52, 6, 66, 3, 58, 1, 52, 2, 68, 4, 41, 
    1, 80, 5, 78, 2, 29, 6, 61, 7,  4, 0, 91, 8, 61, 4, 19, 3, 98, 
    2, 62, 4, 33, 8, 58, 5, 58, 0, 48, 1, 92, 6, 89, 3, 41, 7, 28, 
    4, 83, 2, 70, 7,  9, 0, 53, 6, 71, 5, 91, 3, 88, 8, 91, 1, 88, 
    0, 92, 1, 65, 6, 94, 4, 25, 8, 56, 2, 39, 3, 91, 7, 74, 5, 60, 
    4, 77, 5, 78, 7, 17, 2, 30, 0, 79, 1, 80, 3,  8, 8, 67, 6, 62, 
    8,  9, 2, 63, 3, 52, 7, 43, 5,  1, 0, 16, 6, 40, 1, 31, 4, 86
  };
  const int q3569[] = {
    9, 9, // Number of jobs and machines
    2, 98, 8, 66, 3, 60, 6, 56, 4, 79, 7, 85, 0, 94, 1, 21, 5, 80, 
    0, 37, 1, 42, 4, 56, 2, 35, 6, 22, 5, 72, 7, 57, 3,  6, 8, 33, 
    0, 15, 3, 70, 7, 30, 5, 12, 6,  1, 4, 92, 8, 16, 1, 40, 2, 29, 
    6,  4, 4, 14, 2, 15, 1,  5, 5, 95, 3, 37, 0, 69, 8, 98, 7, 85, 
    3, 65, 5,  1, 1, 25, 0, 84, 7, 80, 6, 43, 8, 28, 4, 81, 2, 59, 
    4, 63, 1,  7, 0, 34, 3, 67, 6, 86, 2, 34, 5, 71, 7,  1, 8, 92, 
    6, 72, 8, 56, 1, 91, 5, 96, 3,  4, 0, 77, 2, 21, 7,  8, 4,  4, 
    8,  5, 3,  2, 5, 16, 6, 35, 7, 49, 2, 10, 1, 72, 4, 70, 0, 68, 
    2, 75, 1, 61, 6, 41, 4, 97, 0, 60, 3, 87, 5, 41, 8, 78, 7, 97
  };
  const int q3570[] = {
    9, 9, // Number of jobs and machines
    0, 12, 2, 27, 6, 80, 8, 70, 4, 58, 5, 21, 1, 29, 7, 12, 3, 19, 
    4, 46, 5, 69, 2, 53, 1, 83, 8, 57, 3, 60, 6, 17, 7, 45, 0, 92, 
    1, 28, 4, 19, 3, 45, 0, 28, 2, 10, 8, 91, 7, 34, 6, 92, 5, 75, 
    3, 43, 0,  7, 1, 96, 2,  4, 7, 71, 8, 80, 4, 16, 6, 87, 5, 45, 
    6, 23, 0,  6, 5, 39, 1, 45, 4, 43, 8, 71, 3, 39, 7, 19, 2, 88, 
    7, 92, 5, 99, 4, 39, 2,  9, 1, 88, 3, 54, 8, 40, 0, 45, 6, 14, 
    1, 52, 2, 40, 0, 48, 5, 38, 7, 19, 4,  9, 6, 20, 3, 20, 8, 50, 
    2, 49, 4, 26, 5, 25, 0, 49, 3, 45, 1, 65, 8, 87, 6, 47, 7, 47, 
    5, 10, 4, 31, 8, 28, 2, 63, 7, 23, 1, 48, 0, 63, 6, 94, 3, 22
  };
  const int q3571[] = {
    9, 9, // Number of jobs and machines
    2, 23, 7, 81, 5, 53, 3, 74, 8, 89, 6, 60, 0, 86, 4, 89, 1, 95, 
    4, 44, 7,  1, 2, 22, 8, 29, 3, 18, 0, 94, 5, 84, 6, 70, 1, 92, 
    3, 53, 1, 96, 4, 91, 6, 31, 7, 12, 0, 91, 2, 48, 5, 79, 8, 51, 
    0, 16, 4, 61, 1, 59, 3, 78, 8,  3, 2,  6, 7, 70, 5, 28, 6,  8, 
    3,  7, 0, 66, 1, 70, 7, 83, 2, 65, 8, 90, 4, 85, 5, 62, 6, 36, 
    3, 62, 5, 70, 1, 41, 4, 46, 2, 79, 8, 85, 6, 52, 0, 50, 7, 85, 
    4, 77, 2, 69, 3, 13, 8, 10, 1, 59, 6, 61, 0, 52, 5, 91, 7, 72, 
    8, 87, 1, 43, 2, 45, 6, 79, 0, 20, 5, 47, 3, 85, 7, 12, 4, 56, 
    5, 57, 6, 71, 4, 94, 0, 87, 1, 67, 2, 44, 7, 86, 3, 36, 8, 18
  };
  const int q3572[] = {
    9, 9, // Number of jobs and machines
    0, 81, 8, 35, 5, 57, 7, 91, 6, 39, 3,  5, 1, 80, 2, 66, 4, 87, 
    5, 64, 8, 55, 2,  2, 4, 51, 6, 59, 0, 32, 3, 95, 7, 70, 1, 32, 
    7, 32, 5, 42, 0, 96, 3, 57, 8, 53, 6, 62, 2, 13, 4, 74, 1,  2, 
    4, 12, 7, 11, 2, 24, 3, 36, 0, 71, 8, 63, 5, 11, 6, 23, 1, 72, 
    0, 28, 3, 34, 4, 76, 5, 91, 8, 44, 6, 50, 2, 10, 1, 60, 7, 27, 
    1, 68, 8, 98, 4, 20, 7, 99, 3, 65, 5, 86, 2, 58, 6, 49, 0, 56, 
    1, 11, 6, 86, 0, 48, 5, 11, 4,  4, 8, 48, 3, 98, 2, 13, 7, 24, 
    3, 69, 2, 50, 6, 61, 7, 56, 0, 89, 4, 75, 5, 57, 8, 46, 1, 13, 
    4, 58, 0, 52, 1, 66, 2, 85, 5, 13, 7, 32, 6, 97, 3, 41, 8, 93
  };
  const int q3573[] = {
    9, 9, // Number of jobs and machines
    0, 13, 4, 10, 7, 29, 6, 38, 2, 86, 8, 88, 3, 85, 5, 16, 1, 65, 
    7, 46, 8, 28, 3, 55, 4, 48, 6, 33, 1, 77, 5, 75, 2, 79, 0, 53, 
    4, 87, 1, 39, 2, 39, 3, 14, 5, 69, 7,  1, 6, 90, 8, 13, 0,  5, 
    0, 41, 1, 88, 3, 49, 8, 26, 5, 89, 4, 94, 6, 50, 7, 15, 2,  2, 
    4, 92, 7, 55, 2,  3, 5, 50, 1, 39, 0, 93, 8, 35, 3, 46, 6,  9, 
    8, 57, 1, 87, 5, 62, 7, 22, 4, 51, 0, 76, 3, 97, 2, 46, 6, 90, 
    3, 94, 7, 31, 2, 52, 5, 48, 6, 93, 1, 53, 4, 95, 0, 69, 8, 57, 
    0, 61, 6, 12, 7, 13, 1, 79, 8, 12, 2, 82, 4, 83, 3, 39, 5, 88, 
    2, 27, 5, 86, 1, 97, 6, 25, 7, 35, 8, 32, 0, 94, 3, 82, 4, 31
  };
  const int q3574[] = {
    9, 9, // Number of jobs and machines
    2, 10, 6, 14, 1, 10, 7, 85, 3, 54, 8, 54, 0, 94, 4, 96, 5, 19, 
    4, 27, 3, 36, 5, 44, 2, 13, 8, 36, 1, 67, 7, 21, 6, 31, 0, 75, 
    6, 79, 3, 76, 8, 48, 2, 12, 5, 47, 0, 36, 7, 88, 1, 57, 4, 77, 
    4, 97, 3, 81, 2, 30, 7, 95, 8, 89, 1, 13, 6, 49, 0, 16, 5, 94, 
    0, 32, 4,  4, 5,  4, 3, 21, 8, 17, 6, 96, 1, 20, 7, 65, 2, 77, 
    0, 46, 7, 46, 4, 18, 1, 33, 3, 47, 8, 94, 2, 57, 5,  3, 6, 28, 
    8, 68, 6, 51, 4, 35, 1, 95, 7, 39, 0, 98, 5, 94, 3, 61, 2, 50, 
    3, 42, 7, 10, 0, 80, 5, 51, 6, 49, 1, 12, 2, 96, 4, 56, 8, 53, 
    1, 79, 6, 25, 3, 55, 8, 64, 7, 31, 2, 10, 4, 83, 5, 57, 0, 64
  };
  const int q3575[] = {
    9, 9, // Number of jobs and machines
    5, 41, 0, 16, 3, 78, 4, 99, 8,  1, 6, 46, 7, 36, 1,  6, 2, 30, 
    8, 25, 2, 32, 5, 10, 3, 82, 0, 91, 1, 57, 6, 32, 7,  7, 4, 81, 
    7, 81, 3, 15, 1, 72, 2, 58, 8, 73, 0, 52, 6, 13, 4, 12, 5,  7, 
    3, 42, 7, 96, 8, 28, 2, 16, 4, 80, 5, 56, 1, 77, 6, 40, 0, 40, 
    5, 12, 6, 64, 2, 78, 8, 18, 3, 94, 7, 41, 1, 81, 4, 56, 0, 53, 
    3, 67, 8, 24, 1, 17, 7, 41, 0, 10, 6, 26, 4, 70, 2, 78, 5, 53, 
    1, 11, 6, 45, 3, 58, 0, 91, 8, 25, 5,  5, 7, 54, 2, 79, 4, 82, 
    1, 88, 6, 78, 2, 99, 8, 10, 7, 29, 3, 80, 0, 63, 4, 16, 5, 71, 
    2, 89, 1, 63, 4, 85, 7, 43, 5, 14, 8, 45, 3, 55, 6,  4, 0, 40
  };
  const int q3576[] = {
    9, 9, // Number of jobs and machines
    5, 99, 2, 46, 3, 49, 1, 94, 0, 83, 8,  4, 7, 17, 4, 88, 6, 25, 
    6, 46, 3, 62, 0,  8, 1, 16, 5, 85, 4, 46, 8, 46, 2, 26, 7, 88, 
    2, 67, 1, 42, 7, 49, 0,  4, 3, 58, 8,  2, 4, 61, 5, 34, 6, 43, 
    5, 62, 4, 57, 0, 85, 2, 42, 6, 80, 1, 51, 8, 93, 3, 31, 7, 53, 
    1, 70, 0, 85, 8, 35, 2, 46, 7, 41, 6, 16, 5, 99, 3, 68, 4, 66, 
    1, 54, 7, 91, 4, 78, 8, 13, 0, 21, 2, 73, 6, 25, 5, 91, 3, 65, 
    1, 66, 8, 70, 0, 35, 7, 83, 4, 45, 6, 69, 5,  5, 2, 89, 3, 25, 
    2, 94, 6, 86, 5,  2, 7, 94, 0, 15, 8, 56, 1, 94, 3, 10, 4, 75, 
    2, 28, 3, 17, 7, 82, 0, 76, 6, 25, 1, 90, 4, 48, 8, 55, 5, 57
  };
  const int q3577[] = {
    9, 9, // Number of jobs and machines
    2, 96, 7, 56, 0, 26, 5, 97, 6, 15, 1, 38, 4, 82, 8, 57, 3,  1, 
    7, 86, 6,  8, 1, 48, 5, 21, 2, 36, 8,  7, 4, 84, 3, 78, 0, 79, 
    1,  9, 8, 60, 3, 14, 7, 56, 2, 78, 5, 56, 0, 33, 4, 84, 6, 31, 
    0, 62, 4, 32, 8, 69, 7, 50, 6, 23, 1, 53, 5, 51, 2, 27, 3, 67, 
    8, 84, 2, 98, 6, 37, 5, 55, 3, 32, 7, 94, 0, 17, 4, 59, 1, 83, 
    5, 11, 6, 82, 8, 98, 1, 15, 4, 13, 2, 44, 7, 45, 0, 53, 3,  7, 
    8, 85, 1, 57, 4, 68, 7, 70, 0, 86, 5, 14, 2, 93, 6, 73, 3, 38, 
    6, 48, 2, 29, 5,  9, 0,  5, 3, 68, 8,  3, 7, 94, 4, 58, 1, 65, 
    7, 70, 5, 48, 0, 51, 1, 53, 8, 46, 4, 99, 6, 78, 2,  6, 3, 94
  };
  const int q3578[] = {
    9, 9, // Number of jobs and machines
    3, 21, 4, 98, 0, 59, 7, 32, 1,  5, 5, 92, 6, 43, 2, 22, 8, 27, 
    1, 43, 6, 45, 7, 80, 8, 69, 5, 40, 4, 61, 2, 45, 3, 43, 0, 75, 
    6, 63, 2, 70, 5, 74, 8, 80, 1,  2, 4, 68, 0, 81, 7, 36, 3, 71, 
    0, 29, 5, 29, 1, 41, 2, 40, 8, 82, 3, 49, 6, 36, 4, 46, 7, 12, 
    0,  1, 3, 11, 4, 59, 7, 60, 6, 82, 8,  4, 2, 85, 1, 78, 5, 84, 
    0, 27, 1,  5, 4, 29, 5, 52, 8, 25, 6,  8, 3, 43, 7, 99, 2, 34, 
    4, 15, 7, 96, 1, 56, 6,  5, 0, 10, 5, 46, 8, 83, 2, 18, 3, 23, 
    4, 27, 2, 28, 5, 37, 7, 30, 3, 81, 0, 14, 6,  2, 8, 61, 1, 81, 
    3, 32, 2, 96, 6, 30, 1, 82, 5, 50, 0, 75, 7, 21, 8, 98, 4, 63
  };
  const int q3579[] = {
    9, 9, // Number of jobs and machines
    7, 25, 1, 28, 3, 35, 0, 42, 4, 11, 2, 34, 5, 11, 6,  3, 8, 84, 
    3, 30, 5, 84, 4, 59, 7, 93, 6, 19, 1, 38, 2, 49, 8, 95, 0, 81, 
    4, 40, 6, 50, 0,  3, 5, 13, 2, 28, 1, 85, 7, 17, 8, 83, 3, 69, 
    0,  5, 1, 79, 2, 32, 7, 64, 5, 18, 8, 70, 4, 50, 6, 64, 3, 63, 
    1, 58, 0, 36, 8, 65, 4, 74, 3, 91, 7, 58, 2, 31, 5,  3, 6, 84, 
    8, 46, 5, 15, 6, 37, 1, 15, 3,  8, 2, 55, 4, 40, 7, 19, 0, 67, 
    7, 37, 5, 14, 3, 60, 4, 32, 1, 13, 6, 39, 8, 67, 0, 70, 2, 48, 
    1, 73, 8, 72, 3, 70, 2, 38, 5, 58, 0, 56, 7, 18, 4,  5, 6, 97, 
    0, 54, 8, 44, 3, 74, 4,  2, 2, 54, 1, 48, 6,  1, 7, 55, 5, 70
  };
  const int q3580[] = {
    9, 9, // Number of jobs and machines
    1, 83, 7, 31, 2, 31, 5, 18, 6,  2, 0, 35, 3, 95, 8, 35, 4, 98, 
    6, 74, 2, 95, 1, 34, 4, 80, 3, 58, 7,  6, 8,  6, 0, 61, 5, 67, 
    6, 20, 1, 66, 2, 66, 4, 72, 3, 84, 0, 85, 8, 15, 7,  4, 5, 67, 
    7, 99, 5, 38, 4, 56, 8, 83, 0, 85, 2, 66, 6,  4, 1, 89, 3, 52, 
    7, 72, 0, 16, 4, 90, 1, 41, 3, 93, 5, 35, 6, 45, 2, 59, 8, 28, 
    4, 38, 7,  2, 1, 64, 2, 15, 8,  4, 0, 69, 6, 57, 3, 95, 5, 46, 
    8, 42, 4, 63, 5, 94, 0, 46, 1, 62, 2, 63, 3, 65, 6, 98, 7, 49, 
    2, 83, 8, 84, 3, 87, 0, 95, 7, 92, 4, 38, 5, 10, 1, 96, 6, 62, 
    7,  5, 3, 92, 4,  2, 6, 23, 2, 95, 0, 83, 1, 40, 5, 14, 8, 38
  };
  const int q3581[] = {
    9, 9, // Number of jobs and machines
    4, 98, 7, 47, 6, 86, 0, 76, 5,  4, 3, 56, 8,  9, 2, 72, 1, 73, 
    5, 34, 2, 26, 7, 20, 6, 31, 4, 92, 1, 19, 8, 47, 0,  4, 3, 53, 
    7, 22, 2, 67, 1, 32, 0, 85, 3, 38, 5, 12, 4, 61, 6, 60, 8, 84, 
    2, 96, 1, 15, 5, 54, 0, 47, 6, 91, 4,  6, 3, 59, 7, 11, 8, 72, 
    6, 25, 2, 28, 4, 79, 0, 67, 5,  5, 8, 97, 1, 93, 7, 28, 3, 73, 
    8, 73, 3, 67, 6, 82, 2, 72, 0, 95, 7, 79, 4, 80, 1, 19, 5, 94, 
    1, 49, 2, 14, 3, 61, 4,  4, 5, 16, 8, 17, 7, 20, 6, 10, 0, 15, 
    6, 18, 8, 61, 0, 78, 3, 61, 5, 86, 1, 93, 2, 80, 7, 77, 4, 38, 
    2, 92, 0, 42, 6, 13, 8, 90, 5, 12, 4,  2, 1, 94, 7, 95, 3, 85
  };
  const int q3582[] = {
    9, 9, // Number of jobs and machines
    6, 19, 7, 52, 0, 81, 8, 65, 1, 65, 2, 54, 4,  4, 3, 45, 5, 73, 
    1, 30, 3, 49, 6, 99, 2, 45, 5, 30, 0, 69, 8, 24, 4, 92, 7, 89, 
    4, 22, 5, 71, 7, 19, 6, 15, 8, 54, 1, 50, 2, 99, 3, 28, 0, 25, 
    8, 32, 4, 37, 0,  2, 3, 37, 2, 42, 5, 21, 7,  4, 1, 81, 6, 11, 
    2, 91, 3,  2, 8, 22, 4, 80, 1, 19, 5, 59, 0, 76, 6, 79, 7, 52, 
    5, 39, 0, 54, 4, 30, 8, 35, 7, 49, 3, 22, 6, 82, 1, 21, 2, 45, 
    5, 17, 3, 19, 8, 76, 6, 74, 2, 87, 7, 33, 1, 42, 4, 34, 0, 55, 
    5, 78, 2, 62, 3, 44, 7, 51, 4, 33, 6, 93, 8, 63, 0, 95, 1, 47, 
    8,  4, 1, 70, 0, 91, 4, 52, 5, 81, 6, 73, 2, 32, 3,  6, 7, 64
  };
  const int q3583[] = {
    9, 9, // Number of jobs and machines
    1, 74, 3, 35, 4, 97, 6, 26, 7, 11, 2, 26, 5, 59, 8, 42, 0,  3, 
    6, 76, 4, 68, 1, 74, 7, 74, 0, 47, 3, 46, 8, 98, 2,  4, 5, 88, 
    6, 43, 4, 46, 2, 26, 3, 92, 8, 91, 1, 38, 5, 39, 0, 33, 7, 86, 
    7, 66, 2, 84, 6, 66, 5, 64, 4,  9, 0,  3, 8,  9, 1, 53, 3, 52, 
    1, 48, 8, 60, 5, 25, 7, 96, 3, 59, 6,  8, 4,  1, 0, 16, 2, 50, 
    0, 88, 2, 33, 4,  2, 1, 70, 6,  1, 8, 58, 7,  9, 3, 88, 5, 66, 
    6, 79, 3, 13, 1, 39, 5, 96, 4, 66, 8, 10, 7, 27, 2,  4, 0,  8, 
    0, 81, 6, 13, 7, 96, 3, 17, 8, 84, 2, 23, 5, 78, 1, 24, 4, 47, 
    6, 32, 1, 66, 3, 56, 5, 31, 4, 30, 2,  7, 7, 75, 8, 21, 0, 43
  };
  const int q3584[] = {
    9, 9, // Number of jobs and machines
    3, 32, 8, 28, 6, 40, 2, 71, 7, 87, 5, 11, 4, 40, 0, 42, 1, 49, 
    5, 93, 3, 51, 7, 62, 6, 23, 2, 85, 0, 73, 1, 42, 8,  6, 4, 92, 
    7, 39, 8, 93, 2, 96, 4, 62, 0, 49, 6, 57, 3, 49, 5, 74, 1, 69, 
    1, 76, 8, 21, 5, 99, 6, 98, 4,  8, 3, 85, 7, 45, 0, 11, 2, 49, 
    4, 30, 3, 28, 7, 90, 0, 16, 5, 26, 6,  8, 8, 53, 1, 88, 2, 39, 
    4, 85, 5,  2, 8, 20, 7, 46, 3, 78, 2, 10, 1, 70, 0, 60, 6, 13, 
    7, 29, 1, 48, 3, 46, 8, 25, 0, 49, 2, 64, 4, 47, 5, 18, 6, 31, 
    5, 70, 1, 23, 3, 99, 2, 22, 7, 21, 4, 77, 8,  2, 6, 41, 0, 58, 
    1, 74, 2, 83, 8, 51, 3, 85, 5, 80, 4,  8, 6, 50, 7, 48, 0,  9
  };
  const int q3585[] = {
    9, 9, // Number of jobs and machines
    3, 81, 1, 29, 6, 99, 7, 91, 0, 99, 2, 35, 8, 44, 5,  1, 4, 41, 
    0, 80, 2, 42, 8, 98, 3, 15, 7, 44, 1, 88, 6,  9, 5, 20, 4, 51, 
    6, 30, 0, 14, 1, 63, 2, 49, 3, 79, 5, 49, 7,  6, 4, 23, 8, 23, 
    6, 61, 1, 37, 3, 37, 7, 54, 4,  3, 5, 12, 2, 76, 8, 38, 0, 15, 
    0, 35, 4, 92, 2, 82, 3, 83, 6, 96, 5, 26, 7, 52, 8, 29, 1, 97, 
    1, 91, 5, 31, 7, 63, 4, 61, 3, 55, 0, 45, 6, 83, 8, 86, 2,  8, 
    6, 76, 1, 35, 8, 40, 5, 90, 2, 42, 3, 60, 0, 91, 4, 92, 7, 93, 
    2, 13, 7, 14, 1, 33, 3, 54, 6, 68, 8, 20, 5, 92, 4, 92, 0, 40, 
    7, 54, 2, 99, 3,  1, 6, 95, 4, 90, 0, 77, 8, 26, 5, 27, 1, 94
  };
  const int q3586[] = {
    9, 9, // Number of jobs and machines
    8, 10, 1,  3, 3, 41, 0, 62, 5, 23, 7, 61, 4, 49, 2, 60, 6, 95, 
    0, 26, 4, 27, 2, 79, 1, 19, 5, 71, 6, 82, 8, 36, 7, 71, 3, 72, 
    6, 23, 5, 40, 8,  3, 2, 42, 4, 78, 3, 42, 7, 88, 1, 52, 0, 14, 
    0, 50, 7, 80, 6, 26, 1, 29, 3, 48, 8, 42, 4, 97, 2,  6, 5, 93, 
    2, 18, 0,  1, 1, 55, 5,  8, 6,  6, 8, 80, 7, 18, 4, 89, 3, 16, 
    0, 90, 5, 30, 3, 10, 1,  8, 7,  6, 8,  4, 4, 98, 6, 40, 2, 85, 
    2, 92, 1,  5, 6, 79, 5, 53, 4, 50, 3, 68, 8, 33, 0, 20, 7, 14, 
    7, 86, 3, 26, 2,  2, 1, 46, 8, 40, 5, 63, 6, 88, 4, 80, 0, 30, 
    5, 98, 1, 28, 3, 37, 6, 46, 0,  6, 2, 38, 7, 49, 8, 44, 4, 67
  };
  const int q3587[] = {
    9, 9, // Number of jobs and machines
    0,  1, 7,  8, 5, 87, 3, 19, 8, 15, 6, 57, 2, 73, 1, 56, 4, 17, 
    4, 21, 0, 96, 2, 91, 3, 24, 6, 26, 1, 32, 5, 85, 7, 45, 8, 76, 
    4, 79, 5,  5, 1, 55, 0,  2, 8, 36, 3, 47, 2,  8, 7, 62, 6, 60, 
    8, 54, 6, 57, 3, 12, 2, 49, 4, 72, 0, 93, 5, 21, 7, 40, 1, 80, 
    6, 68, 0, 53, 1, 42, 4, 83, 8, 32, 5,  3, 7, 29, 3, 24, 2, 28, 
    3, 19, 0, 16, 1, 19, 2, 98, 6, 47, 8, 24, 4, 13, 5, 41, 7, 85, 
    5, 53, 2, 79, 1, 41, 7, 75, 3, 32, 6, 31, 8, 80, 0, 12, 4,  8, 
    8, 50, 7, 62, 3, 14, 5, 34, 4, 88, 1, 96, 0, 90, 2, 50, 6, 74, 
    8, 67, 7, 91, 1, 32, 3, 54, 2, 87, 0, 49, 6, 76, 4, 96, 5, 28
  };
  const int q3588[] = {
    9, 9, // Number of jobs and machines
    8, 31, 3, 92, 2, 61, 4, 62, 1, 14, 5, 56, 7, 74, 0,  9, 6, 53, 
    7, 48, 8,  3, 2, 86, 1, 54, 5, 17, 4, 57, 3, 16, 6, 53, 0, 18, 
    3, 54, 6, 76, 1,  1, 7, 47, 5, 60, 4, 88, 2, 86, 8, 84, 0,  7, 
    1, 20, 3, 92, 6, 72, 8, 62, 0, 67, 5, 64, 4, 67, 7, 69, 2, 89, 
    4, 58, 3, 41, 5, 39, 8, 28, 1, 76, 6, 45, 2, 56, 0, 60, 7, 34, 
    7, 84, 1, 90, 8, 35, 4, 90, 2, 32, 3, 18, 0, 19, 5, 33, 6, 62, 
    7, 83, 6, 20, 0, 44, 2, 80, 4, 94, 5, 93, 8, 51, 3, 57, 1, 58, 
    0, 13, 3, 27, 8, 76, 2, 19, 6, 22, 1,  8, 4, 64, 7, 87, 5, 62, 
    1, 60, 3, 31, 2, 25, 8, 99, 4, 67, 6, 44, 0, 16, 5,  7, 7, 58
  };
  const int q3589[] = {
    9, 9, // Number of jobs and machines
    7, 86, 8, 48, 5, 55, 2, 45, 6, 75, 1, 86, 3, 15, 4, 88, 0, 87, 
    7, 19, 0, 98, 3, 79, 8, 49, 2, 50, 1, 73, 5, 85, 6, 86, 4, 13, 
    1, 36, 5, 99, 3,  1, 0, 79, 4, 87, 6, 82, 2, 14, 7, 63, 8, 66, 
    6, 44, 2, 66, 5,  3, 3, 50, 1, 44, 4, 99, 7, 23, 8, 81, 0, 73, 
    6, 67, 3, 22, 8, 41, 7, 79, 5, 91, 0, 50, 1, 96, 4, 22, 2, 31, 
    6, 13, 1,  5, 5, 16, 8, 99, 3, 26, 7, 23, 0, 67, 2, 65, 4, 26, 
    7, 36, 0, 38, 4, 46, 5, 91, 8, 22, 1, 31, 3,  5, 6, 82, 2, 66, 
    5, 48, 8, 62, 4, 27, 1, 96, 2, 77, 6, 66, 7, 21, 3, 91, 0, 18, 
    0, 23, 5, 50, 4, 47, 7, 71, 1,  8, 3, 36, 6, 71, 2, 75, 8, 49
  };
  const int q3590[] = {
    9, 9, // Number of jobs and machines
    5, 33, 2, 47, 6, 44, 7, 32, 4, 98, 0, 55, 3,  2, 8, 50, 1, 55, 
    2, 84, 8, 96, 3, 97, 7, 41, 0, 27, 4, 34, 6, 96, 5, 35, 1, 84, 
    7, 95, 6, 74, 0, 93, 5, 13, 8, 47, 2,  5, 3, 22, 4, 27, 1, 77, 
    5, 88, 7, 16, 1, 85, 6, 95, 0, 40, 8, 63, 3, 81, 2,  9, 4, 62, 
    6, 70, 5, 37, 2, 47, 8, 72, 1, 52, 4,  9, 7, 12, 3, 63, 0, 28, 
    7, 31, 8, 89, 3, 30, 0, 20, 1, 85, 5, 67, 6, 73, 4, 71, 2, 94, 
    1, 97, 3, 48, 0, 45, 7,  9, 5, 56, 4, 94, 6, 53, 8, 98, 2, 38, 
    8, 21, 5, 13, 7, 30, 3, 50, 0, 83, 1,  3, 4, 98, 2,  6, 6, 39, 
    5, 85, 1, 89, 0, 53, 6, 46, 3,  4, 2, 91, 8, 40, 4, 12, 7, 25
  };
  const int q3591[] = {
    9, 9, // Number of jobs and machines
    3, 65, 7, 41, 4, 48, 5, 10, 0,  7, 6, 78, 8, 76, 2, 41, 1, 14, 
    6, 10, 0, 52, 2, 59, 3, 52, 5, 13, 8, 88, 7, 40, 4, 16, 1, 14, 
    0, 64, 1, 41, 8, 42, 6, 78, 7, 79, 3, 26, 2, 98, 4, 92, 5, 16, 
    5, 91, 2, 67, 4, 24, 8, 72, 0, 73, 1, 71, 3, 15, 7, 30, 6, 92, 
    0, 90, 7, 73, 4, 48, 5, 67, 2, 82, 1, 22, 8, 90, 6, 53, 3, 79, 
    3, 53, 5, 47, 8, 76, 0, 33, 7,  8, 6, 81, 1, 23, 4, 54, 2, 63, 
    7, 16, 6, 94, 0, 52, 1, 23, 4, 17, 2, 40, 5, 69, 8, 35, 3, 58, 
    8, 54, 1, 86, 0, 33, 3, 89, 5, 96, 6, 93, 2, 71, 4, 68, 7, 40, 
    7, 22, 2, 86, 8, 72, 3, 35, 1, 17, 5, 99, 4, 44, 6,  4, 0, 40
  };
  const int q3592[] = {
    9, 9, // Number of jobs and machines
    4, 86, 1, 99, 7, 33, 2, 54, 6, 84, 3, 93, 5, 85, 8, 12, 0, 85, 
    2, 13, 1, 34, 7, 79, 8, 65, 6, 48, 5, 91, 3, 32, 4, 19, 0, 12, 
    3, 22, 0, 50, 6, 48, 1, 58, 8, 32, 2, 29, 7, 65, 4, 74, 5, 59, 
    7, 17, 5, 27, 4, 27, 0, 14, 6, 63, 1, 20, 3, 40, 8, 75, 2, 74, 
    8, 13, 1, 50, 2, 71, 6, 43, 7, 70, 3, 20, 4, 29, 5, 46, 0, 42, 
    6, 77, 4, 16, 5,  3, 8, 75, 7, 29, 2, 86, 1, 76, 0, 42, 3, 94, 
    4, 25, 5, 41, 0, 24, 7, 34, 8, 89, 3, 47, 2, 67, 1, 66, 6, 15, 
    5, 46, 8, 74, 2, 75, 1, 37, 3, 35, 0, 43, 4, 84, 7, 12, 6, 76, 
    5, 36, 7, 15, 3, 33, 2, 81, 1, 11, 8, 58, 6, 24, 0, 45, 4, 82
  };
  const int q3593[] = {
    9, 9, // Number of jobs and machines
    6, 81, 8, 50, 7, 38, 5, 91, 3, 31, 4, 69, 1,  3, 2, 23, 0,  2, 
    3, 66, 6, 15, 8, 72, 7,  3, 1, 99, 5, 40, 4, 88, 2, 98, 0,  8, 
    6,  2, 8, 79, 5, 49, 7, 65, 2,  2, 4, 88, 1, 23, 0, 38, 3, 73, 
    1, 37, 2,  9, 4, 45, 6, 98, 8, 88, 3, 92, 7, 37, 5, 44, 0, 67, 
    7,  1, 3, 97, 4, 39, 8,  9, 2, 52, 0, 25, 6, 30, 1, 80, 5,  2, 
    4, 54, 3, 95, 7, 41, 8, 71, 1, 13, 5, 43, 2, 97, 0, 90, 6, 66, 
    5, 27, 2, 88, 3, 38, 8, 68, 0,  3, 4, 53, 7, 41, 1,  4, 6, 89, 
    7, 89, 8, 33, 2, 88, 6, 99, 1,  9, 3, 87, 5,  3, 4, 21, 0, 59, 
    4, 67, 0, 78, 1, 37, 7, 97, 6, 29, 2, 23, 3, 79, 5, 52, 8, 95
  };
  const int q3594[] = {
    9, 9, // Number of jobs and machines
    8, 38, 0, 77, 7, 19, 4, 87, 3, 28, 6, 27, 5, 25, 1, 24, 2, 67, 
    1, 84, 2, 79, 3, 45, 7, 87, 0, 30, 5, 54, 8, 68, 6, 58, 4, 97, 
    7, 84, 8, 78, 2, 16, 6, 13, 0, 75, 1,  2, 3, 90, 4,  5, 5, 29, 
    5, 45, 7, 46, 3, 23, 2, 49, 8, 66, 6, 58, 4, 82, 0, 29, 1, 90, 
    3, 15, 8, 19, 5, 14, 2,  4, 0, 54, 4, 27, 1, 48, 7, 20, 6,  4, 
    1, 43, 3,  9, 5, 40, 6, 89, 7, 17, 8,  3, 2, 89, 0,  2, 4, 45, 
    2, 98, 8, 76, 4, 62, 5, 26, 3, 74, 6, 25, 1, 14, 0, 61, 7, 33, 
    2, 98, 7, 94, 0, 52, 6, 98, 4, 63, 3,  3, 8, 25, 5, 29, 1, 44, 
    3, 49, 0, 56, 4, 76, 1, 78, 2, 27, 6, 70, 8, 86, 5, 64, 7, 50
  };
  const int q3595[] = {
    9, 9, // Number of jobs and machines
    3, 83, 7, 76, 5, 87, 1, 85, 2, 60, 4,  8, 8, 37, 0, 13, 6, 66, 
    0, 84, 2, 29, 1, 11, 3, 53, 4, 62, 6, 72, 5, 90, 8, 12, 7, 44, 
    1, 99, 5, 81, 3, 98, 6,  7, 7, 44, 4, 17, 0, 98, 2, 30, 8, 50, 
    8, 60, 2, 16, 5, 43, 1, 88, 6, 20, 4, 21, 0, 24, 3, 26, 7, 37, 
    3, 69, 1, 75, 5,  9, 6,  2, 4, 42, 2, 28, 8, 47, 7, 81, 0, 64, 
    4, 74, 1, 89, 7, 10, 3, 78, 8, 92, 0,  4, 6, 11, 2, 33, 5, 99, 
    7, 99, 2, 79, 8, 86, 3, 99, 5, 49, 4, 13, 1, 63, 6, 35, 0, 31, 
    3, 51, 5, 74, 7, 67, 4, 26, 0, 27, 8, 71, 2, 74, 6, 57, 1, 78, 
    0, 60, 4, 37, 7, 34, 8, 65, 3, 58, 5, 87, 6, 25, 2, 64, 1, 55
  };
  const int q3596[] = {
    9, 9, // Number of jobs and machines
    1, 83, 0, 30, 7,  1, 2, 51, 5, 79, 6, 34, 8, 82, 3, 82, 4, 97, 
    0, 90, 3,  1, 6, 21, 2, 21, 8, 65, 1, 17, 5, 76, 7, 70, 4, 18, 
    0, 47, 8, 80, 4, 44, 1,  5, 7, 42, 5, 85, 6, 62, 3, 41, 2, 59, 
    3, 39, 6, 96, 5, 94, 2, 47, 0, 79, 4, 38, 8, 88, 7, 87, 1, 96, 
    5, 15, 0, 66, 3, 52, 6, 61, 1, 91, 7, 42, 2, 44, 8, 51, 4, 76, 
    1, 62, 0, 25, 3, 84, 4, 43, 2, 44, 7, 11, 5, 30, 6, 54, 8, 51, 
    6, 38, 4, 27, 0, 86, 5, 47, 1, 61, 7, 82, 8, 54, 2, 63, 3, 89, 
    4, 85, 7, 75, 5, 14, 1, 35, 0, 35, 3, 71, 2, 69, 8, 24, 6, 94, 
    5, 13, 2, 83, 7, 28, 6,  9, 3,  1, 4, 58, 1, 97, 0, 47, 8, 18
  };
  const int q3597[] = {
    9, 9, // Number of jobs and machines
    8, 50, 1, 48, 0, 95, 6, 42, 5, 54, 4, 30, 2, 12, 3, 49, 7, 88, 
    2, 73, 8, 68, 6, 46, 7, 52, 5,  1, 4, 46, 0, 89, 3, 45, 1, 35, 
    6, 29, 2, 14, 8, 18, 7, 23, 4, 42, 5, 66, 1, 54, 0, 92, 3, 38, 
    4, 21, 2, 59, 3, 37, 8, 15, 5,  2, 6,  8, 1, 49, 0, 31, 7, 77, 
    5, 54, 4, 78, 7, 10, 1, 35, 0, 10, 6, 42, 8, 56, 3, 87, 2, 59, 
    8, 11, 6, 65, 1, 61, 4, 12, 0,  8, 5,  4, 2, 58, 3, 59, 7, 32, 
    0, 75, 3, 21, 4, 73, 6, 29, 8, 54, 5, 87, 7, 45, 1, 67, 2, 75, 
    5, 85, 7, 13, 1, 79, 6, 62, 3, 63, 0, 59, 4, 88, 2, 78, 8, 22, 
    8, 78, 6, 91, 7, 17, 0, 21, 2, 32, 1, 16, 5, 20, 4, 13, 3, 57
  };
  const int q3598[] = {
    9, 9, // Number of jobs and machines
    2, 57, 4, 62, 8, 99, 7, 68, 3, 95, 1, 81, 6, 52, 5, 49, 0, 95, 
    8, 61, 4, 23, 7, 98, 6,  2, 5, 51, 2, 72, 3, 23, 1, 80, 0, 24, 
    1, 95, 6, 21, 3, 42, 7, 93, 8, 72, 4, 95, 0, 87, 5, 55, 2, 72, 
    2, 65, 7, 48, 4, 94, 8, 44, 1, 29, 5, 90, 0, 99, 3, 14, 6, 47, 
    0, 77, 8, 64, 3, 93, 5,  4, 4, 81, 6, 83, 1,  1, 2, 36, 7, 34, 
    5, 32, 3, 89, 2, 29, 6, 32, 1, 60, 8, 74, 4, 79, 7, 72, 0, 84, 
    7, 14, 8, 69, 1, 62, 3, 28, 2, 91, 6, 31, 5, 15, 0, 73, 4, 19, 
    3, 91, 5, 59, 0, 56, 6, 48, 1, 39, 7, 17, 8, 66, 2, 93, 4, 81, 
    0, 31, 6, 50, 3, 19, 4, 50, 5, 27, 8, 97, 7, 75, 1, 91, 2, 34
  };
  const int q3599[] = {
    9, 9, // Number of jobs and machines
    7, 20, 2, 47, 0, 78, 1, 74, 4, 24, 5, 32, 6, 11, 8, 49, 3, 30, 
    3, 88, 5, 35, 6, 73, 7, 75, 0, 69, 2, 17, 8, 70, 4, 11, 1, 98, 
    1, 63, 2, 18, 5, 59, 7, 35, 3, 17, 8,  3, 6, 61, 4, 97, 0, 14, 
    6, 56, 7,  8, 3, 48, 1, 92, 0, 21, 8, 66, 4, 16, 2, 99, 5, 36, 
    4,  7, 3, 98, 5, 18, 2, 20, 8, 92, 1, 12, 6, 74, 7,  3, 0, 87, 
    6, 11, 2, 97, 4, 26, 0, 61, 1, 45, 3, 89, 7, 12, 8, 60, 5, 38, 
    6,  1, 7, 52, 4, 28, 3, 26, 5, 77, 1, 65, 2, 87, 8, 87, 0,  4, 
    8, 48, 6, 59, 1, 63, 5, 29, 0, 47, 2, 47, 4, 76, 3, 34, 7,  9, 
    2, 61, 8, 27, 1, 97, 4, 46, 3, 11, 5, 37, 0, 30, 6, 79, 7, 52
  };
  const int q3600[] = {
    9, 9, // Number of jobs and machines
    1, 81, 5,  1, 8, 98, 7, 98, 3, 18, 6, 10, 2, 73, 0, 41, 4, 84, 
    1, 64, 4, 20, 2, 95, 3, 14, 7, 88, 0, 99, 8, 91, 6, 69, 5, 98, 
    2, 70, 1, 59, 6, 30, 4, 10, 7, 97, 8, 39, 0, 45, 3, 65, 5,  7, 
    3, 88, 5, 58, 1,  6, 4, 95, 7, 15, 8, 98, 2, 81, 0, 74, 6, 26, 
    1, 27, 5, 72, 6,  5, 0, 95, 3, 87, 4, 26, 2, 95, 7, 77, 8, 92, 
    7, 54, 5, 52, 6, 66, 4, 35, 3, 11, 2, 75, 1, 81, 0,  3, 8, 98, 
    4, 81, 8, 56, 6, 93, 2, 87, 1, 13, 7,  8, 3, 23, 5, 60, 0, 59, 
    6, 95, 1, 67, 0, 95, 4, 87, 8, 78, 7, 23, 3, 95, 5, 72, 2, 17, 
    4, 82, 6,  3, 2, 55, 5, 22, 7, 10, 8, 30, 3, 87, 0, 44, 1, 76
  };
  const int q3601[] = {
    9, 9, // Number of jobs and machines
    4, 64, 3, 90, 1,  1, 2, 86, 8, 83, 0, 99, 6, 78, 7, 59, 5, 99, 
    7, 74, 3, 61, 1, 17, 0, 42, 5, 93, 4,  7, 6, 96, 8, 32, 2, 74, 
    2, 88, 1, 33, 6, 77, 8, 87, 4, 44, 5, 66, 7, 26, 3,  6, 0, 56, 
    5, 61, 4, 79, 0,  2, 2, 63, 3, 14, 7, 79, 8, 72, 6, 95, 1, 10, 
    4,  9, 8, 95, 5, 46, 3, 75, 1, 58, 0, 90, 2, 73, 6, 83, 7, 14, 
    5, 67, 8, 96, 3, 24, 1, 30, 2,  3, 7, 82, 6,  4, 4, 69, 0, 80, 
    3, 50, 0, 69, 6, 48, 5, 85, 7, 33, 8, 24, 4, 42, 2, 61, 1, 24, 
    7, 94, 0, 54, 2, 66, 5,  3, 6, 95, 8, 19, 4, 87, 1, 80, 3, 44, 
    2,  7, 6, 80, 0, 10, 7, 94, 1, 12, 4,  8, 3, 71, 8, 33, 5,  4
  };
  const int q3602[] = {
    9, 9, // Number of jobs and machines
    7, 87, 0, 94, 4, 46, 6, 73, 2, 20, 3, 70, 8, 51, 5, 64, 1, 25, 
    3, 30, 4, 22, 6, 23, 5,  4, 7,  4, 8, 77, 2, 16, 0, 80, 1, 97, 
    3, 36, 0, 29, 6, 83, 1, 90, 8, 46, 2, 71, 7, 63, 5, 47, 4, 10, 
    4, 82, 5, 25, 7,  1, 1, 78, 8, 92, 0, 35, 2, 30, 6, 50, 3, 76, 
    3, 62, 8, 86, 7, 78, 6, 61, 2,  6, 4, 21, 0, 14, 5, 55, 1, 86, 
    8, 87, 0, 28, 4, 52, 7, 90, 2, 80, 6, 99, 5, 26, 3, 71, 1, 92, 
    0, 32, 8, 27, 7, 21, 2, 27, 1, 31, 4, 27, 6, 57, 3, 54, 5, 11, 
    6, 55, 5, 47, 2, 75, 7,  5, 4, 95, 3, 56, 8, 43, 0, 59, 1, 81, 
    0, 91, 7, 65, 2, 83, 8, 99, 1, 63, 3,  6, 6, 90, 5, 46, 4, 77
  };
  const int q3603[] = {
    9, 9, // Number of jobs and machines
    5, 85, 1, 22, 7, 54, 0, 69, 6, 44, 3, 59, 4, 34, 8, 78, 2, 16, 
    5, 62, 8, 75, 1, 51, 6, 17, 7, 17, 4, 34, 3, 82, 0, 86, 2, 94, 
    4, 90, 1, 41, 3, 36, 6,  9, 2, 35, 7, 64, 8, 62, 0, 94, 5, 22, 
    2, 39, 0, 57, 5, 13, 8, 97, 3, 24, 1, 63, 4,  3, 6, 19, 7, 28, 
    1, 15, 6, 30, 4, 85, 2, 21, 5, 73, 0, 31, 3, 31, 7, 42, 8, 10, 
    8, 67, 0, 45, 1, 30, 6, 53, 2, 74, 3, 92, 4, 15, 5,  1, 7, 95, 
    0, 88, 4,  9, 2, 28, 8, 15, 6, 42, 3, 78, 7, 41, 1, 29, 5, 38, 
    2, 56, 6, 22, 7, 87, 8, 31, 0, 54, 5, 29, 1, 36, 4, 17, 3, 31, 
    4, 48, 1, 33, 8, 80, 3, 24, 0, 86, 7,  3, 5, 83, 6,  4, 2, 49
  };
  const int q3604[] = {
    9, 9, // Number of jobs and machines
    1, 69, 5, 65, 7, 15, 8, 56, 3, 43, 4, 67, 2,  8, 6, 60, 0, 96, 
    8, 56, 1, 56, 6, 70, 4, 98, 2, 59, 0, 69, 3, 14, 5, 80, 7, 79, 
    2, 30, 3, 45, 5, 87, 1, 43, 0, 72, 8, 61, 4, 89, 6, 97, 7, 30, 
    5, 71, 4, 15, 3, 95, 1, 44, 2, 77, 7, 77, 8, 47, 6, 10, 0, 65, 
    1, 59, 4,  7, 5, 81, 2, 54, 8, 79, 7, 43, 0, 78, 6, 63, 3,  7, 
    0, 83, 6, 74, 2, 11, 1, 22, 3, 89, 7, 44, 4,  5, 5, 92, 8, 30, 
    3, 28, 5, 32, 8, 81, 2, 16, 4, 49, 0, 14, 1, 81, 7, 51, 6, 26, 
    7, 83, 4, 71, 8, 72, 3, 50, 5, 94, 2, 51, 1, 14, 0,  9, 6, 64, 
    7, 68, 4, 78, 1, 95, 0, 60, 2, 33, 3, 27, 5, 31, 6, 62, 8, 86
  };
  const int q3605[] = {
    9, 9, // Number of jobs and machines
    0,  6, 3,  1, 8, 14, 4, 26, 2,  6, 1, 32, 5, 34, 7, 52, 6, 56, 
    1, 57, 2, 72, 6, 95, 4, 87, 3, 16, 7, 41, 8, 48, 0, 78, 5, 23, 
    3, 95, 0, 68, 5,  8, 7, 53, 6, 95, 1,  4, 4, 63, 2,  7, 8, 72, 
    4, 93, 2, 44, 1, 12, 0, 20, 6,  4, 8,  6, 7, 77, 5,  5, 3, 42, 
    5, 25, 0, 70, 3, 27, 6, 33, 4, 44, 7, 31, 1, 24, 8, 14, 2,  2, 
    1, 29, 2, 76, 7, 45, 8, 91, 4, 39, 6, 38, 0, 37, 3,  4, 5, 76, 
    4, 37, 6, 62, 5, 11, 3, 56, 7, 19, 2, 34, 8, 85, 1, 10, 0, 45, 
    4, 42, 2, 72, 0, 60, 7, 41, 1, 48, 5, 28, 3, 88, 6, 31, 8, 43, 
    5, 88, 6, 24, 0, 82, 8, 87, 4, 66, 7, 53, 1, 47, 2, 49, 3,  3
  };
  const int q3606[] = {
    9, 9, // Number of jobs and machines
    8, 77, 1, 98, 5, 46, 6, 99, 3, 80, 4,  3, 0,  8, 2, 14, 7, 12, 
    3, 91, 8, 91, 4, 86, 7, 15, 1, 57, 6, 76, 2, 50, 5, 37, 0, 22, 
    4, 83, 1, 94, 2, 12, 7, 45, 5, 66, 6, 38, 8, 26, 3, 13, 0, 35, 
    7, 55, 4, 66, 3, 88, 5, 80, 2, 18, 1, 50, 8, 51, 0, 65, 6,  6, 
    7, 34, 0, 85, 5, 86, 1, 54, 2, 74, 8, 89, 6, 98, 4, 51, 3, 14, 
    3,  6, 0, 90, 2, 10, 8, 22, 1, 85, 7, 72, 4, 26, 6, 81, 5, 29, 
    6, 55, 3, 41, 2, 30, 4, 79, 0, 68, 8, 97, 7, 17, 1,  2, 5, 69, 
    5, 48, 4, 11, 1,  5, 6,  9, 0, 80, 8, 31, 2, 75, 3, 81, 7, 28, 
    3,  6, 7, 98, 6, 50, 8, 14, 5, 44, 2, 79, 0, 82, 1, 32, 4, 65
  };
  const int q3607[] = {
    9, 9, // Number of jobs and machines
    8, 64, 2, 58, 0, 29, 3, 50, 7, 43, 6, 35, 5, 29, 1, 75, 4,  1, 
    6, 76, 2, 36, 1, 63, 5, 56, 0, 59, 8, 41, 3, 98, 4, 61, 7, 88, 
    3, 62, 7, 21, 8, 29, 4, 82, 0, 61, 1, 45, 6, 55, 5,  5, 2, 93, 
    6, 42, 4, 45, 0, 89, 3, 94, 1, 79, 8, 91, 7, 41, 2, 97, 5,  6, 
    6, 73, 5, 89, 0, 63, 8, 47, 7, 69, 1, 82, 3, 29, 4, 18, 2, 20, 
    2, 92, 4, 49, 7, 87, 6, 61, 8, 20, 1,  1, 3, 23, 5, 41, 0, 49, 
    3, 50, 7, 28, 4, 78, 2, 29, 0, 67, 6, 63, 8,  8, 1, 11, 5, 20, 
    6, 65, 8, 96, 4, 87, 2, 82, 0,  3, 1, 55, 5, 66, 3, 48, 7, 93, 
    4, 48, 6, 42, 7, 75, 3, 87, 8, 19, 1,  6, 5, 15, 0, 21, 2, 14
  };
  const int q3608[] = {
    9, 9, // Number of jobs and machines
    0, 82, 7, 42, 3,  9, 2, 43, 6, 23, 1, 26, 4, 73, 5, 95, 8, 58, 
    8, 86, 2, 14, 1, 20, 5,  5, 7, 41, 4, 91, 3, 71, 0, 67, 6, 95, 
    3, 19, 7, 36, 4, 78, 6, 82, 2, 93, 1, 54, 0, 33, 8, 39, 5, 35, 
    5,  7, 4, 93, 0,  5, 1, 74, 3, 41, 2, 13, 7,  6, 6,  1, 8, 55, 
    4, 85, 1, 35, 8, 16, 2, 23, 5, 67, 6, 55, 7, 50, 3, 94, 0, 36, 
    8, 63, 1, 61, 6, 71, 3, 91, 5, 31, 0, 53, 2, 36, 4, 22, 7, 19, 
    7, 53, 4, 91, 8, 37, 5, 81, 6, 91, 2, 18, 1, 15, 3, 43, 0, 94, 
    4, 61, 8, 95, 0, 29, 6, 93, 3, 17, 5, 16, 1, 78, 7, 25, 2, 59, 
    4, 60, 0, 47, 8, 38, 2, 94, 5,  7, 1, 31, 3,  9, 7,  6, 6, 30
  };
  const int q3609[] = {
    9, 9, // Number of jobs and machines
    3, 60, 0, 20, 5, 62, 4, 82, 2, 92, 6, 37, 1, 73, 8, 73, 7, 98, 
    8,  7, 7, 13, 2, 72, 6, 71, 5, 96, 0, 61, 3, 51, 1,  2, 4, 48, 
    2, 73, 5, 45, 1, 35, 3, 36, 6, 97, 0, 22, 7, 26, 4, 56, 8, 85, 
    2, 74, 6, 36, 4, 50, 5, 70, 3, 64, 8,  4, 0, 94, 7, 62, 1, 17, 
    5, 93, 8, 65, 4, 44, 3, 62, 0, 23, 6, 31, 2, 33, 1, 34, 7, 24, 
    2, 47, 8, 11, 5, 18, 3, 25, 0, 83, 1, 60, 7, 31, 4, 27, 6, 65, 
    3, 47, 7, 14, 2, 20, 8, 34, 6, 63, 5, 82, 1, 92, 4, 15, 0, 22, 
    3, 31, 5, 90, 0, 58, 8, 95, 2, 86, 1, 92, 4, 56, 6,  8, 7, 84, 
    5, 27, 1, 74, 8, 63, 4, 82, 2, 14, 0, 34, 7, 99, 3, 91, 6, 50
  };
  const int q3610[] = {
    9, 9, // Number of jobs and machines
    4, 59, 3,  3, 6, 26, 0, 95, 7, 37, 5, 39, 2, 49, 1, 63, 8, 10, 
    7, 11, 8, 10, 3, 90, 0, 57, 2, 11, 4, 56, 1, 96, 5, 93, 6, 29, 
    3, 71, 1, 96, 4, 43, 7, 35, 6, 52, 5, 46, 0, 58, 2, 93, 8, 90, 
    5, 18, 4, 50, 1, 74, 3, 16, 2, 92, 0, 31, 6, 46, 7, 77, 8, 14, 
    6,  4, 1, 74, 2, 12, 7, 82, 5, 87, 3, 76, 8, 57, 0, 34, 4, 88, 
    7, 73, 1, 34, 2, 75, 3, 13, 6, 32, 0,  9, 5,  9, 4,  5, 8, 34, 
    6, 54, 8, 89, 7, 22, 3,  5, 2, 81, 5, 83, 1, 82, 0, 39, 4, 37, 
    4, 77, 7,  7, 2, 48, 3,  1, 6, 42, 8, 99, 0, 62, 1, 94, 5, 93, 
    2, 33, 5, 14, 1, 42, 8, 51, 6, 33, 3, 34, 7, 59, 0, 56, 4,  8
  };
  const int q3611[] = {
    9, 9, // Number of jobs and machines
    2, 59, 5, 11, 4, 59, 8, 52, 6, 29, 1, 88, 7,  5, 3, 57, 0, 39, 
    4, 89, 1,  6, 8, 35, 0, 55, 5,  1, 6, 90, 3, 64, 2, 14, 7,  3, 
    3, 86, 8, 21, 0, 91, 1, 68, 5, 68, 7, 65, 6, 27, 4, 79, 2, 46, 
    5, 43, 2, 38, 7, 99, 4, 48, 3, 67, 8, 49, 6, 84, 1, 61, 0, 30, 
    2, 75, 4, 10, 0, 94, 1, 10, 5,  8, 3, 65, 7, 49, 8, 68, 6, 98, 
    4, 89, 2, 92, 0, 18, 7, 29, 1, 42, 8,  4, 3, 24, 5, 35, 6, 99, 
    1, 59, 0, 28, 5, 86, 7, 30, 8, 27, 4, 12, 2, 34, 6, 10, 3, 56, 
    4, 58, 0, 27, 3, 58, 5, 45, 1, 53, 2, 71, 6, 70, 8, 83, 7, 38, 
    8, 69, 3, 44, 2, 89, 7, 29, 1, 94, 0, 64, 4, 60, 6, 10, 5,  7
  };
  const int q3612[] = {
    9, 9, // Number of jobs and machines
    5,  7, 6, 94, 2, 40, 8, 67, 0, 64, 7, 40, 1, 70, 3, 26, 4, 10, 
    2, 80, 4, 39, 0, 58, 1, 80, 3, 71, 5, 44, 6, 26, 7, 57, 8, 21, 
    5, 44, 4, 63, 3, 17, 0, 59, 1, 76, 2,  1, 6, 51, 7,  8, 8, 66, 
    1, 96, 4, 29, 6, 18, 0, 97, 2,  3, 3, 94, 5, 85, 7, 21, 8, 98, 
    4, 85, 8, 54, 0, 22, 6, 93, 7, 57, 1, 63, 3, 35, 2, 83, 5, 58, 
    8, 77, 7, 50, 3, 31, 1, 33, 4, 56, 0, 61, 6,  9, 5,  4, 2, 50, 
    3, 31, 7,  1, 0, 67, 4, 19, 8, 60, 6, 50, 2, 59, 1, 93, 5, 15, 
    7, 93, 8, 30, 1, 50, 2, 79, 5, 62, 6, 53, 4, 61, 0, 18, 3, 19, 
    2, 41, 7, 27, 8, 94, 4, 96, 6, 56, 5, 54, 3, 83, 0, 37, 1, 94
  };
  const int q3613[] = {
    9, 9, // Number of jobs and machines
    7, 12, 6, 19, 5, 37, 3, 64, 2, 28, 0, 93, 8, 64, 1, 27, 4, 58, 
    5, 71, 8, 59, 6, 21, 0, 60, 4,  9, 3, 63, 7, 16, 2,  4, 1, 68, 
    7, 61, 3, 73, 8, 22, 0, 62, 1, 83, 4, 15, 6, 29, 5, 92, 2, 89, 
    8, 80, 1, 71, 0, 27, 5, 98, 2,  5, 6,  4, 7, 66, 3, 63, 4, 43, 
    8, 93, 0, 58, 5, 72, 6, 72, 2, 50, 3,  1, 4,  9, 1, 20, 7, 55, 
    4,  3, 6, 33, 2, 75, 1, 23, 3, 13, 5, 86, 0, 96, 8, 67, 7, 54, 
    5, 51, 8, 72, 4, 67, 1, 32, 7, 55, 0, 75, 3, 57, 2, 47, 6, 11, 
    8, 45, 5, 37, 1, 70, 7,  6, 3, 43, 2, 50, 4, 52, 6, 63, 0, 94, 
    7, 63, 0, 81, 4, 41, 2, 15, 5, 41, 8, 19, 1, 10, 3, 17, 6, 12
  };
  const int q3614[] = {
    9, 9, // Number of jobs and machines
    5, 14, 6, 59, 1, 93, 4, 78, 3,  7, 0, 33, 8, 22, 2, 24, 7, 66, 
    7, 35, 3, 75, 8, 81, 1,  6, 6, 63, 2,  8, 5, 86, 4, 72, 0, 36, 
    1, 73, 7, 32, 8, 97, 4,  2, 5, 56, 6, 55, 3, 54, 2, 40, 0, 29, 
    3, 16, 6, 70, 1, 33, 8, 86, 0, 15, 4, 81, 7, 51, 5, 60, 2, 71, 
    6, 57, 1, 77, 0, 27, 3, 66, 8, 79, 4, 53, 2, 27, 5, 20, 7, 63, 
    5, 16, 2, 46, 7, 64, 3, 18, 4, 96, 8,  9, 1, 74, 6, 57, 0, 26, 
    8, 75, 4, 22, 3, 21, 7, 56, 5, 81, 1, 74, 0, 91, 6, 15, 2, 99, 
    6,  9, 4, 66, 5, 16, 3, 23, 7, 82, 0, 77, 8, 80, 1,  9, 2, 19, 
    0, 84, 1,  4, 6, 63, 2, 99, 7, 88, 3, 83, 8, 22, 4, 18, 5, 85
  };
  const int q3615[] = {
    9, 9, // Number of jobs and machines
    8, 19, 4, 94, 7, 93, 2, 78, 6,  9, 0, 90, 3, 70, 1, 86, 5, 75, 
    7, 82, 4, 30, 2,  2, 0, 81, 1, 24, 8, 78, 6, 58, 3, 39, 5, 77, 
    7, 27, 2, 79, 6, 63, 8, 34, 4, 23, 3, 67, 1, 27, 5, 27, 0, 58, 
    8, 41, 2, 36, 0, 61, 3, 15, 6, 99, 4,  9, 1,  8, 7, 87, 5, 79, 
    6, 11, 1, 67, 3, 66, 0, 60, 8, 24, 2, 27, 4, 27, 7, 28, 5, 99, 
    6, 41, 8,  1, 7, 36, 2, 29, 4, 35, 1, 97, 5,  1, 3, 89, 0,  9, 
    8, 96, 1, 22, 6, 48, 0, 68, 4, 19, 3, 17, 5, 70, 2, 77, 7, 68, 
    3, 54, 7, 51, 8, 53, 4, 33, 6, 59, 1, 18, 5, 80, 0, 91, 2, 90, 
    6, 18, 4, 31, 1, 84, 0,  5, 5, 23, 8, 95, 7, 34, 3, 20, 2, 32
  };
  const int q3616[] = {
    9, 9, // Number of jobs and machines
    4, 77, 3, 97, 8, 98, 6, 90, 7, 38, 0, 81, 2, 96, 1, 20, 5, 10, 
    6, 96, 5, 93, 1, 86, 7, 71, 2, 81, 8, 32, 0, 22, 3, 34, 4, 81, 
    7, 39, 6, 13, 1, 38, 3, 33, 8, 75, 5, 19, 2, 20, 0, 43, 4,  9, 
    7, 98, 5, 64, 3, 48, 6, 48, 1,  7, 0, 80, 4, 35, 8, 28, 2, 76, 
    7, 14, 4, 81, 3, 78, 0, 83, 5, 66, 2, 16, 6, 67, 1, 56, 8,  3, 
    1,  4, 4, 23, 7, 75, 2, 19, 5, 28, 3, 13, 6, 46, 0, 50, 8, 85, 
    0,  2, 8, 71, 7, 67, 3, 49, 2, 30, 4,  2, 5, 42, 6, 88, 1, 58, 
    5, 54, 1, 88, 7, 29, 4, 65, 2, 56, 0,  4, 8, 62, 3, 26, 6, 33, 
    4,  6, 1, 79, 6, 32, 7, 70, 8, 52, 5, 99, 2,  5, 0, 52, 3, 88
  };
  const int q3617[] = {
    9, 9, // Number of jobs and machines
    8, 37, 1, 22, 3, 39, 5, 79, 0, 80, 6, 65, 7, 53, 2, 92, 4,  1, 
    8, 51, 1, 17, 4, 45, 0, 56, 5,  1, 3, 62, 6, 18, 2, 52, 7, 50, 
    2, 80, 7, 83, 1,  7, 6, 47, 4, 68, 3, 27, 0, 71, 8, 51, 5, 83, 
    4, 65, 7, 96, 1, 21, 5, 33, 8,  8, 3, 38, 0, 60, 6, 64, 2, 33, 
    8, 77, 3, 47, 7, 67, 4, 16, 0, 35, 1, 23, 6, 56, 5, 67, 2, 32, 
    4, 31, 2, 94, 3, 81, 8, 53, 0, 19, 1, 63, 5, 41, 7, 45, 6, 56, 
    1, 81, 7, 90, 8, 10, 5, 48, 4, 26, 2, 97, 0, 76, 3,  9, 6, 10, 
    7, 81, 2, 14, 4,  6, 5, 44, 8, 44, 6, 30, 3, 83, 0, 24, 1, 60, 
    7, 40, 5, 71, 6, 86, 8, 68, 0, 36, 3, 59, 2, 61, 1, 86, 4,  6
  };
  const int q3618[] = {
    9, 9, // Number of jobs and machines
    3, 20, 6, 87, 1,  8, 7, 16, 4,  7, 8, 91, 5, 36, 0, 52, 2, 89, 
    2, 60, 6, 98, 4, 15, 7, 28, 3, 72, 8, 18, 0, 46, 5, 18, 1, 27, 
    4, 95, 3, 62, 8, 23, 1, 49, 7, 83, 6, 78, 5, 22, 2, 51, 0, 63, 
    3, 56, 0, 85, 8, 42, 5, 54, 4, 48, 7, 74, 6, 98, 1,  3, 2, 74, 
    8, 27, 1, 83, 3,  7, 2, 37, 0, 43, 4, 48, 6, 68, 7, 57, 5, 62, 
    6, 73, 1, 84, 7, 94, 2, 73, 5, 66, 4, 95, 3, 60, 0, 53, 8, 35, 
    1, 95, 5, 30, 6, 81, 2, 58, 8, 72, 3, 79, 4, 74, 0, 93, 7, 91, 
    7, 77, 1, 38, 3,  5, 6, 23, 5,  9, 8, 81, 2, 48, 4,  1, 0, 44, 
    0, 36, 3, 85, 2, 15, 8, 22, 7, 56, 5, 18, 4, 14, 1, 34, 6, 37
  };
  const int q3619[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 62, 6, 89, 1, 54, 0, 46, 3, 55, 7, 73, 5, 63, 8, 39, 
    4, 98, 2, 82, 5, 64, 1, 75, 8,  8, 0, 40, 6,  5, 7, 39, 3, 10, 
    2,  4, 4, 56, 3, 43, 1, 15, 0, 93, 8, 52, 5, 21, 7, 14, 6, 32, 
    6, 76, 7, 97, 3, 79, 0, 86, 8, 39, 1,  2, 5,  5, 4, 74, 2, 62, 
    0, 45, 2, 42, 6, 58, 1, 41, 5, 11, 7, 14, 4, 91, 8, 24, 3,  4, 
    3, 32, 1, 83, 0, 30, 4, 24, 8,  6, 2, 82, 7, 12, 5, 16, 6, 74, 
    1, 47, 0, 36, 8, 35, 4, 42, 3, 65, 6, 59, 5, 42, 7, 57, 2, 24, 
    1, 67, 5, 94, 2, 80, 7, 98, 8, 29, 0, 29, 3, 82, 6, 83, 4, 73, 
    4, 13, 2, 89, 5, 95, 1,  1, 8, 40, 6, 29, 3, 46, 0, 66, 7, 76
  };
  const int q3620[] = {
    9, 9, // Number of jobs and machines
    6, 46, 5,  1, 2, 97, 1, 20, 3, 89, 4, 18, 7, 57, 8, 29, 0, 94, 
    0, 52, 3, 82, 1, 11, 2, 39, 6, 20, 4, 88, 7, 24, 5, 14, 8, 31, 
    1, 73, 4, 57, 7, 87, 5, 70, 3, 42, 0, 30, 8, 76, 6, 90, 2, 51, 
    0, 45, 2, 82, 1, 79, 8, 85, 6,  5, 4, 75, 7, 39, 5, 60, 3, 28, 
    7, 55, 5, 70, 4, 44, 3, 39, 8, 38, 0, 69, 1, 32, 6, 76, 2, 59, 
    4, 60, 6, 97, 2, 47, 0, 49, 5,  4, 1, 99, 3, 45, 8, 11, 7, 18, 
    6, 49, 2, 48, 8, 73, 0, 98, 1, 56, 4, 53, 3, 70, 7, 18, 5, 85, 
    1, 23, 8, 70, 2, 31, 6, 18, 4, 35, 5, 87, 3, 32, 7, 16, 0, 18, 
    2, 31, 6,  5, 5, 43, 7, 46, 3, 43, 1, 30, 8, 21, 0, 47, 4, 45
  };
  const int q3621[] = {
    9, 9, // Number of jobs and machines
    0, 37, 3, 38, 7, 51, 2, 45, 5, 56, 1, 12, 8, 63, 4, 94, 6, 75, 
    8, 65, 5, 85, 2, 58, 4, 90, 1, 23, 3, 62, 6, 55, 7, 61, 0, 58, 
    6, 23, 7, 60, 5, 24, 4, 45, 3, 32, 1, 64, 8, 81, 2, 40, 0, 69, 
    5, 71, 7, 44, 3, 92, 0, 88, 4, 41, 1, 15, 2, 65, 6, 68, 8, 55, 
    1, 45, 7, 38, 3, 81, 8, 28, 2,  6, 4, 40, 6, 20, 5, 95, 0, 64, 
    3, 93, 7, 39, 1, 22, 6, 91, 0, 43, 4, 74, 5, 91, 8, 43, 2, 62, 
    7, 69, 1,  6, 8, 36, 3, 29, 0, 85, 6, 99, 5, 53, 4, 96, 2,  8, 
    3, 74, 4, 11, 0, 74, 2, 73, 8, 28, 1, 59, 5, 14, 7, 40, 6, 63, 
    7, 52, 8, 99, 6, 61, 4, 67, 3, 35, 1, 81, 2, 50, 5, 77, 0, 11
  };
  const int q3622[] = {
    9, 9, // Number of jobs and machines
    8, 27, 3, 80, 5, 55, 0, 60, 6, 74, 2, 62, 7, 10, 1, 57, 4, 68, 
    0, 92, 8,  8, 7, 44, 4, 59, 5,  9, 6, 40, 3, 80, 2, 23, 1, 74, 
    1, 22, 0, 95, 4, 27, 5, 66, 6, 46, 7, 47, 2, 72, 8,  8, 3, 72, 
    8, 23, 0, 50, 2, 13, 6, 24, 3, 90, 4, 86, 1, 83, 7, 37, 5, 44, 
    2, 52, 4, 27, 8, 52, 5, 45, 3, 18, 7, 74, 0, 31, 6, 28, 1, 27, 
    6, 31, 3, 26, 0, 32, 2, 55, 8, 73, 5, 18, 1, 89, 7, 59, 4, 43, 
    6, 33, 2, 61, 3, 45, 4, 65, 1, 82, 5, 38, 7, 47, 0, 43, 8, 42, 
    7, 10, 5, 96, 8, 41, 3, 95, 6, 58, 4, 97, 0, 86, 2, 34, 1, 59, 
    4, 18, 7, 87, 8, 16, 2, 23, 5, 80, 3, 19, 6, 55, 0, 49, 1, 56
  };
  const int q3623[] = {
    9, 9, // Number of jobs and machines
    7, 70, 5, 40, 0, 80, 6, 21, 2, 70, 4, 36, 8, 12, 1,  6, 3, 42, 
    4, 36, 5, 95, 6, 59, 2, 33, 7, 34, 8, 90, 1, 32, 0, 21, 3, 25, 
    2, 47, 8,  2, 0, 79, 1, 71, 6, 74, 5, 43, 3,  1, 7,  3, 4, 63, 
    4, 16, 6,  3, 2,  6, 3,  4, 8, 74, 0, 17, 7, 30, 5, 86, 1, 99, 
    1, 50, 5, 37, 0, 62, 6, 71, 7, 37, 2,  6, 3,  3, 8, 46, 4, 98, 
    8, 61, 3, 13, 2, 40, 6, 91, 4, 86, 0, 98, 5, 71, 7, 99, 1, 31, 
    7, 79, 8, 73, 6, 41, 3, 70, 2, 14, 1,  3, 5, 52, 4, 27, 0, 49, 
    1,  1, 0, 32, 8, 26, 7, 90, 4, 90, 2, 38, 6, 70, 3, 75, 5, 30, 
    1,  4, 8, 51, 6,  7, 4, 25, 3,  9, 5, 84, 0, 86, 2, 64, 7, 17
  };
  const int q3624[] = {
    9, 9, // Number of jobs and machines
    3, 89, 0, 95, 1, 94, 8, 82, 2, 71, 7, 15, 6, 41, 4, 63, 5, 17, 
    2, 98, 3, 75, 8, 18, 6, 62, 5, 43, 0,  3, 7, 47, 4, 36, 1, 26, 
    5, 33, 4, 74, 3,  5, 7, 51, 2, 47, 0, 93, 1, 68, 8,  5, 6, 80, 
    4, 89, 7, 36, 0, 12, 5, 29, 1, 49, 2, 56, 3, 19, 6, 70, 8, 58, 
    7, 77, 1, 24, 8, 25, 5, 86, 6, 50, 2, 77, 4, 95, 3, 89, 0, 69, 
    0, 97, 2, 63, 8, 24, 5, 38, 6, 97, 7, 93, 4, 58, 1, 16, 3, 46, 
    4, 76, 2, 28, 0, 88, 6, 95, 8, 16, 5, 88, 1, 96, 3,  9, 7, 63, 
    7, 76, 2, 58, 0, 96, 5, 87, 3, 93, 4, 41, 6, 12, 8, 83, 1, 27, 
    0,  3, 6, 44, 1, 60, 7, 93, 3, 27, 8, 37, 5, 99, 4, 76, 2, 58
  };
  const int q3625[] = {
    9, 9, // Number of jobs and machines
    6, 88, 1, 69, 8, 18, 2, 40, 4, 65, 0,  3, 5, 62, 7, 26, 3, 24, 
    6, 52, 1, 37, 0, 31, 4, 33, 3, 10, 5, 74, 7, 52, 8, 36, 2, 57, 
    1, 45, 7,  8, 3, 33, 4, 96, 2, 70, 0, 42, 6,  9, 8, 85, 5, 68, 
    7, 62, 8, 95, 3, 99, 2, 77, 4,  3, 5, 14, 6, 69, 1, 17, 0, 82, 
    8, 84, 0, 70, 6, 85, 3, 75, 2, 90, 7,  6, 1, 14, 5, 37, 4, 61, 
    4, 27, 5, 45, 8, 74, 1, 45, 2, 66, 6, 94, 7, 95, 3, 74, 0, 66, 
    8,  2, 6,  1, 5, 78, 3,  4, 0, 43, 2, 97, 7,  8, 1, 53, 4,  9, 
    7, 89, 3, 85, 0, 43, 4, 87, 2, 32, 1, 49, 5, 84, 6, 67, 8, 21, 
    6, 90, 5,  9, 2, 32, 1, 37, 0, 21, 4, 25, 3, 37, 7, 87, 8, 50
  };
  const int q3626[] = {
    9, 9, // Number of jobs and machines
    0, 67, 2, 26, 1,  6, 6, 89, 3, 19, 8,  2, 4, 32, 7, 11, 5, 28, 
    6, 52, 8, 64, 3, 12, 0, 57, 5, 44, 1, 23, 4, 57, 7, 17, 2, 41, 
    8, 37, 3, 48, 2, 80, 0,  1, 7, 55, 6, 95, 1, 75, 5,  6, 4, 88, 
    7, 39, 5, 64, 3, 30, 6, 27, 0, 41, 2, 47, 4, 61, 1, 89, 8, 65, 
    3, 20, 4, 92, 0, 74, 1, 21, 5, 55, 8, 46, 7, 68, 6, 16, 2, 40, 
    1, 47, 8, 42, 7, 38, 4, 39, 5, 57, 2,  7, 3, 89, 6, 32, 0, 35, 
    8, 29, 2, 32, 1, 86, 4, 33, 0, 56, 7, 98, 3, 45, 5, 20, 6, 24, 
    8, 41, 3, 52, 4,  1, 1, 62, 7, 39, 0, 38, 5, 74, 6, 70, 2, 17, 
    3, 11, 4, 61, 5, 18, 6, 38, 1, 49, 2, 82, 0, 62, 8, 70, 7, 97
  };
  const int q3627[] = {
    9, 9, // Number of jobs and machines
    8, 49, 3, 21, 2, 42, 0, 11, 5, 65, 6, 91, 4, 19, 1, 60, 7,  9, 
    2, 59, 8, 20, 5, 20, 1, 99, 0, 94, 6, 94, 4, 64, 3, 31, 7, 23, 
    5, 10, 3, 46, 0, 24, 2, 32, 4, 79, 8, 26, 7,  2, 1, 78, 6, 81, 
    0, 73, 8, 80, 6, 16, 1, 69, 3, 57, 4, 96, 7, 77, 2, 49, 5, 87, 
    3, 70, 4, 51, 2, 77, 0, 67, 7, 20, 6, 17, 1, 42, 8, 47, 5, 56, 
    8, 66, 6, 52, 5, 26, 7, 44, 3, 46, 1, 92, 0, 90, 4, 54, 2, 23, 
    8, 59, 5, 64, 7, 57, 0, 50, 2, 10, 4,  5, 1, 86, 6, 45, 3, 72, 
    0, 56, 8, 59, 3, 42, 5, 94, 1, 12, 2, 59, 6, 17, 7, 76, 4, 38, 
    1, 28, 3,  9, 7, 99, 2, 60, 5, 52, 0, 85, 4, 37, 8, 28, 6,  2
  };
  const int q3628[] = {
    9, 9, // Number of jobs and machines
    0,  6, 7, 74, 8, 50, 5, 90, 3, 72, 4, 49, 2, 79, 6, 78, 1, 31, 
    2, 88, 7, 75, 1, 55, 8, 88, 4, 14, 3, 25, 6, 17, 0, 74, 5, 11, 
    0, 20, 4, 78, 5, 26, 6, 79, 3, 51, 7, 45, 8, 88, 2, 73, 1, 95, 
    6, 88, 5, 63, 3, 68, 0, 39, 2, 83, 8, 47, 4, 29, 1,  1, 7, 12, 
    8, 29, 3,  7, 4, 98, 0, 56, 1, 93, 5, 38, 6, 78, 2, 78, 7, 72, 
    0, 97, 5, 38, 7, 92, 4, 51, 8, 28, 2, 70, 1, 86, 6, 63, 3, 79, 
    8, 84, 2, 89, 0, 37, 4, 22, 7, 83, 1,  1, 5, 55, 3, 85, 6, 28, 
    7, 45, 6, 95, 2, 91, 8, 76, 0, 45, 1, 65, 5, 61, 4, 52, 3, 54, 
    8,  3, 2, 41, 0, 76, 5, 70, 1, 21, 7, 16, 3, 11, 6, 12, 4, 76
  };
  const int q3629[] = {
    9, 9, // Number of jobs and machines
    4, 97, 5, 43, 0, 38, 7, 98, 1, 82, 6, 74, 3, 32, 8, 98, 2, 19, 
    8, 44, 2,  6, 1, 63, 0, 74, 6,  1, 5,  5, 4,  1, 7, 20, 3, 47, 
    0,  5, 7, 34, 1, 91, 6, 98, 4, 74, 5, 51, 2, 57, 8, 96, 3,  3, 
    8, 30, 7, 37, 2, 48, 5, 29, 4, 34, 1, 26, 3, 41, 0,  8, 6, 50, 
    0, 55, 2, 57, 7,  8, 8, 94, 3, 70, 4, 76, 1, 16, 5, 60, 6, 42, 
    2,  6, 7, 77, 0, 93, 1, 55, 3, 56, 5, 71, 6, 36, 8, 10, 4, 41, 
    3,  2, 5, 87, 2, 42, 0,  2, 1, 73, 4, 84, 8, 71, 7, 79, 6, 53, 
    4, 46, 1, 87, 7, 72, 6, 73, 0, 12, 3, 53, 2, 64, 8, 36, 5, 58, 
    1, 18, 0, 81, 3, 16, 6, 83, 8, 33, 2,  6, 7,  1, 4, 20, 5, 72
  };
  const int q3630[] = {
    9, 9, // Number of jobs and machines
    3, 16, 8, 23, 5, 52, 2, 84, 0, 10, 7, 49, 4, 45, 1, 67, 6,  1, 
    2, 60, 5,  2, 1, 56, 4, 22, 0, 12, 3, 66, 8, 46, 6, 64, 7, 40, 
    1, 44, 8, 87, 6, 56, 4,  4, 7, 90, 2, 43, 5, 34, 3, 81, 0, 95, 
    5, 21, 2, 18, 6, 50, 8, 44, 3, 55, 4, 42, 7, 52, 1, 95, 0, 87, 
    7, 79, 0,  3, 2, 54, 5, 34, 1, 81, 3,  3, 6, 54, 8, 35, 4, 41, 
    2, 87, 0, 65, 8, 77, 6, 42, 4, 73, 1, 79, 5, 84, 3, 12, 7, 19, 
    3, 34, 1, 53, 8, 64, 0, 93, 6, 34, 4, 44, 7, 14, 5, 64, 2, 62, 
    1, 37, 5, 48, 3, 68, 2, 10, 4, 41, 7,  1, 0, 60, 8, 18, 6, 77, 
    7, 55, 4, 67, 1, 12, 8, 26, 2, 38, 3, 22, 6, 79, 5, 44, 0, 18
  };
  const int q3631[] = {
    9, 9, // Number of jobs and machines
    7, 64, 8,  4, 0, 89, 5, 44, 6, 64, 4, 86, 1, 64, 3, 71, 2, 81, 
    6, 22, 2, 30, 1, 68, 8, 52, 0, 36, 5,  7, 3, 42, 4, 96, 7, 75, 
    8, 72, 6, 40, 7, 77, 4, 91, 1, 47, 5, 61, 0, 58, 2, 10, 3, 75, 
    7, 60, 0, 56, 8,  7, 6, 31, 4, 94, 5, 89, 2,  9, 3, 53, 1, 47, 
    8, 63, 1, 69, 0, 22, 4,  8, 6, 66, 3, 43, 2, 12, 5, 20, 7, 55, 
    7, 70, 0, 57, 3, 91, 2, 61, 8,  4, 5, 19, 6, 44, 1, 44, 4, 62, 
    2, 74, 5, 98, 7, 66, 1, 29, 3, 89, 8, 53, 4, 95, 0, 57, 6, 51, 
    6, 25, 2,  1, 1, 89, 3, 87, 7, 53, 8, 94, 4, 93, 0, 47, 5, 57, 
    8, 89, 7, 63, 5, 14, 2, 11, 6, 17, 1, 69, 4, 93, 0, 56, 3, 90
  };
  const int q3632[] = {
    9, 9, // Number of jobs and machines
    7, 20, 3, 17, 2, 10, 8, 89, 6, 95, 4, 79, 1,  8, 0,  2, 5, 56, 
    0, 39, 4, 23, 7, 31, 3, 53, 8, 87, 1, 12, 5, 17, 6, 79, 2, 73, 
    1,  7, 2, 67, 3, 94, 5, 11, 6, 36, 7, 88, 0, 53, 4, 84, 8, 38, 
    5, 48, 7, 16, 4, 69, 1, 81, 2, 16, 6, 81, 8, 81, 3, 70, 0, 96, 
    0, 68, 7, 96, 4, 37, 6, 89, 3,  6, 1,  3, 8, 78, 5, 59, 2, 64, 
    4, 27, 6, 10, 7, 79, 0, 68, 8, 45, 1, 39, 2, 70, 5, 19, 3, 74, 
    0,  4, 5,  9, 6,  9, 3, 32, 1, 96, 4, 45, 2, 62, 8, 41, 7, 37, 
    7,  5, 4, 80, 8,  3, 3, 53, 5, 88, 0, 87, 6, 47, 1, 34, 2, 23, 
    5, 61, 1, 74, 2, 38, 8,  3, 3, 14, 4, 48, 6, 68, 7,  3, 0, 79
  };
  const int q3633[] = {
    9, 9, // Number of jobs and machines
    3, 32, 5, 12, 7, 29, 2, 72, 8, 42, 6, 10, 4, 50, 0, 68, 1, 88, 
    1, 53, 4, 35, 3, 73, 6, 25, 8, 57, 5,  3, 2, 24, 0, 33, 7, 84, 
    2, 91, 6, 66, 7, 27, 0, 14, 1, 43, 4, 85, 8, 76, 5, 42, 3, 30, 
    0,  7, 6, 36, 4, 38, 7, 69, 3, 83, 8, 94, 5, 96, 2, 86, 1,  3, 
    7, 26, 4, 89, 8, 40, 2, 78, 0, 11, 3, 58, 1, 87, 5, 61, 6, 49, 
    5, 76, 0, 16, 6, 65, 1, 29, 7, 37, 3, 26, 8,  1, 4, 77, 2, 28, 
    7, 22, 5, 30, 3, 52, 0, 94, 6, 36, 1, 39, 4,  2, 2, 93, 8, 72, 
    0,  3, 2, 39, 8, 46, 1, 48, 6, 53, 7, 19, 5, 26, 4, 82, 3, 28, 
    4, 91, 3, 40, 5, 15, 1, 71, 2, 51, 7,  1, 0, 40, 8, 16, 6, 80
  };
  const int q3634[] = {
    9, 9, // Number of jobs and machines
    3, 92, 7, 37, 8, 97, 4,  5, 6, 33, 5, 94, 2, 93, 1, 85, 0, 12, 
    5, 84, 7, 89, 1, 66, 2, 96, 6,  9, 3, 51, 0, 18, 8, 57, 4, 89, 
    1, 57, 5, 64, 8, 35, 3, 89, 7, 51, 4, 84, 2,  3, 6, 61, 0, 65, 
    4, 17, 6, 88, 7, 64, 2, 42, 5, 81, 1, 27, 3, 37, 0, 89, 8, 34, 
    8, 16, 3, 82, 0, 70, 6, 80, 2, 65, 4, 57, 5, 89, 7, 69, 1,  8, 
    6, 76, 7, 25, 2, 49, 3, 29, 8, 56, 5, 28, 0, 16, 4, 45, 1, 67, 
    3, 57, 2,  9, 7, 98, 0, 65, 1, 86, 5, 96, 8, 41, 4, 43, 6, 93, 
    7, 92, 6, 46, 1,  9, 4, 36, 8, 57, 3, 13, 0, 90, 2, 31, 5, 55, 
    4, 35, 7, 92, 0, 97, 6,  6, 5, 94, 1, 16, 2, 59, 3, 22, 8, 40
  };
  const int q3635[] = {
    9, 9, // Number of jobs and machines
    3, 80, 7, 44, 1, 50, 2, 23, 8, 84, 4, 98, 0, 65, 5, 31, 6, 98, 
    0, 74, 8, 22, 4, 86, 5, 86, 7, 13, 6, 42, 1, 36, 2,  5, 3, 63, 
    8, 62, 5, 58, 2, 37, 0, 99, 6,  6, 7, 47, 4, 60, 3, 75, 1, 14, 
    4,  8, 1, 73, 8, 37, 7, 54, 5, 11, 6, 36, 2, 18, 0, 26, 3, 29, 
    4, 66, 3,  2, 2, 44, 6, 80, 1, 11, 0, 79, 7, 21, 8, 17, 5, 67, 
    6, 29, 2, 80, 8, 54, 3, 13, 1, 36, 4,  3, 0, 87, 7, 87, 5, 37, 
    7, 94, 3, 98, 2, 41, 0, 74, 5, 54, 1, 23, 4, 96, 6, 93, 8, 30, 
    6, 45, 0, 57, 7, 71, 8, 19, 3, 79, 4, 81, 1, 99, 2, 65, 5, 84, 
    2, 57, 8, 25, 4, 26, 1,  7, 3, 85, 5, 41, 0, 26, 6, 32, 7, 79
  };
  const int q3636[] = {
    9, 9, // Number of jobs and machines
    6, 37, 4, 33, 2, 76, 3, 64, 7, 58, 0, 45, 5, 10, 8, 40, 1, 65, 
    7, 91, 5,  8, 2, 16, 1, 90, 6, 39, 8, 26, 4, 68, 0, 53, 3, 73, 
    2, 43, 7, 30, 3, 37, 4,  4, 0, 43, 8, 74, 5, 55, 1, 15, 6, 88, 
    0, 34, 6, 40, 7, 24, 4,  7, 5, 79, 1, 45, 8,  6, 3, 84, 2, 92, 
    0, 85, 4, 85, 1, 29, 7, 96, 5, 97, 6, 27, 3, 34, 8, 54, 2, 13, 
    3, 97, 8, 65, 6, 64, 5, 58, 4, 67, 2, 70, 7, 40, 0, 68, 1, 43, 
    8, 42, 5, 62, 7, 50, 0, 41, 4,  2, 2, 36, 3, 55, 1, 77, 6, 68, 
    3, 71, 6, 24, 0, 49, 8, 34, 1, 11, 4,  9, 2, 35, 5, 23, 7, 94, 
    8, 47, 0, 68, 6, 22, 4, 26, 5, 20, 1, 57, 7, 80, 3, 93, 2, 40
  };
  const int q3637[] = {
    9, 9, // Number of jobs and machines
    4, 53, 2, 29, 8, 68, 1, 45, 7, 36, 5, 13, 0, 89, 3, 74, 6, 10, 
    7, 38, 4, 41, 5, 88, 6, 77, 0, 17, 1, 28, 3, 82, 8, 74, 2, 76, 
    8, 27, 5, 75, 0, 22, 1, 31, 6, 11, 2, 88, 7,  8, 3, 32, 4, 16, 
    4, 72, 1, 89, 8, 39, 2, 91, 0,  2, 5, 58, 7, 12, 3, 75, 6, 45, 
    5, 64, 6, 15, 3, 19, 2, 10, 0, 63, 7, 10, 8,  8, 4,  7, 1, 65, 
    8, 26, 0, 29, 6, 43, 4, 94, 3,  8, 5, 38, 1, 93, 2, 21, 7, 11, 
    0, 86, 1, 10, 3,  9, 4, 56, 8, 50, 5,  9, 2, 66, 7, 92, 6, 92, 
    4, 15, 0, 47, 6, 58, 8, 49, 2, 68, 7, 71, 3, 90, 5, 48, 1, 29, 
    1, 50, 8, 12, 7,  4, 2, 68, 4,  1, 5, 62, 0, 81, 6, 90, 3, 42
  };
  const int q3638[] = {
    9, 9, // Number of jobs and machines
    4, 55, 1, 53, 0, 69, 7, 43, 8, 24, 5, 91, 2, 12, 3, 34, 6, 13, 
    2, 72, 4, 30, 7, 57, 6, 74, 3, 88, 5, 16, 0, 35, 8, 30, 1, 66, 
    4, 97, 8, 78, 1, 95, 3, 86, 6, 13, 5, 81, 0, 94, 7, 78, 2, 16, 
    3, 99, 0, 28, 2, 37, 6, 87, 8, 73, 7, 70, 4, 81, 5, 54, 1, 39, 
    3, 93, 6, 33, 0, 36, 2, 73, 7,  2, 5, 67, 8, 16, 4, 79, 1, 41, 
    7, 74, 4, 67, 1, 87, 3, 13, 2, 79, 6, 47, 0,  7, 8,  5, 5, 99, 
    6, 98, 0, 10, 5, 13, 7, 49, 2, 59, 3, 47, 4, 98, 8,  8, 1, 22, 
    7, 92, 5, 64, 4, 33, 8, 64, 0, 18, 6, 33, 2, 74, 1, 89, 3,  1, 
    1, 11, 7, 25, 3, 81, 8, 31, 0, 24, 5, 86, 4, 43, 6,  9, 2, 42
  };
  const int q3639[] = {
    9, 9, // Number of jobs and machines
    6,  1, 5, 49, 0, 99, 1, 17, 3, 13, 2, 78, 4, 23, 7, 87, 8, 86, 
    0, 52, 7, 72, 5,  8, 8,  4, 6,  3, 2, 47, 4, 23, 1, 95, 3,  6, 
    8, 45, 1,  2, 7,  8, 2, 51, 4, 17, 3, 35, 6, 64, 5, 96, 0, 75, 
    7, 55, 4, 26, 0, 38, 5,  7, 6, 18, 2, 95, 8, 27, 1, 39, 3, 54, 
    8, 94, 1, 94, 7, 87, 3, 72, 0, 40, 5,  3, 4, 56, 2, 82, 6, 62, 
    3, 99, 2, 21, 1, 77, 8, 98, 5, 96, 6,  2, 0, 16, 7, 16, 4, 35, 
    0, 96, 3,  2, 2, 20, 7, 39, 5, 53, 4, 64, 8, 32, 6, 65, 1, 28, 
    4, 45, 6,  4, 8, 96, 0, 40, 3, 15, 2, 35, 5, 65, 1, 67, 7, 94, 
    5, 94, 0, 75, 6, 31, 7, 42, 8, 43, 2, 43, 1, 12, 3, 58, 4,  6
  };
  const int q3640[] = {
    9, 9, // Number of jobs and machines
    7, 67, 5, 34, 2, 63, 1, 66, 0, 36, 6, 52, 4, 48, 8,  5, 3, 14, 
    0, 53, 7, 98, 5, 20, 3, 26, 8, 88, 2, 69, 6, 45, 1, 39, 4, 95, 
    7, 63, 0, 29, 5, 58, 1, 33, 4, 35, 8, 97, 2, 46, 6, 58, 3, 83, 
    4,  1, 1, 35, 0, 28, 7, 10, 3, 67, 5, 96, 8, 13, 6, 63, 2, 58, 
    3, 68, 6, 80, 8, 66, 4, 18, 1, 58, 5, 52, 7, 27, 0, 46, 2, 68, 
    1, 94, 4, 85, 8, 45, 0, 61, 7, 55, 6, 80, 2, 70, 5, 89, 3, 90, 
    2, 70, 3, 83, 7, 96, 6, 83, 0, 36, 4, 72, 1, 31, 8, 58, 5, 28, 
    3, 53, 2, 83, 0, 91, 8,  7, 5, 46, 1, 82, 6, 19, 4, 64, 7, 57, 
    0, 90, 1, 15, 5, 71, 8, 88, 7, 88, 3, 72, 2, 17, 4, 85, 6, 94
  };
  const int q3641[] = {
    9, 9, // Number of jobs and machines
    4, 28, 1, 36, 3, 57, 0, 89, 7, 50, 8, 28, 5, 83, 6, 71, 2, 65, 
    0, 98, 1,  7, 7, 42, 2, 11, 8,  1, 6, 24, 3, 28, 4, 85, 5,  3, 
    2, 12, 7, 48, 4, 50, 0, 58, 1, 41, 8, 97, 5, 26, 6, 73, 3, 40, 
    2, 58, 4, 42, 3, 26, 5, 77, 7, 38, 0, 87, 6, 88, 8, 59, 1, 68, 
    1, 91, 2, 35, 0,  1, 6,  2, 7, 49, 5, 15, 3, 99, 8, 94, 4, 35, 
    6, 59, 2, 39, 8, 18, 7, 19, 1, 32, 0, 13, 4, 24, 3, 19, 5, 19, 
    8, 19, 6, 12, 7,  7, 4, 37, 5,  1, 0, 88, 3, 40, 2, 68, 1, 18, 
    2, 64, 1, 73, 0, 79, 6, 51, 8, 90, 4, 90, 5, 40, 7, 79, 3, 22, 
    2, 50, 1, 53, 7, 59, 0, 50, 8, 74, 5, 82, 6, 68, 4, 32, 3, 50
  };
  const int q3642[] = {
    9, 9, // Number of jobs and machines
    4,  9, 6, 22, 1, 77, 7, 24, 8, 54, 5, 29, 2,  4, 0,  4, 3, 28, 
    0, 51, 2, 56, 3, 37, 8, 40, 7, 33, 5, 13, 1,  1, 4, 64, 6,  7, 
    4, 93, 7, 46, 1, 49, 0, 78, 2, 89, 3, 83, 5, 26, 6, 85, 8, 38, 
    3, 60, 0, 21, 2, 37, 4, 86, 8, 64, 6, 83, 5, 87, 1, 86, 7, 43, 
    3, 91, 8, 68, 4, 47, 5, 71, 7, 91, 0, 92, 1, 36, 6, 28, 2,  7, 
    5, 34, 0, 29, 1, 78, 6, 53, 3, 55, 8, 70, 7, 55, 4, 69, 2, 46, 
    7,  5, 6, 21, 1, 60, 8, 40, 4, 45, 0,  9, 2, 53, 3, 47, 5, 98, 
    0, 74, 2, 49, 5, 76, 3, 25, 8, 51, 1, 15, 4, 96, 7, 54, 6,  3, 
    1, 61, 4,  4, 6, 22, 3, 55, 8, 11, 0, 71, 7, 20, 5, 26, 2, 98
  };
  const int q3643[] = {
    9, 9, // Number of jobs and machines
    3, 31, 8, 86, 2, 26, 4, 93, 5, 53, 1, 98, 6, 51, 0, 12, 7,  5, 
    2, 99, 4, 76, 8, 87, 3, 51, 0, 99, 6, 20, 1, 61, 5, 69, 7, 81, 
    6, 47, 5,  5, 7, 50, 3, 89, 4, 65, 0,  9, 1, 59, 8, 56, 2, 85, 
    6, 43, 1, 17, 4, 12, 8, 84, 7, 19, 3, 92, 5, 60, 2, 25, 0, 30, 
    4, 60, 1, 80, 2, 30, 6, 73, 7, 52, 0, 14, 8, 69, 3, 48, 5, 14, 
    0, 48, 7, 75, 6, 37, 3,  1, 8, 44, 5, 26, 1, 74, 2, 46, 4, 32, 
    0, 56, 3, 86, 5, 34, 4, 63, 7, 26, 2, 56, 8, 65, 1, 82, 6, 13, 
    6, 80, 7, 61, 1, 25, 3, 31, 5,  8, 0, 69, 4, 71, 2, 87, 8, 31, 
    4, 25, 0, 27, 5, 13, 8, 79, 6, 29, 2, 31, 3, 11, 1, 87, 7, 90
  };
  const int q3644[] = {
    9, 9, // Number of jobs and machines
    8,  5, 7, 84, 5, 33, 4, 62, 3, 32, 6, 24, 2, 80, 1, 94, 0, 91, 
    1, 39, 7, 19, 5, 67, 2, 38, 0, 51, 6, 70, 8, 34, 4, 45, 3,  9, 
    8, 91, 5, 25, 1, 89, 6, 25, 3, 66, 2, 70, 4, 46, 7, 49, 0, 44, 
    7, 63, 2, 57, 5, 51, 8, 58, 0, 93, 1, 34, 6, 72, 4, 70, 3, 51, 
    6, 93, 4, 57, 1, 62, 0, 27, 5, 95, 8,  8, 7, 72, 3, 72, 2, 63, 
    4, 33, 5, 65, 2, 22, 8, 68, 6, 83, 7, 55, 0, 99, 3, 19, 1, 56, 
    0, 70, 2, 44, 8, 91, 3, 42, 1,  1, 5, 76, 7, 81, 4, 66, 6, 79, 
    0, 65, 1, 25, 7, 94, 6, 15, 4,  6, 2, 37, 5, 36, 3, 72, 8, 14, 
    3, 34, 1, 52, 5, 64, 6, 66, 8, 52, 0,  5, 2, 73, 4, 77, 7, 62
  };
  const int q3645[] = {
    9, 9, // Number of jobs and machines
    5, 67, 8, 34, 0, 43, 4, 49, 3, 19, 7, 38, 2, 53, 6, 98, 1, 34, 
    2, 17, 1, 24, 7, 66, 4, 15, 5, 83, 6, 15, 8, 82, 0, 21, 3,  8, 
    0, 20, 6, 81, 4, 24, 3, 20, 5, 82, 7, 96, 1, 14, 2,  7, 8,  7, 
    0, 95, 6, 37, 4, 94, 3, 21, 8, 36, 7, 12, 5, 58, 2, 18, 1, 68, 
    5, 66, 0, 87, 1, 84, 7, 28, 4, 74, 3, 49, 2, 94, 6, 41, 8,  4, 
    5, 26, 1, 96, 7, 18, 6, 65, 0, 75, 8, 25, 4, 20, 3, 53, 2, 84, 
    4, 37, 3, 67, 2, 21, 7, 34, 5, 88, 1, 92, 6, 65, 8, 25, 0, 92, 
    3, 38, 4, 95, 1, 82, 5, 27, 0, 27, 6, 23, 7, 48, 2, 80, 8,  7, 
    6, 64, 3, 13, 0, 82, 8, 60, 7, 93, 1, 61, 5,  8, 2,  3, 4, 70
  };
  const int q3646[] = {
    9, 9, // Number of jobs and machines
    6, 85, 8, 66, 0, 83, 3, 62, 4, 77, 2, 41, 5, 54, 7, 13, 1,  6, 
    7, 11, 3, 47, 8, 48, 1, 35, 4, 53, 0, 41, 5, 45, 2, 86, 6, 55, 
    1, 43, 5, 48, 6, 74, 8, 73, 2, 82, 7, 27, 0, 82, 3, 63, 4, 36, 
    5, 38, 6, 59, 8, 13, 0, 93, 1, 62, 3, 95, 2, 30, 7, 72, 4, 14, 
    1, 45, 8, 28, 3, 36, 5,  6, 0, 92, 7,  1, 6, 20, 4, 42, 2, 63, 
    8, 72, 1, 56, 7, 75, 6, 31, 5,  2, 0, 10, 4, 19, 2, 84, 3, 57, 
    6, 63, 8, 55, 5, 70, 7, 46, 2, 44, 4, 86, 0, 17, 1, 69, 3, 19, 
    0, 18, 8, 99, 2, 67, 5, 29, 4, 40, 7, 33, 6, 47, 1, 28, 3, 78, 
    8,  1, 5, 72, 6,  9, 7, 97, 3, 18, 0, 87, 4, 39, 2, 41, 1, 79
  };
  const int q3647[] = {
    9, 9, // Number of jobs and machines
    8,  2, 2, 59, 3, 87, 4, 26, 1,  3, 6, 45, 0, 70, 5, 63, 7, 68, 
    5, 11, 3, 52, 4, 52, 1, 82, 7, 91, 0,  6, 2, 70, 6, 40, 8, 66, 
    3, 67, 1, 57, 0, 43, 8, 28, 7, 94, 5, 96, 6, 58, 4,  3, 2, 69, 
    1, 77, 4, 13, 8, 65, 0, 85, 5, 51, 3, 15, 7, 36, 2, 24, 6, 50, 
    4, 21, 7,  8, 3, 29, 1, 15, 0, 25, 6, 23, 5, 13, 8, 53, 2, 34, 
    8, 11, 4, 61, 3, 28, 7, 17, 0, 62, 2, 88, 5, 81, 1, 26, 6,  4, 
    5, 93, 7, 33, 3,  3, 4, 92, 8, 63, 1, 24, 2, 17, 6, 35, 0, 65, 
    5, 87, 3, 65, 0, 56, 2, 34, 6, 99, 1, 16, 4, 63, 8, 72, 7, 69, 
    6, 60, 0,  7, 5, 80, 1, 88, 3, 44, 7, 34, 8, 22, 4, 75, 2, 73
  };
  const int q3648[] = {
    9, 9, // Number of jobs and machines
    5, 63, 8, 85, 3, 64, 4, 14, 6, 62, 0, 54, 2, 46, 1, 73, 7, 65, 
    3,  2, 0, 75, 2, 15, 4,  6, 5, 91, 6, 12, 1, 63, 7, 36, 8, 58, 
    5, 64, 7, 26, 8, 27, 2, 61, 3, 24, 4, 86, 1,  1, 0, 51, 6, 71, 
    4, 25, 0, 86, 3, 92, 7, 68, 5, 40, 6, 78, 8, 62, 2, 87, 1, 95, 
    2, 51, 4, 45, 0, 42, 6, 96, 3, 48, 8, 38, 5, 85, 7, 49, 1, 29, 
    5,  9, 6, 12, 8, 68, 3, 82, 7, 56, 1, 34, 0, 47, 2, 77, 4, 62, 
    8, 60, 1, 73, 5, 56, 0,  9, 4, 33, 3, 28, 2, 11, 7, 97, 6, 78, 
    4, 60, 6, 43, 3, 94, 2, 58, 7, 12, 5, 26, 8, 62, 1, 51, 0, 44, 
    6, 77, 3, 84, 2, 77, 7, 42, 1, 23, 5, 37, 4, 76, 0, 27, 8, 44
  };
  const int q3649[] = {
    9, 9, // Number of jobs and machines
    7, 51, 5, 94, 4, 76, 1, 69, 2, 41, 8, 14, 0, 23, 3, 29, 6, 67, 
    6, 82, 7, 82, 1, 61, 3, 49, 2, 42, 5,  8, 8,  7, 0, 60, 4, 75, 
    6, 23, 5, 71, 3, 56, 7,  1, 2, 43, 1, 80, 8, 31, 0, 39, 4, 81, 
    0, 53, 1, 55, 5, 29, 7, 24, 2, 63, 3, 67, 4, 62, 8,  6, 6, 71, 
    5, 85, 2, 30, 4, 24, 3, 60, 6,  7, 1, 72, 8,  8, 0, 85, 7, 21, 
    4, 93, 1, 35, 0, 11, 2, 90, 3, 26, 6, 42, 7, 46, 8, 47, 5, 67, 
    0, 74, 5, 55, 2, 65, 1, 14, 4,  2, 6, 82, 7, 39, 8, 39, 3,  2, 
    4, 30, 6, 42, 1, 30, 2, 68, 3, 34, 0, 54, 7, 80, 5, 18, 8, 23, 
    5, 37, 6, 66, 3, 83, 1, 58, 2, 94, 4, 45, 0, 15, 7, 89, 8, 11
  };
  const int q3650[] = {
    9, 9, // Number of jobs and machines
    7, 38, 3, 69, 4, 37, 1, 27, 6, 89, 8, 95, 0, 39, 5, 30, 2, 99, 
    8, 98, 3, 64, 2, 48, 6, 19, 0, 64, 7, 37, 5, 57, 1,  4, 4, 46, 
    8, 64, 3, 15, 0,  6, 6, 51, 4,  2, 5, 58, 1, 86, 2, 75, 7, 29, 
    6, 42, 4, 95, 5, 80, 0, 87, 2, 64, 3,  3, 8, 31, 1, 18, 7, 87, 
    3, 13, 0, 59, 6, 10, 1, 17, 4, 43, 5,  1, 7, 21, 8, 64, 2, 77, 
    8, 48, 5, 75, 3, 10, 0, 95, 7, 31, 6, 41, 1, 84, 4, 29, 2, 76, 
    8,  7, 1, 12, 0, 60, 3, 40, 5, 36, 7, 15, 2, 13, 4, 18, 6, 81, 
    0, 96, 4, 74, 5, 85, 3, 50, 8, 97, 6,  2, 2, 75, 1, 10, 7, 54, 
    5, 49, 4, 46, 8, 56, 1, 39, 7, 87, 6, 96, 0, 40, 2, 22, 3, 62
  };
  const int q3651[] = {
    9, 9, // Number of jobs and machines
    0, 58, 7, 56, 4, 53, 2, 32, 1, 17, 6, 75, 8, 79, 3, 24, 5, 90, 
    1, 40, 3, 50, 0, 44, 8, 79, 5, 45, 6, 87, 7, 20, 2, 53, 4, 52, 
    0, 59, 3, 29, 7, 47, 5, 10, 8,  3, 6, 12, 1, 20, 2, 95, 4, 32, 
    0,  9, 8, 57, 7, 76, 6, 69, 1, 29, 2,  3, 3, 54, 5, 56, 4, 79, 
    1, 97, 8, 31, 3, 45, 0, 71, 7, 94, 6, 89, 4,  6, 5, 95, 2, 77, 
    4, 87, 8, 56, 2, 88, 0, 49, 3,  4, 5, 97, 1, 22, 7, 49, 6,  3, 
    1, 60, 2, 84, 5, 21, 0, 96, 6,  9, 8, 88, 7, 87, 4, 12, 3, 94, 
    4, 28, 5,  1, 7, 91, 2, 32, 6, 47, 3, 79, 0, 28, 1, 37, 8, 46, 
    5, 88, 8, 45, 4, 91, 0, 21, 6, 87, 7, 20, 3, 40, 2, 27, 1, 50
  };
  const int q3652[] = {
    9, 9, // Number of jobs and machines
    8,  7, 4, 70, 6, 80, 5, 23, 0, 48, 2, 13, 3, 39, 1, 38, 7, 79, 
    1,  6, 0, 93, 3, 96, 2, 94, 8,  5, 4, 36, 5, 67, 7, 89, 6, 15, 
    7, 70, 4, 37, 3, 38, 1, 64, 2, 48, 5, 21, 0, 97, 8, 51, 6, 41, 
    1, 59, 4, 55, 5,  2, 7, 71, 0, 80, 6, 48, 3, 42, 8, 36, 2, 18, 
    3, 99, 4, 97, 5, 61, 7, 60, 2, 94, 1, 81, 6, 30, 8, 66, 0, 97, 
    1, 30, 4, 98, 3, 43, 6, 10, 5, 85, 2, 28, 7, 73, 8, 68, 0, 45, 
    6, 32, 4, 78, 5,  8, 1, 52, 8, 94, 7, 34, 0, 95, 2, 55, 3, 79, 
    1,  1, 8, 18, 7, 33, 6, 56, 3, 61, 4, 23, 5, 61, 0, 43, 2, 22, 
    1, 15, 6, 26, 8, 22, 5, 13, 2, 59, 0, 39, 4, 80, 3, 70, 7, 75
  };
  const int q3653[] = {
    9, 9, // Number of jobs and machines
    0, 46, 4, 49, 2,  7, 6, 95, 1, 95, 7, 27, 8, 91, 5, 27, 3, 72, 
    1, 92, 2,  5, 7, 10, 6, 20, 3, 29, 0, 59, 4, 82, 5, 15, 8, 36, 
    3, 56, 2, 40, 6, 33, 8, 45, 1,  1, 5, 75, 7, 81, 4,  5, 0,  6, 
    8, 58, 7, 97, 2, 13, 1, 76, 3, 61, 4, 77, 6,  7, 5, 28, 0, 25, 
    8, 58, 0, 71, 7, 74, 6, 39, 4, 67, 2, 11, 1,  9, 3, 57, 5, 43, 
    3, 29, 7, 39, 6, 56, 0, 14, 4, 64, 2, 13, 8, 23, 1, 93, 5, 69, 
    6, 50, 3, 65, 1, 85, 7, 96, 2, 49, 4, 94, 0, 96, 5, 49, 8, 53, 
    8, 43, 1, 51, 7, 74, 3, 38, 6, 92, 2,  5, 4, 46, 5, 86, 0, 68, 
    7, 60, 1, 74, 0, 24, 5, 35, 3, 81, 6, 34, 4, 95, 8, 62, 2, 89
  };
  const int q3654[] = {
    9, 9, // Number of jobs and machines
    7, 26, 4,  3, 1,  8, 6, 89, 0,  2, 8, 73, 3, 96, 2, 74, 5, 26, 
    2, 32, 4, 21, 5, 34, 6, 61, 0, 89, 7,  7, 8, 98, 1, 39, 3, 68, 
    6, 85, 4, 96, 3, 84, 1, 45, 2, 85, 8, 40, 7, 54, 5,  7, 0, 46, 
    8, 84, 3, 79, 4,  1, 7, 40, 1, 81, 5, 78, 2, 42, 6, 88, 0, 35, 
    5, 21, 3, 91, 6, 22, 0, 41, 7, 30, 2, 93, 8, 98, 4, 21, 1, 64, 
    0, 89, 7, 71, 3, 36, 5,  5, 4, 19, 2, 79, 1, 85, 6, 29, 8, 85, 
    2, 34, 6, 57, 5, 31, 3, 42, 4, 84, 8, 67, 0, 90, 1, 30, 7, 67, 
    3, 93, 1, 59, 5, 25, 8, 48, 0, 63, 4, 94, 6, 24, 2, 89, 7, 83, 
    4, 99, 3, 91, 7, 28, 1, 39, 2, 32, 8, 10, 5, 31, 0, 13, 6, 11
  };
  const int q3655[] = {
    9, 9, // Number of jobs and machines
    0, 18, 4, 30, 8, 86, 3, 24, 1, 27, 7, 78, 6, 59, 2, 24, 5, 32, 
    4, 72, 8, 70, 1, 40, 6, 11, 5,  6, 2, 75, 0, 32, 7, 89, 3, 55, 
    8, 15, 4, 92, 3,  8, 0,  2, 6, 10, 1, 83, 2, 68, 5, 58, 7, 17, 
    7, 32, 0, 40, 6, 24, 2,  8, 5, 62, 1, 95, 3, 10, 8, 68, 4, 51, 
    8, 49, 4, 63, 3, 62, 1, 49, 7, 92, 2, 77, 6, 85, 0, 62, 5, 65, 
    5, 93, 7, 37, 4, 18, 6, 22, 3, 92, 1, 63, 8, 33, 2, 21, 0, 73, 
    7, 46, 3, 80, 0, 80, 6, 52, 4, 60, 5, 73, 8, 86, 1, 91, 2, 37, 
    0, 90, 2, 83, 7, 86, 6,  9, 4, 99, 5, 12, 8, 25, 3, 49, 1, 42, 
    3, 21, 2, 43, 1, 73, 7, 92, 8, 11, 0, 47, 5, 85, 4,  7, 6, 99
  };
  const int q3656[] = {
    9, 9, // Number of jobs and machines
    4, 26, 8,  2, 6,  7, 7, 68, 2, 57, 0, 22, 3, 38, 1, 38, 5, 42, 
    6, 61, 2, 51, 5, 35, 7, 30, 0, 49, 8, 22, 4, 94, 1, 13, 3, 81, 
    6, 71, 3, 50, 0, 32, 1, 87, 8, 34, 2,  6, 4, 51, 7, 30, 5, 51, 
    2, 98, 7, 95, 6, 38, 0, 32, 1, 87, 8, 36, 5, 60, 4, 48, 3, 70, 
    3, 84, 6, 69, 7,  2, 0,  6, 5, 26, 1, 26, 4, 70, 2, 64, 8, 27, 
    3, 85, 2, 49, 4, 92, 5, 38, 8, 21, 7, 94, 0, 95, 1, 55, 6, 75, 
    1, 69, 3, 12, 2, 94, 8, 34, 0, 54, 4,  3, 5, 66, 6, 50, 7, 52, 
    7,  3, 0, 98, 3, 80, 2, 10, 6, 85, 5, 14, 8, 10, 1, 46, 4, 13, 
    0, 39, 3, 74, 8, 20, 7, 70, 2, 15, 1, 30, 5,  3, 4, 34, 6, 11
  };
  const int q3657[] = {
    9, 9, // Number of jobs and machines
    8, 90, 1, 13, 3, 88, 0,  5, 6, 62, 4, 54, 7, 93, 5, 28, 2, 34, 
    7, 88, 6, 77, 2, 85, 5, 71, 0, 64, 8, 75, 4, 51, 3, 28, 1, 27, 
    5, 50, 8, 48, 7, 42, 3, 71, 6, 21, 2, 21, 4, 27, 1, 90, 0, 60, 
    6, 42, 7, 32, 8, 72, 5, 30, 1, 19, 4,  4, 3, 80, 0, 76, 2, 46, 
    1, 45, 2, 49, 0, 22, 3,  3, 6, 45, 4, 56, 7, 93, 5,  5, 8, 20, 
    4, 44, 5, 58, 1, 63, 2, 38, 3, 53, 7, 96, 6, 65, 8, 97, 0, 22, 
    3, 17, 2, 36, 5, 27, 0, 53, 7, 86, 8, 33, 4, 44, 1, 18, 6, 62, 
    0, 59, 4, 52, 7, 34, 8, 59, 1, 10, 2, 40, 3, 46, 6, 79, 5, 62, 
    3, 41, 1, 95, 4, 25, 0, 43, 6, 45, 5,  3, 2, 61, 8, 69, 7, 68
  };
  const int q3658[] = {
    9, 9, // Number of jobs and machines
    0,  3, 4, 73, 1, 44, 5, 95, 6, 80, 8, 67, 3, 71, 2, 12, 7, 38, 
    5, 79, 3, 43, 4, 54, 8, 87, 7, 50, 0, 97, 6,  8, 1, 26, 2, 71, 
    5, 38, 6, 89, 1, 80, 8, 95, 4,  4, 0, 27, 2,  8, 7, 59, 3, 90, 
    1, 93, 2, 86, 0, 74, 4, 84, 7, 81, 3, 28, 5,  3, 6, 11, 8, 61, 
    3, 70, 4, 82, 8, 37, 6, 79, 5, 10, 1, 51, 0, 56, 7, 18, 2, 68, 
    3, 29, 8, 31, 1, 81, 7, 14, 4, 17, 6, 69, 0, 64, 5, 17, 2, 82, 
    3, 43, 7, 29, 5, 10, 0, 95, 6, 18, 8,  6, 2, 48, 1, 62, 4, 65, 
    7, 26, 2, 66, 4, 89, 5, 52, 8, 32, 6,  1, 3, 57, 0, 77, 1, 86, 
    7, 85, 5,  7, 3, 70, 6, 29, 8, 12, 2, 53, 0, 11, 1, 63, 4,  7
  };
  const int q3659[] = {
    9, 9, // Number of jobs and machines
    3, 39, 0, 26, 4, 41, 6, 65, 8, 32, 2, 81, 7, 94, 5, 56, 1, 48, 
    1, 60, 0, 28, 4, 97, 5, 30, 7,  3, 6, 52, 3, 76, 2, 98, 8, 84, 
    7, 37, 1, 93, 6, 80, 0, 77, 8, 51, 4, 36, 3, 49, 5, 79, 2,  4, 
    8, 59, 2,  4, 1, 42, 5,  2, 4, 29, 3, 23, 7, 74, 6, 39, 0, 70, 
    5,  7, 4, 37, 1, 24, 2, 70, 0, 99, 7, 66, 8, 14, 6,  5, 3, 50, 
    6, 70, 3, 68, 7, 70, 2, 24, 4, 10, 0, 86, 5, 74, 1, 29, 8, 87, 
    2, 46, 3, 45, 6, 73, 8, 39, 4, 64, 7, 43, 5, 96, 1, 30, 0, 61, 
    5, 47, 3, 30, 1, 49, 6, 94, 7, 47, 0, 74, 4, 18, 8, 69, 2, 59, 
    0, 77, 7, 17, 4, 88, 8, 47, 6,  1, 1, 16, 3, 11, 5, 13, 2, 44
  };
  const int q3660[] = {
    9, 9, // Number of jobs and machines
    3, 31, 8, 40, 5, 70, 7,  3, 0, 82, 1, 14, 4, 11, 6, 20, 2, 86, 
    1, 96, 7,  7, 0, 38, 4, 28, 6, 45, 3, 29, 5,  2, 8,  6, 2,  8, 
    5, 92, 4, 70, 2, 23, 8, 87, 7, 97, 1, 87, 3, 83, 0, 28, 6,  6, 
    5, 51, 8, 14, 1, 29, 3, 46, 0, 87, 2, 51, 6, 45, 7, 23, 4, 65, 
    0, 72, 7, 93, 8, 50, 4, 72, 6, 92, 3, 52, 2, 96, 5,  7, 1, 86, 
    5, 87, 6, 52, 2, 31, 7,  6, 3, 61, 1,  5, 8, 58, 4, 24, 0, 63, 
    6, 72, 5, 12, 8, 34, 3, 24, 0, 22, 4, 22, 1, 46, 7, 42, 2, 60, 
    6, 33, 8, 62, 2, 46, 3, 95, 1, 68, 5, 36, 4, 63, 7, 33, 0, 12, 
    1, 10, 4, 90, 5, 16, 8, 30, 6,  1, 0, 60, 7, 47, 2, 69, 3,  5
  };
  const int q3661[] = {
    9, 9, // Number of jobs and machines
    6,  9, 8, 79, 2,  2, 3, 27, 5, 36, 4, 21, 7, 44, 0,  2, 1, 22, 
    5, 76, 8, 45, 7, 28, 3,  3, 2, 50, 0, 45, 6, 64, 4, 87, 1, 19, 
    4,  7, 2, 16, 1, 98, 5, 96, 3,  8, 0, 39, 7, 69, 8, 16, 6,  9, 
    0, 90, 8, 34, 6,  9, 4, 97, 3,  8, 2, 38, 5,  7, 1, 94, 7, 22, 
    3, 25, 7, 20, 1,  2, 0, 91, 2, 42, 8, 84, 4, 25, 5, 91, 6, 41, 
    7, 94, 5, 14, 4, 48, 3, 77, 2, 16, 0, 20, 8, 74, 6, 59, 1, 79, 
    8, 97, 0, 66, 3, 83, 1, 60, 6,  1, 4, 78, 2, 69, 5, 34, 7, 84, 
    8, 69, 3, 75, 2, 59, 4, 26, 6, 71, 0, 45, 7, 74, 5, 28, 1, 42, 
    7, 58, 0, 55, 8, 91, 5, 94, 2, 82, 1, 76, 4, 30, 3, 90, 6, 46
  };
  const int q3662[] = {
    9, 9, // Number of jobs and machines
    8, 14, 5, 70, 3,  1, 0, 49, 6, 75, 2, 18, 4, 29, 7, 53, 1, 78, 
    1, 28, 4, 77, 5, 96, 8, 47, 2,  7, 7, 93, 3, 56, 0,  8, 6, 15, 
    8, 61, 6, 77, 1, 72, 2, 60, 7, 81, 4, 34, 0,  2, 5, 30, 3, 72, 
    7, 29, 8, 96, 2, 17, 3, 65, 1, 52, 6, 41, 4,  9, 0, 99, 5, 27, 
    8, 94, 7, 64, 3, 17, 5, 40, 1, 41, 6, 29, 2, 91, 4, 65, 0, 60, 
    7, 61, 8, 22, 6, 90, 5, 43, 4, 57, 3, 31, 2, 79, 1, 13, 0, 62, 
    4, 38, 1, 71, 8, 22, 6, 36, 0, 51, 2,  2, 3, 96, 7, 96, 5, 88, 
    7, 50, 8, 30, 1, 15, 4, 82, 0, 34, 5, 68, 3, 46, 2,  7, 6, 82, 
    4,  7, 1, 18, 2, 69, 8, 85, 5, 83, 6, 14, 3, 66, 0, 61, 7, 42
  };
  const int q3663[] = {
    9, 9, // Number of jobs and machines
    4, 62, 5, 26, 3, 16, 2, 32, 0, 38, 8, 69, 6, 53, 7, 50, 1, 22, 
    2, 33, 4, 66, 5, 13, 3, 54, 6, 37, 0, 65, 7, 98, 1, 42, 8, 35, 
    4, 76, 0, 35, 2,  3, 1, 32, 3, 40, 6, 50, 5, 38, 7, 46, 8, 46, 
    7, 99, 4, 39, 5,  4, 8, 88, 3, 85, 1, 83, 2, 19, 6, 32, 0, 83, 
    7, 56, 8, 66, 4,  6, 0, 80, 6, 97, 1,  2, 3, 46, 2, 96, 5,  9, 
    6, 69, 3, 22, 2, 82, 5, 48, 1, 39, 8, 69, 4, 98, 0,  3, 7, 38, 
    3, 27, 5, 41, 4, 18, 2, 64, 6, 76, 8, 33, 7,  2, 0, 63, 1, 57, 
    2, 27, 3, 44, 4, 65, 1, 57, 6, 35, 5, 97, 7, 66, 8, 91, 0, 50, 
    3, 30, 0, 97, 1, 70, 8, 74, 2, 86, 5, 33, 6, 43, 4, 29, 7, 67
  };
  const int q3664[] = {
    9, 9, // Number of jobs and machines
    5, 54, 6, 45, 7, 76, 2, 91, 0, 45, 8, 85, 4, 50, 3, 66, 1, 43, 
    2,  5, 5, 11, 3, 26, 7, 45, 6, 53, 4, 81, 8, 15, 1, 83, 0, 53, 
    7, 75, 6, 91, 4, 68, 3, 58, 5, 60, 8,  4, 0, 93, 2, 18, 1, 50, 
    2, 59, 5, 74, 1, 64, 0, 56, 3, 47, 7, 76, 6, 11, 8, 41, 4, 16, 
    3, 83, 8, 21, 4, 20, 1, 14, 6, 92, 7, 67, 5, 92, 2, 64, 0, 24, 
    5, 47, 3, 50, 4, 47, 1,  4, 0, 40, 6, 79, 2,  8, 7, 43, 8, 52, 
    4, 57, 2, 93, 8, 17, 6, 24, 1, 40, 5, 26, 0, 81, 7, 24, 3, 84, 
    4,  2, 2, 91, 8, 27, 5, 53, 3, 88, 6, 44, 0, 10, 1, 35, 7, 90, 
    1, 54, 6, 10, 7, 12, 8, 92, 0, 44, 3, 27, 2, 24, 5, 10, 4, 46
  };
  const int q3665[] = {
    9, 9, // Number of jobs and machines
    1, 91, 0, 53, 6, 18, 5, 19, 4,  7, 8,  7, 2, 56, 7, 94, 3, 29, 
    1, 39, 7, 36, 8, 86, 6, 92, 0, 73, 3, 13, 5, 77, 4, 46, 2, 19, 
    8, 25, 3, 24, 2, 59, 4, 66, 0, 20, 5,  2, 6, 27, 1, 31, 7, 97, 
    2, 63, 5, 21, 3, 40, 4, 94, 1, 98, 7, 85, 6, 73, 0, 40, 8, 21, 
    1, 38, 6, 20, 8, 25, 0, 75, 4, 10, 3, 93, 7, 13, 5, 65, 2, 86, 
    2, 97, 4,  2, 1, 72, 3, 56, 6, 70, 8,  3, 0, 29, 7, 59, 5, 99, 
    6, 60, 3, 25, 2, 18, 0, 73, 5, 37, 8, 35, 1, 99, 7, 52, 4, 34, 
    3, 65, 6,  4, 7, 81, 2, 24, 4, 91, 5, 94, 1, 69, 8, 96, 0, 67, 
    4, 31, 2, 48, 0,  2, 6, 81, 7, 24, 3, 73, 8, 33, 5, 47, 1, 13
  };
  const int q3666[] = {
    9, 9, // Number of jobs and machines
    4, 80, 6, 66, 5, 62, 0, 95, 2, 53, 1, 31, 3, 34, 7, 72, 8,  7, 
    3, 22, 5, 53, 8, 88, 4, 19, 0, 53, 2, 10, 7, 53, 6, 59, 1, 63, 
    6,  3, 7, 87, 4, 44, 1, 17, 3, 19, 8, 31, 2, 78, 5, 15, 0, 76, 
    1, 40, 6, 90, 0, 58, 2, 64, 5, 10, 7, 90, 3, 45, 4, 52, 8, 22, 
    0,  1, 7, 67, 5, 26, 6,  3, 3, 95, 2, 93, 8, 70, 4, 19, 1, 14, 
    7,  9, 3, 10, 6,  5, 0, 83, 8, 87, 4,  3, 1, 93, 5, 96, 2, 15, 
    8, 43, 0, 73, 2, 19, 3, 62, 1, 55, 5, 32, 6, 66, 7, 22, 4, 93, 
    8, 23, 2, 57, 0, 34, 3, 18, 6, 91, 5, 94, 4, 95, 7, 55, 1, 44, 
    1, 84, 4, 29, 5, 88, 2, 13, 3, 80, 8, 39, 7, 81, 6, 69, 0, 57
  };
  const int q3667[] = {
    9, 9, // Number of jobs and machines
    7, 95, 5,  9, 2, 31, 8, 99, 0, 89, 1, 92, 6, 74, 3,  4, 4, 10, 
    7, 19, 0, 67, 8, 10, 4, 23, 3, 32, 5, 84, 1, 96, 2, 86, 6, 82, 
    2, 14, 6, 47, 3, 21, 0, 99, 7, 31, 5, 56, 4, 13, 1, 94, 8, 93, 
    8, 38, 1, 18, 3,  5, 0, 10, 5, 59, 6, 64, 7, 68, 2, 92, 4, 34, 
    4, 75, 0, 99, 6, 84, 5,  6, 3, 33, 2, 24, 7, 23, 1, 51, 8, 35, 
    5, 42, 6, 53, 1,  3, 8,  4, 2, 19, 3, 18, 0, 38, 7, 88, 4, 59, 
    5, 11, 6, 71, 4, 80, 7, 20, 0, 90, 8, 83, 3, 13, 1, 55, 2, 16, 
    3, 60, 8, 47, 0, 98, 6, 76, 2, 32, 5, 85, 7, 41, 4, 65, 1, 52, 
    1, 62, 6, 45, 3, 89, 2, 43, 8,  4, 7, 35, 0, 76, 5, 74, 4, 72
  };
  const int q3668[] = {
    9, 9, // Number of jobs and machines
    4, 77, 2, 21, 8, 62, 1, 36, 6, 30, 7,  5, 3, 87, 5, 12, 0, 17, 
    0, 98, 2, 96, 8, 16, 7, 21, 3, 63, 1,  1, 6, 19, 4, 77, 5,  6, 
    0, 76, 2, 60, 8, 42, 6, 57, 7,  2, 5, 57, 3, 91, 1, 32, 4, 15, 
    5, 41, 2, 12, 3, 72, 7, 95, 8, 65, 4, 82, 1, 88, 0, 43, 6, 87, 
    5, 91, 2, 87, 3, 90, 1, 21, 4, 18, 0, 84, 7, 62, 8, 25, 6, 73, 
    2, 80, 5, 84, 8, 54, 4, 50, 0, 99, 3, 16, 1, 61, 6, 89, 7, 68, 
    7, 81, 5, 48, 1,  7, 0, 57, 2, 31, 6, 48, 4, 36, 3, 33, 8, 38, 
    5, 88, 0, 80, 7, 66, 4, 94, 1, 35, 6, 16, 8, 31, 3,  4, 2, 86, 
    4, 56, 3, 61, 2, 80, 8, 79, 0, 62, 1, 85, 6, 19, 7, 15, 5, 98
  };
  const int q3669[] = {
    9, 9, // Number of jobs and machines
    4, 61, 5, 23, 8,  9, 6, 50, 0, 44, 2, 71, 1, 82, 3,  5, 7, 44, 
    6, 94, 1, 64, 4,  1, 0, 51, 5, 36, 2, 76, 3, 63, 7, 35, 8, 62, 
    6, 63, 3, 75, 0, 41, 4, 34, 7, 44, 5, 93, 8, 41, 1, 88, 2, 29, 
    8, 29, 5, 14, 0, 43, 6, 78, 2,  7, 4, 78, 7, 25, 3, 53, 1, 89, 
    0,  9, 7, 25, 3, 53, 1, 39, 2, 59, 4, 56, 5, 15, 6, 12, 8, 28, 
    4, 28, 7, 11, 5, 75, 1, 12, 3,  1, 6, 77, 0, 70, 8, 57, 2, 24, 
    6,  3, 8, 95, 4,  7, 1, 19, 0, 32, 2, 69, 5, 82, 3, 14, 7, 45, 
    1, 90, 0, 69, 7, 25, 2, 87, 6, 46, 5, 95, 4, 81, 3, 16, 8, 78, 
    8, 59, 5, 71, 0, 54, 1, 47, 4, 22, 2, 91, 6, 38, 7, 51, 3, 47
  };
  const int q3670[] = {
    9, 9, // Number of jobs and machines
    1,  8, 3,  8, 4,  9, 0, 45, 2, 35, 8, 55, 7, 63, 5, 41, 6, 35, 
    0, 64, 3, 38, 4, 85, 2, 67, 8, 44, 1, 66, 6, 13, 5, 33, 7, 17, 
    5, 64, 1, 68, 6, 39, 2, 74, 8, 29, 4, 54, 3, 66, 7, 52, 0, 25, 
    8,  6, 1, 27, 5, 23, 0, 91, 4,  5, 7, 40, 3, 42, 2, 46, 6, 44, 
    4, 85, 3, 17, 7, 83, 1, 24, 8, 51, 2, 33, 6, 40, 5, 20, 0, 94, 
    4, 67, 6, 41, 3, 50, 5, 58, 7, 74, 1, 45, 0, 71, 8, 22, 2, 56, 
    1, 90, 5, 14, 2, 94, 0, 79, 8, 70, 4, 62, 3, 38, 6, 58, 7,  8, 
    7, 51, 8, 96, 2, 15, 6, 78, 4, 35, 5, 66, 1, 68, 3, 21, 0,  6, 
    7, 73, 4, 52, 8, 24, 2, 77, 3, 98, 5, 18, 0, 67, 6, 72, 1, 66
  };
  const int q3671[] = {
    9, 9, // Number of jobs and machines
    8, 71, 5, 45, 6, 18, 7, 71, 4, 94, 2,  2, 3, 61, 1, 45, 0,  7, 
    5, 75, 6, 30, 3,  6, 0, 10, 2, 51, 4, 31, 1, 65, 7, 47, 8, 47, 
    5, 38, 6, 20, 7, 50, 0, 34, 3, 37, 4, 19, 1, 11, 8, 81, 2, 54, 
    4, 99, 7, 78, 0, 22, 2, 11, 3, 93, 8, 97, 6, 78, 5,  6, 1, 48, 
    5, 51, 2, 44, 7, 50, 1, 30, 8, 22, 6, 98, 4, 74, 3, 13, 0, 53, 
    4, 71, 8, 67, 7, 88, 0, 92, 6, 99, 1, 98, 2, 56, 3, 65, 5, 53, 
    3, 86, 2, 25, 7, 99, 0, 26, 4, 50, 6, 56, 1, 75, 8,  9, 5, 59, 
    3, 56, 5, 25, 0, 34, 8, 28, 7,  7, 1, 91, 4, 89, 6, 71, 2,  7, 
    4, 97, 2, 85, 5, 32, 3, 80, 1, 39, 7, 51, 6, 15, 8, 43, 0, 79
  };
  const int q3672[] = {
    9, 9, // Number of jobs and machines
    7, 65, 1, 93, 5, 25, 2, 45, 3, 36, 8, 96, 6, 65, 4, 64, 0, 97, 
    7,  5, 3, 99, 1, 56, 4, 65, 8, 78, 0, 86, 2, 24, 5, 81, 6, 37, 
    4, 86, 3,  3, 8, 30, 0, 15, 5, 15, 7, 56, 2, 24, 1, 98, 6, 60, 
    6, 32, 2,  9, 8, 75, 1, 39, 3, 15, 4, 14, 0, 16, 7, 43, 5, 32, 
    4, 20, 3, 79, 8, 31, 5, 67, 6, 69, 2, 12, 7, 96, 0, 53, 1, 78, 
    2, 14, 4, 14, 7, 59, 5, 58, 1, 83, 3, 64, 6, 24, 8,  2, 0, 50, 
    3, 54, 0, 61, 8, 43, 1, 70, 4, 95, 5, 30, 6, 47, 7, 15, 2, 86, 
    0, 32, 7, 39, 1, 66, 5, 27, 2, 89, 8, 57, 3, 90, 4, 39, 6, 36, 
    2, 24, 1, 16, 7, 98, 0, 18, 8, 54, 4,  8, 3, 45, 6, 33, 5, 27
  };
  const int q3673[] = {
    9, 9, // Number of jobs and machines
    5, 10, 4, 27, 2, 10, 0,  3, 1, 99, 3, 47, 8, 72, 7, 86, 6, 81, 
    7, 77, 8, 32, 3, 66, 2, 91, 1, 51, 5, 29, 6, 20, 4, 23, 0, 56, 
    5, 57, 1, 21, 6, 50, 8, 87, 0, 94, 4, 56, 7, 69, 2, 15, 3, 77, 
    7, 81, 0, 97, 4, 57, 8, 14, 6, 97, 5, 54, 1, 48, 3, 97, 2, 55, 
    5, 93, 6, 85, 1, 48, 8, 47, 7, 93, 3, 48, 2, 73, 0, 74, 4, 60, 
    3, 63, 4, 98, 1, 85, 6, 18, 7, 17, 2, 21, 8,  5, 5, 47, 0, 15, 
    0, 19, 7, 85, 2, 19, 3, 91, 1, 48, 4, 61, 6, 64, 8, 51, 5,  9, 
    5, 62, 7, 58, 1, 47, 6, 83, 2, 12, 0, 48, 8, 73, 3, 83, 4, 65, 
    6, 13, 1, 83, 7, 97, 3,  1, 2,  7, 5, 91, 0, 49, 4, 18, 8, 13
  };
  const int q3674[] = {
    9, 9, // Number of jobs and machines
    1,  3, 2, 65, 7, 45, 0, 10, 3, 66, 4, 31, 8, 38, 5, 22, 6, 91, 
    3, 33, 5, 14, 0, 22, 6, 16, 8, 36, 1, 20, 4,  8, 7, 17, 2, 87, 
    3, 68, 2, 47, 1, 51, 4, 12, 0, 38, 5, 79, 6, 71, 7, 17, 8, 18, 
    3, 24, 5, 92, 0, 88, 7, 42, 6, 24, 1, 94, 2, 50, 8, 35, 4,  4, 
    0, 58, 8, 17, 1, 62, 5, 64, 2, 93, 7, 84, 3, 54, 6, 20, 4, 28, 
    3, 81, 0, 73, 4,  1, 1, 21, 6, 14, 7, 10, 5, 78, 8, 42, 2, 70, 
    0, 98, 8, 68, 1, 29, 4, 51, 7, 70, 2,  4, 6, 62, 3, 53, 5, 66, 
    6, 72, 0, 58, 2, 81, 3, 88, 4, 83, 7, 59, 5, 74, 1, 22, 8, 76, 
    8, 92, 0, 58, 2,  6, 4, 35, 5,  8, 3, 55, 6, 13, 7, 80, 1, 19
  };
  const int q3675[] = {
    9, 9, // Number of jobs and machines
    1, 17, 3, 52, 0, 10, 8,  2, 6, 38, 7, 73, 2,  6, 4, 96, 5, 58, 
    5, 15, 4, 37, 6, 65, 2, 12, 3, 23, 7, 75, 0, 44, 1, 92, 8, 40, 
    8, 18, 6, 54, 1,  6, 3, 47, 0, 83, 2, 59, 4, 45, 5, 96, 7, 36, 
    6, 38, 7, 53, 0, 37, 3, 82, 4,  9, 5, 36, 2, 72, 8, 32, 1, 49, 
    5, 66, 4, 74, 1, 63, 3, 51, 6,  8, 0, 80, 7, 28, 8, 92, 2, 39, 
    8, 37, 4, 19, 1, 10, 6, 98, 3, 15, 7, 80, 2, 80, 0, 91, 5, 98, 
    5, 11, 2, 81, 1, 87, 4, 52, 7, 92, 3, 22, 8, 91, 6, 12, 0, 70, 
    4, 18, 3, 20, 7, 23, 5, 34, 0, 14, 6, 86, 1, 32, 2,  5, 8, 85, 
    7, 88, 0, 53, 6, 80, 4, 61, 3, 15, 1, 80, 5, 56, 8, 60, 2, 86
  };
  const int q3676[] = {
    9, 9, // Number of jobs and machines
    1, 12, 6, 30, 8, 11, 7, 31, 2, 45, 0, 94, 3, 20, 4, 42, 5, 71, 
    6, 91, 5, 36, 4, 76, 7, 61, 0, 12, 2, 57, 8, 76, 3, 26, 1, 47, 
    8, 72, 1, 92, 5, 19, 0, 52, 7, 62, 2,  1, 4,  2, 3, 14, 6,  8, 
    3, 56, 4, 29, 5, 75, 0, 72, 8, 86, 7, 41, 1, 61, 2, 43, 6, 76, 
    7, 21, 8, 75, 2, 47, 6, 19, 4, 28, 3, 13, 0, 98, 1, 13, 5,  9, 
    8,  4, 0, 88, 7, 61, 2, 47, 4, 15, 6, 30, 1, 16, 3, 46, 5, 60, 
    2, 76, 0, 99, 4, 91, 1, 64, 7, 14, 8, 47, 6, 70, 3, 61, 5, 27, 
    4, 53, 8, 18, 2, 33, 3, 43, 5, 44, 0, 41, 7, 98, 6, 87, 1, 40, 
    6, 49, 7, 55, 0, 77, 3, 41, 5, 30, 4, 81, 1, 92, 2, 62, 8, 52
  };
  const int q3677[] = {
    9, 9, // Number of jobs and machines
    2, 97, 0,  6, 4, 61, 5, 28, 3,  6, 6, 21, 7, 30, 1, 96, 8, 92, 
    3, 82, 7, 12, 4, 99, 0, 75, 1, 68, 2, 68, 5, 60, 6,  8, 8, 72, 
    7, 58, 4, 77, 0,  9, 3, 75, 2, 81, 5, 32, 1, 46, 6, 44, 8, 94, 
    4, 79, 7, 40, 1, 30, 5, 81, 6, 60, 8, 34, 0, 66, 3, 31, 2, 61, 
    1, 32, 0, 44, 3, 25, 6, 40, 8, 56, 2, 56, 5, 91, 7, 44, 4, 87, 
    2,  7, 3, 73, 6, 76, 7,  6, 8, 27, 0, 57, 1, 15, 5, 79, 4, 20, 
    7, 84, 0, 87, 2, 13, 3, 28, 8, 78, 1, 18, 4, 76, 6, 98, 5, 71, 
    5, 92, 8, 42, 1, 13, 3, 49, 2, 85, 7, 58, 0, 15, 4, 40, 6, 63, 
    7, 48, 1, 95, 5, 59, 0, 77, 8, 97, 6, 52, 2, 65, 3, 88, 4, 71
  };
  const int q3678[] = {
    9, 9, // Number of jobs and machines
    4,  9, 2, 29, 3,  3, 1, 56, 0, 29, 8, 24, 7, 41, 5, 23, 6, 16, 
    4, 44, 5, 94, 1, 27, 7, 86, 3, 76, 0,  9, 2, 85, 8, 48, 6, 36, 
    5, 11, 0, 31, 1, 70, 8, 71, 4, 65, 2, 68, 3, 48, 7, 20, 6, 15, 
    1, 46, 0, 27, 8, 29, 4, 89, 2, 57, 7, 28, 5, 38, 6, 61, 3, 94, 
    0, 94, 4, 33, 5,  1, 2, 78, 8, 91, 6, 76, 7, 25, 1, 89, 3, 44, 
    8, 69, 4, 68, 6, 83, 0, 53, 5, 70, 1, 14, 7, 22, 2, 21, 3, 73, 
    1, 58, 3, 40, 8, 79, 6, 76, 7, 35, 5, 42, 4, 52, 2, 85, 0, 47, 
    5,  1, 1, 60, 3,  9, 2, 68, 0, 99, 8, 90, 4, 83, 7, 14, 6, 98, 
    6, 84, 2, 90, 7, 32, 5, 72, 4, 26, 1, 57, 0, 97, 8, 23, 3, 28
  };
  const int q3679[] = {
    9, 9, // Number of jobs and machines
    1, 66, 7, 41, 8, 83, 5, 46, 6, 78, 4, 14, 3,  4, 2, 18, 0,  2, 
    6, 58, 8, 32, 5, 23, 1, 35, 0, 94, 7, 20, 3, 92, 2, 54, 4, 63, 
    3, 74, 1, 29, 7, 48, 4,  9, 5, 29, 0, 83, 8, 93, 2, 66, 6, 63, 
    4, 88, 1, 40, 6, 33, 7, 82, 8, 17, 3, 97, 5, 24, 0, 96, 2, 39, 
    0,  4, 3, 46, 4,  5, 2, 52, 5, 11, 6, 44, 8, 19, 7, 51, 1, 16, 
    8, 89, 7, 54, 1, 34, 4,  1, 2, 99, 6, 92, 5, 39, 0, 55, 3, 26, 
    6, 68, 2, 52, 1, 22, 0, 92, 4, 41, 7, 68, 8, 45, 5, 45, 3, 27, 
    6, 70, 5, 36, 4, 69, 8, 74, 0, 75, 7, 95, 2, 48, 3, 10, 1, 71, 
    8, 54, 3, 73, 0, 64, 2, 40, 7, 90, 4, 59, 1, 74, 5, 63, 6, 83
  };
  const int q3680[] = {
    9, 9, // Number of jobs and machines
    2, 90, 0, 47, 3, 85, 1, 18, 5, 58, 6, 97, 4, 23, 7, 68, 8, 31, 
    4, 16, 8,  1, 2, 80, 0, 63, 5, 36, 3, 39, 1, 53, 7, 35, 6, 53, 
    6, 53, 5, 72, 0,  5, 4, 93, 3, 20, 1, 63, 2, 29, 7, 77, 8, 65, 
    2, 94, 1, 77, 5, 27, 4, 90, 8, 95, 7, 51, 6, 91, 3, 79, 0, 71, 
    1, 73, 4, 89, 3, 71, 7, 57, 8, 27, 5, 85, 2, 42, 6, 28, 0, 25, 
    2, 28, 0, 32, 8, 13, 7, 32, 5,  4, 1, 80, 3, 39, 6, 48, 4, 92, 
    8, 34, 5, 46, 0, 23, 4, 44, 3, 20, 1, 17, 6, 59, 2, 54, 7, 32, 
    3, 44, 8, 51, 4,  3, 1, 52, 7, 23, 2, 19, 6, 42, 5, 89, 0,  7, 
    4, 87, 6, 72, 8, 48, 1, 29, 7, 92, 5, 30, 2,  6, 3,  1, 0, 61
  };
  const int q3681[] = {
    9, 9, // Number of jobs and machines
    8, 34, 7, 88, 5,  2, 6, 61, 2, 63, 3, 97, 1,  7, 4, 73, 0, 84, 
    6, 22, 3, 37, 2, 71, 5, 91, 4, 59, 8, 38, 7, 50, 0, 35, 1, 85, 
    8, 30, 0, 39, 2, 85, 7, 59, 4, 49, 1, 58, 3, 56, 5, 13, 6,  9, 
    2, 28, 0, 35, 3, 87, 7,  1, 6, 60, 5, 46, 8, 41, 4, 22, 1, 80, 
    0,  3, 3, 87, 1, 33, 8, 45, 2,  6, 4, 57, 6, 64, 5, 56, 7, 72, 
    0, 27, 5, 26, 1, 18, 4, 46, 8, 39, 2, 55, 6, 84, 3, 18, 7,  8, 
    0,  6, 1, 60, 5, 81, 4,  5, 3, 94, 8, 87, 2, 23, 6, 71, 7, 81, 
    6, 75, 7,  9, 8, 22, 4, 65, 1, 45, 2,  8, 0, 78, 3, 84, 5,  9, 
    2, 46, 4, 14, 5, 10, 7, 78, 3, 17, 1,  5, 8, 99, 6, 64, 0, 42
  };
  const int q3682[] = {
    9, 9, // Number of jobs and machines
    0, 68, 5, 25, 7, 86, 6, 78, 4, 48, 8, 87, 1, 19, 2, 21, 3, 15, 
    3, 56, 8, 65, 7, 79, 4, 40, 5, 24, 1, 15, 6, 34, 2, 70, 0,  1, 
    5, 52, 4, 43, 6, 48, 8, 20, 7, 74, 1, 60, 0, 56, 3, 14, 2, 94, 
    0, 73, 3,  2, 6, 92, 2, 40, 1, 91, 8, 17, 5, 69, 7, 35, 4, 60, 
    6, 48, 5, 24, 2, 73, 4, 50, 8, 43, 7, 11, 0, 32, 1, 27, 3, 29, 
    3, 23, 7, 66, 2, 21, 1, 88, 8, 88, 5, 12, 6, 54, 4, 28, 0, 40, 
    8, 77, 2, 58, 0, 24, 1, 36, 5, 16, 7, 91, 4, 84, 3, 23, 6, 74, 
    7, 50, 0, 30, 2, 39, 4, 62, 3, 50, 8,  5, 1, 15, 5, 15, 6, 88, 
    8, 46, 4, 70, 7, 39, 1, 46, 2, 76, 0, 57, 3, 63, 6, 39, 5, 62
  };
  const int q3683[] = {
    9, 9, // Number of jobs and machines
    2, 54, 7, 88, 4, 97, 1, 98, 5, 18, 3,  7, 0, 65, 8, 64, 6, 40, 
    1, 40, 8,  1, 3, 16, 7, 77, 6, 27, 5, 90, 0, 18, 4, 58, 2, 14, 
    6,  2, 8, 51, 1, 81, 7,  3, 2, 67, 5, 91, 3, 48, 4, 14, 0, 59, 
    5, 63, 1, 17, 2, 34, 3, 99, 4, 50, 6, 31, 0, 87, 8, 25, 7, 64, 
    8, 98, 6, 68, 4, 53, 2, 50, 5, 29, 7, 78, 0, 17, 1, 75, 3, 78, 
    1, 83, 6, 44, 0,  7, 4, 82, 3, 41, 8, 41, 5, 15, 7, 45, 2, 95, 
    6, 66, 3, 60, 8, 21, 5, 42, 4, 36, 0, 79, 7, 99, 1, 40, 2, 40, 
    8, 71, 3, 12, 0, 57, 2, 34, 7, 50, 4, 76, 6, 85, 1, 68, 5, 51, 
    3, 14, 1, 11, 7, 33, 6, 30, 4, 58, 8, 20, 2, 38, 5, 18, 0, 47
  };
  const int q3684[] = {
    9, 9, // Number of jobs and machines
    4, 83, 3, 16, 5, 80, 7, 39, 8, 14, 6, 88, 1, 87, 2, 32, 0, 83, 
    2, 56, 0, 52, 6, 40, 4, 64, 5,  2, 1, 54, 8, 47, 7, 56, 3,  4, 
    5, 88, 3, 30, 2,  6, 0, 15, 7, 57, 4, 92, 6, 22, 1, 51, 8, 43, 
    7, 95, 3,  1, 0, 68, 5, 56, 6, 51, 1, 11, 8, 66, 4, 27, 2, 63, 
    7, 74, 0, 71, 2, 49, 1, 97, 6, 73, 4, 95, 5, 61, 3, 40, 8, 51, 
    5, 42, 8, 59, 7, 33, 2, 41, 6, 91, 4, 79, 0, 22, 3, 44, 1, 77, 
    1,  8, 3, 33, 2, 21, 5, 80, 4, 56, 7, 58, 0, 59, 6,  8, 8, 91, 
    7, 44, 0, 24, 2, 84, 5, 31, 8, 88, 3,  7, 4, 88, 1, 64, 6, 39, 
    4, 32, 3, 36, 6, 48, 2, 93, 1, 16, 0, 51, 5, 61, 7, 94, 8, 73
  };
  const int q3685[] = {
    9, 9, // Number of jobs and machines
    2,  7, 6,  7, 8, 55, 7, 83, 5, 78, 1, 86, 4, 28, 0, 32, 3, 85, 
    7, 37, 8, 91, 3, 14, 5, 18, 2, 11, 1, 17, 6,  8, 0, 35, 4, 98, 
    4, 83, 6, 87, 1, 44, 2, 46, 0, 16, 3, 73, 7, 51, 8, 47, 5, 47, 
    6, 32, 2, 69, 7,  8, 8,  7, 0, 63, 1, 89, 5, 18, 4, 63, 3, 64, 
    8, 25, 0, 28, 1, 78, 7, 88, 3, 42, 6, 36, 5, 40, 2, 67, 4, 81, 
    0, 49, 3,  2, 1, 73, 6, 49, 5, 32, 8, 69, 4, 31, 2, 81, 7, 16, 
    7, 27, 0, 25, 4, 52, 6, 67, 8, 74, 5, 99, 1, 62, 3, 32, 2, 98, 
    8, 98, 1, 82, 3, 54, 7, 99, 6, 24, 4, 34, 0, 13, 5, 54, 2, 10, 
    7, 19, 8, 62, 2, 16, 0, 10, 5, 13, 4, 44, 1, 27, 3, 75, 6, 99
  };
  const int q3686[] = {
    9, 9, // Number of jobs and machines
    4, 30, 3, 37, 5, 61, 6, 27, 2,  4, 8,  2, 7, 67, 0, 86, 1, 48, 
    6, 34, 4, 16, 1, 15, 0, 82, 5, 35, 8, 97, 2, 54, 7, 21, 3, 87, 
    6, 40, 3, 25, 4, 57, 0, 67, 2, 93, 8, 25, 1,  6, 5, 78, 7, 38, 
    0, 88, 3,  9, 2, 37, 4, 79, 6, 77, 8, 74, 1, 76, 5, 34, 7, 37, 
    7, 92, 3, 96, 5, 43, 4, 59, 2, 72, 6, 96, 8, 96, 0, 17, 1, 96, 
    1, 76, 2, 59, 3, 58, 4, 79, 6, 21, 8, 83, 7, 26, 0, 65, 5, 17, 
    3,  9, 0, 51, 6, 84, 2, 52, 8, 98, 4, 25, 5, 98, 7, 23, 1, 44, 
    6, 43, 5, 72, 8, 34, 4, 15, 2, 32, 1, 67, 7, 37, 3, 49, 0, 41, 
    4, 70, 6, 35, 8, 33, 2, 89, 0, 27, 7, 61, 1, 86, 3, 41, 5, 74
  };
  const int q3687[] = {
    9, 9, // Number of jobs and machines
    1,  7, 0, 31, 8,  5, 3, 54, 7, 97, 2, 70, 6, 65, 5, 51, 4, 73, 
    7, 41, 0, 96, 3, 32, 1, 33, 8, 26, 4, 75, 6, 49, 5, 53, 2, 58, 
    0, 86, 3, 47, 6,  6, 2, 65, 4, 85, 5, 38, 1, 62, 8, 82, 7, 22, 
    2, 99, 6, 13, 7, 42, 4, 32, 8, 20, 0, 45, 5, 76, 3, 83, 1,  7, 
    4, 74, 3, 13, 8, 78, 5,  4, 6, 23, 1, 87, 2,  4, 0, 29, 7, 52, 
    4, 32, 2,  6, 8, 58, 0, 43, 3,  8, 7, 72, 5, 64, 6, 63, 1, 46, 
    2, 78, 5, 47, 6, 28, 4, 27, 1, 67, 8, 41, 3,  6, 7, 91, 0, 70, 
    8, 47, 7, 51, 1, 51, 6, 14, 2, 77, 0, 55, 4, 13, 5, 96, 3, 99, 
    2, 53, 5, 60, 1, 44, 6, 87, 4, 78, 7, 73, 3, 79, 8, 49, 0,  5
  };
  const int q3688[] = {
    9, 9, // Number of jobs and machines
    6, 76, 8, 40, 5, 42, 7, 78, 0, 31, 2, 26, 3, 66, 4, 20, 1,  6, 
    6, 54, 7, 59, 3, 77, 0, 68, 8, 39, 1, 16, 4, 74, 2, 20, 5, 59, 
    0, 62, 6, 25, 2, 95, 1, 46, 7, 20, 3, 51, 4,  1, 8, 67, 5, 65, 
    7, 17, 8, 15, 1, 79, 2, 94, 3, 36, 4, 98, 6, 10, 0,  8, 5, 14, 
    0, 38, 1,  1, 4, 47, 8, 56, 5, 36, 6, 79, 7, 66, 2, 72, 3, 74, 
    1, 93, 5, 10, 4, 98, 0, 71, 8, 75, 7, 55, 3, 15, 2, 23, 6, 68, 
    3, 65, 5, 57, 1, 82, 4, 77, 0, 87, 2, 87, 7,  9, 8, 46, 6,  9, 
    4, 71, 0, 17, 3, 95, 6, 25, 7, 60, 5, 13, 1, 29, 8, 22, 2, 10, 
    2, 66, 3, 38, 0, 81, 7, 76, 4, 37, 1, 63, 5, 53, 8, 89, 6, 53
  };
  const int q3689[] = {
    9, 9, // Number of jobs and machines
    4, 18, 8, 82, 7, 83, 2, 82, 0, 22, 3, 37, 1, 14, 6, 23, 5, 78, 
    2, 13, 3, 81, 7, 24, 6, 64, 4, 89, 1, 91, 8, 22, 5, 22, 0,  9, 
    8,  4, 3, 59, 1, 40, 4,  5, 6, 79, 5, 62, 2, 20, 0, 58, 7, 73, 
    2, 42, 8, 57, 1, 51, 4, 10, 3, 56, 0, 10, 7, 90, 6, 39, 5, 43, 
    6, 65, 0, 46, 8, 20, 3, 25, 7, 32, 2, 60, 5,  1, 4, 69, 1, 89, 
    2, 90, 5, 24, 6, 62, 1, 88, 8, 73, 7, 29, 3, 85, 4, 37, 0, 15, 
    8,  2, 7,  3, 5, 15, 4, 33, 3, 94, 2, 58, 0, 58, 1, 55, 6, 36, 
    0, 35, 8, 29, 2, 25, 3, 89, 7, 57, 1, 34, 6, 36, 5, 30, 4, 36, 
    0, 47, 1, 42, 2, 17, 5, 82, 4, 10, 6, 21, 3, 76, 7, 94, 8, 47
  };
  const int q3690[] = {
    9, 9, // Number of jobs and machines
    4, 73, 3, 56, 0, 27, 1, 59, 6, 93, 5, 86, 2, 86, 7, 72, 8, 12, 
    0, 10, 8,  2, 5, 17, 4, 19, 7, 63, 6, 70, 3, 44, 1, 47, 2, 99, 
    8, 46, 6, 30, 4, 80, 1,  3, 0, 74, 7, 97, 5, 98, 2, 33, 3, 38, 
    5, 46, 0, 93, 3, 67, 8, 24, 1, 28, 6, 82, 4, 15, 7, 36, 2, 69, 
    2, 43, 8, 81, 4, 32, 5,  8, 3, 65, 6, 82, 1, 90, 7, 85, 0, 87, 
    6,  2, 0, 42, 2,  1, 5,  9, 7, 68, 8, 20, 3, 63, 1,  5, 4, 99, 
    6, 74, 5, 27, 8, 45, 0, 16, 1, 64, 4, 65, 3, 72, 2, 53, 7, 15, 
    4, 57, 2, 77, 8, 36, 3, 81, 5, 76, 0, 19, 6, 41, 7, 98, 1,  6, 
    3, 10, 8, 73, 0, 92, 5, 20, 6,  7, 4, 62, 1,  8, 7, 19, 2, 74
  };
  const int q3691[] = {
    9, 9, // Number of jobs and machines
    3,  7, 2, 99, 0, 60, 4, 70, 5, 80, 8, 15, 6, 66, 7, 66, 1,  1, 
    1, 53, 5, 36, 2, 20, 6, 16, 8, 32, 3, 35, 4, 18, 0, 13, 7, 98, 
    7, 98, 4, 91, 6, 43, 3, 41, 8, 41, 0, 75, 5,  3, 2, 83, 1, 95, 
    5, 70, 1, 91, 7, 88, 3, 83, 2, 29, 4, 16, 6, 45, 8, 49, 0, 25, 
    4,  8, 1, 99, 2, 52, 3, 45, 6, 79, 8, 48, 5, 80, 7,  5, 0, 55, 
    4, 62, 7, 60, 3, 47, 1, 28, 5, 76, 0, 37, 2, 46, 6, 86, 8, 69, 
    5, 91, 8, 18, 6, 94, 3, 56, 1, 62, 0, 44, 7, 81, 4, 68, 2, 30, 
    0, 66, 4, 10, 6, 57, 5, 75, 3, 73, 1, 95, 2, 82, 7, 57, 8, 70, 
    2, 94, 5, 50, 3, 77, 0, 60, 7, 66, 6, 15, 4, 48, 8, 59, 1, 21
  };
  const int q3692[] = {
    9, 9, // Number of jobs and machines
    6, 88, 8, 15, 4, 29, 2, 30, 1, 68, 3, 39, 5, 38, 0, 74, 7, 33, 
    6, 93, 5, 10, 1, 95, 8, 41, 7, 64, 3, 85, 2, 67, 4, 37, 0, 13, 
    7, 45, 2, 51, 4, 94, 0,  9, 5, 57, 8, 25, 1, 61, 6,  1, 3, 98, 
    2, 24, 3, 42, 6, 18, 4, 35, 7, 25, 0, 37, 8, 87, 1, 48, 5, 88, 
    3, 55, 8, 60, 0, 63, 2,  3, 6, 67, 5, 32, 7,  6, 4, 64, 1, 89, 
    0, 58, 2, 64, 4, 79, 6,  7, 5, 13, 1, 80, 7, 89, 8, 34, 3, 30, 
    4, 45, 3,  7, 8, 89, 2, 78, 1, 15, 6, 85, 7, 73, 0, 66, 5, 63, 
    5, 57, 7, 13, 4, 18, 3, 92, 1, 57, 8, 75, 0, 84, 2,  3, 6, 61, 
    7, 97, 4, 67, 2, 84, 6, 52, 0,  6, 5,  3, 3, 51, 8, 72, 1, 68
  };
  const int q3693[] = {
    9, 9, // Number of jobs and machines
    0, 66, 1, 38, 8, 34, 6, 80, 3, 28, 2, 75, 7, 87, 5, 17, 4, 56, 
    1, 97, 0, 11, 2, 67, 5, 18, 7, 29, 4, 12, 8, 81, 6, 76, 3, 63, 
    8, 12, 4, 87, 1, 29, 6, 91, 0, 27, 3, 88, 5, 27, 7, 81, 2, 30, 
    7, 46, 2, 28, 1, 84, 8, 58, 5, 66, 3, 69, 0, 81, 6, 57, 4, 15, 
    6, 97, 1,  6, 2, 76, 5, 58, 4, 90, 7, 97, 0, 65, 8, 50, 3, 16, 
    1, 73, 8, 49, 0, 94, 2,  4, 7, 28, 5, 89, 4, 50, 3, 25, 6, 40, 
    6, 80, 8, 80, 2, 16, 4, 58, 5, 72, 1, 42, 0, 53, 3, 50, 7, 75, 
    6, 78, 7, 18, 2, 82, 4,  5, 3, 37, 5, 83, 1, 60, 8, 79, 0, 50, 
    1, 20, 7, 41, 6, 94, 4, 56, 3,  5, 2, 13, 0, 35, 8, 17, 5, 93
  };
  const int q3694[] = {
    9, 9, // Number of jobs and machines
    2, 53, 4, 21, 1, 88, 8, 78, 6, 74, 7, 89, 5, 84, 0, 82, 3, 69, 
    6, 71, 3, 33, 1, 93, 8, 63, 2, 22, 5, 10, 0, 67, 7,  7, 4, 33, 
    4,  1, 1, 55, 6, 76, 2, 14, 5, 17, 7, 41, 0, 68, 3, 27, 8, 96, 
    8, 11, 3, 58, 7, 25, 6, 16, 4, 89, 5, 45, 0, 86, 1, 43, 2, 87, 
    7, 84, 1, 83, 3, 82, 8, 85, 4, 14, 5, 75, 0, 60, 2, 11, 6, 67, 
    5, 15, 4, 72, 3, 26, 8, 33, 1, 35, 2,  1, 7, 89, 6, 89, 0, 41, 
    0, 22, 1, 47, 7, 57, 5,  7, 4, 43, 8, 58, 6, 50, 2, 28, 3, 23, 
    4, 84, 7, 47, 8, 13, 2, 29, 1, 66, 3, 55, 6,  5, 5, 13, 0,  5, 
    6, 65, 3, 84, 2, 61, 0, 56, 5, 57, 4, 79, 8, 67, 1, 68, 7, 53
  };
  const int q3695[] = {
    9, 9, // Number of jobs and machines
    3, 47, 7, 21, 5, 85, 1, 83, 0, 29, 6,  1, 4, 27, 8, 98, 2, 46, 
    1, 70, 7, 99, 3, 44, 5, 31, 0, 41, 4, 13, 2, 90, 6, 31, 8, 12, 
    8, 57, 5, 91, 4, 58, 7, 80, 2, 69, 3, 99, 6, 39, 1, 94, 0, 68, 
    7, 90, 3, 16, 1, 27, 8, 91, 4, 60, 6, 35, 5, 80, 0,  4, 2, 50, 
    3, 71, 4, 44, 1,  5, 6, 86, 0, 45, 2, 37, 5, 80, 8, 36, 7, 29, 
    5, 39, 2, 43, 3, 87, 6, 63, 4, 66, 7, 64, 0, 96, 1, 39, 8, 34, 
    7, 28, 3, 65, 6, 76, 5, 56, 8, 86, 2, 85, 1, 81, 4, 97, 0, 37, 
    0, 72, 2, 30, 6,  1, 1, 46, 5, 63, 8, 77, 7, 55, 4, 44, 3, 73, 
    7, 90, 0, 51, 3, 71, 1,  5, 4, 80, 8, 51, 6,  2, 2, 65, 5,  5
  };
  const int q3696[] = {
    9, 9, // Number of jobs and machines
    2, 87, 4, 97, 1, 16, 8, 53, 3, 36, 7, 98, 0, 92, 6, 86, 5, 95, 
    3, 56, 8, 68, 6,  5, 4, 15, 1, 25, 0, 55, 2, 34, 5, 34, 7,  5, 
    1, 13, 8, 67, 2, 18, 7, 52, 3, 40, 6, 43, 5,  1, 4, 85, 0, 79, 
    2, 58, 8, 46, 5, 70, 6, 61, 0, 48, 7, 32, 4,  5, 3, 37, 1, 86, 
    3, 83, 0, 35, 5, 98, 7, 22, 1, 32, 6, 34, 8, 37, 2, 83, 4, 76, 
    5, 67, 0, 42, 7, 85, 2, 98, 1, 56, 8, 78, 3, 30, 6, 39, 4, 46, 
    0, 95, 1, 20, 3, 94, 5, 65, 7, 65, 4, 65, 2, 57, 8, 63, 6, 55, 
    4, 36, 6, 58, 0, 31, 7, 54, 3, 91, 5, 80, 1, 44, 8, 13, 2,  6, 
    1, 95, 3, 80, 8, 77, 0, 74, 5, 52, 7, 65, 2, 98, 6, 13, 4, 86
  };
  const int q3697[] = {
    9, 9, // Number of jobs and machines
    2, 88, 0, 12, 6, 97, 1, 84, 4, 52, 5, 37, 8, 71, 7, 65, 3, 26, 
    7, 64, 6,  9, 5, 98, 4, 97, 8,  9, 2, 42, 1, 12, 3, 71, 0, 52, 
    0, 14, 4, 31, 3, 97, 6, 37, 1, 29, 7, 59, 8, 76, 2, 88, 5, 66, 
    3, 51, 6, 96, 2, 86, 0, 91, 8, 56, 7, 66, 1, 68, 4, 45, 5, 12, 
    8,  9, 1, 36, 3, 60, 5,  8, 6, 19, 2, 73, 4, 69, 7, 41, 0, 46, 
    1, 18, 7, 90, 4, 79, 6, 34, 0, 72, 2, 61, 5, 39, 8, 65, 3,  4, 
    6, 72, 1, 85, 7, 89, 4, 58, 3, 63, 0, 53, 2, 43, 5, 14, 8, 46, 
    7, 70, 0, 98, 5, 52, 1, 92, 3, 81, 6, 77, 2, 31, 8, 12, 4, 66, 
    5, 62, 7, 35, 2, 85, 3, 29, 4, 77, 1, 55, 6, 11, 0, 98, 8, 74
  };
  const int q3698[] = {
    9, 9, // Number of jobs and machines
    0, 74, 1, 46, 8, 71, 7, 80, 6, 69, 2, 88, 4, 44, 5, 56, 3,  5, 
    1, 61, 0, 66, 4, 69, 7, 71, 6, 13, 5, 99, 2, 81, 8,  3, 3,  7, 
    2, 64, 3, 75, 6, 93, 8,  3, 1, 69, 4, 74, 7, 70, 0, 80, 5, 49, 
    5, 45, 0, 73, 6, 44, 8, 50, 1, 79, 4, 61, 2, 79, 3, 52, 7, 99, 
    0, 93, 2, 20, 3, 96, 5, 53, 8, 82, 6, 57, 7, 31, 1, 56, 4,  5, 
    5, 42, 4, 43, 8,  9, 6, 37, 7, 30, 1, 57, 0, 18, 2, 48, 3,  2, 
    4, 46, 7, 67, 2, 26, 1,  3, 8,  9, 0, 84, 3, 11, 5, 55, 6,  2, 
    8, 29, 2, 24, 7, 66, 1, 87, 3, 16, 4, 13, 5, 50, 6,  7, 0, 84, 
    6, 47, 4, 56, 3, 26, 0, 88, 8, 83, 1, 93, 5, 21, 2, 58, 7, 79
  };
  const int q3699[] = {
    9, 9, // Number of jobs and machines
    4, 71, 8, 18, 3,  2, 6,  4, 5, 82, 0, 54, 1, 46, 7, 42, 2, 85, 
    7, 84, 2, 58, 3, 11, 5, 95, 8, 46, 0, 93, 1,  9, 6,  3, 4, 84, 
    3, 10, 1, 64, 4, 72, 0, 22, 2, 71, 6, 55, 5, 44, 7, 45, 8, 18, 
    5, 30, 8,  7, 0, 30, 7, 92, 4, 54, 3, 91, 2,  3, 6, 38, 1, 45, 
    1, 55, 4, 53, 8, 64, 3, 95, 6,  4, 7, 47, 2, 49, 0, 60, 5, 13, 
    4, 67, 0,  4, 8, 11, 1, 97, 7, 15, 2, 16, 6, 61, 5, 69, 3, 73, 
    6, 95, 3, 29, 1, 43, 2, 69, 8, 77, 4, 28, 7, 78, 0,  2, 5, 99, 
    3, 83, 0, 94, 4, 78, 8, 35, 1, 45, 5, 18, 2, 60, 6, 24, 7, 76, 
    5,  2, 1, 35, 6, 35, 8, 47, 3, 55, 0, 58, 4, 48, 7, 50, 2,  1
  };
  const int q3700[] = {
    9, 9, // Number of jobs and machines
    8, 38, 7, 27, 1, 62, 3, 11, 6, 33, 4, 82, 2,  4, 0, 49, 5,  2, 
    2, 73, 6, 78, 4, 46, 1, 36, 5, 56, 7,  1, 8, 17, 3, 65, 0, 21, 
    7, 27, 1, 15, 6, 85, 4, 50, 3, 13, 5,  7, 2, 37, 0, 87, 8, 67, 
    8, 61, 2, 42, 7, 13, 3,  7, 0, 70, 5, 95, 4, 82, 6, 62, 1, 62, 
    1, 86, 5, 73, 7, 91, 0, 61, 6, 49, 2,  9, 4, 70, 3, 97, 8, 17, 
    3, 94, 0, 78, 7,  9, 8, 63, 1, 63, 2, 29, 6, 21, 4, 78, 5, 95, 
    0, 36, 7, 31, 3, 61, 5, 32, 8, 80, 4, 78, 1, 22, 6, 68, 2, 25, 
    5, 93, 1, 55, 7, 48, 4, 98, 2, 48, 3, 85, 6, 29, 0, 80, 8, 93, 
    3, 94, 8, 52, 6, 91, 2, 79, 4, 61, 1, 52, 5, 21, 7, 49, 0, 31
  };
  const int q3701[] = {
    9, 9, // Number of jobs and machines
    8, 66, 6, 75, 5, 89, 2, 74, 4, 83, 7, 11, 1, 44, 0, 59, 3, 21, 
    6, 89, 4, 75, 3, 74, 1, 19, 0, 20, 5, 18, 7, 16, 2, 53, 8, 31, 
    1, 93, 7, 62, 2, 12, 6, 95, 8, 30, 5, 88, 0, 94, 4, 94, 3, 85, 
    7, 36, 0,  5, 1,  8, 4, 50, 2, 93, 6, 56, 3,  1, 8, 55, 5,  7, 
    6, 15, 7, 37, 1, 94, 4, 23, 8,  4, 3, 35, 5, 55, 2, 40, 0, 82, 
    3, 46, 0, 21, 2, 81, 4, 46, 6, 46, 7, 86, 8, 21, 5, 15, 1, 74, 
    2, 26, 6, 74, 8, 60, 4, 11, 1, 62, 3, 28, 5, 86, 0, 34, 7, 17, 
    7, 17, 5, 23, 6, 60, 8, 24, 0, 30, 1, 69, 3, 12, 2, 65, 4, 42, 
    1, 88, 5, 69, 6, 34, 8, 49, 2, 19, 7, 52, 3, 96, 4, 59, 0, 22
  };
  const int q3702[] = {
    9, 9, // Number of jobs and machines
    3, 28, 1, 23, 4, 92, 7, 40, 6, 90, 5,  1, 2, 12, 8, 52, 0, 52, 
    5, 54, 1, 25, 2, 51, 8, 45, 4, 56, 0, 98, 6, 59, 7, 24, 3, 25, 
    0,  7, 8, 84, 1, 13, 6,  5, 2, 16, 4, 11, 7,  2, 5, 94, 3, 44, 
    5, 64, 8, 13, 4, 93, 2,  1, 7, 11, 3, 21, 0, 15, 6, 78, 1, 84, 
    3, 35, 8, 73, 5, 68, 7, 32, 4, 61, 1, 39, 0, 89, 6, 78, 2, 59, 
    2, 19, 5, 16, 4, 51, 0, 12, 6, 90, 1, 52, 8, 55, 3, 79, 7, 84, 
    1, 46, 0, 71, 5, 41, 3, 89, 4, 59, 7, 80, 2, 50, 8, 67, 6, 56, 
    7,  7, 1, 36, 2, 69, 3, 59, 4, 99, 5, 10, 8, 97, 0, 15, 6, 48, 
    6, 65, 3, 61, 4, 99, 1, 95, 5, 13, 7, 90, 0, 27, 2, 94, 8, 25
  };
  const int q3703[] = {
    9, 9, // Number of jobs and machines
    0, 87, 6, 13, 4, 85, 8, 70, 2, 82, 3, 38, 7, 21, 5, 19, 1, 37, 
    6, 34, 4, 14, 2,  5, 1, 72, 7, 42, 8, 44, 0, 25, 5, 19, 3, 32, 
    3, 64, 5, 82, 4, 95, 6, 88, 2, 28, 7, 48, 0, 63, 1, 16, 8, 87, 
    7, 56, 0, 85, 6, 99, 1, 68, 3, 46, 4, 71, 5, 13, 8, 25, 2, 62, 
    4, 15, 8, 57, 2, 61, 5, 82, 1, 25, 3, 79, 6, 23, 0, 36, 7, 99, 
    5, 48, 2, 51, 3, 19, 4, 94, 8, 28, 7, 77, 0, 44, 1,  8, 6, 24, 
    1,  4, 7, 91, 5,  2, 8, 93, 6, 50, 3, 13, 4, 61, 0, 95, 2, 84, 
    8, 60, 6, 51, 0, 88, 1, 71, 5, 13, 3,  7, 4, 62, 2, 69, 7, 65, 
    8, 96, 6, 82, 1, 98, 7, 35, 4, 29, 2, 44, 5, 30, 3, 69, 0, 30
  };
  const int q3704[] = {
    9, 9, // Number of jobs and machines
    3, 87, 0, 12, 2, 90, 4, 56, 6, 41, 8, 98, 1, 75, 7, 38, 5, 96, 
    4,  9, 3, 48, 6, 20, 7, 69, 8, 59, 2, 63, 5,  2, 0, 94, 1, 31, 
    2, 60, 6, 22, 5, 61, 1, 58, 3, 50, 7, 46, 4, 16, 8, 46, 0, 80, 
    0, 16, 3, 80, 5, 57, 8, 76, 4, 28, 2, 69, 6, 19, 1, 19, 7, 49, 
    5, 25, 4, 24, 2, 90, 1, 85, 8, 87, 3, 48, 6, 95, 0, 23, 7, 34, 
    3, 10, 1, 98, 7, 35, 0, 62, 4, 57, 6, 82, 8, 87, 5, 41, 2, 70, 
    0, 98, 5,  8, 3, 85, 8, 63, 4, 91, 1, 92, 6, 52, 7, 47, 2, 61, 
    8, 47, 3, 60, 2, 65, 4, 37, 6, 74, 1, 34, 5, 44, 0, 69, 7, 25, 
    5, 41, 3, 39, 4, 23, 7, 90, 2, 42, 8, 77, 6,  2, 1,  1, 0,  2
  };
  const int q3705[] = {
    9, 9, // Number of jobs and machines
    8, 73, 1, 78, 3,  7, 7, 17, 6,  2, 0, 16, 5,  8, 2, 52, 4, 89, 
    6, 82, 4, 93, 8, 85, 1, 53, 5, 32, 0, 68, 7, 46, 2, 74, 3, 64, 
    4, 69, 7, 48, 2, 35, 6, 30, 0, 94, 8, 17, 5, 29, 1, 59, 3, 11, 
    0, 86, 4,  7, 7, 43, 3, 59, 8, 36, 5, 75, 2, 63, 1, 14, 6, 47, 
    2, 52, 3, 59, 5, 95, 7, 54, 6, 71, 1, 25, 0, 25, 8, 70, 4, 49, 
    2, 91, 5, 96, 7, 45, 4, 10, 8, 25, 3, 20, 6, 80, 1, 52, 0, 57, 
    1, 31, 4, 41, 0, 13, 7, 60, 2, 61, 8, 82, 6, 10, 3,  4, 5, 74, 
    3, 66, 4, 77, 7, 33, 2, 39, 6, 23, 8, 74, 5, 93, 0, 51, 1, 22, 
    0, 92, 5, 38, 7, 25, 1, 47, 6,  2, 3, 17, 4, 85, 2, 69, 8, 74
  };
  const int q3706[] = {
    9, 9, // Number of jobs and machines
    0,  5, 6, 88, 3, 21, 1,  1, 2, 94, 8, 56, 4, 67, 7, 91, 5, 55, 
    8, 38, 5, 29, 1,  6, 7, 29, 2, 10, 4, 12, 3, 53, 6, 54, 0, 40, 
    1, 68, 8, 19, 6, 25, 4, 24, 0, 74, 3, 90, 5, 59, 2, 79, 7, 17, 
    7, 52, 2, 36, 1, 85, 6, 92, 0, 22, 8, 60, 5, 98, 3, 82, 4,  4, 
    6, 30, 2, 76, 8, 68, 4, 53, 5, 54, 0, 57, 1, 59, 7, 32, 3,  3, 
    6, 16, 7, 77, 4, 22, 1, 52, 2, 98, 8, 36, 3, 78, 0, 13, 5, 33, 
    3, 49, 4, 57, 6, 68, 8, 61, 7, 70, 0, 24, 1, 21, 2, 55, 5, 50, 
    4, 60, 1, 83, 0, 63, 8,  5, 5, 58, 3, 98, 2, 12, 7, 52, 6, 54, 
    4, 19, 5, 81, 3, 41, 0, 22, 8, 66, 6, 85, 7,  5, 1, 47, 2, 94
  };
  const int q3707[] = {
    9, 9, // Number of jobs and machines
    3, 33, 6, 92, 7, 74, 0, 25, 8, 67, 5, 29, 4, 53, 1, 72, 2, 23, 
    1, 76, 8, 66, 3, 61, 5, 81, 7, 75, 0, 68, 2, 38, 4, 46, 6, 90, 
    5,  2, 7, 74, 6, 17, 3, 75, 2, 73, 8,  8, 1, 62, 0, 79, 4, 79, 
    6,  2, 3, 63, 8, 82, 0, 26, 7, 59, 2, 76, 1, 23, 5, 92, 4,  3, 
    3,  6, 7, 85, 2, 43, 4, 70, 8, 97, 6, 26, 1,  3, 5, 90, 0, 13, 
    2, 60, 8, 74, 0, 40, 5, 95, 6, 56, 4, 97, 1, 58, 7, 48, 3, 14, 
    7, 57, 2, 20, 4,  4, 6, 43, 5, 32, 3, 39, 8, 23, 0, 24, 1, 49, 
    7, 36, 5, 73, 3, 76, 0, 27, 2, 30, 8,  2, 4, 65, 1, 20, 6, 89, 
    4, 78, 2,  3, 6, 10, 7, 38, 8, 75, 3, 22, 1, 50, 5, 47, 0, 69
  };
  const int q3708[] = {
    9, 9, // Number of jobs and machines
    6, 89, 4, 29, 5, 74, 8, 54, 7, 73, 0, 29, 1, 98, 3, 85, 2, 47, 
    0, 64, 6, 90, 1, 28, 4, 84, 3, 39, 8, 22, 5, 95, 7, 13, 2,  6, 
    6, 94, 4, 86, 3, 37, 2, 35, 1, 87, 5,  8, 0, 85, 7, 82, 8, 51, 
    5, 27, 0, 47, 6, 84, 3, 77, 8, 91, 1, 54, 2, 54, 7, 57, 4, 28, 
    8, 49, 7, 52, 0, 65, 6, 51, 3, 93, 2, 56, 4, 66, 5, 89, 1, 12, 
    0, 29, 2,  3, 7, 49, 3, 18, 4, 86, 1, 95, 8, 27, 5, 63, 6, 64, 
    3, 74, 7, 43, 8, 44, 6, 98, 1, 35, 0, 90, 2, 40, 5, 33, 4, 49, 
    0, 17, 5, 20, 4, 61, 8, 66, 6, 17, 2, 32, 1, 23, 3, 40, 7,  5, 
    7, 43, 5, 89, 2,  3, 4, 89, 3, 28, 8,  2, 1, 40, 6, 56, 0,  7
  };
  const int q3709[] = {
    9, 9, // Number of jobs and machines
    3, 80, 1, 98, 4, 76, 2, 69, 7, 71, 6, 45, 8, 71, 5, 87, 0, 95, 
    5, 41, 2, 54, 1, 73, 7, 91, 0,  5, 6, 63, 8, 20, 3, 33, 4, 96, 
    7, 49, 8, 45, 1, 99, 4, 55, 3,  1, 6, 35, 2, 74, 5, 95, 0, 43, 
    5, 57, 3, 60, 7,  6, 1, 70, 8, 49, 2, 19, 0, 47, 6, 34, 4, 22, 
    1, 66, 8, 81, 7, 43, 4, 11, 0, 14, 2, 66, 3, 35, 6, 51, 5, 83, 
    3, 61, 6, 72, 0, 47, 4, 42, 1, 79, 5, 46, 8, 73, 2, 30, 7, 22, 
    2, 98, 0,  5, 3, 13, 6, 15, 7, 83, 5, 81, 8, 91, 4, 66, 1, 39, 
    3, 28, 8, 62, 6, 74, 7, 64, 4, 62, 5, 97, 2, 29, 0, 72, 1, 40, 
    2, 59, 3, 76, 8, 13, 5, 64, 0, 50, 4, 30, 6,  4, 7, 90, 1,  7
  };
  const int q3710[] = {
    9, 9, // Number of jobs and machines
    8, 24, 3, 29, 2, 74, 0, 73, 7, 50, 1, 61, 5, 63, 6, 73, 4, 37, 
    2, 30, 4, 77, 3, 33, 1, 50, 8, 47, 7, 39, 0, 72, 5, 20, 6, 17, 
    5, 75, 7, 92, 4, 43, 6, 89, 0, 14, 8, 31, 3, 60, 1, 88, 2, 73, 
    0, 71, 4, 52, 3, 80, 7,  9, 2, 31, 5,  7, 6, 74, 8,  2, 1, 44, 
    2, 88, 4, 33, 6, 69, 7, 49, 5,  6, 1, 24, 3, 26, 8, 31, 0, 25, 
    4, 83, 2, 95, 6, 69, 0,  6, 3, 72, 1,  9, 7, 29, 8, 52, 5, 67, 
    4, 22, 1, 55, 8, 81, 2, 49, 6, 66, 3, 12, 0, 73, 5, 61, 7, 88, 
    6, 75, 0, 50, 1,  4, 4, 84, 8, 73, 5, 51, 7, 76, 3, 28, 2, 13, 
    5, 22, 1,  6, 8, 37, 7, 63, 2,  2, 0, 56, 4, 26, 3, 81, 6, 37
  };
  const int q3711[] = {
    9, 9, // Number of jobs and machines
    2, 35, 1, 17, 7, 21, 0, 66, 6, 66, 4,  1, 5,  1, 8, 87, 3, 44, 
    4, 45, 6, 29, 7, 14, 0, 95, 3, 19, 5, 55, 2, 12, 8, 82, 1, 99, 
    7, 26, 0, 27, 3, 52, 1, 58, 2, 65, 8, 59, 6,  7, 4, 69, 5, 83, 
    0, 92, 5, 94, 8, 34, 2, 24, 3, 74, 4, 96, 6, 58, 1, 45, 7, 71, 
    3,  4, 0, 41, 5, 91, 6, 51, 4, 95, 1,  1, 2, 94, 8, 74, 7, 35, 
    5, 52, 3, 64, 6, 96, 1, 10, 0, 59, 2, 65, 4,  6, 7,  1, 8, 90, 
    7, 45, 0,  7, 6, 57, 8, 34, 2, 71, 5, 97, 4, 27, 3, 76, 1, 87, 
    6, 61, 3, 47, 2, 21, 8, 90, 4, 68, 5, 41, 1, 26, 7, 30, 0, 64, 
    0, 57, 4, 22, 5, 32, 7, 97, 3, 95, 2, 30, 6, 19, 8, 22, 1, 35
  };
  const int q3712[] = {
    9, 9, // Number of jobs and machines
    0, 21, 3, 39, 6, 57, 7, 82, 1, 94, 8, 51, 4, 73, 5, 49, 2, 46, 
    0,  2, 7, 87, 2, 37, 6, 44, 5, 58, 4, 25, 3, 69, 1, 33, 8, 57, 
    0,  1, 3, 49, 7, 55, 4, 45, 2,  6, 6, 64, 8, 47, 5, 17, 1,  1, 
    8, 15, 5, 58, 0, 14, 3, 90, 6, 17, 7, 17, 2,  1, 4, 80, 1, 49, 
    7, 52, 8, 50, 5, 47, 0, 62, 6, 54, 4, 89, 3, 19, 1, 65, 2, 52, 
    1, 69, 5,  1, 2, 78, 6, 21, 7, 33, 3,  3, 4, 20, 8, 67, 0, 43, 
    4, 26, 1, 15, 7,  2, 5, 11, 2, 89, 6, 15, 0, 29, 3, 21, 8,  9, 
    8, 25, 7, 24, 6, 65, 0,  2, 3, 60, 5, 13, 4, 32, 2, 85, 1, 85, 
    3, 48, 0, 88, 1, 17, 2, 43, 8, 17, 5, 14, 4, 26, 6, 85, 7, 55
  };
  const int q3713[] = {
    9, 9, // Number of jobs and machines
    0, 90, 4, 17, 7, 75, 2, 64, 3, 11, 8, 30, 6, 41, 1, 47, 5, 13, 
    3, 94, 4, 52, 5, 34, 6, 21, 7, 70, 2,  2, 8, 40, 0, 91, 1, 59, 
    5, 11, 6, 12, 2,  7, 8, 83, 4, 68, 3, 66, 1, 87, 7, 31, 0, 87, 
    3, 26, 7, 93, 6, 95, 2, 56, 4, 91, 0, 93, 5, 77, 8, 31, 1, 26, 
    8, 26, 3, 63, 4, 44, 2,  2, 5, 91, 1, 14, 7, 98, 6, 48, 0, 89, 
    6, 23, 3, 24, 8, 61, 7, 87, 2, 56, 1, 86, 5, 72, 4, 13, 0, 44, 
    8,  4, 2, 81, 6, 96, 1, 24, 5,  7, 7, 68, 3, 22, 0, 33, 4, 61, 
    7,  3, 4,  5, 1, 37, 2,  4, 5, 94, 8, 34, 6, 36, 3, 89, 0, 96, 
    1, 28, 7, 50, 8, 83, 4, 58, 0, 41, 3, 87, 5, 35, 6, 13, 2, 26
  };
  const int q3714[] = {
    9, 9, // Number of jobs and machines
    2, 77, 7, 31, 3, 28, 1, 65, 0, 76, 6, 17, 8, 30, 5, 18, 4, 92, 
    0, 59, 4,  8, 2, 95, 5, 94, 6, 87, 8, 82, 7, 74, 3, 80, 1, 81, 
    8, 81, 3, 71, 2,  1, 1, 38, 0, 15, 5, 47, 6, 54, 4, 17, 7, 48, 
    6, 49, 4, 95, 3, 34, 1, 51, 8, 18, 5,  5, 2, 42, 0, 73, 7,  5, 
    3, 85, 5, 41, 6, 61, 1, 64, 2, 28, 0, 63, 4, 79, 7, 40, 8,  7, 
    1, 25, 6, 49, 7, 23, 2, 95, 5, 78, 0, 63, 8, 63, 3, 58, 4, 72, 
    4, 78, 8, 76, 6, 64, 7, 29, 1, 14, 2, 44, 3, 11, 5, 39, 0, 46, 
    0, 27, 4, 46, 8, 53, 5, 10, 2, 60, 1, 92, 7, 54, 3, 59, 6, 38, 
    5, 58, 6, 85, 2, 30, 1, 81, 0,  3, 3, 68, 7, 31, 8, 34, 4, 12
  };
  const int q3715[] = {
    9, 9, // Number of jobs and machines
    4,  1, 5, 48, 1, 63, 2, 68, 8,  5, 3, 87, 7, 42, 0, 28, 6, 94, 
    4, 57, 5,  4, 7, 47, 1, 74, 0, 64, 8, 40, 2, 23, 6, 60, 3, 56, 
    2, 79, 8, 97, 3, 58, 5, 76, 0,  5, 7, 74, 4, 98, 6, 27, 1, 96, 
    4, 71, 6, 87, 1, 86, 2, 64, 0, 29, 8, 67, 3, 47, 5, 19, 7, 80, 
    3, 17, 1, 26, 0, 84, 2, 53, 6, 89, 5, 55, 4, 83, 7, 33, 8, 48, 
    7, 19, 4, 60, 0, 25, 6, 14, 5,  3, 2, 46, 3, 89, 1, 23, 8, 68, 
    6, 41, 0, 56, 3, 53, 2, 67, 5, 99, 4, 67, 7, 29, 1, 85, 8, 26, 
    5, 13, 7, 41, 1, 74, 3, 18, 2, 55, 4, 96, 0, 69, 6, 13, 8, 51, 
    6, 59, 3, 35, 5,  5, 4,  9, 2, 72, 7, 68, 1, 22, 8, 60, 0, 39
  };
  const int q3716[] = {
    9, 9, // Number of jobs and machines
    8, 30, 4,  9, 0, 10, 7, 60, 5, 54, 6, 85, 2, 23, 3, 35, 1, 42, 
    7, 24, 1, 58, 2, 34, 0, 23, 3, 57, 8, 36, 5, 66, 6, 28, 4, 82, 
    5, 80, 8, 32, 1, 43, 2, 52, 7, 58, 6, 12, 0, 63, 3, 41, 4, 80, 
    2, 85, 3, 35, 0, 94, 7, 42, 1,  1, 6, 93, 8, 39, 5, 90, 4, 25, 
    1, 99, 8, 54, 7, 59, 4, 91, 2, 73, 0, 76, 3, 76, 5, 34, 6,  6, 
    2, 81, 5, 11, 3, 72, 8, 10, 0, 52, 6, 67, 7, 33, 4, 26, 1, 74, 
    8, 68, 6, 33, 5, 35, 7, 17, 1, 81, 4, 83, 3, 23, 2, 39, 0, 16, 
    0, 78, 3, 93, 6, 81, 4, 86, 1, 39, 7, 19, 8, 72, 2,  6, 5,  9, 
    2, 28, 4, 83, 8, 85, 5,  8, 3, 10, 0, 47, 6, 74, 1, 30, 7, 70
  };
  const int q3717[] = {
    9, 9, // Number of jobs and machines
    3, 31, 0, 48, 8, 11, 6, 47, 5, 62, 7, 10, 1, 95, 4, 38, 2, 76, 
    0, 29, 1, 56, 5, 73, 4, 20, 7, 66, 8, 98, 2,  1, 6, 37, 3, 83, 
    4, 32, 6, 17, 7, 85, 2,  3, 5, 76, 8, 81, 3, 28, 0, 38, 1, 85, 
    4, 39, 6, 10, 0,  2, 7, 81, 1, 12, 5, 13, 2, 37, 3, 93, 8, 46, 
    0, 91, 8, 31, 1, 98, 4, 54, 3, 61, 7, 11, 6, 57, 2, 78, 5, 81, 
    6, 34, 0,  5, 3, 59, 7, 22, 1, 71, 8, 48, 5, 53, 4, 59, 2, 47, 
    2, 74, 1, 54, 8, 69, 3, 27, 5, 22, 4, 87, 0,  9, 6,  2, 7, 25, 
    4, 87, 1, 32, 7, 40, 5, 96, 8, 50, 0, 33, 6, 11, 2, 92, 3, 78, 
    8,  7, 6, 33, 3, 78, 4, 10, 7, 10, 2, 75, 1, 23, 5, 19, 0, 45
  };
  const int q3718[] = {
    9, 9, // Number of jobs and machines
    7, 44, 5, 53, 2, 46, 3, 38, 1, 94, 8, 70, 6, 47, 0, 12, 4, 62, 
    2, 94, 4, 71, 3, 15, 5, 87, 8, 24, 1, 11, 7, 69, 6, 87, 0, 41, 
    8, 57, 7, 88, 0, 51, 2, 26, 6, 24, 4, 99, 3,  6, 5, 89, 1, 51, 
    1, 15, 2, 44, 7, 67, 5, 55, 3, 38, 0, 73, 8, 42, 4, 82, 6, 44, 
    6, 97, 2,  3, 8, 35, 4, 90, 7, 11, 5, 27, 3, 91, 0, 43, 1, 14, 
    1, 56, 5, 15, 0, 93, 4, 13, 2, 40, 7, 35, 3, 15, 8, 65, 6, 26, 
    7, 96, 2, 95, 0, 10, 6, 38, 4,  5, 8, 99, 3, 37, 5, 17, 1,  9, 
    7, 35, 4, 27, 3, 45, 2, 50, 5, 67, 8, 43, 6, 23, 1, 47, 0, 20, 
    4, 57, 6, 11, 2, 61, 0, 90, 3, 52, 5, 36, 8, 91, 1, 68, 7, 97
  };
  const int q3719[] = {
    9, 9, // Number of jobs and machines
    5, 76, 1, 42, 7, 89, 6, 62, 4, 87, 8, 22, 2, 74, 0, 83, 3, 62, 
    8, 66, 5, 91, 3, 25, 7, 53, 1, 69, 6, 77, 4, 33, 0, 43, 2,  6, 
    7, 50, 2, 66, 0, 42, 6, 29, 3, 77, 8, 92, 4, 58, 1,  3, 5, 90, 
    7, 92, 0, 60, 1, 44, 3, 24, 5,  5, 2, 84, 6, 97, 4, 22, 8, 50, 
    5, 83, 1, 89, 7, 94, 4, 39, 0, 71, 8, 23, 6, 23, 2,  8, 3, 36, 
    5, 40, 8, 71, 7, 58, 4,  3, 3,  1, 0, 43, 1, 45, 2, 70, 6, 71, 
    6, 57, 0, 82, 4, 35, 8,  5, 7, 58, 2, 35, 1, 70, 3, 74, 5, 36, 
    5,  4, 2, 84, 0, 89, 8, 81, 3, 43, 1, 31, 6, 40, 7, 66, 4, 17, 
    0, 76, 4, 25, 5, 71, 3, 21, 8, 13, 7, 35, 6, 63, 1, 88, 2, 22
  };
  const int q3720[] = {
    9, 9, // Number of jobs and machines
    1, 22, 7, 59, 8, 69, 6, 15, 4, 39, 0, 73, 2, 79, 5,  3, 3,  2, 
    8, 65, 2, 79, 5, 82, 6, 76, 3, 53, 1, 47, 7, 91, 4, 61, 0, 34, 
    8, 56, 6,  8, 5, 97, 7, 73, 0, 17, 1, 63, 2, 84, 3, 73, 4, 67, 
    4, 78, 8,  9, 0, 31, 2, 17, 5, 56, 7, 10, 1, 15, 3, 91, 6, 72, 
    0, 27, 8, 89, 5, 55, 1, 88, 6, 85, 2, 34, 7, 11, 3, 89, 4, 40, 
    4,  3, 6, 28, 7, 58, 5, 36, 3,  2, 8, 35, 2,  2, 0, 31, 1, 32, 
    4, 14, 5, 51, 1,  8, 6, 95, 3, 35, 8, 32, 7, 56, 2, 33, 0, 25, 
    4, 38, 2, 56, 0, 82, 7, 41, 1, 89, 6, 72, 5, 87, 8, 85, 3,  8, 
    8, 77, 0, 78, 3, 17, 5, 49, 2, 10, 6, 46, 1, 84, 4,  2, 7, 32
  };
  const int q3721[] = {
    9, 9, // Number of jobs and machines
    8, 59, 3, 43, 1, 83, 0, 27, 5, 24, 7, 20, 4, 80, 2, 87, 6, 29, 
    3, 76, 8, 70, 2,  7, 0, 99, 5, 74, 7, 39, 6, 65, 4, 99, 1, 79, 
    5, 38, 1, 93, 0, 64, 4, 86, 3, 73, 8, 87, 2, 97, 7, 23, 6, 97, 
    4, 53, 2, 21, 3, 46, 1, 19, 0, 88, 7,  3, 8, 24, 5, 91, 6, 21, 
    8, 79, 0, 98, 5, 44, 7, 36, 4, 80, 1, 72, 2, 28, 6, 50, 3, 47, 
    4, 94, 6, 98, 5, 29, 1,  5, 3, 14, 2, 77, 0, 27, 8, 23, 7, 35, 
    3, 97, 7, 72, 1, 84, 4, 22, 2,  8, 6, 99, 0, 86, 5, 35, 8,  1, 
    8, 48, 6, 35, 3, 77, 2,  3, 4,  6, 5, 30, 0, 66, 7, 35, 1, 36, 
    0, 17, 1, 15, 5, 97, 3, 69, 4, 42, 8, 69, 2, 15, 6, 22, 7, 35
  };
  const int q3722[] = {
    9, 9, // Number of jobs and machines
    8, 97, 0, 44, 6, 67, 5, 25, 2, 33, 4, 23, 7, 20, 1, 70, 3, 98, 
    4, 29, 1, 71, 8, 59, 3,  2, 5,  6, 6, 73, 0, 20, 2, 14, 7, 81, 
    0, 60, 8, 12, 6, 54, 4, 22, 1, 98, 2, 58, 7, 35, 5, 95, 3, 33, 
    1, 90, 6, 49, 8, 76, 0, 13, 2, 83, 5, 51, 3, 48, 4, 20, 7, 23, 
    1, 30, 7, 39, 3, 89, 8, 38, 2, 95, 5, 64, 4, 73, 0, 72, 6, 45, 
    0, 76, 5, 21, 4, 25, 7, 44, 3, 52, 6, 27, 2, 81, 1, 51, 8, 76, 
    6, 44, 4, 37, 3, 59, 0, 85, 5, 87, 7,  2, 8, 95, 2, 53, 1, 84, 
    2, 23, 4, 64, 6, 66, 8, 11, 1, 71, 0, 51, 7, 90, 3, 91, 5, 29, 
    7, 94, 8, 60, 4, 14, 1, 28, 5, 40, 3, 93, 2, 87, 6, 37, 0, 45
  };
  const int q3723[] = {
    9, 9, // Number of jobs and machines
    6, 16, 1, 67, 5, 43, 2, 81, 3, 62, 8, 89, 0, 83, 7, 49, 4, 52, 
    4, 90, 5, 55, 8, 92, 1,  8, 6, 11, 7, 57, 3, 69, 2, 97, 0,  4, 
    6, 68, 7, 79, 5, 43, 4, 62, 0, 17, 2, 37, 8, 21, 3, 32, 1, 46, 
    1, 11, 0, 41, 8, 34, 7, 85, 6, 61, 3, 35, 2, 88, 4, 48, 5, 18, 
    7, 85, 4, 14, 0, 39, 8, 98, 5, 27, 6, 22, 2, 67, 3, 16, 1, 17, 
    7, 91, 0, 37, 6, 53, 3,  4, 5, 73, 4, 42, 1, 13, 8,  5, 2, 57, 
    8, 75, 3,  6, 1, 40, 5, 20, 2,  6, 0,  7, 4, 11, 7, 88, 6, 11, 
    3, 58, 0, 30, 4, 90, 7, 11, 5, 93, 1, 56, 8, 66, 2, 92, 6, 74, 
    6, 77, 4, 98, 8,  5, 2, 23, 7,  6, 1, 33, 5, 86, 3, 30, 0, 78
  };
  const int q3724[] = {
    9, 9, // Number of jobs and machines
    1, 85, 5, 87, 0, 19, 7, 31, 3, 62, 2, 98, 4, 26, 6, 91, 8, 18, 
    7, 96, 3, 14, 4, 17, 2, 79, 6, 80, 1,  2, 5, 45, 8, 97, 0, 54, 
    1, 68, 8,  7, 7, 95, 0,  4, 4, 88, 3, 77, 5, 91, 2, 99, 6, 73, 
    3, 33, 2, 91, 4, 90, 6, 83, 8, 21, 7, 65, 1, 25, 5, 46, 0, 13, 
    1, 39, 6, 10, 4, 47, 0, 10, 8, 19, 5, 25, 3, 93, 7,  5, 2, 42, 
    7, 75, 1, 94, 6, 92, 4, 47, 0, 87, 5, 64, 3, 53, 8, 97, 2, 85, 
    7,  7, 8, 50, 5, 30, 0, 22, 3, 90, 2, 11, 4, 61, 1, 62, 6, 66, 
    4, 63, 5,  4, 0, 85, 3,  6, 6, 22, 8, 40, 7, 52, 2, 30, 1, 20, 
    5, 19, 0,  4, 7, 50, 6, 59, 3, 85, 2, 80, 8, 83, 4, 53, 1, 30
  };
  const int q3725[] = {
    9, 9, // Number of jobs and machines
    7, 67, 3, 15, 4, 35, 5, 81, 1, 55, 8, 41, 0, 80, 2, 53, 6,  4, 
    5, 16, 3, 74, 8, 81, 4, 54, 1,  8, 2, 66, 0, 41, 6,  1, 7, 63, 
    5, 68, 2, 29, 4, 86, 0,  6, 3, 36, 7, 38, 6, 84, 1, 41, 8, 30, 
    6, 67, 2, 73, 1, 68, 8, 43, 0, 91, 7,  5, 3, 54, 4, 11, 5, 76, 
    8, 66, 1, 46, 0, 83, 3, 32, 4, 94, 6, 25, 7, 79, 5, 57, 2, 25, 
    8, 73, 7, 78, 6, 43, 3, 19, 5, 42, 1, 80, 0,  9, 4, 31, 2, 47, 
    2, 12, 7, 79, 6, 92, 4, 19, 0, 74, 8,  2, 3, 20, 5, 24, 1,  9, 
    2, 43, 1, 65, 0, 30, 3,  7, 8, 87, 7, 42, 4, 18, 5, 14, 6,  9, 
    3, 19, 0, 93, 5, 32, 6, 81, 2, 12, 8, 91, 4, 36, 7, 99, 1,  2
  };
  const int q3726[] = {
    9, 9, // Number of jobs and machines
    3, 18, 5,  6, 0,  5, 6, 52, 1, 21, 2, 98, 4, 29, 8, 85, 7, 70, 
    6,  3, 1,  9, 7, 12, 0, 18, 2, 58, 4, 53, 3, 41, 8, 52, 5, 27, 
    8,  6, 3, 12, 7, 59, 0, 30, 4,  3, 2, 43, 1, 41, 5, 75, 6, 47, 
    2, 57, 5, 17, 1, 45, 6, 91, 7,  8, 8, 47, 4, 33, 3, 66, 0, 12, 
    3, 10, 2, 29, 6, 58, 4, 57, 8, 82, 5, 75, 7, 21, 0, 94, 1, 11, 
    8, 18, 3, 50, 7, 21, 1, 12, 5,  3, 6, 59, 0, 78, 4, 68, 2, 57, 
    5, 70, 4, 70, 0, 16, 7, 68, 1, 40, 8, 41, 2, 90, 6, 96, 3, 68, 
    2, 24, 6, 49, 1, 40, 8,  5, 0,  3, 3, 66, 4, 28, 5, 62, 7, 89, 
    3, 59, 7, 38, 0,  8, 8, 79, 6, 11, 4, 96, 2, 69, 1, 62, 5, 71
  };
  const int q3727[] = {
    9, 9, // Number of jobs and machines
    4, 10, 1, 45, 2, 82, 6, 65, 7, 59, 0, 55, 3, 91, 8, 68, 5, 36, 
    5, 24, 3, 22, 6, 28, 2, 29, 1, 17, 7, 63, 8, 62, 4, 57, 0, 64, 
    2, 16, 4, 12, 3, 48, 5,  7, 8, 72, 6, 30, 0,  6, 7, 49, 1, 63, 
    1, 11, 2, 75, 4,  7, 3,  5, 8, 47, 0, 94, 6, 67, 7, 47, 5, 55, 
    2, 29, 5, 12, 6, 70, 8, 27, 4, 27, 3, 23, 7, 97, 1, 66, 0, 18, 
    0, 80, 2, 87, 6, 51, 8, 52, 5, 68, 1, 47, 7, 88, 3, 95, 4, 77, 
    8, 34, 4, 72, 7, 80, 6, 41, 5, 25, 2, 90, 1, 76, 3, 64, 0, 45, 
    8, 11, 1, 29, 2, 10, 4, 50, 3, 56, 5, 98, 6,  3, 0, 95, 7, 28, 
    0, 84, 6, 63, 7, 93, 5, 87, 2,  1, 3, 60, 1, 54, 4, 95, 8, 13
  };
  const int q3728[] = {
    9, 9, // Number of jobs and machines
    8,  5, 3, 49, 2, 32, 4, 74, 7, 13, 6, 86, 5,  1, 1, 68, 0, 59, 
    3, 95, 5, 33, 4,  8, 7,  3, 6, 18, 1, 20, 8, 50, 0, 23, 2, 18, 
    3, 66, 1, 48, 6, 59, 7,  8, 0, 35, 4, 93, 8, 51, 2, 56, 5, 64, 
    3, 64, 4,  8, 8, 53, 2,  2, 0, 48, 5, 92, 7, 47, 6, 70, 1, 75, 
    6, 80, 0, 97, 7, 34, 4, 85, 8, 34, 3, 28, 5, 85, 1, 96, 2, 69, 
    4, 68, 8, 59, 5, 10, 6, 84, 7, 85, 3, 40, 1, 46, 2, 78, 0, 37, 
    4, 54, 5, 24, 0, 32, 3, 57, 7, 10, 8, 67, 1,  8, 2, 86, 6, 11, 
    5, 43, 4, 96, 2, 48, 3, 44, 1, 32, 8, 17, 6,  3, 7, 44, 0, 66, 
    3, 27, 4, 11, 5, 94, 6, 17, 8, 36, 0, 21, 1, 45, 2, 84, 7, 10
  };
  const int q3729[] = {
    9, 9, // Number of jobs and machines
    1, 77, 8, 94, 4,  2, 2, 53, 5, 45, 6, 90, 7, 29, 3, 57, 0, 90, 
    1, 79, 0, 97, 7, 13, 2, 49, 8, 18, 6, 20, 5, 85, 4, 94, 3, 68, 
    4, 94, 5, 73, 3, 17, 1,  9, 7, 23, 2, 82, 6, 72, 8, 59, 0, 19, 
    5, 38, 0, 69, 8, 87, 7, 19, 4, 39, 3, 42, 6, 36, 2, 87, 1, 16, 
    3, 78, 0, 29, 7, 68, 5, 29, 6, 82, 2, 52, 4, 49, 8, 93, 1, 24, 
    2,  5, 3, 71, 4, 35, 7, 34, 8,  9, 6, 87, 1, 80, 5, 80, 0, 45, 
    0, 96, 4, 15, 3, 38, 6,  2, 5, 38, 2, 60, 8, 52, 1, 22, 7, 67, 
    7, 72, 3, 18, 5, 67, 6, 16, 1, 99, 2, 18, 4, 79, 0, 33, 8, 24, 
    8, 79, 4, 74, 5, 37, 1, 49, 6, 72, 3, 80, 0, 43, 7, 14, 2, 82
  };
  const int q3730[] = {
    9, 9, // Number of jobs and machines
    8, 99, 6, 62, 7, 51, 5, 64, 4, 81, 1, 34, 2, 72, 3, 58, 0, 55, 
    7, 38, 3, 73, 2,  4, 4, 71, 5, 29, 0, 18, 1,  3, 6, 42, 8, 30, 
    5, 49, 6, 39, 3, 10, 7, 14, 0, 49, 8, 61, 2, 97, 4, 13, 1, 78, 
    1, 91, 5, 87, 3, 40, 7, 87, 8,  5, 0, 26, 6, 60, 4, 64, 2, 42, 
    7,  6, 2, 60, 8,  2, 3,  3, 6, 17, 5, 28, 4, 31, 1, 21, 0,  3, 
    1, 27, 3, 44, 2, 11, 6, 40, 4, 95, 0, 56, 5, 59, 7, 16, 8,  5, 
    1, 79, 0, 55, 7, 62, 4, 28, 8, 26, 5, 26, 2, 71, 3, 75, 6,  4, 
    0, 43, 8, 43, 6, 48, 4, 82, 3, 24, 2, 48, 1,  2, 5, 25, 7, 54, 
    0, 78, 6, 61, 7, 33, 2, 65, 1, 43, 3, 45, 4, 31, 8, 34, 5, 89
  };
  const int q3731[] = {
    9, 9, // Number of jobs and machines
    8, 29, 5, 62, 2, 14, 3, 44, 7, 95, 0, 15, 6,  3, 4,  9, 1,  2, 
    8, 19, 0, 86, 1,  6, 2, 43, 6,  5, 7, 82, 4, 38, 3, 42, 5,  3, 
    7, 70, 0, 17, 2, 30, 3, 68, 1, 19, 4, 22, 6, 47, 5,  5, 8, 28, 
    4, 98, 2, 53, 0, 40, 6, 19, 1, 63, 8, 60, 5, 72, 3, 59, 7,  2, 
    7, 66, 6, 72, 1, 24, 4, 58, 3, 54, 8, 88, 5, 62, 2, 45, 0, 61, 
    3, 94, 5, 69, 4, 51, 2, 66, 8, 90, 0, 80, 6, 29, 1, 55, 7, 14, 
    0, 78, 3, 99, 4,  9, 6, 77, 2, 25, 1,  1, 8, 59, 7, 76, 5, 19, 
    6, 76, 2, 59, 4, 71, 3, 94, 8, 28, 7, 85, 5, 54, 0, 59, 1, 80, 
    4, 22, 7, 95, 5,  1, 6, 24, 2, 44, 8, 26, 1, 91, 3, 85, 0, 36
  };
  const int q3732[] = {
    9, 9, // Number of jobs and machines
    1, 76, 4, 72, 6, 92, 2, 56, 0, 28, 5, 59, 7, 39, 3, 96, 8, 27, 
    0, 56, 5, 44, 7, 61, 6, 43, 3, 90, 2, 69, 4,  4, 1, 32, 8, 26, 
    6, 31, 1, 36, 7, 28, 0, 51, 3,  6, 5, 43, 8,  8, 2, 44, 4, 80, 
    5, 20, 3, 23, 4, 38, 6, 68, 1, 73, 2, 22, 0, 20, 8, 31, 7, 58, 
    3, 15, 6, 39, 1, 66, 5, 82, 4, 82, 8, 77, 7, 74, 2, 18, 0,  4, 
    7,  2, 4, 38, 6, 10, 3, 52, 5, 63, 1, 10, 0, 95, 8, 29, 2, 56, 
    6, 41, 1, 82, 4, 86, 3, 53, 2, 24, 7, 35, 5, 62, 8, 27, 0, 31, 
    7, 76, 3, 26, 0, 11, 5, 13, 8, 42, 2, 23, 6, 67, 1, 78, 4, 80, 
    1, 41, 4, 23, 7, 22, 0, 33, 8, 11, 3, 52, 2, 78, 6, 32, 5,  8
  };
  const int q3733[] = {
    9, 9, // Number of jobs and machines
    5, 80, 7, 16, 2, 73, 4, 97, 8, 38, 6, 56, 0, 26, 3, 29, 1, 85, 
    7, 79, 6, 70, 4, 17, 2, 91, 3, 29, 1, 54, 5, 58, 8, 95, 0, 61, 
    3, 28, 8,  3, 5, 50, 0, 27, 2, 42, 4, 22, 6, 90, 7, 50, 1, 21, 
    6, 35, 0, 14, 1, 95, 3,  5, 7, 92, 2, 23, 5, 22, 4, 36, 8, 62, 
    6, 51, 3, 56, 8, 51, 0,  6, 4, 76, 7, 92, 5, 48, 1, 66, 2, 75, 
    4, 26, 6, 53, 2, 70, 1, 70, 5, 75, 0, 54, 8, 62, 7, 66, 3, 70, 
    6, 36, 0, 42, 5, 58, 7, 76, 4, 74, 3, 52, 8, 32, 2, 18, 1, 38, 
    0, 40, 4, 78, 6, 13, 7, 51, 8, 52, 3, 81, 5, 93, 1,  4, 2, 45, 
    0, 34, 7, 71, 5, 85, 1, 35, 4, 97, 3, 99, 8, 10, 2, 19, 6, 12
  };
  const int q3734[] = {
    9, 9, // Number of jobs and machines
    1, 76, 0, 75, 7, 92, 6, 14, 8, 86, 2, 67, 5, 26, 4, 88, 3, 98, 
    5, 53, 6, 23, 0, 86, 3, 79, 1, 22, 8, 70, 7, 92, 2, 58, 4,  9, 
    7, 75, 4, 85, 3, 29, 5, 54, 6, 38, 1, 62, 8, 17, 0, 73, 2, 76, 
    7, 93, 1, 61, 8, 28, 2, 61, 4, 52, 5, 28, 3, 69, 6,  9, 0, 43, 
    4, 57, 2, 27, 6, 29, 7, 13, 0,  8, 3, 68, 1, 95, 8, 45, 5, 22, 
    3,  8, 0, 53, 5, 60, 2, 74, 6, 40, 1, 15, 8, 21, 4, 99, 7, 93, 
    4, 68, 5, 66, 0, 73, 1, 46, 8, 27, 3, 54, 7, 88, 6, 41, 2, 81, 
    0, 68, 8, 19, 4,  1, 7, 74, 6, 11, 1, 29, 2, 81, 3, 19, 5, 25, 
    4, 29, 3, 34, 1, 38, 8, 39, 7, 73, 0, 71, 6, 14, 2, 50, 5, 77
  };
  const int q3735[] = {
    9, 9, // Number of jobs and machines
    6, 81, 8,  5, 1, 28, 3, 69, 0, 39, 5, 17, 2, 97, 7, 67, 4, 38, 
    3, 46, 4, 76, 5, 93, 7, 64, 6, 35, 1, 98, 8, 29, 0, 55, 2, 46, 
    8, 12, 1, 62, 6, 72, 3, 60, 2, 20, 0, 74, 7, 14, 5, 51, 4, 33, 
    1, 35, 2, 93, 3, 23, 5, 43, 0, 12, 8, 87, 4, 52, 6, 10, 7, 72, 
    3, 77, 4, 56, 2, 52, 7, 89, 5,  6, 8, 18, 0, 37, 1,  1, 6,  5, 
    4, 96, 8, 95, 3, 92, 1, 41, 6, 45, 7, 99, 5, 21, 2, 93, 0, 30, 
    7, 22, 3, 11, 4,  4, 8, 36, 1, 26, 6, 42, 2, 98, 0, 39, 5, 56, 
    0, 83, 2, 81, 8,  7, 3, 67, 6,  8, 1, 22, 4, 81, 7, 59, 5, 58, 
    8, 94, 0, 84, 4, 18, 3, 32, 5, 94, 1, 77, 2, 95, 6, 25, 7, 98
  };
  const int q3736[] = {
    9, 9, // Number of jobs and machines
    1, 31, 0, 70, 4, 27, 5, 17, 3, 54, 8, 42, 2, 63, 7, 51, 6, 77, 
    7, 56, 4, 21, 3, 39, 1,  5, 5, 96, 0, 75, 8, 71, 6, 74, 2, 49, 
    8, 12, 3, 25, 7, 65, 4, 22, 5, 72, 1, 41, 6, 30, 2, 42, 0, 30, 
    1, 78, 7, 26, 4, 80, 8, 18, 6, 37, 3, 22, 2, 72, 0, 38, 5,  7, 
    0, 50, 6, 26, 7,  5, 4, 47, 5, 94, 1, 44, 2, 46, 3, 96, 8, 47, 
    7, 68, 1, 29, 0, 40, 4,  9, 6, 62, 3, 44, 2, 51, 8, 29, 5, 46, 
    6, 18, 3, 92, 8, 78, 5, 89, 7, 25, 2, 35, 0, 36, 4, 86, 1, 44, 
    3, 13, 6, 84, 7, 28, 5, 56, 0, 99, 8,  5, 4,  3, 1, 98, 2, 51, 
    4, 32, 5, 27, 2, 20, 3, 27, 8, 87, 6, 52, 0, 21, 1, 97, 7, 46
  };
  const int q3737[] = {
    9, 9, // Number of jobs and machines
    5, 85, 0, 93, 6, 41, 7, 94, 2, 54, 1, 50, 4, 33, 3, 21, 8, 46, 
    4, 46, 7, 69, 8, 85, 5, 94, 2, 40, 3, 84, 1, 22, 0,  9, 6, 71, 
    4, 35, 8, 92, 6, 29, 3, 57, 7, 76, 0,  4, 2, 62, 5,  1, 1, 80, 
    8, 65, 1, 16, 3, 88, 7, 58, 6, 56, 2, 78, 4, 10, 5, 87, 0, 41, 
    3, 22, 2, 35, 0, 38, 4, 83, 7, 70, 1, 97, 5, 36, 6,  5, 8, 20, 
    4, 84, 8, 69, 0, 32, 5, 52, 1, 79, 3, 21, 7, 64, 6, 52, 2, 29, 
    1, 40, 7, 61, 4, 99, 5, 41, 0, 10, 2, 37, 3, 39, 8, 55, 6, 20, 
    1, 75, 3,  2, 2, 20, 0,  9, 7, 92, 6, 34, 5, 48, 8, 41, 4, 17, 
    2, 48, 0, 30, 7, 23, 5, 88, 4, 28, 8, 84, 1, 17, 6, 24, 3, 12
  };
  const int q3738[] = {
    9, 9, // Number of jobs and machines
    6, 71, 5, 91, 7, 58, 8, 65, 2, 13, 1, 97, 3, 90, 4, 32, 0, 20, 
    0, 98, 6, 21, 1, 10, 7, 99, 2, 62, 3, 23, 4, 95, 5, 52, 8, 68, 
    6, 66, 4, 42, 7, 78, 1, 34, 2, 22, 3, 14, 8, 18, 5,  6, 0, 75, 
    3, 82, 4, 16, 6, 41, 1, 31, 7, 43, 8, 86, 2, 66, 5, 80, 0, 45, 
    7, 26, 5, 53, 8, 35, 2, 27, 1, 68, 6, 34, 3, 66, 4, 80, 0, 55, 
    1,  1, 4, 44, 5, 48, 2, 88, 6, 91, 0, 22, 3, 56, 7, 72, 8, 22, 
    0, 79, 1, 85, 8, 94, 2, 12, 7, 53, 6, 41, 4, 47, 3, 31, 5, 55, 
    6, 18, 2,  8, 7, 93, 5, 94, 3, 11, 1, 10, 8, 39, 4, 16, 0, 28, 
    0, 41, 1, 12, 4, 69, 5, 15, 6, 75, 3, 23, 8, 37, 2, 75, 7, 93
  };
  const int q3739[] = {
    9, 9, // Number of jobs and machines
    0, 48, 2, 19, 7, 67, 8, 16, 4, 26, 6, 55, 5,  4, 1, 63, 3, 87, 
    6, 40, 8, 73, 1, 43, 3, 86, 5, 99, 2,  2, 4, 31, 7, 30, 0, 40, 
    4, 84, 5, 80, 7, 94, 2, 29, 0, 90, 3, 86, 1, 11, 8, 43, 6, 42, 
    0, 66, 3, 58, 7, 81, 2, 13, 8, 78, 1, 11, 5, 33, 4, 33, 6, 74, 
    0, 70, 7, 55, 5, 72, 8,  5, 6, 95, 1, 43, 2, 72, 4, 40, 3, 11, 
    8, 87, 1,  3, 2, 37, 6, 67, 0, 71, 5, 94, 3, 97, 4, 65, 7, 16, 
    2, 90, 8, 13, 4, 86, 7,  9, 0, 69, 6, 70, 1, 68, 5, 79, 3, 59, 
    2, 80, 0,  7, 5, 32, 4, 39, 6, 55, 7, 24, 3, 17, 1, 45, 8, 98, 
    2,  7, 7, 73, 8, 36, 6, 70, 3, 62, 4, 82, 0, 92, 5, 35, 1,  3
  };
  const int q3740[] = {
    9, 9, // Number of jobs and machines
    8, 91, 7, 68, 0, 55, 5, 10, 3, 98, 6, 10, 4, 50, 1, 47, 2, 56, 
    5, 39, 0, 74, 6, 22, 2, 48, 1, 61, 3, 71, 4, 55, 7, 56, 8, 34, 
    3, 27, 0, 91, 7, 74, 5, 71, 1, 34, 2, 63, 4, 10, 8, 85, 6, 42, 
    6, 22, 1, 10, 7, 25, 5, 53, 4, 58, 2, 89, 0, 33, 8, 13, 3, 84, 
    5, 94, 6, 45, 2, 75, 0,  2, 3, 24, 1, 18, 7,  9, 8, 64, 4,  1, 
    3, 12, 2, 79, 5, 23, 7, 72, 6, 51, 4, 62, 8, 75, 1, 56, 0, 97, 
    3, 83, 7, 46, 4, 58, 2,  9, 6,  5, 8, 65, 1, 52, 5, 45, 0, 43, 
    7, 89, 3, 61, 8, 80, 0, 53, 2, 43, 5, 99, 1, 29, 6, 99, 4, 27, 
    1, 60, 2, 34, 0, 32, 6, 48, 4, 11, 5, 49, 3, 26, 7, 51, 8, 95
  };
  const int q3741[] = {
    9, 9, // Number of jobs and machines
    4, 27, 7, 36, 5, 55, 6, 98, 8, 82, 0, 16, 3, 40, 1, 26, 2, 70, 
    8, 79, 4,  9, 5, 22, 7, 94, 0, 10, 3, 82, 1, 48, 6, 67, 2, 80, 
    0, 45, 7, 46, 3, 78, 4, 56, 1,  2, 6, 97, 8, 19, 5, 96, 2, 29, 
    6, 73, 1, 32, 7, 66, 3, 89, 2, 74, 5, 17, 4,  1, 0, 58, 8, 22, 
    6, 43, 5, 70, 2,  7, 3, 67, 8, 40, 0, 40, 4, 86, 7, 46, 1, 57, 
    4, 26, 6, 43, 2, 83, 0, 65, 5, 17, 1, 88, 3,  4, 7, 22, 8, 40, 
    2,  3, 4, 82, 6, 26, 0, 29, 8, 81, 1, 94, 7, 15, 3, 21, 5, 53, 
    0, 54, 7, 43, 8,  5, 6, 86, 3, 32, 4, 90, 5, 85, 2, 91, 1, 14, 
    6, 25, 1, 19, 2, 85, 5, 80, 4, 63, 7,  4, 0, 49, 8, 72, 3, 80
  };
  const int q3742[] = {
    9, 9, // Number of jobs and machines
    5, 67, 8,  9, 7, 57, 4, 22, 2, 76, 0, 24, 1, 48, 3, 78, 6, 75, 
    6, 75, 8, 74, 5, 92, 1, 99, 4, 12, 0, 33, 2, 66, 7, 12, 3, 13, 
    7, 69, 8, 55, 3, 44, 0, 75, 1, 54, 4, 45, 2, 34, 5,  4, 6, 30, 
    5, 18, 0, 34, 7,  5, 3, 49, 2, 89, 1, 59, 8, 93, 6, 77, 4, 11, 
    8, 87, 5, 48, 2, 52, 7, 35, 4, 46, 0, 50, 1, 13, 6, 67, 3, 93, 
    4, 97, 8, 39, 2, 67, 5, 32, 6,  6, 7, 53, 1, 90, 3, 37, 0,  2, 
    7, 81, 2, 77, 1, 23, 8, 82, 6,  2, 5, 14, 3, 58, 4,  2, 0, 61, 
    8, 95, 0, 39, 2, 90, 4, 12, 7, 77, 1, 70, 5, 35, 6, 30, 3, 22, 
    5, 93, 8, 62, 0, 58, 2,  7, 7, 85, 6, 53, 3, 92, 4, 44, 1, 72
  };
  const int q3743[] = {
    9, 9, // Number of jobs and machines
    4, 47, 0, 72, 8,  5, 6, 17, 7, 13, 3, 94, 1, 94, 5, 42, 2, 65, 
    1, 30, 3, 44, 6, 72, 8, 94, 2, 34, 5,  3, 7, 50, 0, 74, 4, 36, 
    7, 14, 6, 69, 5, 79, 8, 28, 4, 70, 3, 98, 0, 39, 2, 28, 1, 93, 
    1, 66, 6, 35, 3, 64, 8, 18, 0, 25, 5, 87, 4, 35, 7, 81, 2, 10, 
    4, 64, 5, 31, 6, 14, 8, 90, 7, 70, 1, 78, 2, 81, 0, 89, 3, 77, 
    5, 98, 2, 57, 4, 57, 7, 31, 8, 65, 3, 44, 6, 87, 1, 68, 0, 45, 
    5, 21, 1, 16, 8, 58, 7, 64, 4, 31, 0, 15, 6, 26, 3, 79, 2,  1, 
    7, 20, 4, 52, 3, 33, 6, 77, 2, 68, 1, 16, 5, 88, 8, 67, 0, 37, 
    4, 99, 7, 45, 2, 44, 1,  9, 5, 32, 3, 83, 6, 60, 0, 25, 8, 10
  };
  const int q3744[] = {
    9, 9, // Number of jobs and machines
    2, 57, 8,  7, 4, 34, 5, 60, 0,  4, 3, 29, 7, 91, 1, 24, 6, 36, 
    3, 56, 2, 91, 0, 56, 1, 22, 5,  9, 7, 12, 8, 40, 6, 82, 4, 48, 
    1, 60, 8, 97, 4, 15, 7, 71, 2,  6, 3, 41, 5, 57, 6, 61, 0, 29, 
    7, 23, 4,  2, 8, 60, 6, 20, 1, 66, 2, 68, 3, 85, 5, 11, 0, 75, 
    5, 48, 8, 39, 6, 37, 3, 17, 2, 80, 7, 84, 4, 68, 0, 86, 1, 22, 
    0, 29, 7,  1, 1, 29, 2, 51, 3, 84, 4, 66, 8, 24, 6, 28, 5,  7, 
    1, 86, 4, 13, 3, 85, 8, 89, 7, 84, 0, 66, 6, 65, 2, 29, 5, 84, 
    7,  6, 6, 85, 1,  9, 3, 64, 5, 23, 4, 96, 2, 78, 0, 52, 8, 15, 
    8, 35, 7, 40, 5, 70, 3, 17, 6, 36, 0, 13, 4, 24, 2,  3, 1, 54
  };
  const int q3745[] = {
    9, 9, // Number of jobs and machines
    3,  3, 2, 73, 8, 39, 1, 62, 7, 13, 0, 92, 5, 21, 4, 98, 6, 78, 
    8, 25, 7, 52, 2, 59, 4, 55, 3, 83, 6, 15, 0, 39, 1, 90, 5, 60, 
    6, 47, 4, 52, 2, 72, 8, 34, 0, 19, 5, 24, 3, 66, 1, 79, 7, 56, 
    8,  4, 4, 77, 1,  5, 6, 28, 2,  4, 5, 82, 3, 38, 0, 57, 7, 54, 
    0, 32, 5, 67, 1, 76, 4, 75, 8, 77, 3, 65, 6, 27, 7, 63, 2, 65, 
    4,  8, 8, 46, 0, 68, 5, 46, 3, 32, 2, 88, 6, 62, 7, 48, 1, 84, 
    1, 23, 7, 87, 3, 95, 5, 88, 0, 83, 8, 88, 6, 12, 4, 11, 2, 21, 
    3, 30, 0, 65, 7, 88, 4, 37, 5, 11, 8, 69, 6, 99, 2, 66, 1, 40, 
    4, 85, 5, 14, 2, 94, 1, 42, 6, 93, 7, 82, 0, 51, 8, 25, 3, 93
  };
  const int q3746[] = {
    9, 9, // Number of jobs and machines
    5,  7, 1, 22, 6, 31, 4, 16, 0, 64, 3, 52, 2, 36, 8, 26, 7, 36, 
    2, 45, 4, 41, 8, 12, 5, 89, 0, 54, 3, 73, 6, 12, 1,  5, 7, 72, 
    8, 30, 1, 78, 5, 45, 0, 85, 2, 71, 3,  9, 6, 36, 4, 46, 7, 88, 
    3, 45, 1, 20, 8, 19, 2, 87, 6, 83, 5, 21, 4, 85, 7, 13, 0, 46, 
    5, 57, 2, 80, 6, 87, 3, 80, 4,  9, 8, 83, 7, 52, 0, 28, 1, 67, 
    7,  7, 2, 24, 0, 40, 5,  4, 1,  4, 8, 56, 4, 92, 3, 96, 6, 23, 
    2, 33, 3, 15, 7, 81, 5, 25, 0, 83, 6, 38, 4, 72, 1, 56, 8, 24, 
    1, 72, 7, 21, 2, 41, 4, 22, 3, 46, 0, 98, 6, 37, 5, 39, 8, 11, 
    7, 14, 0, 91, 3, 62, 5, 84, 2, 21, 8,  6, 1,  5, 6, 19, 4, 64
  };
  const int q3747[] = {
    9, 9, // Number of jobs and machines
    6, 58, 1,  8, 2, 56, 5, 61, 3, 54, 4, 89, 8,  8, 0, 12, 7, 99, 
    5,  7, 6, 90, 7,  4, 3, 86, 2, 85, 8, 17, 1, 71, 4, 84, 0,  6, 
    0, 15, 5,  4, 1, 71, 6, 24, 3, 34, 2, 36, 7, 88, 4,  3, 8,  6, 
    7, 41, 3,  3, 8, 21, 6,  7, 2, 22, 4, 39, 0, 59, 5,  1, 1, 59, 
    8, 19, 4, 71, 2, 99, 5, 95, 7,  7, 6, 79, 1, 69, 3, 82, 0, 14, 
    8, 63, 0, 26, 1, 64, 6, 59, 4, 18, 3, 99, 7, 48, 2, 14, 5, 24, 
    6, 17, 0, 28, 2, 73, 4, 65, 3, 16, 8,  7, 1, 48, 7,  4, 5, 64, 
    0, 54, 5, 96, 7, 56, 6,  1, 3, 85, 2, 52, 8, 23, 1, 21, 4, 74, 
    2, 81, 5, 27, 8, 75, 1, 24, 7, 59, 4, 56, 6, 40, 3, 48, 0, 45
  };
  const int q3748[] = {
    9, 9, // Number of jobs and machines
    2, 43, 0, 58, 7, 77, 6, 21, 5, 22, 4, 80, 1, 60, 8, 94, 3, 49, 
    6, 95, 3, 94, 4, 52, 8, 12, 2, 41, 1, 20, 0, 13, 5, 30, 7, 24, 
    3, 94, 7, 47, 5,  2, 4, 27, 0, 87, 1, 55, 8, 96, 6, 73, 2, 65, 
    0, 41, 7, 41, 2, 11, 4, 83, 1, 49, 3, 73, 8, 79, 6, 49, 5, 74, 
    1, 95, 2, 47, 0, 32, 5,  4, 8, 17, 3, 72, 7, 68, 6, 77, 4, 46, 
    6, 87, 4, 45, 8,  7, 2, 61, 0, 25, 3, 18, 7, 15, 5, 14, 1, 35, 
    2, 37, 0, 85, 6, 15, 4, 25, 7, 75, 1, 83, 5,  3, 8, 53, 3, 69, 
    2, 44, 1, 87, 7, 97, 8, 34, 5, 89, 3, 58, 6, 22, 4,  3, 0, 55, 
    3, 13, 0, 18, 1, 49, 5, 98, 7, 47, 2,  4, 8, 90, 6, 43, 4, 57
  };
  const int q3749[] = {
    9, 9, // Number of jobs and machines
    3,  7, 8,  6, 0, 66, 4, 41, 2, 63, 5, 92, 6, 49, 1, 46, 7, 83, 
    1, 58, 5, 68, 6, 93, 8, 32, 2,  3, 4, 19, 0, 57, 7, 75, 3,  1, 
    7, 27, 4, 53, 8, 81, 3, 23, 6, 39, 5, 76, 2, 52, 0, 34, 1, 73, 
    4, 47, 7, 12, 1, 79, 3, 48, 8, 71, 5, 85, 6, 19, 2, 87, 0, 21, 
    1, 15, 5, 19, 4, 15, 3, 45, 0, 83, 2, 12, 7, 74, 8, 49, 6, 65, 
    7, 16, 1, 21, 8,  5, 0, 49, 3, 56, 5, 60, 6, 24, 4, 36, 2, 24, 
    4, 40, 0, 29, 5, 59, 3, 88, 1, 44, 7,  3, 2, 61, 6, 49, 8, 92, 
    1, 89, 3, 37, 8, 82, 5, 71, 0, 59, 7,  3, 6, 13, 4, 79, 2, 28, 
    4, 71, 2,  8, 6, 80, 5, 15, 3, 60, 0, 62, 8, 27, 7, 26, 1, 29
  };
  const int q3750[] = {
    9, 9, // Number of jobs and machines
    2, 55, 4, 35, 8, 40, 3, 49, 5, 76, 7, 92, 0, 11, 1, 35, 6, 85, 
    6,  7, 0, 18, 8, 19, 7, 26, 1, 77, 3, 91, 4, 34, 5, 94, 2, 28, 
    1, 50, 6, 57, 8, 93, 7, 11, 2, 72, 5,  4, 4, 51, 3, 90, 0, 11, 
    4,  5, 3,  3, 2, 17, 5, 82, 7, 63, 0, 11, 6, 88, 1, 78, 8,  8, 
    7, 21, 4, 72, 6, 20, 2, 51, 3,  9, 5, 69, 8, 10, 0, 81, 1, 94, 
    0, 33, 5,  8, 7,  2, 2, 11, 6, 71, 4, 88, 1, 48, 3, 89, 8, 97, 
    7, 72, 3, 96, 4, 73, 8,  4, 1, 29, 6,  2, 2, 99, 0, 78, 5, 11, 
    5, 94, 2, 68, 4, 78, 6, 54, 3, 84, 7, 28, 0, 33, 8, 49, 1, 87, 
    4, 75, 1, 54, 0,  9, 2, 36, 6,  9, 7, 61, 5, 29, 8, 42, 3, 88
  };
  const int q3751[] = {
    9, 9, // Number of jobs and machines
    4, 37, 6, 30, 3, 79, 7,  9, 0, 71, 5, 86, 2, 70, 8, 78, 1, 97, 
    6, 14, 3, 36, 7, 76, 4, 88, 2, 92, 5, 31, 8, 31, 1,  8, 0, 74, 
    5, 22, 3, 67, 4, 66, 2, 46, 8, 43, 6, 12, 1, 27, 0, 66, 7, 75, 
    0, 79, 3, 92, 5,  8, 2, 75, 6, 38, 1, 99, 4, 69, 7, 78, 8, 96, 
    1, 83, 6, 82, 7, 67, 2, 58, 8, 74, 3,  4, 5, 48, 4, 78, 0, 29, 
    2, 76, 3, 14, 5, 35, 6, 17, 1, 28, 0, 38, 4, 97, 8, 97, 7, 87, 
    5, 12, 3, 25, 0, 75, 4,  2, 6, 29, 1, 36, 7, 34, 8, 72, 2, 28, 
    3, 58, 1, 19, 8, 18, 4, 63, 5, 63, 0, 38, 6, 52, 7, 99, 2,  1, 
    1, 90, 6, 35, 3, 32, 5, 78, 4, 71, 2, 49, 0, 26, 8, 62, 7, 30
  };
  const int q3752[] = {
    9, 9, // Number of jobs and machines
    1, 23, 8, 11, 2, 96, 7, 96, 0,  9, 3, 57, 4, 16, 5, 23, 6, 49, 
    6, 57, 4, 82, 5, 24, 0, 52, 3, 69, 2, 28, 7, 93, 8, 13, 1, 21, 
    4, 40, 0, 97, 6, 84, 2, 22, 1, 81, 8, 57, 3, 22, 5, 99, 7, 44, 
    4, 65, 2,  9, 5, 94, 1, 89, 7, 20, 8, 28, 6, 28, 0, 78, 3, 68, 
    2, 40, 0, 79, 8, 71, 4, 66, 1, 67, 5, 69, 7, 36, 3, 95, 6, 99, 
    2, 16, 8, 31, 0, 23, 4, 46, 5, 36, 6, 85, 7, 91, 1, 61, 3, 64, 
    2,  4, 1, 94, 5, 52, 6,  1, 8, 85, 3,  4, 4, 52, 0, 56, 7,  1, 
    6, 83, 3, 26, 8, 13, 7, 90, 2, 49, 5, 52, 4,  2, 0, 69, 1, 40, 
    0, 48, 1, 42, 8, 54, 6, 66, 2, 86, 3, 66, 7, 52, 5, 19, 4, 82
  };
  const int q3753[] = {
    9, 9, // Number of jobs and machines
    5, 31, 3, 44, 7, 50, 8, 68, 6, 40, 1, 21, 4, 16, 2, 25, 0,  5, 
    5, 73, 6, 94, 2, 56, 1, 67, 3, 41, 4, 72, 0, 84, 7, 99, 8,  1, 
    2, 33, 0, 26, 3, 88, 7, 22, 6, 61, 8, 32, 4, 33, 1, 14, 5, 24, 
    3, 83, 1, 11, 7, 92, 0, 76, 6, 64, 2, 15, 5, 40, 8, 41, 4,  9, 
    4, 67, 6, 70, 5, 27, 8, 10, 0, 83, 3, 60, 7, 40, 2, 74, 1, 33, 
    2, 13, 4, 94, 1, 65, 3, 86, 8, 97, 7, 42, 6, 68, 0, 34, 5, 59, 
    1, 87, 3, 97, 4, 67, 6,  5, 8,  9, 5,  9, 7, 64, 0, 80, 2, 91, 
    5, 86, 6, 10, 4, 67, 2, 23, 7, 43, 3, 76, 0, 20, 8, 81, 1, 75, 
    5, 55, 7, 87, 8, 10, 4, 51, 6, 60, 2, 32, 1, 45, 0, 46, 3, 92
  };
  const int q3754[] = {
    9, 9, // Number of jobs and machines
    1, 55, 2, 24, 5, 41, 7, 19, 3, 59, 8, 40, 0, 10, 6, 15, 4, 24, 
    4, 82, 7, 37, 1, 27, 0, 33, 3, 12, 8, 38, 5, 20, 2, 68, 6, 35, 
    4, 88, 2, 41, 6, 62, 0, 30, 1, 24, 3, 15, 5,  5, 8, 92, 7, 69, 
    0, 86, 1, 41, 5, 47, 3, 46, 8, 74, 4, 20, 2, 52, 6, 62, 7, 98, 
    7, 93, 1, 18, 2, 84, 8,  2, 4, 80, 6, 33, 5, 98, 3, 32, 0, 89, 
    7,  2, 0, 12, 6, 79, 8, 16, 3, 33, 5, 76, 4, 89, 1, 93, 2, 57, 
    1, 95, 5, 41, 4, 70, 6, 71, 3, 92, 0, 71, 7, 76, 8, 56, 2, 90, 
    8, 46, 4,  7, 2, 20, 6, 64, 7, 32, 1, 43, 5, 80, 3, 60, 0, 81, 
    3, 50, 5, 16, 6,  6, 8, 26, 4, 58, 0, 29, 1, 16, 7, 13, 2, 54
  };
  const int q3755[] = {
    9, 9, // Number of jobs and machines
    3,  4, 7, 53, 0, 21, 5,  1, 2, 54, 4, 23, 1, 35, 8, 80, 6, 48, 
    8, 30, 7, 71, 6, 16, 4, 55, 0, 15, 3, 24, 1, 78, 2, 60, 5, 62, 
    3, 76, 4, 83, 0, 94, 1, 41, 5, 12, 2, 82, 8, 96, 7, 24, 6, 89, 
    6, 97, 0, 92, 3, 28, 1,  6, 4, 45, 8,  5, 2, 47, 7, 80, 5, 75, 
    0, 83, 3, 27, 2, 16, 8,  2, 5, 81, 1, 33, 4, 11, 7, 53, 6, 97, 
    4, 41, 7, 63, 6, 24, 2,  8, 8, 32, 0, 77, 5, 98, 3, 37, 1,  9, 
    3, 88, 7, 19, 1, 41, 8, 76, 5,  1, 2, 54, 0,  6, 4, 95, 6, 88, 
    7, 63, 6, 64, 2, 13, 3, 38, 0, 20, 8,  4, 1, 58, 5, 40, 4, 13, 
    0, 46, 7, 95, 2, 70, 5, 66, 1, 80, 6, 26, 3, 35, 4, 44, 8, 25
  };
  const int q3756[] = {
    9, 9, // Number of jobs and machines
    5, 59, 7, 94, 1, 98, 2,  5, 0, 94, 6, 75, 4, 97, 3, 86, 8, 53, 
    5, 27, 1, 62, 7, 92, 2,  3, 6, 76, 3, 49, 4, 11, 0, 25, 8, 11, 
    5, 50, 4, 37, 8, 51, 1,  7, 0, 53, 7, 92, 2, 87, 6, 16, 3, 72, 
    2, 16, 6, 43, 4, 73, 7, 96, 3, 24, 0, 19, 8, 91, 5, 87, 1, 50, 
    1, 41, 7, 58, 5, 20, 0, 19, 2,  4, 6, 80, 4, 16, 3, 20, 8, 37, 
    6, 52, 5, 32, 3, 93, 4, 55, 1, 28, 0, 92, 8, 60, 2, 93, 7, 61, 
    5, 83, 4, 86, 8, 49, 2, 49, 1, 61, 6, 62, 7, 41, 0, 87, 3, 50, 
    6, 53, 8,  4, 0, 97, 2, 81, 5, 48, 3, 89, 1,  2, 4, 40, 7, 64, 
    3, 89, 4, 95, 8, 81, 1, 97, 7, 22, 0, 37, 2, 32, 6, 33, 5, 10
  };
  const int q3757[] = {
    9, 9, // Number of jobs and machines
    1, 84, 0, 22, 8, 36, 5, 84, 7, 21, 3,  3, 2,  5, 6, 83, 4, 36, 
    2, 53, 5, 11, 4, 88, 6, 51, 0, 32, 8, 78, 1, 79, 3,  9, 7, 18, 
    4, 66, 8,  1, 1, 17, 2, 31, 0, 84, 3, 54, 5, 25, 7,  7, 6, 52, 
    4,  7, 5,  7, 6,  4, 7, 87, 2, 52, 3, 43, 0, 67, 8, 50, 1, 36, 
    5, 78, 3, 17, 2, 70, 7, 84, 1, 64, 4, 10, 6, 77, 8, 59, 0, 70, 
    6, 70, 3, 37, 8, 30, 2,  3, 4, 84, 5, 57, 1, 79, 0, 62, 7, 44, 
    0, 48, 3, 91, 6, 16, 7, 69, 5, 67, 1, 74, 2, 89, 8, 55, 4, 90, 
    8, 65, 6, 35, 7, 59, 0, 95, 1, 22, 3,  1, 2, 20, 5, 24, 4, 67, 
    4, 49, 7, 70, 0, 77, 5, 79, 3, 10, 8, 43, 2, 42, 6, 37, 1, 56
  };
  const int q3758[] = {
    9, 9, // Number of jobs and machines
    0, 57, 8, 32, 7,  7, 3, 27, 5, 85, 1, 52, 2,  8, 4, 88, 6, 26, 
    2, 70, 1, 50, 8, 53, 3, 90, 4, 45, 7, 95, 5,  1, 0, 92, 6, 47, 
    8, 10, 1, 10, 2, 14, 3, 35, 0,  9, 6, 17, 7, 93, 5, 86, 4, 83, 
    8, 11, 5, 11, 7, 70, 6, 28, 3, 94, 4, 11, 2, 51, 1, 32, 0, 18, 
    8, 97, 3, 22, 6, 34, 2, 70, 0, 28, 7, 54, 4, 44, 1, 20, 5, 21, 
    0,  9, 2, 14, 5, 92, 7, 39, 3, 98, 6, 57, 4, 95, 8, 53, 1, 88, 
    4, 30, 8, 44, 3,  4, 1, 74, 0, 95, 5, 64, 6, 46, 2, 62, 7, 21, 
    0, 47, 2, 22, 6, 69, 5, 20, 7, 78, 3, 61, 8, 14, 4, 70, 1, 87, 
    4, 62, 0, 15, 3,  3, 1, 61, 6, 82, 7,  1, 2,  7, 5, 10, 8, 77
  };
  const int q3759[] = {
    9, 9, // Number of jobs and machines
    8, 24, 7, 90, 6, 24, 2, 28, 0, 85, 1, 22, 3, 87, 4, 38, 5, 61, 
    5, 84, 7, 66, 2, 86, 1, 50, 0, 26, 4, 10, 8, 55, 6, 15, 3,  1, 
    2, 71, 7, 37, 6, 50, 8, 39, 1, 45, 0, 91, 5, 51, 4,  8, 3, 30, 
    4, 68, 2,  2, 5, 62, 6, 45, 0, 22, 1, 33, 3, 75, 8, 45, 7, 89, 
    1, 61, 0, 29, 3,  7, 7, 27, 8, 19, 2, 12, 5, 37, 6, 41, 4, 71, 
    5, 83, 2,  8, 6, 14, 3, 64, 1, 49, 0, 14, 8, 86, 7, 33, 4, 19, 
    1, 33, 8, 29, 0, 97, 3, 60, 6, 53, 2,  2, 5, 59, 4, 92, 7, 64, 
    4, 91, 1, 72, 8, 43, 5, 54, 6, 61, 3, 54, 2, 60, 7, 81, 0,  6, 
    1, 82, 2, 15, 4, 27, 5, 35, 0, 96, 6, 94, 3, 31, 8, 22, 7, 62
  };
  const int q3760[] = {
    9, 9, // Number of jobs and machines
    7, 52, 3, 93, 6, 72, 5, 28, 0, 26, 8, 87, 2, 14, 4, 40, 1, 48, 
    8, 72, 3, 80, 1, 20, 7, 64, 2, 22, 4,  5, 6, 50, 5, 27, 0, 68, 
    8, 69, 6, 55, 5, 21, 4, 85, 3, 38, 1,  3, 2, 11, 7, 86, 0, 59, 
    8, 29, 1, 95, 6, 28, 7, 78, 3,  9, 5, 12, 0, 59, 4, 71, 2, 94, 
    1, 44, 2, 57, 4, 79, 7,  5, 8,  9, 3, 24, 6,  9, 5, 41, 0, 79, 
    5, 58, 0, 19, 4, 32, 8, 64, 7, 46, 6, 43, 1, 34, 2, 81, 3, 65, 
    6, 87, 7, 43, 3, 60, 8, 90, 4, 13, 2, 42, 1,  9, 5, 57, 0, 90, 
    7, 75, 0, 59, 8, 45, 4, 66, 1, 91, 6, 10, 5,  7, 3, 60, 2, 59, 
    4,  1, 7, 35, 1, 46, 2, 33, 6, 57, 0, 18, 8, 62, 5, 16, 3,  2
  };
  const int q3761[] = {
    9, 9, // Number of jobs and machines
    6, 78, 1, 72, 7, 11, 2, 50, 8, 32, 0,  3, 5, 29, 3, 81, 4, 63, 
    6, 67, 4, 30, 8, 51, 2, 76, 1, 81, 3, 58, 7, 43, 5, 11, 0, 47, 
    6, 51, 2, 79, 7, 27, 3, 23, 4, 37, 1, 83, 5, 59, 0, 63, 8, 20, 
    5, 57, 0, 80, 2, 42, 7, 34, 3, 56, 4, 96, 1, 64, 8, 79, 6,  2, 
    1, 12, 5,  2, 4,  6, 6, 61, 8, 12, 7, 79, 0, 12, 3,  2, 2, 68, 
    0, 57, 2, 30, 6,  5, 7, 35, 1, 47, 4, 84, 3, 59, 5,  7, 8, 79, 
    1, 88, 4, 28, 0, 32, 8, 21, 2, 18, 3, 67, 7, 55, 5, 59, 6, 84, 
    8, 65, 7, 43, 1, 29, 3,  7, 5, 45, 2, 14, 6, 45, 4, 73, 0, 30, 
    7, 47, 4, 30, 3, 23, 6, 52, 8,  4, 2, 35, 5, 91, 0, 62, 1, 67
  };
  const int q3762[] = {
    9, 9, // Number of jobs and machines
    6, 64, 8, 32, 7, 72, 3, 19, 0, 35, 5, 74, 1, 17, 2, 65, 4, 28, 
    2, 59, 0, 81, 4, 17, 5, 56, 3, 82, 6, 20, 8, 91, 1, 73, 7, 97, 
    2, 66, 0, 84, 3, 70, 5, 20, 8, 94, 6, 79, 1, 40, 7, 29, 4, 74, 
    0, 46, 5, 64, 3, 48, 1, 97, 7, 58, 8, 58, 4, 61, 6, 69, 2,  7, 
    4, 60, 0, 12, 2, 10, 7, 71, 1, 71, 5, 10, 8, 91, 6, 59, 3, 86, 
    8, 72, 5, 89, 6,  9, 1, 64, 7, 72, 0, 50, 2, 84, 4, 52, 3, 53, 
    6, 94, 8, 77, 4, 60, 3, 17, 7, 29, 5, 20, 0, 53, 2, 48, 1, 51, 
    8, 72, 4, 54, 3, 83, 0, 15, 7, 40, 5, 20, 6, 24, 2, 35, 1, 72, 
    4, 82, 7, 21, 8, 78, 0, 92, 5, 98, 2, 69, 1, 45, 6, 29, 3, 82
  };
  const int q3763[] = {
    9, 9, // Number of jobs and machines
    6, 85, 3, 84, 7, 22, 5, 31, 0, 52, 8,  6, 4, 47, 2,  4, 1, 85, 
    5, 70, 3, 26, 4, 17, 7, 81, 2, 33, 6, 32, 8, 22, 0, 16, 1, 98, 
    2, 23, 4,  6, 3, 98, 8, 26, 7, 14, 0, 65, 5, 89, 1, 53, 6, 21, 
    4, 69, 8, 14, 6, 25, 1, 81, 5, 51, 3, 12, 7, 38, 2,  5, 0, 78, 
    2, 60, 3, 62, 7,  4, 4, 83, 0, 27, 8,  6, 1, 64, 5, 56, 6, 98, 
    7, 36, 2, 92, 5, 78, 0, 90, 3, 66, 4,  5, 8, 54, 1,  3, 6, 55, 
    2, 26, 5, 61, 0, 65, 8,  9, 4, 23, 7, 69, 3, 45, 1, 62, 6, 84, 
    5, 20, 3, 43, 6, 24, 2,  2, 0, 38, 4, 15, 7, 35, 1, 11, 8, 64, 
    7, 78, 3, 54, 0, 46, 1, 35, 6, 15, 5, 47, 8, 25, 4, 30, 2, 37
  };
  const int q3764[] = {
    9, 9, // Number of jobs and machines
    5, 95, 8, 87, 4, 32, 7, 92, 1, 43, 6, 74, 0,  1, 2, 31, 3, 67, 
    4, 66, 7, 93, 5, 99, 8,  1, 2, 54, 3, 85, 1, 91, 0, 36, 6,  4, 
    3, 66, 1, 54, 0, 55, 5, 82, 4, 47, 7, 90, 2, 83, 6, 95, 8, 70, 
    5, 36, 6, 19, 2, 54, 8, 27, 7,  1, 1, 11, 0, 16, 4, 41, 3, 78, 
    1, 11, 7, 70, 4, 79, 3, 87, 6, 22, 0, 65, 5, 38, 8, 87, 2,  3, 
    5, 61, 6, 77, 1, 96, 0,  5, 3, 36, 8, 56, 2, 27, 4, 87, 7, 31, 
    6, 67, 2, 39, 4, 28, 0, 19, 3, 22, 1, 96, 7, 96, 5, 91, 8, 47, 
    0, 54, 3, 23, 5, 83, 2, 86, 6, 50, 4, 58, 7, 16, 8,  3, 1,  3, 
    1, 28, 4, 45, 6, 29, 5, 15, 2, 30, 7, 27, 3, 70, 8, 52, 0, 62
  };
  const int q3765[] = {
    9, 9, // Number of jobs and machines
    7, 96, 8, 67, 0, 75, 2, 79, 6, 58, 5, 17, 4, 73, 3, 62, 1, 91, 
    1, 95, 0,  1, 2,  7, 4, 96, 8, 11, 3, 11, 6, 29, 5, 61, 7, 61, 
    7, 40, 0, 23, 8, 59, 3, 98, 1, 96, 5, 12, 2, 57, 6, 66, 4, 17, 
    0,  2, 7, 97, 2, 52, 6, 60, 1, 46, 3, 17, 4,  1, 5, 89, 8, 95, 
    7, 71, 0, 46, 6, 76, 2, 47, 3, 77, 4, 62, 5, 83, 8, 23, 1, 80, 
    0, 42, 7, 74, 2,  6, 5,  3, 3,  8, 4, 74, 6, 43, 8, 51, 1, 94, 
    3, 80, 0, 27, 5, 19, 4, 59, 7,  9, 1, 86, 6, 44, 2, 79, 8, 36, 
    6, 10, 4, 80, 0, 25, 2, 35, 5, 58, 8, 63, 3, 11, 1, 17, 7, 54, 
    6, 27, 4, 33, 8, 25, 1, 90, 7, 80, 5, 87, 2, 80, 0, 94, 3, 15
  };
  const int q3766[] = {
    9, 9, // Number of jobs and machines
    7, 82, 0, 17, 4, 42, 5, 45, 6, 98, 1, 76, 8, 46, 2, 71, 3, 95, 
    6, 85, 0, 13, 2, 12, 3, 80, 8, 31, 1, 22, 5, 26, 4, 46, 7, 61, 
    7, 91, 2, 67, 8, 64, 5, 71, 3, 86, 0, 89, 4, 68, 1, 21, 6, 56, 
    2, 49, 4, 15, 3, 37, 1, 72, 5, 92, 8, 38, 6, 96, 0, 70, 7, 24, 
    2, 76, 8, 91, 4, 18, 3, 22, 7, 54, 5, 48, 1, 33, 6, 30, 0, 32, 
    1, 97, 6, 43, 5, 94, 2,  3, 0,  7, 4, 84, 7,  2, 3, 64, 8, 46, 
    6, 83, 5, 28, 4, 29, 3,  4, 8, 54, 2, 32, 7, 10, 1, 82, 0, 27, 
    1, 83, 7, 78, 3, 36, 0,  3, 8, 48, 6, 10, 2, 44, 4, 26, 5,  8, 
    3, 30, 5, 25, 2, 10, 6, 63, 4, 81, 1, 21, 8, 70, 7, 37, 0, 84
  };
  const int q3767[] = {
    9, 9, // Number of jobs and machines
    7,  2, 0, 32, 6, 73, 4, 88, 5, 69, 3, 80, 2, 47, 1, 63, 8, 63, 
    1, 89, 2, 65, 6, 18, 5, 51, 0, 90, 4, 54, 7, 13, 3, 82, 8, 61, 
    7, 90, 0, 45, 8,  7, 1, 95, 4, 64, 2, 17, 6, 24, 3, 95, 5, 73, 
    4, 20, 2, 70, 8, 76, 5, 15, 0, 98, 3, 60, 1, 13, 6, 54, 7, 33, 
    3, 62, 0, 12, 7, 29, 1, 76, 5, 34, 6, 27, 4,  4, 8, 55, 2, 34, 
    2, 37, 5, 95, 7, 43, 0, 55, 8, 41, 1, 17, 3, 22, 6, 93, 4, 72, 
    8, 26, 0, 85, 1, 66, 3, 34, 4, 94, 6, 25, 7, 43, 5, 88, 2, 23, 
    1, 25, 2, 81, 0, 14, 3, 98, 4, 24, 8, 10, 5,  9, 6, 17, 7, 87, 
    4, 45, 5, 71, 7, 68, 2,  3, 8, 92, 0, 69, 6, 58, 1, 70, 3, 36
  };
  const int q3768[] = {
    9, 9, // Number of jobs and machines
    0, 34, 8,  5, 4, 14, 5, 40, 6, 38, 7, 50, 2,  2, 1, 47, 3, 63, 
    8, 83, 3, 44, 2, 58, 1, 68, 0, 37, 6, 85, 7, 88, 4, 46, 5, 76, 
    2, 28, 5, 10, 7, 76, 3, 91, 1, 20, 8,  4, 4, 24, 0, 74, 6, 19, 
    8, 90, 2, 62, 3, 70, 4, 91, 0, 22, 1, 57, 5, 89, 6, 16, 7, 54, 
    7, 22, 3, 71, 8, 30, 1, 54, 5, 22, 0, 25, 6, 75, 4, 34, 2, 91, 
    6, 40, 2, 77, 3, 95, 1, 62, 5, 12, 7, 23, 0, 86, 4, 94, 8, 40, 
    4,  9, 5, 76, 2, 51, 8, 72, 3, 83, 0, 31, 6, 28, 1, 98, 7, 20, 
    8, 37, 6, 17, 0, 50, 2, 21, 1, 89, 4, 71, 3, 89, 7, 52, 5, 44, 
    1, 29, 4, 39, 6, 42, 5, 49, 3,  5, 0, 37, 7, 73, 8, 97, 2,  8
  };
  const int q3769[] = {
    9, 9, // Number of jobs and machines
    3,  2, 5,  4, 6, 62, 2, 53, 0, 89, 7, 57, 4, 49, 8, 48, 1, 23, 
    7, 15, 4, 45, 6, 39, 8, 18, 2, 42, 1, 40, 3, 44, 5, 63, 0, 24, 
    4, 97, 3, 13, 5,  9, 0, 41, 2, 43, 8, 99, 6, 27, 7, 42, 1, 70, 
    7, 42, 5, 15, 3, 60, 2, 50, 1, 80, 8, 76, 4, 73, 0, 56, 6, 49, 
    1,  6, 4, 62, 7, 56, 0, 68, 5, 83, 6, 57, 3, 69, 2, 92, 8, 71, 
    6, 22, 5, 15, 0, 16, 4, 88, 7, 93, 3, 91, 1, 72, 2, 88, 8, 14, 
    8, 63, 6, 59, 1, 54, 3, 40, 4, 76, 2, 69, 0, 13, 7, 27, 5, 39, 
    8, 68, 4, 88, 2, 28, 6, 91, 0, 16, 1, 96, 7, 54, 5, 40, 3, 50, 
    4, 98, 2, 45, 0, 21, 7, 15, 1,  4, 6, 11, 8, 88, 5, 37, 3, 33
  };
  const int q3770[] = {
    9, 9, // Number of jobs and machines
    3, 64, 5, 93, 1, 28, 7, 21, 6, 70, 8, 79, 2, 55, 0,  6, 4, 28, 
    7, 67, 1, 24, 0, 49, 8, 89, 2, 44, 5, 33, 4, 46, 6, 65, 3, 65, 
    6, 88, 1, 28, 8, 56, 3, 53, 0, 49, 7,  2, 5, 79, 2, 90, 4,  5, 
    6, 99, 8, 70, 3, 59, 0, 61, 7, 52, 1, 91, 2, 36, 4, 63, 5, 51, 
    4, 52, 6, 65, 1, 79, 0, 68, 3,  6, 5,  1, 7, 13, 2, 57, 8, 12, 
    5,  8, 6, 57, 2, 29, 1, 14, 3, 61, 0, 41, 7, 67, 8, 51, 4, 78, 
    3, 33, 0, 28, 7, 90, 8,  3, 1, 14, 2, 83, 4, 23, 6,  4, 5, 75, 
    4, 77, 1, 59, 2, 21, 5, 13, 8, 44, 3,  8, 6, 40, 0, 11, 7, 78, 
    1, 20, 6, 91, 5, 80, 2, 80, 3, 72, 4, 48, 0, 18, 8, 54, 7,  1
  };
  const int q3771[] = {
    9, 9, // Number of jobs and machines
    6, 64, 4, 61, 8, 72, 5, 51, 2, 14, 3, 76, 7, 72, 1, 99, 0, 86, 
    2, 70, 4, 68, 1, 67, 7, 98, 5, 17, 8, 58, 6, 58, 3,  1, 0, 35, 
    1, 28, 2, 88, 8,  8, 3, 78, 0, 86, 5,  6, 4,  8, 6, 47, 7, 72, 
    7, 19, 3, 70, 8, 13, 1,  7, 5,  9, 4, 98, 2, 80, 6, 32, 0, 67, 
    8, 40, 3, 99, 7, 15, 4, 44, 5, 82, 0, 14, 2, 80, 1, 89, 6, 19, 
    2, 57, 1,  2, 4, 75, 0, 77, 7, 38, 5, 37, 6, 42, 3, 41, 8, 95, 
    0, 95, 5, 37, 7,  5, 2, 13, 3, 67, 1, 78, 6, 68, 4, 85, 8, 14, 
    7, 82, 6, 92, 5, 24, 1, 68, 2, 44, 3,  5, 8, 73, 0, 38, 4, 89, 
    0, 55, 4, 34, 5, 40, 2, 71, 6, 82, 7,  2, 1, 92, 3, 43, 8, 15
  };
  const int q3772[] = {
    9, 9, // Number of jobs and machines
    2, 64, 5, 13, 4, 64, 7, 17, 3, 95, 8, 24, 6, 61, 0, 68, 1, 51, 
    2, 53, 4, 34, 7, 96, 5, 86, 8, 28, 1, 97, 3,  5, 0,  2, 6, 88, 
    2, 39, 0, 66, 1, 48, 4, 19, 8, 70, 6, 77, 5, 47, 7, 44, 3, 83, 
    0, 23, 6, 86, 4, 58, 3, 31, 7, 13, 2, 21, 1, 73, 5, 41, 8,  9, 
    3, 44, 6,  7, 4, 30, 1, 84, 0, 76, 7, 86, 2, 17, 5, 75, 8, 24, 
    8, 47, 6, 99, 4, 90, 7,  9, 1, 11, 0, 63, 2, 74, 3, 82, 5, 74, 
    6, 23, 0, 65, 8, 20, 4,  2, 2, 65, 7, 21, 3, 80, 1, 47, 5, 80, 
    0,  2, 4, 76, 8, 51, 1, 67, 5, 57, 6, 64, 7, 99, 2, 67, 3, 30, 
    2, 47, 8, 86, 5, 72, 7, 73, 1, 85, 0, 89, 4, 97, 6, 69, 3,  1
  };
  const int q3773[] = {
    9, 9, // Number of jobs and machines
    4, 17, 7, 15, 0, 30, 5, 36, 2, 63, 6, 72, 1, 33, 3, 76, 8, 90, 
    5, 10, 4, 16, 7, 43, 2, 13, 3, 46, 0, 73, 8, 47, 6, 14, 1, 79, 
    4,  9, 2, 21, 1, 71, 3, 93, 8, 93, 5, 51, 7, 36, 0, 40, 6, 43, 
    3, 89, 7, 46, 6, 36, 0, 13, 2, 28, 5, 56, 4, 24, 1, 86, 8,  9, 
    6, 59, 3, 28, 7, 36, 4, 22, 5, 89, 0, 11, 1, 39, 8, 10, 2, 38, 
    0, 19, 7, 43, 8, 46, 6, 77, 3, 21, 2, 92, 5, 39, 1,  5, 4, 44, 
    5, 84, 1, 38, 0, 43, 8, 91, 7, 92, 4, 85, 6, 52, 3, 90, 2, 32, 
    8, 24, 5, 20, 3, 96, 4, 82, 6, 55, 7, 36, 2,  6, 1, 18, 0, 14, 
    0, 59, 7, 22, 1,  5, 3, 63, 2, 19, 5, 39, 6, 38, 4, 86, 8, 10
  };
  const int q3774[] = {
    9, 9, // Number of jobs and machines
    1, 83, 3, 76, 0, 84, 8, 56, 2, 68, 7, 43, 5, 76, 6, 53, 4, 47, 
    2, 37, 5, 29, 0, 59, 1, 76, 4,  9, 8, 88, 7, 84, 3, 29, 6, 28, 
    4,  6, 2, 65, 0, 78, 1, 84, 6, 74, 7, 81, 5, 33, 8, 16, 3, 35, 
    2, 85, 6, 70, 3, 85, 5, 56, 4, 30, 7, 63, 1, 98, 8, 43, 0, 13, 
    5, 97, 6, 44, 4, 35, 2, 30, 0,  6, 3, 78, 8, 82, 1, 38, 7, 49, 
    3,  2, 7,  9, 1, 37, 4, 25, 8, 63, 5, 67, 0, 72, 2, 33, 6, 40, 
    6, 42, 0, 42, 1,  3, 2,  1, 3, 67, 8, 12, 4, 98, 5, 42, 7, 56, 
    6, 84, 3, 19, 5, 83, 7, 80, 4, 11, 8,  9, 0, 97, 2, 52, 1, 64, 
    6, 14, 5, 74, 1, 76, 2, 84, 3, 59, 0, 70, 7, 80, 8, 40, 4, 20
  };
  const int q3775[] = {
    9, 9, // Number of jobs and machines
    0, 69, 7, 29, 6, 34, 2, 20, 4, 24, 8, 40, 1, 17, 5, 68, 3, 39, 
    3, 92, 5, 22, 4, 56, 1, 54, 0, 97, 7, 23, 6, 95, 8, 63, 2, 24, 
    1, 76, 6,  8, 2, 29, 7,  4, 3,  3, 4, 38, 5, 44, 0, 24, 8, 17, 
    7, 60, 4, 62, 3, 50, 1, 86, 6, 28, 5, 29, 0, 37, 2, 99, 8, 58, 
    4, 29, 0, 56, 7, 16, 5, 32, 2, 34, 8, 97, 1, 98, 6, 96, 3, 51, 
    6, 97, 3, 77, 0, 31, 2, 12, 7, 51, 5, 17, 8,  2, 1, 17, 4,  9, 
    3, 95, 0, 70, 7, 63, 8, 73, 6, 33, 4, 16, 5, 10, 2,  7, 1,  4, 
    1, 43, 2, 30, 7, 72, 6,  5, 5, 38, 0, 50, 4, 44, 3, 27, 8, 21, 
    3, 68, 4, 83, 5, 18, 7,  8, 2, 39, 1, 26, 6, 47, 0, 74, 8, 56
  };
  const int q3776[] = {
    9, 9, // Number of jobs and machines
    1, 42, 3, 80, 2, 78, 7, 75, 0, 80, 6, 63, 8, 68, 5, 58, 4,  7, 
    5, 45, 1, 40, 0, 94, 8, 63, 6, 80, 4, 39, 7, 15, 2, 59, 3,  5, 
    0, 92, 6, 29, 4, 34, 3, 15, 1, 30, 7, 64, 5, 51, 8,  9, 2, 23, 
    5, 35, 2, 91, 1, 10, 6, 96, 0, 25, 4,  5, 3, 93, 8, 44, 7, 70, 
    3, 36, 5, 73, 6, 48, 7, 64, 8, 66, 4, 97, 2, 69, 1,  6, 0, 15, 
    2, 94, 1, 74, 4, 83, 7, 84, 3, 42, 5, 10, 6, 37, 8, 45, 0,  5, 
    5, 63, 0, 66, 7, 60, 4,  2, 2, 80, 8, 33, 1, 23, 3, 43, 6, 81, 
    8, 40, 0, 74, 6, 85, 2, 27, 7, 18, 1,  2, 4, 21, 5, 38, 3, 26, 
    5, 91, 1, 23, 2, 56, 3, 61, 7, 83, 4, 57, 8, 55, 6, 34, 0, 93
  };
  const int q3777[] = {
    9, 9, // Number of jobs and machines
    4, 21, 3, 98, 2, 17, 5, 74, 0, 53, 1, 78, 6,  3, 7, 29, 8, 48, 
    3, 70, 6, 16, 0, 65, 7, 89, 5, 44, 1, 89, 4, 28, 8, 41, 2, 79, 
    7, 32, 3, 61, 4, 99, 5, 90, 0, 76, 2, 22, 1, 77, 6, 95, 8, 46, 
    1, 11, 8, 91, 2, 96, 6, 83, 7, 21, 5, 21, 3, 19, 4, 98, 0, 77, 
    0, 20, 7, 45, 5, 66, 6, 30, 2, 79, 8, 74, 4, 95, 3, 46, 1, 10, 
    8, 72, 3, 60, 0, 45, 1, 96, 5, 44, 6, 38, 4, 36, 2, 91, 7,  6, 
    1, 42, 8, 72, 7, 48, 5, 67, 4, 94, 6, 98, 3, 45, 0, 34, 2, 63, 
    8, 84, 0, 47, 2, 34, 6, 58, 4,  1, 5, 58, 1, 34, 7, 23, 3, 81, 
    4, 58, 1, 44, 6, 72, 3, 40, 5, 95, 8, 79, 0, 12, 2, 28, 7, 96
  };
  const int q3778[] = {
    9, 9, // Number of jobs and machines
    8, 85, 7, 48, 0, 34, 3,  6, 6, 55, 5, 40, 4, 32, 2, 33, 1, 91, 
    0, 44, 6, 38, 7, 58, 2, 48, 5, 21, 8,  2, 1, 67, 4, 64, 3, 68, 
    4, 45, 5, 36, 8, 71, 3, 70, 1, 93, 6, 40, 7, 46, 0, 35, 2, 96, 
    5, 93, 6,  3, 7, 10, 2, 84, 0, 75, 1, 60, 4, 68, 8, 84, 3, 41, 
    8, 60, 1,  9, 3, 65, 4, 99, 6, 15, 2, 67, 5,  5, 0, 17, 7, 53, 
    4, 16, 6, 87, 8, 67, 7, 96, 3, 55, 5, 76, 0, 37, 1, 65, 2, 34, 
    7, 35, 6, 73, 3, 84, 5, 57, 2, 22, 1, 49, 4, 59, 8, 97, 0, 86, 
    6, 18, 8, 55, 1, 84, 7, 81, 2, 27, 3, 89, 4,  5, 5, 87, 0,  9, 
    2, 29, 5, 71, 3, 33, 1, 56, 0, 91, 4, 67, 6, 48, 7, 28, 8, 63
  };
  const int q3779[] = {
    9, 9, // Number of jobs and machines
    0, 39, 2, 86, 1, 31, 5, 29, 8, 29, 4, 40, 3, 76, 7, 96, 6, 75, 
    7, 54, 8, 16, 3, 19, 2, 10, 6, 96, 4, 18, 5, 13, 1, 98, 0,  6, 
    8, 83, 7, 38, 6, 21, 1, 51, 0, 18, 2, 18, 4, 78, 3, 54, 5, 43, 
    5, 55, 3, 97, 8, 86, 0, 79, 4, 63, 6, 72, 7, 72, 1, 63, 2, 14, 
    1, 25, 7, 32, 4,  7, 2, 88, 6, 81, 3, 89, 0, 50, 8, 51, 5, 41, 
    0, 82, 7, 80, 4, 44, 8, 28, 2,  5, 1, 42, 6, 63, 5, 67, 3, 70, 
    3, 97, 6, 34, 4, 98, 8, 13, 1, 66, 2,  9, 0, 35, 5, 20, 7,  6, 
    4, 93, 2, 48, 5, 66, 7, 43, 3, 13, 0, 11, 8,  1, 1,  4, 6, 24, 
    5, 65, 0, 86, 1, 85, 3, 10, 6, 17, 4, 66, 8, 46, 7, 14, 2,  3
  };
  const int q3780[] = {
    9, 9, // Number of jobs and machines
    8, 33, 2, 22, 1, 89, 0, 91, 4, 21, 3, 47, 5, 86, 7, 13, 6, 77, 
    5, 63, 2, 30, 7, 88, 3, 73, 4, 39, 0, 89, 6, 73, 1, 65, 8, 57, 
    3, 11, 8, 65, 1, 79, 4, 74, 5, 39, 0, 23, 7, 32, 2, 71, 6, 69, 
    7, 77, 6,  3, 1, 78, 0, 39, 4, 57, 2, 56, 3, 12, 8, 75, 5,  7, 
    0, 77, 7, 48, 1, 17, 5, 30, 2, 28, 3, 40, 8, 26, 6, 49, 4, 48, 
    0, 59, 4,  7, 3, 15, 1, 30, 8, 90, 7,  2, 2, 92, 5,  9, 6, 96, 
    4, 20, 6, 36, 2, 70, 8, 25, 3,  9, 7, 22, 1, 48, 5,  4, 0, 27, 
    6, 62, 2,  5, 4, 53, 7, 87, 0, 82, 8, 90, 5, 97, 3,  2, 1, 89, 
    3, 32, 1, 61, 0, 94, 7, 39, 6, 96, 2, 85, 4, 26, 8, 14, 5, 36
  };
  const int q3781[] = {
    9, 9, // Number of jobs and machines
    8, 34, 3, 90, 0, 83, 7,  9, 2, 81, 4, 15, 5, 78, 1, 51, 6, 36, 
    8,  6, 7,  4, 3, 39, 5, 85, 4, 23, 2, 72, 0, 21, 6, 25, 1, 24, 
    7, 19, 1, 71, 8, 44, 2, 92, 6, 68, 0, 67, 3, 65, 4, 19, 5, 51, 
    3, 44, 4, 71, 8, 97, 7, 11, 1, 11, 0,  5, 5, 51, 2, 63, 6, 36, 
    0,  6, 6, 57, 2, 19, 3, 48, 8, 35, 7, 93, 1, 97, 4, 16, 5, 53, 
    1, 43, 6, 63, 8, 90, 3, 87, 5, 80, 7,  4, 0, 18, 4, 88, 2, 52, 
    7, 10, 0, 35, 8, 21, 6, 45, 1, 16, 3,  2, 4, 21, 5, 83, 2, 78, 
    1,  1, 2, 20, 4, 88, 0,  6, 7, 69, 6, 42, 5, 30, 3, 90, 8, 80, 
    0, 37, 8, 43, 6,  6, 1, 84, 3, 45, 7, 84, 2, 48, 5, 93, 4,  3
  };
  const int q3782[] = {
    9, 9, // Number of jobs and machines
    5, 45, 2, 83, 1, 47, 4, 53, 0, 31, 3, 88, 7, 94, 6,  3, 8, 11, 
    8, 13, 5, 75, 4, 74, 2, 75, 1, 19, 3, 11, 6, 84, 7, 90, 0, 49, 
    2, 62, 7, 86, 8, 87, 5,  5, 6, 76, 0, 73, 1, 92, 4, 27, 3, 75, 
    3, 62, 0, 32, 5, 94, 8, 27, 1, 20, 7, 33, 6,  7, 4, 35, 2, 22, 
    2, 75, 8, 33, 3, 23, 6,  5, 7, 56, 5, 51, 0, 22, 1, 98, 4,  8, 
    0, 60, 6, 63, 7, 21, 1, 50, 8, 58, 4, 54, 3,  1, 2, 38, 5, 40, 
    5,  2, 1, 36, 3, 60, 2, 45, 6, 92, 8, 79, 0, 83, 7, 74, 4,  9, 
    8, 17, 5, 31, 0, 50, 4, 67, 6,  9, 7, 37, 2, 34, 3, 92, 1, 23, 
    6, 99, 0, 79, 2,  2, 5, 23, 1, 62, 8, 11, 7, 93, 3,  5, 4, 45
  };
  const int q3783[] = {
    9, 9, // Number of jobs and machines
    7, 84, 1, 44, 8, 72, 5, 67, 0, 92, 6, 55, 4, 66, 3, 81, 2, 41, 
    8, 72, 2, 35, 7,  3, 1, 35, 5, 91, 4, 29, 6, 91, 0, 27, 3, 21, 
    8,  1, 5, 81, 6, 89, 7,  9, 4, 35, 2, 82, 3, 33, 0, 68, 1, 76, 
    7, 78, 4, 25, 8, 10, 5, 39, 1,  2, 0, 65, 6, 90, 2, 93, 3, 19, 
    2, 59, 1, 85, 3, 29, 8, 77, 7,  7, 5, 60, 6, 14, 4, 96, 0, 16, 
    7, 90, 2, 46, 6, 23, 5, 90, 3, 74, 8, 83, 1, 33, 0, 39, 4, 59, 
    1, 56, 5, 48, 4, 74, 7, 66, 8, 13, 6, 60, 0, 37, 3, 43, 2, 67, 
    3, 72, 7, 81, 6, 45, 2, 79, 5, 85, 0, 85, 4, 14, 8, 61, 1, 23, 
    4, 26, 2, 72, 8, 40, 6, 73, 1, 21, 5, 39, 3, 47, 0, 88, 7, 65
  };
  const int q3784[] = {
    9, 9, // Number of jobs and machines
    8, 14, 0, 99, 1, 21, 2, 82, 7, 34, 6, 98, 4, 73, 5, 58, 3, 28, 
    0, 17, 3, 20, 1,  3, 5, 79, 7, 35, 8,  4, 6, 76, 2, 68, 4, 78, 
    1, 27, 8, 79, 6, 66, 0, 22, 4, 39, 3, 87, 5, 40, 7, 64, 2, 10, 
    1, 61, 6, 15, 7, 19, 3, 35, 0, 17, 2, 17, 4, 12, 5, 73, 8, 37, 
    0, 46, 1, 44, 5, 49, 7, 64, 3, 96, 4, 65, 8, 56, 6, 98, 2, 92, 
    6, 52, 1, 66, 5, 55, 7, 96, 2, 29, 0,  9, 3, 37, 8, 89, 4, 86, 
    2, 39, 5, 86, 3, 49, 6, 63, 0, 35, 1, 45, 7, 73, 8, 66, 4, 10, 
    7,  3, 1, 85, 4, 57, 5, 13, 3, 35, 0, 87, 6, 10, 8, 72, 2,  7, 
    7, 42, 3,  4, 0, 49, 1, 81, 6, 98, 8, 87, 5, 35, 2,  3, 4, 73
  };
  const int q3785[] = {
    9, 9, // Number of jobs and machines
    5, 69, 8, 72, 6, 80, 7, 81, 0, 62, 2, 45, 3, 82, 4, 12, 1, 56, 
    2, 77, 1, 76, 0, 34, 4, 85, 8, 24, 7,  2, 6, 74, 3, 89, 5, 94, 
    0, 21, 3, 71, 6, 83, 2, 57, 8, 96, 4, 78, 7, 65, 1, 69, 5, 85, 
    5, 38, 0,  9, 6, 88, 7,  8, 2, 37, 1, 36, 3, 69, 8, 11, 4, 37, 
    0, 76, 1, 88, 5, 28, 8, 85, 3, 24, 2, 43, 6, 75, 4, 80, 7, 43, 
    4, 93, 7, 45, 8, 38, 2, 52, 5, 53, 6, 54, 3, 93, 0, 75, 1, 15, 
    7, 56, 1, 19, 5, 69, 6, 25, 4,  8, 3, 80, 2, 52, 8,  8, 0, 51, 
    6, 21, 5, 41, 0, 13, 2, 63, 1, 32, 3, 59, 4, 30, 7, 55, 8, 24, 
    8, 35, 4, 26, 2, 63, 1, 57, 7, 93, 5, 65, 6, 37, 0,  3, 3, 33
  };
  const int q3786[] = {
    9, 9, // Number of jobs and machines
    3, 77, 6,  9, 7, 25, 2, 67, 5, 84, 1, 24, 8, 17, 4, 97, 0, 97, 
    2, 18, 7, 22, 0,  3, 1, 37, 5,  1, 3, 77, 4, 62, 6, 89, 8, 66, 
    1,  7, 2, 36, 6, 99, 8, 26, 7,  8, 5, 71, 0, 27, 4, 24, 3, 99, 
    8, 35, 5, 55, 1, 61, 2, 58, 6, 21, 7, 20, 0, 89, 4, 24, 3, 26, 
    1, 40, 6, 82, 4, 60, 3, 38, 0, 50, 5, 32, 2, 97, 7, 20, 8, 42, 
    1, 83, 0, 53, 7, 34, 4, 33, 8, 43, 5, 55, 3, 42, 2, 35, 6, 95, 
    1, 31, 2, 31, 8, 96, 7, 47, 5, 99, 6, 35, 4, 27, 0, 22, 3, 95, 
    4, 34, 7,  4, 5,  2, 2, 12, 1, 29, 3, 65, 6, 99, 8, 59, 0,  9, 
    7, 30, 2, 21, 0, 90, 1, 79, 4, 69, 6, 43, 8,  8, 3, 33, 5, 26
  };
  const int q3787[] = {
    9, 9, // Number of jobs and machines
    3, 50, 7, 46, 1, 12, 4, 75, 5, 68, 0, 23, 6,  2, 8, 25, 2, 97, 
    3, 72, 0, 60, 8, 45, 4, 53, 1, 18, 6, 10, 2, 57, 5, 33, 7, 55, 
    6, 14, 1, 29, 4, 87, 7, 12, 0, 84, 2, 97, 3, 99, 8, 85, 5, 45, 
    5,  5, 6, 24, 8, 46, 7, 80, 1, 43, 4, 63, 3, 22, 2,  5, 0, 38, 
    4, 55, 1, 57, 7, 18, 0, 23, 5, 50, 8, 95, 3, 38, 2, 79, 6, 42, 
    6, 50, 7, 21, 1, 87, 0,  9, 2, 75, 4, 13, 3, 70, 5, 78, 8, 85, 
    8, 22, 5, 41, 4, 11, 3,  6, 1, 59, 7, 78, 2,  6, 0, 91, 6, 14, 
    6, 43, 7, 50, 8, 88, 4, 61, 5, 69, 2, 94, 3, 58, 0, 33, 1, 35, 
    3, 92, 7, 40, 6, 35, 1, 17, 8, 54, 4, 36, 0, 36, 2, 95, 5, 46
  };
  const int q3788[] = {
    9, 9, // Number of jobs and machines
    8, 71, 6,  6, 5, 39, 2, 28, 1, 38, 7, 62, 0, 34, 4, 45, 3, 89, 
    3, 85, 2, 48, 5,  2, 0, 70, 8, 23, 4, 21, 7, 12, 6, 65, 1, 42, 
    1, 50, 0, 53, 7, 31, 3, 48, 2, 67, 6, 15, 8, 10, 5, 68, 4, 28, 
    0, 64, 5,  1, 1, 64, 4, 63, 2, 58, 3, 85, 8, 40, 7, 15, 6, 42, 
    0, 64, 2, 62, 8, 76, 6, 15, 7, 13, 3, 84, 1, 15, 4, 81, 5, 10, 
    0, 14, 8, 92, 3, 30, 6,  7, 2, 42, 5, 91, 4, 19, 7, 48, 1, 86, 
    3, 74, 1,  7, 6, 53, 4, 36, 8, 33, 7, 56, 2, 43, 0, 33, 5, 10, 
    0, 15, 4, 38, 7, 10, 5, 43, 3, 37, 8, 37, 1, 75, 2, 48, 6, 72, 
    1, 91, 5, 29, 7, 47, 8, 88, 2, 51, 3, 41, 0, 15, 4, 66, 6, 34
  };
  const int q3789[] = {
    9, 9, // Number of jobs and machines
    4, 37, 2, 31, 0, 80, 8, 19, 6, 10, 7, 74, 3, 86, 5, 40, 1, 11, 
    1, 18, 5, 31, 7, 91, 0, 41, 4, 22, 6, 96, 8, 75, 2, 39, 3, 28, 
    8, 32, 2, 72, 3, 26, 1, 84, 5, 94, 7, 75, 4, 62, 6, 51, 0, 35, 
    7, 41, 1, 11, 6, 93, 0, 16, 4, 33, 2, 23, 8, 66, 5, 91, 3,  2, 
    2, 48, 5, 55, 3, 15, 1, 37, 7, 20, 6, 60, 8, 50, 0, 27, 4, 92, 
    2, 14, 4, 47, 1, 44, 7, 12, 5, 89, 0, 76, 3, 86, 8, 55, 6, 33, 
    7, 97, 6, 13, 2, 32, 1, 47, 4,  9, 0, 17, 3, 85, 5, 54, 8, 46, 
    5,  1, 8, 22, 3, 99, 4, 63, 2, 69, 0, 70, 1, 94, 6, 37, 7, 22, 
    3, 84, 6, 51, 2, 32, 4, 21, 5, 62, 0, 23, 1, 78, 7, 36, 8, 56
  };
  const int q3790[] = {
    9, 9, // Number of jobs and machines
    7, 25, 4, 20, 3, 42, 8, 48, 5, 48, 2,  1, 1,  2, 0, 94, 6, 64, 
    0, 85, 1, 11, 3, 93, 2, 99, 8, 92, 4, 77, 5,  7, 6, 72, 7, 10, 
    5, 77, 8, 89, 2, 89, 6,  9, 3, 98, 7, 35, 4, 24, 1,  8, 0, 76, 
    4, 71, 6, 65, 3, 64, 7, 60, 0, 48, 1, 41, 8, 82, 5, 69, 2, 71, 
    1,  1, 0, 29, 3, 96, 5,  6, 8, 54, 7, 95, 4, 15, 6, 43, 2,  9, 
    0, 59, 4, 96, 5, 72, 6,  6, 2, 52, 7, 27, 3, 72, 1, 53, 8,  3, 
    6,  7, 0, 87, 5, 35, 2, 94, 4, 49, 3, 50, 8, 31, 1, 92, 7, 60, 
    0, 66, 3, 78, 7, 14, 4, 49, 5, 72, 6, 13, 8, 32, 1, 58, 2, 12, 
    4, 57, 7, 38, 8, 72, 3, 37, 0, 12, 6, 17, 1, 95, 5,  5, 2, 71
  };
  const int q3791[] = {
    9, 9, // Number of jobs and machines
    1, 43, 5, 82, 8, 35, 3, 16, 0, 92, 6, 74, 2, 15, 4, 89, 7, 80, 
    8, 14, 4, 34, 5, 74, 2, 98, 3, 54, 0, 72, 6, 44, 1, 62, 7, 59, 
    0, 88, 8,  4, 7, 99, 4, 91, 5, 56, 1, 15, 6,  7, 2, 11, 3, 81, 
    4, 85, 8, 52, 1,  3, 6,  1, 3, 26, 7, 96, 0, 45, 2, 63, 5, 28, 
    4,  7, 6, 37, 8, 18, 1, 33, 0, 48, 7, 90, 5, 16, 2, 79, 3, 67, 
    2, 76, 3, 33, 8, 75, 0, 59, 7, 28, 5, 47, 6, 59, 1, 88, 4, 59, 
    5, 34, 6,  4, 0, 91, 8, 57, 2, 10, 7, 79, 1, 94, 3, 54, 4, 41, 
    1, 64, 3, 81, 8,  4, 7, 90, 5, 84, 6,  8, 4,  8, 2, 46, 0, 58, 
    4, 82, 8, 25, 0, 22, 7, 92, 1, 67, 6, 45, 3, 25, 5, 50, 2, 27
  };
  const int q3792[] = {
    9, 9, // Number of jobs and machines
    8, 73, 3, 24, 2, 84, 1, 19, 5, 21, 4, 76, 0, 63, 6, 10, 7, 54, 
    5, 49, 3, 18, 1, 72, 4, 19, 6, 92, 7, 16, 8, 43, 0, 60, 2, 57, 
    7, 99, 4, 87, 6,  4, 3, 68, 2, 58, 8, 87, 1, 57, 5, 22, 0, 97, 
    3, 53, 0, 40, 7, 42, 8, 34, 4,  3, 5, 61, 1, 52, 2,  6, 6, 59, 
    1, 16, 2, 21, 8, 51, 3, 12, 5, 40, 6, 83, 0,  9, 7, 95, 4, 16, 
    3, 36, 2, 42, 4, 81, 0,  3, 7, 37, 6, 10, 5, 86, 1, 56, 8, 59, 
    0, 71, 1,  6, 3, 43, 6, 25, 2,  4, 4, 43, 5, 49, 8, 54, 7, 23, 
    0, 44, 3, 47, 4, 22, 8, 67, 2, 96, 5, 60, 7, 53, 6, 10, 1, 94, 
    0,  7, 8, 67, 7, 51, 2, 47, 6, 71, 1, 82, 3, 75, 4,  1, 5, 79
  };
  const int q3793[] = {
    9, 9, // Number of jobs and machines
    6,  3, 8, 68, 2, 37, 3, 26, 7, 21, 0, 53, 1, 46, 5, 82, 4, 72, 
    4, 61, 2, 26, 7, 28, 5, 87, 8, 49, 6, 87, 1, 84, 3, 88, 0, 65, 
    0, 17, 7,  6, 5, 24, 8, 67, 1, 11, 4, 11, 6, 25, 3, 85, 2, 56, 
    8, 64, 3, 27, 0, 46, 7, 74, 5,  6, 4, 86, 1, 67, 6, 16, 2, 92, 
    3,  5, 5, 94, 7, 46, 8, 45, 2, 93, 4, 99, 6, 90, 0,  6, 1, 61, 
    2,  6, 3,  4, 5, 15, 7, 22, 1, 93, 4, 17, 6, 62, 8, 81, 0, 57, 
    7,  6, 3, 90, 5, 44, 1, 34, 4, 24, 6, 42, 0, 19, 8, 22, 2, 75, 
    8, 26, 0, 64, 6, 12, 1, 41, 5, 12, 3, 35, 2, 39, 7, 55, 4, 41, 
    5, 35, 7, 81, 2, 23, 1, 76, 8, 24, 4,  2, 3, 47, 0, 60, 6, 95
  };
  const int q3794[] = {
    9, 9, // Number of jobs and machines
    2, 60, 8, 35, 3, 70, 6, 82, 4, 97, 7, 64, 1,  3, 5, 51, 0, 24, 
    0, 10, 2, 37, 3, 22, 7, 57, 1, 68, 8,  6, 6, 16, 5, 13, 4, 89, 
    1, 91, 6, 65, 7, 36, 5, 58, 3, 21, 2, 81, 4, 81, 0, 79, 8, 79, 
    5, 13, 2, 41, 4, 75, 7, 61, 6, 23, 3, 47, 8, 36, 0, 68, 1, 26, 
    2, 28, 3, 29, 0, 23, 4, 61, 5, 69, 1, 53, 6, 44, 7,  6, 8, 79, 
    4, 87, 6, 13, 0, 94, 8, 11, 3, 15, 1, 88, 2, 45, 5, 50, 7, 83, 
    4, 89, 5, 49, 0,  5, 6,  1, 1, 57, 7, 27, 8,  4, 2, 21, 3,  2, 
    5, 13, 2, 42, 3, 25, 7, 26, 6, 15, 8, 53, 0, 40, 1, 75, 4, 17, 
    5, 55, 4, 23, 6, 32, 7, 81, 0, 24, 2, 76, 3,  9, 1, 57, 8, 70
  };
  const int q3795[] = {
    9, 9, // Number of jobs and machines
    8, 87, 7, 34, 5, 36, 1, 71, 0, 23, 6, 82, 4, 35, 2,  2, 3,  5, 
    6, 49, 5, 42, 7, 64, 1, 38, 8, 57, 4, 70, 0, 53, 2, 28, 3, 95, 
    0, 26, 1, 17, 2, 60, 4, 19, 7, 82, 8, 75, 5, 44, 3,  1, 6, 89, 
    6, 65, 0, 53, 8, 45, 1,  7, 2, 12, 3, 56, 4, 33, 5, 23, 7, 30, 
    1, 25, 6, 54, 4, 56, 7, 96, 0, 42, 5, 65, 8, 40, 3, 77, 2, 37, 
    3, 64, 5, 67, 6, 41, 2, 48, 7, 72, 0, 63, 1,  8, 4, 77, 8, 76, 
    8, 99, 2, 48, 4, 59, 6, 35, 7, 13, 3, 12, 0, 84, 5, 70, 1, 69, 
    7, 96, 2, 88, 4, 79, 5, 37, 3, 93, 1, 36, 6, 33, 8, 28, 0,  4, 
    1, 91, 6, 88, 0, 67, 8, 67, 7, 98, 3, 18, 4, 96, 2, 86, 5, 34
  };
  const int q3796[] = {
    9, 9, // Number of jobs and machines
    1, 90, 8, 38, 3, 64, 4, 59, 5, 94, 6, 92, 7, 93, 2, 80, 0, 62, 
    1, 52, 7, 76, 3, 59, 2, 22, 6, 68, 8, 10, 5, 28, 0, 97, 4, 59, 
    1,  6, 6,  6, 7, 32, 5, 26, 2, 49, 0, 80, 8, 97, 3, 75, 4, 26, 
    7,  3, 8, 14, 1, 86, 6, 86, 5, 34, 4,  8, 0, 17, 2, 32, 3, 76, 
    8, 13, 2, 26, 3, 10, 6, 12, 1, 64, 7, 29, 0, 65, 5, 29, 4,  6, 
    7, 90, 2, 52, 1, 83, 0, 83, 5, 48, 6, 97, 4, 26, 8, 33, 3, 77, 
    1, 35, 7, 57, 4, 86, 5, 30, 2, 44, 0, 36, 8, 11, 6, 36, 3, 54, 
    6, 46, 0,  3, 3,  9, 2, 82, 4,  7, 7, 89, 1, 59, 8, 95, 5, 19, 
    4, 71, 6,  2, 0, 12, 7, 58, 1, 21, 5, 97, 3, 90, 2, 68, 8, 73
  };
  const int q3797[] = {
    9, 9, // Number of jobs and machines
    0, 18, 5, 38, 1, 87, 2, 88, 3, 78, 4, 73, 6, 11, 7,  3, 8, 90, 
    4, 30, 0, 73, 6, 81, 2,  9, 7, 24, 1, 54, 8, 42, 5, 71, 3, 88, 
    0, 36, 1, 40, 2, 35, 6, 86, 7, 96, 8, 66, 4, 72, 3, 67, 5, 78, 
    3, 43, 7, 29, 4, 15, 6, 91, 8, 61, 0, 53, 2, 49, 1, 81, 5, 71, 
    1, 47, 2, 18, 5, 81, 7, 72, 8, 89, 6, 24, 0, 35, 4, 96, 3, 29, 
    6, 36, 1, 11, 2, 15, 8, 51, 4, 10, 7, 34, 3, 89, 0,  1, 5, 52, 
    3, 39, 5, 51, 2, 76, 1, 60, 0, 51, 8, 78, 7, 65, 4,  7, 6, 69, 
    2, 13, 0, 52, 8,  6, 4, 97, 3, 77, 7, 25, 5, 20, 1, 49, 6, 92, 
    1, 72, 5, 12, 2, 81, 7, 45, 0, 44, 8, 16, 6, 28, 4, 28, 3, 53
  };
  const int q3798[] = {
    9, 9, // Number of jobs and machines
    3, 28, 6, 75, 5, 96, 8, 16, 2, 79, 7, 13, 1, 14, 4, 44, 0, 23, 
    5,  9, 1, 73, 8, 61, 2, 94, 6, 99, 4, 46, 0, 62, 7, 49, 3, 68, 
    7, 68, 5, 86, 0, 17, 2, 31, 1, 38, 4, 33, 6, 31, 8, 35, 3, 76, 
    0, 90, 1, 60, 2,  2, 8, 81, 4, 58, 6,  1, 5, 87, 3, 23, 7, 12, 
    4, 96, 1,  3, 6, 65, 8, 16, 7, 50, 5, 66, 3, 49, 0, 67, 2, 15, 
    7, 99, 8, 74, 1, 41, 3, 88, 5, 74, 4, 45, 6, 43, 0, 38, 2, 11, 
    6, 37, 7,  1, 5, 15, 8,  7, 0, 86, 1, 56, 3, 54, 2, 82, 4, 96, 
    6, 22, 0, 54, 3, 80, 7, 68, 1, 29, 8, 74, 4, 61, 2, 60, 5, 61, 
    7,  2, 3, 30, 8, 21, 6, 50, 1, 94, 4, 94, 2, 36, 5, 95, 0, 14
  };
  const int q3799[] = {
    9, 9, // Number of jobs and machines
    8, 96, 3, 31, 4, 37, 1, 78, 0, 52, 6,  3, 5, 90, 2, 90, 7, 19, 
    3, 23, 5, 34, 6,  6, 7, 73, 2, 92, 8, 88, 4, 17, 1, 94, 0, 23, 
    5, 56, 1, 69, 2, 30, 0, 67, 8, 40, 4, 54, 7,  5, 6, 97, 3, 37, 
    4, 98, 7, 45, 6, 59, 0, 80, 3, 33, 2, 81, 5, 15, 8, 50, 1,  4, 
    1, 11, 2,  8, 0, 89, 3, 15, 7, 12, 8, 67, 5, 21, 4, 61, 6, 92, 
    2, 31, 4,  6, 1, 13, 7, 92, 5, 83, 0, 47, 8, 97, 6, 47, 3, 89, 
    6, 26, 2, 32, 3,  2, 5, 17, 1, 14, 8, 72, 0, 98, 7, 65, 4, 89, 
    8, 31, 1, 84, 5, 76, 0, 98, 4, 25, 6, 51, 3, 77, 2, 25, 7, 39, 
    6, 31, 4, 77, 3, 74, 5, 62, 1,  5, 7, 93, 0, 56, 8, 10, 2, 19
  };
  const int q3800[] = {
    9, 9, // Number of jobs and machines
    3, 58, 0, 76, 8, 88, 6, 61, 2, 65, 4,  8, 5,  2, 7, 94, 1, 58, 
    0, 49, 5, 27, 6, 47, 4,  4, 1, 59, 8, 93, 2, 72, 7, 86, 3, 16, 
    1,  8, 6, 20, 8, 11, 7, 53, 0,  8, 2, 87, 3, 91, 4, 46, 5, 86, 
    5, 71, 7, 12, 6, 74, 1, 14, 0, 19, 8, 15, 3, 54, 2, 25, 4,  2, 
    3, 46, 8, 41, 4, 40, 6, 72, 1,  8, 7, 49, 5, 52, 2, 83, 0,  2, 
    8, 23, 3, 59, 1, 50, 0, 91, 2, 47, 4, 28, 5, 93, 7, 28, 6, 29, 
    5, 47, 4, 16, 1, 43, 3, 93, 8,  6, 2, 18, 6, 95, 7, 72, 0, 15, 
    4, 90, 0, 84, 5, 38, 2, 86, 8, 45, 6, 19, 3, 84, 1, 51, 7, 67, 
    6, 61, 4, 18, 2,  7, 1, 14, 5, 74, 8, 93, 7, 47, 0, 53, 3, 86
  };
  const int q3801[] = {
    9, 9, // Number of jobs and machines
    7, 59, 1, 53, 2, 83, 3, 17, 8, 80, 4, 34, 5,  3, 6, 31, 0, 46, 
    7, 33, 8, 56, 3, 70, 6, 69, 1, 21, 0, 69, 2, 33, 5, 71, 4, 45, 
    6, 44, 1,  2, 8, 21, 5, 15, 2, 15, 4,  6, 7, 93, 3, 57, 0,  7, 
    0, 75, 1, 83, 3, 68, 8, 74, 2, 62, 6, 21, 5, 38, 4, 34, 7, 71, 
    8, 10, 1, 98, 6,  7, 3,  4, 5, 18, 0, 84, 4, 38, 2, 41, 7, 32, 
    1, 66, 6, 20, 5,  9, 0, 66, 2, 54, 3, 64, 8, 75, 4, 88, 7, 29, 
    5, 82, 0, 59, 2,  1, 7, 79, 1, 29, 8,  3, 4, 40, 6, 83, 3, 54, 
    8,  1, 0, 50, 3, 76, 6, 70, 5, 68, 4, 98, 7, 51, 2, 56, 1, 23, 
    1,  8, 2, 61, 5, 71, 7, 39, 0, 31, 8, 37, 4, 48, 6, 84, 3,  9
  };
  const int q3802[] = {
    9, 9, // Number of jobs and machines
    2, 20, 7, 18, 1, 79, 6, 43, 0, 24, 3, 51, 5,  8, 4, 84, 8, 35, 
    8, 15, 0, 64, 7, 69, 1, 76, 6, 24, 5, 14, 4, 21, 2, 59, 3,  1, 
    7, 54, 8, 58, 0, 84, 6, 62, 5, 28, 1, 78, 3, 72, 4, 35, 2, 47, 
    3, 82, 6, 39, 5, 61, 2, 18, 7, 77, 8, 71, 0, 20, 1, 46, 4, 17, 
    3, 27, 8, 64, 1, 33, 5,  9, 7, 76, 6, 36, 0, 36, 4, 36, 2,  4, 
    3, 70, 4, 85, 7, 62, 0,  9, 5, 35, 6, 48, 2, 83, 8, 72, 1, 11, 
    8, 58, 2, 30, 7, 16, 5, 61, 3, 24, 0, 22, 1,  7, 6, 19, 4, 57, 
    6,  9, 8,  3, 1,  6, 4, 47, 3, 45, 0, 10, 7, 51, 2, 50, 5,  9, 
    2, 94, 8, 46, 0, 40, 4, 19, 7, 51, 6, 93, 1, 82, 5, 85, 3, 52
  };
  const int q3803[] = {
    9, 9, // Number of jobs and machines
    4, 87, 6, 57, 5, 80, 3, 94, 8, 63, 0, 17, 2, 93, 7, 82, 1, 33, 
    8, 64, 1, 32, 6, 50, 3, 93, 4, 56, 5, 27, 7, 18, 2, 82, 0, 69, 
    2, 97, 7, 96, 4, 12, 3, 23, 0, 58, 8, 95, 5,  4, 1, 66, 6, 44, 
    5, 86, 6, 31, 7, 74, 3, 99, 4, 54, 0, 45, 1, 28, 2, 42, 8, 80, 
    7, 19, 4, 57, 6, 61, 0, 40, 2, 35, 3, 31, 1, 56, 8, 32, 5, 49, 
    3, 15, 1, 72, 0, 77, 8, 25, 7, 89, 5,  2, 4, 65, 6, 86, 2,  6, 
    6, 38, 5, 15, 2, 52, 0, 30, 3, 85, 8, 42, 7, 25, 1, 77, 4, 49, 
    7, 59, 3, 18, 2, 98, 5, 57, 6, 43, 1,  8, 0, 72, 4, 79, 8, 19, 
    2, 27, 8, 43, 5, 44, 6, 36, 0, 91, 4, 29, 1, 68, 7,  6, 3, 30
  };
  const int q3804[] = {
    9, 9, // Number of jobs and machines
    8, 43, 3, 90, 7, 72, 5, 96, 2, 45, 1, 34, 4,  7, 6, 29, 0, 35, 
    0, 17, 2, 17, 3, 71, 7, 85, 4, 97, 1, 51, 5, 14, 8, 94, 6,  3, 
    4, 73, 0, 55, 5, 87, 2, 34, 1, 75, 8, 20, 6, 47, 7, 35, 3, 54, 
    0, 37, 7, 73, 4, 40, 5, 24, 3, 53, 6, 82, 8, 89, 1, 64, 2, 86, 
    3, 58, 1, 42, 0, 24, 5, 99, 4, 42, 8, 12, 2, 77, 6, 89, 7, 22, 
    3, 83, 4, 37, 6, 67, 2, 58, 1, 49, 8, 55, 7, 47, 5, 30, 0, 80, 
    8, 63, 1, 22, 0, 76, 5, 34, 4,  6, 3, 85, 2, 66, 6, 82, 7, 15, 
    3, 24, 5, 21, 0, 24, 2, 68, 1,  5, 8, 78, 6, 87, 7, 71, 4, 41, 
    3, 43, 7, 68, 1, 60, 2, 78, 6, 92, 0, 58, 4, 44, 5, 37, 8, 94
  };
  const int q3805[] = {
    9, 9, // Number of jobs and machines
    0, 68, 3, 34, 2, 96, 6, 65, 8, 23, 7, 52, 5, 79, 1, 11, 4, 52, 
    5, 50, 6, 18, 1,  6, 3, 74, 0, 11, 2, 83, 4, 26, 7, 97, 8, 83, 
    5, 50, 0, 43, 3, 85, 6, 72, 2, 95, 4, 99, 8, 94, 7, 93, 1,  5, 
    0, 42, 6, 13, 8, 67, 7, 29, 4, 58, 5, 52, 3, 39, 2, 26, 1, 62, 
    6, 65, 2, 60, 5,  5, 0,  2, 8,  5, 1, 91, 7, 55, 3, 58, 4, 15, 
    3, 16, 7, 24, 0, 19, 1, 20, 6, 24, 4, 88, 2, 88, 5, 86, 8, 60, 
    8, 39, 1, 53, 6, 68, 5, 73, 3, 72, 0, 33, 2, 91, 7, 48, 4, 11, 
    2, 66, 8, 34, 1, 82, 3, 32, 0, 19, 6, 43, 5, 16, 4, 69, 7,  1, 
    4, 16, 1, 48, 0, 95, 7, 49, 6, 29, 2, 10, 8, 78, 5, 54, 3,  6
  };
  const int q3806[] = {
    9, 9, // Number of jobs and machines
    8, 70, 6, 94, 5, 35, 3, 81, 0, 86, 7,  3, 2, 24, 4, 90, 1, 41, 
    4,  7, 6, 82, 7, 31, 8, 62, 5, 83, 2, 69, 1, 84, 3, 43, 0, 69, 
    2, 16, 6, 22, 0, 92, 1, 29, 5, 80, 4, 24, 7, 55, 3, 55, 8, 87, 
    7, 39, 1, 81, 5, 70, 6, 13, 0, 89, 8, 85, 4, 21, 2, 86, 3, 25, 
    8, 50, 4, 15, 5, 50, 3, 75, 2, 14, 0, 88, 6,  3, 7, 73, 1, 62, 
    6, 92, 3, 17, 4, 58, 2, 12, 8, 16, 0, 28, 1, 78, 5, 26, 7, 72, 
    4, 46, 3, 50, 7,  9, 8, 78, 5, 37, 2,  3, 6, 90, 1, 68, 0, 90, 
    7, 31, 8, 15, 2, 94, 1, 52, 4, 81, 3, 90, 6, 67, 0, 69, 5, 56, 
    5, 91, 4, 72, 2, 85, 3, 85, 6, 34, 7,  4, 1, 17, 8,  3, 0, 11
  };
  const int q3807[] = {
    9, 9, // Number of jobs and machines
    8, 45, 4, 75, 2, 59, 3, 46, 7, 54, 6, 96, 0,  3, 5, 40, 1, 24, 
    8, 77, 5,  2, 0, 53, 1, 77, 3, 57, 2, 80, 4, 44, 7, 10, 6, 54, 
    7, 53, 2, 32, 5, 19, 0, 48, 3, 63, 1, 22, 6, 67, 4, 89, 8, 66, 
    6, 73, 8, 66, 4, 56, 0,  7, 5,  2, 2, 17, 1, 51, 3, 85, 7, 37, 
    4, 94, 5, 89, 8, 50, 2,  7, 6, 43, 3, 48, 0, 41, 7, 24, 1, 67, 
    2, 46, 4, 17, 3, 53, 0, 54, 5, 76, 7, 81, 8, 38, 6, 79, 1,  2, 
    4, 76, 1, 42, 3, 87, 0, 75, 8, 48, 6, 78, 2, 74, 5, 19, 7, 24, 
    8, 41, 7, 59, 0, 38, 2, 61, 1, 63, 3, 31, 5, 17, 4, 92, 6, 12, 
    5, 85, 8,  1, 0, 58, 7, 56, 2, 83, 1, 97, 4, 78, 3, 25, 6, 88
  };
  const int q3808[] = {
    9, 9, // Number of jobs and machines
    7, 78, 2,  2, 5, 42, 4, 49, 0, 54, 6, 24, 8,  6, 1, 64, 3, 61, 
    7, 68, 5, 26, 1, 22, 6,  8, 8, 47, 0, 82, 4, 64, 2,  6, 3, 85, 
    2, 52, 0,  8, 6, 57, 3, 38, 4,  8, 7,  2, 1, 77, 5, 72, 8, 46, 
    5, 57, 8, 12, 2, 63, 3, 88, 1, 82, 7, 63, 0, 55, 4, 54, 6, 68, 
    2, 39, 7, 70, 0, 44, 4, 39, 1, 97, 5, 34, 8, 20, 3, 59, 6, 97, 
    1, 89, 4, 79, 2, 28, 7, 48, 6, 40, 3,  2, 8, 75, 5, 22, 0, 39, 
    2, 62, 5, 88, 6, 87, 1, 58, 3, 26, 7, 10, 8, 86, 4, 50, 0, 17, 
    0, 92, 4, 28, 6, 48, 8, 98, 1, 89, 7, 73, 5, 23, 2, 51, 3, 12, 
    2, 85, 0,  6, 4, 23, 6,  7, 8, 51, 5, 65, 3, 43, 7, 48, 1, 54
  };
  const int q3809[] = {
    9, 9, // Number of jobs and machines
    2, 66, 0, 28, 7,  7, 3, 87, 8, 18, 4, 24, 5, 34, 6, 45, 1,  9, 
    6, 97, 7, 78, 2, 15, 8, 17, 4, 43, 3, 97, 0,  5, 5,  6, 1, 30, 
    1, 92, 2,  5, 7, 68, 8, 72, 4, 73, 5, 89, 6, 56, 0, 61, 3, 40, 
    0, 90, 4, 79, 1,  1, 3, 66, 8,  8, 7, 63, 2, 72, 5, 67, 6, 36, 
    7,  1, 3, 13, 0, 42, 5, 63, 8, 72, 4,  4, 2, 18, 6, 21, 1, 60, 
    4, 12, 3, 27, 6, 71, 1, 21, 2, 36, 0, 41, 8, 36, 5, 66, 7, 33, 
    5, 80, 7, 37, 0, 84, 4, 59, 8, 28, 6, 66, 3, 76, 1, 35, 2,  3, 
    4, 28, 3, 38, 8, 60, 1, 77, 6,  8, 5, 38, 7, 36, 0, 40, 2, 52, 
    5, 13, 3,  4, 6, 20, 2, 68, 8, 50, 7, 17, 1, 25, 4,  9, 0, 61
  };
  const int q3810[] = {
    9, 9, // Number of jobs and machines
    7, 75, 3, 91, 4, 63, 6, 72, 1, 92, 8, 78, 0, 50, 2, 97, 5, 47, 
    7, 81, 4, 40, 2, 95, 5, 74, 8, 51, 6, 51, 1, 81, 3, 52, 0, 15, 
    2, 68, 8, 43, 5, 41, 1, 52, 6, 61, 7, 14, 0, 52, 3, 52, 4, 59, 
    4, 45, 8, 23, 3, 34, 1, 87, 2, 19, 6, 40, 5, 15, 7, 31, 0, 87, 
    7, 53, 5, 42, 1, 40, 3, 52, 4, 32, 8, 81, 6, 94, 0, 82, 2, 39, 
    1, 74, 7, 49, 4, 51, 5, 97, 2, 11, 8, 98, 0, 67, 6,  5, 3, 78, 
    3, 29, 6, 37, 5, 12, 8, 25, 2,  4, 1, 85, 4, 79, 7, 23, 0, 95, 
    6, 40, 3, 73, 5, 41, 1, 61, 0, 95, 2, 18, 4,  7, 8, 24, 7, 27, 
    8, 66, 6, 98, 2, 59, 3, 43, 1, 36, 5, 50, 0, 38, 4, 80, 7, 10
  };
  const int q3811[] = {
    9, 9, // Number of jobs and machines
    5,  2, 7, 39, 6, 57, 3, 89, 0, 42, 1, 14, 4, 51, 8, 79, 2, 58, 
    2, 52, 5,  9, 4, 41, 6, 30, 0, 28, 3, 34, 7, 16, 1, 82, 8,  4, 
    4,  8, 1, 41, 5,  6, 0, 15, 6, 74, 8, 56, 3, 86, 2, 55, 7,  6, 
    1, 48, 0, 68, 5, 67, 6, 22, 2, 20, 7, 95, 4, 44, 8, 28, 3, 91, 
    7, 78, 6, 29, 2,  3, 5, 10, 3, 50, 1, 21, 0, 78, 4, 28, 8, 37, 
    8, 20, 4, 75, 5, 96, 6,  8, 0, 37, 1, 95, 7, 56, 2, 21, 3, 89, 
    4, 62, 0, 61, 3, 70, 8, 98, 2, 72, 6, 25, 7, 54, 1, 41, 5, 17, 
    5, 64, 0, 10, 4, 74, 3, 79, 1, 19, 8, 51, 7, 98, 2, 45, 6, 31, 
    4, 21, 7, 33, 0, 85, 8,  8, 2, 17, 3, 26, 6, 70, 1, 20, 5, 15
  };
  const int q3812[] = {
    9, 9, // Number of jobs and machines
    8, 11, 2, 99, 0, 87, 5, 51, 4,  3, 7, 53, 3, 72, 1, 82, 6, 33, 
    1,  7, 8, 19, 4, 59, 3, 35, 0, 39, 6, 40, 2, 34, 5, 51, 7, 97, 
    8, 62, 6, 77, 5, 54, 1, 96, 3,  3, 0, 76, 4, 10, 2,  4, 7, 86, 
    8, 49, 0, 46, 1, 54, 5, 79, 2, 27, 3, 24, 6, 87, 7, 31, 4, 36, 
    0, 48, 3, 17, 2, 51, 7, 33, 6, 19, 4, 80, 1, 71, 5, 95, 8, 31, 
    4, 28, 0, 76, 2, 99, 7,  1, 5, 31, 8, 53, 3,  1, 1, 80, 6, 70, 
    8, 34, 0,  9, 6, 99, 2, 62, 5, 76, 3, 26, 7, 32, 1, 74, 4, 98, 
    7,  4, 3, 56, 6, 62, 0, 31, 2, 59, 5, 24, 8, 13, 4, 47, 1, 74, 
    7, 40, 8, 35, 0, 30, 2, 58, 1, 89, 3, 91, 6,  5, 5, 97, 4, 62
  };
  const int q3813[] = {
    9, 9, // Number of jobs and machines
    6, 89, 0, 88, 7, 69, 2,  6, 8, 35, 3, 78, 4,  7, 1, 51, 5, 80, 
    2, 25, 4, 17, 6, 45, 5, 35, 1, 54, 8, 34, 0,  1, 7, 73, 3, 53, 
    6, 86, 0,  7, 3, 93, 2, 98, 1, 34, 5, 46, 4, 70, 7, 43, 8, 28, 
    0, 50, 6, 84, 5, 67, 2, 31, 3, 63, 1, 81, 4, 76, 8, 28, 7, 41, 
    1, 45, 6, 96, 4,  2, 5, 11, 8, 18, 0, 47, 7,  5, 2, 84, 3, 86, 
    7, 98, 4, 87, 2, 49, 0, 40, 3, 66, 1, 76, 8, 56, 6, 57, 5, 78, 
    7, 51, 3, 83, 2, 89, 5, 70, 1, 98, 0, 77, 4, 82, 6, 89, 8, 53, 
    5, 88, 3, 43, 0,  2, 4, 71, 6, 16, 8, 40, 1, 17, 7, 60, 2, 56, 
    6, 96, 0,  3, 4, 98, 3, 12, 7,  1, 5, 43, 1, 30, 2, 96, 8, 30
  };
  const int q3814[] = {
    9, 9, // Number of jobs and machines
    6, 43, 1, 46, 5, 10, 2, 43, 4, 21, 7, 71, 8,  5, 3, 17, 0, 98, 
    1, 90, 7, 93, 4, 65, 6, 52, 2,  8, 3,  9, 8, 51, 0, 22, 5, 32, 
    3, 61, 2, 61, 5,  1, 0, 81, 4, 87, 1, 15, 7,  3, 8, 38, 6, 24, 
    7, 89, 4, 74, 6, 67, 2, 61, 5, 43, 8, 35, 1, 34, 0, 56, 3, 68, 
    3, 38, 1, 93, 0, 30, 8, 99, 6, 15, 4,  9, 2, 83, 5,  3, 7, 83, 
    3, 69, 1, 23, 6, 46, 7, 13, 5, 68, 4, 87, 0, 16, 8, 71, 2, 50, 
    7, 70, 6, 70, 1, 68, 4, 52, 3,  5, 5, 59, 8, 64, 0, 17, 2, 61, 
    2, 82, 1, 78, 6, 26, 8, 60, 0, 17, 4, 79, 7, 53, 5, 52, 3, 77, 
    5,  8, 8, 29, 1, 18, 7, 94, 0, 44, 3, 12, 6, 60, 4,  5, 2, 66
  };
  const int q3815[] = {
    9, 9, // Number of jobs and machines
    8, 84, 1, 93, 7, 40, 6, 31, 2, 48, 0, 39, 3, 65, 5, 97, 4, 79, 
    0, 26, 3,  2, 4, 40, 7, 25, 8, 86, 1, 44, 5, 39, 2, 43, 6, 40, 
    3, 22, 0, 29, 4, 89, 1, 40, 5, 76, 6, 46, 7, 24, 2, 66, 8, 79, 
    5, 58, 2, 28, 0, 84, 8, 70, 3, 34, 6, 34, 4, 77, 7,  5, 1, 91, 
    2, 60, 1,  3, 4, 64, 7,  6, 8, 11, 0, 39, 5, 59, 6, 24, 3, 65, 
    4, 35, 5, 98, 6, 70, 0, 82, 1, 65, 7, 17, 8, 75, 3, 96, 2, 57, 
    2, 17, 4, 52, 0, 22, 6, 83, 7, 66, 1, 43, 8, 83, 3,  8, 5, 31, 
    6, 27, 2, 62, 3, 88, 5, 18, 0, 33, 7, 36, 8, 99, 1, 20, 4, 42, 
    8, 62, 5, 11, 3, 67, 7, 24, 2, 82, 1, 39, 0, 15, 6, 57, 4, 65
  };
  const int q3816[] = {
    9, 9, // Number of jobs and machines
    5, 19, 6, 74, 1, 40, 2, 11, 0, 66, 7, 97, 3,  4, 8, 25, 4, 48, 
    1, 29, 2, 62, 5, 49, 3, 45, 6, 17, 0, 87, 4, 81, 7, 64, 8, 74, 
    2, 24, 8, 35, 0, 21, 1, 25, 5, 72, 7, 69, 3, 76, 4, 93, 6, 57, 
    1, 38, 8, 74, 3, 36, 4, 98, 6, 80, 2, 54, 5, 48, 7, 41, 0, 30, 
    7,  3, 5, 48, 1, 96, 8, 80, 0, 57, 3, 65, 4, 42, 6, 33, 2, 30, 
    7, 80, 2, 58, 3, 12, 8, 38, 6, 51, 1, 45, 0, 86, 4, 10, 5, 68, 
    6, 95, 2, 81, 4, 61, 0, 79, 3, 33, 7, 57, 8, 58, 5, 76, 1, 99, 
    4, 96, 0, 94, 3, 83, 1, 76, 5, 76, 8, 36, 2, 33, 7, 78, 6, 48, 
    7, 10, 6, 90, 8, 51, 0,  4, 5, 98, 4, 27, 2, 86, 3, 13, 1, 31
  };
  const int q3817[] = {
    9, 9, // Number of jobs and machines
    3,  8, 7, 16, 5, 31, 8, 54, 4, 27, 1, 78, 0, 14, 6, 24, 2, 15, 
    4, 56, 6,  1, 5, 41, 1, 94, 3, 89, 7, 12, 0, 42, 2,  8, 8, 47, 
    2, 36, 3, 52, 7, 40, 4, 44, 5, 37, 8, 15, 6, 66, 1, 51, 0, 91, 
    3, 12, 7, 20, 5, 36, 2, 13, 0,  9, 8, 23, 6, 20, 4, 39, 1, 12, 
    2, 76, 5, 18, 6, 86, 8, 90, 1, 16, 3, 67, 0, 39, 7, 46, 4, 51, 
    8, 84, 7, 30, 6, 41, 0, 26, 2, 70, 5, 92, 3, 33, 1, 61, 4, 55, 
    0, 78, 1, 32, 3, 51, 8, 59, 7, 24, 2, 54, 5, 85, 6, 60, 4,  1, 
    8, 93, 6,  5, 1, 48, 4, 83, 2, 70, 0,  7, 7, 23, 3, 90, 5, 80, 
    7, 66, 5, 62, 3,  3, 8,  8, 2, 73, 1, 62, 6, 60, 4, 18, 0, 93
  };
  const int q3818[] = {
    9, 9, // Number of jobs and machines
    6, 36, 8, 53, 0, 45, 3, 78, 1, 78, 4, 39, 5, 86, 7, 27, 2, 85, 
    8, 14, 4, 62, 3, 99, 5, 16, 6, 70, 1, 92, 2, 59, 0, 57, 7, 81, 
    4, 23, 2, 58, 3, 71, 5, 19, 1,  4, 8, 42, 7, 91, 6, 43, 0, 62, 
    0,  3, 6, 86, 3,  7, 1, 50, 2,  9, 7, 26, 8, 49, 4, 65, 5, 99, 
    7, 44, 6, 39, 0, 90, 3, 43, 4, 34, 2, 22, 8, 43, 1, 53, 5, 28, 
    2, 74, 8, 77, 0,  6, 4, 12, 5, 29, 1, 87, 7, 78, 6, 99, 3, 19, 
    8, 31, 3, 72, 0, 45, 1, 20, 6, 55, 4,  3, 7, 90, 2, 23, 5, 19, 
    6, 18, 4, 10, 8, 93, 0, 81, 1, 62, 7,  6, 3, 22, 2, 10, 5, 91, 
    7, 64, 3, 33, 8, 97, 6, 31, 2, 12, 5, 74, 0, 40, 4, 40, 1, 97
  };
  const int q3819[] = {
    9, 9, // Number of jobs and machines
    2, 82, 8, 43, 5,  3, 4, 68, 6, 81, 7,  3, 3, 98, 0, 47, 1, 49, 
    7, 97, 8, 34, 5, 21, 4, 27, 6, 98, 1, 62, 0, 90, 3, 89, 2,  6, 
    0, 41, 5, 28, 3, 36, 2, 84, 4, 23, 8, 46, 7, 42, 1, 30, 6, 94, 
    5, 94, 1,  3, 0, 14, 4, 61, 8, 19, 3, 24, 6, 96, 7, 69, 2, 37, 
    8, 81, 1, 66, 2, 67, 3, 78, 4, 13, 7, 16, 6, 92, 0, 44, 5, 60, 
    6, 77, 2, 15, 7, 35, 4, 41, 1, 69, 8, 31, 0, 18, 5, 67, 3, 30, 
    6, 54, 3, 19, 4, 88, 7, 97, 5, 77, 8, 89, 1,  9, 2, 72, 0, 52, 
    4, 42, 2, 36, 0, 83, 8, 10, 6, 80, 1, 69, 5, 25, 7, 38, 3, 20, 
    5,  3, 0, 81, 7, 91, 2, 83, 6, 61, 4, 58, 3, 29, 8, 54, 1, 91
  };
  const int q3820[] = {
    9, 9, // Number of jobs and machines
    2, 27, 0, 57, 5, 98, 8, 88, 7, 98, 3, 90, 6, 71, 4, 75, 1, 93, 
    2, 99, 6, 79, 7, 99, 8, 78, 0, 92, 4,  4, 1, 98, 5, 86, 3, 90, 
    0, 75, 4, 73, 2, 53, 7, 81, 8, 87, 6, 88, 3,  1, 1,  6, 5, 68, 
    3, 91, 0, 30, 8, 22, 2, 36, 5, 37, 1, 81, 4, 44, 7, 44, 6, 11, 
    0,  4, 5, 44, 8, 16, 6, 83, 7, 94, 1, 55, 4, 95, 3, 71, 2, 48, 
    5,  7, 7, 53, 6, 61, 3, 16, 0, 61, 2, 72, 4, 90, 8, 37, 1,  5, 
    7, 30, 3,  1, 4,  3, 5, 15, 2, 22, 0, 76, 8, 14, 6, 25, 1, 16, 
    0, 16, 1, 15, 4, 78, 5, 18, 8, 65, 3, 69, 6, 84, 2, 23, 7, 49, 
    3, 50, 6, 51, 1, 15, 0, 91, 2, 52, 8, 37, 5, 68, 4, 75, 7, 46
  };
  const int q3821[] = {
    9, 9, // Number of jobs and machines
    8, 66, 7, 45, 1,  6, 5, 49, 3, 36, 2,  2, 0, 73, 6,  1, 4, 13, 
    4, 68, 7, 30, 2, 66, 0, 31, 6, 38, 1, 37, 3, 58, 5, 78, 8, 10, 
    4,  5, 7, 25, 2, 98, 5,  5, 6, 40, 1, 79, 8, 13, 3, 16, 0, 56, 
    5, 14, 0, 11, 3, 31, 8, 92, 6, 65, 4, 60, 1, 85, 7, 81, 2,  6, 
    6, 95, 7,  6, 2, 58, 3, 88, 1, 39, 0, 17, 4, 67, 5, 60, 8,  3, 
    0, 75, 4, 73, 5, 70, 2, 96, 8,  3, 6, 29, 3, 78, 7, 28, 1,  3, 
    6, 74, 0, 61, 1, 67, 2, 56, 4, 58, 5, 35, 7,  6, 8, 31, 3, 85, 
    2, 92, 5, 47, 8, 16, 1, 44, 7, 35, 6, 38, 0, 90, 3, 47, 4, 14, 
    4, 57, 0, 18, 7, 40, 3, 85, 1,  5, 8, 62, 2, 46, 6,  3, 5,  3
  };
  const int q3822[] = {
    9, 9, // Number of jobs and machines
    0, 22, 8, 95, 3, 44, 1, 58, 6,  4, 5, 99, 4, 65, 7, 27, 2, 60, 
    2,  3, 5, 32, 8, 59, 7, 33, 3, 70, 1, 82, 0, 64, 4, 16, 6, 10, 
    7, 83, 6, 99, 2, 54, 1, 42, 0, 94, 4, 61, 5, 36, 3,  7, 8, 23, 
    2, 46, 5, 91, 8, 17, 7, 77, 0, 64, 1, 95, 3, 78, 6, 22, 4, 15, 
    2, 46, 3, 49, 5, 83, 4, 38, 1, 92, 7, 90, 0, 27, 6, 83, 8, 42, 
    8, 59, 3, 17, 7, 91, 4,  5, 6, 90, 1, 50, 5, 77, 0, 23, 2, 62, 
    8, 51, 2, 91, 0, 51, 1, 83, 7, 71, 5, 97, 4, 25, 3,  7, 6,  8, 
    5, 43, 0, 90, 1,  9, 4, 66, 6, 78, 2, 21, 3, 54, 8, 70, 7, 19, 
    4, 28, 3, 33, 5, 37, 2, 53, 8, 84, 1, 85, 0,  8, 7, 37, 6, 89
  };
  const int q3823[] = {
    9, 9, // Number of jobs and machines
    8, 59, 0, 37, 4, 31, 7, 60, 2, 95, 1, 31, 3, 97, 6, 71, 5, 91, 
    0, 83, 7, 53, 8, 36, 5, 88, 4, 16, 1, 47, 3, 84, 6, 26, 2, 51, 
    8, 39, 6, 13, 2, 20, 0, 38, 5, 98, 4, 21, 1, 23, 3, 71, 7, 36, 
    0, 49, 3, 50, 7, 52, 4, 55, 6, 99, 8, 70, 2, 71, 1, 32, 5, 46, 
    7, 12, 4, 37, 1, 78, 0,  8, 5, 52, 6, 16, 3, 43, 2,  2, 8, 68, 
    3, 28, 8,  1, 0, 79, 7, 11, 5, 77, 2, 90, 4, 84, 1, 45, 6, 39, 
    8, 18, 7, 90, 4, 98, 5, 77, 6, 86, 0, 72, 3, 65, 1, 52, 2, 71, 
    0, 79, 3, 30, 1, 64, 5,  2, 2,  2, 6, 51, 7, 48, 8, 96, 4, 87, 
    0, 66, 2, 28, 5, 75, 4, 18, 8, 33, 1, 24, 3, 51, 6, 36, 7, 84
  };
  const int q3824[] = {
    9, 9, // Number of jobs and machines
    6, 68, 0, 78, 3, 48, 5, 21, 7, 94, 2, 11, 1, 66, 4, 60, 8, 45, 
    8, 91, 4,  1, 2, 36, 5, 35, 0, 60, 6, 21, 7, 54, 1, 94, 3, 96, 
    1, 58, 4, 24, 2, 71, 5, 97, 7, 87, 8, 90, 6, 17, 3, 34, 0, 76, 
    5, 14, 3, 45, 6, 93, 0, 75, 7, 29, 2, 25, 1, 39, 8,  3, 4,  4, 
    0, 72, 8, 12, 4, 16, 3, 84, 5, 55, 1, 21, 2, 54, 6, 31, 7, 41, 
    6, 46, 4, 50, 0, 45, 7, 82, 2, 25, 5, 89, 8, 12, 3, 21, 1, 54, 
    2, 55, 6, 82, 3, 21, 1, 27, 5, 90, 4, 29, 0, 57, 8,  2, 7, 20, 
    1, 73, 7, 33, 2, 70, 3, 51, 0, 93, 8, 36, 5, 48, 6, 76, 4, 54, 
    6, 57, 0, 22, 3, 31, 7, 25, 1, 70, 5, 44, 4, 60, 8, 18, 2, 49
  };
  const int q3825[] = {
    9, 9, // Number of jobs and machines
    2,  3, 4, 97, 1, 95, 3, 69, 8, 70, 0, 60, 5, 54, 6, 85, 7, 83, 
    2, 14, 6, 39, 5, 17, 7, 96, 3, 34, 4, 17, 8, 86, 1, 74, 0, 45, 
    7, 97, 2, 73, 0, 70, 4, 18, 1, 99, 5, 57, 6,  7, 8, 51, 3, 15, 
    3, 10, 5, 81, 7, 15, 0, 32, 6, 87, 4, 82, 8, 15, 2, 56, 1, 81, 
    1, 84, 5,  8, 3, 32, 8, 68, 4, 62, 7, 77, 0,  7, 2, 45, 6,  1, 
    6, 22, 1, 91, 4, 75, 7, 68, 2,  8, 3, 78, 5, 49, 8, 85, 0, 63, 
    2, 96, 0, 83, 5,  5, 1,  8, 3, 76, 6,  2, 7, 75, 8, 91, 4,  9, 
    1, 38, 6, 93, 0, 97, 7, 65, 4, 22, 8, 30, 3, 76, 2, 18, 5, 60, 
    7, 17, 6, 89, 5, 80, 2, 27, 0, 75, 1, 23, 8, 23, 4, 75, 3, 81
  };
  const int q3826[] = {
    9, 9, // Number of jobs and machines
    4, 79, 3, 20, 8, 86, 7, 80, 0, 25, 6, 53, 5, 21, 1, 19, 2, 69, 
    7, 33, 3, 57, 6, 45, 5, 73, 1, 59, 0, 78, 2, 24, 4, 12, 8, 39, 
    1, 55, 2, 42, 5, 66, 7, 52, 3, 10, 0, 62, 8, 81, 6, 26, 4,  7, 
    2, 19, 8, 89, 5,  5, 4, 79, 7, 20, 6, 94, 0, 92, 3, 57, 1, 91, 
    0, 79, 4, 53, 7, 58, 3, 59, 2,  2, 5, 80, 1,  6, 8, 14, 6, 66, 
    6, 73, 4, 40, 8, 40, 7, 55, 1, 80, 5, 88, 2, 69, 3, 16, 0, 60, 
    8, 82, 2, 21, 7, 94, 3, 23, 5, 29, 0, 90, 4, 97, 1, 44, 6, 25, 
    5, 14, 2, 35, 1, 58, 7, 43, 6, 68, 0, 93, 8, 53, 4, 74, 3, 78, 
    8, 22, 4, 56, 6,  1, 2, 53, 3, 88, 0, 43, 5, 63, 1, 40, 7, 95
  };
  const int q3827[] = {
    9, 9, // Number of jobs and machines
    7, 90, 8, 30, 0, 32, 3, 46, 1, 75, 4, 88, 2, 29, 6, 28, 5,  3, 
    7,  5, 3, 97, 0, 85, 6, 88, 5, 30, 1, 95, 2, 30, 8, 99, 4, 30, 
    6, 13, 5, 61, 7, 96, 0, 11, 3, 36, 8, 48, 1, 36, 2, 79, 4, 68, 
    4, 48, 3, 69, 8, 17, 5, 27, 6, 44, 7, 90, 1, 41, 0, 41, 2, 27, 
    2, 14, 1, 97, 4, 48, 6, 30, 8, 88, 0, 54, 7, 42, 5, 11, 3, 19, 
    8, 40, 1, 33, 2, 62, 3, 22, 6, 37, 4, 95, 7, 10, 0, 55, 5, 96, 
    5, 70, 1, 60, 8, 45, 3,  4, 4, 24, 2, 96, 0, 42, 6, 34, 7,  5, 
    6, 55, 5, 13, 8, 43, 3, 77, 7,  3, 2, 19, 1, 69, 4, 68, 0,  6, 
    4, 43, 7, 78, 0, 48, 2, 89, 6, 48, 5, 72, 3, 83, 8, 61, 1, 75
  };
  const int q3828[] = {
    9, 9, // Number of jobs and machines
    5, 41, 4, 69, 8,  5, 7, 74, 6, 95, 3, 91, 2, 72, 1, 36, 0, 61, 
    7, 29, 8,  5, 3, 25, 2, 94, 5, 10, 1, 68, 4, 50, 6, 97, 0, 16, 
    0, 41, 8, 78, 2, 33, 5,  4, 3,  7, 4, 89, 1, 42, 6, 53, 7, 22, 
    4, 34, 5, 80, 8, 23, 3, 68, 7, 44, 0, 78, 2,  2, 6, 55, 1, 58, 
    4, 58, 6, 69, 1, 53, 2, 79, 0,  7, 5, 61, 3, 79, 7, 57, 8, 20, 
    6, 23, 4,  1, 5, 38, 1, 18, 7,  9, 0, 78, 8, 59, 2, 53, 3, 67, 
    6, 27, 4, 74, 1, 94, 3, 21, 7, 77, 8, 22, 2, 26, 5, 62, 0, 99, 
    2, 94, 7, 31, 3, 33, 4, 61, 0, 44, 6, 83, 5, 26, 8, 51, 1, 34, 
    1, 87, 2, 11, 3, 67, 6,  8, 7, 75, 4, 26, 8, 65, 5, 36, 0, 13
  };
  const int q3829[] = {
    9, 9, // Number of jobs and machines
    7, 23, 2, 64, 8, 49, 3, 39, 6, 35, 5, 12, 0, 31, 4,  4, 1, 68, 
    6, 85, 2, 31, 4, 47, 0, 55, 5, 66, 1, 98, 3, 19, 7, 76, 8, 73, 
    6, 24, 3, 13, 2,  8, 1, 65, 0, 68, 7, 22, 5, 69, 8, 20, 4, 10, 
    6, 55, 3, 24, 5, 11, 8, 48, 7, 25, 1, 73, 4, 32, 0, 28, 2,  3, 
    3, 25, 4, 72, 1, 49, 2, 69, 5, 18, 8, 91, 7, 24, 6, 57, 0, 77, 
    3, 26, 6, 35, 2, 21, 7, 19, 5, 53, 4,  3, 8, 66, 1, 25, 0, 14, 
    6, 25, 4, 30, 5, 43, 0,  4, 3, 74, 1, 80, 8, 93, 7, 45, 2, 69, 
    7, 60, 1, 60, 4,  3, 6, 34, 0, 89, 8, 89, 2, 55, 3, 82, 5, 63, 
    1, 46, 3, 91, 5, 61, 4, 76, 8, 55, 0, 83, 6,  1, 2, 30, 7, 57
  };
  const int q3830[] = {
    9, 9, // Number of jobs and machines
    1, 38, 2, 24, 5, 54, 0, 84, 7, 58, 4, 40, 3, 22, 8, 75, 6,  1, 
    0, 11, 3, 52, 6,  8, 7, 74, 4, 10, 1, 50, 5, 87, 2, 45, 8, 43, 
    7, 87, 4, 95, 5, 94, 2, 19, 6, 99, 8, 56, 0, 13, 1, 50, 3, 98, 
    4, 46, 3, 90, 1, 19, 5, 89, 2, 31, 6, 43, 0,  2, 7,  9, 8, 74, 
    1, 48, 8, 70, 4, 36, 3, 73, 5, 76, 2, 13, 6, 50, 0, 74, 7, 92, 
    2, 92, 8, 71, 4, 11, 7, 12, 6, 56, 0, 64, 1, 93, 3, 42, 5, 47, 
    0, 64, 6,  1, 2, 56, 4,  9, 8, 47, 7, 84, 1, 22, 3, 50, 5, 44, 
    8, 80, 5, 75, 3, 88, 0, 84, 7, 15, 4, 74, 6, 95, 1, 65, 2, 87, 
    6, 32, 2, 82, 5, 43, 3, 36, 1, 46, 7, 66, 0, 21, 4, 96, 8, 14
  };
  const int q3831[] = {
    9, 9, // Number of jobs and machines
    5,  6, 1, 53, 8, 45, 0, 26, 7,  1, 6, 29, 4, 35, 3, 31, 2, 72, 
    7, 18, 4, 44, 0, 39, 2, 45, 1, 56, 3, 13, 5, 55, 6, 14, 8, 29, 
    2, 20, 8, 33, 5,  1, 0, 57, 4, 30, 6, 96, 3, 85, 7, 30, 1, 24, 
    5, 69, 8,  8, 6, 95, 7, 41, 2, 81, 4,  3, 3, 14, 1, 80, 0, 61, 
    7, 86, 2, 14, 4, 36, 1, 93, 8, 73, 0, 49, 3, 16, 6, 22, 5, 44, 
    4, 73, 8, 89, 1, 91, 0,  4, 5, 50, 7, 35, 3, 24, 6, 29, 2, 62, 
    5, 42, 0, 26, 6, 63, 3, 48, 7, 59, 2, 77, 1, 19, 8, 50, 4, 77, 
    1, 30, 5, 76, 8, 95, 0, 90, 3, 16, 6, 80, 4, 11, 7, 58, 2, 37, 
    4, 57, 8, 20, 5,  3, 7, 18, 2,  1, 3, 36, 6, 60, 0, 39, 1, 96
  };
  const int q3832[] = {
    9, 9, // Number of jobs and machines
    4, 70, 8, 27, 7, 27, 3, 66, 2, 18, 0, 19, 6, 99, 1, 60, 5, 49, 
    3,  4, 5, 52, 1, 28, 4, 16, 7, 10, 0, 83, 8,  3, 2, 21, 6,  5, 
    6, 72, 5, 79, 3, 45, 7, 92, 8, 99, 1, 98, 0, 75, 2, 38, 4, 85, 
    6, 15, 3, 75, 8, 58, 7, 29, 1, 57, 4, 25, 2, 34, 5, 85, 0, 55, 
    6,  9, 3, 32, 7, 20, 8, 26, 2, 12, 1, 90, 5,  4, 0, 37, 4, 15, 
    0, 25, 6, 78, 7, 62, 4, 24, 2, 18, 8,  9, 5, 72, 1, 91, 3, 89, 
    5, 77, 1, 12, 8, 21, 7, 38, 3, 47, 0, 94, 4, 69, 6, 13, 2, 29, 
    2, 53, 8, 13, 4, 57, 3, 61, 7,  6, 5, 69, 1, 35, 6, 11, 0, 90, 
    4, 13, 1, 73, 0, 44, 2, 40, 6, 35, 7, 23, 5, 94, 8, 40, 3,  5
  };
  const int q3833[] = {
    9, 9, // Number of jobs and machines
    6, 23, 7, 17, 5, 30, 3, 11, 0, 21, 4, 67, 1, 24, 8, 89, 2, 31, 
    0, 12, 7, 48, 5, 14, 3, 60, 2, 94, 4, 19, 6, 31, 1, 86, 8,  9, 
    2, 78, 8, 41, 7, 72, 4, 15, 5, 88, 0, 26, 1, 38, 3, 36, 6, 99, 
    5, 68, 2, 16, 6, 49, 7, 24, 8, 65, 4, 65, 0, 46, 1, 15, 3, 74, 
    7, 73, 3, 25, 0, 36, 5, 18, 2,  1, 1, 34, 8, 58, 4, 67, 6, 42, 
    2,  7, 1, 47, 6, 69, 5, 22, 0, 35, 8, 50, 4, 80, 3,  7, 7, 55, 
    4, 54, 0, 55, 8, 73, 1, 51, 7, 60, 2, 87, 3, 24, 5, 39, 6, 33, 
    4, 46, 6, 94, 0, 70, 7, 69, 5, 26, 3, 83, 2, 34, 8, 60, 1, 63, 
    5, 22, 0, 53, 2, 45, 7, 40, 8, 60, 3, 16, 6, 53, 1, 68, 4, 92
  };
  const int q3834[] = {
    9, 9, // Number of jobs and machines
    4, 21, 2, 83, 7, 88, 0, 49, 1, 82, 5, 22, 3, 92, 6,  3, 8, 94, 
    1, 88, 4, 28, 0, 80, 7, 93, 8, 13, 2, 21, 3, 40, 6,  2, 5, 38, 
    4, 90, 5, 81, 3, 94, 2, 17, 8, 39, 0, 49, 1, 64, 7, 92, 6,  2, 
    0, 60, 4, 63, 1,  2, 2,  2, 8, 15, 5, 11, 3, 70, 7, 67, 6, 58, 
    8, 95, 5, 39, 3, 21, 7, 21, 0,  9, 6, 37, 2, 73, 1, 11, 4,  3, 
    1, 53, 6, 66, 5, 79, 0, 64, 4, 76, 3, 65, 7, 13, 2, 51, 8, 73, 
    6, 81, 1, 22, 8, 24, 7, 23, 0,  9, 3, 44, 5, 42, 2, 24, 4, 66, 
    0, 54, 1, 45, 2, 50, 5, 56, 6, 20, 8, 62, 7, 13, 3, 13, 4,  3, 
    4, 12, 1, 66, 0, 68, 2, 63, 7, 64, 6, 40, 3, 46, 8, 41, 5, 87
  };
  const int q3835[] = {
    9, 9, // Number of jobs and machines
    7, 37, 6, 65, 5, 35, 3, 71, 8, 60, 2, 61, 0, 77, 4, 38, 1, 52, 
    0,  8, 6, 34, 4, 70, 5, 51, 7, 52, 1, 97, 2, 53, 3, 65, 8, 96, 
    3, 16, 0, 14, 4, 50, 5, 95, 1, 93, 2, 50, 8, 83, 6, 89, 7, 61, 
    6, 54, 4, 42, 8, 75, 7, 44, 1, 62, 3, 89, 5, 57, 2, 24, 0, 17, 
    2, 74, 8, 80, 5, 49, 4, 97, 1, 14, 7, 21, 0, 46, 3, 79, 6, 20, 
    4, 77, 5, 39, 3, 65, 0, 70, 1, 30, 8, 44, 7, 30, 2, 65, 6, 63, 
    8,  6, 6, 45, 3, 76, 2, 14, 4, 86, 1, 16, 7, 41, 5, 40, 0, 71, 
    6, 35, 8, 54, 5, 12, 3,  3, 0, 94, 4, 76, 7, 58, 1, 54, 2, 62, 
    2, 80, 8,  5, 7, 56, 5, 12, 0, 40, 4, 84, 1, 12, 3, 46, 6, 68
  };
  const int q3836[] = {
    9, 9, // Number of jobs and machines
    3,  5, 6, 71, 0, 35, 1, 35, 7, 15, 4, 33, 8,  1, 5, 85, 2,  9, 
    5, 37, 7, 96, 8, 45, 1, 71, 0, 69, 3,  9, 2, 37, 4, 11, 6, 66, 
    1, 60, 2, 40, 6, 47, 3, 83, 8, 25, 4, 25, 7, 85, 0, 50, 5,  7, 
    5, 89, 2, 82, 3, 63, 6,  7, 7, 23, 8, 52, 0, 56, 4, 70, 1, 16, 
    5, 18, 2, 97, 1, 91, 0, 58, 6, 39, 7,  9, 4, 21, 3, 32, 8, 97, 
    6, 35, 3, 71, 0, 54, 4, 46, 5, 42, 2, 19, 7, 91, 8, 16, 1, 46, 
    6, 57, 1, 48, 4, 35, 7, 27, 0,  5, 8, 31, 3, 70, 2, 29, 5, 19, 
    7, 42, 5, 74, 3, 15, 0,  2, 2, 83, 4,  3, 1, 57, 8,  6, 6, 44, 
    2,  5, 8, 55, 6, 21, 0, 86, 1,  3, 4, 36, 5, 43, 7, 66, 3, 89
  };
  const int q3837[] = {
    9, 9, // Number of jobs and machines
    8, 90, 7, 96, 3, 21, 6, 67, 2, 92, 5, 33, 1, 92, 0, 28, 4, 69, 
    2, 38, 1, 36, 3, 26, 5, 98, 8, 36, 7, 40, 0, 77, 4, 35, 6, 39, 
    6, 76, 3, 90, 1, 54, 2, 21, 0, 40, 8, 35, 4, 42, 5,  4, 7, 52, 
    1, 39, 2, 69, 8, 91, 7, 97, 0, 68, 3, 36, 5, 41, 6, 57, 4, 81, 
    4,  6, 2, 65, 5, 19, 0, 60, 3, 18, 6, 79, 7, 32, 1, 69, 8,  6, 
    0, 25, 1, 93, 2,  9, 3, 76, 6, 49, 7, 96, 8, 59, 4, 58, 5, 97, 
    6, 79, 8, 20, 1, 49, 2, 85, 4,  1, 7, 15, 0, 81, 3, 64, 5, 71, 
    6, 67, 5,  6, 8, 81, 2, 19, 4, 78, 0, 72, 3, 20, 7, 62, 1, 50, 
    8,  4, 1, 21, 2,  8, 3, 54, 7, 14, 6, 61, 4, 11, 0, 33, 5, 51
  };
  const int q3838[] = {
    9, 9, // Number of jobs and machines
    0, 29, 5, 14, 7, 53, 2, 72, 8, 53, 1, 73, 4, 60, 6, 93, 3, 49, 
    1, 88, 7, 91, 2, 99, 0, 93, 4, 74, 3, 48, 8, 47, 5, 82, 6, 47, 
    4, 49, 0, 97, 2, 64, 8, 98, 5, 45, 1, 61, 3, 44, 7, 35, 6, 52, 
    5, 32, 3, 14, 8, 53, 7, 56, 1, 24, 4,  4, 2, 69, 0, 24, 6, 39, 
    1, 78, 7, 69, 5, 66, 8, 18, 2, 40, 3, 54, 6, 76, 4, 96, 0, 93, 
    3, 76, 0, 26, 5, 64, 1, 60, 8, 95, 7, 29, 4,  6, 2, 85, 6, 22, 
    1, 23, 6,  8, 2, 35, 7, 87, 4, 55, 0, 60, 5, 59, 8, 43, 3, 17, 
    1, 19, 3,  5, 4, 87, 6, 44, 7, 17, 5, 11, 8, 33, 2, 84, 0, 15, 
    1, 88, 2, 72, 0, 79, 7, 91, 4, 95, 3,  5, 5, 88, 8, 93, 6, 77
  };
  const int q3839[] = {
    9, 9, // Number of jobs and machines
    4, 68, 5,  6, 7, 98, 3, 11, 1, 24, 0, 10, 8, 59, 6, 86, 2, 35, 
    4, 25, 6, 36, 2, 13, 0, 67, 1, 18, 5, 39, 7, 45, 8, 69, 3,  8, 
    1,  5, 7, 59, 3, 36, 6, 15, 0, 98, 5, 52, 4, 79, 8, 57, 2, 28, 
    0, 18, 4, 51, 3,  5, 8, 98, 6, 59, 2, 31, 1, 63, 7, 71, 5, 84, 
    6, 81, 7, 47, 1, 83, 0, 75, 2, 42, 5,  7, 3, 33, 8, 78, 4,  8, 
    1, 78, 6,  3, 2, 93, 0, 67, 3, 81, 8,  4, 7, 18, 4, 77, 5, 90, 
    8, 29, 4, 44, 7, 44, 6, 52, 0, 10, 1, 22, 2, 40, 3, 29, 5, 69, 
    7, 63, 0, 82, 8, 10, 2, 41, 5,  1, 3, 41, 1, 70, 4, 66, 6, 24, 
    3, 24, 8, 65, 0, 48, 6, 65, 7, 24, 1, 98, 5, 49, 4,  1, 2, 47
  };
  const int q3840[] = {
    9, 9, // Number of jobs and machines
    6, 88, 3, 39, 8, 69, 7, 43, 5, 43, 1, 58, 2, 30, 0, 14, 4, 28, 
    6, 42, 3, 78, 4, 22, 1, 82, 2,  3, 7, 31, 5, 70, 0, 15, 8, 31, 
    6, 86, 5, 76, 8, 31, 7, 11, 1, 81, 4,  8, 2, 43, 0, 96, 3, 71, 
    5, 54, 8, 82, 1,  3, 6, 57, 3, 96, 4, 39, 7, 73, 2, 27, 0,  3, 
    0, 85, 5, 46, 2, 16, 7, 40, 3, 14, 4, 25, 8, 51, 6, 97, 1, 49, 
    1, 36, 2,  8, 8, 17, 6, 22, 0, 92, 4, 75, 3, 65, 5, 99, 7, 42, 
    6, 90, 5, 32, 2, 22, 7, 21, 0, 95, 8,  4, 1, 95, 4, 64, 3, 72, 
    1, 60, 5, 49, 2, 65, 3, 26, 4, 29, 8, 61, 7, 34, 0, 54, 6, 46, 
    1, 35, 4,  9, 3, 43, 5, 76, 6, 68, 2, 73, 8, 99, 7, 93, 0, 14
  };
  const int q3841[] = {
    9, 9, // Number of jobs and machines
    3, 95, 2, 25, 4, 88, 0, 66, 1, 73, 8, 51, 6, 28, 5, 76, 7, 87, 
    8, 20, 2, 40, 7, 79, 3, 10, 6, 24, 4, 95, 5, 48, 1, 10, 0, 59, 
    2,  2, 6, 81, 5,  5, 3, 48, 7, 78, 0, 44, 4, 82, 8, 22, 1, 20, 
    3, 71, 5, 30, 8, 57, 4, 15, 6, 98, 2, 93, 0,  5, 1, 91, 7,  6, 
    3, 38, 8, 27, 0, 83, 7, 87, 4, 74, 2,  8, 1, 69, 5, 14, 6, 63, 
    7, 40, 0,  2, 3, 25, 8, 56, 6, 11, 4, 66, 1, 38, 5,  1, 2, 69, 
    1,  8, 3,  4, 0, 48, 7, 57, 8, 69, 2, 12, 5, 45, 6, 14, 4, 75, 
    1, 45, 6, 45, 4, 51, 3, 56, 8, 82, 7, 25, 0, 67, 2, 44, 5, 91, 
    3, 78, 5, 50, 6, 74, 8, 41, 2, 10, 0, 32, 4, 49, 1, 90, 7,  2
  };
  const int q3842[] = {
    9, 9, // Number of jobs and machines
    8, 77, 1, 44, 3, 71, 0, 74, 6, 50, 4, 59, 5, 90, 7, 48, 2, 21, 
    2, 38, 8, 85, 6, 38, 1, 14, 5,  4, 4, 96, 3, 23, 7, 54, 0, 38, 
    0, 94, 5, 98, 4, 58, 7, 54, 3, 44, 2, 85, 1, 82, 8, 97, 6, 44, 
    3, 78, 7, 48, 0, 56, 8, 59, 5, 64, 2,  1, 1, 91, 4,  7, 6, 40, 
    7, 64, 8, 54, 1,  2, 5, 40, 3, 82, 0, 75, 6, 33, 2, 63, 4, 37, 
    7, 36, 2, 65, 6,  7, 5, 15, 3, 32, 4, 32, 1, 18, 8,  7, 0, 17, 
    4, 52, 2, 39, 8, 79, 3, 64, 0, 26, 7, 74, 5, 41, 1,  3, 6, 11, 
    0, 63, 3, 79, 1, 40, 8, 93, 4, 65, 6, 71, 5, 46, 2, 74, 7, 91, 
    6, 85, 4, 82, 0,  1, 7, 27, 5,  2, 2,  6, 1, 26, 8, 99, 3, 80
  };
  const int q3843[] = {
    9, 9, // Number of jobs and machines
    0, 70, 8, 95, 6, 48, 4, 14, 1, 36, 7,  5, 2, 46, 3, 62, 5, 81, 
    5, 34, 7, 80, 6, 98, 1, 29, 4, 57, 8, 68, 0, 32, 2, 83, 3,  7, 
    7, 97, 5,  5, 4, 50, 2, 97, 0, 88, 8, 97, 3, 75, 6, 91, 1,  5, 
    7, 48, 2, 31, 0, 69, 1, 97, 5, 98, 3, 31, 6, 42, 4,  5, 8, 94, 
    8, 31, 2, 37, 1, 97, 0, 58, 5, 75, 3, 97, 7, 83, 4, 65, 6, 95, 
    6, 44, 0, 30, 1, 24, 2,  8, 3, 80, 5, 70, 8, 50, 7, 77, 4, 86, 
    8, 78, 5,  4, 6, 41, 4, 61, 1, 88, 0,  3, 7,  5, 2, 19, 3, 97, 
    1, 28, 8, 43, 4, 49, 0, 92, 6, 51, 2, 99, 7, 60, 3, 42, 5, 26, 
    1, 69, 7, 44, 2, 69, 0,  9, 8, 49, 3, 92, 6, 22, 5, 13, 4, 69
  };
  const int q3844[] = {
    9, 9, // Number of jobs and machines
    4, 23, 6, 52, 8, 52, 7, 34, 5, 83, 2,  8, 1,  2, 0, 45, 3, 20, 
    6, 46, 4, 18, 1, 80, 3, 95, 2, 63, 0, 57, 7, 90, 5, 26, 8, 40, 
    8, 92, 6, 56, 7, 94, 0, 10, 2, 66, 3, 33, 5, 20, 4, 73, 1, 55, 
    2, 76, 5, 28, 1, 91, 6, 51, 3, 11, 8, 97, 0, 72, 7, 59, 4, 74, 
    5, 58, 7, 60, 0,  2, 6, 81, 8, 23, 2, 68, 3, 61, 4, 62, 1, 73, 
    7, 87, 6, 95, 2, 30, 5, 87, 8,  8, 0, 23, 1, 44, 4, 80, 3, 42, 
    5, 85, 2, 96, 3, 37, 8, 15, 7, 17, 1, 12, 6, 66, 4, 86, 0, 99, 
    0, 96, 3, 66, 7, 32, 6, 68, 4, 31, 2, 72, 1, 48, 8, 41, 5, 37, 
    6,  6, 1, 50, 3, 16, 0, 93, 8, 84, 2, 74, 4, 83, 5, 66, 7, 42
  };
  const int q3845[] = {
    9, 9, // Number of jobs and machines
    6, 12, 7, 92, 1, 85, 2, 69, 8, 56, 5, 22, 4, 76, 0, 88, 3, 60, 
    2, 99, 7, 77, 0, 23, 4, 95, 6, 59, 8, 88, 5, 87, 3, 34, 1, 77, 
    1, 83, 3, 97, 2, 98, 7, 68, 6, 27, 5, 70, 4, 89, 0, 33, 8, 48, 
    7, 49, 3, 93, 5, 99, 0, 18, 1, 31, 2, 87, 8, 92, 6, 12, 4, 44, 
    7, 22, 3, 19, 2, 65, 8, 75, 6, 92, 1, 61, 0, 38, 5, 90, 4, 59, 
    2, 80, 4, 47, 3, 88, 7, 45, 6, 72, 0, 24, 1, 14, 5, 59, 8, 59, 
    7, 78, 0, 68, 1, 44, 3, 52, 6, 12, 4, 44, 5, 21, 2, 60, 8, 45, 
    2, 13, 1, 26, 4, 99, 8, 29, 3, 52, 7, 37, 5, 52, 6, 99, 0, 42, 
    8, 18, 4, 38, 6, 39, 2, 87, 1, 35, 0, 12, 5, 28, 7, 61, 3, 12
  };
  const int q3846[] = {
    9, 9, // Number of jobs and machines
    7, 61, 6, 94, 2, 46, 5, 60, 8, 40, 4, 55, 1, 87, 0, 11, 3, 19, 
    7, 65, 3, 79, 2, 82, 5, 67, 8, 10, 6, 94, 4, 11, 1, 84, 0, 65, 
    5, 35, 6, 30, 2, 64, 3, 19, 4, 31, 1, 11, 0,  9, 7, 31, 8, 81, 
    3, 89, 2, 95, 6, 60, 1, 82, 7, 27, 8, 95, 4, 88, 0, 74, 5, 97, 
    4, 98, 6, 67, 5, 19, 7, 39, 2, 52, 0, 67, 3, 32, 8, 59, 1, 61, 
    4, 12, 7, 69, 6, 80, 8, 12, 1, 64, 0, 14, 2, 16, 3, 65, 5, 48, 
    3, 60, 7, 18, 0, 90, 2, 17, 8,  4, 5, 59, 6, 96, 4, 17, 1, 74, 
    5, 23, 6, 68, 3, 40, 8, 17, 1, 94, 7, 42, 4,  2, 0, 92, 2, 74, 
    0, 71, 1, 77, 4, 57, 2, 32, 5, 27, 7, 95, 6, 75, 3, 49, 8, 41
  };
  const int q3847[] = {
    9, 9, // Number of jobs and machines
    7, 21, 5, 93, 1,  4, 8, 94, 3, 63, 4, 30, 0, 71, 6, 82, 2,  9, 
    7, 59, 1, 20, 6, 37, 8, 72, 0, 67, 5, 99, 3, 73, 2, 78, 4, 67, 
    6, 96, 2, 11, 8, 48, 7, 61, 3, 35, 4, 52, 5, 83, 1, 75, 0, 39, 
    4, 30, 7, 50, 1, 21, 8, 42, 2, 91, 0, 91, 3, 39, 6, 52, 5, 84, 
    8, 13, 7, 45, 4, 33, 3, 52, 6, 85, 1, 87, 2, 49, 5, 35, 0, 34, 
    3, 39, 6, 75, 0, 79, 2, 86, 8, 32, 4, 20, 7, 86, 5, 18, 1, 39, 
    1, 87, 6, 82, 7, 47, 4, 54, 3, 46, 0, 70, 5, 82, 2, 77, 8, 66, 
    2, 82, 4, 65, 5, 90, 8, 59, 6,  2, 7, 54, 3, 58, 0, 29, 1, 44, 
    0, 90, 1,  7, 2, 56, 5, 46, 8, 57, 3, 82, 6, 86, 4, 71, 7, 33
  };
  const int q3848[] = {
    9, 9, // Number of jobs and machines
    3, 19, 1, 72, 5, 42, 2, 12, 4, 44, 7, 51, 8,  1, 6, 28, 0, 79, 
    1, 41, 7, 91, 5, 34, 4,  7, 8,  5, 3, 76, 2, 51, 6, 10, 0, 28, 
    1, 58, 7, 12, 5, 99, 3, 27, 0,  9, 6, 90, 4, 11, 8,  7, 2, 90, 
    4, 16, 2, 80, 3, 12, 8, 96, 6, 39, 5, 45, 7, 18, 1, 25, 0, 80, 
    6, 96, 7, 43, 1, 20, 5, 26, 0, 72, 3, 59, 8, 28, 4, 24, 2, 15, 
    4, 35, 3, 19, 8, 26, 7, 32, 0, 39, 6,  1, 2, 78, 5,  5, 1, 68, 
    5, 34, 8, 18, 1, 38, 4, 23, 7, 29, 6, 42, 2, 76, 0, 90, 3,  3, 
    0, 58, 6, 28, 7, 68, 8, 24, 2, 33, 5, 49, 3,  6, 4, 70, 1,  1, 
    3,  4, 5, 79, 6, 48, 4, 56, 7, 37, 1, 46, 0, 39, 2,  9, 8, 25
  };
  const int q3849[] = {
    9, 9, // Number of jobs and machines
    1, 25, 7, 42, 2,  9, 6, 21, 8, 69, 3,  5, 0, 61, 5, 76, 4, 50, 
    3,  1, 5, 18, 7,  6, 8, 56, 2, 66, 4, 40, 6, 33, 0, 37, 1, 75, 
    1, 75, 7, 19, 8, 84, 0, 56, 4, 61, 6,  1, 5, 85, 3, 43, 2, 58, 
    2, 93, 4, 43, 6, 32, 7, 26, 0,  4, 3, 15, 8, 52, 1, 86, 5, 95, 
    2, 82, 6, 42, 5, 46, 0, 40, 1, 62, 3, 52, 7, 25, 8, 33, 4, 25, 
    2,  8, 7, 41, 5, 59, 0, 13, 4, 17, 1,  6, 8, 85, 6, 92, 3, 95, 
    5, 29, 3, 99, 8, 32, 6, 56, 1,  9, 0, 95, 7,  5, 4, 94, 2, 85, 
    6,  4, 3, 71, 1, 77, 2, 28, 8, 55, 0, 40, 5, 93, 4, 53, 7, 51, 
    4,  8, 6, 46, 3, 52, 7, 83, 0, 46, 1, 65, 2, 21, 5, 16, 8, 25
  };
  const int q3850[] = {
    9, 9, // Number of jobs and machines
    3, 10, 7, 36, 4, 50, 1, 33, 6, 32, 0, 58, 8, 38, 2, 21, 5, 37, 
    7, 97, 4,  8, 3, 27, 2, 63, 0, 40, 6, 20, 5, 69, 1, 33, 8, 72, 
    7,  6, 8, 93, 2, 93, 6, 78, 4, 69, 0,  8, 3, 61, 5, 27, 1, 60, 
    4, 76, 3, 12, 6, 29, 8, 77, 7, 59, 5, 53, 2, 25, 1, 74, 0, 11, 
    2,  8, 6, 51, 3, 18, 0, 27, 7, 87, 5, 47, 8, 35, 4, 56, 1, 16, 
    0, 98, 6, 93, 7, 76, 4, 31, 3, 81, 1, 22, 2, 74, 5, 52, 8, 58, 
    5, 61, 6, 69, 7, 35, 1, 83, 2, 90, 8,  7, 4, 96, 0,  3, 3, 16, 
    1, 38, 3, 87, 6, 73, 7, 57, 4, 89, 8, 45, 5, 87, 2, 48, 0, 20, 
    1, 57, 4, 55, 2, 77, 0, 47, 6, 94, 7, 75, 3,  4, 5, 98, 8, 36
  };
  const int q3851[] = {
    9, 9, // Number of jobs and machines
    1, 63, 3, 74, 5, 16, 8, 85, 4, 50, 6, 46, 0, 69, 2, 83, 7, 80, 
    0, 23, 4,  3, 5, 20, 1,  1, 7, 30, 6, 21, 2, 22, 3, 50, 8, 27, 
    0, 10, 4, 54, 1, 83, 7, 84, 6, 96, 2, 34, 3, 62, 5, 57, 8, 54, 
    2, 44, 4, 92, 3, 55, 5, 63, 7, 31, 6, 60, 8, 88, 1, 48, 0, 96, 
    7, 96, 3, 38, 6, 93, 8, 63, 2, 87, 5, 31, 0, 95, 1, 90, 4, 96, 
    5, 85, 7, 50, 4, 87, 6, 32, 0, 26, 8, 94, 3, 14, 1, 37, 2, 96, 
    2, 40, 4, 93, 7, 76, 8,  4, 3, 68, 0, 24, 1, 82, 6, 60, 5,  9, 
    7, 60, 0, 68, 1, 78, 6, 43, 8, 19, 5, 59, 2, 75, 4, 16, 3,  5, 
    6, 85, 1, 97, 5, 18, 4, 70, 0, 25, 8, 63, 2, 91, 3, 12, 7, 99
  };
  const int q3852[] = {
    9, 9, // Number of jobs and machines
    8, 20, 0, 47, 6, 99, 2, 18, 5, 91, 1, 46, 3, 94, 7, 67, 4, 68, 
    7, 91, 4, 58, 2, 77, 1, 72, 6, 10, 8, 39, 3,  8, 0, 12, 5, 93, 
    6, 40, 3, 96, 7, 62, 4, 47, 8, 77, 1, 90, 0, 98, 2, 37, 5, 81, 
    4, 74, 8, 86, 6, 91, 5, 26, 0, 45, 1, 13, 2, 89, 7, 20, 3, 62, 
    6, 16, 8, 68, 3, 62, 2,  6, 1, 98, 7, 25, 5, 89, 4, 81, 0, 40, 
    8, 45, 0, 87, 6, 30, 7, 44, 3, 95, 1, 43, 5, 98, 4, 21, 2,  7, 
    5, 37, 0, 83, 6, 51, 7, 21, 3, 92, 1, 32, 8, 66, 2, 28, 4, 55, 
    0, 67, 5, 20, 1, 19, 4,  8, 8, 13, 6, 12, 3, 21, 2, 78, 7, 15, 
    6, 13, 4, 54, 2, 17, 0, 13, 8, 16, 7, 41, 3, 76, 5, 53, 1, 11
  };
  const int q3853[] = {
    9, 9, // Number of jobs and machines
    6, 64, 3, 18, 2, 51, 8, 15, 0, 53, 1, 98, 7, 57, 4, 26, 5, 95, 
    7, 53, 5, 90, 6, 92, 4, 41, 0, 23, 2, 70, 8, 81, 1, 46, 3, 33, 
    7, 42, 5, 31, 2, 40, 6, 95, 3, 48, 0, 44, 4, 97, 1, 68, 8, 76, 
    2, 27, 3, 20, 0, 29, 8, 14, 4, 44, 6, 32, 7, 91, 1, 21, 5,  5, 
    1, 83, 2, 21, 0, 20, 4, 28, 5, 11, 8,  8, 3, 86, 6, 43, 7, 60, 
    2, 14, 6, 15, 1,  3, 4, 72, 7, 67, 8, 27, 3, 66, 0, 64, 5, 98, 
    3, 72, 6, 30, 7, 54, 2,  1, 1, 91, 4, 20, 8, 77, 5, 54, 0, 31, 
    8, 81, 2, 26, 1, 60, 5,  6, 7,  1, 6, 32, 4, 80, 0, 43, 3, 77, 
    1, 21, 0, 18, 6, 26, 5, 27, 7, 42, 3, 12, 4, 65, 2, 48, 8, 97
  };
  const int q3854[] = {
    9, 9, // Number of jobs and machines
    8, 46, 5, 39, 4, 71, 6, 33, 1, 87, 7, 89, 3, 67, 0, 38, 2, 70, 
    5, 18, 0, 27, 8, 72, 7, 70, 1, 44, 2, 54, 6, 59, 3, 31, 4, 11, 
    5, 77, 0, 55, 3, 96, 7, 65, 6, 81, 8, 25, 4, 54, 2, 41, 1, 16, 
    1, 67, 3, 71, 5, 17, 8, 43, 4, 24, 2, 75, 7, 23, 0, 58, 6, 41, 
    5, 40, 0, 18, 2,  1, 7, 49, 4, 17, 8, 30, 1, 95, 6, 25, 3, 30, 
    3, 74, 7, 66, 1, 80, 2, 82, 5, 53, 8, 67, 4, 75, 0, 11, 6, 44, 
    7,  5, 6,  1, 5, 28, 1, 30, 8, 50, 0, 84, 3, 45, 4, 58, 2, 90, 
    8, 57, 2, 53, 5, 25, 3, 17, 1, 29, 4, 45, 0, 25, 7, 63, 6, 77, 
    0, 61, 4, 94, 7, 82, 5, 28, 1,  5, 8, 53, 6, 67, 2, 60, 3, 23
  };
  const int q3855[] = {
    9, 9, // Number of jobs and machines
    7, 88, 1, 41, 5, 46, 2, 40, 3, 18, 4, 24, 6,  9, 0, 61, 8, 66, 
    4, 64, 5, 76, 1, 99, 3, 84, 2, 31, 8, 71, 0, 13, 7, 87, 6, 25, 
    8,  5, 1, 77, 5, 41, 0, 71, 2, 14, 3, 31, 6, 64, 4, 56, 7, 17, 
    5,  8, 2, 73, 4, 10, 8, 68, 3, 85, 0, 77, 7, 80, 6, 97, 1, 92, 
    8, 45, 7, 75, 4,  8, 1, 71, 6, 10, 5, 69, 3, 11, 0, 93, 2, 96, 
    7, 89, 0, 13, 1, 80, 2, 13, 6, 96, 4, 81, 8, 44, 5, 98, 3, 95, 
    6, 51, 4, 20, 0, 42, 8, 66, 1, 14, 5, 86, 3, 71, 7, 35, 2, 63, 
    3, 59, 1, 33, 8, 82, 5, 20, 7, 94, 4, 94, 0,  1, 6, 74, 2, 47, 
    5, 47, 8, 98, 1, 52, 0, 30, 4, 69, 6, 50, 7, 45, 3, 91, 2, 33
  };
  const int q3856[] = {
    9, 9, // Number of jobs and machines
    5, 56, 6, 89, 3, 29, 4, 25, 1, 76, 7, 52, 2, 61, 8, 85, 0, 90, 
    4, 81, 8, 22, 0, 93, 2, 65, 5, 51, 6, 88, 3, 28, 7, 52, 1, 70, 
    6, 96, 2, 64, 8,  3, 0, 32, 7,  6, 4, 26, 3, 27, 5, 51, 1, 97, 
    6, 24, 5, 15, 8, 22, 7, 16, 3, 26, 4, 73, 0, 52, 1, 62, 2, 74, 
    8, 69, 2,  7, 6, 12, 0, 15, 4, 41, 3, 13, 5,  5, 1, 85, 7, 55, 
    7, 51, 5, 19, 3, 67, 6, 80, 0, 40, 1,  2, 4,  2, 8, 35, 2, 55, 
    1, 27, 3, 33, 5, 32, 6, 15, 2, 46, 8, 66, 4, 31, 0, 62, 7, 12, 
    4, 93, 1, 32, 2, 88, 0, 44, 5,  1, 3,  7, 6, 68, 8, 77, 7, 44, 
    4, 56, 3, 98, 5, 36, 1, 65, 0, 64, 8, 17, 7, 60, 2, 78, 6, 56
  };
  const int q3857[] = {
    9, 9, // Number of jobs and machines
    2, 19, 5, 80, 3, 97, 1, 56, 0, 78, 8, 36, 6, 12, 7, 13, 4, 61, 
    4, 73, 6, 34, 2, 25, 1, 70, 3, 50, 0, 76, 7, 68, 5, 34, 8, 24, 
    0, 30, 7, 85, 8, 26, 3,  2, 6, 31, 2, 62, 1,  2, 5, 62, 4, 72, 
    5, 70, 0, 82, 8, 76, 3, 76, 6, 45, 7, 67, 4, 25, 2,  7, 1, 25, 
    2, 68, 7, 99, 4, 16, 5, 92, 8, 29, 0, 72, 3,  9, 1, 35, 6, 52, 
    2, 32, 1,  2, 3, 35, 6,  6, 0, 47, 7, 81, 8, 33, 5, 32, 4, 66, 
    1, 24, 5, 35, 7, 64, 3, 49, 4, 22, 8, 61, 0, 29, 2, 77, 6, 23, 
    5, 67, 8, 24, 1, 65, 7, 16, 2, 37, 0, 85, 3, 88, 6, 29, 4, 37, 
    5, 82, 1, 94, 6, 51, 4, 78, 0, 30, 2, 78, 3, 41, 8, 13, 7, 70
  };
  const int q3858[] = {
    9, 9, // Number of jobs and machines
    3, 45, 6, 75, 8, 17, 7, 97, 5, 95, 1, 97, 4, 96, 0, 55, 2, 10, 
    3, 63, 5, 69, 6, 63, 1, 43, 8, 46, 4, 11, 0, 30, 2, 80, 7, 56, 
    7, 65, 8, 62, 6, 41, 3, 41, 4, 10, 5, 50, 2, 37, 1, 10, 0, 86, 
    5, 58, 8, 95, 0, 33, 2, 98, 1, 66, 4, 10, 3, 78, 6, 98, 7, 37, 
    3, 71, 0, 30, 4,  8, 5,  9, 8,  6, 1, 66, 6, 63, 7, 87, 2, 79, 
    4,  8, 1, 72, 6, 45, 0, 38, 2, 61, 5, 55, 3, 60, 8, 95, 7, 52, 
    8, 23, 6, 16, 1, 92, 3, 42, 2, 48, 5, 25, 7, 70, 0, 13, 4, 51, 
    8, 20, 0, 73, 2, 81, 7, 88, 5, 17, 3, 23, 4, 32, 1, 22, 6, 91, 
    5, 99, 0, 75, 8, 71, 4, 73, 1, 11, 3, 76, 6, 11, 2,  1, 7, 94
  };
  const int q3859[] = {
    9, 9, // Number of jobs and machines
    1, 90, 5, 63, 8, 32, 2,  6, 0, 50, 3, 31, 7, 46, 6, 49, 4, 84, 
    5, 26, 8, 78, 3, 80, 4, 48, 0,  4, 1, 20, 2, 62, 6, 44, 7, 69, 
    4, 70, 7, 15, 3, 39, 8, 40, 6, 66, 0, 96, 5, 33, 2, 50, 1, 32, 
    7, 26, 4, 74, 0, 44, 8, 91, 5, 29, 2, 25, 6, 17, 1, 90, 3, 20, 
    3, 88, 5, 11, 8, 50, 2, 16, 0, 51, 7, 73, 4, 34, 6, 70, 1, 76, 
    6, 30, 4, 93, 3, 14, 2, 72, 8, 80, 7, 19, 5,  9, 1, 16, 0, 32, 
    1, 30, 5, 48, 3, 16, 7, 33, 2, 15, 4, 69, 0, 19, 8, 97, 6, 71, 
    6, 81, 8, 89, 4,  5, 2,  2, 3, 17, 7, 98, 5, 29, 0, 22, 1,  4, 
    8, 32, 6, 33, 4, 84, 7, 85, 2, 15, 1, 92, 3, 26, 0, 57, 5, 71
  };
  const int q3860[] = {
    9, 9, // Number of jobs and machines
    7, 94, 5, 17, 3, 63, 8, 36, 2, 26, 0, 99, 4, 64, 6, 23, 1, 38, 
    6, 48, 2, 83, 8, 21, 4, 68, 7, 83, 1, 81, 5, 61, 0, 27, 3, 62, 
    8, 46, 2,  7, 1, 69, 7, 84, 0, 56, 5, 23, 4, 30, 6, 30, 3, 80, 
    0,  1, 1, 65, 8,  1, 4, 70, 2, 27, 6, 69, 5, 44, 3, 37, 7, 76, 
    4, 41, 0, 68, 6, 51, 2, 50, 5, 11, 7, 41, 1, 86, 8, 59, 3, 75, 
    2, 20, 7, 87, 6, 25, 8, 79, 0, 87, 5, 17, 4, 56, 1, 83, 3,  5, 
    7, 65, 4, 67, 3, 56, 5, 49, 0, 92, 8, 78, 6, 82, 2, 11, 1, 28, 
    7, 48, 3, 37, 5, 41, 4, 50, 0, 26, 6, 28, 2, 57, 8, 74, 1, 50, 
    2, 46, 6, 79, 3, 17, 8, 98, 7, 84, 5, 30, 1, 86, 4, 18, 0, 37
  };
  const int q3861[] = {
    9, 9, // Number of jobs and machines
    8, 89, 3, 43, 7, 44, 4, 21, 5, 21, 1, 49, 2, 11, 6, 39, 0, 86, 
    0, 91, 6, 74, 7, 39, 4, 72, 3, 71, 2, 20, 8, 44, 5,  1, 1, 87, 
    2, 97, 1,  2, 8, 75, 0, 73, 6, 60, 7, 35, 5, 25, 4, 91, 3, 32, 
    1, 71, 6, 54, 4, 34, 5, 84, 8, 62, 2,  3, 3, 52, 7, 37, 0, 33, 
    6, 86, 7, 25, 0, 27, 5, 89, 8, 41, 2, 10, 4, 17, 1, 68, 3, 68, 
    6, 30, 7, 62, 1, 45, 0, 53, 8, 76, 2, 51, 4, 27, 3, 38, 5, 45, 
    8, 93, 6, 54, 3, 89, 4, 20, 2, 89, 5, 79, 1,  3, 0, 76, 7, 55, 
    1,  7, 7, 35, 4, 12, 8, 67, 5, 25, 3, 59, 2, 40, 0,  9, 6, 84, 
    6, 93, 4, 80, 1, 92, 7, 15, 2, 35, 8,  1, 0, 96, 3, 96, 5, 12
  };
  const int q3862[] = {
    9, 9, // Number of jobs and machines
    3, 26, 5,  6, 0, 31, 8, 97, 1, 89, 4, 15, 6, 55, 2, 66, 7, 53, 
    1, 40, 4, 81, 2, 68, 5, 12, 8, 15, 6, 28, 3, 34, 0, 27, 7, 96, 
    0, 15, 1, 85, 7, 10, 4, 74, 3, 88, 8, 24, 6, 46, 2, 84, 5, 24, 
    1, 40, 7,  4, 6, 32, 0, 67, 2, 13, 5, 73, 3, 91, 4, 49, 8, 23, 
    1, 13, 6, 80, 7, 15, 0, 33, 3, 62, 2,  3, 8,  2, 5, 75, 4, 60, 
    1, 58, 2, 14, 8, 40, 4, 75, 7, 27, 3, 76, 6, 89, 5, 58, 0, 14, 
    3, 52, 6, 58, 8, 19, 7, 47, 4, 56, 0, 70, 5,  5, 2, 63, 1, 97, 
    7,  1, 6, 37, 3, 43, 8, 97, 0, 71, 2, 34, 4,  9, 5, 62, 1, 86, 
    4, 39, 1, 51, 8, 24, 2, 12, 0, 46, 5, 50, 3,  8, 7, 76, 6, 65
  };
  const int q3863[] = {
    9, 9, // Number of jobs and machines
    4, 96, 2, 32, 3, 13, 0,  7, 5, 53, 7, 75, 1, 77, 6, 52, 8,  1, 
    5,  7, 7,  5, 0, 65, 3, 19, 1, 86, 8, 46, 2, 43, 6, 59, 4, 36, 
    1, 32, 7, 60, 8, 87, 3, 79, 0, 77, 5, 12, 4, 52, 2, 72, 6, 15, 
    2,  4, 8, 81, 0, 62, 1,  4, 4, 82, 3, 41, 7, 52, 6, 87, 5, 65, 
    1, 30, 7, 19, 6, 72, 3, 98, 0, 57, 8, 28, 4, 24, 5, 63, 2, 47, 
    5, 82, 0, 53, 4, 90, 7, 77, 6, 62, 3, 25, 1, 78, 8, 29, 2, 64, 
    6, 48, 4, 59, 0, 41, 1,  7, 7, 17, 8, 12, 5, 69, 2, 29, 3, 25, 
    1,  1, 8, 75, 4, 10, 7, 58, 0, 52, 5, 13, 3, 44, 2, 21, 6, 47, 
    7, 39, 6, 42, 2, 29, 4, 32, 3, 61, 8, 20, 5, 76, 0, 70, 1, 71
  };
  const int q3864[] = {
    9, 9, // Number of jobs and machines
    4, 93, 7, 96, 3, 15, 0, 25, 1, 34, 8, 54, 6, 87, 2,  5, 5, 23, 
    7, 67, 5, 14, 4, 39, 6, 27, 8, 91, 3,  4, 1, 87, 2, 46, 0, 79, 
    8, 71, 3, 49, 7, 22, 5, 73, 4, 74, 0, 51, 1, 75, 2, 13, 6, 88, 
    6,  9, 4, 18, 8, 85, 1, 23, 0, 84, 3, 73, 2, 84, 7,  6, 5, 50, 
    4, 18, 0, 19, 1, 29, 5, 86, 8, 27, 2, 25, 7, 66, 6, 58, 3, 13, 
    2, 60, 8, 30, 0, 14, 6, 94, 1, 85, 3, 22, 4, 18, 7, 75, 5, 88, 
    4, 76, 7, 41, 0, 11, 8, 86, 3,  7, 5, 41, 2, 76, 6, 45, 1, 79, 
    7, 82, 4, 19, 6,  8, 8, 40, 2, 68, 1, 92, 0, 78, 5, 60, 3, 46, 
    0, 57, 4, 83, 6, 91, 1, 28, 5, 73, 8, 35, 2, 16, 3, 34, 7,  5
  };
  const int q3865[] = {
    9, 9, // Number of jobs and machines
    7, 30, 0, 88, 5, 17, 8, 72, 1, 37, 6, 41, 2, 63, 3, 29, 4, 26, 
    2, 75, 8, 64, 0, 25, 4, 38, 3, 38, 6, 71, 5, 22, 7, 86, 1, 13, 
    6, 46, 1, 62, 8, 96, 0, 69, 3, 21, 4,  5, 5, 65, 7, 98, 2, 35, 
    0, 49, 4, 70, 1,  5, 6, 15, 3,  4, 7, 45, 2, 22, 5, 37, 8, 78, 
    3, 41, 8, 80, 2, 86, 6,  5, 7, 65, 1, 43, 4, 48, 0, 82, 5, 66, 
    8, 55, 3, 46, 2, 62, 0, 76, 5, 21, 1, 62, 4, 68, 6, 44, 7, 63, 
    7, 72, 5, 88, 6, 33, 1, 92, 2, 72, 8, 89, 0, 33, 3, 37, 4, 57, 
    7, 22, 3, 41, 5, 25, 8,  1, 0, 93, 2,  1, 4, 16, 1, 16, 6, 24, 
    8, 69, 5, 84, 7, 93, 2, 70, 4, 19, 0, 92, 6, 51, 3, 19, 1, 55
  };
  const int q3866[] = {
    9, 9, // Number of jobs and machines
    2, 66, 7, 99, 0, 72, 4, 68, 5, 93, 3, 79, 1, 60, 6, 58, 8, 76, 
    8, 40, 4, 93, 7, 81, 2, 57, 1, 46, 5, 40, 6, 86, 0, 88, 3, 19, 
    5, 85, 1, 12, 0, 99, 2, 87, 8, 87, 3, 22, 7, 13, 4, 82, 6, 81, 
    7, 16, 3, 42, 4, 87, 0, 14, 5, 88, 2, 90, 6, 76, 1, 86, 8, 99, 
    0, 74, 3, 25, 7,  9, 1,  6, 2, 98, 4, 27, 5, 60, 8, 71, 6, 66, 
    4, 48, 1, 28, 7, 92, 6, 46, 3, 13, 5, 88, 8, 39, 2, 34, 0, 25, 
    5, 91, 7, 56, 4, 95, 0, 61, 8, 18, 3, 34, 2, 27, 6, 88, 1, 40, 
    2,  1, 4, 32, 3, 64, 1, 79, 5, 12, 0, 62, 8, 82, 7, 31, 6, 80, 
    6, 18, 7, 23, 5, 80, 0, 88, 2, 36, 8, 63, 1, 48, 4, 41, 3, 76
  };
  const int q3867[] = {
    9, 9, // Number of jobs and machines
    5, 83, 1, 27, 4, 55, 8, 96, 6, 25, 7, 68, 3,  2, 2, 19, 0, 22, 
    7, 88, 1, 44, 2,  4, 5, 63, 6, 23, 0, 85, 4, 93, 8, 84, 3, 87, 
    3, 72, 0, 26, 4, 91, 1, 95, 7, 76, 5, 41, 2, 82, 8, 76, 6, 14, 
    7, 40, 6, 17, 4,  5, 1, 46, 5, 25, 0, 80, 2,  1, 8, 86, 3, 65, 
    7, 54, 6, 64, 5, 41, 3, 49, 4,  5, 1, 94, 0, 42, 2, 76, 8, 97, 
    2,  5, 3,  1, 4, 45, 6, 70, 8, 56, 1, 94, 5, 17, 7, 57, 0, 77, 
    3, 11, 4,  5, 0, 93, 8, 61, 6, 95, 7, 52, 2,  5, 5, 66, 1, 52, 
    1, 52, 4, 63, 2,  6, 8, 48, 5, 85, 0, 94, 6, 10, 3, 24, 7, 11, 
    3, 16, 6, 25, 0, 13, 5, 20, 1, 60, 8, 56, 7,  3, 2, 65, 4, 98
  };
  const int q3868[] = {
    9, 9, // Number of jobs and machines
    1, 42, 3, 18, 7, 52, 2, 62, 8, 65, 0, 19, 6, 33, 4, 43, 5, 14, 
    3, 99, 0, 41, 2, 24, 4, 89, 6, 48, 5, 99, 7, 21, 1, 58, 8, 36, 
    6, 44, 8, 41, 7, 97, 5, 83, 1,  4, 0, 54, 3, 52, 2, 52, 4, 26, 
    5, 62, 3, 58, 1, 60, 6, 50, 4, 25, 8,  5, 0, 39, 2, 72, 7, 45, 
    3, 18, 6,  4, 7, 65, 8, 19, 2, 11, 5, 38, 1, 38, 4, 31, 0, 24, 
    5, 15, 0, 74, 6, 38, 8, 26, 4, 53, 7, 32, 3, 46, 2, 12, 1, 12, 
    1, 68, 2, 59, 0, 16, 7, 92, 6, 82, 5, 29, 4, 32, 8, 68, 3, 80, 
    7, 19, 2, 66, 8, 71, 5,  2, 3, 86, 0, 17, 1, 46, 4, 20, 6, 88, 
    5, 80, 6, 32, 8, 88, 4, 53, 3, 72, 1, 90, 2, 26, 0, 87, 7, 78
  };
  const int q3869[] = {
    9, 9, // Number of jobs and machines
    7, 92, 6, 10, 4,  6, 1, 69, 5, 79, 8, 33, 0, 18, 3, 55, 2, 90, 
    4, 13, 2, 44, 0, 92, 7,  7, 6, 43, 1,  4, 8, 35, 5, 85, 3, 76, 
    3, 29, 6, 34, 5, 20, 1, 43, 8, 79, 4, 60, 2, 57, 0, 85, 7, 23, 
    0, 60, 4, 98, 3, 35, 6, 19, 7, 15, 2, 77, 1, 97, 5, 41, 8, 10, 
    8, 83, 2, 23, 0, 79, 6, 53, 7, 95, 3, 48, 1, 86, 4,  2, 5, 61, 
    1, 80, 2, 95, 0, 95, 7, 93, 5, 84, 4, 40, 6, 72, 3, 41, 8, 61, 
    2, 42, 5, 87, 1, 19, 7, 34, 4, 47, 8,  8, 3,  4, 6, 90, 0, 27, 
    6, 99, 2, 59, 0, 15, 4, 17, 3, 15, 8, 27, 7, 79, 1, 68, 5, 12, 
    0, 82, 2, 92, 1, 41, 8, 23, 6, 35, 5, 51, 3, 26, 4,  3, 7,  3
  };
  const int q3870[] = {
    9, 9, // Number of jobs and machines
    7, 62, 6, 69, 0, 41, 1, 38, 8, 70, 2, 79, 5, 79, 4, 96, 3, 58, 
    4, 96, 1, 75, 5, 28, 0, 26, 7, 56, 3, 40, 8,  7, 2, 30, 6, 27, 
    5, 46, 0, 68, 4, 83, 2, 80, 1, 88, 6, 74, 7, 12, 8, 50, 3, 89, 
    4,  7, 5, 96, 0, 50, 3, 14, 8,  6, 7, 46, 1, 13, 6, 85, 2, 66, 
    2, 77, 7, 95, 4,  7, 8, 84, 0, 54, 1, 47, 5, 64, 6, 14, 3, 47, 
    4, 86, 8,  3, 6, 90, 3, 85, 5, 75, 1,  5, 0, 83, 7, 16, 2, 34, 
    4, 70, 0, 89, 6, 96, 8, 58, 3, 33, 5, 36, 7, 70, 2, 85, 1, 78, 
    1, 92, 8, 27, 0, 64, 6, 73, 3, 12, 7, 75, 5, 42, 4, 21, 2, 15, 
    0, 98, 4, 43, 6, 31, 1, 35, 7, 69, 5, 53, 3, 26, 8, 42, 2,  9
  };
  const int q3871[] = {
    9, 9, // Number of jobs and machines
    0,  5, 2, 73, 6, 28, 8, 71, 1, 66, 7,  5, 5, 53, 3, 69, 4,  9, 
    6, 13, 2, 63, 1, 13, 4, 27, 0, 63, 7, 15, 8, 31, 3, 99, 5, 65, 
    7, 70, 0, 52, 4, 49, 2, 38, 6, 55, 5, 13, 8,  8, 1, 46, 3, 63, 
    5,  5, 0, 38, 4, 86, 8, 27, 3, 23, 1, 47, 7, 49, 6, 27, 2, 74, 
    6, 16, 1, 88, 3, 96, 7, 28, 8, 76, 5, 45, 0,  1, 4,  6, 2, 62, 
    2, 11, 6, 36, 7, 69, 1, 73, 3, 86, 5, 47, 0, 89, 4, 13, 8, 87, 
    2, 97, 1, 55, 4, 31, 8, 50, 6, 61, 0, 26, 7,  1, 5, 62, 3, 98, 
    7, 68, 5, 43, 6, 26, 4, 36, 2, 96, 0, 50, 8, 52, 1, 85, 3, 11, 
    3, 55, 6, 96, 2, 18, 1, 18, 7, 87, 0,  6, 8, 27, 5, 27, 4, 64
  };
  const int q3872[] = {
    9, 9, // Number of jobs and machines
    6, 64, 1, 73, 0, 18, 2, 50, 8, 79, 7, 14, 3, 69, 4, 99, 5, 21, 
    1, 13, 2, 29, 7, 42, 8, 18, 4, 44, 6, 67, 3, 80, 0, 41, 5, 47, 
    7, 68, 0, 47, 6, 56, 5, 96, 4, 41, 3, 78, 8, 28, 2, 16, 1, 76, 
    0, 61, 7, 95, 5, 49, 4, 25, 6, 94, 3, 87, 2, 37, 8, 41, 1,  1, 
    0, 42, 6, 41, 4, 54, 7, 13, 1, 43, 8, 50, 5, 75, 3, 25, 2, 12, 
    0, 26, 8, 21, 7, 35, 5, 12, 2, 56, 6, 52, 3,  7, 4, 67, 1, 90, 
    6, 29, 4, 51, 5, 68, 8, 28, 3, 57, 2,  1, 7, 53, 1,  6, 0, 96, 
    8, 43, 0, 88, 4, 50, 6, 11, 1, 42, 5, 10, 3, 35, 7, 37, 2, 95, 
    4, 64, 7, 69, 5, 45, 8, 79, 6, 27, 0,  3, 2, 77, 3, 76, 1, 74
  };
  const int q3873[] = {
    9, 9, // Number of jobs and machines
    8, 41, 5, 56, 7, 49, 6,  5, 3, 93, 0, 90, 1, 64, 4, 92, 2, 99, 
    4, 23, 7, 58, 5, 20, 6, 86, 0, 62, 8, 67, 2, 38, 1, 62, 3, 95, 
    1, 57, 6, 11, 5, 73, 8, 18, 3, 86, 0, 28, 2, 24, 4, 10, 7,  1, 
    2, 68, 3, 91, 5, 16, 8, 56, 6, 30, 4, 90, 7, 26, 0, 31, 1, 46, 
    6, 24, 2, 61, 0, 12, 7, 90, 4, 92, 5, 99, 3, 16, 1, 75, 8, 15, 
    7, 68, 6, 75, 1, 77, 8, 67, 5, 54, 0, 38, 2, 75, 4, 43, 3, 55, 
    7, 27, 2, 84, 4, 31, 1, 24, 6, 17, 3,  4, 5, 59, 0,  5, 8, 47, 
    2, 80, 1, 24, 3, 98, 5, 63, 4, 24, 6, 38, 0, 33, 7,  2, 8, 78, 
    3, 21, 5, 28, 1, 90, 4, 25, 6, 67, 7, 14, 0, 55, 8, 13, 2, 42
  };
  const int q3874[] = {
    9, 9, // Number of jobs and machines
    1, 65, 7, 58, 4, 56, 0, 51, 8, 51, 2, 18, 5, 81, 3, 69, 6, 74, 
    8, 40, 2, 84, 3, 93, 4, 22, 6, 15, 0,  9, 5, 22, 1, 49, 7, 31, 
    8, 55, 1, 44, 3, 31, 7, 91, 6, 95, 0, 73, 2, 88, 4, 37, 5, 84, 
    8,  5, 3,  5, 7, 70, 4, 73, 1, 81, 2,  8, 5, 47, 0, 56, 6, 65, 
    2, 94, 3, 45, 1, 49, 4, 18, 0, 24, 6, 52, 8, 89, 7, 25, 5, 26, 
    0, 24, 7, 55, 5, 25, 2, 27, 8, 80, 6, 60, 3, 68, 4, 64, 1, 97, 
    6,  7, 5, 35, 0,  5, 2, 54, 1, 83, 3, 62, 7, 80, 4, 39, 8, 52, 
    1, 14, 4, 75, 3, 66, 2, 13, 5, 59, 8, 44, 7, 77, 0, 63, 6, 46, 
    2, 28, 4, 81, 8, 32, 0, 87, 7, 22, 3, 90, 6, 96, 5, 18, 1, 16
  };
  const int q3875[] = {
    9, 9, // Number of jobs and machines
    6, 56, 1, 13, 5, 88, 4, 80, 7, 89, 0, 69, 8, 15, 3, 85, 2, 79, 
    8, 47, 7, 81, 6, 77, 3, 44, 1, 41, 4, 58, 5, 71, 0, 49, 2, 33, 
    5, 39, 4, 11, 6, 21, 8, 41, 1, 75, 7, 55, 2, 13, 0, 57, 3, 46, 
    7, 43, 4, 82, 1, 90, 3, 23, 8, 44, 0, 85, 6, 34, 2, 99, 5, 40, 
    3, 13, 8, 78, 5, 89, 7, 72, 2, 57, 6, 95, 4, 31, 1, 37, 0, 24, 
    7,  7, 6, 20, 0, 85, 4, 54, 5,  1, 3, 58, 8, 15, 1, 49, 2, 19, 
    5, 45, 7, 19, 8, 27, 2,  3, 3, 32, 4, 30, 0, 19, 6, 52, 1, 57, 
    0, 37, 8, 79, 2, 70, 6, 40, 5, 41, 4, 65, 7, 73, 3, 83, 1, 25, 
    0, 63, 3,  4, 4, 49, 1, 25, 5, 13, 6, 86, 7, 35, 2,  7, 8, 59
  };
  const int q3876[] = {
    9, 9, // Number of jobs and machines
    3, 79, 0, 22, 6,  8, 8, 30, 4, 82, 2, 47, 5, 26, 7, 85, 1, 49, 
    4, 11, 7, 76, 2, 19, 1, 44, 5, 75, 6, 25, 8,  1, 3, 50, 0, 96, 
    7, 90, 2, 36, 3, 74, 5, 95, 6, 56, 8, 55, 0, 18, 1, 27, 4, 46, 
    1, 90, 5, 53, 3, 85, 8, 39, 6,  7, 7, 75, 2, 77, 0, 42, 4, 86, 
    3, 35, 4, 84, 6, 37, 0, 96, 1, 33, 5, 36, 8,  1, 7, 75, 2, 53, 
    4, 50, 6, 95, 3,  5, 2, 50, 0,  9, 1, 84, 8, 69, 5, 23, 7, 32, 
    0, 30, 4, 93, 7, 33, 5, 84, 3, 32, 8, 38, 1, 64, 2, 76, 6, 27, 
    2,  2, 1,  9, 3, 25, 0, 68, 7,  6, 5, 94, 8, 26, 6,  2, 4, 75, 
    5, 13, 6, 99, 1, 69, 2, 89, 8,  2, 3, 73, 7, 98, 0, 78, 4, 65
  };
  const int q3877[] = {
    9, 9, // Number of jobs and machines
    0, 85, 7, 14, 8, 94, 5, 47, 6, 75, 2, 15, 3, 83, 4, 37, 1, 76, 
    5,  3, 6, 26, 2, 39, 4, 36, 0, 66, 3, 79, 7, 78, 8, 81, 1, 42, 
    8, 52, 4, 65, 6, 58, 2,  2, 7,  7, 3, 77, 5, 32, 1, 16, 0, 95, 
    5, 34, 7, 60, 1, 55, 2,  7, 8, 82, 0, 56, 6,  5, 3, 32, 4, 70, 
    6, 73, 0, 60, 4, 79, 7, 20, 5, 97, 8, 96, 2, 10, 1, 65, 3, 82, 
    4, 12, 6, 11, 7,  4, 8, 22, 0, 10, 1, 63, 2, 54, 5, 71, 3,  5, 
    6, 12, 8, 91, 4, 10, 3, 33, 1, 45, 2, 44, 0, 63, 5, 32, 7, 44, 
    7, 86, 5, 54, 1, 55, 0, 96, 3, 93, 8, 68, 6, 17, 4, 43, 2, 49, 
    3, 48, 0,  1, 8, 77, 7,  4, 2, 18, 4, 77, 6, 51, 5, 53, 1, 69
  };
  const int q3878[] = {
    9, 9, // Number of jobs and machines
    1, 44, 0, 72, 5,  3, 3, 78, 8, 58, 7, 69, 6, 36, 2, 57, 4, 43, 
    8, 15, 6, 15, 4, 83, 0, 76, 2, 45, 5, 10, 1, 97, 7, 67, 3, 85, 
    7,  9, 3, 33, 0, 78, 2, 74, 4, 49, 5, 98, 1, 76, 8, 13, 6, 63, 
    4, 43, 0,  7, 5, 39, 6, 20, 8, 16, 7, 65, 3, 13, 2, 93, 1, 93, 
    5, 91, 0, 21, 8, 35, 7, 41, 3, 56, 1, 19, 6, 84, 4,  5, 2, 63, 
    1, 80, 3, 23, 2, 13, 0, 10, 8, 67, 5, 77, 6, 60, 4, 96, 7, 26, 
    2, 21, 3, 65, 0,  4, 6, 26, 7, 49, 8, 22, 1, 45, 5, 93, 4, 30, 
    3, 22, 5,  3, 0, 49, 1, 19, 2, 39, 6, 92, 8, 77, 7,  3, 4, 22, 
    1, 87, 2, 77, 0, 55, 5, 82, 6, 68, 3, 87, 8, 38, 4, 73, 7,  3
  };
  const int q3879[] = {
    9, 9, // Number of jobs and machines
    4, 69, 1, 82, 0, 70, 3, 62, 6, 96, 2, 86, 7, 62, 8, 73, 5, 66, 
    5, 94, 0, 79, 7, 35, 1, 52, 3, 44, 4, 63, 2, 83, 6, 46, 8, 98, 
    3,  4, 7, 90, 1, 79, 6, 12, 5, 28, 8, 71, 4, 28, 2, 95, 0, 33, 
    4, 74, 1,  8, 5, 28, 8, 82, 6, 67, 3, 28, 2, 94, 7, 80, 0, 43, 
    0, 89, 4, 38, 6, 71, 2, 35, 3, 41, 7, 34, 8, 36, 5, 42, 1, 47, 
    8, 60, 3, 24, 2, 38, 6, 14, 5, 91, 0, 19, 4, 45, 7,  1, 1, 34, 
    5, 59, 1, 37, 6, 20, 4, 75, 2, 24, 3, 57, 0, 66, 7, 86, 8, 27, 
    2, 43, 0, 65, 1, 76, 5, 40, 4, 44, 6, 41, 7,  2, 3, 92, 8, 84, 
    5, 74, 0,  9, 6, 76, 8, 38, 7, 35, 2,  9, 1, 55, 4, 94, 3, 93
  };
  const int q3880[] = {
    9, 9, // Number of jobs and machines
    1, 53, 3, 98, 2, 98, 8, 24, 5, 96, 4, 80, 0, 19, 6, 15, 7, 46, 
    0, 27, 7,  8, 2, 62, 4, 45, 6, 12, 5, 36, 8,  7, 1, 19, 3,  2, 
    3, 76, 0, 47, 5,  3, 6, 22, 1, 72, 7,  8, 4, 34, 2, 24, 8, 18, 
    3, 75, 1, 32, 4, 21, 0, 75, 7, 20, 2, 85, 5, 25, 6, 97, 8, 69, 
    5, 68, 7, 35, 3, 47, 6, 13, 0, 84, 1, 60, 2, 28, 4,  8, 8, 47, 
    6,  8, 2, 96, 3, 12, 1, 60, 7, 76, 5, 39, 4, 81, 0, 32, 8, 75, 
    6, 37, 0, 64, 8, 54, 7, 90, 3, 80, 2, 76, 4, 90, 1, 93, 5, 12, 
    1, 78, 5, 69, 8, 75, 2, 25, 6, 69, 4, 95, 3, 87, 7, 37, 0, 85, 
    7, 44, 2,  9, 3, 78, 6, 61, 5, 34, 0, 86, 4, 45, 1, 48, 8, 72
  };
  const int q3881[] = {
    9, 9, // Number of jobs and machines
    5, 69, 3, 42, 7, 41, 6, 61, 8, 27, 1, 63, 0, 36, 2, 46, 4, 24, 
    1, 67, 0, 48, 3, 68, 2, 34, 8, 10, 5, 70, 6, 16, 4, 19, 7, 87, 
    6, 77, 4, 13, 1,  5, 2,  5, 8, 87, 7, 47, 3, 66, 5, 72, 0,  6, 
    5,  6, 7, 83, 0, 79, 6, 34, 8, 66, 3, 40, 2, 82, 4, 49, 1, 15, 
    8, 79, 2, 60, 7, 46, 5, 86, 1, 43, 0, 92, 3, 89, 4, 96, 6, 94, 
    3, 83, 1,  2, 0, 49, 8, 67, 4, 19, 2, 82, 6, 50, 5, 78, 7, 35, 
    0, 76, 5, 98, 2, 82, 4, 73, 1,  7, 3, 47, 6, 26, 7, 69, 8, 90, 
    8, 39, 1, 73, 6, 95, 5, 67, 4, 95, 3, 46, 0, 28, 2,  2, 7, 31, 
    6, 56, 4, 56, 5, 19, 8, 70, 2,  9, 3, 66, 1, 85, 0, 53, 7, 68
  };
  const int q3882[] = {
    9, 9, // Number of jobs and machines
    2, 44, 1,  7, 7, 49, 3, 14, 0, 92, 5, 61, 4, 57, 6, 65, 8, 68, 
    0, 41, 1, 94, 7, 85, 5, 74, 8, 99, 2, 42, 4, 26, 6, 78, 3,  7, 
    1, 89, 3, 37, 2, 12, 6, 57, 5, 94, 0, 26, 8, 36, 4, 71, 7, 63, 
    8, 44, 0, 16, 7, 78, 6, 94, 5, 12, 4, 87, 1, 14, 3, 63, 2, 81, 
    1, 74, 3, 87, 6, 12, 5, 74, 8, 46, 7, 41, 2, 19, 4, 89, 0, 43, 
    0, 63, 8, 92, 2, 80, 6, 12, 1, 49, 5, 59, 3, 84, 4, 54, 7, 65, 
    5, 13, 6, 49, 0, 85, 8, 69, 4, 12, 7, 47, 3, 49, 2, 55, 1, 78, 
    2, 22, 7, 39, 1, 57, 4, 41, 6, 41, 5, 65, 8, 45, 3, 68, 0, 56, 
    4, 60, 2, 85, 8, 13, 0, 71, 5, 48, 7, 81, 3, 47, 1, 39, 6, 49
  };
  const int q3883[] = {
    9, 9, // Number of jobs and machines
    5, 65, 0, 91, 1, 21, 2, 68, 7, 40, 4, 98, 8, 79, 6, 32, 3, 53, 
    4, 98, 5, 70, 8, 64, 6, 67, 7, 19, 2, 34, 3, 99, 1, 38, 0, 29, 
    3,  7, 7, 52, 5, 36, 6, 65, 0, 91, 4, 31, 8, 87, 2, 14, 1, 94, 
    3, 22, 1, 30, 7, 56, 4, 31, 2, 62, 5, 37, 6, 28, 8, 62, 0, 95, 
    0, 57, 1, 75, 5, 43, 2, 15, 7, 88, 6,  8, 8, 71, 3, 53, 4, 48, 
    7, 68, 1, 51, 5, 83, 3, 12, 2, 85, 8, 42, 0, 38, 4, 17, 6, 29, 
    3, 53, 0, 84, 2,  6, 5, 29, 6, 37, 7,  6, 8, 81, 4, 23, 1,  5, 
    4, 61, 5, 35, 3, 88, 7, 30, 8, 18, 2, 85, 0, 89, 1, 24, 6, 57, 
    8, 19, 0, 44, 2,  4, 3, 82, 4, 71, 6, 72, 5, 10, 7, 19, 1, 31
  };
  const int q3884[] = {
    9, 9, // Number of jobs and machines
    8, 90, 2, 71, 3, 91, 0,  2, 6,  4, 7,  4, 1, 87, 5,  3, 4, 34, 
    1, 69, 4, 55, 2, 36, 7, 56, 3, 97, 0, 65, 8, 51, 6, 14, 5, 74, 
    1, 41, 7, 41, 8, 18, 6, 48, 0, 67, 3, 22, 2, 77, 5, 42, 4, 49, 
    6, 14, 2, 32, 8, 33, 0, 10, 3, 18, 4, 85, 5, 97, 1, 78, 7, 25, 
    8, 82, 5, 79, 1, 25, 4, 45, 6,  1, 2, 12, 3, 52, 7, 55, 0, 41, 
    2, 11, 1,  8, 8, 93, 4, 59, 3, 42, 7, 37, 6, 16, 0, 38, 5, 98, 
    5, 87, 2, 10, 7, 65, 8, 42, 3, 12, 6,  3, 1, 20, 0, 58, 4, 82, 
    2, 53, 4, 39, 8, 82, 7, 93, 5, 68, 6, 19, 3, 23, 1, 73, 0, 58, 
    5, 52, 8, 94, 2, 73, 3, 33, 6,  7, 7,  1, 4, 30, 0, 83, 1, 50
  };
  const int q3885[] = {
    9, 9, // Number of jobs and machines
    8, 45, 2, 78, 3, 92, 1, 71, 5, 99, 4, 72, 0,  4, 6, 92, 7, 63, 
    6, 73, 7, 95, 0,  8, 5, 84, 1, 10, 2, 81, 4, 79, 8, 95, 3,  7, 
    6, 36, 2, 80, 4, 91, 1, 76, 0, 26, 7, 94, 8, 78, 5, 68, 3, 98, 
    8, 63, 7, 62, 2,  5, 0, 11, 6, 89, 5, 81, 3, 62, 1, 76, 4, 31, 
    6, 77, 5, 83, 7, 44, 4, 52, 8, 23, 1, 90, 2, 57, 3, 80, 0, 19, 
    8, 35, 2, 60, 5, 90, 3,  5, 0, 17, 4, 76, 1, 17, 6, 41, 7, 18, 
    6, 57, 5, 63, 2, 99, 3, 24, 0, 52, 4, 90, 7, 31, 8, 29, 1, 16, 
    1, 42, 8, 99, 6, 70, 2, 39, 3, 84, 5, 75, 0, 30, 7, 32, 4,  5, 
    3, 14, 4, 48, 7, 19, 0, 51, 5, 57, 8, 14, 1, 20, 2, 56, 6, 55
  };
  const int q3886[] = {
    9, 9, // Number of jobs and machines
    0, 77, 3, 62, 4,  1, 2,  7, 5, 80, 7, 73, 6, 51, 8,  7, 1, 40, 
    6, 66, 8, 52, 4, 70, 2, 89, 7, 82, 3, 41, 1, 22, 0, 88, 5,  8, 
    0, 99, 4, 86, 8, 65, 3, 75, 6, 87, 7, 46, 1, 91, 2, 28, 5, 12, 
    0, 31, 3, 11, 4, 50, 7, 79, 2, 95, 1,  3, 6, 46, 8, 34, 5, 78, 
    4, 83, 0, 14, 7, 39, 1, 38, 2, 80, 5, 93, 3, 27, 6, 34, 8, 34, 
    0, 77, 5, 34, 3, 84, 6, 84, 8, 44, 7, 15, 4, 69, 2, 93, 1, 10, 
    7, 88, 1, 81, 2, 35, 8, 24, 3, 22, 0, 85, 6, 57, 4, 32, 5, 78, 
    4, 62, 7, 30, 2, 24, 6, 85, 8, 12, 5, 27, 3, 35, 0, 77, 1, 89, 
    1,  2, 7, 67, 3, 91, 8, 42, 6, 46, 4, 12, 0, 89, 5, 82, 2, 17
  };
  const int q3887[] = {
    9, 9, // Number of jobs and machines
    7, 49, 8, 13, 0, 49, 6, 69, 5, 85, 3, 99, 1, 21, 4, 10, 2, 29, 
    1, 13, 3, 26, 8, 66, 6, 70, 4, 25, 7, 26, 5, 60, 2, 50, 0, 35, 
    3, 32, 4,  4, 1, 19, 8, 39, 0, 80, 2, 69, 6,  7, 5, 99, 7,  9, 
    6, 16, 8, 14, 7, 81, 3, 10, 0, 24, 5, 92, 2, 48, 1, 14, 4, 99, 
    8, 15, 5, 90, 2, 65, 3, 94, 0, 44, 4, 19, 7, 65, 1, 87, 6, 24, 
    7, 48, 5, 60, 3, 25, 8, 57, 1, 65, 4, 83, 6, 30, 0, 83, 2, 26, 
    0, 10, 1, 65, 8, 96, 4, 28, 7, 33, 5, 77, 2, 60, 6, 90, 3, 24, 
    4, 67, 8, 43, 5, 94, 2, 60, 1, 69, 7, 34, 6, 11, 3, 26, 0, 32, 
    3, 15, 0, 43, 4, 28, 5, 91, 8, 37, 7, 26, 1, 52, 2, 26, 6, 61
  };
  const int q3888[] = {
    9, 9, // Number of jobs and machines
    8, 55, 1, 36, 0, 93, 7, 33, 6, 36, 3, 70, 4, 51, 2, 15, 5, 12, 
    0, 60, 4, 20, 7, 34, 1, 53, 3, 85, 5, 99, 8, 43, 6, 63, 2, 28, 
    5,  9, 7, 78, 1, 51, 0, 92, 3, 76, 4, 65, 6, 77, 2,  1, 8, 94, 
    8, 31, 6, 53, 0,  2, 5, 68, 3, 44, 2, 67, 7, 29, 1, 28, 4, 29, 
    7, 34, 8, 90, 3, 84, 2, 79, 4,  7, 1, 47, 5, 20, 0, 32, 6, 98, 
    5,  9, 2, 80, 4, 24, 0, 61, 7, 88, 6, 85, 1, 21, 8, 69, 3, 94, 
    5, 33, 3, 58, 6, 19, 8, 69, 7, 67, 1, 29, 0, 72, 4,  2, 2, 78, 
    1, 63, 2, 75, 8,  3, 5, 79, 3, 78, 6, 43, 0, 60, 4, 49, 7, 40, 
    1, 57, 3, 84, 5, 35, 6, 66, 0, 23, 4, 62, 8,  5, 2, 62, 7, 13
  };
  const int q3889[] = {
    9, 9, // Number of jobs and machines
    0, 76, 6, 30, 4, 41, 3, 77, 2, 46, 5, 46, 7, 44, 8, 57, 1, 75, 
    5, 53, 7, 54, 8, 33, 0, 79, 6, 76, 1, 39, 3, 98, 4, 79, 2, 50, 
    4,  7, 5, 13, 6, 70, 1, 18, 2, 25, 8, 11, 7, 70, 3, 62, 0, 74, 
    7, 40, 4,  7, 1, 79, 8, 51, 6, 37, 0, 61, 5, 32, 2, 14, 3, 12, 
    6, 33, 2, 83, 5, 68, 8, 42, 3, 31, 1, 65, 7, 67, 0, 63, 4, 45, 
    8, 53, 1, 98, 6, 26, 4, 83, 7,  8, 2, 12, 0, 42, 3, 69, 5,  4, 
    5, 39, 4, 29, 7, 67, 6, 56, 2, 56, 3, 15, 8, 65, 0, 88, 1, 79, 
    7, 57, 1, 92, 0, 74, 8, 69, 4,  9, 2, 82, 5, 64, 3, 34, 6, 89, 
    0, 69, 2, 47, 7, 47, 6,  4, 3, 97, 5, 45, 8, 55, 4, 17, 1, 99
  };
  const int q3890[] = {
    9, 9, // Number of jobs and machines
    8, 83, 1, 28, 3, 40, 4, 30, 2, 23, 7, 57, 6, 25, 0, 35, 5, 22, 
    8, 17, 6, 10, 5, 97, 0, 29, 3, 76, 4, 65, 1,  5, 7, 72, 2, 75, 
    8,  7, 0, 43, 5, 47, 3, 39, 1, 56, 4, 39, 6, 66, 7, 93, 2, 85, 
    5, 55, 2, 45, 6, 92, 4, 39, 0, 54, 3, 22, 7, 24, 8, 59, 1, 84, 
    2, 54, 6, 68, 3, 61, 5, 28, 4, 30, 7, 90, 0, 70, 8,  5, 1,  8, 
    2, 54, 8, 56, 6, 41, 1, 12, 0, 56, 5, 52, 4, 75, 3, 11, 7, 95, 
    5,  9, 6, 12, 8, 72, 3, 18, 4, 33, 1, 89, 2, 17, 7, 96, 0, 28, 
    6, 32, 1,  5, 8, 60, 4, 83, 2, 98, 0, 58, 3,  5, 5, 46, 7, 29, 
    7, 42, 3, 75, 6, 83, 0, 69, 8, 19, 5, 64, 4, 94, 2, 43, 1, 29
  };
  const int q3891[] = {
    9, 9, // Number of jobs and machines
    5, 16, 6, 70, 4, 88, 2, 55, 1, 93, 3, 24, 8, 96, 0, 10, 7, 71, 
    1, 28, 5, 54, 2, 26, 0, 19, 3, 20, 8, 55, 4,  6, 7, 99, 6, 19, 
    5, 49, 3,  4, 4, 38, 2, 72, 6, 47, 0, 29, 8,  2, 7, 82, 1, 25, 
    3,  2, 7,  1, 4, 54, 2, 77, 8, 20, 1, 56, 6, 74, 0, 25, 5, 11, 
    2,  2, 1, 32, 8, 63, 0, 61, 6, 90, 7, 13, 5, 51, 4, 22, 3, 72, 
    6,  1, 3, 96, 7, 30, 0, 59, 4, 58, 2, 64, 5,  8, 8, 11, 1, 61, 
    1, 16, 2, 47, 8, 33, 5, 39, 0, 89, 6, 47, 4, 66, 7, 72, 3, 65, 
    0, 94, 4, 55, 7, 79, 6, 73, 3,  1, 5, 97, 1,  7, 2, 64, 8, 14, 
    4, 57, 8, 61, 0, 37, 5, 91, 6,  5, 7, 40, 3, 10, 1, 99, 2, 67
  };
  const int q3892[] = {
    9, 9, // Number of jobs and machines
    2, 76, 7, 10, 4, 13, 3, 90, 8, 86, 6, 19, 1, 59, 0, 20, 5, 24, 
    8, 33, 3, 79, 7,  9, 2, 65, 1, 98, 0, 69, 5, 23, 6, 25, 4, 51, 
    0, 48, 8, 58, 2, 50, 7, 64, 1, 45, 4, 31, 5, 81, 3, 65, 6, 95, 
    6, 53, 5, 21, 4, 16, 8, 71, 3, 24, 0, 96, 1, 85, 2, 81, 7, 23, 
    0, 54, 4, 47, 3, 76, 2, 14, 6, 93, 7, 33, 8, 12, 1, 39, 5, 31, 
    4, 33, 2, 76, 8, 46, 1, 30, 5, 38, 3, 86, 7, 40, 6, 39, 0, 53, 
    3, 49, 2, 40, 4,  1, 8, 58, 0,  5, 6, 23, 7, 90, 1, 88, 5, 77, 
    3,  7, 8, 63, 5, 80, 4, 38, 1, 80, 7, 89, 0, 25, 2,  9, 6, 38, 
    7, 12, 4, 10, 6, 43, 1, 71, 2,  5, 3, 67, 8, 87, 5, 60, 0, 20
  };
  const int q3893[] = {
    9, 9, // Number of jobs and machines
    5, 70, 3, 67, 8,  4, 1, 16, 4, 80, 2, 52, 6, 26, 0, 46, 7, 47, 
    8, 53, 6, 15, 4, 59, 7, 38, 5, 59, 1, 28, 2, 67, 3, 35, 0, 77, 
    5, 85, 0,  1, 8, 84, 6, 81, 4, 61, 1, 82, 2, 37, 7, 17, 3, 94, 
    8, 50, 0,  4, 2, 77, 6, 23, 4, 37, 1, 63, 5, 33, 3, 59, 7, 35, 
    4, 67, 1, 47, 6, 58, 2, 66, 7, 42, 8, 56, 0, 63, 3, 97, 5, 22, 
    1, 30, 0, 18, 4, 58, 7, 95, 6, 71, 3, 16, 2, 86, 8,  6, 5, 44, 
    8, 65, 1, 88, 5, 53, 4, 76, 6, 50, 2, 30, 0, 29, 3, 10, 7, 71, 
    8, 16, 7, 66, 6, 72, 3,  6, 4, 24, 0, 86, 5, 34, 1, 72, 2, 31, 
    0, 78, 7, 99, 5, 50, 2, 81, 3, 59, 4,  9, 1,  5, 6, 61, 8, 53
  };
  const int q3894[] = {
    9, 9, // Number of jobs and machines
    6, 49, 7, 62, 1, 30, 8, 58, 3,  1, 0, 55, 4, 53, 5, 95, 2, 92, 
    7, 45, 1,  1, 3, 69, 8, 75, 6, 91, 5,  9, 0, 64, 4, 28, 2, 92, 
    0, 70, 7,  3, 3, 82, 5, 91, 4, 94, 2,  1, 8, 65, 1, 61, 6, 83, 
    4, 48, 1, 53, 3, 82, 5, 81, 7, 53, 2, 41, 0, 84, 8, 77, 6, 33, 
    2, 12, 6, 13, 1, 38, 7,  6, 3, 23, 5, 99, 0, 68, 8, 29, 4, 90, 
    5, 84, 8, 73, 1, 73, 2, 99, 3, 50, 4, 25, 6, 56, 7, 30, 0, 14, 
    8, 19, 1, 30, 7, 30, 0, 55, 2, 40, 4, 61, 5, 93, 3, 38, 6, 46, 
    2, 20, 5, 16, 7, 42, 3, 74, 1, 62, 0, 75, 6, 21, 4, 46, 8, 15, 
    1, 48, 4, 13, 8, 14, 0, 20, 5, 46, 2, 23, 3, 81, 6, 12, 7, 72
  };
  const int q3895[] = {
    9, 9, // Number of jobs and machines
    8, 10, 2, 16, 5,  9, 3, 95, 0, 98, 7, 54, 6, 91, 1,  2, 4, 79, 
    5, 35, 8, 78, 6, 38, 2, 52, 1, 79, 7, 45, 3, 90, 0, 37, 4,  4, 
    2, 13, 7, 19, 8, 11, 0, 44, 6, 87, 3, 11, 4, 92, 5, 75, 1, 44, 
    5, 24, 8, 93, 2, 48, 7, 92, 1, 61, 0, 36, 6, 73, 4, 28, 3, 44, 
    8, 61, 2, 69, 3, 39, 7, 50, 0, 49, 4, 14, 6,  7, 5, 88, 1, 48, 
    5, 24, 0, 65, 8, 47, 3, 47, 2, 30, 1, 39, 6, 62, 7, 34, 4, 98, 
    8, 70, 0, 43, 7, 67, 6, 55, 2, 98, 5, 76, 3, 62, 4, 64, 1, 15, 
    4, 61, 0, 96, 8, 22, 6, 28, 1, 47, 5, 68, 2, 81, 3, 71, 7, 84, 
    0,  4, 6, 48, 2, 33, 7, 80, 1, 28, 8, 83, 4, 29, 5, 92, 3, 59
  };
  const int q3896[] = {
    9, 9, // Number of jobs and machines
    6, 43, 1, 28, 8, 95, 4, 25, 7, 33, 5, 24, 3, 80, 0, 53, 2, 21, 
    0, 47, 1, 66, 8, 28, 3, 10, 5, 69, 2, 93, 6, 59, 4,  9, 7, 25, 
    6, 45, 3, 48, 8, 56, 2, 10, 7, 19, 4, 22, 1, 75, 5, 61, 0, 73, 
    6, 57, 4, 73, 2, 90, 0, 34, 7, 72, 1, 58, 3, 67, 5, 30, 8, 47, 
    7, 50, 8, 27, 4, 20, 0, 43, 6, 58, 5, 30, 2, 14, 1, 16, 3, 50, 
    5, 25, 7, 43, 4, 13, 6,  1, 8, 86, 3, 26, 0, 36, 1, 17, 2, 14, 
    8, 98, 7, 81, 6, 69, 5, 70, 0, 65, 2, 98, 3, 20, 1, 47, 4, 53, 
    2, 53, 5, 59, 0, 25, 7, 28, 3, 16, 1, 96, 6, 17, 8,  9, 4, 70, 
    8, 12, 2, 54, 6, 99, 4, 49, 3, 22, 7, 98, 0, 77, 5, 90, 1,  4
  };
  const int q3897[] = {
    9, 9, // Number of jobs and machines
    2, 90, 7, 95, 6, 90, 3, 70, 4, 59, 0, 92, 1, 84, 8, 62, 5, 60, 
    0,  5, 6, 28, 1, 88, 5, 21, 7,  1, 4, 12, 2, 57, 3, 42, 8,  9, 
    6, 42, 0, 39, 8,  2, 3, 78, 5, 27, 4, 68, 1, 41, 2, 65, 7,  8, 
    7, 77, 0, 59, 3, 94, 1, 18, 6, 71, 5, 51, 4, 96, 8, 22, 2, 76, 
    0, 86, 5, 38, 6, 86, 8, 19, 4, 27, 7, 46, 1, 22, 2, 78, 3, 32, 
    8, 61, 5, 31, 1,  4, 0,  4, 4, 63, 2, 25, 6, 44, 3, 45, 7,  4, 
    8, 72, 3, 50, 7, 71, 5, 56, 6, 80, 1, 22, 0, 61, 2, 55, 4, 73, 
    5, 25, 6, 69, 8, 53, 0, 18, 2, 49, 7, 13, 1, 17, 3, 10, 4, 12, 
    5, 91, 0, 77, 2,  5, 3, 58, 4, 58, 7, 98, 6, 84, 1, 80, 8, 91
  };
  const int q3898[] = {
    9, 9, // Number of jobs and machines
    3, 34, 6, 18, 5, 35, 1, 61, 8, 78, 0, 11, 4, 95, 2, 24, 7, 32, 
    6, 94, 0, 17, 7,  7, 4, 30, 5, 48, 2, 39, 1, 12, 8, 86, 3, 42, 
    4, 85, 3, 73, 7, 20, 8, 55, 6, 58, 1, 56, 5, 59, 0,  9, 2,  3, 
    0, 97, 7, 47, 2, 85, 6, 99, 5,  3, 1, 62, 3, 44, 8, 37, 4, 41, 
    1, 44, 8, 57, 7, 33, 4, 74, 6, 36, 3, 89, 5, 73, 0, 89, 2, 93, 
    3, 40, 6, 74, 8, 45, 7, 20, 4, 69, 1, 20, 2,  4, 5, 92, 0, 70, 
    5, 82, 8, 26, 3, 76, 6, 61, 0, 64, 2, 28, 1, 56, 4, 77, 7, 73, 
    3, 37, 2, 43, 6, 51, 7, 69, 0, 24, 1, 74, 8, 22, 5, 55, 4, 43, 
    0, 11, 1, 22, 4, 36, 8, 26, 7, 10, 5, 58, 6, 63, 2, 26, 3, 95
  };
  const int q3899[] = {
    9, 9, // Number of jobs and machines
    8, 83, 5, 84, 2, 66, 7, 33, 6, 51, 3, 89, 1, 61, 0, 94, 4, 55, 
    3, 19, 8,  1, 2, 42, 7, 67, 4, 79, 5, 89, 1, 24, 6, 49, 0, 86, 
    4, 73, 3, 42, 8, 46, 2, 79, 0, 54, 6,  6, 1, 70, 7, 46, 5, 80, 
    3, 38, 1, 83, 2, 17, 4, 28, 5, 87, 0,  4, 8, 36, 6, 75, 7, 99, 
    1, 75, 0, 20, 6, 90, 8, 17, 5,  4, 2, 79, 7, 64, 4, 76, 3,  3, 
    8, 27, 5, 40, 7, 62, 0, 10, 2, 25, 1, 79, 4, 51, 3, 11, 6, 51, 
    0, 92, 4, 32, 6,  3, 3, 79, 5,  3, 1, 47, 8, 41, 2, 28, 7, 20, 
    8, 74, 4, 58, 5, 69, 3, 22, 0, 23, 7, 86, 1, 50, 6, 29, 2, 69, 
    3, 81, 7, 99, 0, 62, 8, 58, 5, 42, 6,  9, 2, 92, 1, 95, 4, 79
  };
  const int q3900[] = {
    9, 9, // Number of jobs and machines
    4, 41, 3, 62, 6, 65, 0, 17, 8, 51, 2, 76, 1, 25, 5,  4, 7, 62, 
    2, 15, 3, 70, 7, 14, 8, 59, 0, 29, 1, 37, 6, 13, 4, 69, 5, 76, 
    5, 91, 2, 83, 0, 20, 3, 76, 4, 32, 1,  6, 7, 84, 8, 89, 6, 99, 
    5, 56, 2, 82, 7, 46, 6,  3, 3, 64, 1, 91, 0, 72, 8, 93, 4, 93, 
    6, 39, 3, 66, 7, 53, 2, 31, 5, 31, 4, 50, 1,  8, 8, 31, 0, 86, 
    0, 85, 7, 97, 6, 95, 4,  9, 8, 44, 5, 53, 3, 40, 1, 14, 2, 40, 
    1, 29, 0, 31, 8, 74, 4, 79, 6, 58, 5, 25, 3, 98, 2,  3, 7,  7, 
    1, 21, 6, 89, 3, 61, 7, 26, 8, 35, 2, 56, 4, 53, 5,  5, 0, 32, 
    6,  7, 7, 58, 4, 33, 1, 89, 5, 45, 8, 62, 0, 12, 2,  4, 3,  4
  };
  const int q3901[] = {
    9, 9, // Number of jobs and machines
    1, 39, 2, 97, 8, 43, 7, 94, 4, 98, 0,  4, 5, 44, 6, 26, 3, 26, 
    3, 32, 0, 72, 6, 35, 2, 65, 8,  6, 1, 92, 7, 57, 4, 45, 5, 62, 
    6, 82, 3, 75, 4, 13, 5, 74, 2, 65, 7, 47, 0, 85, 1,  9, 8, 85, 
    5, 22, 2, 55, 3, 27, 8, 55, 0, 68, 4, 45, 6, 11, 7, 54, 1, 11, 
    1, 67, 0, 70, 7, 70, 8, 93, 5, 33, 4, 92, 6, 44, 3, 17, 2, 81, 
    4, 40, 7, 84, 0,  5, 1, 94, 6, 93, 5, 43, 2, 88, 8, 12, 3, 71, 
    4, 46, 6,  7, 2,  6, 3, 25, 0, 87, 7, 57, 1, 50, 5, 86, 8,  5, 
    1, 38, 8, 74, 3, 28, 6, 29, 4, 88, 7, 93, 2, 59, 0, 13, 5, 90, 
    2, 75, 7, 69, 1, 40, 0, 16, 8, 71, 4, 73, 6, 37, 3, 20, 5, 32
  };
  const int q3902[] = {
    9, 9, // Number of jobs and machines
    4, 62, 5, 52, 1, 64, 2, 43, 6, 36, 0, 44, 8, 20, 3, 48, 7, 70, 
    7, 91, 1, 71, 2, 32, 0, 35, 3, 81, 5, 90, 4,  7, 8, 95, 6, 60, 
    6, 38, 2, 96, 1,  3, 0,  7, 4, 47, 3, 65, 5, 83, 8,  1, 7, 95, 
    2, 48, 4, 70, 1, 20, 7, 79, 8, 88, 0, 57, 5, 92, 3, 44, 6, 73, 
    2, 42, 4, 89, 8, 10, 0, 34, 7, 71, 5, 94, 6, 66, 1, 81, 3, 15, 
    0, 60, 6, 81, 8, 23, 5, 31, 1, 81, 2, 80, 4, 23, 3, 70, 7,  7, 
    3, 21, 5, 96, 6, 89, 0, 57, 4, 25, 2, 29, 7, 80, 8, 64, 1, 68, 
    4, 81, 8, 14, 6, 69, 7, 67, 0, 87, 2, 59, 5, 62, 1, 56, 3, 44, 
    6, 68, 3, 63, 0, 91, 2, 64, 4, 89, 7, 22, 8, 87, 1, 71, 5, 36
  };
  const int q3903[] = {
    9, 9, // Number of jobs and machines
    5, 22, 1, 85, 3, 26, 6, 11, 0, 63, 2, 25, 8, 55, 4, 74, 7,  4, 
    5, 71, 8, 67, 6, 91, 4, 70, 0, 48, 3, 89, 2, 12, 1, 10, 7, 79, 
    2, 87, 0, 17, 4, 81, 7, 54, 6, 67, 3, 28, 1, 70, 5, 51, 8, 39, 
    4, 20, 2, 15, 3, 28, 8, 45, 5, 45, 1, 20, 7, 17, 0,  5, 6, 63, 
    4,  6, 2, 89, 6, 73, 0, 25, 3, 42, 5, 44, 8, 51, 1, 32, 7,  8, 
    0, 33, 1, 52, 6, 42, 4, 41, 5, 79, 7, 64, 2, 85, 3, 86, 8, 62, 
    1, 86, 8, 67, 2, 14, 4, 37, 0, 86, 7, 34, 6, 17, 3,  2, 5, 31, 
    6,  6, 5, 86, 7, 77, 2, 26, 4, 24, 3, 82, 0, 46, 1, 54, 8, 44, 
    5, 82, 0, 72, 8, 56, 2,  1, 1, 33, 6,  4, 3, 85, 7, 37, 4, 22
  };
  const int q3904[] = {
    9, 9, // Number of jobs and machines
    1, 44, 2, 64, 6, 73, 3, 63, 4, 71, 7, 38, 0, 58, 8, 53, 5, 89, 
    2, 23, 3, 89, 5, 14, 1, 54, 7, 39, 6,  3, 4, 79, 0, 60, 8, 25, 
    8, 14, 0, 19, 3, 58, 6, 56, 4, 88, 7, 61, 2, 17, 5,  4, 1, 59, 
    0, 99, 1, 89, 3, 89, 8, 74, 7, 16, 4, 19, 5, 40, 2,  1, 6, 71, 
    0,  1, 5, 71, 3, 44, 7, 31, 4, 51, 6, 32, 2, 94, 1, 88, 8, 50, 
    2, 13, 6, 67, 5, 48, 0, 66, 8, 79, 1, 86, 7, 64, 3, 72, 4, 10, 
    5, 24, 0, 31, 7, 91, 1, 31, 6, 16, 2, 41, 3,  5, 4, 44, 8, 82, 
    6, 88, 7,  7, 5, 89, 2, 64, 4, 75, 1, 79, 8, 47, 3, 82, 0, 97, 
    3, 36, 5, 87, 4,  9, 7, 37, 1, 81, 8,  6, 2, 28, 0, 84, 6, 75
  };
  const int q3905[] = {
    9, 9, // Number of jobs and machines
    7, 79, 4, 14, 1, 81, 3, 44, 0, 33, 8, 99, 6, 77, 2, 63, 5, 22, 
    1, 10, 7, 27, 5, 10, 8, 64, 6, 78, 2, 23, 0, 76, 4, 57, 3, 99, 
    6, 92, 4, 18, 7,  3, 3, 47, 1, 64, 8, 58, 5, 42, 0, 71, 2, 39, 
    4, 30, 8, 72, 6, 85, 5, 76, 1, 97, 7, 69, 0, 97, 3, 17, 2, 23, 
    7,  2, 5, 67, 4, 97, 3, 70, 2, 44, 0, 15, 6, 87, 8, 71, 1, 49, 
    2,  9, 3, 29, 6, 69, 1, 10, 7, 22, 5,  3, 4, 31, 8, 63, 0, 22, 
    4, 10, 2, 46, 0, 13, 5, 69, 6, 82, 3, 37, 7, 98, 8, 23, 1, 16, 
    7, 28, 1, 44, 6, 50, 3, 99, 4, 36, 8, 43, 0,  6, 5, 13, 2,  6, 
    0, 87, 5, 57, 7, 97, 4, 13, 3, 98, 1,  5, 6, 40, 8, 81, 2,  1
  };
  const int q3906[] = {
    9, 9, // Number of jobs and machines
    3, 27, 8, 26, 1, 49, 6, 52, 4, 27, 7, 93, 5, 75, 2, 34, 0, 21, 
    0,  6, 4, 91, 6, 51, 5, 42, 2, 83, 8, 70, 1, 33, 3,  5, 7, 68, 
    0, 70, 8, 40, 2, 18, 3, 15, 5, 99, 4, 81, 1, 62, 7, 53, 6, 37, 
    6, 12, 3, 43, 0, 41, 4, 18, 2,  2, 7, 93, 5, 30, 8, 32, 1, 74, 
    1, 65, 6, 40, 0, 19, 7, 17, 4, 54, 3, 52, 2,  9, 8, 32, 5,  3, 
    0, 29, 3,  2, 4, 55, 1, 27, 8, 17, 2, 57, 7, 15, 6, 30, 5, 21, 
    3, 60, 5, 61, 2, 93, 4, 60, 1, 82, 7, 82, 0, 76, 6, 47, 8, 58, 
    0, 74, 1, 96, 2, 24, 8, 51, 4, 85, 6, 41, 5, 12, 3, 40, 7, 62, 
    6, 24, 8, 44, 2, 93, 4, 66, 5, 92, 3, 92, 0, 50, 1, 23, 7, 23
  };
  const int q3907[] = {
    9, 9, // Number of jobs and machines
    1, 83, 7, 19, 6, 17, 4, 99, 8, 98, 5, 83, 3, 29, 0, 65, 2, 20, 
    6, 71, 0, 73, 8, 60, 7, 45, 3, 22, 2, 73, 4, 84, 5, 75, 1, 69, 
    4, 25, 0, 31, 3, 54, 1, 35, 2, 15, 8, 64, 5, 39, 7, 44, 6, 57, 
    4, 40, 5, 47, 8, 44, 7, 66, 1, 52, 2,  1, 3, 98, 6, 50, 0, 20, 
    6, 51, 8, 17, 7,  8, 0, 39, 4, 67, 1, 68, 3, 94, 5, 17, 2, 34, 
    3, 98, 5, 81, 8,  2, 1, 60, 0, 10, 4, 65, 2, 84, 6, 21, 7, 47, 
    3, 41, 6,  4, 4, 38, 2,  6, 0, 89, 7, 67, 1, 71, 8, 58, 5, 83, 
    2, 31, 4, 10, 1, 52, 7, 34, 5, 61, 6, 23, 0, 39, 3, 94, 8,  7, 
    8, 19, 7, 86, 1, 25, 0, 40, 4, 36, 3, 20, 5, 18, 2, 27, 6, 37
  };
  const int q3908[] = {
    9, 9, // Number of jobs and machines
    6, 14, 5, 12, 4, 18, 7, 76, 3, 72, 0, 44, 1, 54, 2,  3, 8, 22, 
    8, 94, 6, 49, 4, 48, 3, 59, 2,  9, 0, 98, 7, 59, 5,  7, 1, 96, 
    4,  7, 8, 32, 2, 64, 0, 89, 1, 32, 7, 49, 6, 28, 5, 38, 3, 35, 
    4, 51, 5, 89, 8, 96, 1, 78, 3, 17, 6, 19, 7, 70, 2, 55, 0, 87, 
    1, 37, 4, 20, 8, 94, 3, 83, 5, 71, 6, 58, 7, 64, 2, 98, 0, 14, 
    0, 40, 8, 12, 7, 65, 6, 86, 4, 32, 5, 56, 3, 15, 2, 44, 1, 49, 
    5, 34, 7, 72, 4, 45, 3, 69, 6, 13, 8,  5, 2, 64, 0, 85, 1, 38, 
    3, 43, 2, 76, 1, 41, 4, 41, 5, 21, 6, 64, 7, 91, 8, 42, 0, 24, 
    3, 92, 8, 32, 6, 62, 7, 91, 5, 24, 2, 28, 4,  8, 1, 37, 0, 25
  };
  const int q3909[] = {
    9, 9, // Number of jobs and machines
    4, 79, 7,  3, 3, 77, 2, 33, 8, 12, 0, 90, 5,  9, 1, 55, 6, 43, 
    0, 46, 6, 74, 1, 63, 8, 15, 3, 14, 7, 97, 2, 79, 4, 50, 5, 13, 
    8, 16, 3, 55, 1, 71, 0, 33, 5, 39, 7, 21, 6, 73, 4, 99, 2,  4, 
    1, 88, 5, 10, 0, 18, 4, 35, 8, 34, 2, 22, 3, 84, 7, 25, 6, 25, 
    6, 16, 1, 12, 7, 79, 3, 57, 2, 17, 4, 85, 5, 39, 8,  5, 0, 46, 
    8, 46, 5, 73, 7, 52, 2, 52, 1, 32, 0, 78, 4, 98, 3, 24, 6,  3, 
    2, 27, 6, 42, 4, 27, 8, 97, 5,  7, 3, 83, 1, 25, 7, 95, 0,  7, 
    4, 47, 2, 25, 5, 31, 6, 50, 1, 99, 7, 11, 8, 42, 0, 81, 3, 35, 
    1, 71, 3, 54, 4, 19, 5, 40, 0, 31, 2, 81, 6, 44, 8, 13, 7, 31
  };
  const int q3910[] = {
    9, 9, // Number of jobs and machines
    3, 89, 0, 17, 1, 93, 7, 47, 4, 70, 6, 24, 5, 77, 2, 49, 8, 99, 
    5, 68, 6, 87, 7, 56, 4, 55, 2, 42, 3, 88, 8, 37, 0,  8, 1,  6, 
    2, 22, 6, 96, 0, 82, 5, 24, 1, 40, 4, 77, 7, 69, 8, 16, 3, 39, 
    2, 47, 8, 54, 5, 89, 6,  4, 1, 43, 4, 46, 3, 43, 7, 56, 0, 67, 
    5, 73, 8, 26, 7, 16, 1, 75, 0, 67, 2, 15, 3, 41, 6, 65, 4, 52, 
    0, 47, 3,  9, 5, 52, 6, 61, 4, 53, 2, 30, 7,  3, 1, 32, 8, 54, 
    6, 47, 0, 60, 1, 62, 8, 55, 7, 16, 5, 42, 4, 48, 3, 11, 2, 40, 
    4, 54, 5, 97, 2, 63, 6, 22, 3, 79, 1, 22, 8, 34, 7, 58, 0, 17, 
    6, 83, 4, 70, 2,  3, 5, 82, 7, 73, 3, 43, 0, 84, 1, 52, 8, 36
  };
  const int q3911[] = {
    9, 9, // Number of jobs and machines
    4, 73, 6, 79, 0,  7, 3, 74, 8, 93, 7, 32, 5, 70, 1, 53, 2, 49, 
    8, 47, 5, 24, 6, 86, 7, 88, 0, 68, 3, 35, 2, 85, 1, 95, 4,  5, 
    5, 26, 7, 93, 0,  4, 3, 68, 2, 75, 4, 53, 1, 93, 8, 98, 6, 43, 
    3, 80, 2, 98, 0, 88, 4, 39, 6, 36, 5, 73, 1, 89, 8, 54, 7, 81, 
    3, 34, 6, 72, 7, 23, 0, 61, 5, 98, 1, 88, 2, 55, 4, 35, 8, 16, 
    2, 45, 5, 50, 8, 34, 4, 89, 0, 87, 7, 40, 6, 93, 3, 48, 1, 30, 
    0, 24, 3, 31, 4, 36, 5, 59, 6, 68, 2, 43, 8, 78, 7, 66, 1, 24, 
    6, 59, 8, 30, 0, 25, 1, 69, 3,  9, 5, 98, 4, 71, 2, 47, 7, 44, 
    8, 49, 5, 55, 6, 75, 7, 95, 2, 93, 4, 18, 0, 76, 3, 66, 1, 56
  };
  const int q3912[] = {
    9, 9, // Number of jobs and machines
    6, 30, 8, 84, 0, 33, 7, 38, 4, 97, 1,  9, 5, 15, 2, 46, 3, 95, 
    5, 33, 8, 69, 1, 25, 6, 87, 0, 59, 4, 94, 3, 27, 7, 39, 2,  5, 
    7, 84, 0, 28, 4, 75, 3, 94, 5, 29, 8, 99, 2, 33, 6, 74, 1, 84, 
    4,  9, 5, 13, 3, 35, 6, 52, 0, 60, 2,  6, 8,  4, 1,  8, 7, 75, 
    8, 90, 5, 97, 0, 14, 6, 65, 4, 36, 2, 73, 3, 49, 7, 35, 1, 83, 
    6, 73, 3, 78, 5, 44, 1,  5, 0, 83, 7, 18, 4, 76, 8, 82, 2, 57, 
    5, 22, 4, 33, 0, 74, 7, 53, 1, 82, 3, 26, 2, 70, 8, 71, 6, 16, 
    5, 96, 8, 44, 4, 90, 2, 57, 0, 96, 6, 42, 7, 64, 3, 99, 1, 26, 
    2, 89, 7, 59, 8, 51, 0, 40, 6, 19, 4, 24, 5, 15, 1, 73, 3, 82
  };
  const int q3913[] = {
    9, 9, // Number of jobs and machines
    0,  4, 1, 32, 7, 15, 3, 16, 5, 46, 8, 32, 2,  7, 4, 84, 6, 39, 
    5, 72, 8, 31, 7, 53, 2,  5, 0, 56, 3, 58, 4, 67, 6, 86, 1, 47, 
    7, 11, 0, 67, 1, 11, 5,  2, 4, 70, 8, 11, 6,  8, 2, 12, 3, 92, 
    2, 87, 4, 97, 5, 96, 1, 20, 0,  1, 3, 19, 6, 79, 8, 10, 7, 60, 
    1,  9, 8, 26, 4, 75, 3, 54, 7, 30, 5, 41, 0, 86, 2, 96, 6, 35, 
    1, 83, 4, 21, 6, 88, 5, 22, 0, 34, 2, 94, 7, 80, 8, 94, 3, 70, 
    1, 87, 5, 74, 7, 19, 8, 34, 2, 43, 0, 52, 3,  6, 6, 67, 4, 46, 
    4, 52, 1, 46, 6, 29, 2, 97, 3, 20, 7,  8, 8, 11, 5, 10, 0, 72, 
    5, 96, 6, 26, 8, 89, 2, 47, 7, 83, 4, 32, 3,  2, 1, 41, 0, 41
  };
  const int q3914[] = {
    9, 9, // Number of jobs and machines
    1, 61, 8, 90, 3, 90, 0, 83, 7, 55, 6, 76, 5, 75, 4, 32, 2,  1, 
    6, 86, 2, 91, 5, 72, 0, 79, 8, 18, 1, 39, 3, 11, 7, 14, 4, 61, 
    0, 46, 5,  9, 3, 40, 8, 90, 1, 96, 4, 47, 6, 25, 2,  7, 7, 14, 
    1, 34, 8, 31, 6, 89, 4, 55, 3, 41, 0, 39, 5, 79, 2, 90, 7, 94, 
    5, 85, 8, 73, 6, 23, 7, 65, 0, 42, 4, 75, 2, 69, 1, 10, 3, 61, 
    1, 14, 3, 81, 6,  6, 0, 76, 5, 28, 2, 86, 7, 47, 4, 74, 8, 49, 
    1, 73, 3, 39, 5, 74, 8, 10, 2, 33, 0,  3, 4, 29, 7, 71, 6, 67, 
    7, 85, 1, 67, 5, 43, 2, 76, 3, 56, 0, 43, 4, 20, 6, 41, 8, 72, 
    0, 14, 8, 64, 7, 56, 3, 29, 4, 53, 1, 32, 6, 11, 5, 34, 2, 69
  };
  const int q3915[] = {
    9, 9, // Number of jobs and machines
    6, 60, 8, 48, 4, 56, 1, 21, 0, 74, 5, 68, 7, 62, 2, 23, 3, 86, 
    0, 66, 5,  5, 7, 81, 4, 44, 2, 27, 3, 31, 1, 95, 8, 60, 6, 77, 
    7, 91, 4, 90, 1, 49, 5, 86, 0, 68, 3, 40, 2,  5, 8, 77, 6, 52, 
    8, 83, 3, 72, 5, 66, 2, 84, 1, 69, 0, 50, 4, 10, 6, 79, 7, 87, 
    6, 63, 1, 58, 2, 58, 0, 50, 4, 18, 3, 95, 7, 28, 5,  7, 8, 50, 
    4, 60, 0, 18, 5, 82, 7, 40, 2, 32, 1, 14, 6, 60, 3, 83, 8, 62, 
    8, 54, 0, 68, 4, 34, 3, 45, 5, 15, 7, 56, 6, 29, 2, 31, 1, 25, 
    2,  2, 4, 73, 5, 97, 7, 54, 1, 81, 0, 59, 3, 99, 8, 83, 6, 21, 
    4, 15, 2, 25, 0, 35, 1, 84, 7, 19, 3, 35, 8, 37, 5, 27, 6, 58
  };
  const int q3916[] = {
    9, 9, // Number of jobs and machines
    6, 50, 2, 35, 3, 73, 1, 81, 7, 21, 8, 30, 5, 21, 4, 84, 0, 52, 
    2, 75, 8, 84, 7, 22, 0, 67, 6, 75, 3,  1, 4,  7, 1, 85, 5, 72, 
    4, 50, 1, 88, 8, 60, 2, 84, 7, 17, 0, 41, 6, 61, 3, 54, 5, 16, 
    2, 86, 6, 70, 0, 92, 5, 45, 4, 49, 3, 62, 8, 97, 7, 50, 1, 98, 
    7, 61, 4, 32, 8, 23, 3, 99, 0, 99, 5,  9, 1, 44, 2, 84, 6, 84, 
    0, 13, 5, 77, 1, 23, 2, 51, 6, 61, 4, 35, 3, 71, 7, 36, 8, 28, 
    1, 24, 5, 70, 6, 96, 0, 74, 2, 91, 3, 27, 8, 38, 7, 40, 4, 54, 
    0, 68, 5, 50, 2, 29, 8,  1, 1, 47, 7, 35, 6, 58, 4, 49, 3, 83, 
    3, 14, 2, 49, 8, 65, 1, 33, 0, 67, 5, 73, 7, 31, 4,  1, 6, 49
  };
  const int q3917[] = {
    9, 9, // Number of jobs and machines
    5, 85, 3, 94, 7, 93, 0, 71, 4, 79, 6, 38, 2, 99, 1, 64, 8, 38, 
    2, 60, 4, 67, 7,  1, 1, 39, 5, 55, 8, 40, 6, 21, 0, 38, 3, 68, 
    3, 90, 1, 80, 6, 94, 2, 34, 8, 27, 5, 77, 7,  1, 0, 15, 4, 45, 
    2, 13, 8, 77, 7, 59, 0, 19, 3, 57, 6, 23, 5,  7, 4,  7, 1, 83, 
    8, 33, 2, 55, 5, 50, 6, 61, 7, 94, 3, 74, 1, 43, 0, 58, 4, 56, 
    8, 22, 5, 50, 4, 47, 2, 53, 7, 53, 1, 16, 6,  2, 0, 54, 3, 68, 
    4, 72, 3, 55, 1, 64, 0, 62, 5,  5, 2, 53, 8, 31, 7, 34, 6, 42, 
    0, 15, 8, 47, 4, 61, 6, 18, 3, 72, 2, 71, 7, 57, 5, 36, 1, 34, 
    1, 73, 7, 73, 6, 91, 3, 41, 8, 71, 0, 46, 5, 22, 4, 90, 2,  6
  };
  const int q3918[] = {
    9, 9, // Number of jobs and machines
    2, 93, 7, 23, 3, 88, 6, 20, 8, 92, 4, 45, 5, 16, 1, 12, 0, 89, 
    8, 46, 6,  1, 1, 32, 7, 54, 0, 28, 5, 19, 2, 55, 4, 82, 3, 70, 
    1, 82, 0, 30, 2, 74, 5, 62, 3, 12, 8, 31, 6, 53, 7, 82, 4,  2, 
    2, 88, 3, 14, 1, 83, 4, 59, 5, 40, 7, 69, 0, 82, 6, 75, 8, 16, 
    7, 70, 3, 91, 2, 53, 5, 81, 6, 98, 0, 10, 8, 90, 1,  9, 4, 47, 
    2, 11, 0, 46, 6, 22, 1, 58, 4, 26, 8, 67, 5,  7, 7, 41, 3, 66, 
    5, 57, 3, 30, 0, 62, 8, 49, 2, 10, 7, 51, 6, 37, 4, 11, 1, 34, 
    6, 28, 1, 77, 0, 85, 3, 56, 4, 57, 2, 41, 5, 20, 8, 87, 7, 18, 
    4, 50, 6, 82, 0, 64, 2, 29, 7, 91, 8, 85, 5, 13, 1, 55, 3, 38
  };
  const int q3919[] = {
    9, 9, // Number of jobs and machines
    0, 10, 3, 86, 2, 31, 6, 21, 7,  5, 1, 43, 8, 96, 5, 71, 4, 55, 
    6, 23, 5, 83, 8, 18, 1, 26, 7, 34, 0, 37, 4, 39, 3, 74, 2, 95, 
    1, 63, 4, 72, 7,  2, 6, 49, 2, 29, 8, 15, 3, 74, 0, 64, 5, 25, 
    1, 21, 4, 58, 2, 11, 8, 16, 5, 70, 3, 19, 6,  8, 7, 30, 0, 17, 
    4, 97, 7, 14, 0, 22, 2, 91, 1, 41, 3, 51, 8, 54, 6, 31, 5, 73, 
    4, 40, 1, 53, 6, 36, 3, 83, 8, 76, 5, 83, 0, 86, 2, 44, 7, 74, 
    5, 15, 3, 16, 1, 34, 4, 20, 8, 83, 0, 52, 6, 33, 7, 47, 2, 45, 
    0, 42, 4, 94, 2, 44, 5, 84, 8,  1, 1, 48, 7, 39, 6, 41, 3, 65, 
    3, 83, 2, 16, 5, 47, 7, 39, 1, 78, 4, 71, 8, 29, 6, 77, 0, 49
  };
  const int q3920[] = {
    9, 9, // Number of jobs and machines
    6,  6, 2, 10, 3, 14, 4, 45, 0, 19, 8, 69, 5, 56, 1, 85, 7, 71, 
    5, 92, 8, 26, 0, 24, 1, 14, 2,  5, 7, 66, 4, 16, 3, 60, 6, 20, 
    0,  3, 2, 37, 8, 35, 1, 21, 4, 78, 3, 98, 7, 16, 6, 80, 5, 34, 
    5, 27, 6, 97, 7, 49, 3, 92, 4, 28, 2,  8, 8, 24, 1, 69, 0, 50, 
    2, 25, 4, 13, 8, 95, 1, 27, 7,  4, 0, 94, 3, 33, 5, 80, 6, 63, 
    0, 17, 3, 73, 8, 73, 5, 89, 6, 59, 2,  1, 4,  4, 1, 21, 7, 94, 
    6, 63, 0, 93, 7,  6, 8, 86, 1, 21, 5, 43, 4, 23, 3, 10, 2, 76, 
    6, 27, 1, 12, 8, 29, 4, 37, 3, 24, 7, 30, 2, 20, 5, 69, 0, 49, 
    1, 98, 2, 90, 3, 42, 8, 42, 0, 43, 4, 33, 7,  3, 5, 10, 6, 48
  };
  const int q3921[] = {
    9, 9, // Number of jobs and machines
    3, 70, 5, 36, 2,  5, 6, 53, 4, 76, 7, 59, 8, 35, 0, 13, 1, 69, 
    4, 62, 7, 86, 3, 66, 6, 70, 1, 33, 2, 19, 5, 59, 8, 29, 0, 69, 
    0, 96, 7, 95, 1, 25, 4, 67, 2, 52, 8,  7, 3, 12, 5, 13, 6, 77, 
    5, 86, 8,  9, 1, 94, 3, 19, 4, 91, 2, 28, 0, 39, 6, 59, 7,  8, 
    0, 63, 3,  9, 6, 54, 1, 64, 8, 12, 2, 57, 4, 37, 5, 52, 7, 58, 
    4, 91, 6, 41, 2, 19, 5, 69, 0, 35, 1, 74, 7,  1, 8, 11, 3, 92, 
    7, 61, 1, 67, 6, 49, 0,  4, 4, 95, 5, 83, 8, 10, 2, 64, 3, 31, 
    3, 61, 7, 68, 6, 52, 2, 53, 4, 48, 1, 66, 5, 31, 0, 16, 8, 94, 
    3, 19, 4, 53, 6, 64, 1, 65, 5, 48, 7, 17, 8, 50, 0, 48, 2, 16
  };
  const int q3922[] = {
    9, 9, // Number of jobs and machines
    0, 17, 2, 39, 6, 66, 3, 31, 5, 64, 1, 26, 8, 34, 7, 94, 4, 21, 
    6, 83, 1, 23, 3, 79, 2, 13, 0, 15, 4, 60, 7, 20, 5, 15, 8,  5, 
    2, 88, 8, 26, 6, 69, 0, 19, 1, 48, 5, 84, 4, 61, 3, 27, 7, 48, 
    3, 92, 7, 19, 5, 80, 1, 65, 4, 19, 0, 15, 6, 16, 8, 22, 2, 83, 
    2, 18, 8,  6, 3, 73, 6, 19, 4, 87, 1, 64, 0, 81, 5, 90, 7, 11, 
    4, 59, 3, 93, 0, 37, 2, 32, 1, 40, 6, 84, 8, 77, 5, 44, 7, 64, 
    6, 22, 7, 53, 1,  5, 2, 51, 5, 61, 4,  2, 3, 94, 8, 35, 0, 81, 
    7, 73, 8, 76, 2,  5, 4, 22, 3, 36, 1, 60, 5, 54, 6, 29, 0, 11, 
    4, 48, 0, 87, 5, 75, 3, 69, 8, 91, 7,  2, 2, 53, 6, 31, 1, 86
  };
  const int q3923[] = {
    9, 9, // Number of jobs and machines
    2, 16, 0, 76, 6, 43, 3, 72, 5, 36, 7, 38, 8, 73, 4, 19, 1, 11, 
    4, 21, 1,  8, 3, 77, 7, 62, 6, 47, 0, 69, 5, 12, 2, 37, 8, 17, 
    5, 44, 8, 78, 3, 50, 2, 43, 4, 19, 7, 40, 0, 23, 1, 28, 6, 64, 
    3, 40, 2, 42, 0, 41, 1,  3, 7,  1, 5, 26, 4, 16, 8, 66, 6, 54, 
    3, 97, 4, 81, 0, 21, 5,  6, 6, 46, 2, 91, 1, 50, 7, 51, 8, 61, 
    7, 12, 6, 24, 3, 71, 2, 26, 5, 51, 4, 34, 1,  1, 8, 27, 0, 31, 
    8, 90, 0, 34, 3,  9, 4, 22, 2, 76, 7, 92, 1, 90, 6, 32, 5,  4, 
    5, 47, 0, 12, 3, 72, 7, 90, 2, 54, 6, 31, 1, 34, 4, 13, 8,  2, 
    3,  1, 1, 55, 8, 45, 4, 25, 7, 85, 2, 63, 0, 44, 6, 72, 5, 32
  };
  const int q3924[] = {
    9, 9, // Number of jobs and machines
    2, 35, 6, 33, 3, 87, 7, 23, 0, 13, 8, 55, 4, 12, 1, 75, 5, 88, 
    1,  5, 0, 38, 6, 62, 5, 54, 8, 15, 7,  5, 3, 10, 4, 69, 2, 11, 
    3, 60, 5, 38, 1, 55, 2, 29, 6, 59, 4, 94, 7, 21, 8, 33, 0,  4, 
    2, 82, 8, 99, 7, 82, 6, 36, 0, 56, 4, 14, 1, 44, 3, 35, 5, 13, 
    5, 10, 8, 47, 1, 59, 6, 86, 4, 45, 2, 36, 3, 65, 0, 50, 7, 75, 
    2, 87, 7, 83, 6, 62, 0, 40, 4, 54, 8,  9, 3, 75, 5, 81, 1, 24, 
    8, 42, 0, 37, 2, 57, 1, 79, 5, 67, 4,  8, 6, 48, 7,  4, 3, 95, 
    5, 19, 2, 51, 6, 76, 0, 61, 3,  9, 4, 75, 1, 91, 7, 20, 8, 66, 
    0, 50, 8, 30, 2, 20, 3, 16, 1, 23, 4,  7, 5, 90, 6, 79, 7, 79
  };
  const int q3925[] = {
    9, 9, // Number of jobs and machines
    0, 94, 3, 92, 7, 36, 4, 30, 8, 75, 2, 71, 5, 78, 1, 82, 6, 97, 
    1, 12, 3,  2, 2, 13, 6, 12, 8,  2, 0, 54, 4, 14, 5, 88, 7, 45, 
    4, 47, 2,  6, 7, 42, 0, 68, 6, 84, 1, 97, 8, 48, 5, 90, 3, 88, 
    2, 13, 7, 85, 4, 43, 8, 15, 6, 51, 3, 31, 1, 28, 5, 56, 0, 27, 
    6, 31, 5, 30, 4, 99, 7, 65, 3, 58, 2, 77, 8, 91, 0, 56, 1, 88, 
    7, 99, 0, 56, 5,  5, 1,  9, 4, 73, 3, 29, 8, 11, 6, 35, 2, 18, 
    2, 36, 3, 88, 5, 93, 0, 62, 8, 10, 7,  4, 6, 90, 4, 54, 1, 20, 
    2,  7, 5, 65, 6,  8, 4,  2, 0, 21, 8, 40, 1, 67, 3, 87, 7, 41, 
    3, 62, 4, 26, 0, 75, 7,  7, 5, 41, 6, 67, 2, 89, 8, 80, 1, 71
  };
  const int q3926[] = {
    9, 9, // Number of jobs and machines
    7, 77, 3, 68, 2, 75, 8, 10, 1,  4, 6, 85, 4, 79, 5, 26, 0, 72, 
    7, 87, 4, 59, 6, 83, 8, 85, 0,  1, 2, 29, 1, 50, 3, 12, 5, 47, 
    2, 14, 8, 45, 7, 21, 1, 89, 5, 53, 3, 77, 0, 20, 6, 42, 4, 11, 
    0, 10, 2, 87, 5, 75, 3,  7, 8, 49, 6,  3, 7, 26, 1, 86, 4, 13, 
    2, 72, 0, 91, 7, 29, 6, 59, 4, 71, 5, 32, 1, 40, 8, 52, 3, 60, 
    4, 98, 2, 61, 1, 53, 8, 21, 3, 74, 7, 57, 0, 78, 6,  8, 5, 80, 
    7, 75, 0, 76, 8, 92, 2, 62, 3, 80, 4, 18, 6, 78, 1,  8, 5, 99, 
    0, 60, 2, 58, 8, 85, 1, 46, 4, 90, 7, 76, 3,  8, 5, 89, 6, 17, 
    8, 73, 3, 48, 2,  7, 0, 39, 6, 27, 1, 27, 5, 45, 4, 51, 7, 44
  };
  const int q3927[] = {
    9, 9, // Number of jobs and machines
    6, 61, 5, 79, 4, 14, 7, 85, 8, 61, 3, 48, 0,  9, 1, 58, 2, 40, 
    8, 20, 6, 18, 2, 88, 5, 81, 1, 64, 3, 33, 7, 96, 4, 32, 0, 79, 
    5, 91, 7, 79, 4, 62, 8, 78, 0, 15, 6, 61, 1,  1, 3, 15, 2, 68, 
    7, 89, 2, 68, 0, 46, 6, 98, 8, 11, 3, 27, 1,  4, 5, 56, 4, 34, 
    3, 41, 0, 56, 7, 90, 5, 74, 4, 27, 8, 58, 6,  2, 2, 58, 1,  3, 
    6, 18, 4,  8, 0, 34, 1, 93, 5, 98, 3, 51, 2,  8, 7, 63, 8, 53, 
    1, 18, 5, 79, 8, 45, 7, 68, 2, 79, 0,  6, 3, 87, 4, 75, 6, 77, 
    0, 51, 8, 88, 4, 98, 2, 19, 3, 69, 6, 38, 5, 28, 7, 89, 1, 36, 
    4, 34, 2, 63, 1,  4, 7, 76, 6, 99, 0, 28, 3, 76, 8, 20, 5, 11
  };
  const int q3928[] = {
    9, 9, // Number of jobs and machines
    6, 43, 2, 21, 7,  7, 8, 58, 3, 90, 4, 24, 0, 17, 5, 89, 1, 55, 
    3, 58, 4, 46, 7,  7, 2, 11, 0, 66, 5, 16, 1, 43, 8, 10, 6, 60, 
    5, 76, 7, 85, 8, 70, 3, 33, 6, 83, 1, 16, 4, 36, 2, 34, 0, 30, 
    5, 76, 7, 93, 2,  7, 8, 47, 1, 70, 4,  4, 0, 36, 6, 91, 3, 75, 
    6, 10, 3,  1, 4, 23, 8, 98, 5, 38, 0, 79, 2, 91, 7, 13, 1, 72, 
    4, 10, 8, 83, 5, 95, 7, 44, 6, 93, 3, 87, 0, 45, 1, 68, 2, 99, 
    0, 59, 3, 63, 2, 58, 6, 12, 5,  7, 1, 55, 4,  1, 7, 57, 8, 58, 
    3, 25, 6, 81, 0, 57, 8, 96, 4, 77, 2, 65, 7, 95, 5, 65, 1, 17, 
    7, 73, 5, 65, 3, 67, 0, 36, 6, 51, 8, 11, 4, 44, 2, 94, 1, 12
  };
  const int q3929[] = {
    9, 9, // Number of jobs and machines
    4, 84, 7, 97, 3, 93, 2, 37, 6, 27, 5, 44, 8, 96, 1, 73, 0, 48, 
    1, 31, 4, 33, 2, 46, 3, 32, 8, 80, 0, 87, 6, 70, 5, 57, 7, 96, 
    1, 61, 5, 78, 7, 91, 4,  6, 6, 16, 2, 77, 8, 62, 3, 15, 0,  3, 
    3, 93, 4, 62, 8, 26, 0, 90, 5, 50, 6, 77, 2, 14, 1, 49, 7, 24, 
    5, 51, 7, 80, 4, 95, 6, 19, 3, 62, 0, 86, 2, 82, 8, 45, 1, 28, 
    3,  3, 4, 68, 6, 49, 8, 23, 1, 73, 2, 29, 7,  2, 5, 86, 0, 48, 
    5, 93, 7, 89, 2, 67, 3, 69, 0, 95, 1, 20, 8, 61, 4, 13, 6, 71, 
    2, 46, 7, 73, 8, 10, 6, 10, 3, 54, 5, 98, 4, 14, 0, 35, 1, 40, 
    6, 46, 2,  7, 8,  2, 3, 30, 7, 82, 1,  2, 0, 56, 4, 52, 5, 37
  };
  const int q3930[] = {
    9, 9, // Number of jobs and machines
    4, 99, 8, 86, 3, 86, 0, 97, 7,  6, 1, 69, 5, 35, 6, 31, 2,  6, 
    2,  6, 6, 74, 3, 49, 5,  5, 8, 27, 0, 83, 4, 76, 7, 24, 1, 56, 
    2, 99, 3, 50, 0, 63, 7, 37, 8, 70, 4, 43, 6, 78, 1, 78, 5,  8, 
    4, 37, 3, 95, 2, 14, 0, 91, 7, 17, 6, 68, 5, 56, 1, 53, 8, 54, 
    1, 68, 0, 57, 7, 11, 3, 82, 6, 46, 2, 79, 4, 96, 5, 45, 8, 47, 
    1, 11, 6, 55, 4, 55, 3, 97, 2, 55, 7, 51, 0, 83, 5, 72, 8,  2, 
    0, 21, 3, 53, 4, 37, 8,  7, 2,  6, 5, 74, 6, 35, 1, 57, 7, 11, 
    5, 28, 0, 82, 2, 79, 4, 54, 7, 80, 3, 30, 8, 54, 1, 99, 6, 34, 
    8, 76, 5, 95, 4, 55, 7, 70, 1, 81, 6, 15, 0, 45, 2,  1, 3, 77
  };
  const int q3931[] = {
    9, 9, // Number of jobs and machines
    2,  1, 5, 67, 4, 71, 8,  1, 6, 76, 0, 24, 1, 68, 3, 65, 7, 75, 
    3, 94, 5, 99, 6, 85, 4,  2, 1, 94, 7, 79, 0,  2, 2,  5, 8, 65, 
    0, 99, 6, 37, 3, 98, 2, 56, 8, 59, 7, 37, 5, 96, 4, 50, 1,  4, 
    3, 22, 1, 97, 8, 17, 5, 51, 4,  6, 2, 96, 6, 99, 0, 32, 7, 42, 
    3, 84, 5, 77, 6, 85, 4, 44, 2, 70, 0, 97, 8, 30, 1,  9, 7, 60, 
    1,  1, 2, 95, 8, 51, 3, 17, 5, 40, 7, 75, 4, 80, 6, 97, 0, 51, 
    5, 99, 8, 13, 3,  7, 7,  1, 6, 90, 0, 40, 4, 55, 1, 51, 2, 25, 
    6, 10, 7, 11, 3, 76, 2, 14, 1, 16, 0, 86, 4, 61, 8, 52, 5, 77, 
    0, 47, 7, 40, 3, 19, 1, 90, 4, 91, 6,  5, 2, 97, 5, 27, 8, 54
  };
  const int q3932[] = {
    9, 9, // Number of jobs and machines
    5, 49, 1, 69, 8, 54, 6, 79, 4, 38, 0, 25, 3, 19, 2, 58, 7, 56, 
    8, 22, 5, 65, 3, 39, 1, 52, 2, 73, 4, 72, 7, 96, 6, 34, 0,  5, 
    5, 26, 8, 91, 6, 75, 0, 76, 2, 59, 3, 77, 7, 71, 1, 94, 4, 96, 
    2, 59, 1, 17, 0, 77, 4, 88, 3, 84, 5, 60, 7, 47, 8, 38, 6, 58, 
    4, 51, 3, 16, 8, 65, 1, 36, 6, 67, 0, 82, 7,  6, 5, 55, 2, 36, 
    3, 65, 7, 11, 4, 24, 6, 77, 8, 11, 0, 59, 1,  2, 5, 77, 2, 27, 
    7, 47, 1, 21, 8, 61, 5, 28, 4, 60, 2, 93, 6,  5, 3, 12, 0, 87, 
    2, 88, 0, 14, 6, 94, 5, 86, 4, 80, 3, 99, 1, 82, 8, 71, 7,  4, 
    8, 95, 1,  3, 2, 86, 6, 96, 4, 46, 3, 73, 0, 88, 5, 88, 7, 17
  };
  const int q3933[] = {
    9, 9, // Number of jobs and machines
    4, 59, 1, 73, 0, 50, 2, 74, 5,  5, 8, 73, 6, 20, 3,  1, 7, 89, 
    0, 52, 8, 76, 5, 52, 6, 50, 3, 22, 7,  6, 2, 38, 1,  8, 4, 90, 
    3, 50, 6, 25, 5, 20, 4, 16, 8, 41, 2, 38, 0, 44, 1, 69, 7, 12, 
    4, 52, 2, 96, 3, 44, 0, 45, 6, 88, 8, 73, 7, 15, 5, 12, 1, 56, 
    4,  7, 6, 92, 2, 50, 8, 18, 3, 46, 5, 62, 7, 40, 0,  2, 1, 95, 
    3, 10, 1, 97, 2, 87, 4, 23, 8, 55, 6, 13, 7, 26, 0, 68, 5,  8, 
    1, 17, 8, 49, 0, 76, 5, 10, 2, 46, 3, 29, 7, 78, 6,  5, 4, 72, 
    7, 38, 5, 92, 3, 34, 6,  9, 0,  4, 2, 25, 8, 69, 4, 72, 1, 81, 
    6, 81, 1, 90, 3, 31, 5, 47, 8, 28, 4, 45, 0, 18, 7, 59, 2, 25
  };
  const int q3934[] = {
    9, 9, // Number of jobs and machines
    7, 71, 6, 12, 0, 95, 2, 65, 4, 22, 1, 77, 8, 51, 3, 68, 5, 10, 
    8, 42, 7, 66, 2, 34, 4, 89, 3, 10, 1, 83, 0, 75, 5, 56, 6, 94, 
    8, 47, 4, 29, 5, 14, 6, 87, 3, 64, 2, 83, 0, 97, 1,  5, 7, 91, 
    5, 63, 4, 13, 2, 90, 8, 27, 6, 48, 7, 68, 3, 26, 0, 59, 1, 19, 
    1,  1, 3, 43, 7, 28, 2, 78, 5, 91, 6, 62, 4, 64, 0, 54, 8, 20, 
    1, 74, 0, 97, 6, 87, 3, 62, 8, 23, 2, 79, 7, 51, 4, 77, 5, 46, 
    6, 44, 0, 64, 1, 45, 8, 49, 5, 31, 7, 37, 3, 38, 4, 29, 2, 49, 
    6, 14, 7, 90, 2, 50, 8, 29, 0, 73, 5, 36, 4, 79, 3, 18, 1, 15, 
    0, 69, 5, 90, 4, 47, 6, 88, 7, 66, 3, 47, 8, 34, 2, 12, 1, 24
  };
  const int q3935[] = {
    9, 9, // Number of jobs and machines
    4, 23, 2, 67, 7, 33, 8, 77, 1, 38, 6, 23, 0, 75, 3, 55, 5, 23, 
    7, 26, 6, 19, 0, 78, 1, 96, 5, 34, 2, 98, 4, 49, 8, 15, 3,  3, 
    3, 32, 5, 40, 6, 95, 4, 70, 2, 43, 0, 42, 7, 99, 8, 31, 1, 25, 
    8, 77, 0, 29, 6, 23, 3, 95, 5, 99, 7, 22, 2, 95, 4, 42, 1, 93, 
    8, 53, 7, 41, 3, 27, 5, 27, 2, 70, 1, 70, 6, 94, 0, 94, 4, 68, 
    1, 48, 5, 16, 4, 96, 8, 61, 2, 79, 3, 30, 0, 68, 7,  1, 6, 24, 
    8, 74, 2, 15, 0, 99, 7, 97, 6, 30, 3, 45, 5, 71, 4, 15, 1, 91, 
    3, 20, 4, 33, 5, 77, 1, 72, 7, 78, 2, 61, 0, 37, 6, 35, 8, 46, 
    5, 37, 6, 48, 1, 21, 4, 24, 3, 65, 7, 17, 0, 99, 8, 16, 2, 85
  };
  const int q3936[] = {
    9, 9, // Number of jobs and machines
    5, 15, 8, 11, 4, 34, 3, 38, 0, 23, 2, 73, 1, 11, 7, 48, 6, 91, 
    1, 36, 5, 79, 6, 26, 4, 37, 8, 27, 7, 36, 3, 68, 0, 80, 2, 60, 
    6, 73, 4, 24, 1, 52, 3, 35, 8, 37, 0, 62, 2, 20, 5, 62, 7, 42, 
    0, 17, 1, 41, 4, 21, 7, 49, 2, 53, 6, 79, 5, 69, 8, 81, 3, 89, 
    0, 97, 6,  3, 3, 17, 8, 59, 4, 10, 1, 97, 2, 59, 7, 12, 5,  9, 
    7, 68, 5, 16, 2, 29, 1, 64, 6, 39, 8, 71, 0, 37, 4, 78, 3, 56, 
    5, 48, 1, 80, 8, 34, 3, 71, 2, 82, 6, 72, 4, 17, 7, 89, 0, 67, 
    2, 16, 1,  9, 3, 68, 0, 97, 6, 22, 8, 52, 4, 31, 5, 70, 7, 25, 
    4, 39, 6, 48, 1, 51, 3, 21, 5, 97, 2, 10, 7, 33, 0, 36, 8, 62
  };
  const int q3937[] = {
    9, 9, // Number of jobs and machines
    2, 39, 4, 48, 6,  7, 7, 88, 3, 84, 8, 81, 0, 32, 5, 78, 1, 87, 
    1, 39, 5, 99, 4, 15, 2, 70, 3, 11, 7, 17, 6, 22, 8, 52, 0, 72, 
    8, 22, 3,  3, 5, 96, 4, 88, 1, 67, 0, 86, 2, 92, 7,  4, 6, 17, 
    8, 78, 6, 30, 1, 37, 7, 87, 5, 46, 4, 78, 3, 89, 0, 36, 2, 72, 
    0, 31, 3, 51, 4, 47, 8, 79, 1, 77, 2, 48, 7, 13, 6, 82, 5, 24, 
    0, 58, 8, 19, 2, 84, 6, 71, 7, 83, 3, 17, 1, 78, 4, 80, 5, 43, 
    6, 19, 2,  2, 5, 36, 1, 16, 0, 76, 7, 72, 4, 36, 8, 12, 3, 76, 
    1, 76, 5, 33, 2, 90, 3, 22, 0, 81, 7,  2, 6, 49, 4, 17, 8, 27, 
    3, 81, 1, 58, 7, 13, 4, 52, 5, 81, 6, 69, 0, 57, 2, 60, 8, 59
  };
  const int q3938[] = {
    9, 9, // Number of jobs and machines
    3, 18, 5, 76, 7, 66, 4, 11, 8, 58, 0, 46, 1, 68, 6, 41, 2, 68, 
    7,  8, 4, 57, 1, 37, 2, 45, 5, 64, 0, 42, 8, 29, 3, 48, 6, 57, 
    0, 40, 4, 66, 6,  1, 2, 69, 3, 85, 1, 33, 7, 68, 5, 95, 8, 10, 
    0, 68, 3, 12, 7, 28, 5, 13, 4, 99, 1, 39, 8, 63, 6, 86, 2, 30, 
    3,  4, 0, 71, 7, 95, 2, 15, 6, 61, 1, 65, 4, 96, 8, 15, 5, 73, 
    0, 45, 5, 79, 8, 55, 4, 48, 1, 81, 7, 79, 3, 68, 6, 57, 2, 30, 
    3, 78, 4, 54, 5, 73, 2, 45, 1, 82, 8, 64, 6, 70, 0, 92, 7, 57, 
    3, 70, 0, 63, 2, 33, 4, 63, 5, 94, 7, 51, 6,  9, 1, 84, 8, 92, 
    4, 29, 2, 51, 0,  7, 7, 21, 3,  1, 5, 90, 6, 30, 8, 57, 1,  9
  };
  const int q3939[] = {
    9, 9, // Number of jobs and machines
    5, 37, 4, 65, 1, 79, 0, 58, 7, 12, 2, 84, 3, 43, 8, 31, 6,  4, 
    3, 31, 0, 65, 5,  3, 7,  3, 8, 12, 6, 14, 2,  3, 4, 89, 1, 30, 
    1, 47, 2, 31, 8, 93, 6, 82, 0, 74, 5, 73, 3, 22, 4, 31, 7, 35, 
    5, 39, 6, 34, 4, 21, 7, 82, 1, 89, 8, 74, 3, 50, 2, 53, 0, 24, 
    6,  9, 5,  7, 7, 71, 2, 60, 0, 25, 8, 53, 3, 66, 1, 14, 4, 33, 
    6, 67, 7, 51, 2,  4, 8, 34, 3,  4, 4, 56, 1, 36, 0, 47, 5, 73, 
    7, 17, 6, 33, 8, 85, 2, 79, 5, 14, 3, 39, 4, 26, 1, 18, 0, 20, 
    7, 54, 6, 13, 4, 60, 3, 31, 8, 76, 0, 55, 1, 71, 2,  6, 5, 27, 
    3, 94, 6, 73, 1, 60, 5,  2, 7, 36, 4, 57, 2, 32, 8, 41, 0, 20
  };
  const int q3940[] = {
    9, 9, // Number of jobs and machines
    8, 27, 1, 25, 5,  8, 7, 78, 4, 60, 0, 53, 2, 89, 6, 73, 3, 34, 
    7, 69, 3, 76, 2, 51, 8, 96, 4, 12, 0, 45, 5, 76, 1, 51, 6,  6, 
    7, 37, 3, 86, 2, 90, 6, 60, 1, 70, 5, 32, 8,  8, 0, 76, 4, 61, 
    8, 20, 0, 86, 6, 83, 4, 73, 2, 31, 7, 59, 5, 17, 3, 23, 1, 81, 
    2,  1, 5, 38, 6, 23, 1, 24, 4, 51, 8, 12, 0, 76, 7, 63, 3, 38, 
    8, 45, 4, 62, 7, 27, 1, 14, 3, 63, 2, 79, 6, 69, 0, 55, 5,  1, 
    1, 27, 4, 87, 2, 20, 7, 48, 8,  7, 0, 99, 5, 38, 6, 78, 3, 68, 
    0, 77, 4, 74, 5, 63, 1, 63, 2, 56, 6,  5, 7, 34, 8, 43, 3, 23, 
    2, 22, 1, 43, 0, 99, 5, 78, 3, 26, 7, 57, 8, 44, 4, 19, 6, 20
  };
  const int q3941[] = {
    9, 9, // Number of jobs and machines
    2, 49, 8, 91, 0, 47, 4, 41, 3, 67, 5, 88, 1, 50, 6, 49, 7, 28, 
    8,  3, 1, 76, 7,  1, 2, 25, 3, 11, 6, 49, 5, 48, 4, 86, 0, 54, 
    5, 82, 1, 17, 8, 56, 0, 65, 4, 50, 2, 70, 3, 21, 6, 13, 7, 53, 
    2, 26, 5, 70, 6, 78, 7, 60, 3, 17, 8, 40, 0, 17, 4, 61, 1, 44, 
    7, 99, 3, 22, 1, 29, 4, 90, 8, 78, 2, 88, 5, 74, 0, 77, 6, 58, 
    6, 45, 2, 90, 1, 18, 4, 82, 3, 61, 5, 45, 0,  8, 8, 50, 7, 65, 
    6, 42, 3, 58, 7, 48, 0, 30, 5, 14, 8, 25, 2, 22, 1, 31, 4,  7, 
    8, 57, 4, 86, 7, 70, 0, 61, 3, 16, 1, 38, 2, 80, 6, 94, 5, 15, 
    6, 31, 3, 23, 1, 80, 5, 70, 4, 28, 0, 29, 7, 38, 2, 73, 8, 34
  };
  const int q3942[] = {
    9, 9, // Number of jobs and machines
    2, 61, 7,  6, 5, 82, 1, 49, 8,  8, 3, 97, 0, 15, 6, 59, 4, 33, 
    2, 54, 1, 38, 8, 48, 4, 36, 3, 51, 0, 31, 7,  4, 5, 16, 6, 34, 
    1, 48, 3, 83, 2, 40, 4,  3, 5, 51, 7, 36, 0, 51, 8, 41, 6, 14, 
    4, 41, 7, 26, 1, 39, 3, 91, 5, 38, 0, 99, 2, 97, 6, 32, 8, 56, 
    7, 67, 0, 99, 1,  9, 5, 54, 3, 31, 2,  9, 6, 75, 8, 30, 4, 84, 
    8, 68, 2, 40, 4, 23, 6, 80, 7, 36, 5, 20, 1, 83, 0, 93, 3, 46, 
    1, 96, 2, 63, 5, 91, 7, 37, 8, 89, 4,  6, 0, 48, 6,  6, 3, 97, 
    3, 88, 8, 65, 6, 92, 5, 55, 7, 25, 2, 29, 4, 64, 0, 48, 1, 60, 
    7, 28, 6, 64, 0, 49, 8, 81, 2, 64, 3, 42, 4, 72, 1, 80, 5, 76
  };
  const int q3943[] = {
    9, 9, // Number of jobs and machines
    8, 80, 2, 94, 4, 96, 6, 29, 3, 64, 7, 98, 0, 78, 5, 99, 1, 82, 
    0, 21, 7, 39, 4,  2, 5, 23, 8,  4, 6, 38, 1, 94, 3, 76, 2, 18, 
    1, 58, 7,  8, 0,  3, 2, 60, 4, 70, 8, 72, 5,  8, 6, 13, 3, 56, 
    5, 28, 2, 62, 0, 51, 1, 66, 6,  9, 3, 70, 7, 36, 8, 88, 4, 24, 
    8, 45, 6, 41, 1, 48, 4, 81, 3, 82, 5, 54, 7, 38, 0, 26, 2, 99, 
    3, 17, 4, 29, 7, 74, 0,  2, 2,  5, 8, 66, 5, 82, 6, 64, 1,  7, 
    8, 29, 6, 26, 3, 33, 2, 79, 5, 57, 1, 55, 0, 77, 7, 86, 4, 10, 
    6, 26, 7, 97, 0, 92, 1, 94, 8, 20, 5,  8, 2, 95, 3, 52, 4, 85, 
    7, 62, 1, 55, 3, 53, 5, 31, 2,  7, 6, 52, 8, 36, 4, 59, 0, 25
  };
  const int q3944[] = {
    9, 9, // Number of jobs and machines
    8, 52, 2, 99, 1, 13, 7, 19, 6, 44, 3, 76, 0, 56, 5, 65, 4,  5, 
    1, 90, 2, 16, 8, 61, 4, 35, 7,  3, 3, 50, 5, 79, 0, 52, 6, 48, 
    5, 31, 6, 89, 8, 93, 3, 76, 2, 91, 4, 68, 0, 24, 7,  2, 1, 93, 
    0, 37, 5, 28, 7, 58, 8, 31, 3, 60, 6, 59, 1, 18, 2, 92, 4, 69, 
    4, 63, 8, 39, 2,  6, 1, 97, 7, 67, 0,  9, 6, 47, 5, 15, 3, 47, 
    3, 95, 0, 77, 6, 25, 2, 90, 7, 30, 4, 73, 5, 45, 8, 42, 1, 95, 
    6, 66, 1, 40, 0, 89, 5, 99, 8, 23, 2, 98, 4, 63, 7, 22, 3, 72, 
    7, 98, 8, 89, 1, 52, 5, 73, 2, 16, 0, 77, 3, 85, 6, 98, 4, 48, 
    8, 34, 4, 78, 6, 22, 2, 64, 3,  6, 5, 36, 7, 60, 1, 53, 0, 52
  };
  const int q3945[] = {
    9, 9, // Number of jobs and machines
    3, 45, 4, 85, 0, 85, 6, 35, 8, 71, 2, 94, 5, 87, 1, 12, 7, 28, 
    0, 99, 7, 24, 8, 51, 5, 73, 6, 78, 1, 68, 2, 30, 4, 32, 3, 20, 
    1, 79, 4, 82, 0, 72, 3, 33, 5, 30, 8, 85, 7, 68, 2, 95, 6, 15, 
    6, 35, 3,  4, 5, 80, 0, 95, 4, 48, 2, 52, 1, 34, 8, 29, 7, 61, 
    7, 51, 3, 17, 2, 17, 0, 10, 4, 11, 5, 71, 8, 50, 6, 62, 1, 94, 
    8, 29, 7, 68, 1, 80, 6, 18, 2, 11, 5, 75, 4, 56, 3, 87, 0, 42, 
    3, 14, 8, 36, 0, 43, 6, 52, 7, 42, 2, 64, 5, 70, 1, 18, 4, 15, 
    4, 70, 2,  9, 8,  7, 6,  5, 5, 66, 0, 36, 7, 98, 1, 45, 3,  9, 
    5, 31, 0, 29, 6, 32, 7, 89, 3, 94, 1, 13, 2, 74, 4, 46, 8, 96
  };
  const int q3946[] = {
    9, 9, // Number of jobs and machines
    0,  6, 7, 54, 2, 86, 8, 99, 1, 31, 5, 16, 6,  5, 4, 17, 3, 75, 
    8, 45, 0, 81, 7, 67, 6, 19, 5, 57, 3, 73, 1, 46, 2, 27, 4, 14, 
    6, 88, 8, 18, 7, 16, 3, 30, 4, 45, 0, 34, 5, 84, 1, 17, 2, 44, 
    8, 40, 3, 68, 6, 33, 5,  7, 7, 97, 1, 20, 2, 21, 4, 37, 0,  6, 
    4, 69, 0, 76, 6,  1, 1, 93, 7, 73, 5, 72, 3, 73, 8, 32, 2, 85, 
    8, 64, 3, 41, 0, 72, 5, 75, 1, 67, 4, 16, 7, 64, 2, 38, 6, 33, 
    1, 27, 8, 22, 0, 14, 7, 37, 4, 47, 5, 38, 6, 34, 3, 61, 2, 30, 
    7, 47, 5, 57, 4, 52, 3, 52, 2, 96, 1, 84, 0, 43, 6, 69, 8, 62, 
    3,  1, 7, 92, 5, 21, 2, 69, 6, 71, 1, 25, 0, 45, 4, 49, 8, 48
  };
  const int q3947[] = {
    9, 9, // Number of jobs and machines
    3, 49, 7, 66, 5, 33, 4,  4, 2, 22, 8, 47, 0, 80, 1, 66, 6, 29, 
    0, 82, 6, 56, 7, 17, 4, 62, 8, 82, 2, 46, 1, 10, 3, 51, 5, 51, 
    3, 45, 0,  8, 1, 53, 4,  2, 5, 56, 2, 23, 6, 11, 8, 11, 7, 32, 
    0, 73, 5, 20, 4, 77, 2, 47, 6, 51, 8, 47, 1, 74, 3,  6, 7, 92, 
    3, 19, 6, 18, 2, 36, 7, 16, 8, 23, 0, 26, 5, 16, 1, 15, 4, 71, 
    7,  4, 8, 50, 1, 24, 0,  8, 6, 31, 3, 84, 2, 50, 4, 19, 5, 41, 
    5, 71, 7, 43, 1, 64, 3, 69, 4, 15, 6, 70, 2, 74, 8, 84, 0,  2, 
    0, 31, 4, 71, 5, 99, 3, 76, 2, 63, 6, 45, 7,  2, 1, 20, 8, 28, 
    6, 56, 1, 65, 8, 59, 0, 45, 4,  2, 3, 39, 2, 45, 5, 41, 7, 68
  };
  const int q3948[] = {
    9, 9, // Number of jobs and machines
    5, 43, 8,  2, 2,  4, 0, 16, 1, 51, 6, 91, 4, 74, 3, 41, 7, 19, 
    6, 82, 0, 81, 5, 28, 4, 83, 7,  6, 2, 87, 1, 28, 3, 92, 8,  9, 
    2, 97, 0, 74, 6, 58, 1, 17, 8, 68, 3, 12, 4,  3, 5, 91, 7, 36, 
    8, 41, 3, 39, 1, 22, 4, 37, 6, 89, 5, 24, 2, 72, 7, 30, 0, 76, 
    4, 38, 5, 62, 8, 93, 0,  4, 2, 97, 1, 56, 6, 26, 7, 47, 3, 55, 
    8, 97, 0, 31, 7, 74, 2, 70, 5, 15, 4, 73, 1, 44, 6, 69, 3, 58, 
    8, 29, 6, 47, 5, 98, 0, 80, 2, 16, 3, 72, 1, 85, 4, 32, 7, 54, 
    3, 48, 1, 96, 4, 64, 5, 13, 0, 96, 7, 28, 2, 20, 6, 81, 8, 31, 
    4,  4, 8,  4, 5, 99, 7,  9, 6, 92, 3, 41, 0, 53, 1, 29, 2, 66
  };
  const int q3949[] = {
    9, 9, // Number of jobs and machines
    1, 47, 8, 98, 3,  8, 2, 78, 0, 15, 6, 21, 5, 44, 7, 79, 4, 24, 
    7, 76, 8, 70, 2, 33, 6, 59, 0, 82, 3, 65, 5, 52, 4,  3, 1, 94, 
    1, 76, 3, 46, 2,  4, 0, 97, 7, 98, 6, 73, 4, 25, 5, 53, 8,  1, 
    4, 39, 3,  2, 5, 21, 2, 38, 6, 55, 8,  4, 0, 91, 1, 14, 7, 55, 
    8, 65, 1, 39, 6, 29, 4, 32, 2, 61, 7,  3, 0, 90, 5, 34, 3, 75, 
    0, 92, 5, 95, 1, 69, 2, 36, 3, 52, 7, 60, 8,  4, 6, 80, 4, 71, 
    3, 31, 6, 70, 1, 20, 5, 45, 2, 51, 7, 13, 4, 87, 0, 40, 8, 87, 
    6, 54, 5, 78, 7, 83, 2, 27, 1, 38, 3, 96, 0, 37, 8, 51, 4,  5, 
    6, 96, 2, 23, 4, 53, 7, 61, 1, 48, 8, 56, 0, 96, 3, 68, 5, 38
  };
  const int q3950[] = {
    9, 9, // Number of jobs and machines
    6, 48, 0, 50, 4, 26, 3, 26, 1, 95, 5, 73, 2, 14, 7, 96, 8, 51, 
    2, 96, 6, 79, 8, 89, 4, 44, 5, 85, 1, 66, 7, 47, 0, 73, 3, 66, 
    6, 49, 8, 51, 5, 96, 2, 69, 3,  1, 7, 31, 4, 64, 1, 87, 0, 26, 
    5, 22, 1,  1, 2, 39, 8,  3, 3,  2, 4, 92, 0, 57, 7,  2, 6, 59, 
    7, 71, 4, 22, 8, 72, 0, 92, 6, 21, 2, 57, 5, 84, 3, 97, 1, 68, 
    7, 37, 3, 73, 4, 49, 0, 48, 2, 20, 6, 69, 5, 97, 1,  4, 8, 42, 
    2, 64, 3, 89, 1,  5, 4, 80, 6, 71, 8, 52, 0, 55, 5, 79, 7, 71, 
    1, 54, 8, 59, 7, 52, 5,  1, 0, 24, 4, 20, 3, 90, 2, 76, 6, 75, 
    5, 49, 7, 21, 2, 67, 3, 45, 6, 37, 0, 91, 1, 68, 8, 11, 4, 67
  };
  const int q3951[] = {
    9, 9, // Number of jobs and machines
    0, 32, 8, 95, 6, 59, 7, 32, 2, 57, 5, 45, 1, 87, 3, 41, 4, 11, 
    8, 66, 5,  1, 3,  2, 0,  8, 1, 10, 2, 80, 4, 62, 7, 75, 6, 13, 
    3, 35, 2, 92, 8, 29, 7, 65, 6, 80, 4, 88, 5, 42, 0, 72, 1, 22, 
    8,  7, 1, 13, 6, 33, 2, 39, 5, 82, 7, 21, 0, 18, 4, 57, 3, 81, 
    8, 88, 4,  9, 5, 66, 3, 67, 7, 91, 0, 59, 6, 22, 1, 57, 2, 81, 
    3, 67, 7, 50, 2, 19, 8, 61, 4,  3, 5, 51, 6, 20, 0, 66, 1, 65, 
    8, 23, 3, 44, 2, 31, 0, 34, 4,  5, 7, 90, 1, 29, 6, 80, 5, 65, 
    2, 34, 0, 59, 5, 91, 1, 23, 7, 61, 8, 50, 6, 37, 4, 88, 3, 17, 
    6, 31, 4, 97, 5, 45, 3, 98, 8, 66, 7, 55, 1, 85, 2, 28, 0, 71
  };
  const int q3952[] = {
    9, 9, // Number of jobs and machines
    0, 23, 7, 17, 4, 24, 1, 58, 5, 41, 6, 27, 8, 66, 2, 74, 3, 47, 
    1, 74, 3, 37, 5, 67, 2, 93, 0, 19, 4, 85, 6, 81, 8, 88, 7, 50, 
    5, 98, 8, 36, 2, 60, 0, 83, 3, 43, 6, 92, 4, 20, 7, 89, 1, 71, 
    5, 55, 4, 55, 1, 52, 6, 36, 2, 47, 8, 65, 0,  8, 7, 48, 3, 49, 
    5, 46, 4, 61, 0, 23, 1, 67, 8, 72, 3, 27, 6, 28, 7, 41, 2, 48, 
    7, 52, 0, 31, 3, 57, 1, 83, 4, 62, 6, 83, 2, 56, 8, 70, 5, 29, 
    4, 48, 3, 85, 7,  4, 1, 62, 0, 28, 8, 90, 6, 94, 5, 11, 2, 96, 
    1, 78, 5,  5, 8, 31, 4, 98, 7, 41, 0, 75, 3, 30, 2, 61, 6, 85, 
    2, 39, 6, 66, 1, 93, 5, 71, 7, 27, 3, 43, 0, 51, 8, 22, 4, 98
  };
  const int q3953[] = {
    9, 9, // Number of jobs and machines
    6, 69, 3, 78, 0,  2, 1, 74, 2, 79, 8, 46, 5, 71, 4, 69, 7, 25, 
    4, 59, 3, 62, 0, 94, 1, 43, 2, 66, 7, 91, 5, 40, 6, 12, 8, 55, 
    6, 14, 0, 65, 5, 92, 7, 62, 3, 67, 1, 27, 8, 75, 4, 57, 2, 53, 
    0, 29, 1, 14, 3, 99, 2, 95, 7, 93, 4,  1, 5, 41, 6, 63, 8, 76, 
    8, 60, 5, 10, 0, 77, 6, 19, 7, 92, 4,  5, 2, 78, 1, 24, 3, 21, 
    7, 62, 0,  2, 4, 21, 1, 14, 8,  4, 3, 19, 5, 52, 2,  9, 6, 40, 
    8, 65, 5,  5, 3, 36, 6, 39, 1, 13, 7, 85, 0, 79, 2, 30, 4, 20, 
    3, 93, 0, 38, 7, 11, 4, 73, 6, 18, 2, 22, 1, 18, 5, 26, 8, 16, 
    5, 64, 1, 25, 8, 68, 6, 56, 4, 54, 2, 91, 0, 62, 7, 58, 3, 78
  };
  const int q3954[] = {
    9, 9, // Number of jobs and machines
    7,  7, 6, 67, 0, 83, 1, 96, 5, 30, 8, 16, 2, 72, 3, 56, 4, 56, 
    6, 53, 0, 43, 1,  4, 7, 26, 4, 38, 2, 65, 8, 75, 5, 55, 3, 66, 
    1, 67, 0, 80, 4, 44, 2, 82, 3, 32, 7, 65, 5, 86, 8, 42, 6, 37, 
    2, 27, 8, 93, 0,  8, 1, 45, 3, 58, 5, 12, 6, 82, 7, 27, 4, 95, 
    1, 20, 3, 51, 2, 53, 7, 50, 6, 92, 5, 61, 0, 38, 4, 97, 8, 22, 
    3, 31, 7, 43, 0,  1, 6, 86, 1, 97, 4, 33, 2, 84, 8, 82, 5, 38, 
    8, 30, 2, 97, 4, 80, 6, 61, 0, 22, 5, 51, 7, 35, 3, 18, 1, 89, 
    6, 54, 1, 19, 2, 99, 3, 52, 5, 50, 7, 37, 0, 18, 8, 79, 4, 74, 
    5, 10, 7,  5, 3, 29, 4, 87, 0, 71, 6, 59, 2, 38, 8, 46, 1, 50
  };
  const int q3955[] = {
    9, 9, // Number of jobs and machines
    1, 35, 0,  1, 6, 58, 2, 53, 3, 37, 8, 86, 4, 13, 5, 26, 7, 94, 
    3, 36, 5, 55, 7, 22, 1, 74, 0, 35, 6, 99, 4, 32, 2, 29, 8, 62, 
    8, 89, 0, 92, 4, 50, 2, 87, 1, 71, 6, 28, 7, 36, 5,  3, 3, 54, 
    5, 82, 2, 36, 4, 16, 8, 38, 0, 18, 1, 68, 7,  1, 3, 32, 6, 17, 
    7, 62, 2, 17, 0, 90, 6, 86, 4, 91, 8, 67, 1, 86, 5, 68, 3,  2, 
    5, 69, 0, 12, 8, 81, 7,  9, 2, 50, 1, 55, 4, 97, 6, 29, 3,  2, 
    6, 53, 0, 61, 4, 28, 3, 18, 1, 13, 8, 86, 5,  4, 2, 97, 7,  3, 
    0, 70, 4, 55, 5,  5, 8,  6, 1, 58, 2, 64, 6, 19, 3, 29, 7, 47, 
    5,  4, 4, 38, 1, 26, 6, 40, 7,  4, 0, 86, 8, 43, 3, 48, 2, 58
  };
  const int q3956[] = {
    9, 9, // Number of jobs and machines
    0, 12, 7, 17, 3, 10, 6, 71, 8, 31, 2, 11, 1,  4, 5, 67, 4, 67, 
    6, 95, 8, 75, 5, 99, 7,  4, 4, 22, 2, 70, 0, 98, 1, 19, 3, 70, 
    8, 89, 0, 96, 1,  5, 7,  3, 4,  2, 2, 95, 6, 47, 5,  1, 3, 63, 
    4, 15, 5, 21, 0, 46, 7, 70, 1, 58, 8, 20, 2, 38, 3,  1, 6,  9, 
    0, 69, 6, 55, 5, 89, 8, 64, 1, 72, 4, 97, 2, 42, 7, 14, 3, 37, 
    5, 20, 4, 20, 2, 14, 0,  1, 1, 40, 7, 93, 3, 32, 6, 20, 8, 45, 
    5, 75, 3, 20, 1, 18, 2, 35, 6, 49, 8, 35, 7, 36, 4, 39, 0, 92, 
    7, 60, 3, 14, 6, 89, 2, 88, 8,  9, 5, 31, 4, 13, 1, 84, 0, 18, 
    4,  5, 7, 34, 1, 61, 0, 94, 3, 45, 6, 71, 2, 86, 5, 27, 8, 56
  };
  const int q3957[] = {
    9, 9, // Number of jobs and machines
    2, 57, 0, 24, 7, 75, 5, 41, 3, 33, 1, 87, 4, 77, 8,  1, 6, 63, 
    5, 33, 1, 31, 6, 13, 7, 32, 4, 35, 0, 38, 8, 75, 2, 79, 3, 98, 
    6,  5, 3, 61, 2, 36, 1, 91, 7, 66, 8, 64, 5, 20, 4, 24, 0, 43, 
    1, 32, 0, 90, 8, 17, 5, 43, 2,  4, 7, 36, 6, 63, 3, 16, 4, 77, 
    4, 93, 5, 58, 1, 63, 6, 81, 2, 65, 8, 16, 0, 59, 3, 60, 7, 10, 
    4,  2, 3, 99, 1, 66, 7, 21, 0, 50, 8,  1, 5, 65, 2, 98, 6, 17, 
    7, 43, 2, 94, 8, 92, 4, 18, 0, 61, 6, 26, 3, 79, 1, 11, 5, 93, 
    1, 25, 2,  4, 4, 17, 8, 59, 3, 69, 0, 28, 6, 60, 5, 89, 7, 46, 
    3, 46, 2, 13, 6, 86, 8, 11, 5, 38, 1, 74, 0, 88, 4, 62, 7, 15
  };
  const int q3958[] = {
    9, 9, // Number of jobs and machines
    0, 85, 6, 48, 5, 49, 2, 57, 7, 21, 8, 16, 4, 78, 1,  4, 3, 86, 
    7, 38, 2, 44, 6, 95, 8,  6, 4, 69, 0, 70, 5, 88, 3, 51, 1, 13, 
    8,  8, 5, 43, 6, 57, 2, 73, 4, 62, 0, 18, 3, 19, 7, 72, 1, 28, 
    8, 68, 3, 60, 7, 17, 0, 56, 6, 89, 4,  4, 5, 87, 2, 68, 1, 52, 
    1, 70, 4, 73, 5, 92, 3, 72, 0, 40, 8, 67, 2, 61, 7, 88, 6, 18, 
    2,  5, 5, 88, 7, 28, 3, 41, 4, 24, 6, 40, 1, 24, 8, 36, 0, 97, 
    4, 44, 2, 39, 7, 82, 0, 13, 1, 17, 8, 50, 3, 58, 6, 44, 5, 37, 
    5, 49, 2, 88, 8, 13, 0, 19, 7, 11, 1, 44, 4, 36, 3, 20, 6, 90, 
    2, 51, 1, 87, 0, 19, 6, 25, 7, 62, 3, 46, 4, 82, 8, 77, 5, 14
  };
  const int q3959[] = {
    9, 9, // Number of jobs and machines
    5,  9, 3, 73, 4, 15, 0, 49, 8, 89, 1, 45, 6, 48, 7, 94, 2, 28, 
    5,  2, 6, 83, 1, 20, 3, 71, 0, 69, 4, 46, 7, 65, 8, 96, 2, 76, 
    2, 13, 1, 58, 8, 39, 5, 16, 7, 70, 4, 88, 3, 63, 6,  7, 0, 21, 
    7, 81, 4, 54, 8, 97, 6, 99, 1, 28, 3, 89, 5, 63, 0, 86, 2, 30, 
    4, 25, 8, 10, 0, 98, 5, 99, 3, 75, 7, 77, 2, 19, 1,  8, 6, 46, 
    4, 46, 5, 30, 6, 83, 8, 66, 7, 41, 0, 26, 1, 13, 2, 90, 3, 32, 
    6, 78, 4, 36, 1, 15, 7, 97, 3, 46, 0, 16, 2, 40, 5, 29, 8, 51, 
    1, 71, 6, 11, 0, 39, 7,  6, 8, 32, 3, 93, 5, 80, 4, 66, 2, 22, 
    2, 25, 4, 82, 1, 33, 0, 57, 7, 36, 5, 61, 8, 74, 6, 96, 3, 29
  };
  const int q3960[] = {
    9, 9, // Number of jobs and machines
    5, 73, 4, 32, 0, 23, 2, 87, 1, 95, 7,  7, 6, 91, 8, 13, 3, 53, 
    6, 65, 0, 16, 3, 85, 5,  8, 2, 95, 4, 89, 1, 54, 7, 28, 8, 28, 
    7, 52, 4, 21, 6, 59, 1, 67, 0,  9, 8, 78, 3, 59, 5, 89, 2, 88, 
    2, 83, 1, 24, 4, 34, 0,  2, 7, 12, 8, 19, 6, 35, 5, 33, 3, 97, 
    0, 96, 2, 14, 7, 44, 1, 13, 6, 77, 5,  6, 8, 44, 3, 51, 4, 55, 
    5, 69, 6, 98, 4, 79, 7, 96, 1, 11, 0, 20, 3, 86, 8, 46, 2, 75, 
    4,  8, 2, 88, 1, 70, 6, 27, 3,  6, 8,  6, 5, 45, 0, 61, 7, 69, 
    6,  5, 3, 19, 8, 67, 2, 44, 5, 25, 4, 99, 1, 28, 7, 34, 0, 13, 
    7, 34, 0, 79, 6, 96, 3, 38, 8, 12, 2, 30, 5, 84, 4, 68, 1, 40
  };
  const int q3961[] = {
    9, 9, // Number of jobs and machines
    8, 85, 2, 11, 5, 40, 0,  7, 4, 89, 7, 27, 6, 11, 3, 11, 1, 15, 
    5, 71, 7, 89, 4, 19, 1, 94, 0, 78, 6, 43, 3, 71, 2, 40, 8, 95, 
    4, 52, 7, 83, 2, 79, 6, 86, 0, 82, 1, 98, 3, 11, 8, 18, 5, 57, 
    3, 55, 7, 53, 2, 68, 5, 82, 1, 66, 4, 92, 6, 36, 0, 88, 8, 16, 
    0, 42, 5, 86, 6, 88, 4, 20, 7, 95, 3, 16, 1, 45, 2,  8, 8, 73, 
    3, 95, 4, 32, 0, 94, 1, 61, 5, 62, 2, 86, 6, 72, 8, 80, 7, 39, 
    1, 56, 7,  2, 4, 22, 6, 44, 2, 27, 8, 98, 3, 22, 5, 44, 0, 96, 
    1, 97, 2, 71, 5,  4, 7, 75, 6, 53, 4, 94, 3, 50, 0, 26, 8, 38, 
    8, 44, 5, 52, 1, 44, 0, 91, 4, 81, 2, 98, 6, 79, 3, 98, 7, 22
  };
  const int q3962[] = {
    9, 9, // Number of jobs and machines
    4, 39, 6, 46, 7, 22, 5, 12, 0, 38, 3, 14, 2, 44, 1, 85, 8,  1, 
    8, 75, 4, 59, 2, 78, 6, 89, 3, 95, 7, 45, 0, 88, 5, 37, 1, 26, 
    1, 64, 2, 95, 4, 15, 6, 75, 3, 51, 0, 37, 5, 50, 7, 19, 8, 19, 
    2,  2, 7, 43, 6, 19, 0, 88, 1, 68, 8, 93, 3, 97, 5, 14, 4,  2, 
    8, 43, 1, 58, 5, 70, 2, 10, 6, 52, 4, 99, 7, 54, 0, 11, 3, 82, 
    3, 59, 1, 74, 2, 59, 7, 63, 8, 58, 4,  6, 6, 86, 5, 86, 0, 44, 
    2, 20, 7, 44, 4, 96, 3, 57, 8, 38, 5,  3, 1, 42, 6, 84, 0, 80, 
    4, 45, 2, 46, 5, 51, 8, 78, 1, 39, 7, 50, 0, 82, 6, 17, 3, 39, 
    3, 92, 7, 59, 4, 64, 0, 51, 8, 98, 1, 56, 2, 65, 5, 19, 6, 54
  };
  const int q3963[] = {
    9, 9, // Number of jobs and machines
    3, 52, 4, 97, 1,  2, 7, 26, 8, 95, 0, 37, 5, 94, 6, 92, 2, 73, 
    2, 61, 7, 31, 5, 90, 1,  9, 4, 15, 8, 86, 3, 33, 6, 11, 0, 87, 
    7, 41, 2, 26, 6, 33, 1, 84, 8, 15, 0, 45, 5, 54, 4, 68, 3,  6, 
    0, 66, 6, 95, 5, 34, 7, 89, 8, 12, 1, 10, 4, 30, 3, 52, 2,  8, 
    7,  6, 3,  7, 0, 62, 4, 77, 2, 60, 8, 12, 5,  2, 1, 40, 6, 74, 
    5, 58, 8, 10, 1,  2, 7, 26, 3, 24, 2, 42, 4, 38, 6, 54, 0, 90, 
    0, 74, 6, 60, 7, 41, 1, 54, 8, 70, 3, 81, 2, 64, 4, 65, 5, 99, 
    5, 77, 2, 58, 4, 48, 7, 26, 0, 40, 3, 37, 6,  7, 1, 40, 8, 28, 
    5, 57, 4, 24, 8, 93, 0, 63, 3,  3, 2, 14, 1, 57, 7, 83, 6, 76
  };
  const int q3964[] = {
    9, 9, // Number of jobs and machines
    2, 32, 1, 16, 7, 10, 5, 19, 4, 80, 8, 68, 3, 24, 6, 14, 0, 58, 
    5, 41, 6, 88, 3, 86, 0, 73, 7, 58, 8,  5, 1, 88, 4, 69, 2, 14, 
    1, 93, 7, 78, 3, 27, 4, 87, 8, 29, 2, 67, 6,  4, 5, 32, 0, 13, 
    8, 85, 3, 32, 0, 98, 7, 59, 5, 52, 6, 52, 1, 96, 4, 76, 2, 53, 
    7, 40, 8, 51, 0, 80, 3, 78, 4, 95, 5, 59, 6, 38, 2,  5, 1, 27, 
    7, 95, 2, 66, 3, 35, 0, 68, 4, 10, 5, 78, 1, 30, 6, 43, 8, 40, 
    7, 62, 4, 70, 8, 29, 1, 42, 0, 27, 2, 54, 5, 48, 3, 41, 6, 69, 
    1, 31, 0, 95, 2, 18, 5, 68, 7, 22, 4, 54, 3, 26, 6, 60, 8, 34, 
    2, 23, 1, 24, 0, 97, 5, 59, 8, 34, 4, 82, 3, 40, 7, 77, 6, 93
  };
  const int q3965[] = {
    9, 9, // Number of jobs and machines
    7, 76, 2, 99, 8, 91, 0, 10, 4, 14, 6, 97, 5, 59, 1, 46, 3, 69, 
    5, 71, 6,  3, 8, 25, 0, 92, 1, 21, 4, 63, 7, 80, 3, 23, 2, 90, 
    5, 95, 7, 51, 0, 83, 1, 59, 6, 67, 2, 50, 4, 51, 3, 91, 8, 84, 
    4,  8, 3, 20, 8, 89, 6, 54, 5, 24, 1, 74, 7, 14, 2,  7, 0, 40, 
    1, 71, 3, 49, 5, 24, 4, 28, 2, 67, 8, 94, 0,  1, 7, 68, 6, 32, 
    7, 11, 2, 35, 8, 61, 3, 71, 5, 47, 4, 89, 1, 41, 0, 65, 6,  5, 
    1, 88, 6, 17, 5,  6, 2, 15, 3, 28, 4, 91, 7, 80, 0, 90, 8, 33, 
    6, 48, 2, 11, 4,  7, 3, 40, 1, 23, 7, 10, 5,  5, 8, 60, 0, 77, 
    7, 16, 2, 56, 0, 64, 4, 87, 8, 47, 3, 55, 5, 42, 1, 73, 6, 34
  };
  const int q3966[] = {
    9, 9, // Number of jobs and machines
    0, 43, 1, 14, 8, 47, 7, 59, 3, 67, 4, 63, 6, 87, 5, 20, 2, 27, 
    3, 44, 4, 69, 5, 76, 1,  3, 7, 41, 2, 49, 6, 99, 0,  6, 8, 98, 
    8, 12, 3, 87, 1, 79, 5, 50, 7, 52, 4, 98, 0, 47, 2, 37, 6, 49, 
    2, 88, 0, 67, 1, 63, 4, 45, 8, 96, 7,  7, 5, 51, 6,  1, 3, 15, 
    6, 85, 8,  1, 2, 64, 4, 12, 3, 17, 0,  5, 5, 82, 1, 71, 7, 72, 
    4, 20, 2, 91, 8, 24, 3, 64, 1, 10, 5, 83, 6, 25, 7, 87, 0, 95, 
    2, 59, 7, 43, 1, 40, 0, 67, 8, 69, 3, 82, 6, 86, 4, 57, 5, 51, 
    5, 45, 8, 26, 7, 21, 1, 53, 2, 46, 4, 22, 6, 85, 3, 14, 0, 57, 
    8, 64, 3, 78, 4, 87, 2, 54, 6, 94, 7, 34, 1, 41, 0,  6, 5, 88
  };
  const int q3967[] = {
    9, 9, // Number of jobs and machines
    3, 74, 4, 63, 5, 31, 2, 57, 1, 98, 6, 73, 7, 12, 8, 94, 0, 15, 
    7, 42, 0, 35, 4, 53, 6, 31, 1, 40, 2, 19, 5, 13, 3, 93, 8, 67, 
    6,  5, 0, 80, 2, 43, 3, 35, 1, 78, 7, 74, 4, 34, 8, 91, 5,  5, 
    4, 41, 1, 74, 7, 52, 8,  6, 6, 33, 5, 43, 2, 73, 0, 76, 3, 61, 
    5, 65, 0, 88, 7, 63, 1, 85, 3, 68, 2,  6, 8, 59, 4, 32, 6, 80, 
    1, 27, 4, 26, 8, 47, 2,  5, 6, 91, 3,  5, 0, 65, 7, 20, 5, 20, 
    0, 69, 5, 83, 7, 83, 2, 64, 4, 56, 6, 97, 1, 52, 8, 93, 3, 76, 
    1,  1, 7, 17, 4, 34, 0, 69, 2, 63, 8, 53, 3, 67, 5, 87, 6, 23, 
    2, 48, 3, 74, 7, 62, 5, 92, 6, 71, 8, 11, 4,  8, 0, 10, 1, 72
  };
  const int q3968[] = {
    9, 9, // Number of jobs and machines
    4, 16, 6, 36, 3, 68, 8, 54, 0, 10, 7,  2, 1, 71, 2,  5, 5, 59, 
    0, 66, 5, 20, 6, 39, 2, 95, 4, 13, 8, 86, 1, 23, 3, 63, 7, 78, 
    2, 28, 8, 26, 3, 57, 6, 76, 0, 30, 4, 44, 1, 70, 7, 40, 5, 38, 
    2, 37, 3, 68, 6, 46, 8, 27, 7, 22, 4, 35, 5, 48, 0, 10, 1, 28, 
    6, 87, 7, 59, 3, 46, 1, 31, 5, 35, 4,  4, 8, 71, 0, 72, 2,  3, 
    8, 60, 1, 61, 3, 23, 0, 86, 7, 68, 6, 44, 2, 23, 5, 73, 4, 55, 
    8, 32, 1, 88, 6, 78, 3, 44, 0, 62, 4, 35, 5,  9, 7, 94, 2, 59, 
    2, 29, 5, 21, 1, 84, 8, 99, 0, 35, 3,  6, 6, 58, 7, 94, 4, 99, 
    3, 46, 1, 78, 2, 11, 7,  8, 6, 87, 0,  3, 5, 92, 8, 72, 4,  5
  };
  const int q3969[] = {
    9, 9, // Number of jobs and machines
    7, 91, 1,  8, 0, 29, 5, 28, 3, 30, 2, 50, 6, 91, 8, 49, 4, 45, 
    2, 65, 5, 31, 8, 19, 0, 31, 6, 21, 1, 78, 7, 54, 3, 76, 4,  3, 
    8, 41, 6, 29, 7, 40, 2, 79, 5, 98, 3, 18, 4, 14, 0, 75, 1, 44, 
    4, 10, 6, 51, 7, 55, 2, 10, 1,  2, 0, 50, 3, 10, 5, 55, 8,  1, 
    3, 79, 4, 45, 6, 25, 7, 74, 2, 80, 1, 10, 8, 80, 5, 12, 0, 92, 
    8, 92, 4, 40, 7, 33, 3, 81, 6, 76, 5, 16, 1, 18, 0, 37, 2,  4, 
    4, 60, 0, 14, 8, 30, 6, 10, 3, 31, 1, 11, 5,  2, 7, 67, 2,  8, 
    8, 65, 0, 76, 5, 41, 1, 52, 2, 68, 7, 18, 6, 44, 4, 79, 3, 27, 
    4, 28, 6, 59, 5, 70, 8, 23, 1, 61, 0, 38, 3,  3, 2, 76, 7, 65
  };
  const int q3970[] = {
    9, 9, // Number of jobs and machines
    0, 60, 2, 61, 6, 35, 8, 53, 1, 39, 5, 31, 7, 68, 3, 76, 4, 33, 
    7, 20, 6, 35, 5, 69, 4,  8, 2, 20, 3, 69, 0, 55, 8, 40, 1, 40, 
    5, 67, 3, 21, 2, 85, 1, 16, 0,  2, 8, 72, 6,  7, 7, 80, 4, 50, 
    6, 62, 4, 29, 1, 11, 7,  9, 0, 63, 5, 29, 3, 82, 2, 56, 8, 29, 
    3, 50, 6, 12, 7, 49, 5, 87, 2,  3, 4, 28, 0, 66, 8, 62, 1, 50, 
    4, 90, 5, 92, 0, 49, 6,  7, 7, 63, 3, 38, 2, 16, 8, 68, 1, 80, 
    2, 25, 0, 68, 1, 79, 7, 49, 3, 38, 8, 70, 6, 51, 4, 58, 5, 16, 
    2,  2, 1, 45, 0, 68, 8, 63, 6, 25, 3, 13, 4, 86, 5, 90, 7, 38, 
    8, 58, 2,  9, 0, 31, 3, 74, 5, 85, 1, 21, 4, 84, 6, 56, 7, 86
  };
  const int q3971[] = {
    9, 9, // Number of jobs and machines
    0,  8, 5,  8, 8, 50, 4,  3, 7, 97, 2, 55, 3, 33, 6, 88, 1, 34, 
    4, 38, 7, 58, 0, 64, 8, 48, 2,  3, 6,  7, 3, 14, 1, 64, 5, 96, 
    4,  2, 1, 37, 3, 69, 7, 13, 5, 89, 6, 76, 0, 46, 8, 26, 2,  3, 
    5, 17, 6, 31, 4, 25, 2, 79, 1, 50, 8, 37, 3, 86, 0, 71, 7, 62, 
    2, 38, 4, 29, 0, 15, 3, 85, 8, 47, 7, 85, 5, 68, 6, 30, 1, 85, 
    6, 51, 3, 11, 1, 94, 7, 23, 0, 64, 2, 71, 4, 76, 5, 83, 8, 24, 
    3,  5, 5,  6, 2, 47, 1, 79, 4, 71, 6, 34, 7, 54, 8, 69, 0, 64, 
    8, 91, 6, 15, 3, 95, 2, 58, 0, 33, 1, 24, 5, 54, 4, 91, 7, 60, 
    6,  8, 8, 44, 0,  6, 2, 40, 3, 68, 7, 38, 4, 63, 5, 69, 1,  7
  };
  const int q3972[] = {
    9, 9, // Number of jobs and machines
    6, 63, 0, 55, 3,  1, 8, 28, 1, 60, 2,  6, 7, 48, 5, 68, 4, 50, 
    7, 43, 3, 63, 2, 16, 4, 38, 6, 36, 1,  2, 0, 64, 8, 45, 5, 42, 
    7, 47, 2, 43, 6, 28, 1, 34, 4, 46, 0, 88, 8,  6, 5, 82, 3, 49, 
    7, 84, 8, 50, 3, 35, 6, 23, 4, 12, 0, 58, 2, 87, 1, 13, 5, 27, 
    0, 41, 6, 82, 8, 74, 1, 61, 5, 19, 4, 72, 3, 92, 2, 34, 7, 67, 
    3,  7, 4, 84, 1,  7, 5, 61, 0, 35, 8, 69, 6, 86, 7, 28, 2, 16, 
    6, 74, 1, 19, 8, 88, 5, 29, 2, 68, 3, 99, 0, 16, 4, 61, 7, 87, 
    8, 59, 5, 12, 2, 35, 7, 73, 3,  6, 4, 52, 6, 21, 0, 38, 1, 11, 
    8, 82, 0, 73, 5, 50, 6, 64, 2, 67, 1, 57, 7, 77, 4,  5, 3,  9
  };
  const int q3973[] = {
    9, 9, // Number of jobs and machines
    1, 18, 2, 19, 6, 34, 7, 79, 3, 67, 8, 86, 0, 24, 4, 26, 5, 85, 
    6, 53, 2, 11, 0, 82, 7, 65, 8, 49, 1, 14, 5, 57, 3, 34, 4, 24, 
    6, 22, 8,  4, 1,  8, 4, 31, 0, 84, 3, 93, 5, 21, 2, 47, 7, 21, 
    8, 94, 4,  2, 6, 94, 7, 60, 0, 84, 5, 70, 1, 30, 2, 52, 3, 91, 
    6, 70, 5, 53, 7,  1, 0, 93, 1, 55, 8, 40, 4, 64, 2, 56, 3, 80, 
    2, 31, 6, 76, 4, 44, 3, 59, 7,  8, 1, 56, 0,  6, 8, 62, 5,  5, 
    3, 46, 2, 12, 6, 57, 5,  1, 0, 80, 1, 68, 7,  4, 8, 92, 4, 74, 
    5, 85, 6, 36, 1,  3, 0, 65, 4, 36, 3, 69, 8, 27, 7, 35, 2, 18, 
    3, 77, 5, 13, 6, 55, 8, 37, 1, 73, 2, 78, 7, 73, 4, 88, 0, 38
  };
  const int q3974[] = {
    9, 9, // Number of jobs and machines
    7, 31, 4, 97, 0, 11, 5, 98, 6,  5, 1, 98, 8, 85, 2, 67, 3, 56, 
    0, 51, 6, 46, 4, 54, 1, 49, 2, 63, 7,  8, 5, 86, 8, 83, 3, 88, 
    3, 30, 1, 39, 5, 89, 4, 74, 7, 10, 0, 29, 6, 17, 8, 57, 2, 41, 
    8, 23, 2, 17, 3, 40, 6, 17, 1,  6, 4, 82, 5, 47, 7, 47, 0, 86, 
    6, 91, 1, 42, 0, 28, 5, 33, 2, 67, 4, 31, 7, 50, 3, 57, 8, 21, 
    5, 21, 1, 40, 6, 46, 2, 64, 4, 83, 0, 23, 7, 95, 8, 66, 3, 44, 
    5,  1, 2, 96, 4, 34, 3, 51, 7, 89, 0, 90, 6, 78, 8,  9, 1, 14, 
    5, 31, 2, 65, 1, 28, 4, 10, 7, 60, 0, 86, 6, 60, 3, 61, 8, 91, 
    6, 72, 2, 29, 3, 59, 4, 56, 0, 42, 5, 40, 7, 39, 1, 91, 8, 29
  };
  const int q3975[] = {
    9, 9, // Number of jobs and machines
    2, 11, 4, 71, 8, 90, 1, 54, 7, 32, 3, 37, 0, 15, 6, 74, 5, 72, 
    6, 56, 7, 92, 2, 87, 8, 24, 0, 10, 5, 95, 3, 40, 1, 82, 4, 88, 
    1, 74, 2, 76, 6, 10, 8, 82, 5, 97, 7, 89, 4, 20, 0, 39, 3, 96, 
    7, 28, 2, 52, 0, 41, 5, 98, 4, 46, 1, 90, 6, 96, 3, 37, 8, 15, 
    8, 62, 1, 46, 3, 42, 7, 74, 0, 64, 5, 18, 4,  6, 6, 92, 2, 56, 
    0, 36, 5, 43, 3, 34, 8, 55, 6, 61, 1, 36, 2, 78, 4, 40, 7, 25, 
    4,  1, 2, 86, 5, 40, 7, 47, 6, 75, 8, 69, 0, 13, 1, 95, 3, 16, 
    5, 37, 7, 77, 0, 46, 8, 22, 3, 90, 6, 98, 4, 51, 2, 69, 1, 52, 
    7, 82, 6, 99, 2, 30, 0, 31, 8, 22, 3, 66, 4, 65, 5, 24, 1, 85
  };
  const int q3976[] = {
    9, 9, // Number of jobs and machines
    1, 61, 3, 37, 4, 37, 8, 82, 7,  5, 2, 65, 6, 60, 5, 50, 0, 35, 
    0,  1, 5, 81, 3, 96, 8, 33, 6, 97, 7, 36, 1, 36, 2, 65, 4, 89, 
    7, 48, 3, 78, 2, 68, 5, 97, 1, 45, 0, 66, 4, 33, 8, 63, 6, 86, 
    2, 58, 0, 32, 8, 94, 1, 68, 7, 87, 6, 47, 4, 80, 3,  1, 5, 13, 
    2, 44, 4, 56, 8, 38, 0, 50, 7, 54, 6, 40, 3, 16, 1, 25, 5, 65, 
    0, 42, 6,  3, 1, 77, 5, 23, 2,  7, 7, 15, 8,  7, 4, 55, 3, 57, 
    0, 65, 5, 88, 4, 17, 3, 96, 7, 40, 8, 65, 2, 83, 1, 38, 6, 19, 
    2, 45, 8, 65, 1, 29, 5, 94, 6, 82, 7, 23, 3, 92, 4, 45, 0, 27, 
    8, 72, 6, 12, 1, 65, 4, 29, 7, 19, 2, 33, 5, 39, 3, 47, 0, 91
  };
  const int q3977[] = {
    9, 9, // Number of jobs and machines
    4, 53, 0, 38, 6, 34, 2, 39, 8, 62, 3, 31, 5, 82, 7, 76, 1, 18, 
    7, 76, 8, 82, 3, 85, 4, 45, 5, 31, 2, 75, 0, 79, 1, 94, 6, 97, 
    6, 91, 2, 57, 4,  3, 8, 30, 1, 42, 0, 32, 3, 47, 5, 20, 7, 53, 
    7, 80, 3, 61, 5, 45, 8, 30, 6, 21, 0, 72, 1, 16, 2, 59, 4, 39, 
    1, 22, 7, 98, 4, 19, 6, 43, 3, 31, 0, 75, 8, 40, 5, 28, 2, 24, 
    3, 25, 7, 49, 2, 35, 4, 55, 1, 66, 0, 72, 8, 45, 6, 83, 5, 12, 
    8, 42, 7, 97, 4, 49, 1, 65, 3, 27, 5, 95, 6, 39, 2, 31, 0, 65, 
    0, 82, 3,  3, 5, 76, 8, 12, 7, 58, 2, 56, 4, 73, 1, 83, 6,  7, 
    8, 83, 6, 34, 1, 88, 3, 45, 5, 26, 4, 81, 7, 19, 2, 18, 0, 75
  };
  const int q3978[] = {
    9, 9, // Number of jobs and machines
    7, 89, 1, 73, 6,  1, 0, 46, 3, 41, 2, 35, 5, 58, 4,  5, 8, 41, 
    5,  6, 7, 36, 4, 86, 0, 31, 2,  9, 3, 21, 1, 26, 6, 99, 8,  6, 
    3, 40, 0, 15, 7,  3, 5, 59, 2, 72, 8, 45, 1, 86, 6, 80, 4, 25, 
    1, 16, 5,  3, 6, 95, 3, 53, 2, 84, 0, 21, 8, 92, 4, 53, 7, 71, 
    7, 76, 8, 64, 3, 76, 5, 71, 2, 60, 6, 93, 0, 92, 1, 59, 4, 74, 
    0,  3, 8, 58, 4, 43, 1, 24, 5,  2, 7,  9, 3, 65, 2, 33, 6, 94, 
    3, 69, 2, 20, 8, 98, 5, 83, 4, 54, 1, 55, 0, 46, 6, 97, 7, 62, 
    1, 13, 0, 91, 5, 64, 2, 53, 7, 76, 4, 28, 3, 26, 8, 32, 6, 81, 
    6, 93, 8, 18, 4, 94, 2,  4, 1, 98, 7, 56, 0, 76, 5, 55, 3, 57
  };
  const int q3979[] = {
    9, 9, // Number of jobs and machines
    3, 49, 2, 24, 0, 15, 1, 23, 8, 28, 4, 11, 6, 31, 7, 61, 5,  1, 
    0, 72, 8, 80, 2, 98, 1, 11, 6, 34, 5, 19, 7, 38, 4,  9, 3, 78, 
    5,  5, 1, 27, 4, 34, 2, 11, 0, 25, 6, 81, 8, 71, 7, 25, 3, 12, 
    2, 26, 5, 69, 0, 20, 8, 22, 4, 34, 7, 65, 3, 85, 1, 42, 6, 34, 
    2, 27, 4, 25, 8, 50, 1, 84, 7, 84, 3, 45, 5, 33, 0, 25, 6, 16, 
    5, 56, 2, 63, 6, 51, 3, 77, 0, 49, 8, 35, 7, 29, 1, 68, 4, 59, 
    2,  9, 1, 18, 6, 78, 7, 61, 5, 21, 0, 47, 8, 74, 3, 72, 4, 98, 
    2, 48, 7, 47, 3, 29, 0, 41, 6, 22, 5, 17, 1, 41, 4, 43, 8, 16, 
    8, 16, 1, 58, 3, 54, 6, 40, 2, 54, 4, 74, 0, 74, 7,  3, 5, 55
  };
  const int q3980[] = {
    9, 9, // Number of jobs and machines
    2, 75, 1, 52, 4,  8, 5, 65, 8, 82, 7, 48, 3, 50, 6, 44, 0, 21, 
    3,  6, 4, 98, 8, 62, 5, 17, 7, 84, 1, 46, 2, 56, 6, 15, 0, 11, 
    4, 48, 8, 24, 1, 94, 6, 12, 5, 85, 2, 95, 7, 45, 3, 45, 0, 70, 
    1, 19, 5, 20, 8, 21, 3, 21, 4, 13, 6, 47, 7, 35, 2, 16, 0, 68, 
    1, 29, 0, 90, 5, 32, 4, 99, 7,  9, 3, 22, 6, 56, 2,  4, 8,  4, 
    8, 86, 3, 85, 4, 96, 5, 73, 7,  2, 1, 57, 2, 24, 6, 39, 0, 26, 
    8,  7, 6, 10, 3, 58, 0, 65, 2, 84, 7, 58, 1, 16, 4, 13, 5, 81, 
    1, 37, 8, 14, 5, 57, 2, 66, 4, 94, 3, 85, 6, 91, 0, 62, 7, 55, 
    6, 17, 0, 74, 5,  5, 7, 67, 8, 68, 3,  9, 4, 97, 1, 22, 2, 40
  };
  const int q3981[] = {
    9, 9, // Number of jobs and machines
    8, 46, 7, 98, 3, 69, 1, 79, 5, 74, 2, 41, 0, 76, 4, 81, 6,  6, 
    2, 29, 6, 83, 1, 72, 4, 86, 3, 62, 7, 95, 0, 27, 8,  9, 5, 88, 
    1, 99, 0, 61, 7, 59, 3, 40, 6, 36, 8, 97, 5, 31, 2, 70, 4, 14, 
    2, 63, 3, 69, 4, 12, 0, 55, 8, 90, 1, 21, 5, 61, 6, 94, 7, 68, 
    8,  4, 6, 59, 5, 50, 2,  6, 3, 92, 4, 66, 0, 42, 1, 48, 7, 10, 
    3, 59, 1, 69, 7,  5, 2, 12, 6, 66, 0, 17, 8, 50, 4, 60, 5, 19, 
    2, 11, 5, 83, 6, 99, 1, 34, 3, 15, 8, 67, 0, 22, 7, 21, 4, 61, 
    1,  5, 2,  3, 4,  3, 0, 95, 3,  9, 8, 87, 6, 83, 7, 96, 5,  7, 
    5, 35, 0, 67, 7, 57, 2, 85, 1, 41, 8, 98, 6, 34, 4, 32, 3, 44
  };
  const int q3982[] = {
    9, 9, // Number of jobs and machines
    8,  2, 3, 60, 7, 96, 0, 77, 1, 66, 6, 97, 5, 39, 2, 90, 4, 43, 
    4, 24, 3, 71, 5,  2, 1, 42, 8,  4, 7, 95, 0,  3, 6, 21, 2, 22, 
    1, 12, 4, 47, 0, 48, 2, 66, 8, 76, 3, 52, 7, 61, 5, 61, 6, 11, 
    0, 54, 8, 96, 6, 69, 3, 23, 5, 54, 4, 39, 7, 94, 1, 45, 2,  5, 
    3, 76, 5, 55, 0, 89, 1, 25, 2, 78, 8, 38, 6, 54, 7, 60, 4, 26, 
    0,  7, 1, 52, 7, 78, 3, 53, 6, 24, 5, 74, 2, 15, 4, 89, 8, 63, 
    6, 23, 7, 24, 4, 98, 8, 79, 3, 91, 0, 41, 1, 16, 2, 12, 5, 14, 
    6, 18, 5, 76, 7, 25, 4, 58, 8, 60, 1, 66, 2, 81, 0, 94, 3, 98, 
    8, 89, 5, 72, 0, 64, 7,  6, 3, 80, 1, 55, 2, 49, 4, 69, 6, 52
  };
  const int q3983[] = {
    9, 9, // Number of jobs and machines
    8, 23, 4, 93, 6, 45, 2, 26, 0, 23, 3, 56, 1, 36, 5, 51, 7, 17, 
    4, 93, 8, 30, 1, 39, 5,  6, 7,  9, 3, 33, 0, 88, 2, 75, 6, 92, 
    4, 70, 7, 43, 1, 44, 3,  7, 5, 95, 0, 28, 2, 14, 8, 95, 6, 10, 
    2, 93, 3,  1, 1, 43, 7, 40, 8, 83, 6, 43, 0, 46, 5, 85, 4, 78, 
    8, 66, 4, 61, 6, 36, 0, 96, 5, 33, 7, 88, 3, 79, 1, 34, 2, 22, 
    2, 74, 1, 92, 6, 31, 5,  1, 0,  1, 8, 72, 7,  9, 3, 85, 4, 10, 
    0, 49, 2, 99, 3, 86, 8,  1, 1, 49, 4, 47, 6, 44, 5, 24, 7, 21, 
    4, 50, 8, 43, 7, 56, 3, 34, 1, 18, 0, 67, 5, 30, 2, 43, 6, 44, 
    7, 74, 1, 63, 3, 47, 6, 40, 5,  6, 0, 90, 8, 44, 4,  5, 2, 77
  };
  const int q3984[] = {
    9, 9, // Number of jobs and machines
    6, 89, 4, 41, 7, 94, 5, 94, 2,  3, 0, 47, 8, 55, 3, 94, 1, 66, 
    8, 93, 7, 24, 0, 66, 6, 27, 2, 43, 3, 45, 1, 64, 4, 59, 5, 34, 
    1, 23, 5, 33, 2, 67, 7,  5, 6, 98, 8, 13, 0,  3, 3, 89, 4, 97, 
    2, 17, 0, 41, 5, 38, 3, 27, 6, 26, 4, 86, 1, 20, 8, 62, 7, 13, 
    8,  8, 1, 42, 3, 13, 0, 11, 4, 36, 5, 61, 7,  7, 2, 51, 6, 78, 
    1, 28, 4, 46, 7, 37, 2, 13, 5, 27, 8, 94, 0, 77, 3, 54, 6, 76, 
    0, 16, 8, 65, 4,  2, 6, 71, 5, 82, 2, 13, 1, 19, 3, 99, 7, 97, 
    1, 95, 6, 69, 4, 67, 7, 55, 2, 70, 3, 10, 0, 15, 8, 40, 5, 10, 
    0,  5, 3, 71, 6, 32, 8, 76, 4, 57, 1, 83, 5, 86, 7, 42, 2, 62
  };
  const int q3985[] = {
    9, 9, // Number of jobs and machines
    0,  1, 1, 89, 8, 73, 6, 68, 5, 14, 4, 68, 2, 80, 7, 77, 3,  6, 
    3, 45, 8, 81, 7, 95, 0, 47, 5, 81, 2, 30, 1, 52, 6, 54, 4, 38, 
    6, 31, 0, 43, 1, 58, 3,  8, 2, 26, 8, 76, 5, 36, 4, 33, 7, 49, 
    5, 74, 3, 84, 4, 84, 7, 62, 1,  9, 2, 84, 8, 74, 0,  7, 6, 77, 
    3,  8, 6, 79, 8, 28, 0, 71, 5, 86, 2,  2, 4, 26, 7, 99, 1, 45, 
    8, 94, 4, 99, 1, 49, 5, 53, 0, 69, 7, 90, 2, 76, 3, 94, 6, 56, 
    2, 42, 6, 57, 7, 90, 5, 38, 1, 50, 3, 23, 0, 67, 4, 74, 8, 49, 
    7, 75, 4,  7, 6, 35, 5, 49, 1, 74, 8, 51, 0, 40, 2, 48, 3, 94, 
    5, 52, 8, 73, 3, 35, 4, 55, 1, 32, 7, 74, 2, 75, 0, 53, 6, 87
  };
  const int q3986[] = {
    9, 9, // Number of jobs and machines
    8,  2, 3, 71, 7, 61, 4, 39, 2, 54, 5,  4, 6, 57, 0, 21, 1, 21, 
    0, 19, 3, 10, 7, 24, 4, 97, 2, 55, 5, 94, 6, 24, 8, 29, 1, 37, 
    5, 39, 0, 37, 1, 22, 8, 41, 6, 72, 4, 62, 3,  9, 7, 93, 2, 82, 
    1, 70, 5, 42, 8,  2, 4, 55, 2, 13, 6, 94, 0,  6, 7, 23, 3, 54, 
    1, 92, 2, 79, 8, 39, 6, 77, 5, 45, 3,  9, 4, 67, 7, 70, 0,  1, 
    4, 99, 8, 64, 5, 90, 7, 22, 0, 33, 1, 50, 2, 33, 6, 62, 3, 91, 
    5,  7, 2, 44, 0, 13, 7,  8, 4, 83, 3, 49, 6, 20, 1, 95, 8, 24, 
    0, 25, 6, 37, 8, 91, 1, 26, 3, 81, 4, 91, 5, 31, 7, 52, 2,  8, 
    3, 38, 2, 79, 4, 53, 7, 87, 1, 24, 5, 52, 0, 30, 6, 12, 8, 25
  };
  const int q3987[] = {
    9, 9, // Number of jobs and machines
    0, 51, 6, 54, 7, 66, 4, 66, 1, 67, 3, 69, 8, 55, 5, 21, 2, 68, 
    0, 85, 8, 21, 3, 89, 1, 42, 5, 25, 4, 13, 2,  2, 6, 69, 7, 11, 
    7, 29, 5, 80, 1, 73, 0, 29, 6,  5, 8, 76, 3,  3, 4, 12, 2, 21, 
    0, 95, 7,  4, 6, 33, 4, 12, 2, 98, 3, 70, 8, 55, 1, 97, 5, 51, 
    5,  3, 8, 49, 2, 33, 0, 36, 6, 38, 4, 65, 3, 99, 7, 79, 1, 42, 
    0, 90, 7, 76, 1, 23, 3, 90, 4, 83, 5, 67, 2, 72, 8, 50, 6, 42, 
    2, 67, 4, 60, 1, 13, 7, 18, 6, 19, 5, 20, 0, 18, 3, 63, 8, 17, 
    4, 89, 3, 53, 5, 41, 7, 84, 8, 39, 1,  6, 2, 92, 0, 54, 6, 80, 
    4, 79, 6, 37, 0, 66, 1, 64, 3, 44, 7, 83, 5, 91, 8, 35, 2, 75
  };
  const int q3988[] = {
    9, 9, // Number of jobs and machines
    8, 92, 7, 90, 3, 26, 4, 75, 5,  3, 0,  7, 1, 19, 2, 24, 6, 12, 
    5, 11, 1, 38, 3, 17, 7, 76, 2,  8, 4, 90, 0, 45, 6, 76, 8, 34, 
    7, 16, 4, 51, 5, 72, 1,  4, 6, 74, 3, 11, 2, 59, 8, 15, 0, 69, 
    5, 71, 2, 36, 7, 20, 4, 63, 1, 65, 6, 51, 3, 23, 8, 41, 0, 67, 
    5, 70, 2, 64, 8, 47, 7, 23, 6, 30, 0,  3, 4, 71, 3, 40, 1, 49, 
    3, 98, 1, 90, 2, 28, 7, 37, 0, 59, 8, 18, 6, 95, 5,  8, 4, 10, 
    8, 73, 7,  2, 5, 19, 0, 82, 3, 87, 2, 65, 4, 13, 1, 67, 6, 80, 
    4, 73, 7,  1, 0, 25, 3, 78, 1, 74, 6, 17, 2, 79, 5, 97, 8, 86, 
    0, 38, 6, 50, 5, 21, 7, 23, 2, 85, 8, 57, 3, 79, 4,  2, 1, 90
  };
  const int q3989[] = {
    9, 9, // Number of jobs and machines
    0, 40, 7, 16, 2, 93, 3, 66, 1, 73, 8, 91, 6, 28, 5, 92, 4, 63, 
    3, 65, 1, 28, 6, 27, 2, 31, 4, 66, 0, 74, 5, 38, 7, 43, 8, 69, 
    2, 23, 1, 61, 5, 29, 7, 76, 8, 12, 3,  9, 6, 33, 0, 34, 4, 17, 
    4, 63, 0, 55, 2, 68, 3, 71, 7, 21, 5, 67, 8, 98, 1, 98, 6,  3, 
    7, 50, 2, 47, 1, 23, 3, 26, 6, 58, 4, 76, 8, 10, 5, 97, 0, 63, 
    7, 38, 2, 62, 6, 37, 4, 87, 1, 99, 8, 89, 0, 78, 3, 72, 5, 36, 
    5, 93, 1, 97, 8, 28, 7, 78, 6, 20, 2, 84, 3, 73, 4, 74, 0, 13, 
    3, 22, 8, 85, 0, 57, 7, 90, 2, 44, 4, 37, 5, 53, 6, 34, 1, 52, 
    5, 54, 3, 33, 0, 38, 1, 40, 7,  2, 8, 73, 4, 96, 2, 67, 6, 50
  };
  const int q3990[] = {
    9, 9, // Number of jobs and machines
    0, 11, 2, 95, 6, 96, 8, 20, 7, 68, 1, 60, 3, 54, 4, 83, 5,  9, 
    0, 70, 1, 98, 2, 53, 6, 16, 8, 86, 4, 26, 3, 25, 5, 19, 7, 91, 
    3, 86, 1, 52, 2, 89, 0, 46, 4, 79, 7, 43, 8, 80, 5, 29, 6, 29, 
    2, 80, 3, 25, 6,  3, 7, 47, 0, 15, 8, 13, 5, 72, 1, 41, 4, 34, 
    2, 56, 0, 17, 8, 55, 3, 31, 7, 71, 6, 12, 5, 35, 4, 90, 1, 69, 
    5, 38, 4, 27, 8,  7, 2, 90, 3, 51, 1, 54, 7, 87, 0, 84, 6, 11, 
    5, 43, 1,  7, 4, 58, 7,  4, 3, 98, 2, 87, 6, 12, 8, 94, 0, 88, 
    0, 79, 5, 21, 3, 21, 4, 33, 7,  2, 2, 57, 8, 47, 6, 92, 1, 72, 
    7, 37, 4,  4, 3, 91, 5, 92, 0, 37, 2, 69, 8, 46, 6,  9, 1, 53
  };
  const int q3991[] = {
    9, 9, // Number of jobs and machines
    2, 83, 7, 71, 8, 87, 3, 78, 1, 97, 4, 29, 5, 55, 0, 95, 6, 15, 
    4, 45, 5, 59, 8, 69, 2, 31, 7, 91, 6, 65, 0, 51, 1, 27, 3, 74, 
    5, 33, 6, 44, 4, 28, 0,  5, 3,  2, 8, 56, 7, 79, 1, 53, 2, 16, 
    2, 46, 3, 67, 5, 12, 7, 55, 0, 87, 1,  2, 8, 28, 4, 57, 6, 24, 
    1, 57, 3, 41, 8, 42, 7, 32, 5, 29, 4, 79, 0, 41, 6, 55, 2,  6, 
    1,  3, 2,  9, 0, 49, 8, 21, 3, 17, 7, 78, 4, 45, 6, 51, 5,  4, 
    0, 50, 5, 68, 3,  3, 2, 62, 7, 20, 4, 78, 1, 42, 8, 36, 6, 93, 
    2, 23, 4, 63, 5, 74, 8,  1, 6,  2, 7, 58, 3, 32, 1, 33, 0, 14, 
    5, 97, 7, 54, 4, 26, 8, 39, 6, 53, 3, 47, 1, 28, 2, 51, 0, 82
  };
  const int q3992[] = {
    9, 9, // Number of jobs and machines
    2, 87, 5, 38, 0, 53, 7, 82, 6, 30, 8, 90, 1, 57, 4, 57, 3, 62, 
    2,  9, 3, 90, 6, 74, 7, 40, 8, 14, 0, 78, 1,  9, 5, 84, 4, 71, 
    1, 60, 7, 51, 3, 73, 2, 93, 5, 95, 6, 96, 8, 82, 0, 25, 4, 12, 
    1, 53, 0, 85, 5, 83, 4, 81, 3, 59, 6, 94, 7, 40, 8, 29, 2, 43, 
    4, 30, 1, 78, 6, 50, 8, 39, 5, 59, 7, 74, 0, 91, 2, 84, 3, 88, 
    0, 96, 4, 81, 7, 55, 5, 21, 6, 26, 8, 82, 2, 95, 1, 76, 3, 86, 
    2, 83, 4, 42, 5, 93, 7, 75, 1, 44, 6,  1, 3, 32, 8, 36, 0, 80, 
    7,  2, 8, 98, 6, 70, 0, 70, 4, 73, 5, 59, 3, 55, 2, 67, 1, 26, 
    1,  6, 8, 17, 4,  9, 6, 17, 3, 94, 5, 65, 2, 82, 7, 70, 0, 86
  };
  const int q3993[] = {
    9, 9, // Number of jobs and machines
    6, 36, 0, 48, 3, 94, 8, 19, 7, 27, 1, 48, 5, 83, 4, 69, 2, 59, 
    4, 11, 8, 48, 6, 83, 5, 68, 1, 75, 3, 68, 7, 41, 0,  4, 2, 37, 
    5, 99, 6, 99, 0, 81, 3, 59, 7, 73, 4, 14, 8, 85, 1, 82, 2, 41, 
    7, 83, 8, 52, 5,  9, 0, 55, 2, 98, 4, 68, 1, 43, 3, 79, 6, 50, 
    1, 57, 8, 24, 4, 92, 0, 44, 3, 80, 2, 99, 6, 75, 5,  7, 7, 64, 
    6, 76, 4, 61, 8, 63, 1, 86, 3, 19, 2, 27, 0, 51, 7, 56, 5, 58, 
    8,  9, 1, 74, 6, 42, 2, 99, 4, 43, 0, 14, 5, 75, 3, 84, 7, 80, 
    7, 88, 1, 90, 4, 28, 8, 62, 2, 50, 3, 11, 6, 16, 0, 50, 5, 88, 
    1, 28, 4, 86, 6, 42, 5, 98, 8, 33, 2, 60, 0, 70, 3, 85, 7, 34
  };
  const int q3994[] = {
    9, 9, // Number of jobs and machines
    6,  5, 3, 90, 7, 52, 0, 55, 2, 64, 4, 80, 5, 16, 1, 31, 8,  9, 
    8, 62, 3, 49, 2, 11, 7, 72, 4, 24, 1,  6, 0, 47, 5, 72, 6, 94, 
    0, 77, 6, 25, 3, 92, 7, 69, 4, 75, 2, 14, 1, 99, 8, 17, 5, 68, 
    7, 73, 3, 49, 6, 20, 8, 19, 2, 74, 5, 90, 1, 91, 0, 87, 4, 18, 
    6, 58, 0, 94, 1, 99, 8,  5, 5, 27, 3, 38, 2, 98, 4, 60, 7, 82, 
    2, 31, 4, 51, 7, 99, 6, 93, 3, 57, 5, 30, 1, 68, 8, 66, 0, 80, 
    7,  9, 8,  1, 3, 87, 6, 41, 4, 18, 1, 56, 5, 93, 0, 20, 2, 74, 
    7, 58, 0, 49, 5, 98, 4, 61, 6, 67, 2,  8, 1, 63, 3, 12, 8, 76, 
    2, 39, 3, 77, 8, 20, 7,  2, 6, 57, 4, 94, 1, 52, 5,  5, 0,  3
  };
  const int q3995[] = {
    9, 9, // Number of jobs and machines
    0, 77, 8, 49, 1, 49, 7, 83, 5, 11, 6, 27, 2, 24, 3, 50, 4, 79, 
    1,  2, 3, 51, 7, 83, 4, 48, 6, 59, 0, 64, 5, 27, 8, 54, 2, 57, 
    4, 42, 3, 73, 5, 40, 0, 97, 8, 39, 1, 19, 2,  7, 6, 24, 7, 10, 
    8, 80, 6, 84, 7, 33, 0, 19, 4, 72, 1, 25, 2, 43, 3, 99, 5,  8, 
    2, 20, 1, 82, 7, 74, 6, 39, 5, 17, 8, 68, 3, 79, 4, 81, 0, 81, 
    2, 11, 6, 35, 7, 27, 4, 55, 1, 49, 3, 20, 0, 39, 8, 29, 5, 43, 
    0, 74, 8, 91, 4, 65, 7, 47, 5, 45, 6, 42, 3, 14, 2, 32, 1, 68, 
    0, 63, 7, 23, 5, 60, 6,  6, 2, 80, 4, 31, 1, 32, 3,  1, 8,  3, 
    1, 79, 6, 11, 2,  3, 7, 48, 8,  2, 5,  7, 3, 48, 4, 72, 0, 50
  };
  const int q3996[] = {
    9, 9, // Number of jobs and machines
    7, 31, 1, 78, 0,  7, 6, 49, 5, 23, 2, 28, 4, 93, 3, 77, 8, 23, 
    1, 65, 4, 85, 5, 73, 3, 38, 2, 94, 7, 40, 0, 14, 6, 39, 8, 18, 
    7,  2, 3, 65, 0, 78, 5,  8, 1, 72, 2, 11, 8, 27, 4, 67, 6, 63, 
    4, 85, 0, 43, 6, 20, 1, 25, 3, 43, 2, 44, 8, 26, 5, 50, 7, 43, 
    7, 80, 0,  2, 1, 23, 5, 30, 6, 54, 3, 82, 8, 66, 2, 52, 4, 19, 
    0, 86, 3, 82, 1, 29, 2, 25, 7, 84, 6, 44, 8, 91, 4, 32, 5, 80, 
    3, 55, 0, 54, 6,  5, 2,  9, 4, 77, 1, 26, 7, 82, 8, 41, 5, 33, 
    2, 93, 1, 49, 7, 69, 8, 95, 3, 57, 6, 83, 5,  5, 4, 18, 0, 79, 
    8, 72, 4, 76, 5, 43, 6, 46, 3, 85, 0, 79, 1, 11, 7, 75, 2, 71
  };
  const int q3997[] = {
    9, 9, // Number of jobs and machines
    4, 19, 1, 45, 3, 40, 0, 47, 6, 53, 7, 28, 8, 35, 5, 61, 2, 70, 
    1, 16, 2, 11, 6, 77, 8, 74, 7, 62, 5, 43, 0, 49, 4, 48, 3, 21, 
    2, 44, 3, 30, 0, 62, 5, 33, 7, 62, 6, 98, 4,  5, 1, 12, 8, 53, 
    5, 70, 2, 68, 4, 76, 8, 85, 7, 87, 3, 81, 1, 71, 0, 31, 6, 69, 
    3, 19, 6, 91, 5, 53, 0, 23, 2,  2, 1, 27, 4, 85, 7, 54, 8, 15, 
    4, 97, 3, 39, 6, 47, 5, 71, 8, 97, 0, 87, 1, 32, 2, 70, 7, 77, 
    1, 24, 0,  2, 2, 84, 3, 71, 8, 60, 5, 76, 7, 61, 6, 75, 4,  3, 
    1, 45, 2,  2, 4, 92, 8, 51, 7, 64, 3, 30, 5,  9, 6, 86, 0, 79, 
    2, 16, 7, 60, 3, 40, 8, 33, 6, 53, 0, 87, 4,  6, 1, 77, 5, 37
  };
  const int q3998[] = {
    9, 9, // Number of jobs and machines
    8, 57, 2, 11, 7, 25, 6, 18, 1,  1, 5, 10, 0, 98, 4, 62, 3, 95, 
    3, 67, 5, 27, 7, 44, 2, 42, 1,  7, 8, 37, 6, 57, 4, 12, 0,  7, 
    8, 52, 1, 84, 0,  5, 4, 86, 3, 38, 2, 52, 5, 28, 6, 18, 7, 16, 
    8,  1, 3, 78, 7, 80, 1, 77, 6, 76, 5, 66, 2, 71, 4,  9, 0, 52, 
    7, 23, 3, 53, 5, 99, 2, 42, 6, 31, 1, 98, 8, 15, 0, 46, 4, 76, 
    4, 53, 2, 16, 5, 18, 8, 17, 6, 52, 0, 88, 1, 74, 7, 60, 3, 93, 
    3, 52, 1,  3, 8, 84, 0, 50, 5, 60, 7, 94, 6, 57, 4, 44, 2, 81, 
    8, 46, 1, 98, 3, 99, 0, 20, 6, 90, 7,  2, 4, 91, 2, 14, 5, 74, 
    2, 14, 5, 50, 8, 33, 0, 56, 3, 85, 6, 99, 1, 87, 4, 22, 7,  8
  };
  const int q3999[] = {
    9, 9, // Number of jobs and machines
    0, 54, 3, 49, 1, 89, 7, 20, 8, 22, 5, 48, 6, 27, 2, 99, 4, 46, 
    1, 87, 0, 70, 5, 85, 6, 71, 2, 64, 7, 89, 4, 80, 8, 41, 3, 74, 
    3, 53, 6, 25, 0, 18, 4, 92, 7, 51, 5, 54, 1, 46, 2, 68, 8, 53, 
    1, 39, 6, 51, 4, 57, 7, 15, 8, 49, 3, 34, 0, 28, 2, 44, 5, 63, 
    5, 29, 6, 36, 2, 32, 8, 63, 0, 38, 3,  6, 4, 85, 7, 90, 1, 36, 
    6, 81, 4, 54, 1, 61, 0, 42, 2, 92, 8, 54, 7, 64, 5, 16, 3, 29, 
    8, 50, 6, 48, 5, 18, 0, 42, 3, 64, 4, 23, 1, 27, 7, 26, 2, 79, 
    5, 46, 8, 57, 2, 60, 4, 23, 1, 16, 6, 58, 3, 40, 7, 52, 0,  2, 
    1, 92, 6, 36, 0, 99, 8, 30, 4, 43, 7,  5, 2, 45, 3, 51, 5,  2
  };
  const int q4000[] = {
    9, 9, // Number of jobs and machines
    8, 10, 6, 34, 7, 14, 2, 67, 3, 81, 4, 47, 0, 38, 1, 83, 5, 96, 
    3,  1, 6, 10, 8, 71, 1, 12, 0, 57, 2, 40, 7, 63, 4, 43, 5, 13, 
    5, 33, 4, 49, 8, 83, 6, 75, 1, 51, 0, 84, 7, 51, 2, 56, 3, 35, 
    0, 73, 8, 34, 6, 32, 7, 36, 3, 43, 5, 35, 2, 70, 4, 49, 1, 66, 
    8, 98, 4, 86, 3, 44, 7, 58, 1, 45, 2, 34, 6, 15, 5, 31, 0, 63, 
    3, 89, 6, 70, 5, 38, 4, 88, 2, 10, 1, 90, 0, 77, 7, 48, 8, 68, 
    3, 33, 6, 50, 2, 65, 0, 38, 4, 73, 5, 89, 7, 31, 1, 87, 8, 98, 
    0, 63, 1, 27, 2, 16, 5, 85, 6, 29, 4, 13, 7, 28, 8, 58, 3, 29, 
    5, 97, 4, 63, 3, 16, 6, 90, 1, 29, 8, 50, 0,  9, 7, 67, 2, 58
  };
  const int q4001[] = {
    9, 9, // Number of jobs and machines
    4, 10, 0, 14, 2, 16, 7, 45, 3, 44, 6, 76, 1, 94, 8, 99, 5, 41, 
    6, 63, 2,  3, 0, 12, 1,  8, 4, 52, 5, 38, 8, 66, 3, 94, 7, 69, 
    4, 18, 1, 18, 7, 24, 5, 18, 8, 19, 0, 19, 6, 64, 2, 20, 3, 28, 
    0, 62, 8, 14, 1, 53, 2, 35, 6, 75, 5, 47, 3, 79, 7, 50, 4, 54, 
    4, 12, 2, 90, 8,  7, 1, 27, 7, 60, 5, 61, 0, 58, 6, 89, 3, 57, 
    2, 35, 1, 39, 6, 85, 7, 25, 5, 30, 0, 51, 4, 91, 8, 93, 3, 38, 
    1, 99, 6, 74, 2, 84, 0, 30, 8, 75, 3, 35, 5, 72, 7, 98, 4, 58, 
    0, 89, 1, 99, 8, 78, 7, 35, 2, 78, 3, 90, 6,  4, 4, 48, 5,  5, 
    4, 41, 2, 47, 6, 90, 1, 55, 7, 15, 5, 77, 3, 80, 0,  8, 8, 47
  };
  const int q4002[] = {
    9, 9, // Number of jobs and machines
    1, 67, 4, 40, 0, 13, 5, 24, 7, 24, 2, 25, 6, 75, 3, 85, 8, 31, 
    8, 91, 1, 58, 6, 74, 0, 99, 5, 43, 7, 98, 3, 76, 2, 91, 4, 23, 
    2, 17, 7, 43, 5,  5, 1, 53, 4, 91, 3, 21, 6, 58, 8, 11, 0, 85, 
    5, 28, 1,  4, 2, 25, 0, 85, 6, 50, 3, 23, 8, 17, 7, 77, 4, 78, 
    1,  7, 6, 81, 0,  9, 2, 57, 7, 48, 4, 44, 3, 75, 8, 31, 5,  4, 
    2, 75, 8, 23, 3, 79, 6, 31, 5, 77, 1,  1, 4, 85, 7, 85, 0, 68, 
    3, 26, 4, 75, 7, 21, 8, 57, 0, 58, 1, 86, 5, 74, 6, 42, 2, 32, 
    8, 87, 4, 74, 3, 16, 6, 94, 7, 45, 5, 40, 1, 95, 2, 28, 0, 47, 
    7, 62, 1, 28, 5,  4, 2, 89, 8, 60, 4, 11, 3, 44, 0, 63, 6, 61
  };
  const int q4003[] = {
    9, 9, // Number of jobs and machines
    7, 60, 3, 51, 1, 99, 5, 15, 4, 73, 8, 74, 2, 53, 0, 98, 6, 43, 
    3, 26, 1, 64, 7, 52, 4, 60, 0, 49, 2,  6, 8, 60, 6, 19, 5, 16, 
    0,  7, 8, 33, 2, 92, 7, 93, 3, 46, 5, 97, 1, 64, 6, 38, 4, 24, 
    3, 25, 4, 36, 5, 22, 6, 86, 8, 19, 7, 14, 2, 29, 0, 70, 1, 81, 
    1, 17, 4, 44, 8, 73, 5, 70, 7, 80, 2, 80, 0, 16, 3, 59, 6, 67, 
    3, 60, 0, 97, 1, 11, 5, 78, 2, 35, 7, 47, 6, 69, 8, 19, 4, 28, 
    8, 88, 2, 46, 4, 56, 7, 42, 3, 71, 0,  9, 6, 51, 1, 21, 5, 89, 
    6, 24, 0, 29, 1, 22, 4, 15, 5, 68, 3, 45, 2, 97, 8, 14, 7, 16, 
    2, 81, 0, 57, 3, 43, 1, 61, 4, 59, 7, 35, 5, 62, 8, 97, 6, 90
  };
  const int q4004[] = {
    9, 9, // Number of jobs and machines
    8, 89, 7, 84, 1, 62, 6, 98, 0, 13, 2, 52, 4, 59, 3, 87, 5, 38, 
    4, 61, 1, 80, 2, 40, 5, 64, 7, 42, 6, 51, 3,  5, 8, 98, 0, 24, 
    4, 70, 0, 80, 3, 58, 6, 71, 5, 19, 7, 39, 2, 34, 8, 56, 1, 78, 
    1, 36, 7,  8, 8, 75, 3, 43, 2, 92, 4, 56, 6, 65, 5, 81, 0, 77, 
    5, 54, 6,  3, 1, 98, 7,  2, 4, 45, 8, 93, 2, 56, 0, 96, 3, 92, 
    0, 64, 5, 41, 7, 53, 3, 38, 6, 12, 8, 57, 4, 80, 2, 58, 1, 35, 
    2, 50, 1, 93, 4, 48, 6, 52, 3, 12, 5, 77, 7, 16, 0, 46, 8, 52, 
    3, 72, 5, 49, 0, 33, 8, 96, 7, 88, 6,  5, 2, 82, 4, 76, 1, 98, 
    0, 69, 2, 43, 1, 77, 3, 19, 6, 18, 8, 21, 4, 66, 5, 19, 7, 79
  };
  const int q4005[] = {
    9, 9, // Number of jobs and machines
    0, 15, 6, 85, 5, 10, 3, 80, 1, 18, 4, 36, 7, 46, 2, 89, 8, 73, 
    5,  7, 2, 84, 0, 55, 7, 92, 8, 58, 3,  4, 4, 80, 6, 18, 1, 29, 
    8, 17, 2, 80, 7, 79, 6,  3, 3, 42, 0, 83, 4, 24, 1, 92, 5, 89, 
    6, 48, 5, 39, 0, 16, 1, 79, 3, 30, 4, 19, 2, 31, 8, 67, 7, 45, 
    8, 98, 6, 87, 1, 78, 3, 69, 2, 87, 4, 56, 7, 84, 5, 61, 0, 50, 
    4, 88, 1, 14, 8, 95, 0, 87, 5, 45, 3, 10, 7, 61, 6, 49, 2, 77, 
    0, 60, 7,  4, 6, 53, 8, 57, 5, 79, 2, 41, 1, 52, 4, 90, 3, 65, 
    3, 87, 6, 57, 8, 85, 0, 54, 7, 83, 5, 51, 4, 27, 1, 33, 2, 93, 
    5, 50, 2, 57, 1, 55, 8, 20, 7, 75, 6, 35, 3, 53, 4, 35, 0, 35
  };
  const int q4006[] = {
    9, 9, // Number of jobs and machines
    8, 82, 2, 76, 7, 86, 6, 58, 3, 68, 1, 62, 5, 14, 4, 69, 0, 44, 
    2, 53, 7, 32, 1,  5, 5, 17, 3, 82, 8, 98, 4, 91, 6, 65, 0, 54, 
    1, 75, 7, 20, 3, 39, 8, 46, 5, 72, 2, 93, 0, 55, 6,  2, 4, 94, 
    6, 87, 7, 60, 8, 61, 4, 63, 2, 93, 5, 57, 1, 95, 0, 19, 3, 33, 
    3, 89, 7, 70, 4, 86, 0, 97, 2, 78, 5, 92, 1, 75, 6, 60, 8, 45, 
    7, 73, 5, 78, 8, 60, 6, 46, 2, 99, 3, 33, 0, 37, 1, 12, 4,  6, 
    1, 69, 6, 80, 7, 17, 5, 39, 0,  6, 8, 57, 2,  3, 4, 19, 3, 41, 
    7, 51, 3,  8, 4, 86, 0, 91, 5, 46, 1, 32, 2, 60, 8, 99, 6, 76, 
    6, 16, 3, 22, 7, 88, 8, 60, 5, 99, 2,  6, 0, 57, 1, 49, 4, 68
  };
  const int q4007[] = {
    9, 9, // Number of jobs and machines
    3, 78, 1, 78, 4, 37, 0, 30, 8,  7, 5, 23, 2, 22, 6, 97, 7, 13, 
    6, 43, 5, 67, 4, 66, 8, 42, 1, 56, 3, 37, 2, 69, 7, 39, 0, 85, 
    1, 94, 0, 39, 2,  4, 8, 94, 7, 42, 3, 28, 5, 79, 6,  9, 4, 26, 
    8, 70, 5, 84, 7, 32, 6, 56, 1, 15, 3, 52, 4, 89, 0,  7, 2, 55, 
    6,  2, 7, 82, 1, 68, 5, 84, 3, 57, 2, 69, 8, 13, 4, 37, 0, 68, 
    4, 24, 1, 98, 3, 72, 0, 32, 8, 57, 7, 90, 6, 91, 5, 67, 2, 71, 
    3, 44, 1, 24, 5, 98, 2, 97, 8, 81, 4, 24, 0, 30, 6, 44, 7, 72, 
    4, 97, 2, 86, 0, 15, 6, 81, 5, 20, 7, 94, 1, 91, 8, 55, 3, 30, 
    8, 56, 7, 72, 2, 27, 1, 27, 6, 13, 0, 66, 4,  1, 3, 69, 5, 20
  };
  const int q4008[] = {
    9, 9, // Number of jobs and machines
    5, 46, 2, 84, 0,  2, 4, 74, 3, 80, 6,  7, 1, 24, 7, 86, 8, 67, 
    5, 40, 4, 49, 3,  8, 8, 82, 6, 89, 0,  8, 7,  9, 1, 50, 2,  9, 
    7, 68, 0, 50, 5, 32, 2, 37, 8, 52, 1, 11, 3, 61, 6, 88, 4, 29, 
    5,  9, 4, 76, 6, 14, 3, 61, 2, 64, 8, 20, 7, 36, 1, 68, 0, 18, 
    2, 85, 5, 37, 8, 82, 4, 52, 1, 49, 7, 67, 0, 85, 3, 32, 6, 71, 
    4,  6, 1, 96, 8, 50, 5, 28, 3, 44, 7, 84, 0, 34, 6, 17, 2, 82, 
    8, 37, 4,  3, 7, 15, 6,  6, 2, 24, 3, 85, 5, 56, 0, 76, 1, 55, 
    1, 52, 2, 67, 8, 70, 7,  3, 4, 38, 3, 86, 6, 35, 5, 17, 0, 29, 
    4, 63, 3, 95, 0, 71, 1,  3, 8, 27, 6, 79, 2, 15, 5, 93, 7, 41
  };
  const int q4009[] = {
    9, 9, // Number of jobs and machines
    8, 35, 0, 99, 4, 98, 7, 63, 1, 80, 5, 55, 2,  1, 6, 42, 3, 31, 
    5, 76, 4, 87, 0, 42, 1, 85, 2,  4, 6, 22, 8, 25, 3, 98, 7, 60, 
    3, 83, 2, 37, 0, 72, 1, 16, 4, 67, 6, 91, 5, 60, 8, 39, 7, 10, 
    7,  9, 0, 96, 3, 38, 6, 53, 1, 26, 8, 93, 2,  7, 5, 18, 4, 91, 
    7, 36, 5, 87, 8, 90, 0, 72, 2, 71, 1, 87, 6, 44, 3, 77, 4, 14, 
    2, 61, 7, 33, 0, 13, 8, 90, 5, 10, 4, 88, 3, 83, 1, 65, 6, 95, 
    7, 93, 2, 74, 5, 81, 3, 13, 8, 43, 0, 83, 4, 40, 1, 97, 6, 62, 
    5, 86, 8, 81, 4, 24, 0, 37, 1, 95, 7, 68, 2, 14, 6, 98, 3, 73, 
    6, 51, 8, 40, 0, 75, 3, 45, 1, 76, 5, 84, 2, 55, 4, 46, 7, 35
  };
  const int q4010[] = {
    9, 9, // Number of jobs and machines
    0, 29, 2, 39, 5, 83, 6, 26, 1, 98, 4, 16, 8, 37, 3, 39, 7, 66, 
    2, 23, 5, 88, 6, 54, 0, 46, 1, 30, 8, 80, 4, 13, 7, 59, 3, 70, 
    4, 99, 2, 60, 3, 70, 7, 44, 6, 87, 0, 30, 5, 74, 1, 40, 8, 79, 
    0, 24, 3, 70, 7, 67, 6, 42, 8, 46, 4, 61, 1, 74, 2, 19, 5, 84, 
    4, 52, 1,  7, 5, 88, 8, 96, 3, 86, 7,  8, 2, 51, 0,  1, 6, 27, 
    1, 36, 8, 29, 6, 34, 3, 72, 2, 37, 7, 19, 5, 57, 4,  1, 0, 91, 
    4, 45, 0,  1, 2, 31, 8, 86, 1, 30, 7, 62, 5, 49, 6, 42, 3,  7, 
    5, 85, 4, 46, 0, 37, 7, 77, 6, 44, 2, 97, 3,  9, 1, 71, 8, 21, 
    6, 94, 1, 83, 0, 44, 3, 11, 5, 42, 4, 31, 7, 16, 2,  2, 8, 97
  };
  const int q4011[] = {
    9, 9, // Number of jobs and machines
    7, 81, 2, 56, 6, 59, 4, 72, 8,  4, 0, 90, 1,  6, 5, 23, 3, 49, 
    7,  2, 5, 22, 2, 99, 4, 61, 3, 48, 1, 95, 8, 24, 0, 94, 6, 81, 
    4, 43, 5, 71, 1, 53, 2, 80, 6, 33, 0, 54, 7, 67, 3, 30, 8, 36, 
    5, 11, 6, 93, 2, 20, 4, 50, 0,  6, 7, 57, 3, 42, 8, 31, 1, 29, 
    7, 61, 4,  9, 6, 14, 5, 48, 2, 27, 0, 45, 3, 99, 8, 44, 1, 13, 
    8, 37, 7, 68, 4, 24, 2, 15, 1, 72, 6,  9, 5, 76, 3, 38, 0, 66, 
    7, 71, 6, 35, 5, 22, 2, 66, 1, 58, 8, 39, 4, 94, 0, 64, 3, 57, 
    0, 50, 7, 99, 3, 29, 4, 19, 8, 82, 1, 34, 2, 97, 5, 26, 6, 30, 
    1, 53, 7, 75, 5, 76, 3, 49, 6, 50, 0, 25, 8, 68, 2, 92, 4,  7
  };
  const int q4012[] = {
    9, 9, // Number of jobs and machines
    3, 99, 2, 75, 0, 53, 1, 11, 8, 55, 7, 62, 5, 17, 4, 31, 6, 40, 
    2, 81, 8, 54, 7, 28, 1, 10, 5,  8, 3, 29, 6, 80, 4, 88, 0, 11, 
    4, 85, 5, 57, 6, 11, 0, 38, 1, 38, 7, 49, 8, 54, 2, 77, 3, 25, 
    0, 14, 1, 68, 6, 82, 4, 92, 8, 58, 2,  6, 7, 32, 3, 71, 5, 69, 
    8, 27, 0, 96, 4, 76, 6, 90, 1, 85, 7, 22, 3, 50, 5, 87, 2, 16, 
    2, 57, 8, 46, 1, 53, 3, 66, 5, 32, 4, 47, 0, 36, 6, 65, 7, 28, 
    8,  7, 7, 70, 5, 91, 0, 45, 4, 17, 1, 90, 6, 27, 2, 72, 3, 12, 
    1, 51, 2, 78, 5, 37, 8, 62, 0, 30, 7, 43, 3,  6, 6,  3, 4, 95, 
    8,  2, 4, 38, 7, 52, 5, 85, 2, 73, 3, 47, 1, 77, 6, 90, 0, 16
  };
  const int q4013[] = {
    9, 9, // Number of jobs and machines
    4,  7, 0, 96, 7, 31, 1, 73, 3, 51, 8, 93, 5, 72, 2, 22, 6, 64, 
    1, 42, 2, 62, 7, 99, 0, 30, 4, 70, 6, 84, 5, 66, 3,  2, 8, 97, 
    3,  8, 0,  1, 4,  3, 7, 43, 8, 36, 5,  6, 6, 69, 1, 35, 2, 91, 
    0,  2, 7, 78, 3, 46, 1, 38, 8, 39, 2, 60, 6, 44, 4, 44, 5, 64, 
    3, 63, 4, 16, 7, 17, 5, 45, 0,  6, 2, 50, 8,  4, 6, 72, 1, 85, 
    5, 10, 7, 41, 4,  6, 6, 15, 1, 76, 8, 76, 0, 37, 2,  7, 3, 70, 
    4, 71, 7, 87, 6, 21, 8, 92, 1, 27, 2, 72, 3, 86, 5, 44, 0, 33, 
    0, 59, 5, 42, 3, 56, 1, 90, 8, 23, 7, 34, 2,  4, 4, 32, 6, 91, 
    7,  6, 5, 47, 8,  1, 0, 69, 6, 41, 4, 90, 3,  6, 1, 38, 2, 30
  };
  const int q4014[] = {
    9, 9, // Number of jobs and machines
    2, 51, 8, 62, 0, 86, 7, 63, 3, 64, 4, 82, 5, 50, 6, 21, 1, 12, 
    2, 17, 4,  5, 5, 98, 7, 38, 0, 14, 8, 49, 1, 22, 6, 90, 3,  3, 
    5, 96, 1, 98, 7, 44, 3, 60, 4, 87, 8, 11, 0, 20, 2,  3, 6, 30, 
    1, 47, 8, 50, 2, 77, 7, 82, 0, 93, 3, 29, 4, 20, 5, 54, 6, 71, 
    1, 44, 6, 38, 7, 97, 3,  2, 4, 46, 0, 62, 8, 54, 2, 91, 5, 48, 
    3, 28, 8, 32, 4, 58, 0, 80, 7,  6, 2, 83, 6, 29, 5, 29, 1, 20, 
    4, 40, 5, 66, 3, 88, 1, 56, 0, 23, 6, 52, 2, 59, 8, 98, 7, 51, 
    6, 10, 1, 99, 7, 54, 0, 97, 3, 67, 4, 69, 8, 20, 5, 60, 2, 22, 
    1, 60, 0, 74, 4, 11, 3, 67, 6, 30, 8,  2, 7, 52, 5,  3, 2, 63
  };
  const int q4015[] = {
    9, 9, // Number of jobs and machines
    6, 27, 4,  8, 0, 66, 7, 87, 2, 65, 8, 26, 5, 83, 3, 77, 1, 92, 
    1,  9, 2, 82, 5,  9, 4, 64, 6, 10, 7, 94, 8, 93, 0,  4, 3, 38, 
    5, 31, 7, 57, 4, 96, 6, 60, 1, 81, 8, 43, 3,  1, 2, 92, 0, 49, 
    6, 21, 1, 53, 3, 62, 7, 21, 8, 13, 5, 11, 2, 41, 0, 97, 4, 91, 
    2, 59, 5, 60, 0, 43, 4, 63, 6, 63, 3, 10, 1, 43, 7, 19, 8,  9, 
    5, 44, 6, 55, 1, 36, 3, 15, 8, 84, 2, 84, 7,  3, 0,  6, 4,  5, 
    7, 17, 6, 66, 5, 84, 4, 26, 8, 98, 1, 38, 3, 93, 0, 24, 2, 18, 
    3, 22, 6,  8, 4, 32, 7, 82, 1, 27, 8, 12, 0, 44, 5,  2, 2, 67, 
    0, 26, 8, 65, 7, 89, 3, 66, 5, 99, 4, 73, 2, 50, 1, 25, 6,  5
  };
  const int q4016[] = {
    9, 9, // Number of jobs and machines
    0, 16, 5, 18, 4, 89, 6, 29, 3, 97, 1, 52, 2,  2, 8, 29, 7, 37, 
    4, 77, 0, 36, 2, 72, 1, 40, 5, 41, 3,  1, 6, 57, 7, 51, 8, 38, 
    4, 68, 5, 55, 7, 99, 1, 14, 6, 29, 2, 66, 3,  7, 8, 10, 0, 10, 
    2, 40, 0, 76, 3, 21, 1, 27, 6, 84, 7, 72, 5, 96, 8, 67, 4, 39, 
    0, 25, 8, 30, 5, 66, 7, 34, 6, 80, 2, 78, 4, 30, 1, 87, 3, 57, 
    1, 99, 6, 47, 0, 99, 3, 83, 7, 34, 8, 23, 5, 20, 4, 62, 2,  5, 
    1, 25, 0,  6, 2, 75, 3, 96, 5, 22, 6, 34, 8, 72, 7, 71, 4,  5, 
    1, 33, 7, 65, 3,  7, 2, 30, 5, 51, 0, 90, 8, 17, 4, 86, 6, 43, 
    2, 77, 4, 30, 7, 67, 8, 95, 6, 89, 0, 55, 5, 65, 1, 73, 3, 49
  };
  const int q4017[] = {
    9, 9, // Number of jobs and machines
    2, 54, 3, 37, 4, 22, 6, 83, 7, 89, 8, 22, 0, 64, 1, 10, 5, 22, 
    8, 37, 5, 51, 3, 76, 4, 94, 0, 74, 2,  9, 6, 46, 7, 75, 1, 74, 
    8, 28, 3, 22, 4, 91, 2, 55, 6, 56, 1, 55, 7,  2, 5, 85, 0, 42, 
    6, 74, 2, 21, 1, 92, 0, 53, 4, 39, 3, 41, 8, 26, 5, 63, 7, 25, 
    8, 80, 4, 92, 1, 91, 0,  7, 5, 51, 6, 20, 3, 42, 2, 22, 7,  9, 
    1, 23, 4, 37, 2, 40, 7, 48, 6, 43, 5, 78, 8, 33, 0, 65, 3, 87, 
    5, 19, 3, 14, 0, 20, 6, 87, 4, 89, 7, 36, 2, 63, 8, 61, 1, 80, 
    8, 19, 1, 54, 0, 12, 7, 75, 4,  7, 5, 13, 6, 64, 2,  8, 3, 58, 
    5, 60, 4,  1, 3,  1, 2, 38, 8, 46, 7, 92, 1, 31, 6, 97, 0, 14
  };
  const int q4018[] = {
    9, 9, // Number of jobs and machines
    4, 63, 6, 98, 1, 18, 8, 64, 3, 91, 7, 79, 5, 24, 2, 64, 0, 39, 
    1, 20, 2, 87, 6, 82, 4, 89, 0, 67, 5, 56, 3,  9, 8, 73, 7, 13, 
    6, 32, 5, 76, 8, 89, 0, 47, 4, 25, 3, 45, 2, 25, 1, 57, 7, 81, 
    7,  5, 4, 99, 0,  7, 3, 69, 5, 62, 6, 53, 1, 35, 8, 22, 2, 84, 
    2, 55, 3, 43, 1, 80, 6, 75, 0,  8, 5, 92, 8, 32, 4, 78, 7, 10, 
    7, 72, 2, 89, 1, 35, 3, 43, 0, 78, 8, 95, 6, 62, 5, 71, 4, 26, 
    7, 84, 6, 93, 2, 45, 1, 75, 4, 41, 8, 67, 0, 41, 5, 29, 3, 42, 
    7, 33, 4, 98, 2, 83, 0, 60, 5, 16, 3, 69, 6, 52, 8, 68, 1, 31, 
    3, 63, 6, 65, 5, 57, 1,  3, 4, 45, 7, 20, 8, 14, 2, 72, 0, 55
  };
  const int q4019[] = {
    9, 9, // Number of jobs and machines
    7, 19, 1, 52, 0, 41, 2, 83, 4, 28, 5, 66, 6, 89, 8, 66, 3, 99, 
    5, 81, 1, 12, 0, 38, 2, 87, 4, 34, 3, 19, 7, 10, 8, 91, 6, 62, 
    3, 71, 4, 21, 5, 19, 7, 67, 8, 31, 2, 38, 1, 46, 0, 90, 6, 79, 
    1, 51, 0, 73, 7, 75, 3, 15, 8, 98, 5, 56, 4, 20, 6, 13, 2, 59, 
    6, 55, 2, 96, 5, 50, 8, 67, 7,  4, 1, 25, 4, 74, 0, 89, 3, 16, 
    6, 14, 5, 78, 8, 29, 7, 13, 1,  8, 4, 28, 3, 67, 2, 81, 0, 90, 
    2, 21, 5, 16, 1, 98, 3, 70, 6,  9, 7, 63, 8, 83, 4,  7, 0, 35, 
    7, 47, 4, 48, 1, 69, 3, 72, 8, 74, 6, 14, 0, 23, 5, 16, 2, 30, 
    2, 27, 0, 60, 7, 69, 6, 98, 1, 65, 3, 81, 5, 81, 8,  8, 4,  9
  };
  const int q4020[] = {
    9, 9, // Number of jobs and machines
    8, 78, 7, 37, 4, 15, 5, 79, 3, 70, 1, 61, 0, 33, 2, 37, 6, 72, 
    1, 53, 4, 51, 0, 63, 7, 20, 2, 83, 6, 77, 3, 30, 5, 81, 8, 45, 
    3, 99, 0, 29, 4, 98, 7, 32, 2, 61, 6,  7, 8, 79, 5, 63, 1, 85, 
    5,  1, 7, 45, 3, 65, 2, 28, 8, 52, 4, 78, 1,  5, 0, 18, 6, 20, 
    6, 89, 4, 91, 5, 92, 2, 30, 7, 44, 0, 14, 1, 82, 3, 74, 8, 71, 
    6, 73, 7, 57, 0, 24, 8, 18, 2, 99, 3, 20, 1, 15, 4, 33, 5, 37, 
    6, 54, 7, 75, 8, 96, 1, 58, 5, 86, 2, 75, 4, 87, 3, 81, 0, 44, 
    6, 29, 7, 64, 3,  3, 5, 48, 8, 52, 2,  2, 1, 66, 0, 90, 4, 12, 
    2, 46, 8,  9, 5, 66, 1, 80, 0, 41, 6, 63, 3, 30, 7, 12, 4, 23
  };
  const int q4021[] = {
    9, 9, // Number of jobs and machines
    3, 14, 4, 81, 7, 72, 6, 24, 5, 13, 8, 75, 2, 42, 0, 45, 1, 34, 
    0, 41, 7, 40, 1, 76, 4, 24, 5, 67, 8, 87, 2, 16, 6, 78, 3, 42, 
    5, 74, 1, 19, 7, 10, 0, 55, 3, 86, 6, 98, 4, 54, 2, 10, 8, 41, 
    4, 72, 2, 77, 6, 77, 8, 73, 3, 92, 0, 54, 1, 16, 5, 77, 7, 45, 
    6,  7, 7, 70, 5, 98, 3, 64, 8, 10, 1,  3, 2, 35, 4, 66, 0, 96, 
    4, 45, 0, 82, 2, 17, 1, 68, 6, 27, 5, 80, 3, 13, 8, 86, 7, 39, 
    5, 32, 4, 40, 8, 63, 2, 91, 3, 11, 7, 60, 1, 49, 0, 67, 6, 42, 
    4,  1, 5, 98, 8, 92, 0, 26, 3, 47, 2, 70, 6, 97, 7, 38, 1, 82, 
    4, 38, 7,  8, 8, 81, 1, 60, 3,  1, 2, 58, 0, 40, 5, 84, 6, 71
  };
  const int q4022[] = {
    9, 9, // Number of jobs and machines
    2, 31, 7, 36, 8, 61, 4, 51, 0, 66, 5, 98, 1, 25, 6, 76, 3, 98, 
    7, 19, 0, 14, 6, 59, 4, 47, 3,  8, 2, 57, 5, 55, 8,  5, 1,  1, 
    4,  3, 5, 63, 8, 20, 7,  1, 0, 32, 2, 38, 1, 21, 3, 28, 6, 19, 
    7, 11, 6, 51, 8, 53, 1, 44, 5, 98, 2,  1, 4, 24, 0, 11, 3, 68, 
    6, 12, 0, 41, 4, 36, 2, 62, 8, 97, 3, 39, 7, 63, 5, 12, 1,  6, 
    2, 77, 0, 43, 6, 70, 3, 58, 8, 64, 7, 26, 4, 50, 1, 65, 5, 28, 
    7, 77, 4, 75, 1, 61, 8, 82, 3,  3, 5, 18, 6, 28, 0,  4, 2, 10, 
    1,  3, 0, 32, 7, 39, 2, 65, 4,  1, 8, 21, 5, 56, 6, 27, 3, 67, 
    7, 75, 4, 19, 8, 13, 6, 36, 5, 23, 3, 87, 2, 88, 0, 31, 1, 99
  };
  const int q4023[] = {
    9, 9, // Number of jobs and machines
    5,  7, 1, 31, 6, 70, 3, 75, 2, 60, 4, 82, 8, 93, 0, 66, 7, 31, 
    2, 17, 6, 59, 8, 64, 5, 57, 0, 26, 7, 81, 4, 43, 1,  1, 3, 78, 
    1, 14, 0,  4, 7, 67, 8, 29, 2, 51, 6, 22, 4, 32, 5, 51, 3, 87, 
    7, 81, 5, 88, 6, 83, 1,  4, 8, 29, 3, 18, 2, 52, 4,  5, 0, 69, 
    4, 40, 6, 13, 1, 57, 8, 15, 5, 89, 7, 76, 2, 12, 0, 35, 3, 31, 
    1, 94, 6, 72, 4, 76, 5, 41, 3, 55, 7, 80, 8, 33, 2,  5, 0, 76, 
    4, 61, 6, 73, 2, 83, 1, 98, 8, 91, 3,  7, 7, 66, 0, 29, 5, 19, 
    2, 66, 4, 99, 6, 47, 3, 62, 8, 31, 5, 52, 1, 35, 7, 77, 0, 29, 
    8, 73, 7, 21, 6, 65, 2, 14, 5, 67, 4, 17, 0, 39, 1, 69, 3,  2
  };
  const int q4024[] = {
    9, 9, // Number of jobs and machines
    4, 78, 0, 49, 8, 71, 3, 66, 5, 85, 6, 31, 2, 50, 7, 24, 1, 19, 
    6, 38, 0, 69, 7, 89, 3, 72, 1, 92, 2, 60, 5, 36, 4, 52, 8, 40, 
    1, 94, 6, 40, 2, 41, 0, 12, 8, 12, 4, 30, 5, 35, 7, 93, 3, 60, 
    7, 34, 8, 85, 0, 51, 5, 15, 2, 34, 4, 64, 6, 60, 1, 60, 3,  2, 
    1, 63, 7, 35, 8,  7, 6, 93, 3, 98, 0, 78, 5, 55, 2, 75, 4, 93, 
    5, 42, 2, 73, 1, 76, 0, 77, 8, 34, 4, 54, 7, 26, 3, 42, 6, 53, 
    6, 33, 8, 66, 3,  1, 1, 84, 2, 50, 4,  5, 0, 96, 5, 76, 7,  7, 
    6, 46, 8, 30, 4, 28, 1, 66, 7, 50, 0, 42, 5, 15, 2, 99, 3, 87, 
    3, 22, 0,  1, 7, 40, 5, 83, 1, 80, 4, 26, 8, 11, 2, 73, 6, 93
  };
  const int q4025[] = {
    9, 9, // Number of jobs and machines
    4, 50, 8, 92, 2, 77, 3, 50, 7, 13, 1, 29, 6, 71, 0, 81, 5, 85, 
    2, 75, 8, 32, 7, 91, 0, 95, 3, 37, 4, 27, 1, 70, 5, 55, 6, 35, 
    5, 82, 3, 19, 7, 11, 0, 17, 1, 75, 6, 46, 8, 70, 4, 76, 2, 16, 
    4, 82, 6, 20, 8, 79, 3,  2, 7, 75, 2, 12, 0, 31, 5, 11, 1, 24, 
    6, 89, 0, 19, 7, 79, 8, 45, 2, 86, 1, 23, 5, 55, 4, 86, 3,  5, 
    7, 91, 4, 73, 6, 51, 2, 35, 5, 25, 1, 73, 8, 47, 3, 55, 0, 41, 
    3, 39, 7, 78, 8, 93, 2, 89, 0, 74, 6, 92, 1, 91, 5, 25, 4, 61, 
    7, 75, 8, 48, 5, 49, 6, 76, 3, 90, 0,  9, 1,  7, 4, 46, 2, 25, 
    1, 55, 7, 81, 6, 65, 2, 17, 4, 15, 8, 61, 0, 15, 3, 84, 5, 65
  };
  const int q4026[] = {
    9, 9, // Number of jobs and machines
    3, 11, 0, 29, 2, 38, 7, 81, 8, 98, 4, 43, 6, 17, 5, 65, 1, 60, 
    2, 57, 5, 12, 6, 26, 1, 67, 8, 59, 7, 40, 3, 50, 4, 79, 0, 16, 
    2, 75, 5, 17, 8, 59, 3, 54, 4,  4, 6, 99, 7, 95, 0, 35, 1, 84, 
    6, 19, 4, 30, 1, 77, 5, 94, 8, 39, 0, 34, 2, 39, 3, 81, 7, 16, 
    3, 64, 6, 87, 1, 60, 7, 75, 4, 56, 0, 68, 8, 67, 5, 62, 2, 82, 
    2, 10, 5, 60, 8, 94, 3, 66, 6, 65, 4, 25, 0, 16, 7, 39, 1, 91, 
    6, 69, 1, 61, 2, 21, 0, 85, 5, 64, 8, 52, 3, 34, 7, 71, 4, 77, 
    3,  5, 4, 58, 6, 20, 1, 13, 7, 15, 8, 66, 0, 16, 5, 48, 2, 84, 
    3, 34, 6, 89, 5, 54, 0, 99, 4, 38, 2, 17, 8, 50, 1, 69, 7,  6
  };
  const int q4027[] = {
    9, 9, // Number of jobs and machines
    0, 65, 3, 55, 6, 52, 5, 47, 1, 15, 2, 52, 7, 58, 4, 66, 8, 77, 
    7, 12, 5, 10, 6, 45, 2,  8, 4, 85, 0, 21, 8, 40, 3, 66, 1, 26, 
    8,  5, 0,  6, 3, 55, 5, 79, 2, 89, 7, 43, 1,  9, 6, 34, 4, 30, 
    1, 86, 6, 52, 2, 99, 8,  9, 4, 40, 3, 65, 7, 62, 5, 71, 0, 11, 
    1, 95, 6, 63, 4, 20, 3,  2, 7, 56, 0, 80, 8, 23, 2, 48, 5, 80, 
    7, 37, 5, 49, 1, 38, 6,  7, 3, 42, 0,  2, 4, 99, 2, 45, 8, 43, 
    4, 48, 3, 32, 8, 83, 6, 37, 0, 82, 5, 67, 2, 72, 7, 94, 1, 91, 
    7,  3, 1, 22, 5, 69, 4, 98, 3, 84, 0, 45, 6, 29, 8, 39, 2, 94, 
    8, 73, 4, 12, 6, 20, 5, 87, 2, 64, 7, 58, 1, 86, 3, 26, 0, 31
  };
  const int q4028[] = {
    9, 9, // Number of jobs and machines
    2, 70, 5, 36, 3, 28, 0, 16, 4, 75, 8, 37, 7,  7, 6, 63, 1, 12, 
    4, 75, 3, 17, 7, 94, 5, 63, 8, 69, 6, 77, 2, 84, 0, 84, 1, 64, 
    7, 81, 5, 30, 2, 96, 1,  4, 4, 82, 0, 87, 6, 40, 3, 85, 8, 68, 
    0, 61, 7, 67, 3, 85, 8, 98, 2, 21, 1, 83, 4, 11, 6, 64, 5, 50, 
    3, 18, 7, 36, 2, 75, 8, 19, 4, 30, 6, 60, 1, 90, 0,  8, 5, 69, 
    8, 46, 5, 60, 0, 17, 1, 18, 7, 68, 4, 36, 6, 47, 2, 90, 3, 88, 
    3, 13, 2, 83, 4, 72, 7, 88, 8, 28, 0, 77, 5, 74, 6, 28, 1, 17, 
    4, 83, 7,  4, 2, 10, 6, 22, 3, 99, 5,  9, 1, 56, 8, 29, 0,  1, 
    1,  3, 3, 98, 4, 48, 6, 10, 0, 81, 7, 82, 5, 54, 8, 89, 2, 74
  };
  const int q4029[] = {
    9, 9, // Number of jobs and machines
    5, 28, 0,  7, 6, 14, 1, 57, 4,  5, 3, 77, 2, 84, 7, 22, 8, 31, 
    8, 35, 3, 52, 0, 46, 5, 82, 4,  2, 6, 79, 7, 17, 2, 60, 1, 65, 
    3, 36, 7, 30, 4, 85, 2, 89, 5, 99, 8,  2, 1, 37, 6, 24, 0, 35, 
    0, 82, 1, 98, 5, 89, 3, 36, 4, 11, 7, 37, 8, 56, 6, 56, 2, 64, 
    8, 79, 7, 42, 2, 36, 3, 81, 0, 65, 5, 39, 1, 82, 4, 83, 6, 55, 
    7,  5, 4, 91, 5, 80, 8, 46, 6, 43, 1, 38, 2, 53, 3, 40, 0,  2, 
    0, 92, 5, 90, 4, 46, 3, 44, 1,  1, 6, 30, 8, 29, 7, 23, 2, 79, 
    4, 63, 5, 69, 2, 78, 3, 56, 0, 37, 8, 14, 6, 95, 7, 28, 1, 75, 
    2, 94, 5, 62, 8, 79, 6,  3, 3, 72, 1, 55, 4, 44, 0, 97, 7, 59
  };
  const int q4030[] = {
    9, 9, // Number of jobs and machines
    5, 72, 7, 66, 3, 49, 1, 82, 8, 85, 0,  3, 4, 86, 2, 90, 6, 47, 
    1, 16, 2, 67, 6, 97, 0, 89, 8, 58, 7,  9, 5, 64, 4, 96, 3, 93, 
    8, 43, 0, 52, 3, 76, 4,  8, 5,  6, 7, 67, 2, 87, 6,  4, 1, 96, 
    1, 17, 3, 70, 2, 68, 8, 34, 7, 27, 4, 75, 6, 16, 5, 48, 0,  9, 
    2, 33, 0, 16, 8, 82, 1, 83, 3, 40, 7, 15, 5, 17, 6, 65, 4, 40, 
    6, 40, 1, 97, 4,  1, 2, 44, 5, 25, 7, 19, 8, 49, 0, 73, 3, 97, 
    3, 91, 5, 57, 6, 70, 0, 12, 7, 25, 4, 85, 2, 95, 8, 65, 1, 65, 
    7,  9, 3, 48, 8, 90, 1, 16, 6, 51, 2,  2, 0,  7, 5, 90, 4,  5, 
    8, 90, 6, 34, 1, 76, 2, 46, 4,  8, 3, 28, 7, 68, 0, 54, 5, 95
  };
  const int q4031[] = {
    9, 9, // Number of jobs and machines
    6, 65, 8, 41, 3, 87, 0, 68, 7, 82, 2,  4, 4, 10, 5, 95, 1, 76, 
    6, 61, 8, 14, 0, 41, 7, 34, 5, 75, 1, 97, 2, 95, 3, 30, 4, 70, 
    4, 96, 7, 60, 0, 19, 6, 97, 8, 66, 1, 42, 2,  4, 3, 13, 5, 54, 
    3, 55, 4, 10, 7, 40, 6, 26, 5, 69, 1, 71, 8, 82, 2, 14, 0, 92, 
    6, 18, 1, 90, 5, 37, 4, 75, 8, 20, 2, 92, 0,  6, 7, 97, 3, 42, 
    6, 17, 0, 65, 7, 61, 2, 46, 3, 34, 8, 89, 4, 11, 5, 42, 1, 85, 
    7, 46, 3, 64, 0, 68, 4, 40, 6, 57, 5, 99, 1, 32, 8, 96, 2, 42, 
    8, 15, 7, 58, 4, 41, 3, 63, 2, 24, 6, 51, 1, 99, 0, 87, 5, 50, 
    5, 91, 2, 47, 8, 17, 4, 41, 0,  1, 6, 99, 1, 25, 3, 94, 7, 25
  };
  const int q4032[] = {
    9, 9, // Number of jobs and machines
    6, 93, 8, 35, 0, 20, 1, 89, 2, 35, 3, 72, 5, 61, 4, 86, 7, 20, 
    2, 69, 7, 67, 6, 20, 8, 20, 5, 14, 3, 92, 0, 40, 4, 63, 1, 77, 
    5, 59, 3, 65, 6, 97, 4, 35, 2,  4, 1, 28, 0, 54, 7, 83, 8, 12, 
    7, 59, 5, 87, 2, 76, 0, 18, 4, 73, 8, 86, 6, 49, 1, 33, 3, 33, 
    5,  3, 1, 82, 3, 39, 4, 10, 7,  8, 8, 26, 6,  8, 2, 73, 0, 54, 
    3, 53, 7,  2, 6, 45, 2, 97, 5, 79, 1, 24, 0, 18, 4, 32, 8, 29, 
    5,  8, 0, 31, 7,  1, 2, 53, 3, 92, 1, 27, 6, 24, 8, 56, 4, 47, 
    5, 74, 1, 64, 3, 95, 4, 33, 6, 26, 0, 75, 7, 98, 8, 54, 2, 61, 
    3, 24, 0, 78, 4,  6, 6, 65, 1, 96, 7, 17, 2, 69, 8,  1, 5, 51
  };
  const int q4033[] = {
    9, 9, // Number of jobs and machines
    7,  8, 2, 12, 1, 88, 4, 29, 3, 45, 5,  2, 0, 40, 6, 37, 8, 84, 
    6, 65, 2, 18, 1, 48, 7, 60, 8, 99, 3, 70, 4, 76, 5, 50, 0,  1, 
    5, 92, 3,  4, 2, 43, 0, 16, 7, 10, 6, 96, 8, 18, 1, 19, 4, 22, 
    0, 88, 7, 95, 8, 90, 4, 84, 1, 35, 3, 43, 5, 25, 6, 47, 2, 20, 
    3, 78, 4,  9, 6, 84, 7, 86, 8, 77, 1, 69, 0, 50, 5,  8, 2, 62, 
    8, 96, 4,  1, 2,  8, 7, 80, 5, 54, 6, 59, 0, 43, 1, 18, 3, 24, 
    4, 29, 8, 65, 3, 82, 6, 89, 1, 42, 0, 28, 7, 76, 2, 50, 5, 35, 
    4, 73, 0, 69, 5, 80, 8, 12, 1, 19, 2, 44, 7, 39, 6, 65, 3, 44, 
    3, 29, 4, 51, 8,  9, 1, 99, 2, 59, 6, 29, 5, 95, 0, 58, 7, 25
  };
  const int q4034[] = {
    9, 9, // Number of jobs and machines
    8, 81, 4, 81, 3, 29, 1,  5, 2, 93, 0, 82, 5, 15, 6, 13, 7, 15, 
    3, 54, 2, 41, 5, 59, 7, 32, 1, 76, 0,  7, 6, 89, 4, 60, 8, 57, 
    2, 47, 8, 45, 3, 24, 0, 11, 7, 44, 5, 15, 1, 88, 6,  7, 4, 86, 
    1, 58, 0, 50, 3, 92, 5, 31, 8, 38, 4, 67, 6, 70, 7, 57, 2, 89, 
    7, 62, 4, 81, 3, 33, 2, 30, 5, 50, 6, 12, 8, 27, 0, 21, 1, 19, 
    5,  1, 8, 72, 2, 85, 4, 93, 3, 20, 1, 14, 6, 86, 7,  4, 0, 35, 
    1, 78, 0, 16, 2, 42, 8, 47, 7, 49, 4, 81, 3, 53, 5, 61, 6, 12, 
    3, 63, 8, 59, 7, 12, 0, 18, 6,  5, 1, 10, 5,  5, 4, 94, 2, 93, 
    1, 81, 0, 53, 3, 11, 6, 25, 7, 76, 4, 70, 2,  7, 5, 49, 8, 42
  };
  const int q4035[] = {
    9, 9, // Number of jobs and machines
    3, 98, 8,  6, 6, 60, 5, 54, 0,  1, 1, 73, 4, 67, 7, 32, 2, 40, 
    8, 66, 5, 57, 1, 53, 2, 59, 0, 60, 3, 19, 6,  2, 7, 82, 4, 25, 
    4, 69, 6,  3, 2, 96, 8, 13, 7,  9, 0, 28, 1, 33, 5, 86, 3, 58, 
    5, 60, 0, 84, 6, 67, 7, 62, 1, 52, 3, 76, 8, 43, 4, 29, 2, 61, 
    4, 58, 0, 33, 2, 27, 3, 73, 1, 33, 8, 48, 7, 34, 5,  9, 6, 34, 
    5, 63, 1, 75, 3, 21, 4,  5, 0, 97, 2, 22, 6, 44, 8, 63, 7, 50, 
    7,  1, 2, 71, 6, 75, 1, 32, 5, 34, 3,  8, 8, 62, 0, 52, 4, 66, 
    3, 97, 1, 51, 6, 41, 8,  7, 4, 16, 7, 92, 0, 53, 5,  3, 2, 38, 
    6,  6, 2, 92, 0, 14, 8, 90, 1, 14, 7, 93, 3, 74, 4, 19, 5, 13
  };
  const int q4036[] = {
    9, 9, // Number of jobs and machines
    0, 40, 2, 90, 3, 49, 8,  7, 4, 50, 6, 74, 1, 42, 5, 99, 7, 32, 
    1, 58, 0, 53, 4, 65, 5, 40, 8, 51, 6, 54, 2, 91, 7, 97, 3, 82, 
    3, 21, 8, 16, 1, 49, 2,  4, 6, 90, 7,  7, 5, 13, 0, 89, 4, 22, 
    3, 93, 0, 56, 7, 37, 1, 67, 8, 35, 4, 35, 2, 20, 5, 79, 6, 18, 
    6, 59, 4,  9, 2, 26, 5,  1, 7, 70, 1, 81, 3, 43, 0, 69, 8, 89, 
    1,  4, 4, 32, 3, 35, 7, 35, 5, 40, 0, 26, 8, 24, 6, 11, 2, 23, 
    6, 56, 5, 11, 1, 33, 8, 32, 3, 54, 4, 22, 7, 30, 0, 11, 2, 96, 
    0, 23, 4, 51, 3, 95, 1, 38, 5,  9, 8, 49, 2, 29, 6, 10, 7, 98, 
    2, 48, 8, 75, 7, 78, 1, 94, 5, 46, 4, 82, 3, 43, 6, 68, 0, 15
  };
  const int q4037[] = {
    9, 9, // Number of jobs and machines
    6, 50, 7,  3, 2, 16, 4,  9, 1, 31, 0, 52, 3,  4, 8, 58, 5, 86, 
    5, 25, 8, 41, 3,  4, 7, 78, 1,  5, 4, 93, 0, 53, 2, 38, 6, 68, 
    0, 58, 7,  1, 6, 60, 2, 22, 5, 21, 8, 69, 1,  2, 4, 13, 3, 78, 
    2, 48, 5, 38, 4, 67, 1, 14, 0, 32, 3, 26, 8,  4, 7, 16, 6, 76, 
    0, 10, 5, 56, 3, 51, 2, 41, 8, 33, 6, 40, 1, 35, 7, 14, 4, 86, 
    1, 24, 5, 15, 3, 70, 7, 57, 2, 71, 8, 79, 4, 36, 0, 87, 6, 61, 
    3, 10, 6, 78, 2, 61, 7, 76, 8, 13, 5, 91, 0, 79, 1, 23, 4, 27, 
    5, 77, 2, 77, 0, 50, 7, 80, 3, 41, 4,  4, 8, 72, 6, 49, 1,  7, 
    4, 13, 3, 73, 7, 77, 1, 55, 6, 58, 0, 11, 8, 13, 5, 70, 2, 55
  };
  const int q4038[] = {
    9, 9, // Number of jobs and machines
    0,  4, 1, 81, 5, 66, 7, 80, 8, 24, 2,  8, 3, 86, 6, 87, 4, 94, 
    5, 85, 3, 58, 1, 94, 6, 77, 4, 58, 7, 40, 0, 35, 2, 69, 8, 20, 
    1, 16, 5, 74, 7, 91, 6, 53, 0, 36, 3, 17, 4, 84, 2, 56, 8, 93, 
    1, 85, 6,  6, 2, 33, 5, 65, 7, 57, 4, 94, 8, 78, 3, 14, 0, 66, 
    2, 69, 0, 96, 8, 44, 1, 22, 7, 23, 5, 18, 6, 66, 3, 63, 4, 56, 
    5, 44, 2, 17, 1, 88, 3, 80, 4, 70, 8, 19, 7, 20, 0, 99, 6, 84, 
    5, 68, 4, 79, 3, 36, 1, 99, 0, 94, 7, 10, 6, 29, 8, 19, 2, 23, 
    2, 79, 0, 73, 4, 80, 5, 78, 8, 83, 3, 76, 7, 34, 1, 49, 6, 62, 
    2, 93, 3, 30, 7, 90, 8, 93, 1, 59, 4, 50, 5, 98, 6, 98, 0, 70
  };
  const int q4039[] = {
    9, 9, // Number of jobs and machines
    4, 73, 1, 85, 0, 88, 3, 61, 7, 39, 8, 79, 2, 90, 6, 23, 5, 49, 
    2, 68, 7, 77, 4, 93, 3, 93, 6, 97, 8, 77, 0,  8, 1, 66, 5, 23, 
    5,  5, 2, 11, 1, 70, 7, 73, 4, 28, 8,  3, 3, 12, 0, 81, 6, 50, 
    4, 44, 2,  1, 8, 45, 3, 32, 7, 45, 0, 32, 6, 36, 1, 22, 5,  2, 
    6, 53, 7, 28, 8, 65, 0, 44, 2, 22, 1, 61, 3, 83, 5, 95, 4, 18, 
    6, 76, 1, 71, 4, 59, 2, 75, 7, 14, 3, 39, 5, 29, 0, 91, 8, 43, 
    6, 26, 8, 49, 7, 24, 5, 99, 3, 45, 1, 81, 2, 56, 4, 27, 0, 58, 
    8,  8, 3, 42, 1,  8, 5, 10, 4, 62, 2, 81, 0, 55, 6, 76, 7, 58, 
    3, 91, 1, 49, 8,  9, 7, 25, 4, 98, 0, 98, 5, 64, 2, 54, 6, 99
  };
  const int q4040[] = {
    9, 9, // Number of jobs and machines
    6, 51, 7, 59, 4, 70, 8, 88, 0,  9, 2,  8, 1, 77, 3, 72, 5, 42, 
    4, 85, 0,  7, 1, 19, 5, 96, 3, 86, 8, 53, 2, 83, 7, 65, 6,  7, 
    6, 99, 5, 57, 7, 45, 4, 74, 1, 76, 2,  4, 8, 41, 0, 49, 3, 49, 
    0, 45, 1, 65, 6, 33, 3,  7, 5, 25, 2, 66, 8, 28, 7, 86, 4, 30, 
    4, 13, 1, 46, 5,  2, 3, 64, 8, 46, 2,  9, 0, 39, 6, 26, 7, 63, 
    3, 38, 8,  5, 2, 38, 0, 22, 6, 17, 4, 30, 7, 85, 1,  2, 5, 74, 
    1, 28, 0, 64, 3, 52, 8, 43, 7, 30, 2, 87, 4, 48, 6, 90, 5, 78, 
    8, 30, 3, 80, 0, 45, 2, 89, 1, 52, 4, 47, 6, 87, 5, 77, 7, 67, 
    0, 64, 6,  5, 7, 23, 5,  2, 8, 26, 3, 66, 4,  9, 1, 25, 2, 13
  };
  const int q4041[] = {
    9, 9, // Number of jobs and machines
    0, 62, 6, 22, 8, 85, 1, 62, 7, 98, 3, 83, 2, 53, 4, 96, 5, 79, 
    6, 23, 0, 50, 5, 24, 1, 29, 7, 75, 8, 80, 4, 41, 3, 95, 2, 92, 
    7, 90, 0, 63, 8, 32, 3, 65, 4, 61, 2, 17, 5, 99, 6, 80, 1, 40, 
    3, 99, 8, 21, 1, 98, 2, 93, 6, 66, 5, 76, 0, 93, 7, 20, 4, 81, 
    2, 52, 1, 99, 0, 33, 3, 88, 6,  4, 4, 41, 5, 83, 8,  4, 7, 62, 
    8, 22, 7, 69, 6, 27, 4, 14, 0, 80, 1, 25, 5, 64, 3,  4, 2, 77, 
    5, 28, 3, 36, 2, 39, 1, 92, 4, 43, 7, 16, 6, 91, 0, 67, 8, 87, 
    5, 83, 8,  5, 0, 92, 1, 87, 6,  6, 7, 56, 4, 90, 2, 61, 3, 77, 
    0, 14, 5, 36, 3, 68, 2, 41, 4, 14, 7, 95, 1, 32, 6, 19, 8, 44
  };
  const int q4042[] = {
    9, 9, // Number of jobs and machines
    5, 33, 3, 82, 7, 90, 1, 96, 2,  3, 4, 15, 8, 33, 6, 10, 0,  2, 
    6,  8, 8, 99, 5, 38, 2, 82, 4, 93, 7, 28, 1,  1, 3, 86, 0, 25, 
    7,  1, 2, 52, 5, 77, 3, 99, 8, 65, 4, 91, 1, 74, 6, 62, 0, 11, 
    8, 34, 7, 42, 5, 84, 0, 58, 2, 49, 4, 20, 3, 52, 6, 88, 1, 99, 
    3, 85, 0, 39, 2, 17, 4, 39, 6, 28, 7, 69, 1, 27, 8, 21, 5, 66, 
    6, 61, 2, 98, 7, 21, 1, 71, 5, 46, 4, 14, 8, 24, 3, 90, 0,  9, 
    0, 41, 7, 29, 4, 60, 8, 19, 5, 46, 2, 49, 6,  2, 1, 45, 3, 17, 
    3, 59, 8, 97, 0, 86, 6, 23, 4, 46, 5, 25, 7, 41, 1,  9, 2, 31, 
    0, 44, 2, 95, 5, 10, 7, 41, 3, 77, 8, 63, 4, 54, 1, 76, 6, 65
  };
  const int q4043[] = {
    9, 9, // Number of jobs and machines
    2, 26, 3, 83, 8, 41, 5,  6, 0, 76, 6, 38, 7, 74, 1, 82, 4, 32, 
    3, 39, 6, 72, 7, 90, 4, 65, 5, 25, 2, 42, 0, 51, 8, 78, 1, 11, 
    0, 21, 4, 42, 3, 39, 2, 94, 5, 36, 7,  7, 8, 72, 1, 57, 6, 24, 
    6,  7, 8, 71, 7, 54, 2, 49, 5, 77, 3, 45, 4, 68, 1, 23, 0, 68, 
    3, 13, 1, 15, 8, 20, 0, 75, 2, 72, 5, 45, 4, 43, 6, 65, 7, 76, 
    6, 10, 1, 42, 2, 21, 5,  1, 0, 13, 8, 43, 3, 97, 7, 33, 4, 15, 
    8, 51, 4, 59, 5, 67, 7, 60, 0,  1, 3, 21, 2, 18, 1, 70, 6, 45, 
    1,  6, 2, 20, 8,  7, 6, 22, 5, 33, 0, 88, 7,  1, 3,  8, 4, 35, 
    7, 70, 3, 13, 6, 84, 0, 74, 1, 21, 4, 37, 8, 48, 2, 74, 5, 33
  };
  const int q4044[] = {
    9, 9, // Number of jobs and machines
    0, 48, 4, 79, 2, 22, 3, 47, 6, 20, 8, 88, 7, 24, 1, 21, 5, 96, 
    4, 91, 8, 31, 7, 45, 2, 51, 6, 96, 5, 33, 0, 89, 3, 16, 1, 68, 
    0, 36, 2, 39, 6, 93, 4, 41, 7, 53, 3, 32, 5, 32, 8, 82, 1, 90, 
    1, 86, 8, 25, 0,  5, 6,  8, 5, 78, 4, 46, 7, 72, 3, 94, 2, 16, 
    2, 51, 7, 14, 3, 53, 5, 97, 8, 62, 1, 89, 6, 37, 4,  9, 0, 75, 
    1, 44, 5, 97, 2, 88, 8, 21, 4, 78, 7, 71, 0, 47, 6, 51, 3,  6, 
    7, 35, 0, 57, 6, 93, 8,  8, 3, 62, 4, 22, 1, 57, 2, 90, 5, 38, 
    1, 40, 2, 69, 8, 68, 3, 89, 7, 40, 5, 66, 0,  3, 4, 10, 6, 26, 
    0, 65, 7, 81, 4, 61, 2, 62, 6, 48, 5, 48, 8, 39, 1, 35, 3, 86
  };
  const int q4045[] = {
    9, 9, // Number of jobs and machines
    4, 19, 1, 75, 6, 32, 8, 94, 5, 54, 2, 93, 7, 35, 3, 19, 0,  9, 
    3, 87, 7, 89, 4, 17, 0, 63, 8, 98, 2, 95, 1, 49, 5, 66, 6, 16, 
    3, 37, 7, 85, 0,  1, 1, 78, 8, 52, 5, 94, 4, 58, 6, 44, 2, 64, 
    6, 18, 7, 12, 0, 58, 2, 49, 4, 28, 1, 63, 3, 97, 5, 82, 8, 12, 
    7, 33, 5, 31, 0, 55, 2, 72, 8, 26, 6, 43, 4, 25, 3, 67, 1, 76, 
    8, 86, 7, 51, 5, 97, 3,  4, 0, 79, 2, 56, 1, 72, 6, 88, 4, 76, 
    1, 50, 4, 65, 3, 72, 6,  4, 5, 48, 2, 13, 7, 78, 0,  9, 8, 52, 
    5, 35, 7, 81, 3, 78, 2, 16, 8, 40, 0, 31, 6,  8, 4, 66, 1, 34, 
    3, 63, 5, 27, 4, 52, 0, 80, 7, 71, 2, 54, 6, 60, 1, 81, 8,  2
  };
  const int q4046[] = {
    9, 9, // Number of jobs and machines
    3, 38, 4, 82, 8, 46, 5, 50, 1, 26, 0, 46, 7, 80, 2, 38, 6, 87, 
    1, 98, 3, 61, 5, 32, 6, 31, 7, 21, 2,  6, 8,  5, 0, 21, 4, 26, 
    4, 92, 6, 98, 2, 61, 0, 74, 5, 67, 3, 24, 1, 11, 7, 39, 8,  8, 
    1, 57, 3, 70, 2, 40, 8, 33, 5,  1, 0, 16, 6, 85, 4, 41, 7, 78, 
    5, 15, 2,  3, 8, 60, 7, 33, 1,  1, 6,  5, 4, 55, 0, 80, 3, 22, 
    3, 90, 4, 99, 7, 60, 5, 84, 0, 86, 1, 60, 6, 71, 8, 99, 2, 19, 
    1, 60, 2, 62, 8, 11, 4, 69, 7,  5, 6, 21, 0, 77, 5, 33, 3, 18, 
    2, 52, 3, 34, 4, 56, 5,  6, 0, 23, 8, 82, 6, 47, 7, 67, 1, 53, 
    7, 45, 1, 54, 3, 66, 0, 32, 4, 90, 5, 28, 2, 10, 8, 89, 6, 34
  };
  const int q4047[] = {
    9, 9, // Number of jobs and machines
    4, 86, 2, 26, 8, 86, 0, 49, 5, 75, 1, 20, 7, 33, 6,  3, 3, 30, 
    3, 18, 8, 27, 5, 38, 4, 17, 6, 14, 7, 69, 0, 74, 1, 54, 2, 96, 
    6, 77, 7, 79, 5, 84, 8, 64, 2, 68, 4, 41, 0, 49, 1,  7, 3, 96, 
    8, 71, 0, 38, 6, 94, 3, 22, 2, 75, 4, 45, 5, 22, 1, 43, 7, 74, 
    2, 22, 4, 51, 3, 48, 6, 10, 5, 48, 0,  1, 7, 91, 8, 26, 1, 80, 
    6, 21, 5,  7, 0, 70, 4, 57, 3, 81, 1,  6, 2, 90, 7, 30, 8, 81, 
    3, 55, 4, 22, 8, 16, 7, 90, 1, 14, 2, 77, 0, 55, 5, 52, 6, 45, 
    4, 73, 0, 80, 8, 51, 7, 92, 3, 32, 2, 81, 6,  8, 1, 33, 5, 78, 
    7, 33, 8, 71, 3, 15, 6, 63, 0, 14, 2, 76, 4, 14, 5, 16, 1, 11
  };
  const int q4048[] = {
    9, 9, // Number of jobs and machines
    6, 30, 3, 19, 1, 52, 0, 44, 2, 54, 4, 59, 8, 98, 5, 61, 7, 20, 
    1, 83, 2, 17, 0, 85, 8, 89, 4, 94, 6, 92, 3, 87, 5, 29, 7,  2, 
    2, 83, 3, 65, 4, 57, 1, 54, 8, 81, 0, 18, 7, 26, 6, 66, 5, 73, 
    4, 27, 1, 87, 6, 77, 3, 91, 2, 14, 0, 93, 7, 80, 5, 81, 8, 65, 
    6, 89, 7, 22, 1, 55, 3, 64, 0, 19, 5, 42, 8, 96, 4, 14, 2, 60, 
    1, 35, 4, 48, 2, 78, 3, 42, 7, 44, 8, 70, 5, 48, 6, 37, 0, 69, 
    5, 56, 6, 25, 8, 58, 2, 24, 1, 72, 0, 98, 4, 46, 7, 56, 3, 69, 
    4, 24, 5, 99, 0, 91, 6, 48, 7, 37, 1, 38, 8, 43, 2, 87, 3, 32, 
    4, 87, 2, 72, 3, 64, 0, 81, 1, 85, 8,  2, 5, 30, 7, 74, 6, 32
  };
  const int q4049[] = {
    9, 9, // Number of jobs and machines
    6,  5, 0, 84, 8, 40, 5, 18, 3,  9, 2, 65, 1, 97, 7, 57, 4, 96, 
    5,  2, 2, 55, 0, 57, 7, 86, 1, 93, 8, 41, 6, 93, 3, 35, 4, 66, 
    3, 32, 6,  7, 4, 60, 0,  4, 8, 87, 2, 52, 5, 31, 1, 85, 7, 60, 
    4, 27, 2, 32, 8, 33, 7, 43, 5, 66, 1, 76, 3,  1, 0, 10, 6,  8, 
    4, 76, 3, 93, 7, 87, 6, 53, 0, 68, 8, 97, 2, 76, 5, 92, 1, 15, 
    8, 93, 2, 98, 3, 68, 7, 15, 1, 77, 0, 93, 4, 76, 5, 81, 6, 62, 
    6, 70, 3, 88, 0, 34, 2, 71, 1, 15, 5, 50, 8, 13, 4, 32, 7, 96, 
    1, 50, 2, 91, 5, 75, 8, 71, 3, 84, 6, 65, 7, 48, 0, 95, 4, 17, 
    2, 56, 6, 87, 1, 71, 0, 78, 7, 73, 5,  6, 4, 78, 8, 16, 3, 16
  };
  const int q4050[] = {
    9, 9, // Number of jobs and machines
    4, 62, 6, 87, 8, 13, 3, 96, 1,  1, 2, 91, 7, 44, 5, 63, 0, 33, 
    0, 35, 8, 48, 4, 96, 7, 90, 1,  3, 6, 97, 5, 98, 2, 19, 3,  2, 
    2, 85, 5, 40, 4, 87, 8, 58, 1, 24, 6, 57, 7, 56, 3, 12, 0, 27, 
    1, 96, 7, 64, 5, 71, 4, 69, 8, 87, 0,  2, 3,  8, 6, 35, 2, 37, 
    1, 77, 5, 74, 3,  5, 0, 42, 8, 72, 2, 57, 4, 44, 7, 73, 6, 98, 
    0, 67, 2, 20, 4, 32, 1, 95, 6, 62, 3, 61, 5, 33, 8, 77, 7, 39, 
    8, 20, 0,  9, 3, 55, 5, 30, 4, 40, 2, 99, 1, 73, 7, 42, 6, 83, 
    1, 11, 5, 10, 6, 16, 3, 90, 7, 71, 8, 91, 2, 32, 4, 49, 0, 25, 
    5, 17, 2, 64, 0,  2, 8, 77, 6, 36, 7, 82, 1, 97, 4, 18, 3, 50
  };
  const int q4051[] = {
    9, 9, // Number of jobs and machines
    1, 33, 5,  2, 7, 26, 2, 16, 4,  6, 0, 74, 8, 94, 6, 18, 3, 76, 
    3, 76, 0, 89, 4, 87, 5,  2, 6, 28, 1, 16, 2, 34, 8, 26, 7, 92, 
    3, 60, 2, 15, 4, 69, 8, 72, 6,  4, 7, 67, 5, 80, 0, 51, 1, 47, 
    7, 74, 5, 10, 2, 72, 3, 80, 6, 26, 8, 77, 0, 73, 1, 37, 4, 23, 
    0, 51, 2, 85, 1, 88, 4, 60, 3, 93, 5, 44, 8, 57, 7,  7, 6, 70, 
    8, 78, 5, 38, 1, 44, 3, 41, 7, 37, 0, 15, 4, 39, 2, 16, 6, 97, 
    7, 32, 4, 37, 1, 52, 8, 47, 0, 14, 3, 81, 6,  1, 2, 82, 5, 69, 
    2, 11, 3, 56, 4, 17, 6, 92, 5,  1, 0,  7, 8, 21, 7, 15, 1, 20, 
    6, 84, 4, 28, 2, 66, 7, 46, 0,  5, 5, 14, 1,  7, 8, 24, 3, 88
  };
  const int q4052[] = {
    9, 9, // Number of jobs and machines
    5, 22, 4, 16, 7, 25, 2, 57, 1, 91, 8, 31, 6, 32, 3, 64, 0, 25, 
    7, 15, 8, 11, 4, 40, 6, 81, 2, 36, 3,  1, 1, 95, 0, 92, 5,  8, 
    6,  7, 0,  6, 3, 29, 2, 94, 1, 87, 7, 21, 8, 30, 4, 79, 5, 93, 
    5, 71, 6, 13, 8, 31, 4, 98, 7, 29, 2, 12, 3, 17, 0, 49, 1, 11, 
    8, 87, 7, 89, 1, 67, 0, 33, 5, 11, 3, 18, 2, 40, 4, 63, 6, 19, 
    6, 11, 1, 76, 3, 52, 7, 53, 2, 65, 8, 31, 4, 23, 0,  7, 5, 59, 
    6, 94, 1, 99, 4, 42, 8, 66, 2, 54, 3,  5, 0, 37, 5, 76, 7, 93, 
    5, 37, 6,  7, 4, 30, 8, 25, 0,  4, 2, 89, 7, 83, 3, 70, 1, 62, 
    3, 97, 1, 85, 8, 63, 0, 72, 4, 36, 5, 29, 6, 59, 2, 10, 7, 18
  };
  const int q4053[] = {
    9, 9, // Number of jobs and machines
    1, 41, 6, 31, 7, 85, 3, 94, 4, 93, 2, 60, 8, 32, 5, 45, 0, 36, 
    3, 76, 0, 32, 5, 84, 2, 80, 1, 50, 7, 66, 8,  2, 6, 42, 4,  9, 
    8, 40, 3, 35, 7, 28, 1, 81, 6, 65, 4, 57, 0, 63, 5, 42, 2, 13, 
    7, 98, 8, 22, 1, 42, 6, 18, 5, 83, 2, 42, 4, 59, 3, 93, 0, 61, 
    7, 78, 4, 96, 0, 13, 3, 21, 8, 16, 6, 28, 1, 13, 2, 83, 5, 16, 
    6, 33, 5, 43, 3, 47, 8, 96, 2,  8, 0,  5, 7, 46, 1, 78, 4, 90, 
    3, 97, 7, 45, 8, 29, 2, 86, 1, 32, 0, 24, 6, 34, 5, 58, 4, 77, 
    0, 41, 5, 26, 8, 49, 4, 44, 2, 17, 7, 58, 1, 98, 6, 88, 3,  8, 
    7, 41, 8, 33, 1, 60, 3, 47, 4, 56, 0, 72, 5, 13, 2, 53, 6, 49
  };
  const int q4054[] = {
    9, 9, // Number of jobs and machines
    5, 57, 1, 71, 7, 14, 0, 75, 2, 42, 8, 16, 4,  8, 6, 76, 3, 31, 
    8, 67, 0, 99, 4, 25, 5, 34, 6, 72, 7, 52, 3, 86, 1, 85, 2, 62, 
    0, 43, 6, 59, 5, 14, 4, 49, 2, 33, 7,  9, 3, 22, 1, 14, 8, 51, 
    8,  1, 0, 42, 5, 23, 4, 91, 3, 50, 7, 15, 1,  5, 2, 78, 6, 91, 
    8, 85, 4,  1, 5, 32, 7, 35, 2, 85, 3, 38, 0,  4, 1, 32, 6, 82, 
    4,  4, 1, 22, 0,  6, 5, 41, 3, 58, 8,  2, 6, 97, 2, 35, 7, 34, 
    3,  9, 4, 71, 0, 28, 6, 64, 5,  7, 7, 64, 8, 25, 2,  3, 1, 25, 
    1,  5, 7, 49, 6, 77, 3, 55, 8,  9, 2, 19, 0, 12, 5, 22, 4, 81, 
    8, 67, 1, 78, 2, 99, 6, 37, 4, 66, 0, 92, 7, 69, 3, 90, 5, 24
  };
  const int q4055[] = {
    9, 9, // Number of jobs and machines
    0, 41, 1, 90, 7, 85, 8, 67, 6, 54, 5, 18, 4,  2, 2, 23, 3, 90, 
    1, 55, 7, 29, 4, 55, 8, 12, 5, 82, 2, 44, 6, 43, 3, 16, 0, 92, 
    8, 13, 4,  4, 5, 27, 0, 26, 1, 83, 7, 27, 6, 50, 2,  5, 3, 53, 
    0, 42, 7, 39, 5, 44, 3, 25, 1, 33, 2, 29, 6, 97, 4,  9, 8, 63, 
    4, 65, 6, 35, 7, 59, 8, 57, 3, 32, 1, 49, 0, 78, 2, 11, 5, 83, 
    7, 56, 4, 38, 8, 50, 3, 91, 1, 36, 6, 79, 0, 30, 2, 81, 5, 12, 
    1, 43, 5, 47, 6, 13, 0, 22, 3, 50, 8, 70, 2, 74, 4, 39, 7, 18, 
    2, 41, 4, 63, 6, 85, 8, 21, 0, 13, 3, 45, 5,  9, 7,  9, 1, 80, 
    8, 92, 7,  2, 2, 33, 6, 34, 0, 33, 3, 90, 5, 77, 4, 19, 1, 14
  };
  const int q4056[] = {
    9, 9, // Number of jobs and machines
    5, 10, 1, 47, 0, 60, 3, 35, 6, 98, 2, 63, 7, 89, 4, 46, 8, 35, 
    0, 68, 2, 75, 6, 17, 5, 31, 3, 38, 1, 19, 4, 63, 7, 69, 8, 97, 
    8, 34, 7, 73, 3, 42, 0, 30, 2, 80, 1, 54, 4, 66, 5, 23, 6,  1, 
    4, 60, 2, 55, 5,  2, 1, 16, 7, 87, 0, 28, 8, 94, 3, 63, 6, 59, 
    8, 26, 1, 75, 6, 67, 0, 98, 2, 83, 5, 37, 7,  4, 4, 61, 3, 32, 
    1, 31, 7,  6, 5, 87, 6,  9, 2, 51, 3, 75, 4, 91, 8, 62, 0, 46, 
    7, 71, 3, 96, 6, 71, 5, 10, 2, 78, 1, 15, 0, 18, 8, 30, 4, 37, 
    4,  5, 1, 94, 7, 52, 2, 28, 0, 56, 5,  2, 3, 97, 6,  5, 8, 37, 
    1, 20, 4, 93, 8, 26, 5, 39, 0, 35, 6, 89, 3, 61, 2, 51, 7, 28
  };
  const int q4057[] = {
    9, 9, // Number of jobs and machines
    3, 75, 8, 68, 1, 45, 7, 77, 0, 43, 6, 14, 5,  1, 4, 45, 2, 35, 
    5, 66, 3,  8, 1,  3, 4, 73, 6, 82, 8, 73, 7, 23, 0, 22, 2, 94, 
    4,  8, 8, 12, 0, 47, 2, 49, 5, 57, 1, 35, 6, 72, 7, 21, 3, 32, 
    0, 62, 4, 32, 2, 30, 6, 75, 7, 59, 3, 56, 1, 24, 5, 21, 8, 17, 
    2, 52, 4, 32, 5, 62, 3, 20, 7, 96, 1, 66, 6, 49, 0, 59, 8, 67, 
    4, 58, 8, 53, 2, 45, 3, 98, 5, 70, 6, 26, 7, 49, 1, 50, 0, 16, 
    8, 74, 7, 57, 1, 15, 5, 55, 2, 52, 3, 18, 6, 92, 0, 76, 4,  4, 
    4, 95, 1, 74, 3, 96, 0, 26, 8, 57, 7, 42, 2, 94, 5, 65, 6, 40, 
    4, 58, 6, 57, 7,  1, 0, 12, 8, 53, 3, 93, 2, 66, 1, 70, 5, 55
  };
  const int q4058[] = {
    9, 9, // Number of jobs and machines
    7, 93, 3, 77, 4, 52, 8, 82, 2, 89, 1, 51, 6, 35, 0, 67, 5, 63, 
    8, 38, 1, 87, 7, 25, 3, 30, 5, 27, 0, 74, 4,  1, 6, 49, 2, 58, 
    1,  4, 8, 41, 4, 32, 2, 66, 3, 21, 0, 86, 7, 41, 6, 58, 5, 27, 
    0, 32, 7, 65, 2, 76, 6, 80, 1, 90, 4,  6, 8, 71, 5, 70, 3, 39, 
    3, 88, 7, 23, 8, 47, 1, 45, 6, 39, 0, 66, 4, 74, 5, 79, 2,  6, 
    7, 91, 3, 27, 6, 12, 4, 66, 0, 96, 8, 22, 5,  6, 2, 86, 1, 12, 
    3, 39, 1, 59, 8, 24, 2, 44, 6, 97, 4,  4, 5, 55, 0, 16, 7, 22, 
    1, 47, 8,  2, 3, 77, 5, 63, 2, 33, 6, 69, 0, 38, 4, 56, 7, 10, 
    8, 54, 0, 75, 4, 35, 3, 86, 1,  8, 5, 36, 2, 27, 7, 63, 6, 52
  };
  const int q4059[] = {
    9, 9, // Number of jobs and machines
    7, 66, 3,  4, 4,  4, 1, 53, 0, 52, 5, 52, 6,  6, 2, 59, 8, 82, 
    8, 37, 0,  9, 7, 65, 6, 46, 1, 68, 4, 66, 2, 77, 5, 10, 3, 56, 
    0, 99, 4, 22, 3, 25, 5, 11, 8, 82, 1, 93, 2,  1, 6, 50, 7, 35, 
    5,  8, 1, 34, 4, 11, 7, 22, 2, 41, 8, 85, 0, 31, 3, 23, 6, 24, 
    6, 54, 3, 94, 8, 59, 7,  6, 4,  8, 2, 80, 5, 50, 1, 64, 0, 46, 
    6, 82, 4, 61, 8, 11, 0, 78, 3, 94, 1, 69, 7, 95, 2, 97, 5, 80, 
    2, 27, 0, 98, 4, 73, 1, 78, 7,  8, 6, 33, 3, 15, 8, 85, 5, 98, 
    1, 20, 6, 63, 0, 56, 8, 23, 4, 99, 7, 48, 3, 13, 5, 98, 2, 46, 
    7,  5, 3, 44, 4, 98, 8, 92, 1, 70, 6, 75, 2, 33, 5, 93, 0, 70
  };
  const int q4060[] = {
    9, 9, // Number of jobs and machines
    6, 25, 7, 51, 4, 73, 2, 16, 3, 99, 5, 96, 0, 57, 1, 52, 8, 90, 
    1, 63, 3, 30, 6, 49, 2, 99, 0, 31, 5, 53, 8, 61, 7, 20, 4, 96, 
    7, 91, 0, 94, 1,  4, 4, 75, 8, 30, 3, 16, 2, 91, 6, 24, 5, 54, 
    6, 66, 8, 39, 5, 17, 1,  7, 4, 24, 7, 86, 3, 69, 2, 81, 0, 87, 
    0, 61, 8, 87, 1, 32, 2, 48, 6, 31, 7,  9, 4, 28, 5, 75, 3, 27, 
    2, 68, 5, 41, 4, 21, 0,  7, 6, 43, 8,  2, 7, 74, 1, 47, 3, 56, 
    6, 99, 4, 67, 8, 94, 5, 58, 3, 11, 2, 91, 0,  5, 1, 88, 7, 43, 
    4, 40, 3, 37, 0, 75, 5, 15, 8, 72, 7, 72, 2, 77, 6, 54, 1, 85, 
    0, 20, 2,  3, 6, 15, 1, 81, 7, 98, 3, 18, 8, 28, 4, 64, 5, 28
  };
  const int q4061[] = {
    9, 9, // Number of jobs and machines
    3, 31, 4, 76, 2, 86, 0, 36, 5, 10, 1, 64, 8, 30, 7,  5, 6, 20, 
    2, 10, 3, 88, 8, 28, 4, 41, 7, 56, 6, 58, 1, 79, 5, 63, 0, 28, 
    1, 23, 2, 49, 5, 32, 8, 79, 3, 75, 4, 66, 0, 77, 6, 44, 7, 18, 
    8, 72, 6, 28, 5, 53, 0, 69, 7,  5, 4, 61, 2, 75, 3, 60, 1, 93, 
    4,  2, 3, 30, 0, 31, 1, 65, 6, 58, 7, 90, 8, 76, 5, 27, 2, 43, 
    7, 45, 5, 42, 8, 76, 2, 78, 3, 91, 4, 72, 6, 53, 0, 92, 1, 19, 
    6, 13, 1, 63, 5, 73, 0, 12, 8, 10, 3,  4, 2, 91, 7, 40, 4, 59, 
    3, 97, 0, 13, 5, 28, 8,  3, 1, 80, 7, 46, 6, 10, 4, 74, 2, 57, 
    2, 11, 5, 20, 4, 61, 6, 93, 1,  2, 0, 31, 7, 10, 8, 52, 3, 43
  };
  const int q4062[] = {
    9, 9, // Number of jobs and machines
    3,  7, 8, 12, 2, 58, 0, 78, 7, 58, 1, 69, 5, 15, 6, 43, 4, 50, 
    3, 41, 1, 32, 2, 34, 5, 87, 0, 24, 8, 86, 7, 18, 4, 77, 6, 64, 
    2, 38, 7, 62, 6, 70, 3, 13, 0, 11, 8, 42, 1, 19, 5, 39, 4, 59, 
    2, 57, 1, 25, 5, 13, 7, 23, 6, 64, 4,  2, 8, 81, 3, 27, 0, 94, 
    2, 36, 4, 36, 5, 44, 1, 61, 8, 35, 6, 16, 7, 27, 3, 19, 0, 49, 
    1, 36, 0, 13, 7, 63, 8, 16, 6, 19, 2, 86, 5, 76, 4, 17, 3, 75, 
    3, 16, 4, 27, 7, 45, 0, 55, 2, 55, 5, 58, 6, 21, 1, 74, 8, 27, 
    6, 24, 4,  5, 0, 81, 5, 28, 8, 57, 1, 89, 2, 28, 7, 54, 3, 43, 
    6, 43, 3, 36, 2, 91, 5, 87, 7, 13, 1, 46, 0, 26, 4, 67, 8, 89
  };
  const int q4063[] = {
    9, 9, // Number of jobs and machines
    1, 80, 2, 55, 0, 93, 3, 76, 7, 37, 8, 35, 6, 64, 5, 62, 4, 20, 
    5, 91, 2, 52, 0, 80, 3,  5, 1,  3, 7, 49, 4, 16, 6, 25, 8, 25, 
    8, 55, 6, 49, 0, 44, 1, 49, 4, 96, 5, 27, 7,  2, 2, 57, 3, 44, 
    0, 18, 8, 63, 5, 58, 4, 15, 2, 37, 7, 18, 3, 37, 1,  3, 6, 71, 
    5,  3, 2, 56, 6, 70, 4, 97, 0, 15, 1, 53, 3, 87, 8, 28, 7, 87, 
    1, 73, 0, 89, 4, 35, 7, 83, 6, 41, 2, 25, 3, 44, 8, 68, 5, 41, 
    5, 41, 1, 46, 8, 71, 7, 54, 4,  3, 6, 13, 0, 58, 2, 66, 3, 20, 
    7, 30, 0, 11, 4, 32, 6, 55, 2, 50, 5, 80, 3, 35, 1, 71, 8, 80, 
    1, 21, 4, 58, 7, 33, 8, 52, 2, 41, 5,  1, 3, 64, 6, 50, 0, 60
  };
  const int q4064[] = {
    9, 9, // Number of jobs and machines
    4,  5, 5, 33, 2, 66, 3, 46, 7, 38, 1,  4, 0, 89, 6, 77, 8, 12, 
    4, 22, 6, 11, 7, 72, 0, 94, 5, 36, 1, 21, 3, 74, 8, 92, 2, 73, 
    5,  6, 2, 34, 8, 18, 4, 95, 7, 18, 1, 77, 3, 25, 0, 55, 6, 11, 
    3, 73, 0, 49, 7, 43, 8,  9, 2, 26, 4,  7, 5, 10, 1, 65, 6, 73, 
    3, 97, 6, 13, 5, 69, 2, 12, 1, 33, 8, 14, 7, 89, 4, 46, 0, 41, 
    3,  4, 8, 44, 7, 24, 6, 79, 2, 62, 0, 47, 4, 55, 5, 76, 1, 91, 
    1, 89, 7, 46, 5,  4, 3, 92, 2, 19, 6, 31, 0, 42, 4,  8, 8, 11, 
    4, 77, 8, 24, 0, 38, 2, 68, 7, 23, 6, 21, 3, 27, 5, 96, 1, 33, 
    4, 71, 8, 28, 2, 72, 3, 76, 0, 19, 7, 64, 6, 45, 5, 61, 1, 27
  };
  const int q4065[] = {
    9, 9, // Number of jobs and machines
    7, 81, 1, 85, 3, 85, 4, 55, 0, 41, 6,  1, 2, 49, 8, 46, 5, 86, 
    5, 47, 2, 41, 6, 74, 8, 52, 7, 98, 3, 35, 4, 82, 0, 62, 1, 63, 
    5, 34, 7, 40, 2, 82, 3, 16, 4, 23, 6, 69, 1, 15, 8,  9, 0, 52, 
    2, 63, 6, 23, 8, 57, 7, 26, 4, 36, 1, 47, 0, 55, 3,  3, 5, 57, 
    5, 39, 2, 72, 0, 56, 8, 14, 3, 82, 4, 83, 1, 42, 6, 23, 7, 43, 
    0, 72, 6, 22, 3, 35, 2, 19, 8, 27, 7, 89, 1,  7, 5, 82, 4, 99, 
    4, 89, 5, 95, 3, 66, 1, 60, 8, 74, 6, 16, 2, 88, 7, 42, 0, 44, 
    5, 62, 2, 92, 4, 76, 8, 27, 0, 61, 3, 33, 6, 55, 1, 80, 7, 92, 
    8, 26, 7, 57, 1, 18, 0, 76, 6,  2, 4, 30, 3, 61, 5, 22, 2, 87
  };
  const int q4066[] = {
    9, 9, // Number of jobs and machines
    1, 28, 7, 74, 8, 67, 5, 79, 4, 32, 6, 41, 2, 80, 0, 60, 3, 48, 
    4, 21, 3, 25, 0, 26, 8, 77, 6, 82, 1, 30, 5, 59, 7, 27, 2, 16, 
    8, 10, 5,  2, 2, 78, 6, 81, 1, 58, 7, 27, 3, 29, 0, 16, 4, 79, 
    5, 91, 0, 12, 3, 41, 6, 56, 4, 15, 7, 78, 8, 63, 1, 61, 2, 69, 
    3,  2, 7, 50, 2, 72, 0, 94, 4, 62, 1, 93, 5, 59, 6, 91, 8, 36, 
    8, 76, 5, 36, 1, 45, 3, 79, 0, 13, 7, 37, 2, 69, 6, 67, 4, 35, 
    8, 50, 5, 64, 2,  3, 6, 19, 0, 10, 3, 49, 1, 24, 4, 39, 7, 54, 
    2, 85, 8, 93, 7, 35, 5, 77, 1, 39, 3, 94, 0, 52, 6, 79, 4, 15, 
    1, 13, 7,  4, 8, 19, 0,  4, 2, 48, 6, 88, 3, 71, 4, 78, 5, 78
  };
  const int q4067[] = {
    9, 9, // Number of jobs and machines
    7, 31, 8,  5, 4, 29, 3, 12, 5, 24, 1, 94, 0, 20, 2, 76, 6, 92, 
    4, 34, 7, 25, 6, 45, 1, 96, 0, 30, 3, 64, 8, 12, 2, 32, 5, 85, 
    7, 26, 1, 13, 0, 76, 8, 43, 4, 70, 5, 66, 2, 97, 6, 94, 3, 41, 
    7, 90, 1,  6, 8, 80, 3, 29, 4, 78, 2, 58, 0, 70, 6, 87, 5, 85, 
    2, 71, 7, 53, 0, 66, 3, 30, 5, 53, 4, 51, 1, 64, 8,  9, 6,  2, 
    7, 26, 0, 82, 3,  3, 1, 79, 8, 33, 2, 98, 6, 37, 4, 70, 5, 11, 
    3, 23, 0, 62, 2, 21, 7, 29, 8, 79, 1,  3, 4, 65, 6, 70, 5, 54, 
    6, 76, 5, 75, 3, 36, 4, 28, 7, 37, 2, 11, 1, 65, 0, 48, 8,  7, 
    1, 41, 5,  6, 6, 93, 2, 55, 7, 90, 0, 75, 8, 53, 3, 61, 4, 62
  };
  const int q4068[] = {
    9, 9, // Number of jobs and machines
    0, 25, 4, 38, 2, 31, 1, 48, 6, 91, 8, 14, 7, 37, 3, 23, 5, 77, 
    2, 13, 5, 14, 4, 40, 0, 99, 6, 89, 7, 75, 3, 95, 8, 26, 1, 15, 
    5, 52, 6, 51, 8, 11, 2,  2, 4, 87, 7, 56, 1, 36, 3, 49, 0, 65, 
    3, 62, 2, 47, 8, 19, 7, 93, 0, 11, 5, 48, 4, 91, 1, 30, 6, 42, 
    3, 16, 1, 51, 5, 54, 4, 73, 0, 99, 8, 42, 7, 21, 6, 25, 2, 96, 
    2, 13, 8, 96, 0, 93, 7, 13, 3, 11, 1, 25, 5, 57, 4, 39, 6, 26, 
    3, 76, 8, 44, 2, 84, 1, 14, 0, 72, 4, 47, 7, 91, 6, 66, 5, 99, 
    6,  3, 7, 97, 8, 61, 3, 49, 1, 66, 0, 19, 5,  6, 2, 16, 4, 35, 
    4, 43, 2, 54, 1, 95, 0, 95, 7, 66, 8, 52, 5, 58, 6, 18, 3, 51
  };
  const int q4069[] = {
    9, 9, // Number of jobs and machines
    1,  3, 4, 47, 7, 56, 2, 41, 6, 35, 8, 32, 0, 35, 3, 59, 5, 95, 
    7, 58, 1,  8, 8, 67, 0, 73, 2, 51, 3, 41, 4, 27, 6, 13, 5, 16, 
    7, 14, 2, 74, 8, 12, 6, 20, 5, 19, 3, 29, 4, 69, 0, 59, 1, 64, 
    8, 73, 5, 40, 2, 62, 1, 81, 4, 42, 3, 56, 7, 28, 6, 76, 0, 58, 
    7, 33, 4,  9, 2, 86, 0,  9, 8, 17, 3, 89, 1, 57, 6, 76, 5, 23, 
    5, 80, 1, 55, 3, 64, 0, 73, 7, 46, 8, 64, 6, 11, 4, 11, 2, 70, 
    4, 43, 2, 82, 8, 13, 6,  6, 5, 94, 3, 70, 7, 83, 1, 68, 0, 61, 
    5, 14, 6, 52, 0, 84, 7, 45, 3, 61, 2, 12, 4, 78, 8, 15, 1, 62, 
    4, 62, 3, 50, 6,  3, 0, 78, 2, 13, 7, 65, 1, 32, 8, 21, 5, 35
  };
  const int q4070[] = {
    9, 9, // Number of jobs and machines
    3, 45, 1, 92, 5, 89, 4, 65, 2, 71, 6, 91, 8, 98, 0, 36, 7, 73, 
    2, 89, 1, 55, 0, 62, 6, 24, 5, 95, 4, 22, 8, 86, 3, 26, 7, 56, 
    2, 61, 3, 37, 8, 78, 0, 34, 6, 42, 1, 57, 4, 85, 5, 88, 7, 32, 
    7,  8, 6,  3, 4,  6, 2, 14, 8, 37, 5,  5, 3, 60, 1,  9, 0, 99, 
    6, 80, 7, 54, 0, 99, 3,  6, 2, 62, 5, 63, 4, 24, 8, 28, 1, 21, 
    4, 28, 8, 36, 5, 58, 0, 65, 7, 33, 2, 23, 6, 62, 3, 33, 1, 16, 
    1, 69, 7, 72, 5,  2, 3, 90, 6, 82, 8, 23, 4, 96, 0, 38, 2, 39, 
    3, 56, 8, 21, 4, 53, 6, 31, 1, 12, 2,  9, 7,  3, 5, 64, 0, 75, 
    4, 77, 3, 90, 7,  4, 8, 18, 1, 86, 0, 64, 5, 54, 2, 79, 6, 32
  };
  const int q4071[] = {
    9, 9, // Number of jobs and machines
    6, 40, 4,  3, 0, 85, 1, 86, 2, 93, 8, 39, 5, 42, 7, 55, 3, 52, 
    1, 85, 6, 68, 3, 94, 4, 36, 7, 59, 2, 72, 0, 86, 8,  4, 5,  1, 
    7, 53, 5, 90, 6, 74, 8, 56, 1, 39, 0,  4, 4, 52, 2, 84, 3, 28, 
    4, 24, 3, 28, 5, 97, 8, 31, 7, 11, 2, 94, 6, 43, 1, 24, 0, 20, 
    7,  4, 0, 73, 3, 17, 4, 24, 8, 18, 5, 98, 1, 18, 6, 13, 2, 58, 
    1, 41, 6, 18, 2, 81, 4, 65, 3,  9, 0, 98, 7, 70, 8, 59, 5,  7, 
    3, 12, 1, 42, 7, 69, 2, 65, 8, 91, 0, 14, 4, 76, 6, 73, 5, 45, 
    4, 89, 6, 77, 0, 12, 3, 44, 2, 16, 5, 66, 8,  9, 1, 37, 7, 64, 
    4, 78, 5, 57, 8, 45, 6, 94, 0, 81, 2, 63, 3, 82, 7,  6, 1, 48
  };
  const int q4072[] = {
    9, 9, // Number of jobs and machines
    7, 70, 0, 23, 3, 50, 5, 63, 2, 21, 4, 26, 8, 70, 6, 47, 1, 21, 
    5, 52, 2, 33, 7,  4, 3, 70, 1, 39, 4, 67, 6, 67, 8, 18, 0, 58, 
    8, 53, 2, 24, 7, 41, 4, 91, 1, 99, 0, 99, 6, 95, 5, 76, 3, 88, 
    4, 76, 8,  9, 3, 50, 7, 63, 0, 92, 6,  7, 1, 77, 5, 89, 2, 38, 
    3, 75, 2, 96, 4, 92, 0, 39, 5, 59, 7, 44, 8, 59, 6, 18, 1, 88, 
    7, 51, 2, 17, 1, 92, 5, 66, 3, 58, 4, 74, 8, 45, 0,  7, 6, 36, 
    1, 84, 8, 31, 5, 16, 0, 42, 7, 16, 6, 28, 2, 82, 4, 60, 3, 42, 
    3, 66, 8, 85, 6, 37, 0, 98, 2, 11, 4, 56, 5, 94, 7, 22, 1, 17, 
    7, 81, 3, 64, 5, 23, 6, 71, 1, 83, 8, 40, 0,  4, 4, 91, 2, 23
  };
  const int q4073[] = {
    9, 9, // Number of jobs and machines
    3, 90, 1, 33, 7,  4, 0, 94, 2, 83, 5, 82, 4, 74, 8,  2, 6, 49, 
    8, 18, 3, 96, 5, 88, 2, 47, 0, 78, 6, 60, 7, 96, 1,  7, 4, 56, 
    0, 97, 7, 84, 3,  8, 1, 90, 2, 48, 5, 10, 4, 93, 8, 73, 6, 35, 
    8, 38, 4, 12, 3, 18, 1, 64, 0, 14, 5, 73, 6, 91, 2, 27, 7, 32, 
    1, 73, 7, 88, 0, 20, 4, 31, 5, 60, 8, 43, 2, 84, 6, 69, 3, 44, 
    1, 61, 8, 17, 4, 31, 3, 61, 5, 58, 7, 69, 2, 67, 0, 47, 6, 45, 
    4, 33, 7, 34, 5, 10, 3, 93, 8, 70, 1, 94, 2, 42, 0, 73, 6, 74, 
    1, 87, 0, 32, 5, 68, 7, 64, 8, 14, 4, 96, 3, 62, 2, 42, 6, 75, 
    3, 59, 1, 11, 5, 51, 2,  4, 6, 35, 0, 74, 4, 72, 7, 59, 8,  4
  };
  const int q4074[] = {
    9, 9, // Number of jobs and machines
    2, 83, 1, 89, 8, 43, 4, 18, 5, 94, 6, 25, 0, 51, 7, 87, 3, 46, 
    5,  1, 3, 14, 2, 96, 1, 68, 4, 74, 0, 51, 6, 61, 8, 92, 7, 76, 
    2, 98, 6, 60, 0,  7, 8,  7, 7, 96, 4, 97, 1,  4, 5, 22, 3, 50, 
    4, 72, 6, 71, 2, 99, 3, 35, 5, 94, 1, 39, 7, 14, 0, 40, 8, 42, 
    7,  2, 0, 77, 8, 96, 2, 14, 5, 83, 1, 42, 4, 80, 3, 27, 6, 46, 
    6, 41, 5, 38, 4, 43, 1, 81, 8, 74, 3, 47, 2, 78, 7, 58, 0, 24, 
    5, 89, 2, 22, 6, 10, 3, 99, 4, 11, 7, 81, 8, 61, 0, 15, 1, 14, 
    3, 77, 6,  9, 4, 94, 2,  8, 0, 24, 5, 56, 8, 36, 1, 57, 7, 23, 
    2, 52, 0, 80, 4, 74, 8, 67, 5, 83, 6,  2, 3, 69, 7, 40, 1, 12
  };
  const int q4075[] = {
    9, 9, // Number of jobs and machines
    2, 96, 0, 35, 8, 80, 4, 79, 5, 39, 6, 69, 3, 33, 7, 23, 1, 37, 
    2, 27, 5, 75, 7, 73, 8, 59, 6, 94, 4, 79, 0, 92, 1, 11, 3, 46, 
    7, 90, 0, 43, 3, 45, 1, 19, 5, 82, 8, 96, 4, 86, 6, 45, 2, 81, 
    0, 33, 6, 68, 3, 36, 5, 41, 2, 84, 4, 86, 7, 47, 1, 32, 8, 94, 
    4, 40, 0, 98, 2, 96, 5, 34, 3, 25, 1, 87, 8, 57, 7,  9, 6, 41, 
    4, 22, 8, 78, 5, 51, 0, 72, 1, 55, 7, 87, 6, 80, 2, 20, 3,  9, 
    8, 52, 1, 79, 0, 55, 5, 35, 3, 16, 4, 61, 2, 11, 7, 65, 6, 81, 
    2, 99, 7, 57, 3,  8, 0, 66, 6, 77, 5, 14, 1, 23, 8, 84, 4,  1, 
    0, 42, 7,  2, 6, 33, 3, 35, 4, 36, 8, 40, 2, 71, 5, 33, 1, 62
  };
  const int q4076[] = {
    9, 9, // Number of jobs and machines
    8, 26, 1, 97, 7, 57, 3, 48, 4, 32, 6,  1, 0, 27, 5, 40, 2, 21, 
    1, 63, 5, 43, 2, 64, 7, 57, 8, 59, 3, 50, 0, 86, 6,  6, 4, 50, 
    1, 28, 3, 53, 7, 46, 4,  4, 5, 64, 8, 53, 2, 49, 6,  9, 0, 88, 
    2, 50, 0,  5, 8, 94, 5, 90, 7, 35, 1,  4, 6,  3, 3, 40, 4, 50, 
    2, 48, 7, 96, 6, 39, 0, 58, 3, 22, 8, 75, 4, 95, 1, 25, 5, 17, 
    2, 81, 4, 55, 1, 60, 6, 47, 5, 63, 8, 36, 0, 77, 7, 31, 3, 99, 
    3, 96, 8, 39, 6, 38, 1, 72, 2, 52, 7, 51, 4, 11, 0, 77, 5, 33, 
    0, 82, 6, 98, 7, 25, 4, 31, 5, 42, 2, 92, 3, 63, 8, 79, 1, 53, 
    7, 66, 3, 59, 8, 36, 5, 22, 0, 58, 4, 29, 2, 61, 6, 56, 1, 22
  };
  const int q4077[] = {
    9, 9, // Number of jobs and machines
    1, 17, 3, 13, 8, 57, 7, 48, 5, 89, 6, 67, 0, 88, 2, 59, 4, 90, 
    2, 35, 6,  1, 0, 33, 7, 48, 4, 18, 1,  9, 5, 31, 3, 14, 8, 35, 
    2,  3, 7, 84, 1, 19, 6, 53, 3, 51, 4, 52, 8,  6, 5, 34, 0, 69, 
    0, 37, 3, 63, 8, 50, 5, 70, 1, 45, 2, 32, 6, 54, 4, 71, 7, 33, 
    5, 64, 8, 85, 6, 51, 0, 76, 2, 87, 7, 19, 1, 15, 4, 83, 3, 53, 
    4, 65, 8, 91, 6, 44, 3, 18, 2, 24, 0, 70, 5, 32, 1, 95, 7, 37, 
    3, 84, 4, 47, 1, 12, 8, 25, 7, 22, 0,  4, 2, 66, 5, 34, 6,  2, 
    0, 23, 8, 89, 2, 86, 4, 48, 7, 74, 3, 20, 6, 33, 1, 42, 5, 44, 
    3, 51, 5, 13, 6, 57, 7, 16, 2, 91, 4, 71, 0, 42, 1, 33, 8, 51
  };
  const int q4078[] = {
    9, 9, // Number of jobs and machines
    8,  6, 0, 46, 2, 72, 7, 63, 1, 97, 4, 25, 5,  3, 6, 36, 3, 58, 
    0, 23, 8, 71, 5, 69, 6, 55, 7, 14, 2, 46, 1, 71, 4, 18, 3, 26, 
    7, 29, 0, 45, 1, 15, 6, 66, 3, 30, 5, 79, 8, 78, 2, 78, 4, 39, 
    0, 28, 5, 97, 2, 87, 8, 22, 6, 27, 4, 23, 3, 84, 1, 84, 7, 31, 
    7, 42, 5, 73, 2,  5, 4, 51, 8, 48, 6, 91, 1, 53, 0,  5, 3, 41, 
    8, 83, 5, 91, 4, 87, 2, 64, 3, 42, 1, 12, 7, 98, 6, 44, 0, 30, 
    1, 48, 8, 67, 4, 83, 3, 17, 5, 96, 7, 50, 0, 44, 6, 31, 2, 88, 
    1,  7, 2, 32, 4, 52, 0, 26, 7,  3, 6, 55, 3, 16, 5, 78, 8, 81, 
    3, 92, 7, 46, 8, 90, 1, 93, 5, 63, 6, 77, 2, 18, 0, 33, 4, 12
  };
  const int q4079[] = {
    9, 9, // Number of jobs and machines
    6, 24, 0, 21, 5, 74, 2, 10, 8, 48, 7, 36, 1, 37, 3, 39, 4,  8, 
    1, 49, 6, 16, 0, 72, 5, 82, 4,  5, 3, 32, 2, 84, 7, 11, 8, 76, 
    0, 31, 1, 64, 7, 87, 3, 74, 2, 35, 8, 15, 5, 35, 4, 49, 6, 39, 
    7, 89, 1, 13, 2, 68, 0, 14, 4, 42, 8, 92, 3, 52, 6, 74, 5, 72, 
    6, 17, 2, 33, 7,  6, 8, 15, 4, 89, 1, 60, 3, 32, 0, 65, 5, 24, 
    5, 53, 6, 25, 4, 29, 1, 19, 0, 36, 2, 81, 3, 62, 7, 40, 8, 23, 
    1, 38, 0, 79, 4, 52, 7, 44, 6, 85, 5,  4, 3, 96, 8, 42, 2, 29, 
    3, 17, 4, 25, 8, 91, 2, 59, 0,  8, 7, 77, 1, 69, 6, 82, 5, 75, 
    8, 22, 1, 42, 2, 88, 6, 36, 5, 53, 3, 56, 7, 37, 4, 55, 0, 11
  };
  const int q4080[] = {
    9, 9, // Number of jobs and machines
    4, 11, 8,  5, 0, 99, 7, 34, 3, 23, 6, 18, 5, 76, 2,  5, 1, 37, 
    2, 82, 3, 86, 6, 21, 0, 68, 4, 43, 5, 57, 7, 91, 8, 21, 1, 69, 
    8, 21, 6, 80, 0, 90, 3, 29, 2, 73, 5, 98, 1, 81, 4, 79, 7, 72, 
    3, 37, 7, 80, 1, 76, 0,  8, 6, 52, 8, 33, 2, 38, 4, 64, 5, 92, 
    1, 74, 2, 81, 0, 98, 4, 11, 8, 27, 5,  1, 6, 73, 3, 76, 7,  4, 
    8, 64, 0, 25, 5, 58, 1,  8, 7, 83, 4,  9, 3, 23, 2, 36, 6, 77, 
    2, 92, 4, 95, 6, 94, 7, 46, 5, 99, 0, 60, 8,  1, 3, 84, 1, 36, 
    1, 93, 6, 15, 3, 76, 2, 62, 8, 40, 0, 50, 7, 57, 4, 58, 5, 32, 
    6, 10, 2, 29, 8, 84, 1, 96, 4, 58, 5,  5, 0,  3, 3, 13, 7, 62
  };
  const int q4081[] = {
    9, 9, // Number of jobs and machines
    0, 45, 1, 96, 2, 38, 6, 49, 8, 41, 4, 79, 3,  8, 5, 39, 7, 29, 
    8, 91, 6, 93, 1, 26, 5, 88, 0, 83, 4, 12, 3, 92, 7, 53, 2, 68, 
    3,  3, 4,  5, 2, 72, 5, 43, 1, 61, 0, 41, 6, 72, 8, 23, 7, 27, 
    5, 68, 6, 68, 1, 63, 0, 45, 2, 53, 7, 60, 4, 54, 8, 44, 3, 62, 
    2, 37, 6, 82, 8, 21, 0,  7, 4, 91, 5, 56, 7, 13, 3, 96, 1, 33, 
    5,  4, 8, 41, 1, 58, 4, 48, 2,  2, 6, 26, 0, 81, 7, 13, 3, 95, 
    2, 78, 8, 56, 1, 62, 0, 51, 7, 85, 3, 75, 5, 35, 4, 28, 6, 25, 
    7, 61, 2,  8, 8,  2, 5, 37, 0, 63, 4, 56, 6, 47, 3, 78, 1, 36, 
    7, 26, 0, 50, 6, 25, 1, 94, 4, 56, 2, 64, 3, 14, 8, 68, 5, 74
  };
  const int q4082[] = {
    9, 9, // Number of jobs and machines
    4, 33, 6,  9, 3, 98, 7,  5, 2, 54, 8, 51, 1, 52, 5, 54, 0, 17, 
    1, 72, 3, 17, 6,  4, 0, 60, 2, 37, 7, 46, 5, 10, 4, 89, 8, 88, 
    1,  7, 2, 37, 5, 66, 8, 47, 4, 85, 3, 99, 6, 81, 7, 95, 0, 40, 
    1, 33, 0, 22, 2, 39, 8, 33, 7, 11, 3, 85, 6, 37, 5, 47, 4, 40, 
    2, 51, 8,  2, 7, 42, 0, 56, 5, 61, 6, 91, 1, 47, 4,  5, 3, 97, 
    3, 69, 0, 74, 5, 29, 2,  6, 4, 38, 1, 95, 7, 90, 8, 71, 6, 51, 
    8, 30, 7,  2, 3, 94, 2, 64, 5,  3, 0, 64, 6, 47, 4, 13, 1, 54, 
    1, 57, 2, 37, 7, 71, 6, 38, 8, 84, 0, 28, 3, 92, 5, 72, 4, 79, 
    8, 10, 4, 20, 3, 46, 6, 33, 7,  2, 5, 33, 0, 62, 2, 48, 1, 27
  };
  const int q4083[] = {
    9, 9, // Number of jobs and machines
    3, 54, 0, 67, 7, 38, 4, 81, 5, 57, 1, 41, 8, 48, 6,  6, 2,  8, 
    4, 84, 0, 99, 2, 73, 7, 85, 8, 95, 5, 41, 3, 29, 1, 26, 6, 46, 
    7, 18, 2, 89, 0, 18, 6, 14, 5, 81, 8, 35, 3, 21, 4, 66, 1, 37, 
    8, 12, 7, 92, 3, 85, 4, 27, 6, 69, 0, 73, 1, 77, 2,  4, 5, 96, 
    5,  8, 2, 77, 6,  5, 8, 38, 7, 92, 3, 22, 1, 17, 0, 53, 4, 91, 
    1, 14, 7, 87, 4, 14, 2,  4, 6, 33, 5, 73, 8, 82, 3, 33, 0, 16, 
    2, 68, 3, 74, 1, 23, 6, 61, 7, 69, 4, 41, 8, 38, 5, 89, 0, 58, 
    3, 64, 4, 97, 1, 79, 0, 32, 2, 44, 6, 57, 8, 22, 5, 32, 7, 27, 
    3, 15, 6,  5, 8, 76, 4, 72, 2, 15, 1,  7, 0, 65, 5, 39, 7, 74
  };
  const int q4084[] = {
    9, 9, // Number of jobs and machines
    8,  9, 4, 96, 3, 59, 0, 48, 6, 18, 2, 82, 7, 45, 5, 25, 1, 84, 
    3, 25, 2, 79, 7, 75, 8, 95, 6, 59, 1, 52, 5, 37, 4, 84, 0, 70, 
    8, 66, 4, 71, 0, 63, 3, 23, 1, 54, 2,  1, 5, 73, 7, 78, 6, 80, 
    4, 12, 7, 11, 0, 57, 3, 27, 5, 41, 2, 77, 1, 46, 6, 26, 8, 96, 
    0, 82, 4, 82, 8, 67, 6, 47, 7, 98, 2, 96, 3, 70, 1, 12, 5, 74, 
    4, 93, 0, 78, 7, 72, 1, 21, 2, 71, 5, 12, 8, 76, 3, 53, 6, 82, 
    3,  4, 7, 99, 4, 92, 8, 43, 0, 21, 1, 73, 6, 22, 5, 14, 2,  4, 
    5,  4, 0, 18, 6, 31, 2, 62, 1, 81, 3, 94, 4, 91, 8, 71, 7, 37, 
    6, 65, 3, 54, 1,  7, 0, 50, 8, 67, 4, 23, 5, 31, 2, 26, 7, 80
  };
  const int q4085[] = {
    9, 9, // Number of jobs and machines
    8, 28, 1,  3, 0, 63, 5, 34, 3, 50, 7, 74, 4, 75, 6, 54, 2, 23, 
    5, 73, 6, 11, 2, 36, 0, 42, 4, 99, 1, 69, 8, 17, 7, 25, 3, 71, 
    4, 58, 1, 24, 2, 59, 7, 99, 3, 11, 8, 62, 0,  3, 6,  6, 5, 82, 
    4, 87, 0, 59, 2, 53, 6, 31, 7, 96, 8, 53, 5,  8, 1, 37, 3, 21, 
    1, 81, 2, 86, 4,  1, 6, 60, 7, 73, 5, 19, 8, 21, 3, 99, 0, 48, 
    1, 83, 7, 31, 5, 59, 2, 69, 8, 15, 4, 50, 6, 64, 0,  2, 3, 53, 
    4, 12, 8, 24, 1, 23, 6, 14, 0, 35, 2, 83, 5, 82, 3, 98, 7,  4, 
    7,  8, 1, 48, 8, 26, 5, 54, 6,  2, 2, 59, 3, 19, 0, 80, 4, 16, 
    4, 11, 3,  9, 7, 93, 1, 42, 0, 34, 2, 72, 5, 60, 8, 85, 6, 83
  };
  const int q4086[] = {
    9, 9, // Number of jobs and machines
    5, 11, 7, 93, 3, 15, 1, 76, 0, 26, 2, 37, 4, 26, 6, 38, 8, 61, 
    4, 70, 5, 97, 1, 29, 8, 10, 7, 91, 0, 18, 2, 17, 3, 78, 6, 93, 
    2, 77, 6, 62, 5, 49, 8, 45, 7, 90, 3, 58, 0, 79, 4, 85, 1, 69, 
    4, 47, 0, 29, 5, 67, 1, 31, 8,  4, 6, 31, 7, 42, 3, 30, 2,  6, 
    2, 39, 7, 83, 1, 80, 0, 57, 6, 48, 4, 72, 5, 66, 8, 42, 3, 41, 
    2, 86, 3, 11, 1, 77, 8, 38, 6, 27, 5, 37, 4, 54, 7, 37, 0, 14, 
    3, 50, 6, 11, 0, 13, 2, 92, 5, 36, 8, 13, 1, 34, 7, 47, 4, 59, 
    8, 74, 4, 56, 7, 56, 0, 18, 3, 67, 5, 49, 2, 84, 6, 21, 1, 47, 
    4, 69, 7, 94, 8, 70, 3,  5, 6, 98, 2,  4, 5, 22, 1, 99, 0, 96
  };
  const int q4087[] = {
    9, 9, // Number of jobs and machines
    4, 25, 3, 32, 7, 32, 8, 82, 0, 95, 2, 88, 6, 29, 1, 17, 5, 95, 
    5, 41, 3, 43, 6,  8, 0, 53, 1,  8, 8, 62, 4, 57, 7, 24, 2, 66, 
    5, 30, 7, 58, 8,  8, 2, 24, 3, 22, 6,  8, 1, 81, 4,  4, 0, 82, 
    4, 90, 8, 80, 6, 11, 5, 40, 3, 50, 2, 64, 1, 36, 7, 89, 0, 69, 
    0, 70, 7, 83, 2, 76, 1, 53, 4, 22, 5, 89, 3, 19, 6, 81, 8, 26, 
    2, 84, 5, 98, 8, 34, 6,  6, 3, 79, 1, 50, 7, 35, 4, 34, 0, 97, 
    4, 64, 5, 73, 3, 78, 7, 86, 2, 23, 6, 13, 1, 46, 0, 98, 8, 80, 
    5, 22, 3, 85, 6, 27, 8, 39, 7, 96, 2, 42, 1, 35, 0, 14, 4, 46, 
    8, 33, 0, 60, 4, 32, 7, 13, 5, 46, 2, 16, 6, 17, 3,  8, 1, 75
  };
  const int q4088[] = {
    9, 9, // Number of jobs and machines
    7, 73, 5, 43, 1, 30, 2, 91, 3, 93, 4, 89, 0, 68, 6, 25, 8, 84, 
    3, 44, 8, 88, 1, 40, 6, 77, 4, 79, 5, 76, 0, 21, 7, 70, 2, 65, 
    6, 40, 3, 82, 4, 60, 7, 60, 1, 13, 2, 28, 0, 36, 8, 26, 5, 83, 
    6, 88, 8, 75, 4, 66, 2, 18, 0, 25, 5, 44, 3, 81, 7, 33, 1, 47, 
    6, 81, 3, 53, 8, 28, 1, 14, 0, 73, 5, 18, 7, 98, 4,  6, 2, 10, 
    6, 97, 5, 51, 3, 61, 4, 93, 0, 72, 2, 14, 7, 76, 8,  2, 1, 22, 
    7,  2, 6, 24, 4, 70, 1, 33, 3, 52, 0, 24, 5, 32, 2,  5, 8, 22, 
    0, 16, 3, 15, 2, 41, 7, 58, 6, 83, 8, 59, 4, 73, 5, 71, 1, 95, 
    3, 35, 6, 54, 2, 67, 5, 44, 0, 51, 4, 14, 1, 37, 8, 15, 7, 85
  };
  const int q4089[] = {
    9, 9, // Number of jobs and machines
    8, 67, 4, 56, 7, 52, 2, 28, 3, 18, 5, 98, 1, 79, 0, 49, 6,  9, 
    5, 67, 2, 75, 1, 25, 3, 31, 8, 97, 7, 12, 6, 59, 4, 62, 0, 60, 
    4, 95, 6, 30, 1, 80, 0,  4, 8, 56, 2, 38, 7,  5, 3, 89, 5, 57, 
    7, 71, 4, 84, 5,  5, 0, 71, 3, 25, 6, 53, 2, 19, 8, 69, 1, 14, 
    3, 97, 5,  9, 1, 47, 7, 92, 6, 34, 2, 31, 4, 20, 8, 50, 0, 29, 
    7, 65, 6,  8, 2, 11, 1, 45, 3, 41, 5, 66, 8, 13, 4, 68, 0, 65, 
    5, 75, 3, 62, 2, 29, 7, 57, 6,  5, 0, 79, 4, 50, 8, 28, 1, 19, 
    0, 29, 3, 40, 8, 65, 7, 26, 2, 77, 4, 37, 5, 19, 6, 29, 1, 42, 
    1, 79, 6,  9, 7, 80, 5, 12, 3, 51, 2, 46, 4, 55, 8, 80, 0, 78
  };
  const int q4090[] = {
    9, 9, // Number of jobs and machines
    0, 75, 4, 21, 2, 14, 7,  9, 5, 59, 8, 49, 6, 48, 1, 14, 3, 58, 
    1, 23, 0, 51, 7, 89, 3, 40, 5, 83, 4, 93, 2, 34, 8, 89, 6, 23, 
    1, 52, 6, 96, 2, 45, 0, 48, 7, 31, 5, 80, 4, 23, 8, 30, 3, 18, 
    5, 79, 0, 39, 1, 49, 4, 49, 6, 41, 2, 38, 3, 15, 8, 79, 7, 76, 
    4, 66, 3, 70, 8,  7, 6,  2, 1,  9, 0,  4, 2, 95, 7, 77, 5, 80, 
    3, 83, 7, 62, 8,  7, 2, 67, 6, 76, 1, 93, 4, 33, 0, 81, 5, 58, 
    1, 61, 3, 72, 0, 45, 4, 62, 2, 59, 5, 39, 7, 36, 6, 43, 8, 11, 
    7, 50, 8, 43, 5, 72, 1, 46, 0, 58, 3, 13, 6, 52, 4, 60, 2, 34, 
    3, 19, 6, 94, 8, 60, 2, 53, 5, 72, 0, 23, 7,  4, 4,  8, 1, 33
  };
  const int q4091[] = {
    9, 9, // Number of jobs and machines
    8, 34, 5,  5, 1, 24, 3, 18, 2, 45, 4, 65, 0, 17, 7, 27, 6, 82, 
    3, 88, 4, 47, 1, 24, 7, 59, 5,  2, 8, 27, 6, 93, 0, 70, 2, 49, 
    8, 29, 6, 96, 2, 91, 4, 77, 0,  3, 1, 45, 7, 63, 3, 74, 5, 68, 
    5, 53, 1, 86, 7, 73, 4, 99, 3, 18, 2, 18, 6, 48, 8, 58, 0, 18, 
    4, 45, 1, 53, 0, 68, 3,  3, 6, 30, 8, 86, 5, 59, 7, 39, 2, 64, 
    7, 59, 1, 43, 8, 80, 4, 68, 5, 25, 2, 72, 0, 14, 6, 89, 3, 11, 
    6, 25, 1, 53, 5, 13, 7,  8, 2,  4, 8, 56, 4, 97, 3, 64, 0, 77, 
    7, 70, 5, 69, 3, 55, 2, 24, 8, 37, 6, 13, 4, 99, 1, 60, 0, 23, 
    5, 66, 0, 17, 4, 79, 2, 34, 1, 57, 3, 73, 7, 86, 8, 71, 6, 12
  };
  const int q4092[] = {
    9, 9, // Number of jobs and machines
    1, 16, 2, 17, 3, 98, 5, 31, 4,  2, 7, 53, 0, 63, 6, 22, 8, 20, 
    2, 98, 5, 61, 7, 16, 1, 57, 3, 13, 6, 16, 0, 58, 8, 84, 4, 63, 
    0, 84, 7, 52, 2, 99, 5, 15, 3, 65, 8, 52, 6, 55, 1, 67, 4, 74, 
    7, 23, 1, 82, 0, 83, 2, 40, 4, 78, 8, 91, 3, 13, 6, 52, 5, 77, 
    6, 81, 8, 91, 0, 92, 4, 34, 7, 91, 5, 22, 1, 56, 2, 66, 3, 98, 
    8, 54, 5, 46, 6, 40, 7, 72, 2,  4, 0, 73, 1, 92, 3, 99, 4, 17, 
    4, 14, 7, 59, 3, 44, 6, 33, 0, 43, 8, 87, 2, 55, 1, 46, 5, 62, 
    5, 43, 4, 74, 0, 62, 1, 76, 7,  5, 8,  7, 6, 41, 3, 13, 2, 32, 
    5, 50, 3, 42, 2, 69, 6, 84, 1, 94, 7, 89, 8, 71, 0, 90, 4, 47
  };
  const int q4093[] = {
    9, 9, // Number of jobs and machines
    3,  2, 0, 81, 2, 46, 4, 20, 8, 24, 5, 69, 7, 31, 1, 78, 6, 25, 
    0, 11, 6, 79, 7, 97, 3, 27, 8, 77, 4, 10, 2, 91, 1, 43, 5, 30, 
    1, 23, 8, 43, 2, 46, 6, 37, 7, 43, 4, 30, 5, 61, 0, 81, 3, 32, 
    2,  8, 0, 37, 1, 65, 6, 57, 5, 24, 7, 76, 3, 13, 4, 16, 8,  2, 
    7, 55, 5, 91, 1, 85, 3, 99, 6, 32, 0, 72, 8,  5, 4, 67, 2, 96, 
    4, 12, 8, 46, 7, 49, 3, 45, 5, 40, 6, 24, 0, 90, 2, 10, 1, 65, 
    7, 13, 8, 64, 5, 94, 1, 28, 4, 49, 3, 13, 2, 62, 6, 48, 0, 56, 
    7, 87, 4, 42, 0, 22, 5, 51, 1, 40, 2, 12, 8, 78, 6, 76, 3, 32, 
    7, 55, 5, 98, 8,  8, 0, 51, 6, 18, 2, 51, 1, 82, 4, 85, 3,  4
  };
  const int q4094[] = {
    9, 9, // Number of jobs and machines
    3, 42, 1, 12, 5, 91, 8, 90, 7, 48, 6, 99, 2,  9, 0, 25, 4, 57, 
    3, 73, 7, 98, 6,  6, 1, 48, 0, 98, 5, 41, 4, 89, 2, 32, 8, 28, 
    8, 34, 3, 48, 2, 19, 6, 58, 1,  5, 4, 92, 0, 10, 7, 55, 5, 77, 
    6, 91, 3, 16, 4, 73, 5, 51, 7, 59, 0, 79, 2, 24, 1, 22, 8, 34, 
    7, 52, 2, 81, 1, 48, 3, 76, 4, 22, 8, 38, 5, 26, 6, 29, 0, 81, 
    3, 69, 5, 17, 1, 29, 0, 26, 7, 31, 2, 36, 4, 38, 8, 95, 6, 95, 
    6, 31, 0, 92, 8, 73, 7, 13, 2,  9, 3, 68, 5, 79, 1, 75, 4, 68, 
    6, 14, 3, 27, 5, 36, 7, 34, 8, 56, 0, 72, 4, 75, 1, 39, 2, 19, 
    5, 57, 0, 85, 6, 11, 7, 42, 3, 50, 1, 36, 8,  4, 4, 33, 2, 11
  };
  const int q4095[] = {
    9, 9, // Number of jobs and machines
    2,  5, 1, 19, 6, 29, 5, 45, 3, 63, 0,  1, 7, 63, 8, 84, 4, 20, 
    1, 19, 5, 22, 2, 33, 0, 93, 3, 27, 8, 67, 6, 19, 7, 40, 4, 46, 
    2, 33, 4, 98, 0, 91, 6, 74, 7, 41, 3, 96, 8, 68, 1, 59, 5, 47, 
    8, 85, 5,  7, 3, 66, 1, 66, 4, 86, 7, 63, 2, 80, 6, 64, 0, 10, 
    6,  7, 5, 29, 7, 91, 8, 94, 3, 45, 2, 86, 1, 87, 4,  5, 0, 37, 
    7, 51, 2, 47, 3, 27, 6, 93, 8, 99, 1, 63, 4, 67, 0, 66, 5, 78, 
    6, 94, 1, 35, 2, 82, 8, 52, 3, 92, 4, 22, 5,  8, 7, 87, 0, 47, 
    0, 90, 7,  4, 5,  6, 8, 19, 1, 68, 6, 17, 2, 92, 3, 38, 4, 33, 
    1,  1, 8, 17, 7, 52, 6, 16, 5, 84, 4, 19, 0, 42, 3, 11, 2, 58
  };
  const int q4096[] = {
    9, 9, // Number of jobs and machines
    2, 94, 5, 74, 3, 39, 1, 95, 8, 67, 0, 74, 7, 62, 6, 14, 4, 48, 
    7, 42, 1, 34, 0, 49, 5, 76, 4, 48, 2, 32, 6, 90, 8, 69, 3, 54, 
    4, 41, 3, 50, 1, 43, 6, 97, 8, 19, 2, 97, 7, 33, 5, 98, 0, 89, 
    1,  5, 5, 85, 0, 89, 4, 20, 2, 99, 3, 43, 8, 57, 7, 91, 6, 20, 
    1, 18, 7, 71, 3, 71, 6, 81, 4, 65, 0, 78, 8, 11, 2, 14, 5, 40, 
    2, 14, 8, 74, 0, 90, 4, 49, 7, 42, 1, 34, 6, 42, 3, 39, 5, 59, 
    6, 24, 1, 72, 7,  2, 8, 25, 2, 48, 0, 71, 3, 66, 5, 44, 4, 39, 
    1, 89, 3, 53, 4, 79, 0,  6, 2, 81, 5, 34, 7, 91, 8, 21, 6, 29, 
    6, 68, 5, 87, 1, 11, 3, 18, 7,  6, 8, 59, 0, 18, 2, 12, 4, 68
  };
  const int q4097[] = {
    9, 9, // Number of jobs and machines
    1, 56, 6, 15, 7, 29, 3, 92, 5, 53, 4, 22, 0, 49, 2, 47, 8, 84, 
    8, 86, 2, 47, 3, 43, 1, 39, 0, 56, 5, 95, 4, 30, 6, 98, 7,  8, 
    8,  1, 7, 34, 3, 16, 4, 15, 5, 41, 1, 58, 6,  4, 0, 66, 2, 71, 
    2, 73, 4, 13, 1, 29, 5, 69, 0, 68, 7, 82, 6, 35, 3, 20, 8, 16, 
    0,  8, 1, 15, 4, 87, 2, 23, 8, 40, 7, 95, 6, 38, 5, 23, 3, 45, 
    3,  1, 2, 86, 0, 38, 8, 68, 5, 62, 6, 74, 1, 20, 4, 29, 7, 48, 
    4, 39, 6, 26, 5, 77, 1, 83, 2, 16, 7, 34, 0,  4, 8, 15, 3, 45, 
    0, 72, 7, 95, 1,  8, 3, 62, 2, 98, 4, 48, 8, 67, 5, 49, 6, 22, 
    3, 86, 8, 19, 5, 93, 0, 54, 7, 10, 1, 69, 2, 36, 4, 64, 6, 91
  };
  const int q4098[] = {
    9, 9, // Number of jobs and machines
    0, 87, 8, 55, 1, 23, 5, 47, 2, 70, 4, 60, 3, 52, 6, 19, 7,  1, 
    7, 87, 1, 59, 0, 12, 5, 99, 8, 34, 3, 10, 6, 90, 2, 89, 4, 38, 
    2, 81, 8, 62, 3, 10, 5, 72, 4, 13, 6, 54, 1, 23, 7, 56, 0, 98, 
    0, 47, 4,  5, 2, 87, 7, 57, 3, 82, 6, 90, 8, 60, 5, 84, 1, 75, 
    1, 44, 4, 39, 8, 94, 0, 85, 3, 46, 2, 42, 6, 68, 5, 57, 7, 19, 
    0, 56, 1, 46, 5, 58, 8, 27, 7, 18, 2, 73, 4, 50, 6, 87, 3, 61, 
    6, 69, 7, 62, 2,  1, 4, 21, 8,  4, 5, 76, 0, 79, 1, 65, 3, 75, 
    0, 22, 2, 30, 7,  1, 8, 88, 3, 56, 4, 81, 6, 81, 5, 65, 1, 82, 
    6,  3, 1, 73, 2, 42, 0, 36, 7, 34, 3, 42, 4, 40, 5, 70, 8, 89
  };
  const int q4099[] = {
    9, 9, // Number of jobs and machines
    6, 89, 1, 61, 0,  3, 2, 76, 4, 59, 8, 34, 3, 67, 5, 67, 7,  3, 
    0, 18, 5, 12, 6, 99, 7, 50, 2,  7, 4, 99, 1, 49, 8, 22, 3, 38, 
    1, 43, 3, 25, 6, 39, 4, 73, 7, 29, 2, 50, 0, 59, 5, 75, 8, 61, 
    5, 54, 0, 75, 8, 62, 7, 30, 2, 47, 4, 11, 1, 30, 6, 46, 3, 38, 
    6, 71, 5, 53, 8, 32, 3, 19, 4, 69, 1,  5, 0, 82, 2, 62, 7, 75, 
    8, 41, 7, 84, 2, 42, 4, 93, 6, 63, 0,  6, 5, 77, 1, 42, 3, 40, 
    3, 81, 1, 31, 0, 90, 6, 30, 2, 34, 7, 11, 8, 16, 5, 31, 4, 64, 
    3, 20, 5, 76, 6, 32, 1, 53, 0, 97, 8, 46, 4, 44, 7, 59, 2, 67, 
    1, 12, 3,  1, 6, 67, 2, 85, 8, 88, 5, 93, 4, 74, 7,  1, 0, 56
  };
  const int q4100[] = {
    9, 9, // Number of jobs and machines
    8, 86, 4, 89, 1, 71, 6, 29, 0, 65, 3, 75, 5, 10, 2, 47, 7, 28, 
    3, 93, 2, 47, 7, 89, 0, 42, 1, 40, 6, 21, 5, 13, 8,  4, 4, 71, 
    2, 70, 1, 80, 8, 18, 5, 90, 7, 76, 6, 49, 4, 54, 0, 45, 3,  6, 
    1, 47, 4, 96, 3, 74, 8,  5, 5, 66, 6, 89, 0, 10, 7,  9, 2, 32, 
    7, 90, 8, 95, 4, 38, 3, 75, 2, 23, 0, 21, 1, 92, 5, 38, 6, 34, 
    6, 87, 1, 15, 3, 34, 4, 57, 7, 98, 8, 31, 2, 14, 5, 33, 0, 67, 
    6, 74, 0, 55, 2, 25, 8, 74, 5, 54, 4, 52, 1, 37, 3, 10, 7, 12, 
    5, 90, 2, 65, 1,  1, 6,  9, 4, 52, 0, 52, 7, 70, 3, 58, 8, 26, 
    0, 41, 2, 41, 8, 32, 1, 18, 5,  4, 7, 45, 6, 89, 3, 46, 4, 97
  };
  const int q4101[] = {
    9, 9, // Number of jobs and machines
    6, 56, 1, 27, 8, 47, 3, 55, 2, 11, 4, 15, 7, 35, 5, 37, 0, 62, 
    3,  3, 7,  1, 2, 76, 5, 15, 1, 99, 8, 30, 0, 72, 4, 51, 6, 58, 
    8, 90, 4, 85, 1, 44, 5, 13, 0, 62, 6, 92, 2, 53, 7, 90, 3, 51, 
    4,  5, 0, 94, 3, 14, 2, 64, 7,  9, 6,  7, 1, 62, 8, 81, 5, 29, 
    6, 63, 2, 51, 0, 60, 4, 95, 7, 24, 8, 92, 3, 70, 5, 42, 1, 38, 
    3, 79, 7, 77, 5, 34, 4, 44, 0, 11, 2, 23, 6, 24, 1,  3, 8,  5, 
    7, 95, 5,  2, 1, 77, 2, 42, 3, 76, 8, 67, 0, 47, 4, 72, 6, 37, 
    3, 40, 2, 24, 1,  9, 4, 99, 5, 51, 7, 24, 0, 32, 8, 95, 6, 56, 
    0, 59, 8, 17, 6, 31, 4, 47, 5, 73, 2, 23, 3, 52, 1, 29, 7, 27
  };
  const int q4102[] = {
    9, 9, // Number of jobs and machines
    5, 56, 8, 26, 0, 88, 1, 20, 6, 68, 2, 53, 7, 79, 4, 12, 3, 69, 
    6, 36, 7, 22, 0,  4, 2, 75, 3, 33, 1, 94, 5,  8, 4, 29, 8, 18, 
    2,  7, 5, 60, 0, 56, 3, 16, 1, 37, 7, 59, 8, 37, 6, 10, 4, 60, 
    5, 80, 4, 19, 2,  6, 6, 36, 0, 21, 7, 37, 1, 72, 3, 45, 8, 94, 
    7, 29, 1, 72, 2, 64, 4, 73, 6, 89, 3,  8, 8, 22, 0, 35, 5, 75, 
    8, 90, 3, 36, 4, 46, 5, 34, 1, 46, 6, 90, 2, 24, 0, 12, 7, 91, 
    6, 75, 8, 34, 7, 26, 1, 68, 4, 98, 0, 16, 3,  8, 2, 29, 5, 35, 
    2, 48, 7,  2, 5, 27, 6, 46, 3, 22, 0, 89, 1, 57, 4, 32, 8, 92, 
    6, 92, 0, 42, 8, 44, 7, 10, 5, 21, 2, 22, 3, 30, 4, 71, 1, 13
  };
  const int q4103[] = {
    9, 9, // Number of jobs and machines
    0, 55, 4, 35, 5, 75, 3, 24, 7, 61, 2, 48, 8, 30, 1, 44, 6, 15, 
    2, 60, 6, 85, 1, 69, 7, 86, 3, 85, 4,  7, 8, 47, 0,  2, 5, 80, 
    6, 44, 0, 29, 2, 43, 5, 97, 4, 87, 3, 62, 8, 67, 1, 85, 7, 11, 
    5, 83, 3, 79, 2,  2, 6, 37, 7, 10, 0, 91, 1, 46, 8, 22, 4, 16, 
    3, 14, 4, 66, 8, 20, 1, 53, 0, 99, 6, 66, 2, 23, 5, 21, 7, 97, 
    6, 32, 4, 24, 3, 49, 8, 62, 7, 95, 5, 35, 1, 19, 0, 37, 2, 69, 
    5, 98, 6, 83, 3, 25, 1, 83, 0, 23, 8, 27, 2, 90, 4, 78, 7, 33, 
    1, 62, 7, 62, 4, 93, 3, 68, 5, 53, 6, 16, 8, 53, 2, 24, 0, 79, 
    4, 10, 0, 67, 7,  4, 6, 44, 3, 11, 5,  4, 2, 82, 8,  4, 1, 82
  };
  const int q4104[] = {
    9, 9, // Number of jobs and machines
    8,  9, 3, 19, 4, 61, 6,  7, 0, 78, 2,  2, 5, 48, 1,  3, 7, 45, 
    2, 50, 6, 75, 1, 73, 5,  6, 8, 18, 0, 96, 3, 99, 4, 76, 7, 90, 
    0, 91, 4, 31, 7, 45, 2, 87, 6, 86, 3, 83, 1,  2, 8,  5, 5, 66, 
    4,  2, 7, 48, 1, 75, 5, 42, 2, 67, 3, 82, 6, 57, 8, 85, 0, 17, 
    0, 33, 8, 41, 6, 69, 2,  1, 1, 19, 7, 25, 4, 89, 5, 44, 3, 87, 
    4, 92, 6,  4, 1, 61, 2, 67, 8,  5, 3, 18, 7, 80, 0, 45, 5, 17, 
    2, 29, 5, 56, 4, 42, 7, 63, 3, 14, 8, 51, 0,  9, 6, 31, 1,  7, 
    8, 83, 7, 27, 0, 43, 4, 50, 6,  7, 2, 23, 3, 84, 5, 40, 1, 51, 
    8, 73, 5, 57, 6, 83, 3,  8, 1, 51, 4,  8, 0, 99, 2, 95, 7, 84
  };
  const int q4105[] = {
    9, 9, // Number of jobs and machines
    6, 79, 5, 58, 3, 20, 7, 18, 1, 50, 8, 76, 0, 42, 2, 58, 4, 40, 
    1, 65, 8, 79, 2, 70, 4, 58, 7, 65, 3, 77, 0,  8, 6, 47, 5, 66, 
    2, 74, 7, 57, 4, 90, 1, 82, 0, 17, 8, 13, 5, 33, 6, 88, 3, 91, 
    0, 16, 6,  7, 5,  5, 3, 99, 8, 51, 1, 37, 2, 38, 4, 61, 7,  8, 
    1, 85, 6, 84, 5,  6, 3, 32, 2, 80, 7, 35, 8, 96, 0, 49, 4, 34, 
    3, 62, 8, 37, 5, 43, 1, 98, 6, 21, 4, 97, 7, 13, 0, 58, 2, 43, 
    7, 39, 4, 80, 6, 10, 8, 71, 1, 51, 5,  3, 2, 89, 0, 19, 3,  7, 
    4,  8, 3, 37, 0, 24, 2, 92, 5, 17, 7, 76, 8, 85, 6, 24, 1, 83, 
    6, 27, 3, 68, 0, 12, 2, 70, 8, 39, 4,  8, 1, 28, 5, 92, 7, 40
  };
  const int q4106[] = {
    9, 9, // Number of jobs and machines
    3, 31, 5, 48, 0, 57, 7, 56, 8, 89, 2, 57, 6, 26, 4, 84, 1, 81, 
    5, 73, 2, 54, 8,  1, 0, 12, 6, 15, 3, 49, 1, 47, 7, 95, 4, 27, 
    4, 42, 1, 97, 6, 50, 8, 52, 5, 48, 7, 11, 2, 88, 3,  9, 0, 60, 
    2,  7, 7, 17, 6, 38, 8, 77, 3, 11, 1, 74, 0, 48, 5, 45, 4, 20, 
    5,  3, 2, 41, 8, 56, 7, 55, 3, 70, 1, 60, 6,  8, 4, 99, 0, 37, 
    0, 96, 8, 23, 4, 93, 7, 43, 5, 18, 3, 50, 2, 21, 1, 46, 6, 63, 
    2, 14, 3, 48, 7, 83, 5, 36, 6, 50, 8, 97, 1, 79, 4, 59, 0, 98, 
    8, 93, 6, 37, 5, 92, 1,  6, 3, 65, 4, 76, 0, 76, 7, 15, 2, 50, 
    7, 58, 6, 59, 2, 71, 1, 62, 3,  9, 5, 69, 8, 16, 4,  3, 0, 69
  };
  const int q4107[] = {
    9, 9, // Number of jobs and machines
    6,  2, 8, 39, 2, 20, 3, 82, 1, 39, 7,  1, 0, 62, 4, 51, 5, 19, 
    1, 35, 7, 67, 8,  6, 0, 15, 3, 27, 4, 93, 5, 32, 6, 52, 2, 46, 
    4, 51, 5, 79, 2,  1, 6, 92, 3, 58, 8, 67, 7, 58, 0, 47, 1, 77, 
    6, 26, 5, 46, 1,  2, 2, 94, 4, 89, 8,  5, 3, 88, 0, 47, 7,  6, 
    7, 34, 0, 21, 6,  9, 1, 19, 5, 38, 3, 67, 2, 69, 8,  4, 4, 94, 
    3, 61, 5, 79, 0, 84, 8, 27, 4, 78, 2, 39, 6, 35, 7, 56, 1, 64, 
    5, 74, 1, 37, 6, 93, 0, 47, 7,  6, 4, 11, 2, 36, 8, 75, 3, 60, 
    8,  8, 5, 78, 3, 11, 1, 27, 4, 26, 7, 33, 0, 54, 2, 40, 6, 48, 
    2,  9, 5, 18, 3, 10, 4, 16, 8, 80, 7, 12, 6, 13, 0, 15, 1, 85
  };
  const int q4108[] = {
    9, 9, // Number of jobs and machines
    2, 10, 7, 90, 0, 96, 6, 92, 4, 45, 8, 80, 5, 51, 1, 37, 3, 55, 
    0, 22, 2, 15, 7, 45, 6, 47, 8, 34, 1, 33, 4, 95, 3, 22, 5, 92, 
    3, 29, 6, 18, 0, 74, 8, 87, 4, 75, 1, 17, 5, 77, 2, 36, 7, 45, 
    3, 29, 6, 44, 8, 31, 4, 90, 7, 43, 0,  9, 1, 71, 2, 30, 5, 18, 
    0, 79, 8,  2, 4, 63, 3, 70, 6, 75, 1, 30, 7, 11, 5, 37, 2, 28, 
    0, 92, 5,  7, 3, 57, 2, 95, 7, 99, 4,  4, 6, 36, 1, 98, 8, 36, 
    5, 40, 8, 22, 1, 61, 7, 64, 4, 33, 6, 43, 2, 93, 0, 60, 3, 52, 
    8, 59, 4, 96, 6, 84, 1, 88, 5,  4, 2, 26, 3, 96, 7, 35, 0, 52, 
    5, 90, 3, 68, 0, 55, 4, 17, 1, 12, 7, 83, 6, 79, 2,  4, 8, 85
  };
  const int q4109[] = {
    9, 9, // Number of jobs and machines
    7, 23, 5, 50, 3, 73, 1, 36, 0, 44, 6, 73, 4, 59, 8, 83, 2, 13, 
    4, 33, 8, 62, 1, 72, 2, 50, 6, 95, 3, 65, 0, 21, 5, 79, 7, 51, 
    7, 41, 3, 34, 5, 13, 4, 24, 2, 23, 0, 94, 1, 28, 6, 79, 8, 92, 
    8, 92, 2, 65, 6, 84, 1, 57, 0, 43, 4,  9, 5, 14, 3, 61, 7, 44, 
    0, 31, 6, 18, 7, 21, 1, 93, 2, 48, 4, 71, 5, 47, 3, 61, 8, 63, 
    2, 45, 8, 42, 4, 12, 0, 58, 5, 69, 3, 68, 1, 63, 7,  6, 6, 20, 
    0, 26, 4, 40, 3, 22, 7, 50, 1, 15, 5, 49, 8, 71, 2, 14, 6, 19, 
    1, 93, 8, 47, 5, 88, 0, 23, 3,  1, 6, 12, 7, 58, 2, 70, 4, 89, 
    7, 13, 8, 54, 3, 24, 4, 81, 1, 18, 0, 63, 5, 68, 6, 25, 2, 29
  };
  const int q4110[] = {
    9, 9, // Number of jobs and machines
    8, 13, 1, 57, 4, 94, 7,  6, 3, 45, 2, 82, 0, 27, 5, 11, 6, 44, 
    3, 53, 0, 59, 7, 68, 6, 85, 2, 63, 1, 34, 4, 25, 8,  4, 5, 19, 
    4,  7, 7,  6, 0, 12, 6, 77, 3, 68, 8, 44, 5, 63, 2, 80, 1, 91, 
    8, 33, 2, 21, 3, 89, 7, 58, 4, 53, 0, 94, 5, 81, 6, 82, 1, 45, 
    8, 91, 2, 40, 4, 85, 5, 42, 6, 42, 7, 79, 3, 24, 0, 80, 1, 81, 
    8, 94, 6, 59, 5,  1, 7, 16, 2, 81, 4, 90, 3, 49, 1, 58, 0, 30, 
    7,  9, 4, 32, 2, 31, 8,  5, 0, 21, 3, 91, 6, 91, 1, 55, 5, 18, 
    5, 67, 7, 30, 0, 16, 3, 11, 2, 37, 6, 16, 4, 18, 1, 42, 8, 37, 
    2, 28, 5, 95, 1,  6, 0, 13, 3,  8, 7, 10, 6, 89, 4, 12, 8, 18
  };
  const int q4111[] = {
    9, 9, // Number of jobs and machines
    1, 82, 7, 19, 2, 76, 6, 38, 8, 46, 0,  2, 4, 90, 5, 95, 3, 70, 
    0, 81, 5, 59, 6, 89, 3, 97, 2, 59, 1, 25, 7, 93, 4, 50, 8, 15, 
    0, 31, 5, 43, 6, 28, 1, 22, 4, 82, 7, 80, 8, 32, 3, 93, 2, 64, 
    8, 37, 0, 89, 4, 73, 7, 38, 2, 60, 3, 38, 5, 85, 6, 34, 1, 59, 
    3, 52, 2, 79, 4,  3, 7, 76, 6, 91, 8, 51, 1,  7, 0, 67, 5, 30, 
    3, 61, 4, 49, 0, 26, 1, 96, 2, 74, 6, 58, 8, 91, 7,  7, 5, 75, 
    3, 66, 5, 86, 2, 25, 1, 48, 6, 69, 8, 66, 4, 93, 0, 74, 7, 88, 
    6, 92, 8, 32, 0, 82, 2, 46, 4, 27, 1,  6, 7, 37, 5, 16, 3, 97, 
    1, 53, 3, 24, 8, 57, 2, 24, 7, 56, 4, 51, 5, 83, 0, 89, 6, 54
  };
  const int q4112[] = {
    9, 9, // Number of jobs and machines
    7, 81, 3, 61, 5, 39, 4, 80, 8, 99, 2, 67, 1, 18, 0, 94, 6, 83, 
    1, 34, 2,  7, 6, 59, 7, 67, 0, 42, 5, 46, 4, 38, 8, 39, 3, 72, 
    3, 25, 0, 98, 1, 27, 8, 12, 5, 99, 2,  2, 7,  1, 6, 52, 4, 54, 
    0, 60, 1, 38, 4, 97, 8, 61, 7, 53, 2, 30, 6, 83, 3, 83, 5, 62, 
    0, 46, 5, 30, 7,  7, 6, 73, 1,  9, 3, 47, 8, 93, 4, 76, 2, 55, 
    6, 22, 4, 77, 0,  1, 5, 86, 8, 90, 7, 70, 2,  8, 3, 77, 1, 18, 
    6, 29, 5, 83, 7, 43, 8, 91, 2, 36, 0, 15, 3, 73, 1, 64, 4, 73, 
    4, 90, 6, 15, 8, 92, 2, 39, 7, 85, 3, 11, 1, 92, 5, 48, 0, 36, 
    5, 58, 2, 26, 6, 71, 1, 79, 0, 58, 8, 54, 7, 67, 4, 16, 3, 56
  };
  const int q4113[] = {
    9, 9, // Number of jobs and machines
    3, 41, 4, 62, 5, 13, 6, 70, 7, 63, 2, 49, 1, 99, 8, 12, 0,  2, 
    6, 68, 4, 35, 3, 76, 0, 93, 7, 99, 2, 23, 8, 34, 1, 16, 5, 29, 
    5, 10, 3, 83, 0, 68, 2, 44, 7, 29, 8, 49, 4, 95, 6, 68, 1, 71, 
    0, 35, 6, 76, 2, 54, 5, 79, 3, 94, 7, 49, 4,  9, 8, 63, 1, 55, 
    7, 39, 3, 32, 8, 17, 4,  4, 6, 13, 1, 59, 0,  8, 5, 48, 2, 54, 
    0, 45, 8, 24, 4, 13, 7, 77, 3, 86, 5, 77, 6, 92, 1, 71, 2, 45, 
    5, 99, 7, 94, 8, 41, 2, 77, 1, 56, 0, 39, 3, 74, 4, 40, 6, 98, 
    1, 91, 8,  6, 5,  1, 2, 34, 3, 47, 0,  1, 4, 90, 7, 54, 6, 29, 
    2, 12, 5, 34, 1, 92, 6, 75, 4, 45, 0, 18, 7, 39, 3,  5, 8, 42
  };
  const int q4114[] = {
    9, 9, // Number of jobs and machines
    2, 94, 8, 64, 1, 47, 3, 80, 4, 58, 7, 13, 0, 62, 6,  3, 5, 90, 
    7, 58, 4, 10, 5, 66, 6,  5, 3, 33, 0, 90, 2, 14, 1, 95, 8, 63, 
    8, 58, 4, 24, 7, 97, 5, 10, 0, 97, 1, 16, 6, 47, 2, 73, 3, 62, 
    1, 24, 3, 98, 2, 76, 0, 32, 6, 19, 5, 80, 8,  2, 4, 22, 7, 61, 
    6, 81, 4, 84, 2, 54, 3, 47, 0, 43, 8, 55, 7,  9, 5,  2, 1, 39, 
    7, 99, 2, 35, 8, 89, 0, 60, 6, 80, 1, 40, 3,  3, 4, 58, 5, 88, 
    4, 12, 7, 91, 3, 67, 6, 42, 5, 99, 1, 92, 2, 81, 8, 46, 0, 82, 
    6, 43, 7, 25, 2, 30, 3, 43, 5, 91, 0, 72, 8, 48, 4, 28, 1, 17, 
    1, 76, 6, 74, 8, 53, 3, 25, 2, 75, 0, 34, 4, 92, 7, 40, 5, 92
  };
  const int q4115[] = {
    9, 9, // Number of jobs and machines
    8, 76, 1, 46, 4, 34, 7, 19, 2, 93, 3, 45, 6, 95, 0, 74, 5, 91, 
    5,  1, 4, 11, 3, 45, 1, 44, 0, 16, 2, 66, 8, 76, 6, 20, 7, 48, 
    7, 36, 6, 19, 5, 69, 8, 50, 2, 49, 3, 37, 0, 81, 4, 96, 1, 96, 
    6,  2, 5,  9, 1, 94, 2,  8, 4, 97, 7, 17, 3,  8, 8,  7, 0, 10, 
    1, 47, 8, 58, 3, 76, 2, 74, 0, 37, 6, 94, 5, 46, 7, 97, 4, 68, 
    3, 92, 7, 76, 0, 12, 6,  3, 5, 30, 2, 68, 1,  9, 8, 27, 4,  6, 
    3,  2, 2, 27, 7, 89, 6, 97, 4, 39, 5, 37, 1,  2, 0, 22, 8, 54, 
    4, 96, 5, 30, 0, 98, 3, 10, 7, 83, 1,  5, 6, 60, 8, 29, 2, 38, 
    5, 81, 0, 39, 8, 69, 6, 83, 7, 81, 1, 26, 4, 59, 2, 31, 3, 21
  };
  const int q4116[] = {
    9, 9, // Number of jobs and machines
    1, 61, 7,  7, 8, 97, 4, 35, 0,  2, 3, 71, 5,  3, 2, 17, 6, 28, 
    5, 95, 7, 81, 1, 46, 3, 17, 2, 53, 4, 59, 8, 21, 0, 84, 6, 37, 
    0,  8, 4, 79, 5, 24, 6, 96, 3, 55, 2, 56, 7, 43, 1, 13, 8, 23, 
    1, 18, 0, 35, 3, 55, 5,  7, 7, 38, 8, 28, 6, 61, 2, 37, 4, 79, 
    8, 66, 5, 46, 6, 11, 4, 73, 0, 87, 1, 65, 3,  6, 2,  9, 7, 59, 
    0, 29, 5, 59, 1, 91, 2, 15, 6, 63, 8, 58, 3,  8, 7, 47, 4, 55, 
    7, 44, 3, 10, 1, 99, 8, 44, 6, 30, 4, 92, 0, 89, 5, 48, 2,  2, 
    7, 99, 8,  6, 5, 97, 2, 37, 1, 14, 6, 30, 4, 65, 0, 52, 3, 86, 
    5, 65, 7, 35, 1, 13, 0, 85, 2, 61, 6,  3, 8, 48, 4,  7, 3, 29
  };
  const int q4117[] = {
    9, 9, // Number of jobs and machines
    7, 72, 5, 22, 0, 80, 3, 25, 6, 12, 4, 94, 8, 99, 1, 49, 2, 19, 
    0, 62, 4, 79, 8, 11, 6, 37, 3, 43, 7, 85, 1, 32, 5, 12, 2, 59, 
    2, 59, 8, 85, 3, 18, 6, 91, 0,  8, 4, 63, 7,  5, 5, 65, 1, 23, 
    7, 50, 2, 40, 0, 30, 8, 46, 1, 75, 6, 88, 3,  1, 4, 48, 5, 85, 
    6, 69, 4, 15, 5, 36, 7, 87, 3, 89, 0, 93, 2, 68, 8, 73, 1,  4, 
    0, 81, 5, 77, 4,  3, 3, 54, 1, 16, 2, 37, 8, 76, 7, 56, 6, 48, 
    8, 20, 0, 70, 1, 41, 2, 30, 6, 29, 3, 60, 7, 40, 5, 99, 4, 85, 
    6, 25, 0, 28, 3, 99, 7, 33, 5, 29, 1, 16, 8, 68, 4, 20, 2, 59, 
    8, 79, 0, 93, 7, 10, 5, 16, 1, 85, 2, 89, 6, 76, 4, 81, 3, 28
  };
  const int q4118[] = {
    9, 9, // Number of jobs and machines
    3, 15, 4, 84, 7, 26, 8,  8, 1, 54, 0, 79, 6, 61, 2, 22, 5, 94, 
    1,  7, 0, 27, 5, 74, 8,  3, 2, 25, 6, 42, 3, 61, 4, 71, 7, 64, 
    0, 50, 6,  3, 8, 24, 5, 12, 2, 54, 7, 34, 3, 81, 1, 96, 4, 68, 
    7, 83, 1, 26, 5, 64, 4, 91, 6, 65, 8, 61, 3, 25, 2,  7, 0, 86, 
    3, 88, 0, 80, 6, 10, 8, 44, 5, 79, 4, 22, 1, 32, 2, 22, 7, 84, 
    1, 63, 2, 15, 3, 34, 6, 51, 8,  4, 7, 21, 4, 87, 5, 69, 0, 81, 
    8, 93, 4, 95, 0, 58, 3, 50, 7, 43, 2, 76, 6, 86, 1,  8, 5, 50, 
    6, 90, 0, 79, 1, 62, 7, 70, 4, 44, 3, 95, 8, 46, 2,  4, 5, 50, 
    3, 58, 5, 84, 2, 27, 6, 50, 7, 55, 0, 21, 4, 23, 1, 99, 8, 26
  };
  const int q4119[] = {
    9, 9, // Number of jobs and machines
    4, 60, 5, 61, 6, 86, 3, 41, 1, 97, 7, 77, 2, 86, 0, 21, 8, 34, 
    2, 22, 7, 45, 5,  5, 1, 44, 3, 90, 0, 55, 6, 62, 4, 98, 8, 53, 
    4, 63, 0, 73, 6,  4, 7, 18, 3, 75, 8, 81, 5, 81, 1, 65, 2, 75, 
    2, 57, 8, 83, 0, 63, 1, 13, 4, 34, 5,  4, 6, 56, 3, 39, 7, 11, 
    6,  2, 7,  6, 3,  3, 5, 95, 1, 27, 8, 75, 4, 65, 2, 26, 0, 76, 
    5, 22, 1, 90, 3, 85, 7, 17, 4,  7, 6, 41, 0, 45, 2, 51, 8, 50, 
    3, 48, 8, 25, 2, 80, 7, 93, 6, 38, 1, 58, 5, 18, 0, 97, 4, 66, 
    0, 82, 8, 53, 3, 67, 4, 44, 5, 96, 2, 46, 6, 81, 7, 57, 1, 39, 
    1, 24, 3, 81, 6, 13, 8, 91, 5, 49, 7, 41, 0, 87, 2, 80, 4, 61
  };
  const int q4120[] = {
    9, 9, // Number of jobs and machines
    1, 17, 4, 52, 2, 61, 0, 49, 3, 85, 7, 18, 8, 32, 6, 63, 5, 33, 
    1,  5, 3, 62, 4,  3, 2, 58, 6, 87, 8, 16, 7, 21, 5, 81, 0, 95, 
    2, 63, 8, 65, 3, 62, 1, 76, 0, 89, 5, 79, 7, 57, 6,  5, 4, 94, 
    8, 76, 6,  3, 4, 42, 2, 71, 7, 11, 1, 88, 5, 76, 3,  5, 0, 92, 
    3, 88, 6,  3, 4, 92, 2, 69, 0, 66, 8, 96, 5, 58, 7, 86, 1, 76, 
    6, 71, 8,  4, 0, 10, 5, 33, 3, 59, 1,  7, 7, 66, 4, 85, 2,  7, 
    1, 46, 4, 13, 6, 22, 7,  3, 5, 91, 0,  6, 2, 64, 8, 90, 3, 84, 
    6, 75, 1, 81, 2, 40, 4, 49, 7, 60, 5, 52, 8, 55, 3, 24, 0, 63, 
    1, 72, 3, 17, 2, 63, 0,  1, 7, 10, 8, 19, 5, 31, 4,  3, 6, 42
  };
  const int q4121[] = {
    9, 9, // Number of jobs and machines
    6, 55, 5, 50, 4, 47, 0,  7, 1, 64, 7, 24, 3, 54, 8, 84, 2,  4, 
    1, 74, 6, 55, 3, 17, 7, 24, 0, 98, 5, 68, 8, 61, 2, 34, 4, 98, 
    0, 86, 4, 61, 2, 77, 6, 72, 7, 59, 3, 74, 5, 10, 8, 79, 1, 48, 
    0, 96, 8, 37, 2, 44, 6, 71, 4, 73, 1, 68, 5, 83, 7, 68, 3, 79, 
    3, 23, 2,  6, 1, 23, 4, 32, 0, 34, 7, 28, 5, 99, 6, 49, 8, 75, 
    0, 28, 2, 53, 1, 59, 4, 41, 7, 70, 5, 33, 3, 59, 6, 40, 8, 79, 
    7, 63, 3, 95, 4, 49, 8, 48, 1, 34, 0, 37, 2, 66, 5, 61, 6, 91, 
    0, 98, 8, 77, 7, 26, 3, 25, 4, 28, 1, 84, 5, 65, 2, 86, 6,  5, 
    1,  7, 7, 17, 3, 58, 8,  1, 6, 89, 4, 87, 2, 27, 0, 23, 5, 97
  };
  const int q4122[] = {
    9, 9, // Number of jobs and machines
    3, 76, 1, 32, 6, 30, 2, 71, 0, 85, 4, 74, 5, 74, 7, 79, 8, 85, 
    3,  6, 0, 10, 8, 50, 6, 53, 1, 33, 2, 50, 4, 90, 5, 12, 7, 66, 
    4,  3, 5,  7, 1, 40, 3, 61, 0, 39, 7, 34, 2, 79, 6, 54, 8, 52, 
    1,  4, 8, 51, 7, 78, 5, 54, 3, 80, 0,  2, 2, 39, 6, 85, 4, 86, 
    3, 23, 2, 64, 6, 81, 4, 50, 0, 42, 8, 58, 1, 51, 5, 66, 7, 52, 
    7, 49, 4, 75, 1, 75, 3, 93, 5, 60, 8, 72, 0, 28, 2, 27, 6, 36, 
    3, 68, 7, 89, 6, 80, 4, 14, 0, 64, 5, 91, 1, 61, 8, 62, 2, 46, 
    7, 45, 8, 72, 5, 26, 4, 75, 6, 23, 3, 64, 2, 12, 0, 87, 1, 77, 
    3, 35, 6, 22, 5, 14, 7, 57, 0, 49, 1, 35, 2, 70, 4, 82, 8, 95
  };
  const int q4123[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 25, 8, 46, 3, 94, 7, 46, 0,  3, 1, 50, 6, 14, 5, 96, 
    2, 39, 3, 55, 6, 80, 7, 12, 5, 49, 0, 93, 8, 46, 1, 21, 4, 98, 
    2, 15, 0, 23, 3, 20, 4, 35, 5, 53, 7, 18, 1, 69, 8, 62, 6, 14, 
    3, 77, 6, 27, 8, 85, 0, 98, 2,  2, 1, 83, 7, 45, 5, 48, 4, 51, 
    5, 21, 7, 23, 8, 65, 2, 21, 4, 67, 0, 79, 3, 74, 1, 86, 6, 21, 
    4, 27, 6, 30, 7, 77, 8, 99, 0, 28, 1, 59, 3, 26, 5, 16, 2, 37, 
    7, 86, 6, 83, 5, 21, 4, 55, 1, 60, 8, 92, 0, 22, 2,  9, 3, 45, 
    8, 34, 5, 27, 4, 75, 2, 58, 6, 21, 7, 50, 1, 28, 3,  6, 0, 41, 
    3, 18, 4, 78, 0, 25, 5, 70, 2, 51, 8, 73, 1, 47, 6,  3, 7, 71
  };
  const int q4124[] = {
    9, 9, // Number of jobs and machines
    3, 13, 1, 40, 4, 28, 0, 74, 8, 60, 5, 50, 7, 69, 2, 53, 6,  6, 
    6, 89, 1, 54, 3, 78, 0, 18, 5, 13, 7, 52, 4, 50, 8,  7, 2, 92, 
    7, 90, 4, 68, 3, 31, 2, 57, 0, 48, 6, 89, 1, 36, 5,  3, 8,  7, 
    2, 71, 5, 35, 4, 25, 3, 49, 0, 89, 7, 23, 8, 26, 1, 28, 6, 43, 
    2, 81, 1, 70, 6, 57, 8, 67, 7, 75, 0, 75, 3, 85, 5, 77, 4, 15, 
    4, 34, 2, 41, 1, 49, 5, 91, 7, 21, 6, 60, 0, 66, 3, 15, 8, 88, 
    6, 17, 7, 63, 1, 98, 8, 41, 0, 38, 3, 87, 2, 24, 5, 52, 4, 78, 
    7, 47, 4, 80, 6,  8, 2, 72, 5, 66, 3, 94, 8,  2, 1, 15, 0, 38, 
    1, 97, 4, 19, 6, 66, 8, 97, 7, 83, 5, 73, 0, 97, 2,  9, 3, 72
  };
  const int q4125[] = {
    9, 9, // Number of jobs and machines
    3, 97, 7, 42, 8, 54, 1, 84, 6,  2, 4, 85, 5, 34, 2, 65, 0, 63, 
    5, 43, 4, 80, 3, 68, 7, 84, 6, 94, 1, 67, 2,  7, 0, 23, 8, 37, 
    4, 95, 3, 79, 1, 98, 6, 84, 5, 35, 7, 11, 8, 43, 0, 61, 2, 44, 
    1,  6, 2, 20, 4,  5, 7, 96, 0,  9, 5,  9, 8,  8, 6, 32, 3, 28, 
    5, 15, 2, 58, 3, 65, 7, 24, 6, 23, 8, 90, 4, 72, 0, 30, 1, 23, 
    8, 79, 7, 46, 3,  8, 4,  3, 1, 50, 2, 56, 5, 34, 6, 88, 0, 75, 
    0, 99, 7, 14, 4, 41, 8, 87, 5, 73, 6, 95, 3, 96, 1, 19, 2, 98, 
    0, 99, 5, 35, 2,  7, 1, 33, 6, 26, 3, 44, 4, 51, 7, 46, 8, 61, 
    2,  6, 3, 78, 4, 27, 7, 70, 0, 95, 8, 32, 5, 21, 6, 18, 1, 69
  };
  const int q4126[] = {
    9, 9, // Number of jobs and machines
    0, 78, 6, 35, 1, 46, 2, 26, 7, 36, 4, 86, 8,  7, 3, 94, 5,  6, 
    5, 13, 4, 82, 8, 65, 1, 20, 2, 95, 0, 31, 7, 76, 3,  8, 6, 80, 
    4, 71, 2, 80, 0, 62, 8, 47, 5, 38, 1,  7, 7, 41, 6, 84, 3, 51, 
    6, 28, 4, 67, 5, 57, 0, 67, 7,  3, 3, 11, 2, 39, 8, 20, 1, 20, 
    3, 36, 8, 27, 0, 64, 4, 23, 1, 97, 2, 31, 5, 53, 7, 73, 6, 46, 
    8, 15, 4, 46, 0, 14, 3, 93, 7, 19, 2, 26, 5, 42, 6, 18, 1, 75, 
    1, 10, 4, 94, 3, 85, 0, 17, 6,  5, 7, 71, 2, 24, 5, 21, 8, 82, 
    3, 87, 2, 31, 4, 36, 6, 16, 1, 57, 8, 39, 5, 13, 0, 29, 7, 14, 
    5, 34, 8, 19, 3, 40, 4, 63, 1, 14, 0, 54, 7, 71, 6, 77, 2, 40
  };
  const int q4127[] = {
    9, 9, // Number of jobs and machines
    6, 65, 5, 58, 8, 82, 1,  2, 0, 70, 2, 16, 7, 75, 3, 99, 4,  2, 
    2, 86, 0, 19, 8, 74, 6, 89, 5, 24, 1, 29, 4, 31, 3, 26, 7, 81, 
    8,  5, 0, 39, 5, 40, 7,  8, 1, 64, 6, 79, 2, 53, 4, 44, 3, 84, 
    7, 83, 8, 30, 0, 45, 2, 80, 5, 30, 3, 11, 1,  3, 6, 80, 4, 38, 
    7, 74, 6, 89, 2, 61, 0, 89, 3,  2, 1, 24, 5, 30, 8, 40, 4, 50, 
    1, 44, 3, 52, 6, 30, 0, 11, 2, 60, 5, 12, 7,  8, 4, 38, 8, 22, 
    6, 17, 3, 92, 5, 13, 8, 50, 1, 69, 7, 92, 0, 91, 4, 37, 2,  1, 
    2, 97, 7, 26, 3, 74, 0, 53, 8, 56, 5, 51, 6, 49, 4, 61, 1, 47, 
    1, 50, 4, 13, 0, 72, 6, 10, 7,  6, 2, 80, 5, 10, 8, 10, 3,  6
  };
  const int q4128[] = {
    9, 9, // Number of jobs and machines
    0, 89, 6, 84, 2, 20, 4, 44, 8, 33, 3, 90, 7,  3, 5, 66, 1, 99, 
    3, 88, 2, 96, 7,  6, 4, 38, 0, 60, 6, 80, 8, 22, 5, 69, 1, 88, 
    4, 33, 6, 74, 2, 64, 5, 47, 1, 39, 0, 23, 7,  3, 8, 11, 3, 92, 
    0, 57, 6, 62, 5, 94, 1, 63, 4, 49, 7, 71, 3, 85, 2, 65, 8, 74, 
    1, 11, 5, 52, 0, 15, 4, 78, 6, 33, 2, 18, 3, 93, 8, 48, 7, 17, 
    0, 88, 5, 71, 3, 99, 1, 77, 7, 50, 6, 26, 2, 59, 4, 69, 8, 49, 
    0, 36, 5, 16, 6, 95, 4, 45, 7, 79, 3, 15, 8, 50, 2, 64, 1, 91, 
    1, 91, 2, 87, 4, 43, 3, 97, 0, 93, 7, 74, 6, 11, 5, 10, 8, 25, 
    6, 92, 5,  9, 4, 48, 1, 53, 7, 10, 2, 71, 0, 79, 8, 51, 3, 61
  };
  const int q4129[] = {
    9, 9, // Number of jobs and machines
    2, 82, 1,  6, 7, 93, 3, 32, 5, 46, 4, 84, 8, 24, 0, 98, 6, 42, 
    3, 36, 8, 19, 1, 51, 5, 59, 4, 89, 6, 40, 7, 48, 2, 60, 0, 19, 
    4, 99, 6,  3, 5,  6, 3, 79, 7, 94, 1, 71, 8, 27, 0, 92, 2,  1, 
    1, 28, 8, 73, 6, 57, 5, 30, 3, 45, 0, 61, 2, 33, 4, 68, 7, 49, 
    8, 19, 5, 42, 6, 96, 1, 31, 4, 89, 7,  7, 3, 43, 0, 39, 2, 90, 
    4, 83, 8, 64, 1, 24, 0, 28, 2, 20, 7,  7, 5, 49, 3, 51, 6, 25, 
    6, 73, 3, 23, 7, 34, 8, 98, 1, 12, 4, 65, 2, 54, 5, 14, 0, 89, 
    0, 92, 3, 41, 2,  9, 6, 34, 7, 59, 1, 53, 8, 28, 5, 47, 4, 79, 
    8,  8, 0, 62, 4, 80, 7, 31, 3, 17, 5, 74, 6, 45, 2, 42, 1, 13
  };
  const int q4130[] = {
    9, 9, // Number of jobs and machines
    7, 64, 5, 46, 6, 48, 4, 69, 0, 76, 1,  1, 2, 68, 3, 44, 8, 12, 
    6, 96, 1, 70, 8, 70, 2, 20, 0, 43, 7, 17, 4, 82, 3, 44, 5, 32, 
    1, 71, 8, 46, 0, 30, 7,  5, 3, 40, 5, 44, 2, 96, 4, 18, 6, 10, 
    8, 51, 0, 39, 1, 39, 2, 54, 3, 24, 5, 71, 4, 13, 7, 25, 6, 66, 
    2, 80, 0, 22, 6, 30, 8, 63, 1, 46, 5, 19, 3, 67, 7, 28, 4,  2, 
    8, 34, 0, 59, 1, 44, 7, 64, 4, 42, 5, 46, 2, 72, 6, 56, 3, 50, 
    5, 88, 6, 98, 2, 75, 0, 68, 7, 42, 3, 28, 4, 90, 1, 89, 8, 40, 
    3, 40, 4, 57, 0, 29, 8, 72, 5, 44, 1, 26, 6, 77, 2, 80, 7, 49, 
    8,  8, 3,  5, 6, 40, 5, 47, 4,  5, 1, 69, 0, 30, 2, 68, 7, 20
  };
  const int q4131[] = {
    9, 9, // Number of jobs and machines
    6, 85, 2,  2, 1, 45, 0, 68, 8, 56, 5, 26, 7, 49, 4, 73, 3,  4, 
    0, 32, 4, 95, 3, 46, 1, 71, 5,  8, 2, 23, 6, 96, 8, 86, 7, 35, 
    6, 17, 3, 19, 4, 61, 5, 56, 0,  7, 1, 87, 2, 76, 7, 87, 8,  9, 
    0, 78, 2, 18, 3, 83, 4, 23, 8, 52, 7, 52, 1, 22, 6, 77, 5, 24, 
    8, 93, 1,  7, 5, 18, 2, 73, 0, 49, 6, 11, 3, 90, 4, 26, 7, 24, 
    1, 28, 6, 54, 7, 92, 0, 60, 3, 26, 8, 35, 2,  2, 5, 23, 4, 15, 
    8, 27, 5, 75, 3, 64, 7, 19, 0, 96, 1, 97, 6, 22, 2, 84, 4, 67, 
    5,  4, 3, 19, 1, 74, 0, 40, 6, 88, 7, 46, 4, 60, 8, 20, 2, 41, 
    5, 43, 0,  1, 1, 33, 3, 70, 8, 87, 6, 54, 4, 26, 7, 20, 2, 36
  };
  const int q4132[] = {
    9, 9, // Number of jobs and machines
    7, 34, 0, 13, 5, 24, 4, 51, 8, 94, 6, 98, 3,  2, 1, 53, 2, 80, 
    2,  4, 4, 95, 0, 73, 8, 84, 6, 11, 1, 62, 3, 34, 7, 99, 5, 59, 
    4, 79, 1, 30, 0, 16, 3,  2, 2, 84, 6, 48, 8, 28, 7, 13, 5, 10, 
    4, 26, 6, 22, 0, 63, 3, 63, 8, 62, 1, 40, 5, 78, 2, 52, 7, 87, 
    5, 53, 3, 70, 8, 66, 7, 95, 1, 21, 0,  9, 4, 81, 2, 19, 6, 56, 
    7, 33, 2,  7, 5, 49, 0,  5, 3, 28, 1, 76, 8, 79, 4, 82, 6, 15, 
    3, 59, 5, 79, 7, 26, 4, 33, 8, 77, 1, 10, 6, 84, 0, 85, 2, 86, 
    3,  6, 8, 73, 1, 11, 4, 95, 0, 16, 2, 62, 5,  4, 6, 87, 7, 82, 
    8, 85, 6,  9, 0, 47, 5, 91, 4, 89, 7, 64, 2, 34, 1, 57, 3, 84
  };
  const int q4133[] = {
    9, 9, // Number of jobs and machines
    1, 64, 5, 40, 6, 58, 4,  1, 0, 27, 8, 80, 7, 43, 3, 80, 2, 88, 
    7, 86, 5, 38, 3, 24, 6, 26, 8,  3, 1, 69, 4, 73, 2, 10, 0, 51, 
    2, 39, 6, 74, 7, 44, 5, 27, 1, 30, 8, 93, 3, 37, 0,  9, 4, 74, 
    8, 97, 2, 79, 5, 18, 6, 32, 4, 14, 0, 94, 3, 34, 1, 73, 7, 33, 
    0, 50, 1, 19, 3, 11, 5, 39, 6, 37, 8, 45, 4,  7, 2, 87, 7, 43, 
    5, 89, 1, 54, 2, 59, 4, 50, 6, 29, 0,  5, 3, 56, 8, 69, 7, 47, 
    4, 73, 0, 40, 2, 90, 5, 41, 3, 13, 6, 38, 8, 89, 7, 53, 1, 21, 
    4, 62, 0, 53, 2, 50, 6, 34, 7, 14, 8, 87, 3,  7, 5,  8, 1, 71, 
    3, 13, 0, 57, 6,  8, 8, 53, 1, 86, 5, 56, 2, 12, 4, 40, 7,  2
  };
  const int q4134[] = {
    9, 9, // Number of jobs and machines
    0, 99, 4, 10, 7,  5, 8, 83, 1, 65, 3,  8, 5, 10, 2, 14, 6, 27, 
    6, 69, 5, 90, 7, 94, 8, 36, 1, 71, 2, 36, 3, 59, 0, 68, 4, 45, 
    7, 19, 6, 84, 2, 22, 1, 24, 3, 56, 0, 33, 4, 37, 8, 82, 5, 98, 
    2, 53, 3, 77, 6, 17, 0, 73, 7, 61, 1, 12, 5, 24, 4,  5, 8, 95, 
    5, 74, 2, 10, 7, 26, 4, 54, 0,  3, 1,  5, 6, 58, 8, 65, 3, 76, 
    6, 51, 8,  1, 2, 23, 3, 10, 5, 45, 7, 46, 1, 18, 0, 15, 4, 90, 
    3, 57, 4, 51, 5, 28, 2, 58, 8, 16, 7, 53, 6, 90, 1,  9, 0, 37, 
    2,  9, 5, 17, 6,  7, 7, 79, 4, 39, 3, 23, 0, 33, 1, 16, 8, 82, 
    4, 38, 8, 82, 2, 31, 7, 80, 6, 72, 1, 47, 3, 75, 5, 51, 0, 40
  };
  const int q4135[] = {
    9, 9, // Number of jobs and machines
    5, 89, 4, 87, 1,  4, 6, 35, 2, 89, 0, 37, 8, 73, 3, 43, 7, 17, 
    2, 60, 8,  2, 4, 59, 0, 32, 1, 43, 5,  1, 6, 32, 3, 81, 7,  9, 
    0, 17, 4, 29, 7, 56, 8, 85, 1, 10, 2, 30, 5, 63, 3, 21, 6, 34, 
    2, 92, 3,  6, 5,  4, 8, 83, 7, 33, 0, 51, 4, 51, 6, 77, 1, 25, 
    8, 37, 2, 50, 7, 38, 5, 64, 4,  9, 1,  7, 6, 45, 0, 17, 3, 34, 
    4, 57, 1, 82, 2, 22, 3, 52, 5, 14, 6,  2, 0, 25, 8, 54, 7, 44, 
    7, 37, 2, 33, 6, 26, 3, 30, 4, 73, 1, 88, 0, 41, 8, 53, 5, 84, 
    3, 70, 0, 65, 5, 75, 1, 34, 8, 70, 4, 74, 2, 65, 6, 42, 7, 82, 
    4, 56, 3, 83, 0, 60, 2, 14, 5,  1, 8, 19, 1,  5, 7,  2, 6,  5
  };
  const int q4136[] = {
    9, 9, // Number of jobs and machines
    3, 66, 7, 42, 8, 46, 1, 69, 5, 20, 0, 43, 4, 63, 2,  8, 6,  9, 
    0,  1, 6, 46, 3, 81, 2, 66, 8, 42, 1, 44, 4, 25, 5, 83, 7, 61, 
    6, 17, 7, 80, 1,  6, 3, 92, 0, 76, 8, 72, 4, 14, 5, 69, 2, 83, 
    3, 84, 7, 37, 0, 62, 4, 84, 6, 95, 2,  6, 5, 85, 1, 58, 8, 53, 
    8, 31, 6,  5, 1, 65, 4, 48, 3, 45, 7, 32, 2, 16, 5, 15, 0, 19, 
    5, 80, 0,  9, 4, 55, 2,  5, 8,  7, 3, 79, 6, 36, 7, 83, 1, 36, 
    6, 36, 5, 51, 1, 20, 0, 92, 4, 18, 3, 98, 8,  8, 2, 41, 7, 12, 
    4, 56, 6, 53, 7,  3, 1,  5, 5, 80, 3, 55, 0, 31, 2, 57, 8, 92, 
    8, 48, 0, 92, 3, 34, 2, 78, 6, 42, 7, 96, 5, 12, 4, 25, 1, 50
  };
  const int q4137[] = {
    9, 9, // Number of jobs and machines
    7, 28, 4, 23, 3, 35, 6, 61, 0, 79, 5, 68, 1,  9, 2, 56, 8, 16, 
    0, 99, 7, 28, 5, 81, 3, 93, 8,  4, 4, 70, 6,  3, 2, 85, 1, 56, 
    8, 69, 6, 89, 0, 24, 3, 52, 4, 70, 1, 12, 7, 82, 5,  3, 2, 17, 
    3, 48, 7, 43, 2, 82, 8, 27, 4, 56, 0, 43, 1, 67, 6, 89, 5, 38, 
    4, 91, 2, 25, 8, 91, 1,  1, 6,  6, 5, 28, 3, 25, 0, 15, 7, 23, 
    4, 98, 3,  7, 5, 36, 6,  2, 2,  6, 7, 80, 8, 19, 0, 60, 1, 57, 
    2, 20, 1,  1, 7, 53, 3, 31, 0, 26, 8, 94, 4,  4, 5, 20, 6, 88, 
    1, 64, 8, 54, 2, 16, 7, 87, 5, 93, 0, 32, 3, 60, 4,  1, 6, 82, 
    8, 77, 0, 69, 7, 46, 3, 92, 4, 51, 6, 22, 2, 29, 5, 80, 1, 22
  };
  const int q4138[] = {
    9, 9, // Number of jobs and machines
    1, 11, 0, 11, 7, 74, 3, 84, 4, 77, 8, 84, 5, 27, 2,  7, 6, 77, 
    5, 96, 1, 19, 2, 73, 8, 33, 7,  5, 0, 70, 4, 78, 3, 55, 6, 63, 
    4, 59, 2, 58, 3, 69, 6, 27, 8, 92, 5, 44, 1, 55, 0, 95, 7, 84, 
    7,  9, 1, 86, 0, 95, 6, 78, 8, 88, 5, 66, 4, 60, 2, 89, 3, 70, 
    5, 92, 6, 48, 3, 34, 0, 33, 4, 68, 8, 16, 7, 30, 2, 27, 1, 17, 
    3, 94, 2, 54, 8,  5, 4,  4, 6, 73, 0, 47, 7, 11, 5, 84, 1, 92, 
    4, 25, 2, 99, 8, 71, 1, 90, 5, 82, 6, 86, 0, 18, 3, 89, 7, 79, 
    2, 58, 6, 51, 1, 58, 8, 37, 5, 45, 4, 45, 3, 24, 7, 84, 0, 61, 
    7, 32, 8, 33, 4, 37, 0, 88, 1, 12, 6, 96, 3, 58, 2, 82, 5, 64
  };
  const int q4139[] = {
    9, 9, // Number of jobs and machines
    1, 99, 0, 28, 6, 81, 3, 90, 2, 57, 4, 78, 5, 79, 7, 98, 8, 72, 
    7, 19, 5, 89, 0, 52, 8, 75, 1, 49, 3, 35, 6, 91, 4, 54, 2,  5, 
    3, 38, 6, 53, 7, 44, 0, 96, 8, 57, 5,  3, 4, 82, 2, 70, 1, 30, 
    0, 56, 3, 84, 5, 17, 2, 98, 4, 53, 8, 18, 1, 12, 6, 61, 7, 31, 
    2, 73, 1, 15, 0, 63, 7, 90, 6,  1, 4, 72, 5, 38, 3, 68, 8, 77, 
    4,  3, 2, 33, 8, 13, 7, 60, 3, 95, 1, 38, 5, 83, 0, 97, 6, 48, 
    0, 67, 6, 18, 7, 13, 5, 58, 3, 60, 4, 41, 8, 98, 1, 14, 2, 47, 
    2, 74, 0, 36, 1, 43, 8, 67, 6, 37, 5, 38, 7,  8, 3, 29, 4, 10, 
    0, 70, 4, 65, 3, 53, 2,  4, 8, 64, 5, 35, 7, 36, 6, 45, 1, 66
  };
  const int q4140[] = {
    9, 9, // Number of jobs and machines
    8, 30, 2, 30, 7, 11, 3, 68, 4, 87, 5, 57, 6, 77, 1, 21, 0, 35, 
    6, 24, 4, 80, 1, 91, 8, 32, 0, 24, 5, 96, 3, 14, 7, 49, 2, 77, 
    0, 57, 8,  6, 1, 55, 7, 83, 5, 22, 6, 31, 4, 82, 2, 95, 3, 87, 
    0,  8, 6, 33, 2, 98, 5, 17, 1, 34, 8, 91, 4,  4, 7, 51, 3, 95, 
    8, 75, 1, 76, 3, 80, 2, 95, 4, 29, 7, 56, 5,  5, 6, 92, 0, 38, 
    4, 13, 7, 29, 8,  7, 0,  1, 1, 85, 2, 16, 6, 75, 3,  4, 5, 87, 
    4, 66, 3, 31, 5, 72, 8,  7, 2, 28, 6, 13, 1, 45, 0, 19, 7, 68, 
    6, 45, 5, 15, 2, 59, 0,  1, 7, 51, 4, 85, 3, 77, 8, 74, 1, 89, 
    7, 89, 1, 55, 5, 51, 8, 85, 6, 87, 2, 25, 4, 86, 0, 58, 3,  1
  };
  const int q4141[] = {
    9, 9, // Number of jobs and machines
    3, 69, 0, 13, 5, 43, 7, 39, 8, 18, 1, 92, 4, 43, 6, 65, 2, 21, 
    2, 87, 6,  5, 7, 42, 5, 50, 4, 80, 1, 26, 8, 77, 0, 25, 3,  6, 
    3, 76, 1, 78, 0, 19, 7, 13, 5, 95, 8, 15, 2, 78, 4, 59, 6, 48, 
    2, 73, 8, 74, 7,  8, 4, 57, 1, 57, 5, 18, 0, 73, 6, 39, 3, 56, 
    6, 79, 7, 55, 4, 71, 3, 88, 0, 19, 5,  8, 2, 23, 8, 34, 1, 22, 
    6, 97, 1, 67, 2, 15, 0, 15, 7, 73, 3,  2, 4, 91, 5,  9, 8, 83, 
    5, 99, 7, 12, 1,  1, 6, 83, 0, 77, 8, 67, 3, 80, 2, 78, 4, 31, 
    3,  7, 8, 63, 2, 88, 1, 45, 7, 89, 5, 24, 0, 21, 4, 57, 6, 69, 
    8, 54, 5, 29, 1, 71, 4, 41, 3, 82, 2, 97, 6, 31, 7, 79, 0, 78
  };
  const int q4142[] = {
    9, 9, // Number of jobs and machines
    3, 77, 1, 20, 6, 77, 4, 39, 0, 64, 7, 46, 5, 60, 2, 66, 8, 68, 
    7, 66, 2, 97, 8, 30, 5, 93, 0, 83, 1, 99, 4,  1, 6, 21, 3,  3, 
    4, 76, 1, 95, 0, 18, 6, 28, 2, 38, 8, 87, 7, 36, 3, 61, 5, 42, 
    3, 79, 0, 37, 2, 42, 4, 88, 1, 79, 6, 89, 5, 28, 7, 58, 8, 77, 
    1, 81, 7, 21, 3, 29, 6, 64, 0, 61, 2, 67, 5, 88, 8, 57, 4, 79, 
    7, 17, 3, 71, 5, 88, 4,  3, 0, 39, 8, 30, 2, 42, 1, 79, 6, 11, 
    5,  1, 0, 70, 7, 44, 8, 32, 6, 50, 1, 16, 3, 77, 4, 36, 2, 37, 
    6, 72, 0, 90, 5,  4, 2, 87, 8, 83, 4, 79, 1, 26, 7, 65, 3, 53, 
    7, 69, 3, 48, 5, 30, 1, 85, 2, 87, 0, 29, 6, 31, 8, 97, 4, 58
  };
  const int q4143[] = {
    9, 9, // Number of jobs and machines
    5, 62, 3, 27, 4, 99, 1, 53, 2, 90, 0, 41, 8,  7, 7, 84, 6, 45, 
    3, 80, 7, 57, 5, 51, 1, 13, 4, 61, 6, 22, 0, 28, 2, 86, 8, 73, 
    0, 33, 5,  9, 7, 66, 8, 27, 1, 29, 6, 49, 4, 54, 2, 74, 3, 85, 
    4, 85, 2, 40, 8, 94, 1, 29, 5, 59, 7, 76, 3, 71, 6, 31, 0, 17, 
    3, 11, 1, 88, 2,  5, 4, 39, 6, 93, 0, 65, 5, 86, 8, 24, 7, 44, 
    7,  7, 5, 80, 3, 77, 0,  4, 4, 24, 2, 49, 8, 80, 1, 85, 6, 87, 
    5, 85, 8, 25, 1, 96, 6, 63, 2, 42, 3, 43, 7, 29, 4, 31, 0, 96, 
    2, 17, 5, 96, 8, 53, 1, 15, 3, 21, 0, 33, 4, 10, 6, 36, 7,  5, 
    8, 53, 3, 21, 0, 35, 5, 72, 7, 36, 1, 71, 6, 82, 4, 12, 2, 50
  };
  const int q4144[] = {
    9, 9, // Number of jobs and machines
    4, 23, 8,  2, 6, 29, 5, 98, 3, 56, 0, 66, 7,  9, 1, 74, 2, 64, 
    6,  1, 1, 60, 3, 13, 8, 87, 0, 40, 2, 52, 5, 98, 7, 95, 4, 46, 
    0, 94, 2, 78, 5, 41, 7, 65, 3, 99, 8, 96, 6, 88, 1, 68, 4, 57, 
    6, 31, 7, 42, 4, 13, 0, 60, 2, 36, 1, 90, 8, 61, 5,  3, 3, 65, 
    6, 34, 1, 45, 0, 80, 5, 63, 4, 37, 7, 34, 8, 23, 3, 97, 2, 93, 
    3, 63, 7, 56, 1, 60, 8, 91, 0, 83, 5, 86, 2, 58, 6, 13, 4, 27, 
    3, 71, 7, 29, 4, 84, 6,  4, 2, 59, 0, 34, 8, 42, 1, 85, 5, 17, 
    6, 48, 0, 10, 4, 78, 2, 14, 7, 94, 3, 45, 5,  4, 8, 97, 1, 24, 
    6, 44, 2, 81, 5, 86, 7, 36, 3, 57, 1, 56, 0, 81, 4, 94, 8, 56
  };
  const int q4145[] = {
    9, 9, // Number of jobs and machines
    6, 45, 1, 48, 7, 20, 5, 28, 3, 28, 4, 57, 0, 22, 8, 56, 2, 95, 
    6, 89, 1, 42, 4,  3, 2, 73, 5, 36, 7, 67, 0, 15, 8, 60, 3, 68, 
    8, 15, 4, 98, 1, 12, 3, 60, 6, 10, 0, 91, 5, 78, 2, 13, 7, 80, 
    3, 13, 4, 37, 5, 76, 0, 77, 1, 68, 2, 74, 7, 69, 8,  9, 6, 67, 
    0, 25, 5, 96, 7, 20, 2, 11, 1, 57, 3, 83, 6, 64, 8, 14, 4, 78, 
    3, 35, 0, 65, 8, 31, 7, 66, 4, 38, 6, 18, 2, 90, 1, 29, 5, 83, 
    5, 41, 7, 19, 0, 78, 1, 79, 8,  8, 6, 82, 4, 77, 3, 48, 2, 57, 
    5, 71, 4, 45, 3, 62, 7, 84, 8, 56, 2, 34, 1, 83, 0, 82, 6, 75, 
    5, 66, 0, 69, 4, 58, 2, 56, 8, 95, 3, 31, 7, 64, 6, 18, 1, 35
  };
  const int q4146[] = {
    9, 9, // Number of jobs and machines
    1, 78, 8, 89, 4, 51, 3, 72, 2, 18, 6, 88, 0,  8, 7, 89, 5, 75, 
    4, 55, 8, 80, 0, 17, 1, 12, 2,  8, 7,  9, 3, 52, 5, 78, 6, 63, 
    7, 95, 6, 42, 0, 85, 3, 90, 5, 40, 8, 93, 4, 28, 2, 85, 1, 30, 
    8, 44, 0, 86, 5, 71, 7, 19, 4, 95, 6, 14, 2, 60, 3, 60, 1, 19, 
    7, 82, 8, 75, 5, 11, 4, 90, 6,  5, 0, 40, 3,  6, 1, 93, 2, 18, 
    2, 18, 6, 86, 1, 89, 5, 83, 8,  7, 3, 29, 0, 36, 4, 35, 7, 28, 
    8, 29, 3, 29, 0, 29, 7, 11, 1, 68, 5, 60, 4, 54, 6, 54, 2, 19, 
    3,  4, 0, 33, 4, 67, 1, 15, 6, 47, 2,  8, 5,  5, 7,  5, 8, 13, 
    3, 37, 0, 60, 5, 72, 8, 93, 1, 23, 6, 40, 4, 10, 2, 50, 7, 87
  };
  const int q4147[] = {
    9, 9, // Number of jobs and machines
    4, 23, 2, 80, 6, 92, 8, 13, 5, 42, 7, 26, 3, 27, 1, 30, 0,  9, 
    8, 35, 5, 86, 0, 40, 6, 69, 3, 29, 1, 30, 2, 48, 4, 69, 7, 86, 
    4, 17, 1, 54, 7,  5, 3,  4, 0, 80, 5, 45, 2, 11, 6, 10, 8,  1, 
    7, 96, 0, 18, 1, 79, 8, 91, 4, 91, 3, 19, 2, 70, 5, 66, 6, 95, 
    6,  8, 5, 12, 2, 36, 4, 22, 8,  1, 7, 34, 1, 47, 3, 45, 0,  4, 
    2, 62, 1, 64, 0, 34, 5,  6, 3, 98, 6, 34, 8, 11, 7,  1, 4,  9, 
    4, 39, 3, 32, 8, 11, 1, 74, 5, 85, 2, 10, 0, 81, 6, 16, 7, 57, 
    3, 64, 2, 53, 8, 52, 7,  5, 6,  5, 4, 87, 0, 84, 5, 51, 1, 32, 
    5, 42, 0, 35, 1,  2, 4, 81, 2, 37, 6, 22, 3, 69, 8, 13, 7,  7
  };
  const int q4148[] = {
    9, 9, // Number of jobs and machines
    1, 92, 4,  1, 5, 22, 7, 39, 8, 34, 0, 15, 6, 23, 2, 68, 3, 17, 
    3, 19, 4, 17, 5, 68, 8, 46, 6, 55, 7, 64, 2, 69, 0, 28, 1, 66, 
    8, 23, 5, 38, 2, 84, 1, 97, 7, 71, 4, 73, 3,  3, 0, 30, 6, 79, 
    8, 51, 1,  3, 0, 68, 2,  7, 4, 38, 6, 35, 5, 74, 3, 81, 7, 63, 
    4, 37, 3, 68, 7, 24, 5, 69, 1, 19, 8, 56, 2, 91, 0, 94, 6, 52, 
    8, 29, 2, 60, 4,  3, 1, 31, 3, 82, 0, 42, 6, 12, 5, 97, 7, 70, 
    6, 71, 5, 86, 0,  4, 2,  4, 8, 36, 1, 67, 3,  3, 7, 65, 4, 94, 
    1, 97, 8, 56, 3, 77, 5, 86, 6, 95, 4, 35, 7, 27, 2, 12, 0, 37, 
    8, 67, 6, 22, 5, 53, 3,  1, 4, 22, 7, 44, 0, 59, 2, 50, 1, 31
  };
  const int q4149[] = {
    9, 9, // Number of jobs and machines
    2,  9, 0, 87, 4, 41, 6, 26, 7, 37, 1, 99, 3, 43, 8, 94, 5, 21, 
    3, 30, 2, 19, 5, 68, 0, 93, 7, 30, 6, 90, 1, 99, 8, 87, 4, 58, 
    0, 97, 7, 34, 3, 14, 4, 71, 8,  9, 6,  6, 2,  1, 5, 45, 1, 49, 
    7, 84, 2, 96, 1, 33, 3, 41, 8, 76, 5, 60, 0, 60, 6, 16, 4, 62, 
    0, 40, 6, 73, 3,  4, 5,  9, 7, 65, 2, 92, 4,  4, 8, 38, 1, 39, 
    4, 13, 3, 33, 7, 79, 8, 13, 2, 10, 6, 82, 0, 37, 1, 86, 5, 81, 
    2, 62, 1,  4, 3, 12, 7, 63, 8, 53, 5, 40, 4, 85, 0, 14, 6, 78, 
    7, 95, 1,  7, 4, 78, 6, 89, 5, 84, 3, 44, 2, 86, 8, 86, 0, 66, 
    4, 27, 5, 84, 7, 63, 0, 30, 6, 88, 8, 54, 3,  9, 2, 30, 1, 94
  };
  const int q4150[] = {
    9, 9, // Number of jobs and machines
    3, 40, 4, 16, 6, 93, 5,  4, 1, 44, 8, 16, 0, 86, 2, 38, 7, 91, 
    0, 38, 1, 41, 2, 65, 8, 50, 7, 88, 6, 31, 3, 70, 4, 35, 5, 24, 
    2, 60, 4, 33, 6, 97, 1, 34, 3, 52, 7, 48, 0, 84, 8, 89, 5, 88, 
    1, 30, 4, 79, 0, 23, 7, 57, 8, 10, 3, 66, 6, 14, 5, 73, 2, 66, 
    5, 68, 0, 21, 2, 35, 8, 13, 1, 30, 3, 54, 6, 89, 7, 60, 4, 85, 
    5, 99, 1, 50, 8, 62, 6, 55, 0,  2, 3, 42, 7, 43, 2, 40, 4, 32, 
    1, 48, 8, 47, 5, 34, 7, 78, 3, 10, 2, 10, 4, 38, 6, 47, 0,  9, 
    6, 70, 3, 99, 2, 63, 4, 82, 7, 69, 1, 85, 5, 16, 0, 61, 8, 11, 
    1, 50, 4, 63, 2, 72, 8, 12, 5, 94, 0,  9, 6, 29, 3, 77, 7,  2
  };
  const int q4151[] = {
    9, 9, // Number of jobs and machines
    2, 66, 1,  5, 3, 61, 5, 55, 4, 64, 8, 31, 7,  5, 0, 12, 6,  2, 
    2, 59, 5, 62, 8, 11, 4, 82, 7, 60, 6, 18, 1, 41, 3, 58, 0, 43, 
    0, 28, 8, 45, 4, 35, 6, 24, 1, 14, 3, 35, 5, 22, 7,  8, 2, 44, 
    4,  7, 7, 86, 3, 99, 6, 81, 5, 13, 8, 44, 0, 11, 1, 23, 2, 59, 
    8, 38, 6, 71, 4, 24, 7, 26, 5, 67, 2, 37, 0, 46, 3, 20, 1, 16, 
    2, 84, 6, 79, 8,  3, 1, 10, 7, 13, 0, 57, 4, 86, 5,  1, 3, 58, 
    5, 69, 6,  6, 7, 58, 0, 35, 3, 73, 8, 21, 4, 44, 2, 95, 1, 85, 
    1, 33, 0, 91, 5, 29, 6, 78, 3,  5, 7, 60, 4, 47, 8, 44, 2, 49, 
    0, 99, 4, 89, 1, 94, 3, 75, 7, 59, 8, 84, 2, 28, 6, 55, 5, 21
  };
  const int q4152[] = {
    9, 9, // Number of jobs and machines
    8, 50, 7, 72, 0, 21, 3, 47, 6,  4, 2, 92, 5, 39, 1, 76, 4, 16, 
    8, 55, 4, 45, 0, 95, 2, 76, 6, 60, 7, 38, 5, 75, 3, 59, 1, 32, 
    2, 85, 5, 90, 0, 98, 7, 72, 4, 92, 3, 76, 6, 86, 1, 91, 8, 90, 
    1, 93, 7, 43, 6,  2, 5, 43, 8,  6, 0, 47, 3,  1, 2, 95, 4, 13, 
    8, 95, 4, 32, 5, 93, 7, 44, 2,  4, 0, 23, 3, 40, 1,  6, 6, 40, 
    4, 79, 1, 77, 6, 18, 7, 52, 2, 27, 8, 80, 0, 42, 5, 30, 3, 77, 
    1, 87, 4, 51, 5, 37, 7, 86, 2, 17, 8,  3, 0, 72, 3, 18, 6, 93, 
    4, 62, 5, 69, 7, 68, 2, 57, 3, 97, 8, 82, 1, 66, 6,  6, 0, 33, 
    7, 32, 8, 61, 4, 39, 0, 24, 5, 21, 2, 52, 3, 89, 6, 32, 1, 35
  };
  const int q4153[] = {
    9, 9, // Number of jobs and machines
    4, 11, 1, 47, 3, 34, 6, 14, 2, 90, 8, 60, 5, 89, 7, 28, 0, 98, 
    0, 65, 3,  1, 6, 61, 1,  9, 5, 31, 4, 12, 7, 50, 8, 54, 2, 83, 
    8, 19, 1, 27, 7, 35, 5, 33, 2, 49, 4, 18, 0, 27, 6, 51, 3, 26, 
    6, 74, 5, 70, 4, 41, 8, 50, 3, 81, 0, 35, 7, 37, 1,  9, 2, 11, 
    2, 98, 5, 60, 8, 73, 0, 26, 1, 91, 4, 61, 7, 71, 3, 78, 6, 37, 
    0, 38, 7, 81, 5, 98, 3, 75, 1, 26, 6, 14, 8, 44, 2, 42, 4, 36, 
    1, 99, 5, 57, 8, 43, 4, 80, 3, 71, 6, 24, 2, 11, 0, 66, 7, 83, 
    3, 66, 5, 11, 8, 50, 7, 74, 2, 33, 4, 60, 6, 94, 0, 54, 1, 23, 
    2, 22, 6, 87, 1, 12, 3, 88, 0, 23, 7,  4, 4, 48, 8, 55, 5, 80
  };
  const int q4154[] = {
    9, 9, // Number of jobs and machines
    8, 66, 5, 76, 4, 76, 6, 90, 0, 13, 7, 15, 2, 43, 3, 62, 1,  7, 
    4, 19, 8, 26, 2, 19, 7, 44, 6, 56, 3,  1, 1, 70, 5, 29, 0, 37, 
    1, 32, 2, 80, 6, 48, 0, 25, 3, 40, 4, 79, 8, 54, 7,  6, 5, 82, 
    4, 93, 6, 52, 1, 64, 2, 98, 3, 73, 0, 71, 5, 64, 8, 13, 7, 21, 
    7, 22, 4, 13, 5, 33, 0, 37, 6, 73, 8, 64, 3, 55, 1, 37, 2, 57, 
    3, 30, 8, 93, 6, 60, 4, 18, 0, 47, 7, 54, 2, 62, 1, 19, 5, 35, 
    8, 94, 6, 32, 2, 37, 3, 83, 4, 55, 7, 61, 0, 10, 5, 69, 1, 67, 
    3, 82, 7, 20, 5, 75, 1, 13, 4, 98, 0, 27, 2, 94, 6, 22, 8,  8, 
    7, 51, 8, 49, 3, 56, 2, 46, 6, 78, 5, 70, 1, 96, 0, 15, 4, 48
  };
  const int q4155[] = {
    9, 9, // Number of jobs and machines
    3, 96, 0, 11, 6,  9, 4, 57, 7, 29, 5, 47, 8,  8, 1, 69, 2, 49, 
    7, 45, 2, 34, 5,  4, 3, 80, 1, 97, 6, 44, 8, 37, 4, 67, 0, 62, 
    5, 18, 7, 74, 1, 45, 3,  2, 6, 88, 2, 67, 8, 72, 4, 11, 0, 85, 
    0, 93, 1, 25, 5, 56, 3, 36, 7, 70, 8, 85, 4, 94, 6, 18, 2,  6, 
    4, 95, 3, 72, 2, 66, 7, 66, 6, 56, 0, 35, 8, 67, 1, 17, 5, 60, 
    4, 61, 8, 96, 7, 16, 6, 10, 0, 20, 1, 96, 3, 79, 2, 53, 5, 92, 
    3, 76, 0, 85, 2, 35, 8, 47, 6, 49, 5, 29, 4, 68, 1, 36, 7, 67, 
    2, 26, 4, 40, 1, 27, 8, 68, 7, 70, 6, 90, 5, 40, 0, 72, 3, 15, 
    7, 32, 1, 96, 0, 35, 2, 65, 5, 67, 8, 23, 6, 76, 3, 38, 4, 61
  };
  const int q4156[] = {
    9, 9, // Number of jobs and machines
    8, 48, 4, 77, 5, 98, 7, 62, 3, 76, 2, 21, 0, 13, 1, 94, 6, 84, 
    7, 12, 2, 36, 1, 92, 5,  2, 3, 43, 6,  8, 8, 34, 4, 76, 0, 10, 
    2, 75, 3, 96, 7,  6, 4, 74, 8, 35, 5, 10, 6, 26, 1, 81, 0, 23, 
    2, 86, 1, 36, 0, 84, 4, 69, 8, 71, 7, 60, 3, 73, 6, 25, 5, 86, 
    6,  3, 1, 63, 3, 48, 2, 21, 4, 47, 8,  8, 7, 16, 0, 25, 5, 14, 
    5, 96, 2,  7, 4,  5, 6, 45, 1, 33, 8, 54, 7, 45, 3, 95, 0, 59, 
    1, 27, 6, 63, 8, 31, 4, 13, 2, 78, 5, 56, 0, 39, 7, 79, 3, 87, 
    3, 80, 8, 79, 0, 67, 6, 58, 5,  3, 1, 55, 7, 57, 2, 54, 4, 14, 
    3, 32, 0,  7, 5, 67, 1, 48, 6, 79, 7, 97, 8, 23, 4, 51, 2, 16
  };
  const int q4157[] = {
    9, 9, // Number of jobs and machines
    2, 10, 7, 95, 8, 97, 5, 34, 4, 75, 1, 72, 6, 70, 3, 65, 0, 93, 
    1, 65, 2, 62, 8, 84, 3, 76, 4, 13, 7, 51, 6, 89, 5, 40, 0, 93, 
    0, 49, 8,  5, 1, 92, 4, 78, 2, 39, 6, 20, 5, 59, 3, 99, 7, 16, 
    2, 11, 1,  5, 0, 42, 8, 61, 7, 88, 4, 36, 6, 48, 5, 52, 3, 26, 
    4, 92, 7, 87, 1, 95, 6, 74, 0, 58, 3,  7, 5, 33, 8, 33, 2, 77, 
    4, 25, 2, 30, 0, 93, 5, 75, 6,  8, 1,  6, 8, 87, 3, 84, 7,  1, 
    7, 79, 6, 63, 2, 53, 0, 89, 4, 82, 8,  3, 3, 86, 5,  6, 1, 50, 
    7, 10, 1, 98, 0, 19, 2, 24, 4, 13, 3, 34, 6, 62, 5, 77, 8, 47, 
    7, 66, 2, 41, 5, 38, 8, 21, 3, 14, 4, 13, 6, 38, 1, 46, 0, 38
  };
  const int q4158[] = {
    9, 9, // Number of jobs and machines
    4,  2, 7, 50, 5, 93, 1, 93, 2,  3, 8, 84, 3, 54, 0, 28, 6, 48, 
    7, 72, 0, 14, 6, 90, 1, 24, 4, 98, 2, 58, 3, 73, 8, 49, 5, 98, 
    0, 49, 5, 33, 4,  1, 7, 63, 2, 99, 3, 40, 1, 74, 6, 17, 8,  4, 
    5, 87, 8, 31, 0, 93, 6, 69, 1, 19, 7, 85, 3, 36, 2,  3, 4, 39, 
    1, 25, 0, 59, 4, 91, 6,  5, 2, 79, 8, 28, 3, 71, 7, 91, 5, 52, 
    6, 19, 5, 80, 1, 16, 0, 98, 4, 96, 8, 21, 2,  8, 7, 19, 3, 81, 
    0, 10, 7, 62, 6, 32, 8, 64, 2, 97, 4, 82, 1, 46, 5, 65, 3, 54, 
    7, 81, 2, 59, 0, 70, 6,  9, 8, 12, 3, 73, 4, 27, 1, 45, 5, 21, 
    5, 94, 1, 59, 0, 37, 3, 10, 7, 98, 2, 84, 4, 68, 6,  3, 8, 13
  };
  const int q4159[] = {
    9, 9, // Number of jobs and machines
    1, 24, 7, 66, 6,  9, 8, 90, 5, 68, 0, 66, 2, 12, 4, 94, 3,  4, 
    4, 57, 1, 23, 3, 26, 7, 46, 5, 84, 8, 85, 0, 56, 2, 54, 6, 47, 
    3, 26, 2, 83, 4, 12, 7, 93, 8, 13, 1, 32, 6, 25, 5, 72, 0, 74, 
    6, 30, 7, 28, 1, 54, 5, 70, 2, 43, 4, 44, 3, 49, 8, 48, 0, 68, 
    4, 85, 1, 61, 5, 89, 2,  9, 3, 65, 0, 35, 6, 27, 8, 24, 7, 41, 
    0,  2, 1, 77, 5, 17, 8, 59, 7, 58, 3, 31, 2, 85, 6, 99, 4, 21, 
    4,  1, 0,  8, 5, 99, 7, 10, 1, 29, 3, 63, 6, 13, 8, 78, 2, 13, 
    6, 24, 7, 28, 2, 62, 0, 52, 5, 40, 3, 40, 8, 80, 1, 22, 4, 26, 
    7, 32, 3, 74, 6, 33, 4, 21, 2, 37, 0, 70, 8, 20, 1, 87, 5, 55
  };
  const int q4160[] = {
    9, 9, // Number of jobs and machines
    1, 32, 8, 99, 7, 15, 2, 61, 4, 23, 5, 64, 3, 68, 0, 87, 6, 90, 
    5, 12, 6, 11, 3, 48, 4, 71, 2, 78, 7, 28, 8, 23, 1, 61, 0, 10, 
    2, 73, 1, 28, 0, 68, 5,  3, 6, 91, 4, 39, 3, 64, 8, 12, 7,  8, 
    8, 93, 5, 98, 3, 57, 0,  9, 1, 48, 7,  3, 2, 41, 4, 21, 6, 38, 
    0,  2, 4, 91, 7, 69, 3, 80, 6,  7, 5, 12, 1, 13, 8, 68, 2, 94, 
    1, 57, 0, 22, 4,  8, 6, 51, 2, 90, 5, 74, 3, 12, 8, 16, 7, 37, 
    7, 72, 4, 77, 2, 55, 6, 91, 8, 59, 3, 13, 1, 42, 5, 23, 0, 90, 
    6, 87, 3, 51, 7, 62, 1, 94, 2, 44, 5, 29, 4, 21, 8, 53, 0, 57, 
    6, 53, 7, 87, 2, 33, 3, 71, 1, 32, 4, 32, 8, 89, 5, 33, 0,  2
  };
  const int q4161[] = {
    9, 9, // Number of jobs and machines
    4, 37, 2, 98, 5, 88, 1, 55, 6, 32, 3, 27, 7, 65, 0, 48, 8, 22, 
    5, 44, 2, 32, 1, 14, 8, 65, 4, 10, 6, 90, 3,  3, 7, 72, 0, 37, 
    0, 93, 4, 14, 1, 28, 8,  5, 2, 97, 6, 43, 5, 26, 3, 80, 7, 98, 
    0,  4, 7, 80, 4, 98, 1, 62, 5, 53, 8,  2, 6, 28, 2, 65, 3, 35, 
    0, 60, 2, 10, 1, 61, 5,  4, 3,  6, 8, 44, 7,  4, 4, 81, 6, 84, 
    8, 75, 3, 41, 7, 74, 2, 83, 1, 61, 0, 24, 5, 47, 6, 19, 4, 70, 
    8, 56, 5, 66, 6, 55, 4, 93, 3, 48, 7, 39, 1, 37, 2, 97, 0, 71, 
    0, 56, 8, 13, 1, 28, 2, 18, 7, 17, 5,  9, 6, 36, 4, 51, 3, 38, 
    8, 35, 0, 63, 3, 76, 2, 80, 7, 40, 5, 92, 4, 47, 6, 72, 1, 93
  };
  const int q4162[] = {
    9, 9, // Number of jobs and machines
    8, 20, 3, 31, 7, 30, 0, 21, 2, 88, 5, 81, 6, 25, 4, 83, 1, 40, 
    3, 34, 5, 57, 1, 98, 7,  8, 2, 94, 4, 92, 0, 72, 8, 18, 6, 82, 
    8, 63, 1, 31, 4, 32, 2, 12, 0, 94, 3, 69, 5, 79, 6, 50, 7, 21, 
    0, 76, 4, 33, 3, 38, 6,  8, 8, 44, 1, 34, 2, 78, 5, 17, 7,  8, 
    0, 83, 6, 52, 3, 14, 1, 71, 5, 80, 4, 55, 7, 25, 8, 21, 2, 87, 
    8, 79, 3,  7, 0, 92, 7, 74, 4, 30, 5, 96, 2, 58, 1, 47, 6, 50, 
    2, 91, 6,  2, 0, 79, 8, 57, 1, 78, 7, 22, 5, 72, 3, 17, 4, 14, 
    5, 18, 2, 75, 6, 70, 7, 21, 8, 75, 0, 95, 3, 99, 1, 77, 4, 46, 
    1,  1, 4, 60, 8, 75, 6, 94, 2, 11, 0, 10, 5, 17, 7, 99, 3, 87
  };
  const int q4163[] = {
    9, 9, // Number of jobs and machines
    7, 54, 3, 46, 0, 29, 4, 30, 6,  9, 5, 55, 2, 60, 1, 99, 8,  4, 
    7, 64, 2, 15, 0, 33, 8, 91, 5, 76, 4, 85, 1, 11, 6, 55, 3, 27, 
    2, 11, 3, 77, 4, 10, 0, 57, 1, 15, 7,  5, 8, 43, 6, 15, 5, 99, 
    4,  5, 2, 85, 3, 65, 5, 99, 0, 49, 1, 19, 7,  6, 6, 86, 8, 98, 
    7, 36, 6, 10, 8,  8, 0, 58, 2, 20, 5, 91, 4, 84, 1, 85, 3, 80, 
    7, 91, 3, 48, 1, 64, 6, 77, 2,  7, 0, 47, 4, 11, 5, 68, 8, 94, 
    6,  5, 3, 24, 2, 14, 4, 86, 7, 88, 5, 85, 0, 78, 1, 88, 8, 56, 
    6, 76, 2, 52, 5, 52, 8, 27, 3,  4, 1,  2, 4, 28, 7, 95, 0, 93, 
    0, 49, 5, 16, 3, 20, 8, 88, 7, 32, 6, 51, 1, 30, 2, 11, 4, 53
  };
  const int q4164[] = {
    9, 9, // Number of jobs and machines
    2, 65, 8, 71, 7, 67, 4, 99, 3, 78, 5, 19, 1, 31, 6, 49, 0, 43, 
    2,  6, 8, 84, 3, 73, 4, 54, 1, 39, 0,  6, 5, 24, 6, 96, 7, 69, 
    8, 41, 0, 34, 4, 97, 6, 99, 2,  4, 5, 54, 3, 56, 7, 60, 1,  9, 
    4, 99, 5, 47, 7,  7, 1, 14, 2, 13, 8, 49, 3, 30, 6, 26, 0, 99, 
    2, 86, 3, 94, 4, 95, 1, 59, 6,  6, 8, 20, 7, 15, 5, 43, 0, 20, 
    0, 36, 4, 70, 6, 71, 8, 18, 3, 49, 2, 76, 1, 19, 5,  6, 7, 94, 
    4, 10, 6, 68, 0, 43, 7,  6, 1, 33, 8, 56, 5, 60, 2, 31, 3, 55, 
    5, 30, 1, 80, 4, 64, 7, 92, 2, 26, 6, 42, 8, 52, 0, 88, 3, 13, 
    4,  6, 3, 43, 5, 51, 1, 50, 6,  4, 0, 32, 2, 35, 8, 38, 7, 89
  };
  const int q4165[] = {
    9, 9, // Number of jobs and machines
    3, 34, 2, 28, 1, 31, 7, 32, 6, 98, 0, 66, 4, 79, 8, 56, 5, 55, 
    6, 84, 1, 66, 5,  7, 0, 45, 2,  5, 7, 50, 8, 93, 3, 10, 4, 96, 
    8, 31, 6, 22, 7, 71, 3, 77, 2, 35, 0, 95, 4, 46, 5, 31, 1, 25, 
    2, 38, 8, 93, 3, 31, 6, 13, 5, 29, 7, 46, 4,  3, 0, 45, 1, 45, 
    3, 17, 6, 32, 5, 83, 7, 99, 2, 12, 1, 47, 4, 61, 0, 93, 8, 33, 
    0, 14, 4, 21, 8, 99, 7, 86, 5, 19, 3, 24, 6, 43, 2, 66, 1, 42, 
    5, 19, 6, 15, 3, 64, 1, 43, 7, 46, 2,  4, 0, 45, 4, 67, 8, 48, 
    6, 60, 1, 73, 5, 20, 8, 68, 0, 81, 2, 40, 7, 70, 4, 84, 3, 88, 
    4, 81, 3, 13, 6, 83, 1, 18, 0, 66, 2, 80, 8, 77, 7, 89, 5, 74
  };
  const int q4166[] = {
    9, 9, // Number of jobs and machines
    4, 36, 6, 54, 5, 61, 3, 65, 0, 23, 8, 81, 2, 77, 7, 74, 1, 74, 
    0, 74, 4, 21, 3, 66, 6, 99, 8, 84, 7, 83, 2, 53, 5, 82, 1, 13, 
    0, 25, 4, 91, 7, 48, 8,  3, 2, 62, 5, 29, 1, 50, 6, 79, 3, 17, 
    8, 64, 1, 79, 2, 26, 0, 57, 7, 66, 3, 55, 4, 53, 6, 17, 5, 32, 
    1, 82, 3, 99, 7, 86, 8, 54, 4, 82, 0, 91, 6, 69, 2,  9, 5, 76, 
    7, 74, 2, 71, 0, 87, 1,  3, 5, 59, 4, 98, 3, 47, 6, 83, 8, 38, 
    6, 79, 2, 41, 1, 99, 7, 37, 5, 42, 4, 78, 8, 39, 0, 78, 3, 14, 
    6, 16, 3, 72, 4, 96, 5, 24, 1, 24, 8, 33, 2, 51, 7, 76, 0, 70, 
    3, 22, 5, 74, 8, 32, 4,  5, 6, 39, 7, 28, 0,  5, 1, 58, 2, 58
  };
  const int q4167[] = {
    9, 9, // Number of jobs and machines
    5, 79, 0, 22, 1, 40, 8, 15, 4, 32, 6, 84, 7,  8, 3, 17, 2, 95, 
    2, 43, 6, 83, 7,  9, 1, 82, 3, 47, 4, 87, 8, 41, 5, 14, 0, 45, 
    6, 29, 3, 87, 5, 78, 1,  6, 8, 90, 2, 77, 0, 87, 4, 77, 7, 64, 
    1, 10, 4, 41, 8, 40, 6, 92, 0, 21, 5, 51, 2, 26, 3, 25, 7, 90, 
    8, 19, 2,  8, 0, 72, 4, 55, 7, 32, 3, 36, 1, 89, 6, 70, 5, 65, 
    4, 89, 7, 84, 2,  8, 6, 62, 5, 59, 8, 63, 3, 65, 0, 51, 1, 30, 
    1, 15, 8, 43, 0,  4, 6, 92, 4, 59, 3, 45, 7, 62, 5, 37, 2, 91, 
    3, 87, 0, 51, 7, 27, 8, 96, 5, 93, 2, 17, 1, 88, 6,  7, 4, 55, 
    5,  8, 6, 98, 1, 26, 8, 40, 7, 21, 0, 47, 4, 10, 2, 91, 3, 95
  };
  const int q4168[] = {
    9, 9, // Number of jobs and machines
    0, 86, 8, 70, 3, 65, 6, 43, 1, 72, 2, 83, 7, 64, 4, 73, 5, 73, 
    6, 93, 8, 31, 3, 62, 1,  6, 4, 25, 0, 69, 5, 24, 7, 67, 2, 50, 
    6,  1, 1, 86, 0, 25, 7, 45, 2, 45, 5, 55, 3, 45, 4, 32, 8, 45, 
    8, 87, 4, 69, 6, 89, 2, 19, 5, 48, 1,  4, 7, 27, 3, 69, 0, 86, 
    7,  7, 2, 78, 0,  6, 4, 42, 3, 25, 6, 87, 5, 26, 8, 93, 1, 47, 
    4, 24, 3, 44, 8, 20, 1, 71, 0, 37, 2,  3, 6, 34, 7, 51, 5, 27, 
    7, 11, 6, 90, 5, 44, 8, 86, 1, 82, 4, 28, 3, 47, 2,  9, 0,  5, 
    8, 74, 4, 19, 2,  2, 3, 36, 5, 69, 6, 67, 0, 57, 1, 56, 7, 22, 
    6, 57, 7, 49, 4, 61, 3, 87, 1, 35, 0, 25, 8, 78, 5,  2, 2, 89
  };
  const int q4169[] = {
    9, 9, // Number of jobs and machines
    3, 33, 1, 49, 7, 31, 2, 79, 0, 21, 4, 74, 6, 93, 8, 18, 5, 25, 
    1, 88, 7,  4, 3, 64, 5, 49, 2, 70, 6, 79, 0, 88, 4, 67, 8, 69, 
    2, 45, 6, 83, 5, 99, 4, 51, 7, 87, 1,  8, 0,  3, 3, 45, 8, 63, 
    3, 57, 6, 69, 1,  4, 0, 78, 4, 67, 7, 85, 2, 14, 8, 85, 5, 63, 
    2, 33, 0, 75, 6, 75, 8, 15, 4, 14, 5, 90, 3, 46, 7, 94, 1, 88, 
    6, 58, 2, 22, 3, 60, 8, 62, 4, 76, 7, 23, 0, 31, 5, 86, 1, 36, 
    4, 34, 1, 61, 0,  8, 3, 64, 6,  5, 8,  7, 2, 41, 7, 46, 5, 76, 
    5,  4, 0, 84, 8, 90, 1,  4, 7, 61, 6, 72, 2, 56, 3, 48, 4,  5, 
    2, 72, 7, 39, 4,  3, 0, 91, 1, 92, 8, 23, 6, 71, 3, 66, 5, 56
  };
  const int q4170[] = {
    9, 9, // Number of jobs and machines
    5, 74, 2, 10, 1, 21, 6, 38, 8, 73, 7, 30, 0, 86, 4, 21, 3, 41, 
    3, 43, 0, 65, 7,  6, 8, 77, 6, 35, 1, 37, 4, 52, 5, 50, 2, 88, 
    8,  9, 5, 58, 3, 42, 1, 96, 2, 66, 7, 80, 6, 67, 0, 39, 4, 33, 
    5, 97, 1, 47, 0, 10, 6, 70, 2, 33, 3,  2, 8, 84, 4, 93, 7, 96, 
    6, 48, 8, 38, 5, 20, 7, 56, 4, 31, 3, 74, 1, 56, 2, 13, 0, 51, 
    3, 60, 0, 61, 4, 65, 8, 81, 7, 70, 2, 32, 6, 96, 1, 69, 5, 76, 
    3, 87, 4,  6, 0, 22, 6, 79, 5, 74, 1, 29, 8, 13, 7,  4, 2, 33, 
    4, 75, 3, 63, 7, 31, 1, 56, 6,  5, 8, 47, 5, 35, 0, 36, 2, 78, 
    6, 13, 2, 65, 1, 32, 8, 62, 5, 29, 7, 11, 4, 25, 0, 66, 3, 93
  };
  const int q4171[] = {
    9, 9, // Number of jobs and machines
    8,  9, 1, 52, 0, 47, 5, 97, 4, 27, 3, 61, 2, 21, 6, 42, 7,  9, 
    2, 78, 3, 46, 5, 33, 6,  2, 0, 30, 1, 49, 4, 44, 8, 55, 7, 80, 
    4, 99, 7, 63, 3, 63, 8, 86, 1, 24, 0,  4, 5, 39, 2, 91, 6, 61, 
    4, 29, 2, 46, 5, 48, 6, 38, 0, 93, 1, 63, 3, 32, 7, 91, 8, 17, 
    0, 81, 6, 78, 4, 56, 7,  3, 1, 53, 3, 74, 2, 44, 5, 64, 8,  7, 
    0, 91, 5, 78, 3, 14, 7, 74, 8, 19, 6, 34, 1, 99, 4, 83, 2, 53, 
    1, 72, 8, 37, 4,  2, 2, 17, 6, 75, 7, 21, 0,  7, 3, 15, 5, 97, 
    1, 26, 4, 85, 2, 54, 5, 65, 6, 75, 7, 89, 8, 32, 3, 67, 0, 61, 
    3, 32, 1, 76, 4, 73, 7, 49, 6, 99, 2, 98, 0, 31, 8,  5, 5, 61
  };
  const int q4172[] = {
    9, 9, // Number of jobs and machines
    2, 88, 1, 15, 6,  5, 5, 21, 8, 61, 4,  4, 0, 74, 3, 78, 7, 13, 
    3, 12, 6, 57, 5, 57, 2, 45, 1, 14, 8, 37, 4, 66, 0, 53, 7, 37, 
    1, 59, 8, 74, 7, 79, 2, 58, 0, 41, 6,  1, 4, 66, 5, 15, 3, 34, 
    1, 93, 5, 33, 0, 74, 3, 66, 7, 17, 6, 23, 8, 49, 4, 65, 2, 52, 
    4, 15, 0, 63, 6, 84, 8, 79, 5, 32, 3, 36, 7, 51, 1, 68, 2,  1, 
    8, 58, 0,  2, 4, 50, 2, 72, 6, 87, 1, 31, 3, 98, 5, 37, 7, 48, 
    4, 25, 7, 50, 1, 48, 3, 21, 0,  5, 5, 70, 2, 35, 8, 21, 6, 87, 
    7, 87, 2,  2, 1, 66, 5, 33, 0, 75, 4,  3, 8, 45, 3, 99, 6, 10, 
    6, 66, 5, 18, 3,  1, 2, 95, 1,  8, 4, 50, 8,  1, 7, 77, 0, 70
  };
  const int q4173[] = {
    9, 9, // Number of jobs and machines
    1, 70, 3, 19, 4, 75, 2, 78, 8, 10, 0,  3, 6, 25, 7, 79, 5, 35, 
    5, 25, 6, 18, 1, 75, 3, 81, 8,  1, 4, 77, 2, 60, 7,  2, 0, 43, 
    5, 24, 0, 41, 6, 96, 3, 75, 8, 82, 4, 61, 7, 91, 2, 81, 1, 11, 
    5, 36, 7, 14, 0, 52, 4, 88, 8, 87, 2,  5, 6, 93, 1, 24, 3, 26, 
    3, 55, 2, 82, 5, 40, 1, 33, 7, 13, 8, 54, 0, 25, 4, 92, 6, 61, 
    0, 65, 8, 68, 6, 88, 5, 77, 3, 98, 2, 30, 7, 96, 1, 22, 4, 88, 
    7, 98, 2,  3, 0, 32, 6,  2, 1, 86, 3, 79, 4, 49, 8, 98, 5, 58, 
    5, 55, 7, 91, 6, 66, 4, 15, 1, 11, 2, 93, 0, 20, 3, 97, 8, 64, 
    7,  8, 3, 90, 6, 15, 5, 53, 4, 92, 8,  1, 0,  7, 1, 75, 2, 17
  };
  const int q4174[] = {
    9, 9, // Number of jobs and machines
    6, 33, 4, 45, 0, 23, 5, 85, 3, 84, 7, 86, 1, 94, 2, 37, 8, 34, 
    6, 49, 7, 24, 0, 35, 8, 97, 2, 27, 5, 49, 1, 41, 4, 39, 3,  2, 
    1, 58, 3, 86, 7, 89, 6, 88, 2, 90, 8, 73, 5, 77, 4, 33, 0, 48, 
    0, 85, 5, 34, 3, 29, 6, 21, 2, 64, 4, 39, 8, 23, 1, 79, 7, 28, 
    0, 33, 2, 93, 3, 14, 5, 95, 7, 79, 8, 37, 6, 44, 1,  2, 4, 87, 
    3, 73, 5, 38, 1, 55, 6, 63, 0, 10, 7, 11, 2,  2, 4, 93, 8, 27, 
    8,  6, 0, 44, 4, 86, 6, 54, 7, 75, 2, 49, 5, 36, 3, 61, 1, 24, 
    1, 20, 3, 17, 4, 92, 5, 56, 0, 72, 7, 30, 6, 90, 8, 46, 2, 24, 
    7, 42, 3, 95, 6, 39, 1, 52, 0, 68, 8, 96, 4, 38, 2, 67, 5, 47
  };
  const int q4175[] = {
    9, 9, // Number of jobs and machines
    1, 79, 6, 67, 0, 16, 7,  5, 5, 75, 3, 39, 4,  3, 2, 34, 8, 30, 
    2,  8, 1, 98, 6, 81, 3, 43, 8, 87, 7, 86, 0, 49, 5, 22, 4, 10, 
    8, 86, 5, 99, 1, 95, 2, 88, 7, 52, 6,  1, 3, 87, 4, 72, 0, 15, 
    0, 25, 7, 34, 8, 86, 2, 72, 3,  7, 4, 94, 6, 44, 5, 63, 1, 30, 
    8, 50, 1, 28, 3, 96, 2, 84, 0, 81, 5, 25, 4, 18, 7, 98, 6, 33, 
    2, 47, 3, 81, 6, 40, 7, 46, 5, 56, 8, 56, 4, 90, 0, 74, 1, 21, 
    0, 11, 1,  1, 5, 13, 8, 58, 2, 99, 7, 72, 4, 82, 3, 72, 6, 47, 
    0,  9, 7, 81, 2,  2, 8, 36, 6, 53, 1, 73, 3, 23, 5, 92, 4, 98, 
    8, 21, 2, 96, 5, 80, 7, 91, 3, 21, 0,  4, 4, 37, 6, 57, 1, 96
  };
  const int q4176[] = {
    9, 9, // Number of jobs and machines
    1,  5, 5, 96, 4, 13, 0, 88, 3, 46, 6, 74, 7,  9, 8, 35, 2, 44, 
    7, 34, 1, 25, 8, 68, 2, 99, 5, 10, 6, 82, 0,  7, 4, 58, 3, 21, 
    8, 45, 5, 64, 2, 79, 7, 69, 4, 59, 1, 56, 6, 70, 3, 42, 0, 36, 
    5, 71, 2, 99, 0, 89, 7, 39, 3, 72, 8,  6, 4, 26, 1, 52, 6, 19, 
    7, 97, 1,  8, 4, 56, 5, 99, 3, 29, 8, 89, 2, 32, 0, 74, 6, 97, 
    6, 59, 1, 97, 5,  1, 8, 76, 0, 70, 2, 60, 3, 40, 7, 91, 4, 85, 
    1, 42, 3, 77, 2, 46, 4, 10, 8, 52, 7, 69, 5, 19, 0, 29, 6, 74, 
    7, 63, 3, 61, 5, 58, 8, 29, 1,  9, 4, 23, 2, 59, 6, 40, 0, 60, 
    4, 67, 8, 72, 0, 52, 5, 16, 7, 23, 6,  8, 1, 37, 2, 88, 3, 50
  };
  const int q4177[] = {
    9, 9, // Number of jobs and machines
    4, 28, 8, 43, 5, 42, 6,  1, 1, 92, 2, 11, 0, 22, 3, 99, 7, 57, 
    1, 22, 7, 91, 4, 15, 6, 95, 5, 80, 0, 20, 8, 40, 2, 63, 3, 45, 
    8, 83, 4,  5, 6, 70, 7, 37, 5, 12, 0, 56, 2, 37, 1, 85, 3, 11, 
    0, 98, 5, 26, 4, 12, 3, 91, 2, 54, 7, 81, 1, 71, 6, 76, 8, 90, 
    1, 63, 8, 70, 6, 89, 7,  3, 2, 70, 3, 92, 0, 57, 4,  5, 5, 43, 
    8, 56, 1, 93, 5, 40, 0, 73, 6, 67, 2, 95, 7, 51, 3, 64, 4, 66, 
    1, 77, 4, 22, 3, 73, 0, 75, 6,  8, 5, 90, 2, 43, 8, 66, 7, 49, 
    0, 70, 2, 46, 4,  3, 5, 60, 1, 31, 3, 23, 8, 58, 7, 98, 6, 62, 
    0, 51, 2, 79, 4, 59, 1, 53, 7, 95, 8, 42, 6, 72, 5, 90, 3, 25
  };
  const int q4178[] = {
    9, 9, // Number of jobs and machines
    1, 87, 6, 59, 0, 49, 4,  8, 2, 51, 7, 88, 8, 17, 3, 95, 5, 20, 
    5, 68, 6, 60, 3, 98, 8, 12, 1, 43, 0, 28, 4, 88, 7, 30, 2, 65, 
    8, 46, 2,  1, 5, 73, 0, 35, 3, 83, 1, 13, 4, 54, 7,  6, 6,  8, 
    0, 43, 5, 72, 8, 45, 2, 91, 7, 29, 4, 46, 3, 41, 1, 17, 6, 76, 
    4, 81, 5, 71, 0,  6, 1, 83, 6, 74, 7,  6, 8, 94, 3, 83, 2,  7, 
    4, 18, 2, 34, 3, 79, 7, 87, 0,  3, 5, 90, 1, 23, 6, 32, 8, 21, 
    7, 74, 5, 46, 4, 10, 0,  9, 8, 15, 6, 64, 1, 40, 3,  2, 2, 62, 
    0,  7, 7, 30, 5, 40, 6, 37, 4,  8, 2, 27, 1, 13, 3, 23, 8, 43, 
    5, 22, 1, 10, 0, 68, 2, 69, 8, 54, 6, 75, 3, 46, 4, 58, 7, 85
  };
  const int q4179[] = {
    9, 9, // Number of jobs and machines
    4, 95, 5, 37, 1, 19, 3, 95, 8,  1, 2, 51, 6, 40, 0,  4, 7,  7, 
    1,  7, 7, 87, 6, 78, 4, 65, 5, 74, 8, 61, 3, 92, 0, 97, 2, 37, 
    7, 74, 4, 80, 1, 93, 3, 57, 8,  2, 0, 17, 2, 37, 6, 92, 5, 99, 
    2, 74, 4,  5, 7, 29, 1, 34, 3, 29, 0, 30, 5, 26, 8, 34, 6, 72, 
    8, 16, 3,  6, 6, 19, 0, 37, 2, 55, 7,  3, 4, 78, 5, 72, 1, 36, 
    2, 82, 8, 29, 0, 13, 4,  8, 1, 62, 7, 87, 3, 16, 5, 37, 6, 25, 
    1, 81, 8, 94, 4, 28, 0, 98, 3, 59, 5, 32, 6, 87, 7,  2, 2, 68, 
    6, 78, 4, 83, 3, 50, 1, 73, 8, 29, 0,  5, 5,  6, 2, 17, 7, 56, 
    6, 18, 0, 92, 4, 75, 3, 19, 1, 26, 8, 24, 7, 47, 2, 83, 5, 29
  };
  const int q4180[] = {
    9, 9, // Number of jobs and machines
    7, 21, 4, 95, 8, 55, 5, 98, 6, 85, 2, 88, 1, 80, 0, 76, 3, 24, 
    6, 78, 3, 10, 5, 17, 0, 60, 4, 61, 1, 22, 7, 58, 8, 40, 2, 40, 
    8, 52, 6, 34, 7, 41, 2, 32, 0, 99, 5, 17, 4, 91, 1, 14, 3, 40, 
    3, 10, 4, 80, 1,  7, 6, 11, 8, 97, 7, 49, 5, 79, 2, 82, 0, 59, 
    8, 74, 2, 69, 3, 98, 1, 45, 5, 19, 6, 67, 4, 83, 7,  8, 0, 44, 
    6,  7, 4, 26, 3, 56, 7, 36, 1, 67, 8, 15, 2, 68, 0, 53, 5, 63, 
    2, 90, 4, 52, 7, 50, 3, 29, 1, 97, 8, 60, 6, 56, 5, 75, 0, 32, 
    6, 31, 4, 81, 2, 94, 0, 27, 3, 53, 5, 64, 1, 61, 8, 31, 7, 94, 
    8, 47, 4, 30, 5, 17, 1, 97, 0, 91, 6, 94, 3, 10, 7, 75, 2, 42
  };
  const int q4181[] = {
    9, 9, // Number of jobs and machines
    7, 50, 2, 95, 5, 57, 4, 71, 8, 60, 0, 32, 6, 54, 3, 19, 1, 27, 
    1, 84, 2, 25, 6, 70, 3, 50, 0, 29, 5, 40, 4, 22, 7, 92, 8, 75, 
    2, 17, 3, 49, 8, 70, 4, 48, 7, 22, 1, 18, 0, 48, 6, 62, 5, 19, 
    0, 71, 6, 91, 8, 48, 5, 57, 1, 49, 2, 40, 7, 83, 3,  4, 4, 83, 
    6, 73, 8, 46, 3,  3, 4, 92, 5, 35, 0, 21, 1, 93, 2, 97, 7, 56, 
    8, 29, 6, 10, 7, 51, 5, 39, 4, 64, 2, 29, 3, 15, 0, 10, 1, 10, 
    0, 15, 1, 31, 6, 78, 4, 92, 8, 29, 7, 40, 2, 48, 3, 28, 5,  6, 
    1, 33, 2, 24, 0,  9, 6, 37, 8, 82, 5,  2, 4, 78, 7, 11, 3,  6, 
    0, 97, 5, 94, 1, 80, 3, 71, 7, 29, 8, 86, 4, 63, 6, 58, 2, 49
  };
  const int q4182[] = {
    9, 9, // Number of jobs and machines
    6, 78, 5,  1, 8, 17, 2, 20, 7, 17, 3, 17, 1, 17, 0, 44, 4, 94, 
    8, 44, 1, 39, 4,  6, 7, 54, 0, 31, 5, 27, 6, 40, 2,  8, 3, 14, 
    2, 80, 3, 46, 1,  8, 8, 89, 5, 32, 7, 83, 0, 37, 6,  6, 4, 53, 
    0, 20, 6, 14, 3, 58, 8, 88, 7, 41, 2, 26, 4, 99, 1, 63, 5, 32, 
    3, 27, 0, 22, 7, 40, 5, 96, 2, 42, 6, 19, 4, 53, 8, 54, 1, 33, 
    2, 95, 7, 75, 1, 79, 4, 46, 5,  8, 6, 92, 3, 53, 0, 76, 8, 93, 
    4, 48, 7, 82, 2, 35, 1, 10, 5,  2, 8, 17, 3, 14, 0, 65, 6, 44, 
    3, 16, 5, 12, 6, 99, 4, 98, 1, 94, 7, 59, 8, 34, 2,  4, 0, 69, 
    7, 28, 0, 76, 5, 27, 3, 81, 4, 88, 6, 10, 1, 56, 8, 79, 2, 78
  };
  const int q4183[] = {
    9, 9, // Number of jobs and machines
    5, 77, 4, 55, 2, 87, 3, 72, 6, 18, 8, 73, 1, 55, 7, 66, 0, 57, 
    2, 23, 3, 66, 8, 81, 1, 36, 5,  6, 4, 36, 7, 94, 0, 54, 6, 52, 
    5, 49, 3, 22, 2, 93, 4, 30, 7, 91, 8, 96, 1, 88, 0, 47, 6, 67, 
    6,  1, 5, 38, 2, 60, 3, 39, 7, 51, 4,  3, 0, 17, 1, 32, 8, 94, 
    5, 64, 8, 91, 2, 95, 7, 81, 0, 67, 3, 26, 4, 48, 1, 95, 6,  7, 
    8, 54, 5, 81, 7, 71, 4, 36, 2, 85, 6, 15, 1, 21, 0, 85, 3, 66, 
    8, 53, 7, 53, 6, 26, 3, 17, 4, 83, 0,  9, 1, 97, 2, 98, 5, 48, 
    0, 32, 8, 92, 4, 42, 7,  6, 3, 17, 5, 30, 2, 33, 1, 33, 6, 82, 
    6, 36, 3, 55, 4, 56, 5, 84, 8, 70, 0, 93, 2, 31, 7, 92, 1, 18
  };
  const int q4184[] = {
    9, 9, // Number of jobs and machines
    3, 17, 2, 54, 0,  2, 7, 73, 5, 24, 8, 28, 6,  5, 4, 86, 1, 91, 
    2, 23, 5, 57, 4, 30, 8, 41, 3, 76, 1, 86, 0, 45, 6, 89, 7, 40, 
    2, 47, 0, 56, 8,  9, 1, 62, 3, 27, 6, 96, 7, 53, 5, 33, 4, 93, 
    3,  9, 8, 45, 2, 24, 6, 80, 7, 89, 4, 98, 5, 51, 0, 27, 1, 89, 
    8, 11, 6, 31, 2, 17, 4, 34, 5, 32, 7, 80, 3, 67, 1, 73, 0, 36, 
    8, 27, 2, 64, 5, 59, 1, 33, 0, 75, 7, 88, 6, 48, 4, 91, 3, 92, 
    7, 47, 5, 94, 6, 51, 3, 22, 1, 23, 2, 25, 8, 24, 0, 34, 4,  7, 
    4, 99, 0, 23, 6,  1, 2, 66, 5, 57, 7, 35, 3, 75, 1,  7, 8, 36, 
    1, 24, 8, 46, 6, 65, 3, 15, 7,  5, 0, 44, 4,  7, 2, 73, 5, 25
  };
  const int q4185[] = {
    9, 9, // Number of jobs and machines
    2, 48, 6,  8, 1, 25, 0, 92, 4,  8, 5, 73, 3, 12, 7, 91, 8, 26, 
    6, 10, 4, 59, 8, 89, 2, 82, 1, 13, 3, 61, 5, 52, 0, 19, 7, 96, 
    2, 24, 1, 57, 0, 54, 3, 58, 6, 26, 8, 49, 5,  8, 4, 66, 7, 66, 
    3, 28, 4, 25, 6, 94, 1, 62, 2, 57, 7, 43, 0, 49, 8, 95, 5, 14, 
    1, 53, 5, 43, 2, 77, 3, 19, 7, 85, 0, 52, 6, 99, 4, 65, 8, 24, 
    3, 52, 2, 78, 1, 70, 5, 11, 4, 58, 6, 15, 8, 67, 7, 28, 0, 32, 
    2, 55, 0,  3, 1, 72, 6, 80, 8, 67, 3, 19, 7, 72, 5, 98, 4, 13, 
    1, 31, 2, 51, 0, 83, 7, 97, 8, 59, 6, 42, 3, 61, 5, 73, 4, 37, 
    6, 81, 0, 43, 7, 97, 4, 90, 1, 56, 5, 40, 3, 98, 2, 68, 8, 93
  };
  const int q4186[] = {
    9, 9, // Number of jobs and machines
    6, 40, 7, 93, 5, 76, 4, 70, 8, 52, 1, 72, 0, 32, 3, 95, 2, 32, 
    4, 53, 1, 55, 8, 90, 3, 75, 2, 96, 0, 43, 5, 86, 6, 97, 7, 69, 
    3, 34, 5, 34, 1, 62, 2, 50, 7, 13, 0, 10, 6,  6, 8, 87, 4, 26, 
    8, 36, 4, 80, 0, 77, 5, 71, 3, 24, 6, 41, 1, 66, 2, 95, 7, 54, 
    1, 15, 4, 22, 7, 19, 5, 68, 0, 75, 3, 95, 6, 84, 2, 14, 8, 68, 
    2, 52, 5, 36, 7, 43, 3,  2, 4, 64, 6, 27, 0, 38, 1, 87, 8, 99, 
    4, 61, 1, 76, 5, 99, 6, 98, 2, 62, 3,  9, 7, 98, 8, 80, 0, 49, 
    5, 26, 3, 23, 2, 68, 7, 52, 1, 24, 6,  6, 8, 59, 4, 91, 0, 48, 
    0,  6, 4, 61, 6, 88, 2, 78, 7, 16, 8, 63, 1, 20, 5, 67, 3, 47
  };
  const int q4187[] = {
    9, 9, // Number of jobs and machines
    5, 74, 3, 61, 4, 92, 1, 30, 7, 90, 0, 91, 8, 57, 2, 77, 6,  7, 
    0, 67, 1, 60, 8,  4, 3, 78, 2,  4, 4, 99, 7, 98, 6, 65, 5, 67, 
    4, 90, 3, 88, 2, 96, 1, 27, 6, 66, 8, 73, 7, 28, 0, 56, 5, 63, 
    5,  8, 1, 59, 7, 53, 6, 74, 3, 45, 0, 24, 2, 20, 8, 41, 4, 60, 
    0, 19, 3, 63, 6, 48, 1, 42, 8, 65, 7, 56, 4, 15, 2, 15, 5, 75, 
    4, 58, 5, 86, 1, 57, 8, 65, 7, 71, 2, 47, 6, 79, 3, 90, 0, 47, 
    1,  5, 3, 55, 2, 94, 5, 37, 8, 29, 4, 50, 6, 90, 7, 90, 0, 52, 
    8,  8, 4, 18, 6, 39, 7, 10, 5, 77, 0, 72, 1, 41, 3, 61, 2, 37, 
    8, 26, 0, 16, 3, 79, 2, 38, 4, 57, 6, 53, 5, 35, 1, 42, 7, 43
  };
  const int q4188[] = {
    9, 9, // Number of jobs and machines
    1, 13, 5, 83, 4, 80, 2, 72, 8, 97, 7, 93, 0, 69, 3, 41, 6, 43, 
    4, 22, 1, 30, 8, 23, 7, 15, 5, 44, 3, 14, 0, 13, 2, 12, 6, 83, 
    0, 68, 2, 54, 3, 94, 5, 18, 6, 15, 7, 25, 4, 42, 8, 50, 1, 25, 
    5, 79, 7,  2, 4,  4, 3, 60, 1, 53, 2, 46, 0, 82, 8, 13, 6, 92, 
    5, 67, 1, 82, 8, 18, 6,  7, 0, 82, 2, 66, 4, 76, 7, 86, 3, 39, 
    0, 15, 8, 49, 3, 63, 5, 63, 7, 82, 4, 35, 6, 70, 1, 40, 2, 24, 
    6, 57, 5,  8, 0, 25, 1,  9, 2, 15, 3, 99, 8, 41, 4, 92, 7, 14, 
    5, 87, 7, 99, 4, 76, 2, 48, 0, 37, 1, 37, 6, 46, 8,  4, 3, 59, 
    8,  6, 1,  2, 6,  9, 0, 84, 2, 74, 7, 47, 5, 84, 4, 72, 3, 64
  };
  const int q4189[] = {
    9, 9, // Number of jobs and machines
    0, 91, 5,  3, 8, 23, 7, 17, 6, 15, 2, 77, 1, 13, 3, 77, 4,  9, 
    4, 95, 0, 94, 7, 95, 5, 65, 2, 77, 3, 67, 6, 87, 8, 13, 1, 65, 
    7, 10, 6, 87, 0, 28, 3, 16, 4,  6, 8, 37, 2, 82, 1, 16, 5, 75, 
    6, 97, 4, 56, 3,  3, 5,  9, 8, 69, 0, 48, 2, 72, 1, 83, 7, 86, 
    4, 69, 1, 21, 8, 20, 2, 66, 6, 31, 7, 41, 3, 50, 0, 46, 5, 75, 
    5, 87, 3, 65, 4, 23, 8, 86, 6, 80, 1, 28, 7, 89, 0, 75, 2, 98, 
    1, 15, 0, 56, 7, 44, 2, 61, 3, 66, 8, 68, 4, 58, 5, 32, 6,  4, 
    3,  6, 1, 91, 2, 60, 4,  6, 7, 47, 5, 53, 8, 24, 6, 93, 0, 73, 
    7, 16, 0, 60, 5, 27, 2, 73, 8, 51, 3, 88, 1, 82, 6, 32, 4, 67
  };
  const int q4190[] = {
    9, 9, // Number of jobs and machines
    0, 94, 5, 52, 3, 67, 2, 44, 4, 21, 1, 90, 6, 90, 7,  4, 8, 53, 
    6, 64, 5, 68, 8, 10, 7, 87, 2, 45, 3, 85, 0, 79, 4, 51, 1, 31, 
    7, 28, 2, 98, 5, 90, 3, 21, 4, 27, 0, 26, 1, 51, 6, 51, 8, 10, 
    2, 32, 4, 71, 5, 45, 7, 23, 0, 62, 1, 20, 8, 49, 3, 13, 6, 81, 
    2, 29, 7, 53, 0, 70, 3, 72, 6,  8, 4, 48, 1, 61, 5, 28, 8, 55, 
    4, 77, 5,  9, 1, 60, 6, 46, 0, 95, 3, 94, 7, 51, 8, 57, 2, 35, 
    2, 81, 4,  5, 1, 51, 0, 80, 3, 63, 6, 15, 7,  7, 8,  8, 5, 32, 
    0, 68, 6, 96, 4, 37, 2, 90, 1, 26, 7, 34, 5, 25, 8, 24, 3, 76, 
    6, 17, 5, 82, 4, 42, 1,  1, 3, 72, 8, 28, 7, 97, 0, 14, 2, 82
  };
  const int q4191[] = {
    9, 9, // Number of jobs and machines
    8, 78, 7, 21, 3, 38, 1, 36, 5, 38, 6, 25, 4, 17, 2, 81, 0, 76, 
    3, 86, 2, 55, 8, 97, 4, 59, 5, 26, 1, 93, 0, 41, 6, 69, 7, 16, 
    2, 85, 7, 87, 5, 99, 3, 30, 0, 56, 4, 51, 6, 38, 8, 37, 1,  5, 
    7, 91, 6, 60, 4, 10, 1, 17, 2, 20, 8, 49, 5, 93, 3, 60, 0, 78, 
    8, 43, 3, 70, 4, 55, 0, 24, 5, 86, 6, 53, 7, 46, 1, 25, 2, 85, 
    1,  9, 7, 82, 6, 59, 3, 29, 2, 23, 0,  3, 5, 42, 4, 37, 8, 30, 
    0, 66, 7, 46, 5, 37, 3, 57, 8,  6, 6, 25, 4, 59, 1, 77, 2, 64, 
    1, 51, 4, 37, 3, 19, 7, 75, 8, 68, 6, 90, 0, 26, 5, 26, 2, 72, 
    0, 44, 1, 41, 6, 19, 2,  7, 8,  1, 3, 80, 7, 16, 5, 49, 4, 84
  };
  const int q4192[] = {
    9, 9, // Number of jobs and machines
    7,  1, 6, 32, 8, 76, 1, 83, 2, 18, 4,  7, 0, 81, 3, 84, 5, 30, 
    4,  7, 2, 32, 6, 83, 5, 80, 8, 90, 1, 81, 0, 94, 7, 51, 3, 41, 
    8, 37, 0, 95, 4, 44, 5, 10, 7, 29, 1, 82, 2, 40, 3, 95, 6, 31, 
    5, 98, 2, 11, 3, 67, 6, 30, 8,  4, 7, 49, 0, 93, 4, 36, 1,  5, 
    6, 16, 1, 26, 5, 24, 3, 73, 2, 54, 7, 67, 4, 70, 8, 62, 0, 17, 
    1, 84, 7, 21, 6, 82, 8, 61, 3, 92, 0, 42, 5, 98, 2,  9, 4, 15, 
    1, 87, 6, 62, 2,  2, 7, 20, 0, 30, 4, 38, 3, 69, 5, 31, 8, 38, 
    4,  4, 1, 82, 2, 42, 3, 10, 5, 86, 0, 83, 7, 12, 8, 25, 6, 91, 
    4, 13, 1, 61, 5, 43, 3, 25, 2, 63, 6, 44, 7, 46, 8, 99, 0, 58
  };
  const int q4193[] = {
    9, 9, // Number of jobs and machines
    1, 87, 2, 69, 0, 60, 8, 25, 7, 28, 4, 84, 3, 84, 6, 69, 5, 89, 
    1, 52, 8, 68, 0,  7, 5, 23, 3, 30, 4, 54, 7, 26, 6, 60, 2, 44, 
    5, 43, 0, 43, 8, 62, 3,  3, 4, 73, 2, 88, 6, 53, 7, 34, 1, 26, 
    5, 62, 7, 37, 6, 20, 0, 33, 1, 37, 3, 19, 2, 57, 4, 64, 8, 90, 
    6, 99, 3, 36, 8, 92, 4, 95, 7, 63, 5, 64, 0, 29, 2, 35, 1, 97, 
    5, 53, 0, 64, 6, 95, 2, 45, 3, 21, 1, 87, 7, 21, 4, 56, 8, 77, 
    2, 62, 8, 30, 0, 51, 3, 90, 4, 78, 5, 56, 1, 11, 7, 25, 6, 42, 
    8, 65, 1, 90, 0, 70, 4, 87, 6, 79, 5, 54, 3, 14, 2, 28, 7, 65, 
    6, 68, 7, 69, 5,  3, 4, 79, 3, 45, 1, 80, 0, 82, 8, 52, 2,  2
  };
  const int q4194[] = {
    9, 9, // Number of jobs and machines
    2, 53, 5, 56, 1, 10, 8,  9, 6, 30, 7, 86, 4, 76, 3, 64, 0, 68, 
    7, 40, 8, 23, 4, 61, 3, 78, 1, 35, 2, 71, 6, 74, 5, 55, 0, 62, 
    8, 30, 1, 40, 6, 66, 7, 54, 4, 68, 5, 36, 3, 15, 0, 39, 2, 24, 
    0, 59, 8, 79, 7, 86, 4, 32, 1, 21, 2, 44, 5, 62, 3, 95, 6, 13, 
    5, 55, 3, 20, 7, 81, 1, 26, 8, 51, 4, 66, 6, 99, 0, 62, 2, 10, 
    0,  6, 4, 11, 3, 10, 7,  7, 2, 22, 1, 43, 5, 91, 8, 41, 6, 54, 
    7, 83, 8, 88, 4, 37, 5, 98, 2, 34, 0, 20, 1, 85, 6, 27, 3, 63, 
    8, 87, 3, 42, 5, 59, 2, 18, 4, 99, 1, 66, 0, 18, 6, 65, 7, 59, 
    0, 90, 7, 41, 5,  6, 1, 66, 6, 75, 4, 12, 2, 20, 3, 89, 8, 31
  };
  const int q4195[] = {
    9, 9, // Number of jobs and machines
    2, 40, 0, 65, 8, 82, 7, 18, 1,  6, 4, 68, 6, 21, 3, 55, 5, 54, 
    2, 39, 3, 19, 5, 12, 8, 64, 0, 96, 7, 84, 6, 79, 1, 33, 4, 28, 
    2, 13, 4, 53, 8, 41, 7, 59, 1, 14, 5, 35, 6, 58, 3, 67, 0,  9, 
    6, 79, 1, 94, 4, 81, 2, 17, 5, 23, 8, 32, 7,  5, 0, 94, 3, 94, 
    4, 66, 6,  9, 3,  5, 8, 91, 5, 84, 0, 45, 1, 77, 2, 29, 7, 86, 
    0, 55, 4, 14, 6, 99, 7, 33, 5, 26, 2, 16, 3, 46, 1, 45, 8, 28, 
    5, 14, 7, 94, 4, 51, 2, 92, 3, 24, 8, 13, 1, 79, 0, 64, 6, 60, 
    4, 73, 2, 80, 3, 88, 7, 77, 6, 23, 8, 78, 0, 69, 1, 89, 5, 59, 
    2, 52, 6, 97, 3, 92, 1, 18, 4, 49, 7, 36, 0, 73, 8, 80, 5, 11
  };
  const int q4196[] = {
    9, 9, // Number of jobs and machines
    0, 34, 3, 27, 7, 37, 1, 35, 6, 96, 4, 59, 8, 83, 5, 58, 2, 36, 
    0, 38, 2, 21, 3, 74, 7, 73, 5,  4, 4, 21, 1, 87, 6, 65, 8, 50, 
    5, 40, 2, 67, 3,  8, 4, 94, 6, 89, 1, 19, 0, 60, 7, 74, 8, 48, 
    1, 78, 0, 62, 3, 98, 7, 92, 2, 59, 4,  5, 8, 18, 6, 79, 5, 41, 
    8, 89, 7, 57, 5,  4, 2, 35, 4, 20, 3, 83, 0, 26, 6, 19, 1, 37, 
    7, 68, 5, 13, 0, 80, 1, 28, 2, 27, 3, 12, 6, 11, 4, 20, 8, 22, 
    6, 88, 1, 63, 3, 13, 0, 89, 5, 31, 2, 94, 8, 95, 7, 96, 4, 49, 
    4, 91, 6, 63, 7, 49, 1,  2, 0, 90, 8, 73, 2,  1, 5, 75, 3, 56, 
    2, 70, 0, 43, 1, 13, 4, 84, 3,  2, 8, 58, 7,  2, 6, 74, 5, 44
  };
  const int q4197[] = {
    9, 9, // Number of jobs and machines
    5, 13, 7, 91, 3, 64, 2, 75, 6, 38, 8, 24, 1, 53, 0, 36, 4, 64, 
    8, 25, 6,  1, 0, 49, 1, 14, 2, 37, 3, 26, 7, 53, 5, 37, 4, 22, 
    7, 67, 5, 11, 4, 62, 2, 71, 8, 61, 6, 95, 3, 76, 0, 32, 1, 78, 
    3, 33, 7, 52, 2, 76, 1, 61, 4, 81, 8, 65, 6, 61, 0, 24, 5, 82, 
    4, 48, 2, 14, 6, 90, 1, 66, 0, 31, 3, 34, 8, 86, 7, 53, 5, 33, 
    0, 88, 8, 65, 4, 45, 5, 96, 6,  5, 2, 25, 1, 99, 3, 16, 7, 92, 
    6, 85, 7, 65, 5, 78, 2, 51, 0, 40, 3, 16, 1, 77, 4, 42, 8, 40, 
    6, 85, 2, 26, 3, 65, 8, 63, 1, 67, 4, 58, 0, 78, 7, 69, 5, 61, 
    7, 98, 1, 12, 0, 30, 8, 19, 6, 69, 3, 55, 4, 31, 5, 25, 2, 14
  };
  const int q4198[] = {
    9, 9, // Number of jobs and machines
    2, 84, 0, 15, 5, 73, 4, 93, 1, 83, 7, 21, 8, 48, 3, 78, 6, 65, 
    2, 20, 8, 77, 7, 84, 0, 24, 4, 62, 1, 38, 6, 97, 3, 21, 5, 53, 
    3, 97, 2, 59, 8, 90, 4, 78, 6, 13, 7, 18, 1, 37, 0, 64, 5, 31, 
    8, 57, 0, 31, 7,  2, 5, 19, 1, 46, 2, 42, 4, 90, 6, 49, 3,  3, 
    0, 73, 2, 53, 7,  3, 6, 67, 8, 21, 1, 79, 5, 34, 4, 16, 3,  6, 
    3, 12, 8, 29, 6, 77, 5, 57, 7,  2, 1, 88, 2, 29, 4,  9, 0, 53, 
    0, 62, 7, 46, 4, 94, 3, 13, 8, 46, 2, 65, 6, 56, 1,  4, 5, 48, 
    7, 31, 0, 65, 5, 25, 6, 17, 8, 12, 4, 85, 2, 69, 1, 38, 3, 80, 
    7, 96, 3, 48, 6, 56, 5, 33, 4, 14, 1, 11, 0, 83, 8,  1, 2,  7
  };
  const int q4199[] = {
    9, 9, // Number of jobs and machines
    5, 91, 6, 78, 8, 43, 3,  6, 2, 29, 4,  9, 7, 39, 0, 30, 1, 14, 
    8, 96, 3, 25, 6, 18, 5, 97, 4, 88, 2, 77, 7, 78, 1, 27, 0, 34, 
    3, 35, 0, 93, 5,  1, 8, 89, 7, 55, 2, 67, 6, 13, 1, 47, 4, 32, 
    4,  5, 7, 90, 3,  8, 5,  5, 6, 32, 1, 16, 8, 83, 0,  2, 2, 24, 
    4, 70, 6, 74, 8, 87, 0, 74, 1, 11, 5, 72, 3, 81, 2, 92, 7, 79, 
    3, 27, 4, 49, 8, 75, 0, 39, 2,  8, 5, 48, 7, 69, 6, 44, 1, 23, 
    7, 41, 5, 12, 8, 18, 0, 67, 2, 73, 6, 25, 4, 92, 3, 50, 1,  3, 
    0, 88, 7, 27, 2, 64, 1, 50, 3, 39, 6,  2, 8, 36, 5, 74, 4, 48, 
    5, 11, 7, 54, 0, 66, 1, 35, 4, 53, 8, 14, 6, 50, 2, 36, 3, 20
  };
  const int q4200[] = {
    9, 9, // Number of jobs and machines
    5, 37, 2, 47, 0,  6, 7, 65, 4, 45, 6, 55, 8, 71, 3, 61, 1, 40, 
    2, 82, 3, 29, 5, 63, 4, 61, 0, 65, 6, 12, 8, 18, 7, 52, 1,  6, 
    1, 64, 2, 44, 6, 16, 5,  5, 0, 42, 7, 18, 4, 98, 8, 94, 3, 63, 
    1, 37, 3,  4, 7, 66, 2, 51, 4, 35, 0,  1, 5,  1, 6, 61, 8, 77, 
    7, 43, 2, 42, 1, 23, 3, 69, 5, 65, 6, 45, 8,  9, 4, 45, 0,  8, 
    4, 83, 6, 95, 8, 58, 7, 16, 2, 28, 3, 26, 1, 47, 0, 40, 5, 48, 
    7,  6, 2, 18, 0, 62, 1, 38, 6, 32, 3, 93, 8, 31, 5, 67, 4, 14, 
    3, 41, 2, 22, 4, 14, 5, 80, 6, 44, 1, 21, 8, 56, 0, 50, 7, 65, 
    1, 65, 0, 14, 3, 45, 8, 66, 7, 21, 4, 40, 2, 98, 5, 86, 6, 21
  };
  const int q4201[] = {
    9, 9, // Number of jobs and machines
    6, 94, 3, 16, 1, 95, 4, 37, 5, 99, 0, 42, 8, 79, 7, 15, 2, 17, 
    5, 32, 1, 51, 4,  1, 3, 66, 8, 45, 6, 68, 0,  8, 2, 64, 7, 45, 
    1, 88, 7, 45, 3, 80, 4, 98, 5, 97, 0, 17, 2, 55, 6, 87, 8, 20, 
    0, 83, 2, 87, 7, 61, 4, 77, 3, 22, 6, 57, 8, 29, 5, 87, 1, 68, 
    1, 32, 0, 15, 2, 44, 5, 68, 7, 15, 6, 76, 3,  2, 4, 45, 8, 76, 
    8, 15, 3, 12, 6,  6, 2, 85, 0, 69, 7, 12, 4,  3, 1, 78, 5, 34, 
    5, 21, 4, 44, 6,  6, 3,  4, 2,  7, 0, 84, 8, 83, 1, 17, 7, 11, 
    2, 57, 8,  8, 1, 91, 4, 62, 5, 68, 7,  5, 3, 64, 0, 75, 6, 45, 
    7, 60, 4, 45, 3, 76, 8, 27, 1, 15, 5, 23, 0, 61, 6, 22, 2, 13
  };
  const int q4202[] = {
    9, 9, // Number of jobs and machines
    7,  5, 5, 73, 2, 51, 6, 20, 4,  6, 3, 84, 1, 18, 0, 17, 8,  3, 
    8, 65, 7, 55, 5, 55, 4, 39, 6,  9, 0, 29, 2, 15, 1, 90, 3, 27, 
    0, 11, 4,  1, 1, 86, 5, 73, 2,  7, 8, 53, 6,  6, 3, 17, 7, 51, 
    4, 82, 0, 17, 1, 68, 3, 33, 2, 67, 8, 26, 5, 51, 6, 82, 7, 57, 
    1, 41, 7, 63, 3,  3, 8, 71, 0, 59, 2, 69, 6,  4, 4, 70, 5, 71, 
    6, 74, 7, 46, 3,  7, 4, 83, 8, 63, 0, 83, 2, 76, 5,  1, 1, 65, 
    2, 74, 5, 77, 0, 48, 3, 19, 8, 95, 1,  6, 6, 83, 7,  8, 4,  2, 
    8, 42, 5, 24, 0, 56, 6, 64, 1, 35, 4, 91, 2, 67, 3, 34, 7, 52, 
    3, 44, 2, 11, 0, 60, 5, 99, 7, 51, 1, 71, 6,  1, 4, 49, 8, 73
  };
  const int q4203[] = {
    9, 9, // Number of jobs and machines
    1, 89, 2,  8, 6, 52, 4, 24, 8,  6, 5, 62, 0, 96, 3, 31, 7, 50, 
    7, 97, 8, 22, 2, 73, 4, 83, 6, 19, 0, 82, 5, 77, 1, 42, 3, 98, 
    4,  1, 1, 51, 2, 93, 8, 52, 0, 86, 3, 77, 6, 19, 7,  1, 5, 56, 
    0, 53, 7,  5, 5, 98, 8, 77, 3, 64, 4, 21, 2,  1, 6, 21, 1, 65, 
    4, 80, 1, 50, 2, 10, 7, 36, 8, 30, 3, 64, 0,  9, 6, 59, 5, 73, 
    7, 62, 1, 62, 8, 56, 5, 83, 0,  1, 2, 31, 6, 51, 3, 22, 4, 40, 
    2, 39, 3, 68, 7, 37, 0,  9, 8, 20, 5, 41, 4, 18, 1, 65, 6, 14, 
    8,  3, 2, 51, 7, 39, 3,  9, 4, 78, 5, 95, 1, 17, 6,  4, 0, 17, 
    0, 58, 8, 92, 3, 10, 5, 33, 4, 50, 6, 25, 2, 16, 7, 62, 1, 78
  };
  const int q4204[] = {
    9, 9, // Number of jobs and machines
    6, 61, 2, 31, 0, 63, 3, 57, 7, 53, 4, 34, 8, 13, 1, 77, 5, 30, 
    2, 84, 1, 58, 7, 96, 8, 37, 3, 38, 4, 65, 5, 96, 6, 82, 0,  9, 
    5, 87, 4, 63, 1, 62, 6, 69, 8, 28, 0, 48, 2, 69, 7, 26, 3, 65, 
    7, 31, 1, 65, 5, 74, 2,  5, 8, 59, 0, 81, 4, 31, 6, 22, 3, 23, 
    5, 75, 2, 61, 6, 99, 3, 50, 8, 13, 7, 19, 1, 99, 0, 58, 4, 76, 
    3, 37, 2, 67, 1, 76, 5, 63, 4, 66, 6, 95, 8, 53, 0, 75, 7, 12, 
    6, 56, 1, 87, 8, 12, 7, 85, 5, 30, 3, 84, 4, 13, 2, 21, 0, 94, 
    8, 98, 3, 72, 2, 27, 6, 52, 5, 83, 1, 96, 7, 60, 0, 95, 4, 17, 
    7, 24, 8, 85, 2, 37, 6, 75, 5, 65, 0, 89, 1,  6, 4, 34, 3, 23
  };
  const int q4205[] = {
    9, 9, // Number of jobs and machines
    3, 95, 7, 29, 0, 15, 2, 60, 8, 61, 5, 51, 1, 60, 6, 96, 4, 43, 
    7, 41, 3, 86, 4, 66, 1, 59, 2, 54, 8, 88, 5,  3, 6,  7, 0, 89, 
    7, 70, 2, 75, 0, 79, 8, 19, 3, 45, 6, 78, 5, 22, 4, 63, 1, 26, 
    2, 69, 6, 18, 0,  6, 8, 16, 4, 81, 1, 58, 7, 41, 3, 38, 5, 27, 
    2, 10, 5, 39, 4, 22, 8, 23, 0, 22, 3, 33, 7, 59, 1, 50, 6, 43, 
    1, 14, 3, 26, 0, 44, 8, 17, 6, 16, 5, 72, 4, 48, 2, 23, 7, 18, 
    5, 69, 4, 54, 0,  1, 3, 58, 7, 66, 8,  6, 6, 98, 2, 69, 1, 70, 
    8, 47, 2, 55, 4, 42, 3, 28, 6,  7, 7, 69, 0, 14, 1, 88, 5, 18, 
    1, 70, 0,  7, 7,  6, 5, 78, 2,  9, 3, 52, 4, 69, 8, 54, 6, 46
  };
  const int q4206[] = {
    9, 9, // Number of jobs and machines
    7, 75, 5, 99, 0, 34, 2,  5, 8,  6, 1, 35, 6, 18, 4, 43, 3, 70, 
    1, 56, 6, 47, 0, 76, 5, 42, 3, 97, 4, 40, 8, 84, 7, 47, 2, 88, 
    6, 87, 1, 32, 8, 52, 7, 72, 0, 51, 2, 23, 5, 63, 4, 58, 3, 41, 
    0, 41, 2, 83, 4, 90, 8, 21, 6, 74, 5, 39, 3,  1, 7, 50, 1, 88, 
    3, 94, 0, 25, 1, 92, 4, 35, 2, 14, 6, 24, 5, 46, 8, 51, 7, 66, 
    3, 84, 4, 88, 6, 24, 1, 24, 7, 94, 5,  6, 0, 95, 8, 56, 2, 39, 
    2, 27, 8, 87, 5, 94, 4, 26, 7, 11, 6, 51, 1,  2, 3, 45, 0, 37, 
    5, 97, 1, 95, 8, 60, 4, 25, 0, 22, 6,  9, 3, 48, 2, 35, 7, 64, 
    3, 64, 5,  4, 6, 39, 1, 41, 7, 50, 0, 53, 4, 48, 8, 66, 2, 97
  };
  const int q4207[] = {
    9, 9, // Number of jobs and machines
    0, 62, 1, 20, 8, 18, 2, 67, 4, 26, 7, 50, 3, 70, 6, 82, 5, 30, 
    2, 97, 1, 11, 3, 74, 7, 37, 6, 57, 0, 31, 4, 22, 5, 55, 8, 85, 
    6,  4, 4,  2, 7, 68, 1, 53, 3, 62, 8, 69, 2, 57, 0, 45, 5, 90, 
    5, 77, 4, 21, 3, 12, 8, 90, 7, 24, 2,  1, 0, 30, 1, 89, 6, 51, 
    1, 66, 7, 58, 2, 96, 6, 63, 5, 85, 8, 41, 0, 49, 3, 81, 4, 20, 
    4, 19, 5, 88, 2, 59, 3, 57, 0, 74, 8, 97, 7, 48, 6, 40, 1, 20, 
    8, 96, 6, 66, 2, 55, 3, 22, 0, 38, 5, 32, 1,  6, 7, 86, 4, 66, 
    4, 19, 6, 34, 5,  2, 7, 61, 8, 78, 2, 36, 1, 21, 3, 16, 0, 10, 
    2,  8, 3, 80, 1, 10, 5, 86, 4, 36, 7,  4, 8, 48, 0, 42, 6, 70
  };
  const int q4208[] = {
    9, 9, // Number of jobs and machines
    8, 43, 1, 74, 3, 48, 2,  3, 5, 34, 6, 46, 0, 10, 4, 23, 7, 20, 
    5, 20, 6, 54, 3, 43, 8, 82, 4, 98, 2, 70, 0, 91, 7, 88, 1, 62, 
    4, 20, 0,  6, 3, 85, 8, 19, 2, 35, 7, 64, 1, 81, 5, 32, 6, 85, 
    7, 29, 6, 69, 5, 96, 8, 73, 1, 41, 3, 74, 4, 66, 2, 53, 0,  6, 
    6, 10, 0, 63, 8, 31, 2,  6, 7, 25, 3,  8, 4, 85, 5, 93, 1, 49, 
    4, 43, 2, 74, 0, 99, 7, 19, 8, 59, 5, 76, 6, 80, 1, 56, 3, 97, 
    0, 68, 3, 34, 4, 96, 2,  9, 7, 68, 6, 64, 8, 50, 1, 58, 5, 42, 
    0, 58, 8, 70, 2,  3, 3, 63, 6, 27, 1, 68, 7, 89, 5, 85, 4,  1, 
    1,  7, 4, 13, 3, 12, 7, 18, 0, 21, 5, 98, 8, 40, 2, 74, 6, 10
  };
  const int q4209[] = {
    9, 9, // Number of jobs and machines
    2, 48, 8, 25, 0, 81, 4, 92, 3, 51, 5, 61, 7, 47, 6, 54, 1,  2, 
    3, 79, 7, 43, 0, 64, 6, 83, 2, 25, 4, 68, 1, 16, 8, 14, 5, 72, 
    1, 87, 4, 60, 5, 96, 3,  9, 0, 97, 7, 39, 2, 21, 8, 21, 6, 54, 
    6, 48, 2, 80, 5, 83, 7, 68, 8, 74, 1, 40, 4, 47, 0, 25, 3, 27, 
    3, 54, 1, 86, 8, 92, 0, 15, 7, 47, 4, 17, 5, 82, 6, 46, 2, 48, 
    3,  5, 6, 68, 0, 77, 2, 73, 1, 57, 8, 12, 5, 40, 4, 22, 7, 28, 
    4, 90, 6, 44, 7, 89, 5, 84, 1, 55, 0, 10, 3, 60, 8, 90, 2, 63, 
    1, 90, 4, 24, 2, 24, 5, 99, 6, 40, 3, 89, 0, 70, 7, 36, 8, 67, 
    1, 31, 8, 94, 2, 88, 5, 48, 7, 56, 6, 54, 0, 36, 3, 53, 4, 71
  };
  const int q4210[] = {
    9, 9, // Number of jobs and machines
    3, 15, 4, 59, 6, 48, 8, 65, 7, 54, 5, 12, 1, 40, 2,  9, 0, 54, 
    2, 95, 3, 29, 4, 66, 0, 54, 7,  9, 8, 76, 6,  7, 5,  4, 1, 94, 
    7, 98, 2, 32, 4, 33, 6, 98, 5, 65, 0, 26, 3, 52, 8, 18, 1, 54, 
    8,  6, 4, 84, 6, 35, 3, 99, 1, 37, 0, 75, 2, 78, 7, 63, 5, 63, 
    0, 31, 4, 52, 1,  5, 5, 47, 7,  3, 2, 34, 3, 34, 8, 91, 6, 78, 
    7, 24, 6, 83, 0, 59, 3, 18, 1, 81, 2, 79, 5, 38, 8, 67, 4, 96, 
    6, 63, 8, 16, 2, 24, 4, 74, 1, 11, 3, 17, 0, 56, 5, 41, 7, 30, 
    2, 78, 0,  1, 1, 23, 5, 53, 4, 74, 6,  5, 3, 60, 7, 47, 8,  7, 
    2, 96, 4, 18, 3, 55, 6, 57, 0, 54, 7,  8, 8, 54, 5, 63, 1, 63
  };
  const int q4211[] = {
    9, 9, // Number of jobs and machines
    3, 57, 4,  2, 7, 56, 2, 53, 6, 72, 5, 97, 0, 59, 8, 87, 1, 77, 
    5, 73, 2, 95, 7, 64, 8, 39, 6, 54, 1, 54, 0, 89, 3, 98, 4, 34, 
    3, 50, 0, 35, 8, 93, 7, 96, 4, 77, 5, 42, 6, 81, 1, 12, 2,  3, 
    8, 94, 1, 12, 5, 78, 2, 37, 0, 16, 3, 86, 7, 46, 6, 60, 4, 90, 
    6, 52, 7, 10, 1, 74, 2, 38, 8, 91, 4, 54, 5, 99, 0, 91, 3, 90, 
    8, 93, 5, 26, 2, 99, 4, 91, 7, 79, 3, 49, 0, 30, 1, 33, 6, 57, 
    3, 87, 2, 45, 7, 91, 1,  2, 5, 34, 4,  4, 6, 72, 0, 78, 8,  6, 
    5, 10, 3, 98, 4, 62, 2, 16, 6,  3, 8, 72, 1, 94, 7, 81, 0, 19, 
    4, 96, 3, 71, 8, 58, 6, 53, 0, 21, 1, 91, 5, 90, 7, 97, 2,  6
  };
  const int q4212[] = {
    9, 9, // Number of jobs and machines
    0, 61, 8,  6, 1, 51, 4, 58, 2, 76, 7,  5, 3, 59, 6, 69, 5, 97, 
    5, 49, 3, 27, 1, 61, 2, 31, 4, 11, 7, 33, 6, 41, 0, 77, 8, 34, 
    5, 90, 0, 87, 3, 95, 2, 80, 8, 16, 6, 41, 1, 48, 4,  6, 7, 79, 
    1, 90, 3, 55, 4, 74, 5, 87, 7, 21, 2, 89, 8, 85, 0, 57, 6, 61, 
    0, 14, 4, 71, 7, 54, 5, 86, 6, 59, 3, 86, 2, 31, 1, 16, 8, 36, 
    2,  4, 7, 40, 1, 95, 0, 19, 8, 70, 5, 31, 6,  8, 3, 38, 4,  1, 
    6, 47, 5, 66, 7, 94, 0, 93, 1, 34, 3, 18, 2, 80, 8, 14, 4, 76, 
    8, 49, 1, 93, 5, 74, 3, 14, 7, 43, 0, 74, 4, 55, 6,  5, 2, 46, 
    2, 19, 8, 32, 0, 51, 7, 22, 4, 52, 3, 25, 1, 21, 5,  3, 6, 91
  };
  const int q4213[] = {
    9, 9, // Number of jobs and machines
    5, 84, 8, 85, 1, 60, 7, 92, 2, 32, 6, 74, 0, 58, 3, 54, 4, 73, 
    5, 49, 3, 66, 4, 17, 0, 93, 8, 75, 6, 51, 7, 71, 2, 46, 1, 42, 
    4, 82, 6,  9, 3, 90, 2, 96, 7, 47, 1, 94, 8, 86, 5, 81, 0, 79, 
    4, 85, 7, 64, 3, 73, 8, 11, 6, 31, 1, 43, 0, 88, 2, 46, 5,  4, 
    8, 74, 1, 56, 2, 47, 7, 99, 3, 28, 5, 56, 6, 13, 0, 77, 4, 77, 
    5, 13, 7, 78, 1, 46, 6, 39, 8, 51, 4, 80, 0, 73, 3, 61, 2,  5, 
    1, 84, 3, 84, 8, 57, 5, 89, 7, 40, 2,  3, 6, 87, 0, 93, 4, 16, 
    2, 39, 0, 59, 3, 71, 1, 97, 5, 36, 8, 73, 7, 30, 4, 35, 6, 79, 
    6, 49, 5, 30, 7, 48, 4, 44, 1, 61, 2,  1, 0, 73, 8, 17, 3, 34
  };
  const int q4214[] = {
    9, 9, // Number of jobs and machines
    2, 50, 6, 34, 1, 58, 8, 15, 4, 55, 0, 12, 7, 55, 5, 57, 3, 89, 
    1, 93, 7, 46, 3, 93, 6, 67, 4, 85, 2, 38, 5, 51, 0, 41, 8, 94, 
    7,  7, 5, 19, 1, 97, 4, 69, 0, 66, 6, 33, 3, 58, 2, 49, 8, 31, 
    8, 34, 1, 60, 0, 14, 4, 54, 6, 41, 7, 42, 5, 99, 3, 74, 2, 41, 
    6, 45, 5, 16, 3,  7, 4, 36, 8, 66, 0, 50, 7, 81, 1, 47, 2, 14, 
    2,  6, 5, 93, 4, 69, 7, 49, 8, 35, 3, 65, 6, 96, 0, 72, 1, 33, 
    8, 24, 5, 68, 2, 39, 1, 75, 0, 32, 6, 77, 3, 13, 4, 35, 7, 69, 
    8, 23, 4, 40, 1, 41, 0, 24, 6, 68, 5, 62, 3, 73, 7, 61, 2, 15, 
    5, 17, 6, 14, 7, 74, 2, 85, 1, 74, 0, 28, 3, 79, 4, 91, 8,  8
  };
  const int q4215[] = {
    9, 9, // Number of jobs and machines
    8, 23, 3, 81, 1, 31, 4, 37, 7, 68, 5, 38, 0, 72, 2, 79, 6, 17, 
    8, 36, 2,  5, 5, 23, 6, 88, 0, 77, 3, 80, 4, 54, 7, 81, 1, 89, 
    1, 19, 2, 60, 7, 93, 5, 33, 0,  8, 8, 97, 3, 24, 6, 62, 4, 10, 
    3, 19, 6, 99, 5, 98, 1, 51, 4, 77, 8, 58, 0, 90, 7, 93, 2, 70, 
    8, 23, 1, 28, 4, 65, 6,  6, 3, 40, 0, 56, 7, 87, 2,  8, 5, 37, 
    7, 78, 3, 46, 2, 35, 8, 32, 6, 82, 4, 80, 5, 34, 1, 72, 0,  3, 
    4, 54, 3, 78, 2, 86, 1,  7, 0, 70, 8, 13, 5, 93, 7, 98, 6, 85, 
    4, 99, 5,  8, 3, 83, 6, 61, 7, 19, 8, 74, 0, 69, 1, 33, 2, 42, 
    8, 24, 5, 23, 1, 99, 2, 33, 6, 28, 4, 59, 3, 56, 7, 68, 0, 54
  };
  const int q4216[] = {
    9, 9, // Number of jobs and machines
    8, 35, 6, 74, 7, 84, 5, 71, 0, 24, 2, 31, 3, 79, 4, 94, 1, 62, 
    7,  7, 4, 12, 8, 78, 0, 22, 3, 52, 2, 67, 5,  1, 1, 83, 6, 95, 
    3, 95, 7, 53, 2, 34, 1, 40, 0, 84, 6, 72, 4,  8, 5, 24, 8, 68, 
    8, 81, 5, 16, 3, 86, 4, 74, 1, 60, 0, 87, 6, 50, 7, 55, 2,  1, 
    3, 78, 2, 71, 6, 96, 0, 25, 7, 75, 1, 54, 4, 67, 8, 75, 5, 66, 
    2, 76, 3, 72, 6, 22, 0, 15, 1, 28, 7, 19, 8, 70, 4, 48, 5, 55, 
    3, 18, 8, 42, 7, 21, 2, 14, 5, 52, 4, 25, 1, 52, 0, 82, 6, 77, 
    4, 60, 5, 45, 3, 74, 7, 14, 0, 23, 6,  3, 8, 39, 2, 23, 1, 24, 
    3,  3, 8, 82, 2, 85, 5, 79, 0, 95, 7, 36, 6, 77, 4, 83, 1,  7
  };
  const int q4217[] = {
    9, 9, // Number of jobs and machines
    6, 50, 7, 42, 2, 72, 1, 61, 8, 39, 4, 81, 5, 74, 3, 65, 0, 93, 
    1, 94, 5, 87, 3, 57, 2,  5, 6, 73, 4, 34, 7, 87, 8, 25, 0, 74, 
    3, 67, 4, 36, 1, 45, 5, 38, 0, 84, 2, 39, 7, 93, 6, 84, 8, 48, 
    1, 63, 5, 12, 7, 55, 6,  5, 0, 90, 4, 10, 8, 50, 2, 61, 3, 50, 
    4, 55, 8, 46, 3, 83, 5, 81, 1, 21, 6, 52, 2, 22, 0, 38, 7,  2, 
    3, 36, 1,  5, 2, 81, 6,  1, 8, 71, 5, 39, 4, 88, 0, 33, 7,  7, 
    1, 82, 2, 22, 5, 97, 0, 24, 7,  1, 4, 26, 8, 75, 6, 13, 3, 23, 
    3, 67, 0, 68, 2, 40, 7, 87, 6, 47, 4, 47, 5, 40, 1, 47, 8, 35, 
    8,  8, 5, 91, 0, 91, 4, 93, 6, 51, 7, 87, 2, 54, 3, 14, 1, 34
  };
  const int q4218[] = {
    9, 9, // Number of jobs and machines
    5, 81, 1, 88, 8, 18, 4, 95, 6, 81, 7, 47, 3, 48, 0, 79, 2, 76, 
    5, 65, 8, 76, 7, 68, 2, 57, 3, 50, 6, 63, 0, 57, 1, 63, 4, 80, 
    4, 50, 5, 85, 3, 95, 0, 66, 7, 11, 2, 61, 6, 42, 8, 41, 1, 32, 
    7, 95, 5, 74, 3, 17, 8, 84, 0, 70, 2, 15, 6, 56, 1, 68, 4, 61, 
    6, 53, 5, 53, 1, 89, 8, 86, 3, 33, 7, 75, 4, 58, 2, 52, 0, 66, 
    8, 95, 6, 49, 2, 94, 3, 89, 4, 74, 1, 13, 0, 57, 7, 29, 5, 21, 
    1, 65, 0, 96, 7, 65, 2,  2, 4, 56, 5, 26, 6, 13, 8, 59, 3, 84, 
    1, 60, 4, 64, 7, 74, 2, 29, 8, 91, 5,  4, 3, 97, 0, 98, 6, 52, 
    4, 61, 1, 14, 0, 77, 3,  3, 7, 14, 8, 79, 5, 75, 2,  6, 6, 89
  };
  const int q4219[] = {
    9, 9, // Number of jobs and machines
    8, 20, 7, 78, 1, 69, 3, 73, 5, 94, 2, 97, 4, 11, 6, 26, 0,  6, 
    3, 17, 1, 97, 5, 56, 6, 64, 8, 18, 7, 14, 2, 72, 4, 23, 0, 49, 
    8, 81, 3, 96, 7, 29, 0, 34, 2, 48, 1,  1, 5, 15, 4, 17, 6, 42, 
    6, 57, 3, 31, 4, 33, 1, 40, 5, 30, 2, 86, 0, 39, 8, 25, 7, 13, 
    2, 49, 7, 30, 3, 90, 0, 81, 8, 25, 4, 31, 1, 44, 6,  6, 5, 96, 
    3, 24, 0, 65, 6,  7, 7, 63, 2, 61, 8, 46, 4,  8, 5,  9, 1, 33, 
    0, 17, 6, 75, 5, 82, 3, 65, 1, 14, 2, 24, 7, 50, 4,  3, 8, 28, 
    1, 36, 5, 44, 8, 41, 6, 36, 2, 43, 0, 50, 4, 32, 3, 57, 7,  8, 
    2, 96, 5, 29, 8, 81, 0, 73, 3, 23, 4, 99, 6, 75, 1, 57, 7, 11
  };
  const int q4220[] = {
    9, 9, // Number of jobs and machines
    1, 71, 4, 43, 7, 54, 2,  5, 8, 26, 0, 32, 5, 13, 3, 87, 6, 87, 
    7, 41, 4, 85, 6, 20, 8, 89, 0, 26, 3, 81, 1, 18, 5, 49, 2,  8, 
    6, 93, 3, 23, 8, 89, 7, 66, 1, 15, 0, 15, 4,  6, 2, 54, 5, 45, 
    4, 79, 6, 18, 2, 46, 0, 44, 5,  2, 1, 71, 3,  1, 7, 80, 8, 62, 
    7, 94, 1, 31, 8, 70, 2, 42, 4, 87, 0, 28, 3, 17, 6, 48, 5, 67, 
    7, 53, 4, 94, 6, 99, 0, 18, 8, 32, 3, 99, 5, 60, 1, 57, 2, 40, 
    3, 99, 4, 12, 1, 62, 7, 78, 8, 13, 0, 10, 6, 62, 2, 47, 5, 71, 
    7, 17, 2, 13, 0, 69, 5, 28, 4, 60, 8, 93, 3, 28, 6, 60, 1, 46, 
    8, 87, 5, 59, 3, 79, 7, 35, 2,  2, 6, 91, 0, 62, 4, 39, 1,  5
  };
  const int q4221[] = {
    9, 9, // Number of jobs and machines
    2, 94, 5, 38, 6, 48, 4, 72, 8,  1, 0, 87, 1, 13, 3, 39, 7, 37, 
    5, 15, 8,  1, 0, 37, 3, 21, 4, 33, 7, 19, 6, 93, 1,  1, 2, 93, 
    7, 52, 3, 93, 0, 89, 6, 68, 2, 99, 4, 12, 1, 47, 5, 94, 8, 74, 
    5, 58, 0, 14, 8, 44, 4, 19, 7, 16, 3, 26, 1, 90, 6, 57, 2, 91, 
    8, 36, 1, 59, 4,  3, 2, 95, 3, 85, 5, 51, 7, 48, 6, 22, 0, 86, 
    8, 36, 6, 26, 3, 26, 7, 13, 4, 63, 5, 56, 1, 71, 0, 14, 2, 39, 
    7, 75, 2, 52, 8, 94, 3, 17, 4,  8, 1, 42, 0, 36, 5, 38, 6, 98, 
    3, 95, 8, 19, 5, 91, 2, 81, 6, 68, 7, 90, 0, 33, 1, 99, 4, 61, 
    1, 26, 3, 64, 7, 47, 0, 13, 4, 68, 5, 34, 2,  2, 6, 85, 8, 46
  };
  const int q4222[] = {
    9, 9, // Number of jobs and machines
    2, 91, 0, 86, 5,  4, 3, 36, 7, 94, 4, 23, 6,  4, 1, 82, 8, 17, 
    1, 62, 4, 27, 3, 34, 0, 58, 6, 51, 7, 63, 2,  3, 8, 95, 5, 17, 
    7, 94, 8, 74, 6, 41, 5, 82, 3, 41, 4, 20, 0, 32, 2, 73, 1, 13, 
    8, 76, 3, 35, 7, 97, 6, 16, 4, 48, 2, 95, 5, 64, 1, 36, 0, 17, 
    0, 21, 7, 22, 1, 89, 2, 93, 5,  8, 4,  9, 6, 98, 8, 73, 3, 47, 
    1, 73, 3, 25, 0, 62, 5, 39, 4,  5, 7, 12, 2,  8, 6, 29, 8, 28, 
    1, 37, 6, 70, 2, 41, 7, 92, 8, 34, 4, 76, 0, 54, 5, 47, 3, 41, 
    4,  7, 2, 97, 0, 37, 8, 23, 1, 54, 7, 18, 5, 79, 3, 78, 6, 69, 
    0, 11, 6, 43, 7, 43, 4, 51, 8, 60, 2, 63, 3, 68, 5, 15, 1, 18
  };
  const int q4223[] = {
    9, 9, // Number of jobs and machines
    4, 27, 7, 44, 5, 32, 0, 50, 6, 27, 2, 82, 1, 72, 8, 58, 3, 91, 
    0, 65, 6,  2, 5, 51, 2, 17, 1, 33, 4, 55, 7, 23, 3, 79, 8, 50, 
    0, 84, 2, 57, 1, 31, 4, 56, 8, 79, 7, 39, 6, 63, 3, 71, 5,  6, 
    3, 40, 4, 29, 5, 25, 8, 33, 2, 95, 7, 82, 0, 42, 1, 26, 6, 71, 
    6,  3, 4,  2, 1, 58, 8, 33, 3, 70, 0,  6, 5,  8, 7, 59, 2, 62, 
    3, 12, 5, 21, 7, 98, 4, 37, 6, 89, 2, 25, 0, 38, 1, 35, 8, 88, 
    6, 99, 1, 51, 4, 27, 2, 26, 0, 15, 7, 57, 8, 16, 5, 90, 3, 46, 
    1, 36, 7, 44, 2, 11, 0, 91, 8, 37, 3,  4, 4, 84, 5, 84, 6, 60, 
    0, 32, 3,  3, 8, 13, 2, 63, 4, 51, 5, 84, 6, 47, 7, 95, 1, 23
  };
  const int q4224[] = {
    9, 9, // Number of jobs and machines
    7,  1, 8, 20, 0,  7, 3, 71, 2, 95, 5, 69, 1, 18, 6, 93, 4, 80, 
    6, 96, 4, 90, 7, 46, 0, 31, 1, 87, 8, 42, 3, 86, 5, 43, 2, 33, 
    8, 59, 5, 83, 7, 27, 6, 38, 0, 99, 1, 17, 3, 25, 2,  3, 4, 19, 
    5, 34, 0, 64, 2, 97, 7, 37, 6, 45, 8, 50, 4, 75, 1, 19, 3, 36, 
    5,  8, 4,  2, 1, 37, 2, 62, 3, 74, 6, 58, 8, 12, 7, 32, 0, 39, 
    4, 96, 0, 41, 2, 98, 1, 15, 8, 13, 3, 72, 6, 19, 7, 65, 5, 84, 
    3, 61, 1, 20, 0, 33, 2, 49, 5, 82, 8, 82, 7, 17, 4, 38, 6, 19, 
    7, 10, 6, 93, 2, 67, 1, 55, 8, 62, 0, 22, 4, 14, 3, 29, 5,  3, 
    1, 59, 5, 30, 2, 25, 0, 95, 6, 37, 3, 12, 7, 64, 8, 52, 4, 44
  };
  const int q4225[] = {
    9, 9, // Number of jobs and machines
    6, 19, 8, 21, 0, 85, 2, 17, 7, 88, 4, 11, 3, 35, 1, 73, 5, 86, 
    7, 88, 1,  9, 2, 34, 3, 50, 0, 32, 4,  7, 6, 23, 5, 94, 8, 11, 
    5, 78, 8, 92, 0, 24, 1, 89, 2,  5, 7, 52, 4, 93, 6,  7, 3, 22, 
    1, 76, 2, 17, 4, 66, 3, 74, 8, 67, 5, 22, 7, 71, 0,  3, 6, 72, 
    7, 90, 3, 35, 2, 28, 6, 52, 5, 48, 4, 90, 1, 16, 0, 48, 8, 80, 
    6, 38, 7,  5, 3, 36, 1, 48, 5, 86, 2, 81, 0, 97, 8, 37, 4, 37, 
    0, 76, 1, 75, 7, 59, 6, 41, 3, 15, 5, 67, 8, 12, 4, 31, 2, 98, 
    8, 53, 4, 26, 2, 43, 3, 60, 6,  6, 5, 42, 1,  8, 7,  4, 0,  7, 
    6, 18, 5, 16, 0, 57, 7, 84, 8, 10, 2, 74, 4, 97, 3, 28, 1, 50
  };
  const int q4226[] = {
    9, 9, // Number of jobs and machines
    1, 90, 5, 49, 8, 36, 4, 81, 2, 57, 3, 57, 0,  1, 6, 13, 7, 71, 
    6, 40, 0, 99, 7, 34, 2, 61, 1, 66, 3,  6, 8, 98, 5, 97, 4, 87, 
    8, 33, 5, 50, 6, 90, 2, 19, 1, 84, 4, 63, 3, 29, 7, 14, 0, 70, 
    4, 51, 6, 61, 3, 32, 1, 19, 2, 77, 5, 44, 7, 99, 0, 21, 8, 78, 
    5, 62, 0, 59, 1, 17, 3, 97, 4, 82, 2, 31, 8, 35, 6, 51, 7, 50, 
    1, 60, 5, 21, 8, 23, 4, 34, 3,  8, 7, 43, 6,  1, 0, 78, 2, 21, 
    1, 33, 0, 95, 6, 72, 4, 44, 7, 54, 8, 53, 3, 39, 2, 47, 5, 44, 
    1, 26, 3, 25, 0, 87, 2, 86, 7, 17, 8, 38, 6, 17, 5, 98, 4, 36, 
    7, 96, 4, 45, 1, 67, 6, 66, 5, 93, 0, 12, 3, 39, 2, 75, 8, 96
  };
  const int q4227[] = {
    9, 9, // Number of jobs and machines
    1, 75, 2, 53, 0, 77, 7, 31, 4, 72, 5, 99, 8, 28, 3, 44, 6,  9, 
    4, 76, 0, 75, 5, 53, 7, 13, 3, 90, 2, 76, 8, 83, 6,  2, 1, 57, 
    1, 65, 0, 54, 2, 36, 7, 99, 6, 73, 4, 42, 3, 79, 5, 35, 8, 14, 
    1, 87, 8, 68, 6, 89, 3, 62, 7,  5, 4, 23, 5, 57, 0, 41, 2, 41, 
    4, 18, 5, 66, 2, 80, 1, 39, 8, 83, 3,  9, 0, 85, 7, 16, 6, 61, 
    1, 78, 0, 71, 4, 30, 8, 27, 5, 33, 2, 22, 3, 43, 7, 74, 6,  3, 
    4,  9, 2, 69, 1, 85, 0, 15, 3, 47, 7, 24, 5, 78, 8, 86, 6, 30, 
    6, 50, 8, 50, 5, 82, 2, 63, 0, 92, 3, 11, 1, 27, 7, 10, 4, 38, 
    1, 87, 5, 84, 4, 45, 3, 29, 2, 38, 7, 60, 0, 52, 8, 80, 6, 54
  };
  const int q4228[] = {
    9, 9, // Number of jobs and machines
    4, 67, 2, 34, 7, 13, 0, 40, 6, 24, 5, 79, 3, 35, 8, 42, 1, 29, 
    4,  9, 6, 44, 1, 26, 2, 57, 0, 50, 3, 81, 5, 31, 7, 90, 8, 85, 
    4, 10, 8, 49, 6, 67, 7, 28, 0, 53, 3, 25, 1, 71, 2, 54, 5, 39, 
    0, 94, 6, 54, 2, 64, 5,  3, 8, 57, 1, 68, 3, 76, 7, 12, 4, 82, 
    8, 79, 0, 30, 6, 26, 4, 91, 2, 34, 5, 75, 3, 63, 1, 29, 7, 86, 
    2, 92, 5, 78, 6, 63, 8, 64, 7, 73, 4, 60, 1, 49, 3, 67, 0, 95, 
    5, 56, 0, 15, 8, 48, 1, 69, 4,  4, 2, 62, 7, 98, 6, 87, 3, 19, 
    6, 51, 2,  5, 4,  4, 1, 86, 0, 29, 8, 89, 7, 35, 5, 35, 3, 48, 
    7, 27, 5, 33, 0,  1, 8, 83, 3, 98, 1, 19, 4, 84, 6, 41, 2, 29
  };
  const int q4229[] = {
    9, 9, // Number of jobs and machines
    7,  9, 6, 67, 8, 73, 2, 60, 0, 46, 4, 67, 5, 74, 1,  1, 3, 18, 
    0,  7, 6, 26, 7, 87, 1, 20, 4, 42, 2, 60, 8, 39, 3, 66, 5, 59, 
    3, 14, 1, 73, 5, 71, 2, 11, 4, 48, 7, 22, 0, 71, 6, 89, 8, 40, 
    1, 88, 0, 43, 3, 13, 4, 28, 8, 31, 7, 30, 6, 76, 2, 23, 5, 95, 
    7, 91, 5, 67, 1, 95, 8,  5, 3, 86, 0,  6, 2, 38, 4, 29, 6, 67, 
    6, 13, 0, 92, 5, 94, 7, 70, 3, 15, 4, 46, 1, 45, 2, 84, 8, 14, 
    1, 92, 7, 71, 3, 85, 6, 43, 5, 88, 2, 27, 8, 84, 4, 46, 0, 32, 
    2, 21, 6, 39, 8, 85, 3, 45, 1, 77, 7, 52, 4, 21, 5, 74, 0, 53, 
    0, 79, 1, 54, 8, 15, 4, 83, 6, 15, 7, 25, 2, 59, 3, 40, 5, 28
  };
  const int q4230[] = {
    9, 9, // Number of jobs and machines
    8, 33, 4, 62, 1, 94, 3, 26, 5, 97, 7, 91, 6, 16, 2, 31, 0, 66, 
    5, 51, 1, 38, 7, 90, 6, 35, 3, 73, 8,  6, 2, 41, 4, 77, 0, 76, 
    4, 89, 3, 52, 6, 17, 2, 57, 7, 12, 0, 70, 5, 77, 1, 48, 8, 16, 
    6, 29, 3, 42, 1, 33, 5, 83, 0, 33, 7, 62, 8, 51, 4,  3, 2, 79, 
    5,  5, 3, 80, 4,  5, 0, 85, 1, 74, 7, 36, 6, 95, 8, 97, 2, 56, 
    7,  7, 1, 41, 6, 24, 3, 35, 8, 31, 0, 61, 5, 98, 2, 30, 4,  1, 
    6, 27, 4, 45, 7, 43, 5, 97, 2, 55, 0, 49, 3, 71, 8, 32, 1, 54, 
    5, 63, 2, 41, 4, 67, 0, 40, 1, 86, 6, 36, 7, 59, 8, 79, 3, 24, 
    8, 46, 4, 78, 1, 45, 6, 55, 0, 28, 2, 25, 7, 45, 5, 11, 3, 17
  };
  const int q4231[] = {
    9, 9, // Number of jobs and machines
    0, 66, 3, 81, 5, 21, 8, 57, 1, 57, 7, 20, 4, 16, 2, 99, 6, 88, 
    6, 90, 1, 47, 4, 80, 8, 97, 0, 52, 2,  2, 7, 67, 5, 81, 3, 32, 
    6, 74, 2, 86, 5,  5, 0,  5, 1, 60, 7, 71, 3,  6, 4, 59, 8, 72, 
    4, 28, 3, 54, 7, 60, 1, 93, 5, 57, 0, 38, 6, 83, 2, 67, 8, 44, 
    0, 72, 7, 43, 2, 66, 5, 58, 1, 43, 3, 22, 8,  5, 4, 17, 6, 22, 
    3, 79, 6, 78, 2, 69, 1, 84, 4, 57, 0, 87, 5, 98, 8,  7, 7, 50, 
    1, 85, 8, 51, 7, 78, 3, 31, 0, 60, 5, 40, 6, 47, 2, 56, 4, 24, 
    0, 11, 7, 54, 8,  5, 1, 54, 3, 94, 2, 69, 4,  4, 5, 71, 6, 16, 
    3, 39, 4,  1, 0, 97, 1, 74, 2, 11, 5, 61, 8, 32, 7, 25, 6, 57
  };
  const int q4232[] = {
    9, 9, // Number of jobs and machines
    7, 96, 3, 51, 2, 99, 5, 29, 6, 10, 4,  8, 8, 34, 0, 47, 1,  6, 
    0, 25, 5, 85, 7, 74, 6, 74, 2, 34, 4, 52, 8, 94, 3, 64, 1, 92, 
    2, 32, 1, 53, 7, 99, 4, 66, 8,  7, 3, 42, 5, 53, 0, 42, 6, 78, 
    6, 66, 0, 78, 4, 16, 2, 57, 8,  7, 7, 40, 3, 15, 5, 12, 1, 64, 
    1, 62, 3, 66, 6, 17, 8, 25, 0, 94, 2, 61, 5, 63, 7, 74, 4, 99, 
    7, 40, 1, 11, 4, 64, 6, 11, 0, 67, 3,  8, 5, 79, 2, 49, 8, 10, 
    0, 30, 4, 39, 5,  2, 6, 75, 7, 98, 2, 92, 3, 88, 8, 17, 1, 31, 
    4, 13, 7, 82, 5, 37, 0, 47, 3, 32, 1, 84, 8, 82, 6, 26, 2, 50, 
    6, 34, 7, 73, 2, 49, 5, 11, 3, 80, 1,  2, 0, 88, 4, 88, 8, 90
  };
  const int q4233[] = {
    9, 9, // Number of jobs and machines
    5, 55, 7, 18, 4, 31, 2, 33, 3, 98, 0, 82, 6, 68, 8,  5, 1, 41, 
    1, 38, 5, 31, 7, 53, 4, 63, 8, 46, 2, 98, 0, 92, 3, 55, 6, 51, 
    0, 84, 3, 54, 1, 60, 2, 86, 6, 32, 4, 50, 7, 72, 8, 17, 5, 58, 
    1, 25, 0, 96, 3, 12, 8, 65, 6, 10, 7, 49, 5, 34, 2, 10, 4, 45, 
    3, 31, 5, 55, 1, 92, 2, 75, 4, 21, 6, 73, 8, 54, 0, 18, 7, 19, 
    5, 54, 8, 50, 7, 68, 3, 77, 0, 99, 6, 85, 4, 15, 1, 90, 2,  4, 
    8, 52, 2, 77, 3, 61, 5, 16, 1, 81, 4, 78, 7, 12, 6, 62, 0,  1, 
    2, 75, 5, 59, 8, 18, 0, 81, 3, 59, 6,  2, 1, 67, 7, 99, 4, 51, 
    4, 52, 1, 30, 8, 31, 6, 68, 5,  5, 7, 87, 0, 25, 2,  2, 3, 73
  };
  const int q4234[] = {
    9, 9, // Number of jobs and machines
    2, 73, 0,  7, 6, 77, 7, 49, 5, 32, 1,  5, 4, 63, 8, 84, 3, 43, 
    1, 77, 7, 82, 4, 12, 8, 17, 0, 31, 3, 96, 2, 37, 6,  1, 5, 51, 
    1, 22, 2, 36, 3, 98, 7, 21, 5, 44, 0, 22, 6, 95, 4, 22, 8, 79, 
    5, 86, 1, 91, 4, 17, 2,  8, 0, 80, 7, 89, 6, 60, 8, 42, 3, 66, 
    1, 53, 3, 50, 8, 41, 4, 35, 0, 90, 6, 61, 2, 20, 7, 98, 5, 35, 
    6, 41, 2, 45, 8, 76, 0,  8, 5, 86, 7, 29, 1, 10, 3, 57, 4, 94, 
    4,  9, 0, 18, 5, 79, 1, 37, 7,  4, 3, 73, 8, 54, 6, 72, 2, 59, 
    7, 39, 1, 39, 6, 46, 4, 75, 5, 89, 2, 80, 0, 34, 3,  3, 8, 57, 
    4, 66, 1, 22, 0, 11, 8, 40, 6, 88, 7, 38, 5, 71, 2, 49, 3, 14
  };
  const int q4235[] = {
    9, 9, // Number of jobs and machines
    1, 33, 5, 29, 2, 72, 8, 75, 6, 42, 3, 42, 7, 88, 0, 89, 4, 33, 
    2, 86, 0, 50, 3, 99, 4, 73, 1, 24, 7, 93, 8,  3, 5, 72, 6, 35, 
    1, 68, 2, 25, 4, 62, 5, 24, 6, 48, 7, 13, 8, 41, 3, 56, 0, 24, 
    2, 68, 6,  7, 1, 92, 0, 93, 4, 90, 8, 45, 5, 73, 3, 75, 7, 78, 
    6, 12, 3, 63, 2, 86, 8, 12, 7, 52, 4,  2, 0, 82, 5, 38, 1, 10, 
    8, 60, 7, 36, 4,  8, 5, 23, 0, 18, 6, 71, 1, 60, 2,  3, 3, 50, 
    0, 60, 3, 59, 6, 39, 2, 97, 7, 80, 5, 17, 1, 57, 8, 33, 4, 55, 
    0,  3, 1, 84, 2,  5, 7, 34, 8, 56, 5, 20, 6,  8, 3, 60, 4, 47, 
    6, 63, 5, 75, 8, 48, 4, 55, 2, 36, 7, 96, 1, 74, 0, 36, 3, 30
  };
  const int q4236[] = {
    9, 9, // Number of jobs and machines
    6,  8, 2,  5, 1, 75, 4, 88, 7, 27, 0, 53, 3, 76, 8, 79, 5, 30, 
    4, 23, 6, 86, 5,  6, 7, 41, 2, 68, 0, 32, 8, 47, 1, 72, 3, 82, 
    6, 20, 2, 65, 1, 56, 3, 25, 8, 80, 0, 91, 7, 49, 4, 62, 5, 34, 
    8,  9, 6, 25, 7, 63, 1, 37, 3, 76, 4, 78, 5, 87, 2, 23, 0, 56, 
    8, 16, 3, 92, 4, 69, 5, 35, 6,  6, 2,  9, 7, 60, 0, 53, 1,  2, 
    0, 76, 2, 85, 5,  3, 4, 64, 6, 89, 7, 53, 3, 17, 8, 55, 1,  2, 
    5, 77, 2, 49, 8, 65, 3, 59, 0, 62, 6, 90, 4, 24, 7, 83, 1, 33, 
    0, 50, 2, 49, 5, 35, 6, 12, 7, 51, 1, 47, 8, 91, 4, 68, 3, 79, 
    0, 70, 2, 68, 3, 52, 4, 55, 7, 30, 5, 79, 8, 46, 1, 84, 6,  7
  };
  const int q4237[] = {
    9, 9, // Number of jobs and machines
    7, 27, 2,  7, 5, 40, 0, 84, 6, 26, 1, 36, 8, 96, 4, 10, 3, 24, 
    8, 93, 3, 13, 4, 72, 6, 85, 1, 63, 7, 68, 2, 39, 0, 37, 5,  8, 
    7, 78, 2, 40, 8, 67, 1, 94, 4, 18, 0, 16, 3, 41, 5, 86, 6, 86, 
    7, 18, 8, 72, 4, 65, 3, 39, 5, 95, 2, 65, 0, 28, 6, 48, 1, 35, 
    2, 97, 3, 78, 5, 12, 7, 94, 8, 44, 6, 31, 1, 38, 4, 93, 0, 74, 
    3, 12, 8,  9, 1, 12, 2, 60, 7,  1, 4,  4, 0, 10, 5, 66, 6, 20, 
    3,  4, 6, 47, 5, 94, 1, 89, 4, 49, 2, 51, 7, 92, 0, 60, 8, 58, 
    6, 50, 7, 40, 1, 26, 4, 75, 8,  1, 5, 83, 3, 63, 0, 45, 2, 34, 
    1, 69, 0, 28, 5, 19, 2, 37, 3, 98, 4, 79, 8,  6, 6, 64, 7, 42
  };
  const int q4238[] = {
    9, 9, // Number of jobs and machines
    3, 96, 5, 76, 4, 85, 0, 40, 6, 68, 1, 34, 7, 53, 2, 26, 8, 32, 
    4, 71, 6,  9, 5, 76, 2, 56, 0, 33, 1,  9, 7, 43, 3, 80, 8, 77, 
    1, 16, 4, 51, 3,  3, 8, 70, 6, 46, 0, 74, 2, 34, 5, 78, 7, 15, 
    7, 42, 1,  4, 5, 24, 3,  4, 4, 57, 0, 51, 6, 36, 8, 61, 2, 74, 
    6, 44, 7, 62, 5, 75, 2, 67, 8, 90, 4, 26, 3, 71, 0, 88, 1, 27, 
    3, 91, 2,  1, 5,  6, 0, 67, 8, 29, 6, 42, 4, 63, 1, 62, 7, 74, 
    8, 49, 0, 34, 5, 80, 7, 58, 3, 59, 4, 94, 1, 38, 6, 82, 2, 15, 
    1, 89, 8, 35, 3, 33, 5, 15, 7, 60, 2, 44, 0, 58, 4, 38, 6, 39, 
    8, 80, 2, 10, 3, 15, 6, 90, 4, 92, 0, 14, 7, 85, 5, 30, 1, 15
  };
  const int q4239[] = {
    9, 9, // Number of jobs and machines
    6, 95, 0, 76, 3,  9, 2, 29, 1, 82, 7, 88, 4, 73, 5, 58, 8, 84, 
    4, 98, 1, 52, 8, 69, 0, 19, 2, 54, 7, 97, 6,  1, 5, 27, 3, 42, 
    4, 89, 2, 74, 7, 27, 1, 27, 8, 52, 5, 17, 3, 81, 0, 88, 6, 82, 
    1, 32, 3, 70, 8, 99, 0, 51, 2, 44, 5,  2, 7, 11, 4, 38, 6, 44, 
    4, 33, 5, 74, 7, 19, 3,  8, 2, 24, 0,  1, 8, 64, 6, 82, 1, 25, 
    5, 83, 7, 34, 4, 90, 2, 50, 3, 28, 1, 97, 6, 15, 8, 65, 0, 38, 
    2, 87, 7, 36, 5,  1, 8, 46, 1, 77, 6, 63, 3, 75, 0, 18, 4, 38, 
    8, 93, 0, 40, 3, 62, 5, 70, 4, 11, 2, 15, 1, 86, 7, 24, 6, 14, 
    2, 22, 1, 95, 8, 83, 7, 56, 3, 31, 6, 92, 4, 90, 0, 73, 5, 53
  };
  const int q4240[] = {
    9, 9, // Number of jobs and machines
    0, 18, 6, 57, 1, 26, 3, 34, 5, 55, 7, 34, 8,  6, 4, 19, 2, 99, 
    5, 61, 0, 63, 3, 34, 7, 94, 6, 17, 2, 54, 4, 22, 8, 70, 1, 46, 
    6, 50, 8, 11, 0, 36, 7, 63, 3, 59, 2, 85, 1, 58, 4, 71, 5, 26, 
    0, 35, 7, 47, 1, 28, 6, 11, 2, 73, 8, 58, 5, 63, 3, 95, 4, 42, 
    7, 53, 5, 63, 2, 61, 1, 58, 6, 47, 8, 12, 4,  2, 0, 98, 3, 27, 
    4, 18, 7, 41, 8, 14, 5, 33, 0, 16, 1, 86, 2,  1, 3, 97, 6, 18, 
    4, 46, 3, 78, 5, 49, 8, 60, 6, 73, 0, 17, 7, 55, 1, 23, 2,  6, 
    0, 79, 1, 31, 2, 91, 5, 82, 7, 89, 6, 13, 4, 95, 3, 82, 8, 25, 
    0, 64, 2, 41, 5, 68, 1, 98, 8, 76, 6,  7, 4, 74, 3, 67, 7, 71
  };
  const int q4241[] = {
    9, 9, // Number of jobs and machines
    7, 94, 6, 48, 5, 35, 8, 72, 2,  6, 0, 25, 4, 54, 3, 46, 1, 91, 
    4, 22, 6,  8, 1, 93, 8, 81, 5, 15, 0, 96, 3, 52, 7, 63, 2, 61, 
    0, 89, 1, 82, 5,  8, 3, 32, 6, 50, 2, 67, 8, 68, 7, 85, 4, 68, 
    3, 95, 0, 42, 2,  6, 5, 14, 1, 66, 8,  3, 4,  1, 7,  7, 6, 66, 
    1, 26, 2, 31, 3, 31, 4,  6, 7, 99, 0, 91, 5, 47, 6, 36, 8, 21, 
    1, 82, 2, 98, 3, 51, 4, 10, 5, 16, 6, 57, 8, 93, 0, 61, 7, 73, 
    0, 86, 3, 42, 8,  1, 6, 80, 1,  7, 5, 53, 7, 90, 4, 82, 2, 52, 
    6, 99, 2, 24, 1, 16, 3, 64, 8, 84, 0,  8, 4,  2, 5, 42, 7, 53, 
    5, 38, 7, 12, 8, 63, 3, 28, 4, 27, 2, 29, 0, 43, 1, 53, 6,  7
  };
  const int q4242[] = {
    9, 9, // Number of jobs and machines
    3, 38, 8, 76, 0, 90, 2, 53, 4, 52, 5, 20, 7, 42, 6, 83, 1, 14, 
    0, 79, 7, 70, 6, 42, 4, 19, 1, 21, 5, 78, 8, 26, 3, 47, 2, 34, 
    0, 14, 7, 14, 4, 93, 1, 52, 6, 68, 2, 14, 8, 42, 3, 69, 5,  6, 
    6, 55, 3, 15, 1, 21, 4, 26, 2,  4, 8, 82, 7, 75, 0, 69, 5, 40, 
    8, 21, 1, 26, 2, 43, 4, 37, 6, 33, 0, 83, 3, 47, 7,  7, 5, 40, 
    6, 33, 3, 98, 8, 39, 2, 66, 7, 70, 5, 13, 1,  5, 4, 81, 0, 96, 
    3, 72, 5, 20, 2, 16, 8, 91, 4, 89, 0, 91, 6, 11, 7, 23, 1, 17, 
    8, 71, 3, 98, 6, 16, 1, 43, 2, 88, 5,  8, 7,  4, 4, 41, 0, 76, 
    1,  7, 6, 16, 7, 62, 5, 26, 3, 58, 8,  9, 2, 47, 4, 22, 0, 97
  };
  const int q4243[] = {
    9, 9, // Number of jobs and machines
    3, 78, 5, 89, 2, 21, 8, 89, 0, 86, 1, 14, 4, 88, 6, 98, 7, 35, 
    1, 66, 3,  7, 7, 56, 4, 24, 2, 13, 5,  7, 0, 74, 8, 72, 6, 44, 
    3, 55, 2,  7, 8, 75, 7, 45, 6, 20, 1, 70, 0, 95, 5, 99, 4, 29, 
    5, 43, 8, 28, 4, 87, 3, 56, 1, 79, 0, 65, 6, 17, 7, 67, 2, 79, 
    6, 33, 1,  3, 4,  2, 7, 47, 2, 31, 3, 36, 8, 38, 5, 22, 0, 16, 
    3, 44, 0, 96, 8, 90, 7, 97, 2, 18, 1, 18, 4,  9, 5, 46, 6,  8, 
    1, 77, 7, 54, 3,  9, 0, 80, 2, 85, 8, 31, 4, 88, 6, 33, 5, 46, 
    7, 84, 5, 97, 1, 75, 6, 65, 3, 65, 0, 61, 8, 82, 2,  5, 4, 72, 
    3, 19, 0, 70, 8, 75, 5, 39, 6, 10, 4, 14, 2, 32, 7, 15, 1,  5
  };
  const int q4244[] = {
    9, 9, // Number of jobs and machines
    6, 36, 2, 90, 0, 54, 4,  6, 8, 83, 7, 73, 1, 25, 3, 30, 5, 85, 
    2, 30, 4, 19, 0, 47, 1, 62, 6, 58, 5, 24, 7,  8, 8, 90, 3, 54, 
    2, 47, 4, 76, 3, 19, 0, 95, 1, 62, 8, 94, 7, 79, 6, 81, 5, 98, 
    3, 38, 2, 83, 5, 44, 6, 12, 4, 20, 0, 67, 7, 75, 8, 20, 1, 68, 
    1, 59, 6, 95, 2, 96, 5, 93, 0, 92, 8, 15, 4, 55, 3, 62, 7, 78, 
    6, 18, 7, 62, 3, 19, 4, 88, 8, 32, 0, 53, 5, 90, 1, 94, 2, 92, 
    7, 69, 2, 32, 0, 28, 5, 26, 4, 27, 1, 85, 3, 26, 6, 89, 8, 81, 
    1, 83, 7, 46, 3, 76, 2,  7, 5, 20, 4, 56, 8, 25, 0, 19, 6, 10, 
    2, 72, 8, 51, 0, 85, 4, 36, 7, 71, 5, 11, 3, 92, 1, 60, 6, 75
  };
  const int q4245[] = {
    9, 9, // Number of jobs and machines
    8, 91, 0, 61, 6, 66, 5, 28, 3, 27, 2, 39, 1, 40, 7, 31, 4, 86, 
    4, 43, 5, 18, 8, 56, 7, 44, 1, 44, 2,  7, 0, 55, 6, 83, 3, 61, 
    3, 76, 8,  8, 1, 60, 7, 63, 2,  4, 5, 24, 0, 13, 6, 90, 4, 48, 
    5, 56, 6, 25, 0, 95, 1, 37, 2, 95, 4, 92, 8, 52, 7, 33, 3, 33, 
    6, 10, 8, 13, 7, 28, 5, 95, 2, 92, 3,  5, 4,  8, 1,  4, 0, 64, 
    5, 44, 1, 17, 4, 90, 6, 48, 0, 88, 8, 56, 7, 81, 2, 59, 3,  4, 
    7, 36, 6, 47, 1, 42, 8, 85, 4, 29, 5, 63, 0,  7, 3, 87, 2, 94, 
    8, 58, 7, 99, 1, 39, 3, 56, 5,  4, 2, 27, 4, 85, 0, 21, 6, 74, 
    7, 41, 6, 51, 4, 55, 0, 88, 1, 44, 5, 25, 3,  2, 2, 25, 8, 54
  };
  const int q4246[] = {
    9, 9, // Number of jobs and machines
    7, 43, 4, 29, 8, 47, 2,  1, 1, 60, 6, 36, 3, 98, 0, 44, 5, 37, 
    5, 84, 0, 57, 2, 43, 3, 39, 7, 39, 8,  9, 4, 67, 1, 53, 6, 83, 
    7, 74, 0, 81, 4,  3, 3, 23, 8, 97, 5, 78, 6, 78, 2, 37, 1, 65, 
    8, 14, 7, 37, 5, 34, 1, 19, 4, 97, 0, 94, 6, 85, 2, 29, 3, 73, 
    5, 56, 8, 68, 3, 38, 7, 94, 6, 21, 1, 95, 4, 95, 0, 35, 2, 33, 
    4, 13, 2, 16, 3, 34, 5, 98, 1, 89, 0, 35, 7, 40, 8, 10, 6, 70, 
    0, 69, 5, 40, 1, 30, 2, 14, 8, 17, 3, 24, 4, 49, 7, 95, 6, 75, 
    4, 27, 6, 17, 8, 82, 2, 67, 3, 56, 1, 41, 7, 74, 0, 12, 5, 78, 
    3, 80, 2, 24, 4,  3, 6, 12, 7, 85, 0, 12, 8, 58, 1, 26, 5, 21
  };
  const int q4247[] = {
    9, 9, // Number of jobs and machines
    5, 15, 8, 91, 0, 79, 6, 28, 4,  4, 2, 79, 1, 16, 7, 82, 3, 85, 
    1, 92, 8,  4, 6, 86, 2, 77, 0, 98, 7, 70, 3, 14, 5, 65, 4,  2, 
    8, 77, 1, 88, 6, 61, 2, 98, 7, 63, 4,  2, 5, 67, 0, 81, 3, 75, 
    5, 57, 2, 89, 4, 97, 3, 59, 1, 10, 7, 28, 0, 30, 6, 49, 8, 89, 
    6, 43, 1, 62, 2,  1, 4, 65, 7, 64, 3, 76, 5, 62, 8, 18, 0, 53, 
    1, 50, 5, 31, 2, 51, 4, 23, 0, 84, 3, 50, 6, 58, 8, 76, 7, 84, 
    6, 29, 3, 53, 4, 22, 1, 76, 0, 88, 8, 83, 5, 46, 7, 89, 2, 97, 
    1, 10, 5, 12, 6, 70, 4, 36, 0, 36, 3, 49, 8, 99, 7, 77, 2, 54, 
    6, 68, 7, 28, 8, 68, 3, 55, 4, 19, 2, 61, 1, 15, 5,  4, 0, 63
  };
  const int q4248[] = {
    9, 9, // Number of jobs and machines
    2, 70, 7, 25, 0,  3, 1, 95, 5, 73, 8, 64, 6, 83, 3, 96, 4, 87, 
    6,  5, 4, 59, 2, 45, 7, 88, 1, 41, 8, 10, 3, 71, 5, 69, 0,  1, 
    2, 18, 4,  5, 5,  7, 6, 70, 1, 62, 7, 29, 8,  8, 0, 29, 3,  3, 
    3, 46, 4, 26, 7, 51, 0, 63, 2, 99, 8, 22, 5, 87, 6, 14, 1, 26, 
    4, 79, 6, 29, 3, 83, 0, 80, 8, 91, 7, 18, 1, 48, 2, 23, 5, 54, 
    4, 57, 8, 86, 6, 99, 5, 71, 2,  3, 7, 11, 1, 84, 0, 90, 3, 15, 
    1, 63, 5, 27, 0, 14, 7,  3, 6, 31, 8, 39, 4, 79, 3, 67, 2, 41, 
    6, 77, 0, 36, 2, 98, 3, 57, 7, 22, 5, 53, 8,  1, 1, 88, 4, 60, 
    2, 42, 7, 29, 8, 99, 0, 36, 6,  7, 4, 40, 5, 99, 1, 68, 3, 93
  };
  const int q4249[] = {
    9, 9, // Number of jobs and machines
    4, 36, 0, 82, 7, 72, 1, 56, 5, 70, 6, 77, 3, 70, 8, 72, 2,  7, 
    4, 86, 0, 92, 3,  3, 6, 23, 5, 46, 7, 73, 8, 24, 1, 54, 2, 47, 
    4, 88, 8, 29, 7, 50, 3, 86, 2, 90, 0, 69, 5, 98, 1, 40, 6, 87, 
    1, 39, 6, 56, 2, 14, 3, 15, 8, 36, 7, 98, 4, 69, 0, 32, 5, 47, 
    0, 37, 4, 54, 1, 81, 2, 66, 7, 83, 3, 27, 6, 74, 5, 71, 8, 78, 
    5, 60, 0, 84, 6, 66, 8, 54, 2, 86, 1, 63, 4, 87, 7, 53, 3, 87, 
    4, 23, 8, 56, 1, 32, 7,  7, 0,  8, 3, 76, 6, 18, 2, 52, 5, 68, 
    4, 21, 3, 49, 2, 60, 5,  1, 1, 21, 8, 17, 7, 62, 6, 38, 0, 66, 
    6, 63, 3, 99, 8, 19, 1, 30, 0, 56, 7, 77, 5, 38, 2, 31, 4, 31
  };
  const int q4250[] = {
    9, 9, // Number of jobs and machines
    0, 35, 6, 48, 7, 66, 5, 46, 4,  9, 2,  9, 8, 19, 3, 39, 1, 35, 
    4, 69, 5, 43, 8, 97, 7, 32, 0, 70, 6, 19, 2, 74, 3, 92, 1, 74, 
    5, 56, 3, 61, 7, 72, 4, 12, 0, 77, 6, 68, 8, 17, 2, 49, 1, 73, 
    1, 95, 3, 38, 8,  4, 2, 47, 4, 98, 5, 81, 6, 58, 7, 41, 0, 43, 
    2, 40, 4, 54, 8, 35, 7,  6, 5, 17, 6, 86, 1, 74, 3, 84, 0, 36, 
    0, 37, 7, 72, 6, 10, 3, 53, 4, 75, 2, 78, 5, 52, 8, 65, 1, 31, 
    1,  3, 7,  2, 2, 95, 8, 68, 4, 81, 6, 54, 0,  3, 3, 71, 5, 68, 
    8, 26, 0, 99, 4,  1, 2, 45, 6,  9, 1, 23, 7, 67, 5, 74, 3, 55, 
    4, 91, 1, 34, 3, 39, 2, 24, 6, 80, 0, 74, 8, 65, 7, 53, 5, 45
  };
  const int q4251[] = {
    9, 9, // Number of jobs and machines
    3, 46, 0, 26, 2, 89, 4, 38, 6, 72, 1, 85, 7, 32, 8,  4, 5, 26, 
    1, 27, 8, 87, 6, 52, 7, 88, 5, 47, 0, 42, 3, 29, 2, 84, 4, 28, 
    3, 20, 0, 94, 2, 81, 7, 31, 6, 69, 4, 29, 1, 32, 5, 67, 8, 59, 
    1, 58, 2, 16, 7, 78, 3,  3, 5, 73, 4, 88, 0, 10, 8, 49, 6, 30, 
    8, 29, 2, 46, 5, 34, 4, 88, 7, 69, 3, 22, 1, 48, 6, 31, 0, 23, 
    5, 23, 3, 65, 7, 48, 2, 70, 8, 68, 0, 84, 6, 52, 1, 71, 4, 36, 
    8,  4, 7, 21, 6, 92, 5, 62, 2, 67, 0, 32, 4, 62, 1, 59, 3, 86, 
    0, 12, 8, 48, 5, 82, 1, 32, 7, 31, 4, 75, 6, 65, 3, 55, 2, 68, 
    1, 34, 6, 80, 0,  6, 3, 70, 4, 80, 8, 18, 2,  6, 5, 51, 7, 33
  };
  const int q4252[] = {
    9, 9, // Number of jobs and machines
    0, 63, 7, 75, 8, 56, 4, 15, 5, 68, 2, 24, 6, 58, 1, 99, 3, 75, 
    4, 18, 5, 58, 7, 47, 1, 70, 6, 97, 2, 44, 3, 58, 8, 71, 0, 21, 
    1, 49, 4, 23, 2, 33, 7, 53, 3, 53, 6, 81, 8, 38, 5, 19, 0, 26, 
    4, 44, 0, 52, 2, 36, 7, 87, 8, 10, 5, 50, 3, 24, 6, 86, 1,  2, 
    3, 37, 5, 19, 7, 44, 4, 60, 0, 83, 2, 14, 8, 93, 1, 54, 6, 11, 
    4, 29, 5, 41, 7, 30, 3,  9, 6,  6, 1, 57, 0, 59, 2, 75, 8, 19, 
    2, 32, 0, 56, 4, 70, 7, 14, 6, 61, 1, 86, 8, 28, 5, 65, 3, 83, 
    6, 61, 7, 91, 8, 72, 3, 47, 2, 41, 1, 27, 4, 35, 0, 61, 5, 13, 
    6, 23, 3,  5, 7,  5, 4, 96, 5, 17, 0, 58, 2, 56, 1, 29, 8, 65
  };
  const int q4253[] = {
    9, 9, // Number of jobs and machines
    0, 73, 4, 12, 7, 83, 3, 24, 2,  9, 5, 34, 6, 65, 8, 78, 1, 66, 
    2, 83, 8, 11, 4,  4, 5,  8, 7,  7, 0, 19, 6, 81, 3, 63, 1,  8, 
    1, 54, 5, 72, 2,  4, 3,  3, 6, 16, 0, 35, 7, 16, 8, 29, 4, 79, 
    7, 79, 0, 88, 3, 31, 8,  8, 4, 14, 2, 51, 5, 52, 6, 58, 1,  5, 
    7, 30, 4, 12, 8, 12, 3, 17, 0, 19, 2, 47, 6, 85, 1, 35, 5, 59, 
    1, 59, 4, 93, 8, 90, 5, 51, 0, 17, 3, 70, 6, 31, 7,  1, 2, 67, 
    2, 84, 4,  7, 8, 88, 0, 58, 3, 57, 1,  6, 6, 32, 7, 17, 5, 96, 
    3, 19, 0, 21, 8, 36, 7, 50, 4, 72, 6, 96, 1, 24, 5, 59, 2, 65, 
    4, 14, 5,  1, 8, 82, 0, 85, 1, 24, 7, 14, 3, 31, 6, 34, 2, 95
  };
  const int q4254[] = {
    9, 9, // Number of jobs and machines
    1, 49, 4, 94, 0, 40, 7, 24, 3, 48, 6, 74, 8, 69, 5,  8, 2,  1, 
    5, 68, 3,  9, 0, 79, 4, 48, 2, 39, 6, 34, 7, 99, 1, 89, 8,  2, 
    1, 77, 7,  4, 0,  5, 5, 91, 6, 13, 2, 85, 4, 34, 8, 44, 3, 46, 
    4, 13, 6, 91, 8, 13, 7, 15, 5, 59, 3, 97, 0, 12, 1, 39, 2, 20, 
    6, 73, 4, 81, 1, 60, 7, 89, 3, 52, 5, 76, 0, 48, 2, 60, 8, 53, 
    2, 54, 1, 41, 7, 58, 3, 90, 5, 92, 4, 77, 0, 58, 8, 61, 6, 35, 
    2, 49, 1, 53, 3, 18, 0, 49, 8, 74, 6, 60, 5, 25, 4, 91, 7, 84, 
    2, 92, 0, 69, 6, 78, 1, 54, 8,  6, 7, 41, 4,  3, 5, 56, 3, 56, 
    7, 38, 5, 77, 8, 66, 6, 67, 2,  6, 1,  3, 3, 73, 4, 70, 0, 19
  };
  const int q4255[] = {
    9, 9, // Number of jobs and machines
    1, 61, 0, 86, 8, 72, 4, 55, 5, 16, 7, 83, 6, 76, 3, 52, 2, 52, 
    6, 37, 8, 89, 4, 25, 1, 27, 3, 80, 7, 97, 2, 30, 0, 15, 5, 37, 
    7, 61, 2, 12, 6, 12, 1, 70, 0, 45, 5, 89, 3, 27, 8, 36, 4,  1, 
    8, 53, 0, 32, 3, 98, 5, 37, 2,  5, 4,  6, 7, 82, 1, 80, 6, 73, 
    5, 52, 2, 30, 8, 22, 4,  6, 7, 69, 1,  7, 0, 21, 3, 94, 6, 17, 
    2, 51, 3, 29, 8, 18, 6, 51, 7, 65, 4, 31, 5, 68, 1,  8, 0, 94, 
    4, 85, 0, 98, 3, 20, 8, 24, 7, 54, 5, 59, 1, 27, 2, 84, 6, 99, 
    6, 17, 4, 68, 5, 75, 2, 30, 1, 55, 8, 13, 3, 66, 0, 82, 7, 70, 
    7, 28, 6, 41, 4, 67, 8, 30, 2, 49, 3, 47, 5, 26, 0, 97, 1, 77
  };
  const int q4256[] = {
    9, 9, // Number of jobs and machines
    1, 60, 8, 31, 5, 23, 3, 53, 0, 77, 2,  5, 4, 68, 6, 51, 7, 15, 
    3, 77, 2, 26, 8, 47, 0, 25, 7, 61, 4,  2, 6, 58, 5, 80, 1, 45, 
    3, 28, 5, 63, 7, 49, 6, 42, 4, 73, 8, 43, 1, 86, 2, 83, 0, 63, 
    3, 85, 5, 96, 0, 72, 4, 91, 6, 95, 8, 76, 1, 41, 7,  5, 2, 94, 
    7, 34, 5, 29, 3, 44, 1, 87, 4,  4, 6, 64, 0, 48, 2, 55, 8, 34, 
    6, 86, 4, 62, 1, 11, 5, 18, 8, 91, 7, 70, 0, 65, 2, 34, 3, 36, 
    3, 93, 7, 90, 5, 82, 8, 77, 1, 43, 4, 68, 6, 65, 2, 11, 0, 47, 
    2, 44, 8, 76, 3, 13, 5, 69, 1, 32, 4, 29, 0, 47, 6, 50, 7, 20, 
    7,  7, 8, 26, 3, 27, 0,  9, 6, 13, 2, 53, 4, 89, 5, 59, 1, 79
  };
  const int q4257[] = {
    9, 9, // Number of jobs and machines
    3, 61, 2, 13, 1, 95, 5, 68, 8, 41, 4, 47, 0, 80, 6, 52, 7, 55, 
    3, 45, 7, 49, 5, 13, 1, 90, 2, 91, 8, 59, 6, 94, 0, 90, 4, 88, 
    3, 82, 8, 22, 0, 54, 2, 64, 6, 11, 1, 29, 7,  3, 4,  8, 5, 73, 
    4, 27, 5, 13, 6, 22, 1, 28, 2, 31, 7, 76, 0, 48, 3, 36, 8, 17, 
    7, 20, 2,  3, 1, 74, 5, 96, 4, 65, 6, 36, 3, 95, 8, 36, 0, 73, 
    1, 55, 0, 26, 2, 40, 5, 33, 7, 90, 3,  5, 4,  2, 8, 58, 6, 55, 
    0, 32, 3, 14, 4, 73, 7, 31, 8, 94, 5, 78, 2, 59, 6, 94, 1, 53, 
    8, 66, 4, 77, 3, 20, 0, 82, 1, 83, 6,  2, 5, 33, 7, 49, 2, 93, 
    8, 58, 7, 75, 4, 64, 3, 36, 1,  2, 2, 88, 6,  7, 0, 36, 5, 33
  };
  const int q4258[] = {
    9, 9, // Number of jobs and machines
    2, 61, 3, 83, 0,  6, 8, 74, 6, 99, 5, 88, 4, 30, 7,  7, 1, 69, 
    2, 59, 8, 82, 5, 69, 7,  9, 3, 54, 1, 22, 6, 61, 4, 39, 0, 92, 
    1, 88, 8, 48, 5, 96, 6, 61, 3,  5, 2, 60, 7, 79, 4, 41, 0,  5, 
    0, 24, 3, 46, 4, 77, 2, 88, 5, 75, 1, 49, 8,  6, 7, 59, 6, 57, 
    4, 29, 8, 73, 1, 20, 5, 37, 7, 43, 6, 22, 0, 74, 2, 39, 3, 42, 
    7, 50, 2, 55, 3, 86, 8, 51, 0, 86, 1, 20, 4, 41, 5, 54, 6,  1, 
    4, 78, 6, 53, 3,  4, 7, 52, 5, 72, 1, 58, 2, 91, 8, 96, 0, 56, 
    7, 86, 0, 68, 5, 38, 3, 74, 2, 14, 8, 72, 6, 75, 1, 37, 4, 38, 
    6, 27, 4, 75, 0, 74, 7,  9, 3, 77, 5, 67, 2, 52, 1, 63, 8, 92
  };
  const int q4259[] = {
    9, 9, // Number of jobs and machines
    0, 67, 3, 64, 4, 24, 8, 78, 5, 11, 7, 16, 1, 89, 6, 38, 2, 60, 
    4, 96, 3, 41, 0, 99, 7, 46, 5, 50, 8, 39, 2,  6, 1, 36, 6,  3, 
    1, 94, 3, 70, 6, 38, 0, 53, 8, 26, 5, 58, 2, 27, 4,  8, 7, 28, 
    2, 55, 0, 84, 3, 57, 5, 44, 8, 79, 6, 58, 1, 90, 4, 36, 7, 80, 
    2, 20, 8, 57, 6, 62, 4, 56, 3, 17, 7,  4, 5, 17, 0, 98, 1, 54, 
    1, 14, 6, 14, 8, 20, 0, 21, 4, 47, 3, 98, 7,  3, 5, 17, 2, 15, 
    7, 92, 5, 77, 3, 40, 8, 55, 0, 67, 6, 41, 2, 80, 1, 99, 4, 54, 
    2, 17, 0, 52, 3, 71, 7, 26, 6, 11, 8, 46, 5,  9, 4, 32, 1, 90, 
    2, 22, 5,  5, 8, 53, 6, 49, 4, 64, 0, 76, 1, 29, 7, 95, 3, 33
  };
  const int q4260[] = {
    9, 9, // Number of jobs and machines
    6, 25, 4, 22, 8, 62, 0, 38, 2, 14, 7, 82, 3, 28, 1, 56, 5, 67, 
    7,  6, 8, 28, 5, 82, 6, 54, 3, 95, 1, 61, 4,  6, 0, 60, 2, 84, 
    4, 58, 0, 94, 8, 93, 7, 69, 3, 79, 1, 81, 5, 73, 2, 96, 6, 80, 
    4, 96, 5, 65, 6, 36, 8, 76, 0, 12, 3, 21, 7, 44, 2, 20, 1, 42, 
    1,  2, 3,  4, 2, 29, 6, 60, 5, 11, 4, 69, 7, 90, 8, 17, 0, 10, 
    7, 54, 1, 91, 4, 12, 3, 97, 2, 76, 5, 42, 0, 63, 8, 75, 6, 56, 
    8,  4, 7, 87, 3, 83, 2, 33, 1, 29, 6, 18, 0, 19, 5, 94, 4, 74, 
    6,  4, 7, 47, 4, 67, 2, 29, 1, 49, 8, 91, 0, 99, 3, 36, 5, 65, 
    4, 66, 2, 17, 5,  4, 0, 11, 8, 38, 1, 80, 7, 99, 3, 58, 6, 75
  };
  const int q4261[] = {
    9, 9, // Number of jobs and machines
    0, 18, 4, 27, 8, 63, 3, 11, 6, 11, 7, 10, 2, 83, 5, 18, 1, 27, 
    7, 25, 4, 82, 5, 16, 8, 23, 3, 21, 6, 29, 2, 96, 0, 44, 1,  6, 
    2, 89, 4, 30, 0, 45, 6, 42, 8, 61, 3, 37, 5, 79, 7, 97, 1, 57, 
    6, 37, 8, 40, 2, 71, 5, 14, 4, 59, 3, 26, 1, 32, 7, 93, 0, 84, 
    4, 18, 5, 11, 3, 92, 7, 26, 1, 12, 2, 98, 8, 24, 0, 25, 6, 70, 
    7, 81, 2, 64, 3, 61, 4, 53, 5, 28, 6, 84, 8, 44, 1, 27, 0,  9, 
    6, 49, 3, 26, 1,  8, 4, 57, 7, 32, 5, 54, 0, 73, 8, 53, 2,  1, 
    3, 53, 8, 41, 2, 57, 6, 90, 1, 13, 7, 94, 5,  3, 4, 81, 0, 94, 
    2, 65, 3, 96, 5, 54, 6,  5, 4, 70, 1,  9, 7, 58, 8, 36, 0, 36
  };
  const int q4262[] = {
    9, 9, // Number of jobs and machines
    0, 52, 2, 81, 3, 64, 5, 29, 7, 65, 1, 18, 6, 61, 8, 73, 4, 11, 
    2, 99, 0, 42, 3, 85, 5, 43, 7, 26, 6, 63, 8, 88, 4, 48, 1, 36, 
    6, 85, 2, 71, 4, 83, 3, 17, 0, 37, 7, 64, 5, 67, 8, 45, 1, 15, 
    6, 90, 4, 48, 1, 33, 2, 64, 7, 71, 8,  6, 5, 83, 3, 90, 0, 38, 
    3,  7, 6, 41, 4, 12, 7, 34, 1, 19, 5, 68, 8, 18, 2, 12, 0, 10, 
    7, 92, 3,  5, 6, 82, 0, 30, 1, 96, 4,  4, 2, 87, 5, 35, 8, 48, 
    2, 87, 3, 48, 6, 15, 0, 19, 1, 58, 5,  6, 7, 38, 4, 48, 8, 90, 
    2, 98, 0, 67, 5, 19, 4, 90, 3,  4, 6, 14, 8, 54, 1, 38, 7, 66, 
    0, 45, 8, 50, 6, 71, 7, 14, 2, 60, 3, 51, 1, 15, 5,  3, 4, 80
  };
  const int q4263[] = {
    9, 9, // Number of jobs and machines
    0, 41, 6,  2, 7, 15, 5, 31, 1, 61, 2, 30, 3, 18, 8, 20, 4,  7, 
    7, 89, 3,  1, 1,  7, 0, 66, 4, 43, 2, 42, 8, 70, 5, 47, 6, 46, 
    8, 65, 3, 80, 1, 18, 2, 96, 4, 48, 5, 17, 6, 36, 0, 37, 7, 84, 
    0, 13, 2, 27, 5, 13, 4, 26, 7, 84, 1, 73, 6, 18, 3, 18, 8, 32, 
    6, 22, 1, 82, 3, 45, 0, 53, 2, 36, 7, 74, 5, 17, 4, 67, 8, 16, 
    2, 51, 1, 91, 3, 67, 6, 39, 4, 76, 8, 20, 7, 81, 0, 33, 5, 81, 
    8, 65, 7, 52, 1, 70, 4,  3, 5, 81, 0, 96, 3, 58, 2, 76, 6, 12, 
    4, 30, 8, 76, 7, 48, 0, 61, 1,  3, 6, 12, 5,  4, 3, 64, 2, 52, 
    5, 32, 1,  7, 0, 44, 3, 97, 2, 28, 4, 16, 7, 63, 8, 59, 6, 78
  };
  const int q4264[] = {
    9, 9, // Number of jobs and machines
    4, 74, 0, 96, 6, 48, 2, 25, 8, 93, 1, 31, 7, 23, 3,  5, 5, 31, 
    0, 35, 7, 47, 5, 81, 4, 82, 1, 42, 6, 12, 8, 97, 2, 40, 3, 69, 
    5, 81, 3, 88, 1, 23, 7, 41, 0, 43, 6,  6, 2, 42, 8, 68, 4, 16, 
    8, 44, 0, 73, 5, 19, 7, 82, 4, 31, 1, 42, 6, 78, 3, 86, 2,  8, 
    8, 34, 5, 63, 2, 24, 4, 93, 7, 79, 0, 44, 3, 94, 1, 45, 6,  8, 
    1, 19, 3,  9, 4, 75, 8, 64, 2, 62, 5, 80, 0, 41, 6, 64, 7,  3, 
    5, 24, 0, 34, 2, 22, 4, 83, 7,  7, 8, 17, 1, 27, 3, 34, 6, 90, 
    3, 18, 8, 70, 1, 76, 2, 49, 0, 36, 4, 70, 5, 58, 6, 75, 7, 68, 
    6, 84, 4, 86, 5, 98, 2, 26, 7, 61, 8, 46, 0, 23, 3, 73, 1, 50
  };
  const int q4265[] = {
    9, 9, // Number of jobs and machines
    4,  1, 5, 47, 0, 65, 8, 10, 7, 12, 2, 75, 3, 82, 6, 25, 1,  2, 
    6, 96, 8, 83, 2, 56, 1, 12, 7, 16, 4, 92, 0, 76, 3, 12, 5, 78, 
    0, 38, 2, 25, 1, 15, 6, 70, 7, 68, 3, 74, 4, 32, 8, 52, 5,  4, 
    3, 79, 6, 69, 4, 38, 5, 13, 0, 51, 2, 96, 7, 44, 8, 46, 1,  3, 
    4, 60, 0, 77, 6, 69, 3, 90, 5, 73, 2, 57, 1, 41, 7, 66, 8, 77, 
    1, 27, 5, 44, 6,  3, 8, 93, 7, 30, 2, 36, 3, 81, 0, 31, 4,  8, 
    2, 27, 3, 19, 7, 97, 1, 54, 4,  7, 0, 59, 8, 19, 5, 63, 6, 47, 
    7, 22, 5, 34, 8, 50, 3,  4, 2, 26, 4, 16, 0, 77, 1,  4, 6, 23, 
    0, 70, 5, 79, 6, 92, 2, 71, 1, 72, 8, 52, 3, 71, 7, 86, 4, 17
  };
  const int q4266[] = {
    9, 9, // Number of jobs and machines
    0, 13, 5, 26, 2, 82, 4, 76, 3, 71, 8, 34, 1, 73, 6, 23, 7, 63, 
    2, 42, 7,  9, 8, 19, 0, 81, 6, 81, 4, 51, 3, 87, 5, 59, 1, 85, 
    6, 33, 0, 40, 7, 59, 1, 52, 5, 58, 2, 99, 8, 26, 3, 32, 4,  6, 
    3, 69, 7, 48, 5, 35, 4,  6, 8, 59, 2, 65, 0, 27, 1, 26, 6, 48, 
    8, 30, 0,  5, 4,  5, 6, 57, 5, 32, 1, 71, 3, 48, 2, 91, 7, 24, 
    6, 75, 0, 67, 2, 96, 1, 77, 4, 87, 7,  1, 3, 92, 5, 52, 8, 55, 
    5,  2, 7, 96, 2, 37, 0, 94, 1,  6, 6, 39, 4,  9, 3, 84, 8, 75, 
    4, 64, 8, 38, 1, 14, 6, 13, 7, 43, 5, 91, 3, 27, 0, 93, 2, 70, 
    0, 36, 4, 26, 1, 56, 6, 60, 3, 91, 2, 72, 8,  1, 7, 34, 5, 58
  };
  const int q4267[] = {
    9, 9, // Number of jobs and machines
    0, 77, 7, 51, 5, 92, 4, 70, 2, 78, 6,  2, 8, 63, 3, 16, 1, 51, 
    0, 20, 6, 87, 1, 33, 5, 30, 4, 44, 3, 86, 7, 92, 2, 69, 8, 49, 
    7, 79, 1, 16, 4, 75, 6, 59, 3, 18, 5, 83, 0, 11, 8, 18, 2, 15, 
    6, 75, 4, 65, 2, 46, 5, 10, 8, 21, 1, 96, 3, 42, 0, 56, 7, 88, 
    1,  9, 3, 44, 8, 41, 6, 13, 7, 76, 0, 55, 2, 55, 4, 33, 5,  9, 
    1, 85, 5, 25, 6, 78, 4, 80, 0, 99, 7, 97, 8, 13, 2, 19, 3, 24, 
    6, 56, 4, 80, 7, 73, 0, 32, 8, 91, 5, 66, 2, 90, 1, 49, 3, 36, 
    6, 80, 0, 49, 7, 96, 4, 54, 3, 87, 2, 11, 1, 88, 8, 98, 5, 70, 
    4, 49, 8, 95, 7, 58, 5, 99, 2, 77, 6, 99, 3, 74, 1, 69, 0, 29
  };
  const int q4268[] = {
    9, 9, // Number of jobs and machines
    0, 77, 3, 39, 1, 90, 7, 69, 5, 99, 4, 56, 8, 57, 2,  4, 6, 56, 
    8, 28, 5, 81, 2, 36, 3, 50, 0, 92, 6, 56, 1, 38, 7, 15, 4, 68, 
    4, 70, 5, 53, 7, 75, 0, 18, 3, 76, 1, 82, 6, 22, 2, 31, 8,  1, 
    0, 90, 2, 97, 5, 14, 6, 55, 1, 17, 7, 61, 4, 42, 8, 48, 3,  8, 
    3, 98, 4, 34, 1, 43, 5,  2, 6, 20, 7,  5, 0, 92, 8, 16, 2, 11, 
    6, 95, 3, 23, 0, 63, 7, 56, 1, 77, 2, 97, 8, 70, 4, 47, 5, 58, 
    8, 96, 5, 98, 3, 15, 7, 42, 4, 21, 6, 67, 0, 32, 2, 67, 1, 25, 
    0, 84, 1, 43, 3, 54, 7, 24, 4, 77, 5, 61, 6, 79, 8, 21, 2, 98, 
    7, 79, 8, 82, 1, 63, 2, 55, 3,  1, 0, 33, 6, 22, 5, 41, 4, 94
  };
  const int q4269[] = {
    9, 9, // Number of jobs and machines
    2, 41, 8, 34, 7, 98, 3, 16, 4, 79, 5, 75, 1, 16, 6, 50, 0, 37, 
    8,  6, 0,  1, 6, 80, 1, 69, 2, 53, 5, 20, 7, 57, 4, 57, 3, 22, 
    0, 26, 1,  7, 2,  4, 3, 25, 6, 43, 5,  7, 4, 76, 7, 35, 8,  5, 
    7, 81, 6, 33, 3, 18, 4,  4, 2, 75, 8, 55, 5, 14, 0, 20, 1, 37, 
    2, 92, 4, 44, 7, 51, 5,  1, 6, 46, 1,  8, 8, 61, 0, 50, 3, 28, 
    2, 39, 0, 68, 4, 30, 6, 74, 1, 57, 8, 90, 3, 76, 5, 92, 7,  8, 
    3,  4, 4, 15, 7, 17, 5, 48, 6, 80, 0, 43, 2, 96, 1, 92, 8, 41, 
    7, 29, 3, 11, 8, 61, 0, 20, 2, 44, 1, 50, 6, 68, 4, 49, 5, 87, 
    6, 84, 0, 52, 4, 91, 2, 52, 3, 87, 8, 99, 7, 95, 5, 58, 1, 48
  };
  const int q4270[] = {
    9, 9, // Number of jobs and machines
    2, 13, 1, 83, 3, 29, 8, 51, 0, 10, 5, 63, 4, 30, 6, 31, 7,  6, 
    2, 15, 7, 89, 1, 22, 6, 10, 0, 44, 5, 32, 4, 89, 8, 68, 3, 58, 
    7, 96, 2, 20, 3, 40, 0, 33, 5, 32, 4, 86, 6,  5, 8, 35, 1, 80, 
    6, 51, 7, 86, 5, 21, 2, 72, 3, 49, 1, 35, 0, 60, 4, 16, 8, 94, 
    0, 57, 5, 76, 2, 65, 1, 41, 3, 62, 7,  5, 8, 90, 6, 38, 4, 81, 
    1, 28, 8, 33, 5, 59, 2,  2, 6, 32, 7, 92, 4, 75, 3, 17, 0, 47, 
    1, 88, 2, 22, 6, 48, 8, 38, 0, 95, 3, 87, 5, 58, 7, 16, 4, 62, 
    7, 13, 1, 99, 3, 56, 0, 41, 2, 37, 8, 34, 5, 77, 4, 47, 6, 19, 
    0, 31, 5, 72, 4, 46, 2, 76, 3, 63, 6, 88, 1, 48, 8, 88, 7,  3
  };
  const int q4271[] = {
    9, 9, // Number of jobs and machines
    0, 40, 4, 81, 7, 19, 3, 50, 6, 67, 1, 28, 2, 77, 8, 65, 5,  5, 
    7,  5, 8, 81, 3, 93, 5, 16, 1, 56, 0, 93, 6, 55, 2, 84, 4, 45, 
    6, 42, 5, 77, 1, 22, 3,  4, 7, 15, 0, 16, 4,  7, 2, 27, 8, 39, 
    6, 25, 7, 80, 1, 79, 5, 59, 2, 15, 4, 49, 8, 55, 3, 64, 0, 18, 
    8,  7, 6, 30, 3, 67, 7, 82, 1, 58, 0, 35, 5, 57, 4, 38, 2, 39, 
    7, 58, 1, 73, 8, 55, 3, 28, 6,  8, 4,  2, 2, 72, 5, 28, 0, 96, 
    4, 17, 3, 68, 5, 40, 6, 57, 2, 35, 0, 25, 7, 26, 1, 49, 8, 76, 
    7, 50, 4, 54, 5, 26, 8, 94, 2, 38, 0, 44, 1, 76, 6, 19, 3, 98, 
    5, 48, 2, 92, 1, 46, 6, 59, 0,  4, 7, 55, 4, 40, 8, 68, 3,  6
  };
  const int q4272[] = {
    9, 9, // Number of jobs and machines
    6,  1, 0, 56, 1, 12, 3, 37, 4, 36, 8, 95, 2, 19, 7, 13, 5, 86, 
    8, 65, 6, 87, 5, 49, 1, 69, 2, 52, 0, 78, 3, 36, 7, 84, 4,  7, 
    2, 37, 6, 79, 8, 83, 5, 84, 7, 78, 1, 81, 0, 52, 3, 80, 4, 86, 
    8, 26, 1, 42, 5, 96, 6, 81, 0, 92, 4, 12, 2, 28, 7, 78, 3, 89, 
    7, 94, 1, 93, 5, 78, 2, 57, 0, 34, 8, 48, 4, 34, 6, 25, 3, 36, 
    5, 82, 1, 49, 6, 41, 3, 22, 8,  2, 0, 15, 7, 73, 2, 42, 4, 32, 
    8, 25, 4, 65, 5, 40, 2, 63, 3,  9, 6, 67, 1, 89, 0, 62, 7, 80, 
    8, 16, 3, 21, 7, 97, 6, 30, 0, 85, 4, 27, 2, 34, 5,  3, 1,  3, 
    4, 93, 2,  9, 6, 62, 0, 50, 7, 86, 3, 16, 5, 31, 8, 30, 1, 85
  };
  const int q4273[] = {
    9, 9, // Number of jobs and machines
    1, 54, 0, 98, 5, 84, 3, 33, 6, 50, 8, 62, 7, 91, 2, 69, 4, 77, 
    5,  2, 0, 17, 7, 58, 3, 77, 2, 57, 4, 85, 1, 37, 6,  3, 8, 24, 
    0, 25, 8, 19, 5, 23, 4, 58, 2, 41, 3, 86, 7,  8, 6,  6, 1,  5, 
    0, 73, 4, 19, 1, 73, 5, 43, 3, 78, 8, 73, 2, 56, 6,  9, 7, 65, 
    3,  4, 5, 29, 1, 43, 7, 90, 4, 92, 2, 33, 0, 72, 8, 11, 6, 74, 
    4, 34, 1,  5, 2, 80, 7, 70, 0, 64, 5, 10, 3, 34, 8, 45, 6, 97, 
    2, 36, 5, 73, 6, 31, 0, 52, 3, 21, 4, 48, 1, 36, 8, 91, 7,  7, 
    6, 93, 0, 45, 2, 53, 5, 19, 4, 43, 3, 48, 7, 63, 8, 91, 1, 21, 
    3,  7, 0, 18, 6, 30, 5, 79, 7, 88, 1, 86, 2,  5, 4, 62, 8,  4
  };
  const int q4274[] = {
    9, 9, // Number of jobs and machines
    5, 54, 8, 24, 2, 24, 6,  2, 0, 65, 3, 42, 1, 23, 4, 12, 7, 78, 
    4, 86, 1, 58, 0, 56, 3, 85, 6, 28, 7,  9, 5, 16, 8, 56, 2, 95, 
    8, 50, 2, 21, 5, 20, 4, 24, 3, 67, 0, 95, 7, 96, 1, 49, 6, 93, 
    0, 35, 4, 76, 3, 36, 6, 10, 5,  7, 2, 83, 1, 48, 7, 93, 8, 81, 
    6, 19, 5, 77, 7, 63, 8, 20, 3, 96, 0, 35, 4, 62, 1, 48, 2, 19, 
    6, 18, 4, 76, 3, 87, 0, 16, 1, 58, 8,  1, 7, 60, 5, 64, 2, 22, 
    8,  2, 0, 96, 1, 96, 3, 25, 2, 34, 4, 18, 7,  3, 5, 44, 6, 19, 
    8, 24, 4, 62, 5, 37, 7, 57, 2, 49, 0, 12, 1, 31, 3, 35, 6, 69, 
    7, 79, 4,  8, 5, 17, 3, 30, 8, 46, 6, 64, 0, 32, 2, 59, 1, 94
  };
  const int q4275[] = {
    9, 9, // Number of jobs and machines
    1, 36, 3, 72, 8, 78, 7, 28, 2, 78, 5, 21, 6, 69, 0, 62, 4, 57, 
    6, 69, 7, 48, 1, 20, 5, 98, 4, 96, 0, 26, 3, 97, 8, 62, 2, 18, 
    2, 69, 1, 81, 3,  8, 6, 72, 0, 84, 5, 51, 8, 94, 7, 59, 4, 71, 
    1,  9, 6,  1, 2, 60, 3, 27, 4, 41, 5, 21, 8, 91, 7, 72, 0, 75, 
    1, 73, 7, 92, 2, 94, 4, 86, 0, 66, 3, 54, 5, 92, 6, 93, 8, 13, 
    0, 24, 3, 62, 6, 42, 1, 27, 2, 34, 8, 54, 5, 80, 4, 61, 7, 49, 
    5, 34, 2, 83, 8, 19, 1, 45, 0, 58, 3,  8, 6, 95, 7, 82, 4, 66, 
    1, 55, 2,  7, 5, 34, 0, 52, 4, 72, 3,  1, 8,  1, 6, 99, 7, 30, 
    2, 96, 1, 97, 3, 67, 4, 43, 7, 58, 8, 98, 0, 76, 6, 21, 5, 87
  };
  const int q4276[] = {
    9, 9, // Number of jobs and machines
    7, 98, 6, 44, 8, 56, 3, 52, 0, 42, 1, 76, 5, 80, 2, 49, 4, 18, 
    1, 66, 0, 48, 7, 37, 6, 44, 8, 10, 2, 80, 5, 89, 3, 73, 4, 93, 
    4, 22, 6, 42, 7, 82, 1, 86, 3, 52, 0, 52, 5, 99, 2, 89, 8, 96, 
    5, 22, 8, 58, 1, 77, 3, 53, 0, 70, 4, 26, 2,  8, 7, 12, 6, 62, 
    5, 73, 3, 25, 0, 44, 1,  5, 6, 21, 8, 82, 4, 14, 2, 48, 7, 36, 
    6, 93, 0, 86, 7, 36, 1, 21, 8, 51, 4, 97, 5, 51, 3, 62, 2, 83, 
    8, 52, 1, 81, 5, 21, 7, 97, 3, 67, 2, 28, 0, 26, 4, 79, 6, 53, 
    3, 32, 7, 33, 6,  7, 4, 47, 1, 94, 8, 32, 0, 85, 5, 72, 2, 44, 
    2, 73, 1, 85, 0, 56, 3, 70, 7, 91, 8, 56, 4, 38, 5, 87, 6, 97
  };
  const int q4277[] = {
    9, 9, // Number of jobs and machines
    7,  7, 5, 62, 6, 53, 1, 81, 8, 59, 4, 16, 2, 53, 0, 79, 3, 90, 
    3, 21, 5, 97, 6,  9, 4, 46, 8, 13, 0, 33, 1, 22, 2, 17, 7, 41, 
    6, 55, 1, 73, 4, 46, 3, 55, 2, 51, 8, 21, 0, 46, 5, 70, 7, 42, 
    5, 12, 6, 69, 4, 76, 8,  1, 0, 81, 1, 90, 3, 92, 2, 86, 7, 82, 
    4, 90, 1, 76, 5, 81, 7, 35, 3, 54, 2,  9, 8, 93, 0, 82, 6, 65, 
    0, 93, 1, 16, 4, 38, 6, 26, 2, 63, 8, 10, 3, 91, 5, 52, 7, 42, 
    8, 59, 7, 18, 4, 86, 1, 87, 6, 58, 5, 63, 3, 14, 0, 26, 2, 56, 
    8, 23, 4, 41, 2, 10, 3,  3, 6, 46, 5, 72, 0,  8, 7,  5, 1, 31, 
    7,  2, 0,  8, 5, 26, 2, 88, 6, 20, 3, 16, 1, 75, 8, 97, 4, 49
  };
  const int q4278[] = {
    9, 9, // Number of jobs and machines
    3, 46, 1, 34, 2, 29, 6, 25, 4, 35, 5, 15, 7, 50, 0, 34, 8, 43, 
    7, 92, 5, 86, 6,  2, 3, 80, 1, 80, 8, 52, 2, 77, 4, 85, 0, 28, 
    4, 47, 7, 66, 1, 79, 3, 75, 8, 82, 5, 20, 2,  1, 6, 86, 0, 46, 
    1, 54, 0,  7, 5,  4, 3, 52, 4, 72, 6, 23, 2,  7, 8, 39, 7, 73, 
    3, 78, 1, 25, 6,  2, 2, 80, 8, 42, 7, 57, 4, 49, 5,  6, 0, 30, 
    3, 93, 1, 33, 7, 92, 0, 31, 4,  3, 8, 80, 2, 42, 5, 16, 6, 42, 
    8, 14, 4, 15, 7, 89, 0, 16, 6, 44, 5, 22, 1, 71, 2, 95, 3, 48, 
    1, 92, 2, 50, 5, 48, 0, 82, 3, 75, 7, 25, 4,  3, 6, 52, 8, 44, 
    6,  5, 1, 83, 3, 10, 4, 74, 2, 28, 7, 57, 0, 94, 8, 27, 5, 33
  };
  const int q4279[] = {
    9, 9, // Number of jobs and machines
    5, 48, 8, 10, 4, 27, 2, 93, 3, 26, 7, 21, 1, 96, 6, 23, 0, 74, 
    8, 29, 2, 71, 6, 64, 0, 34, 3, 78, 5, 56, 4, 64, 1, 11, 7, 86, 
    3, 13, 8,  3, 0, 30, 2,  3, 5, 52, 7, 75, 1, 47, 6, 63, 4, 11, 
    0, 59, 2, 38, 6, 82, 3, 28, 4, 77, 7, 48, 5, 35, 1, 40, 8, 90, 
    0, 16, 8, 18, 4, 38, 1, 85, 3, 37, 7, 38, 6, 86, 2, 44, 5, 12, 
    2, 22, 3,  1, 6, 70, 1, 85, 7,  7, 4,  4, 0, 96, 5,  5, 8, 66, 
    2, 89, 5, 12, 0, 86, 4, 98, 7, 97, 3, 76, 1, 65, 8, 18, 6, 73, 
    3, 85, 6, 61, 1, 76, 0, 23, 4, 40, 7, 77, 5, 30, 2,  4, 8, 27, 
    0,  6, 4, 19, 2, 86, 5, 93, 6, 68, 7, 96, 3, 75, 1, 66, 8, 46
  };
  const int q4280[] = {
    9, 9, // Number of jobs and machines
    5, 30, 2, 44, 3, 45, 8, 26, 4, 47, 0, 13, 1, 58, 7, 98, 6, 41, 
    3, 76, 5, 20, 0, 66, 8, 69, 2, 38, 4, 11, 1, 45, 6, 77, 7,  6, 
    4, 46, 7, 95, 3, 71, 2, 89, 1, 96, 6, 10, 8,  9, 5, 14, 0, 51, 
    7, 80, 8, 40, 2,  9, 4, 20, 6, 86, 5, 51, 3, 71, 0, 74, 1, 57, 
    6, 90, 4, 20, 7, 38, 0, 22, 1, 20, 8, 72, 2, 33, 3, 52, 5, 64, 
    8, 54, 5, 95, 1,  9, 6,  2, 2, 14, 3, 64, 0, 37, 4, 22, 7, 54, 
    5, 29, 7,  4, 2, 44, 4, 49, 0,  9, 3, 58, 1, 59, 6, 92, 8, 26, 
    7, 65, 2, 22, 6, 85, 3, 32, 5, 82, 4, 49, 0, 65, 1,  1, 8, 22, 
    6, 52, 1, 78, 4, 58, 3, 40, 2, 77, 8,  8, 5, 77, 0, 20, 7, 77
  };
  const int q4281[] = {
    9, 9, // Number of jobs and machines
    4, 55, 3, 14, 5, 39, 7, 98, 6, 27, 0, 82, 1, 91, 8, 71, 2,  7, 
    4, 32, 8, 38, 5, 15, 3, 56, 7, 22, 2, 12, 1, 31, 6, 70, 0, 67, 
    8, 42, 5, 70, 7, 23, 4, 37, 6, 94, 1, 28, 2, 14, 3, 73, 0, 24, 
    8, 86, 0, 55, 2, 19, 6, 45, 3, 41, 7, 64, 5,  5, 1, 89, 4,  4, 
    5, 98, 0, 43, 3, 76, 8, 58, 4, 46, 2, 27, 1, 21, 7, 44, 6, 38, 
    1, 81, 7, 90, 5, 71, 4, 39, 6, 89, 0, 64, 8, 12, 3, 63, 2, 78, 
    1, 70, 2, 89, 6, 62, 8, 34, 5, 50, 7, 46, 4, 81, 0, 88, 3, 31, 
    3,  9, 0, 77, 6, 10, 8, 38, 1, 13, 7,  7, 2,  2, 4, 11, 5, 78, 
    8, 60, 6, 79, 1, 89, 4, 73, 3, 90, 2, 93, 7,  5, 0, 69, 5, 31
  };
  const int q4282[] = {
    9, 9, // Number of jobs and machines
    4, 22, 7, 11, 0, 31, 2, 41, 8, 91, 6, 85, 1, 11, 5,  4, 3, 34, 
    7, 88, 2,  5, 3, 39, 4, 81, 1, 79, 8, 62, 0,  7, 5, 99, 6, 32, 
    0,  3, 6, 74, 7, 52, 3, 45, 1, 52, 8, 27, 5, 85, 2, 73, 4,  3, 
    7, 10, 0, 45, 8, 54, 5, 78, 6, 99, 2, 17, 3, 56, 4, 99, 1, 77, 
    8,  2, 5, 63, 0, 39, 3, 19, 2, 95, 6, 18, 4,  8, 1, 56, 7, 56, 
    7, 89, 1, 41, 8, 19, 4, 47, 3, 64, 0, 65, 5,  7, 6, 66, 2,  5, 
    2, 26, 1, 48, 4, 22, 6, 66, 7, 88, 3, 77, 8,  5, 5, 66, 0, 98, 
    1, 47, 6, 21, 7, 60, 8, 54, 5, 77, 3,  8, 0, 58, 4, 77, 2, 19, 
    5, 34, 3, 69, 8, 73, 1, 45, 6, 57, 4, 18, 7, 80, 2, 29, 0, 90
  };
  const int q4283[] = {
    9, 9, // Number of jobs and machines
    8, 92, 2, 42, 6, 73, 4,  7, 5, 45, 0, 42, 1, 82, 7, 40, 3, 62, 
    5, 72, 3, 72, 8, 81, 0, 63, 2,  2, 6, 53, 1, 71, 4, 26, 7, 25, 
    8, 67, 1, 14, 2, 59, 5, 87, 6, 43, 4, 75, 7, 48, 0,  3, 3, 61, 
    6, 42, 1, 18, 8, 35, 0, 24, 3, 37, 2,  9, 4, 46, 7, 17, 5, 96, 
    3, 19, 1, 28, 4, 44, 5, 43, 2, 80, 6, 41, 7, 80, 0, 77, 8, 40, 
    4, 27, 8, 91, 5, 84, 6, 43, 7, 85, 0, 18, 3, 56, 2, 44, 1, 52, 
    7, 38, 3, 92, 0, 45, 2, 45, 6, 91, 1, 42, 5, 13, 8, 36, 4, 72, 
    4, 51, 7, 81, 3, 57, 8, 29, 0, 27, 6, 28, 2, 54, 5, 13, 1, 54, 
    5, 64, 2, 38, 1, 25, 0, 74, 8, 96, 4, 29, 6, 71, 3, 43, 7, 43
  };
  const int q4284[] = {
    9, 9, // Number of jobs and machines
    5, 22, 8,  3, 2, 40, 4, 46, 3, 15, 0, 90, 7, 59, 1,  3, 6, 13, 
    4, 86, 8, 72, 0, 53, 6, 44, 5, 66, 1, 17, 7, 86, 3, 20, 2, 95, 
    1, 98, 7, 43, 5, 52, 3, 15, 8, 48, 4, 68, 0, 51, 6,  8, 2,  6, 
    8, 10, 1,  6, 5, 77, 7, 81, 4, 31, 0, 49, 2, 97, 3, 97, 6, 40, 
    6, 11, 0, 77, 2, 97, 4, 67, 7, 50, 8, 99, 5, 61, 1,  7, 3, 51, 
    0, 18, 6, 21, 4, 63, 2, 58, 3,  2, 5, 29, 8, 14, 1, 93, 7, 82, 
    8, 68, 3, 10, 2, 35, 7, 68, 5, 10, 0, 53, 4, 13, 1, 90, 6, 94, 
    0, 13, 4, 60, 1, 33, 5, 82, 8, 46, 2, 10, 3, 21, 7, 89, 6, 58, 
    7, 71, 5, 45, 3, 54, 0, 64, 1, 69, 2,  8, 8, 15, 4, 17, 6, 34
  };
  const int q4285[] = {
    9, 9, // Number of jobs and machines
    7, 34, 5, 95, 6, 36, 0, 56, 8, 31, 4, 37, 1, 21, 3, 24, 2, 50, 
    3, 84, 8, 77, 0, 16, 2, 47, 1,  2, 5, 21, 7, 71, 4, 70, 6, 50, 
    7, 83, 6, 78, 0, 44, 2, 74, 5, 29, 1, 18, 4, 60, 3, 83, 8, 36, 
    7, 66, 1, 16, 3, 50, 2, 31, 5, 72, 4, 87, 8, 67, 6, 25, 0, 15, 
    1, 47, 0, 72, 7, 32, 5, 83, 3, 93, 6, 86, 2, 20, 8, 78, 4, 41, 
    4, 10, 2, 71, 1,  3, 5, 79, 6, 98, 8, 33, 7, 93, 3, 44, 0,  2, 
    3, 34, 2, 86, 6, 21, 1, 76, 7, 47, 0, 29, 4, 39, 5, 77, 8, 81, 
    7,  7, 1, 75, 3, 90, 8, 29, 4, 72, 2, 65, 6, 46, 5, 31, 0, 32, 
    3, 32, 4, 56, 7, 26, 5, 68, 6, 57, 2, 43, 8, 60, 1, 20, 0, 92
  };
  const int q4286[] = {
    9, 9, // Number of jobs and machines
    5, 63, 1, 59, 8, 76, 2, 76, 3, 15, 7, 66, 0, 67, 4, 22, 6, 59, 
    1, 11, 4, 97, 3, 13, 6, 35, 7, 17, 8, 76, 0, 30, 5, 96, 2, 24, 
    2, 51, 5, 49, 3, 77, 8, 37, 6, 94, 7, 28, 1, 29, 0, 45, 4, 34, 
    6, 42, 0, 22, 4, 87, 2,  6, 8, 78, 7, 58, 1, 19, 3, 26, 5, 88, 
    4, 67, 3, 43, 5, 13, 7, 25, 8, 89, 1,  1, 0, 71, 6, 76, 2, 84, 
    0,  1, 2, 66, 7,  7, 8, 84, 4, 21, 1, 73, 3, 28, 6, 18, 5,  2, 
    2, 13, 3, 70, 4, 33, 0, 49, 5, 12, 6, 16, 1, 60, 7, 38, 8, 35, 
    2, 98, 1,  2, 0, 49, 5, 46, 3, 47, 6, 61, 8, 99, 7, 32, 4, 93, 
    7, 35, 6, 54, 4, 48, 8, 67, 3, 60, 5, 25, 1, 87, 2, 57, 0, 26
  };
  const int q4287[] = {
    9, 9, // Number of jobs and machines
    1, 15, 6, 66, 8, 27, 3, 51, 5, 86, 4, 37, 2, 79, 0, 35, 7, 94, 
    3, 58, 4, 18, 5, 56, 2, 55, 7, 39, 1, 97, 6, 39, 8, 44, 0,  6, 
    7, 12, 1, 65, 6, 89, 3, 82, 4, 41, 8,  7, 0, 42, 2, 80, 5, 11, 
    1,  3, 6, 63, 7, 23, 8, 27, 5, 99, 4, 48, 0, 55, 2, 10, 3, 45, 
    3,  8, 8,  3, 0, 66, 1, 21, 7, 13, 5, 99, 2, 68, 6, 57, 4, 52, 
    5, 10, 6, 13, 1, 87, 3, 24, 7, 65, 4, 86, 2, 74, 0, 43, 8, 57, 
    5, 58, 1, 26, 6, 88, 2, 23, 7, 73, 3, 66, 8, 70, 4, 44, 0, 78, 
    4, 58, 3, 21, 8, 25, 2, 29, 0,  8, 5, 40, 6, 17, 7, 32, 1, 38, 
    7, 58, 6, 27, 4, 35, 1, 78, 3, 43, 0, 18, 5, 31, 8,  8, 2, 16
  };
  const int q4288[] = {
    9, 9, // Number of jobs and machines
    0,  6, 6, 70, 1, 74, 3, 20, 8, 64, 5, 10, 7, 92, 2, 65, 4, 25, 
    4, 66, 7, 83, 3, 85, 5, 92, 6,  7, 0, 35, 2, 52, 1, 18, 8, 19, 
    3, 88, 6, 44, 1, 35, 5,  7, 2, 42, 4, 95, 8, 98, 0,  7, 7,  5, 
    6, 52, 1, 48, 7, 39, 2, 18, 0, 99, 3, 50, 8, 66, 4, 67, 5, 65, 
    2,  9, 4, 29, 3, 20, 7, 96, 1, 87, 6, 39, 5, 20, 8, 73, 0, 92, 
    3, 80, 2, 58, 8, 92, 6, 33, 1, 51, 5, 92, 4, 83, 7, 29, 0, 28, 
    3, 38, 5, 85, 2, 27, 6, 76, 1, 82, 4, 89, 0, 13, 7,  5, 8, 24, 
    5, 87, 0, 18, 3, 34, 7, 38, 4, 13, 6, 16, 8, 71, 1, 11, 2, 35, 
    4, 26, 2, 90, 0, 79, 8, 71, 5, 70, 6, 15, 7, 10, 3, 73, 1, 97
  };
  const int q4289[] = {
    9, 9, // Number of jobs and machines
    3, 30, 4, 18, 8,  6, 2,  1, 5, 82, 1, 41, 0, 64, 6, 18, 7,  8, 
    2, 72, 1, 40, 8, 35, 5, 98, 0, 52, 4, 79, 6, 61, 3, 23, 7, 14, 
    5, 16, 7, 50, 3,  1, 1, 13, 8, 95, 4, 13, 0, 34, 2, 90, 6, 60, 
    2, 42, 0, 58, 4, 60, 1, 32, 7, 93, 8, 44, 6,  1, 3,  8, 5, 86, 
    1, 91, 5, 95, 7, 67, 8, 34, 4, 17, 3, 59, 2, 25, 6, 95, 0, 33, 
    3, 70, 4, 31, 1, 87, 2, 52, 0, 26, 6, 88, 5, 36, 8, 52, 7, 11, 
    7, 77, 2, 53, 3, 12, 5, 92, 0, 32, 4, 74, 6, 70, 1, 84, 8, 18, 
    1, 30, 6,  8, 8, 16, 4, 83, 3, 23, 7, 86, 0, 14, 5, 92, 2, 83, 
    5, 73, 6,  3, 1, 41, 3, 60, 2, 56, 7, 70, 8, 58, 4, 52, 0, 31
  };
  const int q4290[] = {
    9, 9, // Number of jobs and machines
    8, 67, 2, 14, 0, 70, 4, 60, 5, 41, 1, 67, 6, 59, 7, 81, 3, 84, 
    8, 12, 4, 65, 2, 86, 3,  3, 1, 52, 7, 46, 0, 14, 5,  5, 6, 55, 
    8, 24, 6, 88, 5, 91, 0, 22, 1, 23, 3, 12, 4, 70, 2, 96, 7, 12, 
    6, 70, 7, 60, 0, 35, 1, 83, 4, 35, 8, 31, 2, 67, 5, 12, 3, 91, 
    0, 12, 8, 72, 5, 36, 7, 43, 6, 33, 3, 12, 1, 64, 4, 23, 2, 91, 
    4, 81, 7, 40, 3, 87, 5, 54, 8, 21, 2, 15, 0, 29, 6, 84, 1, 27, 
    3,  5, 4, 95, 0,  1, 2, 37, 1, 46, 7,  6, 5, 47, 6, 57, 8, 28, 
    1, 61, 5, 26, 6, 37, 3,  1, 0,  6, 7, 52, 4, 43, 8, 33, 2, 71, 
    3, 82, 4, 54, 2, 45, 0, 33, 6, 84, 1, 20, 7, 75, 8, 50, 5, 91
  };
  const int q4291[] = {
    9, 9, // Number of jobs and machines
    2, 37, 1, 43, 8, 11, 4, 41, 7, 27, 0, 75, 5, 63, 6, 63, 3, 75, 
    2, 90, 8, 66, 1, 54, 4, 56, 7, 85, 3, 67, 6, 39, 0, 76, 5, 60, 
    7, 72, 5,  1, 4, 74, 3, 55, 2, 84, 6, 51, 8, 58, 1,  3, 0, 14, 
    8, 19, 2, 92, 1, 98, 4, 62, 3, 71, 6, 97, 0, 34, 5, 61, 7, 26, 
    3, 23, 0, 43, 2, 62, 4, 95, 8, 88, 1, 16, 5, 81, 6, 58, 7, 30, 
    4, 18, 7, 23, 8, 13, 1, 78, 0, 79, 3, 46, 5, 27, 2, 73, 6, 25, 
    2, 57, 4, 67, 7, 70, 5, 66, 3, 86, 1, 78, 6, 46, 8, 31, 0, 68, 
    4, 30, 7, 24, 6, 91, 2, 59, 0, 49, 8, 77, 5, 31, 1, 88, 3, 75, 
    3, 36, 2, 53, 7, 40, 6, 32, 5, 96, 8, 86, 4, 12, 0, 91, 1,  9
  };
  const int q4292[] = {
    9, 9, // Number of jobs and machines
    0, 82, 2, 87, 3, 22, 8, 68, 5, 32, 4, 85, 6, 10, 7, 35, 1, 89, 
    0, 78, 1, 78, 5, 85, 8, 40, 7, 72, 4, 79, 3, 36, 2, 46, 6, 26, 
    8, 11, 2, 48, 6, 15, 3, 48, 4, 18, 0, 53, 5,  5, 1, 25, 7, 15, 
    3,  9, 4, 98, 5, 69, 1, 54, 8, 43, 7, 98, 2, 52, 6, 87, 0, 18, 
    5, 23, 0,  8, 1, 25, 7, 53, 2, 30, 4, 34, 6, 87, 3, 31, 8, 32, 
    3, 95, 8, 22, 5,  6, 4, 94, 7, 84, 1, 37, 0,  7, 6, 54, 2,  9, 
    5, 23, 0, 75, 7,  7, 4, 38, 8, 86, 6, 73, 1, 96, 2, 28, 3, 87, 
    3, 81, 5,  7, 4, 96, 7, 20, 2, 58, 0, 78, 8, 50, 6, 56, 1, 85, 
    6, 13, 3, 53, 0, 86, 8,  3, 4, 84, 1, 76, 2, 25, 5, 67, 7, 86
  };
  const int q4293[] = {
    9, 9, // Number of jobs and machines
    3, 18, 4, 86, 5, 28, 0, 90, 8, 30, 1, 50, 7, 30, 2, 37, 6, 40, 
    6, 75, 8,  2, 2,  4, 4, 53, 1, 68, 7,  1, 3,  8, 0, 95, 5, 82, 
    2, 13, 5, 91, 1, 11, 3, 79, 4, 68, 8, 30, 0, 66, 6, 87, 7, 84, 
    8,  7, 6, 48, 0, 31, 2, 63, 5, 61, 4, 46, 7, 14, 3, 77, 1, 85, 
    1, 53, 5, 39, 0, 58, 6, 37, 4,  4, 8, 37, 2, 52, 3, 11, 7, 74, 
    1, 61, 7, 54, 5,  7, 3, 69, 4, 77, 0,  9, 6, 64, 2, 92, 8, 95, 
    5, 39, 1, 51, 8, 69, 7, 58, 4, 59, 2, 49, 0, 60, 6, 81, 3, 34, 
    1, 89, 2, 33, 4, 96, 7, 18, 6, 87, 0, 88, 3, 90, 8, 47, 5, 43, 
    1, 13, 3, 40, 8, 53, 7, 34, 6, 49, 2, 48, 0, 44, 4, 33, 5, 69
  };
  const int q4294[] = {
    9, 9, // Number of jobs and machines
    6, 40, 1, 22, 2, 46, 8, 63, 3, 43, 7, 10, 0,  4, 4, 64, 5, 17, 
    8, 74, 6, 56, 3,  7, 7, 67, 2, 41, 0, 58, 5, 27, 1, 96, 4,  6, 
    8, 69, 6, 96, 7, 65, 1, 80, 2, 14, 0, 73, 3, 30, 4, 23, 5,  1, 
    6, 35, 2, 40, 7, 14, 5, 42, 0, 72, 1, 61, 3, 25, 8, 28, 4, 69, 
    0, 22, 7, 50, 1, 71, 5, 39, 6, 74, 4, 50, 2, 73, 8, 55, 3, 82, 
    0, 34, 3, 22, 2, 92, 7, 91, 8, 30, 5, 33, 4, 77, 1, 55, 6, 78, 
    5, 33, 3, 91, 7, 55, 2, 97, 4, 57, 8, 26, 6, 21, 0, 62, 1, 38, 
    1, 19, 2, 76, 4,  6, 5, 65, 8, 81, 3, 79, 7, 60, 0, 61, 6, 54, 
    7, 11, 5, 93, 6, 98, 1, 21, 4, 43, 8, 35, 3, 42, 0,  7, 2, 73
  };
  const int q4295[] = {
    9, 9, // Number of jobs and machines
    0,  6, 8, 68, 7, 95, 4, 86, 2, 76, 6, 42, 3, 31, 5, 94, 1, 52, 
    0, 62, 2, 22, 3, 62, 5, 98, 6, 65, 8, 97, 4,  7, 1, 28, 7, 84, 
    8, 22, 2, 81, 7, 33, 0, 61, 4, 67, 5, 24, 3, 51, 6, 58, 1, 74, 
    2, 88, 8,  6, 0, 42, 1, 52, 5, 38, 7, 80, 4, 32, 3, 25, 6, 38, 
    5,  6, 6, 19, 7, 44, 8, 45, 3, 40, 2, 64, 0, 55, 1, 94, 4, 46, 
    6, 89, 1, 99, 5, 76, 4,  8, 0,  9, 3, 67, 2,  9, 8, 69, 7, 40, 
    2, 43, 6, 90, 7, 17, 8, 58, 1, 67, 3, 51, 4, 72, 5, 23, 0, 47, 
    1, 95, 2, 83, 0, 27, 4, 13, 6, 30, 5, 28, 8, 63, 3, 27, 7,  2, 
    1, 71, 6, 26, 0, 37, 5, 76, 2, 61, 3, 56, 7, 14, 8, 99, 4, 81
  };
  const int q4296[] = {
    9, 9, // Number of jobs and machines
    0, 60, 2, 67, 7, 48, 4, 33, 8, 92, 3, 13, 6, 84, 1, 51, 5, 79, 
    6, 70, 1, 23, 5, 45, 4,  6, 3, 92, 8, 23, 2, 61, 0, 81, 7, 22, 
    5, 74, 1, 48, 4, 20, 3, 76, 2, 85, 6, 63, 8,  1, 0, 74, 7,  6, 
    2, 78, 5, 55, 7, 89, 3,  2, 1, 20, 0,  5, 8, 64, 4, 28, 6, 11, 
    8,  5, 5, 27, 4, 81, 6, 74, 2, 83, 7, 46, 1, 12, 0, 68, 3, 91, 
    7, 75, 5, 51, 1, 97, 2, 31, 3, 23, 4, 18, 0, 59, 8, 25, 6,  2, 
    5,  2, 4, 61, 8, 37, 6, 56, 2, 12, 7, 32, 3, 20, 0,  7, 1, 36, 
    2, 72, 5, 40, 8, 93, 0, 65, 7, 90, 6, 82, 3, 66, 1, 46, 4, 20, 
    0, 41, 1,  5, 3,  9, 7, 61, 8, 92, 6, 38, 4, 98, 2, 79, 5, 52
  };
  const int q4297[] = {
    9, 9, // Number of jobs and machines
    8, 41, 4, 75, 1, 26, 0, 46, 6, 99, 3, 47, 7, 93, 2, 79, 5, 29, 
    2, 55, 4, 92, 5, 16, 6, 63, 1, 34, 8, 60, 0, 12, 7, 32, 3, 72, 
    7, 58, 3, 37, 1, 83, 2, 88, 6, 27, 0, 98, 8, 49, 5, 59, 4, 97, 
    2, 80, 4, 62, 1, 10, 0, 91, 5,  2, 3, 41, 8, 62, 7, 23, 6, 36, 
    6,  3, 4, 83, 5, 49, 2, 28, 8, 44, 0, 72, 7, 33, 3, 43, 1, 54, 
    3, 44, 0, 24, 7, 91, 6, 47, 8, 60, 1, 65, 5, 15, 2, 81, 4, 34, 
    0,  9, 1, 79, 3, 23, 7, 77, 8, 72, 4, 92, 6, 28, 5, 33, 2, 26, 
    1, 84, 0, 84, 2, 46, 5, 29, 3, 85, 6, 66, 8, 43, 4,  6, 7, 10, 
    0, 66, 6,  7, 7,  9, 3, 13, 2, 71, 4, 71, 5, 84, 1, 66, 8, 82
  };
  const int q4298[] = {
    9, 9, // Number of jobs and machines
    6, 98, 3, 36, 8, 20, 2, 36, 1, 28, 5, 81, 7, 45, 0, 23, 4, 99, 
    1, 72, 2, 14, 4, 11, 7, 68, 8,  8, 0, 64, 5, 69, 3, 37, 6, 55, 
    8, 28, 7,  8, 2, 44, 6, 21, 4, 28, 1, 30, 0, 96, 3, 39, 5, 74, 
    5, 66, 2, 20, 8, 52, 7, 95, 3, 63, 6, 70, 1, 82, 4, 50, 0, 62, 
    8, 58, 2, 77, 0, 25, 1, 39, 6, 35, 4,  4, 5, 46, 7, 67, 3, 41, 
    2,  5, 4, 87, 1, 65, 5, 85, 8, 56, 3, 28, 0, 90, 6, 16, 7, 60, 
    1,  1, 7, 84, 3, 89, 0, 40, 2, 52, 4, 84, 8, 50, 5, 54, 6,  3, 
    1, 80, 0, 31, 7, 20, 3, 66, 2, 81, 4, 85, 6, 74, 5,  5, 8, 93, 
    1, 74, 8, 51, 2, 28, 3, 34, 4, 15, 0, 73, 7, 31, 5, 92, 6, 18
  };
  const int q4299[] = {
    9, 9, // Number of jobs and machines
    3, 59, 0, 74, 1, 23, 5, 73, 2, 17, 7, 41, 6, 73, 4, 62, 8, 80, 
    7, 85, 4, 91, 0, 39, 3, 29, 1, 66, 6, 55, 5, 35, 2,  1, 8,  4, 
    6, 47, 1, 19, 3, 78, 7,  3, 5, 44, 2, 23, 0, 26, 4, 67, 8, 63, 
    3, 19, 8, 41, 5, 37, 1,  7, 7,  9, 4, 21, 0, 47, 6, 49, 2, 76, 
    4, 93, 6, 56, 7, 15, 1, 32, 0, 37, 5, 19, 3, 87, 2, 56, 8, 34, 
    2, 18, 7, 62, 4, 10, 8, 27, 1, 63, 6, 83, 5, 36, 0, 91, 3, 80, 
    6, 24, 5, 28, 0, 76, 1, 50, 2, 28, 3,  1, 8, 34, 7, 80, 4, 25, 
    5, 38, 4, 69, 7, 89, 0, 14, 6, 78, 8, 28, 3, 52, 1, 11, 2, 35, 
    1, 70, 0, 92, 8, 45, 7, 28, 4, 10, 5, 66, 6,  8, 2, 43, 3, 55
  };
  const int q4300[] = {
    9, 9, // Number of jobs and machines
    8, 53, 3, 21, 6, 61, 4, 81, 7, 77, 0, 49, 1, 37, 2, 88, 5, 47, 
    0, 82, 1, 77, 8, 86, 3, 99, 5, 64, 6,  1, 4, 82, 7, 26, 2,  2, 
    5, 43, 0, 51, 2, 52, 4, 28, 3, 26, 7, 23, 6, 73, 8, 67, 1, 71, 
    3, 12, 7,  4, 1, 79, 4, 90, 6, 84, 5,  3, 8, 86, 0, 13, 2, 45, 
    0, 66, 1, 41, 2, 75, 8, 75, 4, 47, 6, 95, 3, 20, 7, 40, 5, 36, 
    6, 10, 0, 99, 2, 65, 3, 36, 5, 38, 1, 36, 7,  4, 4, 44, 8, 95, 
    0, 46, 4, 88, 2, 20, 8, 89, 6, 27, 7, 16, 3, 16, 5,  4, 1, 65, 
    0, 13, 5, 20, 2, 75, 7, 80, 1, 69, 4, 53, 8, 59, 6, 23, 3, 54, 
    6, 63, 2, 26, 8, 67, 1, 62, 3, 73, 7, 76, 4, 80, 5, 83, 0, 41
  };
  const int q4301[] = {
    9, 9, // Number of jobs and machines
    5, 75, 1, 12, 8, 46, 2, 63, 4, 25, 0, 85, 7, 10, 6, 42, 3, 19, 
    5, 16, 6, 56, 2, 68, 1, 38, 8, 97, 3, 13, 4, 62, 0, 53, 7, 11, 
    6, 91, 4,  7, 3, 77, 7, 69, 1,  1, 5, 78, 0, 53, 2, 47, 8, 35, 
    3, 68, 4, 29, 5, 85, 7, 36, 8, 42, 0, 25, 6, 83, 1, 13, 2, 25, 
    4, 24, 0, 68, 1, 27, 3, 42, 8, 13, 2, 84, 5,  7, 6, 76, 7, 25, 
    2, 25, 7,  6, 3, 93, 6, 69, 1, 93, 4, 79, 5, 93, 0, 80, 8, 14, 
    6, 74, 0, 92, 2,  8, 5, 10, 3, 51, 7, 26, 1, 66, 4, 36, 8, 56, 
    1, 43, 8, 78, 5, 80, 3, 49, 4, 86, 2, 42, 6, 79, 0, 71, 7, 61, 
    4, 94, 8, 88, 0, 51, 6, 59, 5, 92, 7, 99, 1, 85, 2, 18, 3, 91
  };
  const int q4302[] = {
    9, 9, // Number of jobs and machines
    5, 77, 4, 25, 6, 76, 7, 30, 2, 42, 3, 56, 0,  8, 8, 88, 1, 28, 
    2, 38, 4, 60, 5, 24, 6, 12, 8, 30, 1, 90, 3, 39, 7, 61, 0,  4, 
    7, 60, 6, 27, 8,  6, 5, 88, 4, 63, 3,  1, 0, 13, 1, 97, 2, 48, 
    4, 18, 2, 16, 7, 44, 5, 92, 8,  6, 3, 52, 0, 46, 1, 85, 6, 92, 
    4, 93, 3, 38, 2, 18, 5, 72, 8, 60, 7, 93, 6, 96, 1, 27, 0, 57, 
    6, 78, 7, 40, 8, 22, 4, 43, 3, 17, 1, 24, 5, 98, 0, 86, 2, 41, 
    8,  3, 5, 45, 4, 28, 1, 42, 3, 26, 6, 75, 7, 22, 2, 71, 0, 40, 
    1, 35, 6,  8, 8, 77, 3, 66, 4, 43, 0, 56, 5, 87, 7, 72, 2, 26, 
    6, 70, 7, 45, 3, 67, 4, 62, 5, 88, 8, 33, 0,  8, 2,  8, 1, 73
  };
  const int q4303[] = {
    9, 9, // Number of jobs and machines
    7,  6, 1, 38, 3, 82, 6, 39, 5, 25, 8, 77, 0, 84, 4, 14, 2, 88, 
    2, 87, 8, 81, 3, 99, 4, 26, 7, 51, 5, 46, 0, 59, 6, 39, 1, 44, 
    3, 20, 1, 96, 4, 39, 5,  1, 0, 10, 6, 26, 2, 93, 7, 10, 8, 39, 
    5, 30, 2, 97, 0, 46, 8, 92, 3, 71, 4, 16, 1, 41, 7,  1, 6, 87, 
    7, 86, 0, 91, 2, 24, 3, 97, 4, 31, 5, 30, 8, 47, 1, 51, 6, 86, 
    5, 20, 0, 17, 3, 88, 7, 33, 6, 36, 4, 26, 8, 50, 2, 68, 1, 13, 
    4, 25, 2, 21, 1, 90, 3, 18, 6, 66, 8, 79, 0, 31, 5, 29, 7, 67, 
    5, 15, 3, 48, 4, 91, 8, 67, 7, 29, 1, 83, 0, 57, 2, 31, 6, 10, 
    3, 43, 7, 44, 8, 46, 2, 70, 0, 52, 6, 42, 1, 22, 5, 11, 4, 54
  };
  const int q4304[] = {
    9, 9, // Number of jobs and machines
    3, 37, 4, 35, 2, 49, 5, 30, 7, 72, 8, 37, 6, 84, 1, 21, 0, 42, 
    5, 51, 7, 96, 8, 60, 2, 57, 0, 70, 4, 95, 1, 97, 6, 39, 3, 35, 
    2, 38, 8, 70, 4, 87, 7, 71, 0, 16, 3, 60, 6, 92, 1, 68, 5, 85, 
    5, 75, 2, 34, 4, 50, 1, 96, 7,  5, 6, 78, 8, 10, 3, 21, 0, 61, 
    1, 95, 8,  2, 3, 21, 7, 40, 0, 41, 4, 64, 6, 82, 2, 64, 5, 87, 
    7, 66, 1, 73, 6, 41, 4, 94, 5, 36, 3, 92, 0, 13, 8, 96, 2, 70, 
    7, 85, 8, 96, 4, 22, 3, 47, 2, 77, 5, 87, 1,  6, 0, 38, 6,  6, 
    4, 68, 3, 90, 8, 62, 0, 34, 6, 89, 5, 21, 1, 63, 7, 20, 2, 33, 
    5, 79, 0, 21, 2, 55, 8,  4, 3, 27, 6, 55, 1, 20, 4, 73, 7, 47
  };
  const int q4305[] = {
    9, 9, // Number of jobs and machines
    0, 92, 8, 64, 4, 65, 7, 43, 1, 17, 6,  7, 5, 62, 2, 45, 3, 96, 
    2,  3, 7, 44, 6, 31, 0, 66, 4, 22, 5, 52, 8, 63, 1, 59, 3, 44, 
    1, 88, 0, 23, 4, 72, 8, 96, 5, 49, 7, 94, 2, 94, 3, 75, 6, 18, 
    1, 93, 7, 72, 4, 94, 6, 46, 5, 32, 0, 94, 2, 84, 8, 15, 3, 65, 
    8, 17, 5, 27, 6, 86, 4, 60, 7, 33, 2, 49, 0, 50, 3, 28, 1, 77, 
    1, 24, 0, 28, 7, 20, 3, 98, 5, 79, 2, 54, 4, 13, 6, 73, 8, 37, 
    4,  1, 1, 73, 8, 32, 5, 24, 2, 55, 6, 80, 0, 92, 7, 13, 3, 39, 
    8, 58, 3, 63, 0, 25, 4, 30, 2, 89, 6, 99, 1,  9, 5, 87, 7, 21, 
    5, 90, 6, 71, 2, 64, 7, 50, 4, 89, 0, 69, 8, 32, 3, 55, 1, 78
  };
  const int q4306[] = {
    9, 9, // Number of jobs and machines
    7, 94, 2, 31, 8, 47, 6, 88, 1, 96, 5, 44, 3, 90, 0, 28, 4, 36, 
    3,  3, 6, 27, 2, 46, 4, 44, 0,  3, 8, 93, 7, 94, 1, 82, 5, 85, 
    8, 36, 4, 27, 6, 12, 5, 28, 0, 68, 2, 52, 3, 31, 7, 63, 1, 46, 
    5, 76, 7, 82, 6, 66, 3,  1, 8, 63, 2, 70, 0, 64, 1, 31, 4, 19, 
    3, 95, 4, 45, 0, 68, 6, 50, 8, 18, 5, 52, 2, 92, 7, 59, 1, 46, 
    7, 78, 6, 74, 0, 92, 5, 74, 1, 58, 8, 43, 2, 58, 3, 99, 4, 58, 
    7, 81, 3,  7, 1, 69, 4, 83, 8, 96, 5, 41, 2, 45, 6, 85, 0, 80, 
    2, 29, 1, 23, 7, 62, 5, 93, 8, 92, 3, 64, 6, 92, 0, 72, 4, 50, 
    2, 61, 6, 29, 5, 23, 8,  9, 0, 84, 1, 11, 3, 52, 4, 52, 7, 61
  };
  const int q4307[] = {
    9, 9, // Number of jobs and machines
    1, 78, 8, 73, 0, 73, 6, 88, 7, 97, 4, 36, 3, 19, 2, 33, 5, 52, 
    5,  9, 0, 58, 4, 67, 1, 97, 2,  8, 8, 76, 7, 15, 3, 80, 6, 58, 
    4, 47, 6, 28, 5, 15, 2, 80, 1,  7, 0, 71, 3, 85, 8, 64, 7, 31, 
    8,  4, 6,  3, 5, 29, 7,  3, 0, 35, 4, 60, 1,  8, 2, 77, 3, 22, 
    7,  8, 5, 94, 2, 81, 8, 81, 1, 80, 4, 24, 6, 13, 0, 47, 3,  5, 
    8, 78, 7, 51, 4, 56, 0, 48, 1, 65, 5, 69, 2, 81, 6, 45, 3, 47, 
    0, 87, 6, 56, 2, 55, 8, 33, 7, 33, 4, 13, 3, 23, 5, 31, 1, 79, 
    5,  1, 1,  7, 0, 42, 7, 13, 2, 47, 6, 43, 4, 60, 3, 78, 8, 75, 
    8, 88, 3,  2, 6,  1, 1, 93, 0, 48, 5, 49, 4, 73, 7, 43, 2, 61
  };
  const int q4308[] = {
    9, 9, // Number of jobs and machines
    8, 56, 2, 27, 3, 45, 6, 98, 1, 99, 0, 43, 7, 30, 5, 80, 4,  5, 
    4, 79, 3, 49, 0, 46, 1, 46, 5, 13, 2, 63, 8, 98, 7, 64, 6, 61, 
    7, 19, 0, 97, 3, 79, 2, 14, 6, 12, 5, 88, 4, 66, 8, 27, 1,  6, 
    1, 30, 3, 37, 2, 30, 8, 86, 0, 29, 4, 60, 5, 33, 6, 26, 7, 18, 
    7, 80, 8, 75, 5, 70, 3, 57, 2, 52, 0, 82, 1, 64, 4, 79, 6, 82, 
    6, 73, 5, 68, 3, 16, 0, 76, 2, 68, 4, 91, 8, 87, 1, 16, 7, 12, 
    5,  5, 6, 12, 2,  3, 0, 19, 7, 49, 4, 49, 8, 93, 1, 50, 3, 53, 
    6, 26, 5, 28, 1, 10, 4, 17, 0,  4, 2, 81, 3, 50, 8, 24, 7, 81, 
    4, 29, 2, 83, 1, 70, 7,  2, 6, 99, 0, 86, 5, 72, 3, 57, 8, 45
  };
  const int q4309[] = {
    9, 9, // Number of jobs and machines
    1, 75, 6, 32, 7, 53, 5, 37, 4, 55, 2, 57, 8, 36, 3, 71, 0, 67, 
    6, 91, 8, 50, 3, 19, 1, 58, 2, 92, 0, 37, 5,  6, 4, 58, 7, 81, 
    5, 96, 7, 94, 6, 28, 0, 73, 3,  2, 8, 89, 2, 77, 4, 86, 1, 62, 
    7, 30, 3, 32, 4, 15, 2, 39, 0, 51, 8, 54, 5, 27, 1, 75, 6, 60, 
    6, 96, 0, 80, 1, 32, 3, 39, 4, 78, 8, 36, 7, 80, 5,  4, 2, 45, 
    6, 51, 7, 77, 0, 99, 3, 36, 2, 61, 5, 77, 1, 64, 4, 40, 8, 45, 
    4, 70, 5, 69, 3, 83, 2, 96, 7, 24, 0, 34, 6, 57, 1, 82, 8, 72, 
    8, 77, 7, 13, 1, 29, 4, 48, 5, 87, 0, 26, 3, 87, 6, 59, 2,  3, 
    8, 11, 6, 13, 3, 59, 5, 89, 4, 90, 7, 41, 1, 36, 0,  7, 2, 98
  };
  const int q4310[] = {
    9, 9, // Number of jobs and machines
    1, 15, 6, 14, 8,  2, 5, 20, 4, 30, 2, 22, 7, 61, 3, 44, 0,  6, 
    1, 91, 0, 81, 8, 60, 7, 53, 4, 37, 3, 92, 6,  9, 2, 24, 5, 46, 
    1, 90, 0, 62, 7, 20, 2, 54, 3, 49, 5, 20, 6, 28, 8, 47, 4, 75, 
    2,  3, 6, 21, 5, 43, 0, 95, 7, 35, 8, 86, 1, 50, 4, 98, 3, 89, 
    1,  5, 0, 80, 7, 27, 3, 87, 4, 60, 2, 70, 6,  6, 5, 53, 8, 23, 
    0, 93, 5, 16, 3, 21, 4, 37, 2, 15, 7, 55, 8, 44, 1, 23, 6, 42, 
    7, 22, 2,  3, 1, 39, 0, 46, 8, 39, 3, 95, 5, 34, 6, 77, 4, 84, 
    8,  3, 6, 20, 7, 41, 1, 97, 4, 71, 5, 48, 2, 33, 3, 92, 0, 94, 
    5, 55, 6, 89, 2, 42, 7, 34, 0, 88, 1, 33, 4, 46, 8, 54, 3,  1
  };
  const int q4311[] = {
    9, 9, // Number of jobs and machines
    0, 57, 6, 26, 4, 26, 1, 18, 7, 69, 3, 98, 8,  3, 2, 79, 5,  2, 
    6, 36, 8, 40, 7, 98, 5, 37, 4, 91, 1, 74, 3, 98, 0, 86, 2, 36, 
    0, 93, 7,  6, 8, 35, 6, 66, 2, 61, 1, 77, 5, 19, 4, 45, 3, 52, 
    8, 95, 5, 46, 4, 46, 7,  1, 1, 58, 2, 39, 0, 47, 6, 36, 3, 91, 
    4, 51, 5, 50, 6, 97, 8, 11, 0, 92, 3, 18, 1,  3, 7, 37, 2, 94, 
    4,  5, 1, 88, 3, 42, 2, 31, 6, 44, 8, 64, 0, 65, 7, 60, 5,  2, 
    0, 53, 8, 47, 3, 42, 5, 40, 1,  3, 7, 95, 6, 79, 2, 42, 4, 53, 
    0,  1, 7, 64, 1, 80, 2, 25, 4, 42, 6, 25, 8, 19, 3, 37, 5,  4, 
    8, 62, 5, 23, 0, 91, 2, 97, 6,  7, 4, 79, 1, 27, 7, 48, 3, 43
  };
  const int q4312[] = {
    9, 9, // Number of jobs and machines
    7, 52, 4, 43, 8, 30, 2, 67, 0, 40, 6, 34, 1, 65, 3, 75, 5, 51, 
    7, 84, 6, 78, 0, 14, 2, 30, 3, 39, 5, 30, 8,  1, 4, 82, 1, 71, 
    8, 32, 0, 23, 4,  4, 1, 24, 2, 38, 6, 70, 5, 63, 7, 71, 3, 33, 
    2, 98, 5, 44, 6,  9, 7,  3, 3,  5, 0, 56, 4, 89, 1, 80, 8, 22, 
    5, 74, 4,  9, 2, 61, 6, 16, 3, 51, 0,  4, 7, 77, 8, 47, 1, 40, 
    2, 19, 4, 43, 8, 99, 0, 86, 7, 60, 3, 91, 1, 31, 6, 23, 5, 46, 
    5, 41, 1, 63, 4, 77, 6, 85, 0, 78, 3, 58, 7, 10, 2, 96, 8, 70, 
    1, 98, 5, 92, 0,  6, 6, 28, 2, 89, 8, 60, 4, 42, 7,  8, 3, 41, 
    0, 98, 6,  2, 7, 29, 2, 71, 8, 88, 3, 12, 1, 61, 4, 79, 5, 51
  };
  const int q4313[] = {
    9, 9, // Number of jobs and machines
    5,  9, 3, 93, 6, 32, 0,  3, 2, 41, 7,  7, 4, 99, 1, 85, 8, 33, 
    3, 55, 5, 19, 4, 82, 0, 66, 2, 19, 8, 14, 7, 15, 6, 18, 1, 49, 
    4, 71, 2,  1, 7, 19, 6, 19, 5, 70, 1, 38, 8, 27, 3, 26, 0, 67, 
    2, 15, 5, 10, 1, 83, 0, 50, 7, 59, 4,  4, 3, 68, 6, 17, 8, 51, 
    0, 18, 4, 91, 6, 44, 5, 65, 3, 73, 8,  1, 2, 70, 1, 13, 7, 66, 
    8, 45, 5, 98, 6, 21, 2, 61, 4, 40, 0, 67, 7, 19, 1, 90, 3, 15, 
    0, 94, 5, 90, 1, 44, 7, 93, 6, 87, 8, 15, 2, 37, 4,  7, 3, 59, 
    0, 95, 3, 26, 8,  9, 4, 39, 1, 41, 6, 82, 7, 48, 5, 76, 2, 85, 
    5, 77, 6, 32, 7,  6, 3, 54, 2, 48, 8, 97, 0, 31, 4, 73, 1, 43
  };
  const int q4314[] = {
    9, 9, // Number of jobs and machines
    6, 44, 2, 32, 7, 62, 0, 74, 8, 54, 5, 58, 3, 58, 1, 29, 4, 76, 
    5, 69, 0, 41, 6, 47, 4, 53, 2, 16, 1, 72, 3, 98, 8, 87, 7, 50, 
    2, 69, 0, 12, 7, 93, 1, 57, 6, 76, 3, 65, 5, 28, 8, 63, 4, 84, 
    4, 60, 5, 58, 6, 94, 7, 63, 1, 15, 0, 18, 8, 78, 2, 50, 3, 33, 
    4, 10, 3, 10, 6, 40, 1, 96, 8, 87, 5, 75, 2, 96, 0, 43, 7, 29, 
    8, 49, 5, 72, 2, 98, 3,  8, 6, 10, 1, 88, 0, 68, 4, 56, 7, 15, 
    1, 56, 4,  9, 0, 11, 8, 47, 5, 65, 7, 87, 2, 14, 6, 17, 3, 65, 
    4, 56, 8, 76, 2, 79, 0, 74, 5, 66, 6, 50, 3, 19, 1, 90, 7,  8, 
    7, 38, 4, 88, 2, 78, 0, 24, 1, 30, 6,  7, 8, 98, 5, 46, 3,  7
  };
  const int q4315[] = {
    9, 9, // Number of jobs and machines
    1, 66, 3, 47, 5,  3, 8, 64, 7, 43, 0, 91, 2, 62, 6, 12, 4, 28, 
    0, 12, 2, 46, 7, 77, 3, 56, 8, 57, 4, 17, 6, 14, 5, 53, 1, 75, 
    4, 89, 2, 26, 3,  9, 7, 55, 0, 30, 8, 27, 5, 76, 6, 68, 1, 12, 
    7,  8, 8, 31, 3, 29, 4, 50, 6, 11, 2, 76, 5, 12, 1, 84, 0, 96, 
    0,  4, 1,  8, 7,  8, 8, 97, 2, 18, 6, 36, 3, 93, 4, 11, 5, 98, 
    1, 31, 4, 94, 0, 19, 2, 76, 8, 60, 6, 54, 5,  9, 7, 61, 3,  3, 
    4, 40, 5, 43, 7, 37, 2,  6, 8, 54, 0, 76, 1, 41, 3, 86, 6, 18, 
    6, 70, 0, 70, 7, 72, 4, 26, 3, 37, 8, 13, 1, 58, 5, 75, 2, 32, 
    4, 59, 5, 74, 7, 80, 2,  9, 8, 49, 1, 52, 3, 39, 6, 11, 0, 26
  };
  const int q4316[] = {
    9, 9, // Number of jobs and machines
    3, 43, 4, 94, 6, 29, 8, 55, 2, 61, 0, 41, 1, 64, 5, 67, 7,  1, 
    0, 83, 5, 11, 7, 42, 1, 51, 3, 65, 8, 45, 2, 65, 6, 98, 4, 58, 
    4,  3, 7, 19, 6, 34, 5, 40, 1, 77, 0, 90, 3, 94, 8,  7, 2, 80, 
    2, 24, 4, 31, 0, 16, 5, 18, 3, 54, 8, 88, 1, 76, 7, 68, 6, 55, 
    2, 79, 0, 73, 6, 49, 3, 87, 8, 90, 1, 66, 4, 31, 5, 41, 7, 29, 
    6, 87, 2, 30, 3, 12, 1, 77, 8, 71, 0, 36, 7,  3, 4, 76, 5, 91, 
    0, 31, 5,  7, 2, 14, 8, 88, 6, 23, 3,  9, 1, 13, 4, 69, 7, 19, 
    8, 59, 2, 83, 5, 69, 1, 49, 6, 71, 7, 80, 0, 12, 3, 70, 4, 22, 
    0, 48, 7, 39, 6, 47, 4, 19, 1, 27, 2, 26, 8, 71, 5, 80, 3, 48
  };
  const int q4317[] = {
    9, 9, // Number of jobs and machines
    6, 49, 4, 14, 0, 30, 2, 43, 8, 44, 3, 27, 5, 92, 1, 37, 7, 64, 
    1, 54, 3, 43, 6, 84, 7, 92, 0, 31, 8,  9, 4, 72, 2,  5, 5, 26, 
    2, 47, 4,  5, 8, 96, 3, 72, 0, 62, 7, 17, 6, 84, 5, 94, 1, 33, 
    7, 48, 0, 25, 3, 33, 5, 57, 2, 17, 1,  8, 4, 21, 8, 39, 6, 56, 
    4, 80, 2, 59, 8, 68, 5, 75, 6,  6, 1, 75, 7, 73, 3, 14, 0, 10, 
    2, 83, 5, 76, 1, 87, 4, 97, 7, 22, 3,  9, 0,  8, 6,  8, 8, 18, 
    1, 41, 7, 94, 0, 42, 5, 58, 4, 12, 8, 20, 6,  2, 3, 34, 2, 12, 
    6, 90, 0, 90, 1, 49, 3, 94, 4, 37, 5, 23, 7, 30, 8, 42, 2, 83, 
    1,  4, 6, 72, 7, 56, 4, 87, 5, 23, 8, 51, 0, 12, 2, 67, 3, 84
  };
  const int q4318[] = {
    9, 9, // Number of jobs and machines
    5, 77, 1, 54, 8, 83, 2, 97, 4, 92, 7, 91, 6, 71, 0, 31, 3, 22, 
    5, 22, 0, 23, 8, 19, 3, 25, 6, 80, 7, 49, 1, 24, 2, 67, 4, 68, 
    3, 42, 5, 57, 8, 85, 1, 86, 6, 31, 0, 51, 4, 80, 2, 45, 7, 60, 
    8, 37, 0, 52, 6, 40, 7, 98, 1, 13, 5, 23, 2,  2, 3, 39, 4, 30, 
    2, 72, 6, 34, 7, 68, 0, 58, 5, 89, 4, 27, 1,  5, 8, 96, 3, 11, 
    6, 97, 4, 12, 1, 12, 8,  3, 0, 54, 5, 40, 2, 30, 7, 18, 3, 70, 
    7, 94, 8, 74, 3, 15, 2, 85, 6, 67, 1, 91, 5, 25, 4, 63, 0,  2, 
    7, 98, 0, 14, 1, 73, 8, 56, 2, 99, 5, 17, 3, 43, 4, 77, 6,  8, 
    3,  6, 7, 23, 6, 29, 0, 82, 4, 44, 2, 10, 8, 24, 5, 80, 1, 19
  };
  const int q4319[] = {
    9, 9, // Number of jobs and machines
    0, 41, 3, 30, 7, 15, 5, 11, 2, 20, 1, 98, 4, 66, 8, 15, 6, 47, 
    4, 68, 1, 67, 3, 82, 5, 52, 2, 77, 6, 44, 8, 52, 7, 54, 0, 85, 
    0, 56, 7, 61, 3, 87, 5, 69, 2, 42, 8, 94, 4, 39, 1, 43, 6, 40, 
    3,  2, 1, 70, 6, 73, 0,  6, 5,  7, 7, 69, 4, 28, 8, 57, 2,  7, 
    1, 93, 6, 79, 5, 63, 2, 67, 0, 30, 7,  1, 3,  3, 8, 77, 4, 76, 
    1, 43, 0, 69, 7, 15, 2, 82, 5, 10, 6,  1, 4, 41, 8,  1, 3, 13, 
    6, 19, 8, 44, 3, 80, 4, 66, 2,  3, 5, 70, 7,  4, 0, 57, 1,  9, 
    0, 68, 8, 14, 1, 73, 7, 12, 5, 33, 2, 10, 4, 82, 6, 81, 3, 46, 
    4, 49, 8, 53, 7, 91, 1, 22, 5,  5, 0,  7, 2, 32, 3, 16, 6, 13
  };
  const int q4320[] = {
    9, 9, // Number of jobs and machines
    3, 93, 0, 75, 8, 66, 1, 83, 6, 79, 2, 44, 7, 54, 5, 89, 4, 83, 
    7, 91, 1, 65, 8, 72, 2, 52, 3, 94, 0, 62, 5, 37, 4, 83, 6, 48, 
    6, 47, 5, 88, 2, 47, 1, 38, 8, 10, 3, 88, 4, 38, 0, 62, 7, 84, 
    8, 56, 2, 89, 4, 61, 6, 31, 0, 33, 1, 41, 7, 50, 3, 97, 5, 51, 
    6, 46, 5, 74, 3, 33, 2, 72, 4, 66, 1, 14, 7, 82, 8, 41, 0, 76, 
    6, 10, 3, 60, 0, 81, 8, 94, 5, 57, 1, 42, 4,  8, 2, 25, 7, 70, 
    3, 67, 7, 37, 6, 27, 8, 81, 2, 36, 0, 54, 1, 82, 4, 83, 5, 24, 
    1, 16, 7, 47, 0, 44, 8, 64, 6, 33, 2, 96, 3, 74, 4, 88, 5, 89, 
    8, 36, 3, 65, 5, 58, 6, 33, 4, 96, 0, 10, 2,  9, 1, 57, 7, 89
  };
  const int q4321[] = {
    9, 9, // Number of jobs and machines
    5, 31, 0, 78, 1, 83, 7, 89, 2, 93, 8, 80, 4, 24, 6, 70, 3, 70, 
    5, 49, 6, 13, 1, 56, 8,  6, 4, 13, 0, 37, 7, 20, 2, 92, 3, 97, 
    1, 59, 4, 76, 6, 35, 7, 20, 5, 44, 3, 74, 2, 86, 0, 97, 8,  8, 
    4, 55, 5, 10, 6, 81, 0, 96, 7, 58, 3, 42, 2, 11, 1, 55, 8, 25, 
    6,  6, 5, 27, 3, 50, 7, 31, 8, 15, 1, 29, 4, 35, 2, 89, 0, 83, 
    1, 93, 8, 88, 7, 56, 0, 93, 3, 81, 2, 54, 6, 80, 5, 58, 4, 38, 
    2, 64, 8, 14, 5, 58, 0, 79, 6,  3, 4, 71, 3, 46, 7, 68, 1, 40, 
    6, 34, 7, 75, 3, 13, 4, 39, 1, 11, 8, 30, 0, 15, 2, 12, 5, 78, 
    7, 74, 6, 38, 3, 29, 5, 59, 8, 83, 1, 74, 4, 81, 0, 11, 2, 61
  };
  const int q4322[] = {
    9, 9, // Number of jobs and machines
    0, 34, 3,  7, 2, 34, 4,  8, 6, 60, 5, 12, 1, 52, 8, 73, 7, 63, 
    6, 30, 4, 55, 8, 16, 5,  7, 3, 20, 0, 74, 7, 93, 2, 14, 1, 71, 
    0,  7, 8, 27, 3, 23, 2, 63, 5, 96, 4, 35, 1, 49, 7, 60, 6, 76, 
    6, 52, 7, 82, 0, 14, 8,  8, 1, 28, 3, 49, 2, 71, 4, 83, 5, 82, 
    1, 51, 6, 57, 0, 23, 7, 12, 4,  8, 2, 20, 8, 41, 5, 92, 3, 43, 
    6, 17, 0,  1, 5, 22, 7, 86, 2, 89, 3, 71, 4, 24, 1, 24, 8, 12, 
    4, 64, 1, 75, 2, 86, 6, 64, 8, 54, 5, 57, 0, 65, 7, 53, 3, 82, 
    5, 14, 2, 25, 8, 80, 1, 17, 0, 91, 4, 28, 6, 28, 3, 77, 7, 54, 
    8, 93, 4, 68, 0, 62, 6, 28, 7, 57, 2, 61, 1, 79, 5, 63, 3, 19
  };
  const int q4323[] = {
    9, 9, // Number of jobs and machines
    6, 24, 1, 52, 5, 96, 0, 56, 4, 77, 2, 20, 7, 42, 3, 36, 8, 22, 
    6, 97, 3, 57, 8, 43, 5,  9, 2, 54, 0, 65, 1, 70, 7, 66, 4, 83, 
    1, 30, 8, 35, 0, 94, 4, 39, 2, 17, 5, 49, 3, 31, 7, 97, 6, 18, 
    1,  2, 5, 91, 6, 20, 3, 18, 7, 88, 2, 39, 4, 44, 0, 97, 8, 28, 
    5,  3, 6, 33, 8, 90, 0, 66, 3, 25, 1, 61, 2, 12, 4,  8, 7, 94, 
    7, 37, 1, 23, 0, 81, 5, 86, 2, 48, 6, 74, 3, 88, 4, 28, 8, 73, 
    2, 79, 8, 98, 4, 41, 1, 71, 0,  2, 6, 81, 7, 87, 5, 31, 3, 16, 
    2, 19, 5, 94, 3, 28, 6, 78, 0, 56, 1, 74, 8, 86, 7, 57, 4, 86, 
    8, 23, 4,  5, 5, 46, 0, 36, 2, 97, 6, 77, 7, 20, 1, 92, 3, 61
  };
  const int q4324[] = {
    9, 9, // Number of jobs and machines
    2, 91, 0, 50, 3, 66, 8, 81, 6, 48, 7, 47, 4, 49, 1, 68, 5, 46, 
    4,  1, 7, 97, 2, 91, 3, 62, 6,  7, 8,  1, 5, 79, 0, 48, 1, 99, 
    0, 31, 6, 69, 2, 77, 3, 90, 5, 82, 4, 21, 7, 38, 1, 36, 8, 63, 
    6, 77, 7, 92, 4, 20, 8, 23, 3, 51, 5, 89, 0, 64, 2, 40, 1, 89, 
    3, 47, 7, 95, 8, 42, 5, 87, 0, 67, 4, 25, 1, 76, 2, 87, 6, 81, 
    1, 88, 0, 36, 7, 45, 4, 44, 3, 35, 5, 99, 8, 41, 6, 75, 2, 66, 
    4, 62, 0, 75, 1, 15, 3, 90, 8, 30, 6, 83, 2, 85, 5, 26, 7, 23, 
    2, 25, 1,  8, 8, 31, 3, 44, 6, 38, 4, 84, 0,  6, 7, 35, 5, 60, 
    0, 26, 3, 52, 4, 74, 1,  2, 2, 48, 5, 77, 7, 21, 8, 59, 6,  9
  };
  const int q4325[] = {
    9, 9, // Number of jobs and machines
    4, 32, 8, 41, 2,  8, 1,  3, 6, 30, 3, 20, 0, 82, 5, 92, 7, 31, 
    5,  7, 0, 85, 4, 76, 6, 58, 8,  6, 3, 66, 7, 16, 2, 57, 1, 80, 
    3, 42, 4, 30, 2, 40, 8, 27, 5, 11, 0, 76, 6, 82, 7, 89, 1, 82, 
    6, 66, 7, 26, 8, 35, 0,  8, 2, 99, 3, 13, 1, 18, 4, 16, 5, 56, 
    0, 23, 3, 11, 4,  1, 8, 40, 2, 28, 7, 83, 6, 79, 1, 33, 5, 48, 
    6, 20, 0, 21, 8, 94, 4, 94, 5, 32, 1, 50, 2, 73, 7, 51, 3, 25, 
    3, 83, 8, 28, 2, 89, 1, 99, 5, 95, 0,  6, 7,  2, 6, 69, 4,  9, 
    3, 32, 4, 97, 0,  7, 2, 63, 6, 51, 8, 37, 5, 32, 1, 71, 7, 30, 
    2,  5, 6, 53, 7, 55, 0, 69, 3, 33, 1, 63, 5, 51, 4, 51, 8, 14
  };
  const int q4326[] = {
    9, 9, // Number of jobs and machines
    3, 94, 6,  9, 4, 52, 5, 40, 2, 11, 8, 46, 0, 63, 1, 56, 7, 48, 
    6,  6, 0,  1, 5, 54, 4, 59, 1, 17, 8, 50, 3, 96, 2, 32, 7, 94, 
    0, 27, 2, 62, 6,  8, 5, 98, 4, 80, 1, 44, 3, 56, 7, 17, 8, 67, 
    7, 19, 1, 53, 6, 75, 0, 67, 2,  9, 5,  2, 4, 49, 3, 11, 8, 93, 
    3, 26, 6, 67, 1, 28, 5, 30, 4, 91, 8, 31, 0, 37, 2,  9, 7,  8, 
    7, 30, 8, 98, 1, 68, 5, 49, 3, 17, 0,  4, 6, 37, 2, 34, 4, 32, 
    7, 50, 1, 53, 6, 36, 3, 68, 5, 68, 4, 24, 2, 95, 0, 76, 8, 50, 
    8,  7, 2, 59, 7,  8, 4, 88, 6, 29, 5, 83, 0, 72, 3, 71, 1, 39, 
    1, 91, 6, 83, 4, 21, 2, 68, 8, 27, 3,  8, 5, 27, 0, 95, 7, 87
  };
  const int q4327[] = {
    9, 9, // Number of jobs and machines
    1, 20, 4, 89, 6, 43, 3, 71, 0, 60, 8, 11, 7, 53, 2, 21, 5, 87, 
    1, 64, 0, 67, 8, 83, 7,  1, 5,  3, 2, 58, 3, 53, 6, 60, 4, 55, 
    3,  4, 1,  4, 7, 97, 4, 12, 5, 22, 2,  6, 8,  4, 6, 35, 0, 59, 
    2, 57, 1, 66, 4, 11, 6, 95, 5, 98, 3, 28, 8, 71, 0, 22, 7, 78, 
    3, 41, 4, 21, 1, 91, 2, 26, 5, 31, 0, 90, 8, 23, 6, 73, 7, 92, 
    2, 20, 5, 79, 7, 84, 8, 92, 1, 86, 6, 77, 0, 58, 3, 83, 4, 84, 
    1, 70, 7, 39, 0, 44, 3, 93, 4, 77, 5, 21, 8, 16, 2, 93, 6, 10, 
    7, 73, 2, 63, 4, 78, 6, 41, 8,  8, 3, 58, 1, 30, 5, 43, 0, 50, 
    5, 37, 4, 65, 7, 54, 0, 39, 8, 81, 3, 81, 6, 57, 1, 95, 2, 88
  };
  const int q4328[] = {
    9, 9, // Number of jobs and machines
    8, 30, 0, 14, 7, 93, 1,  2, 5, 38, 6, 37, 2,  2, 3, 77, 4, 48, 
    3,  9, 1, 20, 7, 51, 8, 51, 5, 13, 2, 44, 6, 91, 0, 20, 4, 28, 
    7, 33, 0, 66, 4, 60, 5, 10, 2, 43, 3, 70, 8, 42, 6, 32, 1, 10, 
    8, 10, 1, 97, 3, 35, 5, 24, 0, 86, 6, 34, 7, 52, 4,  9, 2, 61, 
    4, 21, 3, 25, 1, 93, 5, 86, 2, 73, 7, 12, 6, 27, 0, 47, 8, 73, 
    3, 89, 8,  6, 6, 94, 7, 24, 5, 41, 2, 76, 1, 21, 4, 59, 0, 61, 
    4,  2, 5, 97, 2,  9, 3, 78, 6, 52, 0, 70, 7, 61, 1, 47, 8, 36, 
    8, 39, 5, 69, 4, 21, 3, 36, 7,  8, 1, 41, 2, 90, 0, 26, 6, 60, 
    5, 85, 0, 97, 4, 21, 2, 16, 6, 20, 1, 92, 8, 60, 3, 24, 7, 43
  };
  const int q4329[] = {
    9, 9, // Number of jobs and machines
    6, 70, 5, 24, 7, 82, 0, 79, 2, 50, 1,  1, 8,  3, 3, 65, 4, 33, 
    1, 53, 7, 73, 3, 32, 5, 51, 4, 99, 8, 34, 0, 16, 6, 42, 2, 11, 
    8, 16, 3, 61, 1,  7, 0, 51, 7, 71, 2, 35, 4, 23, 6, 74, 5, 45, 
    7, 87, 8, 48, 0, 57, 2, 93, 6, 19, 1, 10, 3, 63, 5, 58, 4, 95, 
    3, 48, 4, 57, 5, 66, 1, 40, 8, 58, 7, 87, 0, 51, 2, 46, 6, 13, 
    4,  5, 1, 96, 7, 10, 0,  5, 2,  4, 8, 78, 5,  9, 3, 20, 6, 35, 
    7, 43, 1, 50, 6, 14, 8, 39, 0, 84, 3, 22, 4, 10, 5, 10, 2, 83, 
    6, 78, 1,  6, 4, 30, 2, 25, 0, 54, 5,  2, 7, 41, 3, 25, 8, 12, 
    5, 91, 4, 88, 0, 83, 7, 98, 2,  9, 6, 62, 1, 67, 3, 80, 8, 90
  };
  const int q4330[] = {
    9, 9, // Number of jobs and machines
    6, 97, 0, 63, 5, 62, 8, 21, 4, 48, 3, 44, 1, 60, 7, 61, 2, 46, 
    4, 76, 5, 91, 1, 81, 2, 99, 3,  6, 0, 20, 6, 77, 7, 48, 8, 56, 
    5, 91, 1, 33, 7, 40, 4, 58, 2, 98, 0, 84, 3, 58, 8, 85, 6, 16, 
    0, 85, 2,  1, 8, 46, 5, 22, 1, 45, 4, 83, 3, 37, 7,  5, 6, 57, 
    0,  7, 2, 36, 4, 72, 8, 10, 5, 44, 1, 36, 6, 15, 3, 82, 7, 28, 
    7, 47, 5, 86, 0,  4, 8, 43, 3, 80, 6, 17, 2, 62, 4, 88, 1, 67, 
    6, 76, 7,  1, 5, 38, 8,  9, 2, 81, 1, 45, 4, 67, 0, 69, 3, 23, 
    0, 80, 1,  3, 2, 20, 7,  7, 6, 85, 8,  3, 5, 77, 3, 36, 4, 72, 
    7, 42, 2, 40, 1, 31, 6, 16, 3, 36, 0, 26, 4, 84, 8, 64, 5, 43
  };
  const int q4331[] = {
    9, 9, // Number of jobs and machines
    0, 82, 7, 44, 5, 10, 4, 36, 8, 14, 6, 38, 2, 40, 1, 46, 3,  6, 
    8, 79, 7, 34, 0, 42, 4, 55, 2,  9, 6, 86, 3, 33, 5, 43, 1, 56, 
    4, 65, 6, 58, 5, 73, 8, 33, 1, 85, 0, 70, 2, 40, 3, 99, 7,  9, 
    8, 87, 3,  1, 0, 40, 7, 22, 5, 63, 1, 92, 6, 74, 2, 69, 4, 82, 
    7, 13, 6, 79, 1, 15, 0, 29, 8, 88, 3, 71, 5, 15, 2, 59, 4, 90, 
    7,  2, 4, 58, 0, 97, 8, 79, 2, 99, 5, 35, 1, 53, 6, 98, 3, 84, 
    0,  7, 3, 55, 6, 32, 4, 34, 8, 21, 2, 54, 7, 37, 5, 50, 1, 92, 
    6, 21, 1, 31, 2, 29, 7, 71, 3, 49, 8, 84, 4, 90, 5, 22, 0, 13, 
    8, 12, 7,  7, 5, 38, 4, 10, 1, 90, 2, 42, 0, 88, 3, 16, 6, 96
  };
  const int q4332[] = {
    9, 9, // Number of jobs and machines
    0, 49, 6,  3, 2, 56, 1, 96, 5, 85, 7, 44, 8, 51, 3,  5, 4, 99, 
    5, 57, 7, 24, 3, 24, 4, 32, 0, 96, 1, 85, 6, 50, 2, 90, 8, 35, 
    8, 60, 2, 89, 7, 31, 6, 17, 3, 25, 0, 81, 5,  9, 1, 64, 4, 52, 
    6, 13, 1, 74, 3, 45, 2, 67, 4, 26, 7, 91, 8, 95, 0, 65, 5, 25, 
    5, 12, 1, 65, 3, 43, 2,  9, 0, 97, 4, 76, 6, 75, 7, 33, 8, 57, 
    6, 82, 7, 62, 2,  4, 8, 14, 3, 29, 0, 25, 4, 37, 1, 63, 5, 60, 
    1, 17, 8, 27, 7, 19, 3, 49, 4, 89, 5, 92, 0, 14, 2, 83, 6, 72, 
    1, 48, 3, 89, 0,  3, 4, 57, 5, 63, 7, 17, 8, 81, 2, 79, 6, 82, 
    2, 81, 7, 71, 6, 81, 0, 45, 4, 52, 3, 89, 1, 76, 8, 51, 5, 40
  };
  const int q4333[] = {
    9, 9, // Number of jobs and machines
    6, 91, 8, 88, 7, 23, 2, 10, 4, 10, 3, 54, 1, 76, 5, 35, 0, 46, 
    1, 99, 0, 37, 2, 70, 8, 41, 6, 42, 4, 32, 5,  7, 7, 83, 3, 74, 
    7, 51, 4, 94, 0, 94, 5, 95, 1, 87, 2, 38, 3,  7, 8, 39, 6, 55, 
    0, 26, 6, 44, 4, 18, 7, 23, 2, 13, 5, 84, 1, 77, 3, 45, 8, 73, 
    7, 44, 1, 43, 4, 94, 6, 48, 5, 48, 0, 83, 8, 90, 3, 14, 2, 43, 
    1, 74, 2, 95, 3,  2, 4, 47, 5, 93, 0, 93, 7, 92, 8,  1, 6, 86, 
    1, 30, 2,  1, 6, 85, 8, 14, 0, 60, 3,  2, 4, 20, 7, 33, 5, 22, 
    4, 33, 6, 61, 0, 23, 3, 45, 8, 21, 5, 34, 1, 59, 7, 95, 2, 67, 
    2, 39, 7, 13, 8, 34, 4, 14, 0, 28, 3, 64, 1, 36, 6, 89, 5, 52
  };
  const int q4334[] = {
    9, 9, // Number of jobs and machines
    7, 91, 0, 77, 4, 77, 6, 71, 1, 81, 5, 43, 3, 56, 2, 32, 8, 62, 
    5, 16, 0, 45, 6, 34, 3, 93, 8, 58, 1, 68, 4, 35, 2, 73, 7, 52, 
    7, 50, 8, 51, 1, 39, 3, 69, 5, 60, 6, 20, 2, 99, 0, 42, 4, 80, 
    4, 35, 7, 68, 3,  5, 2, 55, 8, 32, 0, 98, 5, 48, 1, 98, 6, 35, 
    4, 69, 0, 49, 3, 28, 7, 94, 6,  3, 2, 10, 8, 44, 5, 26, 1, 92, 
    2, 96, 4, 43, 7, 24, 1, 24, 0, 86, 5, 37, 3, 99, 6, 24, 8, 41, 
    6, 97, 1, 73, 2, 74, 7, 54, 3, 22, 5, 48, 0, 42, 8, 23, 4, 16, 
    1, 65, 4, 43, 7, 18, 6, 94, 2,  2, 8, 95, 0, 69, 5, 93, 3, 41, 
    7, 53, 8, 75, 2, 95, 3, 63, 5, 76, 4, 97, 1, 56, 6, 72, 0, 75
  };
  const int q4335[] = {
    9, 9, // Number of jobs and machines
    4,  5, 3, 44, 0, 67, 1, 61, 5, 73, 6, 70, 2, 16, 7, 84, 8, 19, 
    5,  4, 1, 74, 8, 60, 6, 41, 3, 39, 0, 87, 2, 13, 7, 26, 4, 65, 
    2, 97, 6, 41, 7, 86, 0, 44, 3, 85, 5, 96, 4, 55, 1, 71, 8, 30, 
    3, 62, 0, 78, 4, 80, 1,  4, 8, 86, 6, 54, 7, 81, 2,  1, 5, 12, 
    5, 40, 2, 74, 1, 46, 8, 72, 0, 60, 4,  6, 7,  7, 6, 67, 3, 93, 
    8, 35, 1, 75, 3, 60, 4, 76, 5, 74, 2, 74, 7, 14, 0, 14, 6, 84, 
    5, 26, 6, 91, 4, 14, 8,  5, 0, 39, 2,  6, 7, 39, 3, 41, 1, 58, 
    3, 93, 4, 58, 6, 31, 1, 83, 0, 13, 2, 41, 8, 89, 7, 28, 5, 28, 
    1,  9, 4, 50, 5, 76, 3, 20, 2, 38, 8, 99, 6, 55, 7, 29, 0, 73
  };
  const int q4336[] = {
    9, 9, // Number of jobs and machines
    7, 99, 0, 22, 1, 79, 2,  5, 6, 67, 8, 84, 4, 90, 5, 29, 3, 89, 
    1, 42, 2, 74, 3, 35, 0, 68, 7, 27, 8, 43, 6, 43, 5, 99, 4,  9, 
    4, 95, 5,  4, 1, 74, 2, 72, 6, 80, 3, 12, 7, 30, 8, 15, 0, 22, 
    2, 62, 3, 65, 5, 22, 0, 58, 7, 45, 6, 61, 1, 57, 8, 30, 4, 83, 
    7, 85, 1, 42, 8, 77, 0, 12, 3, 58, 6, 16, 2, 37, 4,  9, 5, 64, 
    2, 42, 7, 61, 1, 89, 0, 80, 6,  2, 3, 24, 8, 22, 4, 29, 5, 51, 
    5, 12, 1, 57, 7, 63, 2,  2, 6, 20, 4, 86, 0, 13, 3, 10, 8, 93, 
    0, 26, 8, 94, 4, 66, 1,  2, 3, 49, 2, 86, 6,  6, 5, 42, 7, 94, 
    6, 96, 5, 18, 1, 38, 0, 10, 8, 35, 2, 60, 4, 53, 3, 15, 7, 57
  };
  const int q4337[] = {
    9, 9, // Number of jobs and machines
    1, 52, 4, 37, 0,  4, 7, 99, 3,  7, 2, 18, 8, 78, 6, 24, 5, 25, 
    3, 25, 7, 62, 1, 75, 2, 71, 5, 46, 6, 37, 4, 25, 0, 69, 8, 32, 
    0, 32, 7, 99, 1, 50, 3, 67, 8, 34, 6, 63, 2,  5, 4, 29, 5, 76, 
    1, 81, 4, 66, 3, 89, 7,  1, 6, 43, 0, 51, 5, 98, 8, 82, 2, 20, 
    6,  4, 3, 95, 7, 80, 4, 31, 0, 34, 2, 34, 1, 76, 5, 23, 8, 45, 
    6, 91, 7, 42, 1, 93, 0,  3, 2, 29, 3, 86, 4, 79, 5, 77, 8, 40, 
    1, 80, 8, 55, 7, 64, 4, 87, 2, 75, 6, 12, 0, 62, 5, 81, 3, 94, 
    7, 23, 2, 42, 5, 49, 4, 34, 8, 65, 0, 22, 6, 35, 1,  2, 3, 67, 
    5, 41, 2, 29, 7, 94, 8, 97, 0, 15, 3, 43, 6, 66, 1, 62, 4,  4
  };
  const int q4338[] = {
    9, 9, // Number of jobs and machines
    3, 60, 6, 28, 7, 46, 8, 41, 5, 47, 0,  1, 2, 81, 1, 23, 4, 50, 
    7, 45, 0, 85, 6, 46, 3, 66, 2, 60, 1, 59, 5,  1, 8, 18, 4, 59, 
    3, 38, 1, 36, 4, 38, 2,  5, 8, 88, 6, 88, 7, 27, 0, 49, 5, 10, 
    6, 79, 1, 81, 3, 91, 2, 57, 5, 86, 0, 34, 4, 82, 7, 89, 8, 41, 
    2,  5, 1, 99, 6, 26, 0, 42, 8, 36, 4, 45, 7,  6, 5, 36, 3, 66, 
    0, 19, 3, 71, 4, 35, 5, 18, 2, 41, 8,  2, 1, 72, 6, 27, 7, 97, 
    1, 51, 8, 42, 2, 94, 3, 15, 6, 28, 5,  7, 0, 41, 7, 33, 4, 72, 
    4, 30, 7, 22, 1, 70, 0, 74, 8, 94, 3, 10, 6, 34, 2, 37, 5, 38, 
    8, 71, 4, 86, 0,  2, 6, 99, 3, 51, 7,  9, 2, 37, 1, 74, 5, 16
  };
  const int q4339[] = {
    9, 9, // Number of jobs and machines
    3, 33, 5, 44, 2, 98, 8, 14, 6, 75, 4, 87, 0, 75, 7, 84, 1, 85, 
    5, 38, 3, 17, 8, 12, 7,  2, 2, 87, 0, 64, 6, 20, 1, 54, 4, 84, 
    0, 88, 1, 45, 5,  8, 4, 71, 8, 92, 3, 64, 2, 26, 7,  6, 6, 76, 
    5, 36, 0, 75, 7, 23, 2, 94, 6, 27, 3, 32, 4,  1, 8, 92, 1, 83, 
    5, 20, 7, 47, 3, 20, 8, 61, 6, 13, 2, 59, 1, 49, 4, 11, 0, 23, 
    5, 10, 8, 38, 3, 25, 7, 42, 1, 87, 6, 78, 4, 49, 2, 45, 0,  6, 
    7, 23, 2, 26, 8,  8, 1, 57, 0, 19, 4, 61, 3, 10, 5, 74, 6, 25, 
    5, 57, 0, 96, 8, 31, 6, 13, 3, 87, 1, 16, 7, 89, 4, 69, 2, 23, 
    8, 27, 4, 84, 5, 38, 6, 16, 3, 60, 1, 81, 2, 82, 0, 58, 7, 42
  };
  const int q4340[] = {
    9, 9, // Number of jobs and machines
    8, 27, 4, 11, 2, 45, 5, 75, 7, 16, 3, 63, 1, 11, 0, 33, 6, 85, 
    8, 30, 2, 95, 3, 12, 7, 71, 1, 80, 4, 44, 6, 43, 5,  3, 0,  8, 
    7, 26, 5, 26, 2, 39, 6, 42, 4, 28, 1, 44, 8, 49, 0, 42, 3, 87, 
    6, 96, 3,  7, 2,  1, 7, 77, 4, 42, 5,  5, 8, 83, 1, 77, 0, 83, 
    6, 83, 2,  6, 0, 48, 4, 23, 8, 47, 5, 55, 3, 11, 7, 99, 1, 32, 
    4, 56, 6, 62, 3, 27, 0, 15, 2, 34, 5,  8, 1, 44, 8, 44, 7, 18, 
    4, 65, 7, 43, 5, 13, 3, 46, 6, 76, 0, 19, 1, 82, 8,  4, 2, 19, 
    5, 54, 1, 24, 2, 49, 0, 70, 3, 75, 8, 12, 6,  5, 4, 57, 7, 29, 
    7, 20, 3, 83, 1, 45, 8, 14, 6, 82, 4, 98, 0, 33, 5, 24, 2, 28
  };
  const int q4341[] = {
    9, 9, // Number of jobs and machines
    7, 76, 3, 79, 2, 85, 0, 44, 6, 35, 5, 28, 4, 95, 1, 81, 8,  7, 
    7, 38, 2, 53, 6, 29, 3, 28, 8, 89, 4, 12, 1, 78, 0, 63, 5, 31, 
    0, 72, 5, 70, 8, 24, 1, 84, 6, 96, 4, 25, 3, 19, 2, 98, 7,  3, 
    2, 98, 0, 41, 7, 48, 8, 62, 3, 88, 5, 86, 4, 55, 6, 24, 1, 50, 
    1, 32, 4, 24, 0, 50, 2, 68, 3, 39, 7, 43, 8, 32, 5, 47, 6, 63, 
    6, 49, 8, 24, 4, 70, 0, 42, 7, 19, 2, 50, 1, 96, 3, 75, 5, 10, 
    5, 98, 4, 67, 7, 36, 1, 81, 6, 93, 2, 70, 3, 25, 8,  9, 0, 54, 
    7, 57, 6,  6, 0, 30, 3, 88, 8, 40, 1, 66, 5, 60, 2, 57, 4, 69, 
    5, 80, 6, 85, 0, 66, 1, 86, 2, 65, 8,  5, 3, 38, 4, 29, 7,  2
  };
  const int q4342[] = {
    9, 9, // Number of jobs and machines
    0, 59, 3, 50, 6, 38, 5,  2, 2, 65, 4, 25, 7, 98, 8, 72, 1,  2, 
    3, 82, 0, 35, 5, 41, 6, 63, 8, 24, 1, 37, 4, 98, 7, 60, 2, 69, 
    5, 14, 7, 64, 8, 64, 0, 65, 6, 24, 2, 62, 1, 61, 4, 41, 3, 83, 
    0,  6, 2, 11, 6,  5, 8, 40, 4, 24, 5, 65, 7, 67, 3, 79, 1, 16, 
    1, 33, 8, 25, 6,  9, 5, 86, 3, 23, 2, 11, 4, 67, 0, 75, 7, 20, 
    2, 48, 7, 71, 1, 46, 3, 68, 8, 89, 6, 75, 5, 19, 0, 13, 4, 37, 
    8, 29, 5, 31, 7, 52, 0, 88, 1, 92, 4, 48, 2,  9, 6,  2, 3, 27, 
    6, 22, 7, 44, 1, 67, 5, 25, 8, 68, 0, 54, 3, 67, 2, 21, 4, 54, 
    5,  5, 3, 66, 8, 14, 0, 67, 2, 26, 6, 91, 1, 17, 4, 50, 7, 61
  };
  const int q4343[] = {
    9, 9, // Number of jobs and machines
    5, 94, 7, 54, 3, 30, 4,  1, 1, 16, 8, 51, 2, 99, 6, 36, 0, 92, 
    2, 45, 1, 89, 5, 72, 6, 78, 3, 47, 0, 91, 7, 28, 8, 65, 4, 29, 
    3, 65, 5, 76, 1, 97, 6, 47, 0, 50, 2, 94, 8, 11, 4,  5, 7, 27, 
    1, 75, 4,  9, 6, 12, 8, 84, 7, 54, 3, 69, 5, 91, 0, 24, 2, 33, 
    7, 35, 8, 31, 4,  5, 6, 13, 2, 12, 1, 21, 5, 70, 3, 13, 0, 52, 
    5, 49, 7, 52, 3, 69, 8, 93, 2, 28, 4, 66, 1, 70, 6, 16, 0, 41, 
    0, 58, 2, 31, 5, 99, 7, 49, 8, 52, 1, 45, 3, 42, 6, 42, 4, 43, 
    3, 60, 1,  7, 5, 66, 7, 47, 6, 66, 0, 69, 8, 72, 2, 16, 4, 49, 
    1, 90, 3,  8, 5, 76, 8, 11, 2, 83, 0, 65, 4, 90, 7, 96, 6, 30
  };
  const int q4344[] = {
    9, 9, // Number of jobs and machines
    0, 17, 5,  2, 4, 87, 3, 26, 2, 31, 7, 22, 6, 68, 8, 29, 1, 43, 
    5,  2, 0, 80, 2, 59, 3, 28, 4, 95, 1, 15, 6, 63, 7, 57, 8, 65, 
    8, 27, 0, 46, 1, 61, 5, 77, 7, 45, 6,  1, 2, 77, 4, 26, 3, 11, 
    3,  7, 8, 44, 2, 43, 6, 39, 7, 69, 1, 48, 4, 54, 5, 54, 0, 41, 
    3, 43, 5, 33, 7, 23, 0, 66, 6, 30, 2, 15, 4,  9, 1, 47, 8, 30, 
    7,  5, 6, 19, 1, 15, 8, 67, 2, 56, 3, 80, 0, 22, 4,  3, 5, 26, 
    8, 61, 2, 29, 3, 21, 0, 52, 5,  4, 1, 16, 6, 72, 4, 78, 7, 23, 
    3, 57, 1, 94, 0, 38, 8, 45, 2, 76, 4, 49, 7, 83, 6, 54, 5, 85, 
    2, 21, 4, 67, 6, 44, 0, 67, 1, 77, 7,  1, 3, 55, 5, 77, 8, 88
  };
  const int q4345[] = {
    9, 9, // Number of jobs and machines
    3, 61, 8, 36, 2, 85, 0, 28, 5, 96, 1, 71, 7, 33, 4, 82, 6, 16, 
    8, 37, 4, 70, 6, 45, 0, 74, 3, 21, 7, 50, 2, 43, 1, 69, 5, 25, 
    5,  1, 0, 70, 8, 73, 3, 92, 1, 77, 2, 38, 4, 37, 7, 60, 6, 14, 
    1, 22, 4,  3, 3, 48, 2, 86, 0, 85, 8, 85, 5, 94, 6, 99, 7, 94, 
    7, 15, 4, 73, 8, 75, 1, 41, 5, 19, 6, 68, 3, 85, 0, 52, 2, 24, 
    4,  8, 6, 54, 5, 83, 3, 87, 7, 52, 8, 17, 2, 49, 0, 50, 1, 95, 
    7, 45, 6, 15, 1, 80, 5, 43, 0,  3, 3, 52, 8, 69, 2, 46, 4, 69, 
    6, 91, 8, 27, 0, 19, 5,  8, 3, 43, 4, 83, 7,  7, 2, 79, 1, 59, 
    0, 22, 4, 99, 1, 65, 6, 72, 8, 77, 3, 73, 5,  9, 7, 49, 2, 84
  };
  const int q4346[] = {
    9, 9, // Number of jobs and machines
    2, 86, 5, 50, 7, 67, 1, 12, 6, 17, 4, 65, 8, 65, 3, 46, 0, 67, 
    7, 65, 0, 88, 4, 10, 3, 75, 6, 80, 5, 48, 1, 97, 8, 48, 2, 64, 
    8, 65, 4, 19, 3, 69, 7, 76, 6, 28, 5, 53, 2, 31, 1, 44, 0, 96, 
    5, 66, 3, 31, 4, 99, 0, 58, 7, 21, 1, 11, 6, 81, 2, 35, 8, 52, 
    3, 90, 7, 85, 0, 45, 1, 46, 5, 83, 4, 69, 6, 92, 8,  1, 2, 52, 
    5, 21, 2,  2, 8,  6, 6, 61, 7, 49, 3, 31, 1, 83, 4, 83, 0, 17, 
    8, 50, 7, 20, 6, 12, 2, 16, 4, 29, 1, 80, 5, 90, 3, 97, 0, 37, 
    6, 57, 0, 50, 3, 66, 4, 44, 1,  7, 5,  9, 2, 25, 7, 66, 8, 16, 
    7, 36, 5, 72, 0, 99, 6, 77, 2, 43, 8, 89, 1,  4, 4, 31, 3, 94
  };
  const int q4347[] = {
    9, 9, // Number of jobs and machines
    1, 99, 3, 71, 7, 45, 6, 16, 8, 85, 2, 24, 5, 75, 0, 79, 4, 14, 
    1, 93, 4, 47, 8, 97, 2, 33, 3, 18, 5, 45, 0, 94, 6, 36, 7, 20, 
    7, 78, 5, 75, 2, 85, 1, 53, 3, 59, 4, 37, 6, 73, 0, 78, 8, 66, 
    6, 11, 3, 75, 2, 55, 0,  7, 4, 84, 1, 49, 5, 38, 7, 96, 8, 43, 
    5, 25, 7,  7, 0, 99, 4, 91, 2, 65, 8, 47, 3, 84, 1, 40, 6, 97, 
    4, 34, 6, 75, 8, 49, 2,  2, 0, 74, 5, 81, 3, 33, 7, 11, 1, 99, 
    0, 30, 4, 52, 8, 47, 3, 69, 1, 35, 2, 29, 5, 17, 6, 48, 7, 95, 
    0, 73, 2, 27, 5, 12, 8, 72, 6, 38, 7, 91, 3, 72, 1, 46, 4, 90, 
    5, 16, 0, 12, 1, 47, 7, 82, 4, 92, 2,  5, 8, 68, 3, 59, 6, 35
  };
  const int q4348[] = {
    9, 9, // Number of jobs and machines
    7, 84, 1, 25, 3, 85, 5,  4, 0, 10, 2, 21, 4, 23, 6, 85, 8, 80, 
    3, 47, 7,  7, 5, 22, 2, 86, 1, 41, 4, 75, 8, 12, 0, 14, 6, 96, 
    2, 43, 5, 76, 1, 31, 6, 52, 7, 91, 4, 13, 3, 11, 8, 10, 0, 22, 
    2, 57, 6,  4, 3, 69, 0, 24, 4, 15, 8, 28, 1, 87, 7, 62, 5, 50, 
    8, 88, 1,  5, 0, 15, 5, 37, 6, 42, 2, 76, 7, 33, 4, 13, 3, 88, 
    7, 49, 6, 52, 3, 41, 2,  6, 4, 26, 0, 10, 8, 80, 1, 25, 5, 87, 
    3, 83, 5, 42, 7, 31, 6, 97, 1, 84, 4,  7, 2, 47, 0, 68, 8, 71, 
    5, 76, 6, 43, 1, 39, 8,  2, 2, 69, 7, 44, 4, 20, 0, 17, 3, 52, 
    3,  6, 0, 44, 6,  6, 4, 86, 1, 73, 2, 54, 7, 38, 5, 44, 8, 15
  };
  const int q4349[] = {
    9, 9, // Number of jobs and machines
    6, 62, 8, 37, 5, 16, 2, 97, 4, 50, 3, 79, 1, 19, 0, 32, 7, 36, 
    6,  9, 8, 26, 5, 30, 0, 36, 4, 63, 3, 62, 1, 24, 2, 20, 7, 49, 
    1, 67, 0, 86, 8, 44, 2, 30, 5, 69, 7, 68, 3, 98, 4, 68, 6, 50, 
    2, 63, 4, 82, 0, 11, 6, 25, 8, 22, 5, 15, 7, 53, 1, 56, 3, 33, 
    6, 82, 4, 48, 1, 33, 7,  1, 2, 90, 3, 15, 0, 88, 8, 81, 5,  5, 
    0, 63, 3, 46, 8, 91, 7, 53, 2, 72, 1, 39, 5, 36, 4, 28, 6, 77, 
    6, 13, 2, 34, 0, 82, 8, 21, 5,  8, 3, 27, 7, 90, 4, 73, 1, 91, 
    2, 87, 6,  8, 1, 69, 3, 89, 8, 86, 4, 45, 5, 13, 7, 93, 0, 21, 
    3, 76, 4, 37, 6, 34, 0, 75, 2, 54, 7, 86, 5, 54, 8, 64, 1, 37
  };
  const int q4350[] = {
    9, 9, // Number of jobs and machines
    1,  9, 0,  2, 8, 27, 6, 13, 4, 89, 7,  9, 2, 45, 3, 88, 5, 44, 
    2, 47, 4, 43, 0, 55, 5, 52, 6,  6, 8, 59, 1, 96, 3, 36, 7, 79, 
    4, 14, 6, 25, 3, 74, 8, 32, 1, 34, 2, 86, 7, 89, 5, 26, 0, 75, 
    2, 43, 1, 66, 4, 28, 8, 77, 5, 46, 3, 23, 0, 91, 7, 79, 6, 53, 
    3, 17, 1, 52, 7, 36, 8, 54, 4, 88, 2, 92, 0, 23, 6, 20, 5, 66, 
    7, 18, 5, 33, 8, 73, 3, 11, 4, 77, 0, 64, 6, 42, 2, 84, 1, 30, 
    6, 57, 8, 56, 1, 52, 5,  6, 2, 11, 0, 67, 4, 25, 7, 11, 3, 71, 
    5, 26, 8, 55, 2, 37, 0, 25, 7, 43, 3, 81, 6, 27, 4, 51, 1,  3, 
    6, 33, 2,  3, 0, 48, 1, 17, 5, 46, 7, 36, 8, 15, 4, 48, 3, 49
  };
  const int q4351[] = {
    9, 9, // Number of jobs and machines
    6, 84, 1, 38, 7, 46, 0, 29, 4, 74, 5, 71, 2, 37, 3, 66, 8, 25, 
    2, 85, 6, 19, 5, 81, 4, 38, 0, 56, 1, 65, 7, 41, 8, 34, 3,  8, 
    2, 35, 4, 88, 5, 78, 3, 59, 7, 90, 6, 95, 1, 70, 8,  5, 0, 31, 
    3, 94, 8, 47, 5, 47, 1, 68, 0, 28, 7, 96, 6, 37, 4,  3, 2, 37, 
    4, 20, 0, 16, 8, 54, 6, 39, 2, 19, 5, 85, 1,  1, 3, 85, 7, 23, 
    8,  9, 3, 29, 4, 59, 5, 23, 0, 27, 7, 13, 1, 39, 6, 43, 2, 45, 
    1, 51, 4, 33, 8, 34, 5, 52, 2, 52, 3, 90, 0,  7, 7, 44, 6, 23, 
    8, 56, 7, 50, 0, 76, 3, 41, 5, 70, 2, 90, 1, 53, 6,  2, 4,  7, 
    0, 35, 4, 63, 6, 91, 3, 81, 8, 30, 5, 45, 2, 53, 7, 37, 1,  9
  };
  const int q4352[] = {
    9, 9, // Number of jobs and machines
    8, 29, 6, 77, 5, 42, 0, 86, 3, 56, 1, 51, 7, 62, 4, 50, 2, 59, 
    8, 66, 5, 77, 6, 61, 1, 43, 7, 89, 2,  6, 4, 83, 3, 86, 0, 23, 
    8, 69, 6, 44, 7,  7, 3, 44, 5, 14, 1, 29, 2, 13, 0, 41, 4, 69, 
    7, 39, 4, 22, 5, 44, 8, 90, 6, 91, 1,  7, 3, 88, 0, 40, 2, 23, 
    7, 78, 1, 24, 2, 26, 6, 65, 3, 92, 0, 60, 4, 37, 5, 65, 8, 23, 
    6, 52, 8, 17, 7, 49, 3, 53, 0, 39, 2,  1, 1, 80, 4, 47, 5, 76, 
    5, 88, 2, 45, 4, 64, 8, 25, 0, 50, 6, 93, 7, 20, 1, 68, 3, 33, 
    4, 92, 3, 60, 6, 25, 5,  2, 7, 34, 0, 15, 1, 97, 8, 28, 2, 11, 
    2, 24, 1, 22, 6, 17, 4, 12, 8, 28, 3, 72, 0,  5, 5, 73, 7, 89
  };
  const int q4353[] = {
    9, 9, // Number of jobs and machines
    3, 56, 4, 56, 8, 37, 7, 16, 2, 56, 0,  1, 5, 10, 1, 75, 6, 70, 
    3, 21, 0,  3, 6, 24, 8, 30, 1, 68, 2, 80, 7,  2, 5,  1, 4, 57, 
    7, 97, 5,  3, 2, 73, 1, 88, 3, 66, 4, 63, 8, 52, 0, 90, 6,  3, 
    6, 90, 0, 83, 5, 49, 1, 52, 2, 59, 7, 56, 3, 27, 8, 53, 4, 87, 
    2, 30, 1, 68, 4, 16, 3, 92, 8, 52, 6, 20, 5, 97, 0, 96, 7, 86, 
    3, 18, 8, 77, 0, 33, 4, 45, 7, 39, 1, 99, 2, 18, 6, 42, 5, 12, 
    7,  5, 3, 78, 0, 68, 2, 32, 8, 60, 6, 29, 1, 34, 4, 99, 5, 26, 
    0, 24, 8, 26, 1, 75, 2, 19, 3, 66, 5, 21, 7, 16, 4, 93, 6, 98, 
    1, 69, 5, 32, 3, 36, 8, 31, 0, 49, 6, 19, 2, 97, 4, 33, 7, 74
  };
  const int q4354[] = {
    9, 9, // Number of jobs and machines
    7,  8, 0, 12, 1, 82, 8, 10, 6, 90, 3, 61, 4, 47, 2, 20, 5, 42, 
    8, 37, 0, 81, 7,  2, 5, 47, 3, 72, 2, 12, 6, 79, 1, 82, 4, 61, 
    3, 47, 5, 70, 8, 40, 7,  5, 4, 91, 1, 11, 2, 44, 6, 27, 0, 96, 
    1, 95, 3, 76, 4, 33, 2, 47, 8, 55, 6, 76, 0,  1, 7, 45, 5, 51, 
    2, 79, 3, 44, 6, 73, 5, 49, 0, 90, 4, 28, 8, 85, 1, 54, 7, 55, 
    3,  7, 4, 20, 7, 63, 5, 62, 0, 26, 8, 91, 6, 57, 2, 87, 1, 46, 
    8, 66, 1, 26, 0, 62, 3,  8, 2,  3, 6, 63, 7, 42, 4, 35, 5,  8, 
    7, 26, 1, 40, 3, 78, 0, 11, 5,  3, 8, 21, 2,  8, 6, 71, 4, 41, 
    5, 11, 7, 52, 0, 58, 1, 69, 2, 28, 6, 55, 8, 26, 3, 59, 4, 48
  };
  const int q4355[] = {
    9, 9, // Number of jobs and machines
    0, 74, 6, 22, 8, 70, 3,  3, 2, 68, 1, 43, 5, 46, 4, 85, 7, 73, 
    3, 48, 5, 53, 6, 51, 0, 61, 8, 14, 4, 84, 1, 31, 7,  5, 2,  7, 
    4, 39, 7, 20, 8, 12, 5, 41, 1, 97, 6, 60, 2, 14, 0, 90, 3, 20, 
    8, 94, 7, 60, 2, 67, 1, 42, 5, 60, 4, 66, 3,  5, 6, 16, 0,  8, 
    4, 27, 8,  3, 1, 63, 5, 20, 0, 16, 7, 23, 3, 15, 2, 64, 6, 38, 
    2, 73, 7, 78, 1, 18, 0, 14, 8,  3, 5, 82, 4, 81, 3, 98, 6, 92, 
    7, 85, 6, 95, 8, 82, 3, 71, 1, 61, 5, 78, 4, 78, 0, 90, 2, 38, 
    6, 41, 1,  9, 8, 97, 4, 40, 7, 36, 3, 32, 2, 87, 5, 52, 0, 29, 
    6, 66, 1, 43, 3, 10, 8, 36, 5, 63, 7, 31, 4, 76, 0, 81, 2,  2
  };
  const int q4356[] = {
    9, 9, // Number of jobs and machines
    3, 16, 1, 27, 8, 94, 5, 34, 6, 65, 7, 88, 2, 14, 0, 46, 4, 81, 
    2, 21, 6,  5, 1, 48, 0,  9, 3, 71, 5, 87, 8, 68, 7, 24, 4, 59, 
    4, 76, 6, 84, 8, 15, 1, 79, 2, 61, 5, 36, 0, 71, 7, 47, 3, 73, 
    6, 76, 1, 10, 8,  4, 2, 97, 4, 69, 5, 46, 3, 74, 7, 11, 0, 63, 
    4, 75, 6, 46, 3, 30, 0, 46, 2, 61, 5,  1, 8, 88, 7, 11, 1, 91, 
    0, 75, 8, 13, 5, 77, 6, 40, 4, 16, 1, 62, 7, 67, 3, 64, 2,  7, 
    5, 12, 0, 75, 7, 70, 6, 92, 2, 25, 4, 49, 1, 75, 3, 37, 8, 60, 
    3, 93, 1, 83, 2, 19, 6, 25, 5,  7, 8,  3, 0, 32, 4,  9, 7, 44, 
    2,  9, 6, 64, 1, 40, 3, 28, 7, 62, 4, 18, 0, 31, 8, 60, 5, 12
  };
  const int q4357[] = {
    9, 9, // Number of jobs and machines
    1, 16, 4, 20, 7,  4, 8, 54, 0,  1, 2, 20, 6, 48, 5, 46, 3, 28, 
    3, 50, 8, 12, 5, 30, 0, 57, 1,  1, 7, 12, 2, 12, 4, 44, 6,  3, 
    1,  1, 3, 94, 0, 43, 8, 99, 7, 45, 5, 56, 4, 61, 2, 68, 6, 14, 
    4, 68, 1, 91, 8, 85, 5,  9, 6, 18, 3, 31, 0, 60, 7, 68, 2, 68, 
    3, 25, 1, 76, 8, 61, 6, 83, 0,  7, 5, 94, 7, 41, 2, 33, 4, 12, 
    8, 58, 5, 65, 6, 73, 4, 44, 2, 30, 1,  3, 0, 81, 3, 57, 7, 49, 
    6, 85, 5,  8, 7, 29, 4, 44, 2, 25, 8,  2, 1, 30, 3, 34, 0, 68, 
    5,  6, 8, 25, 0, 60, 6, 57, 4, 70, 3, 48, 2, 78, 7, 38, 1, 70, 
    2,  7, 1, 53, 0, 88, 6, 48, 4,  4, 8, 11, 7, 88, 3, 62, 5, 17
  };
  const int q4358[] = {
    9, 9, // Number of jobs and machines
    7, 44, 6, 10, 5, 17, 4, 72, 2, 47, 3, 87, 8, 23, 1,  5, 0, 22, 
    5, 85, 6, 92, 4, 56, 8, 77, 1, 60, 2, 37, 7, 64, 0,  5, 3, 38, 
    3, 61, 8, 16, 2,  9, 1, 30, 7, 44, 5, 67, 6, 47, 0, 12, 4, 29, 
    7, 74, 8, 64, 0, 99, 6, 82, 1, 34, 2, 26, 3, 33, 5, 70, 4, 44, 
    0, 48, 3, 47, 8, 80, 2, 32, 1, 51, 6, 11, 4, 87, 7, 35, 5, 90, 
    0, 15, 6, 96, 8,  5, 1, 18, 4, 61, 2, 90, 3,  3, 7,  8, 5, 13, 
    4, 12, 0,  6, 8,  5, 6, 39, 7, 55, 2, 53, 3, 11, 5, 29, 1, 87, 
    4, 89, 1, 47, 5, 55, 8, 13, 3, 32, 0, 48, 7, 86, 6, 55, 2, 18, 
    0, 13, 6, 31, 4, 18, 7, 13, 3, 31, 5,  8, 1, 48, 2,  3, 8, 37
  };
  const int q4359[] = {
    9, 9, // Number of jobs and machines
    1, 26, 3, 31, 0, 45, 5, 44, 6, 13, 2, 53, 4,  6, 7, 42, 8, 43, 
    2, 21, 7, 27, 8, 38, 1, 93, 5, 45, 0, 66, 3, 69, 4, 93, 6, 32, 
    8, 63, 0, 98, 7, 96, 4, 92, 1, 99, 5, 57, 6, 64, 3, 15, 2, 84, 
    8, 30, 4, 88, 2, 27, 5, 65, 0, 32, 6, 15, 3,  4, 7, 89, 1, 90, 
    7, 94, 0, 64, 5, 32, 6, 66, 2, 10, 4,  3, 3, 50, 8, 85, 1, 93, 
    7, 13, 3, 23, 2, 69, 8, 38, 6, 61, 5, 32, 0, 61, 1, 57, 4, 94, 
    5, 93, 0, 31, 7, 79, 3, 69, 1, 38, 8, 90, 4, 63, 6,  8, 2, 87, 
    2, 10, 5, 83, 1, 90, 8, 91, 0, 81, 3,  5, 7, 90, 6,  9, 4, 69, 
    7, 78, 1, 18, 0, 48, 3, 94, 4, 44, 6, 88, 2, 39, 5, 54, 8, 62
  };
  const int q4360[] = {
    9, 9, // Number of jobs and machines
    0, 60, 6, 21, 8, 28, 7, 38, 3,  2, 4, 87, 5, 63, 2, 25, 1, 84, 
    0, 28, 2, 45, 6, 57, 8, 60, 5, 28, 7, 23, 3, 53, 4, 19, 1, 91, 
    2, 45, 0, 98, 1, 83, 4, 65, 6, 95, 3, 77, 7, 29, 8, 70, 5, 13, 
    0, 64, 5, 71, 7, 85, 6, 11, 4, 60, 8, 83, 1, 90, 2, 69, 3, 82, 
    0, 46, 5, 23, 2, 15, 4, 13, 6, 42, 1, 33, 3, 15, 8, 44, 7, 10, 
    1, 20, 0, 90, 4, 62, 7, 69, 3, 22, 8, 87, 6, 84, 2, 18, 5, 56, 
    3, 62, 2, 42, 1, 17, 6, 64, 5, 16, 0, 94, 8, 78, 4, 79, 7, 31, 
    4, 67, 3, 23, 8, 89, 1,  4, 2,  4, 6, 52, 5, 31, 7, 29, 0, 56, 
    4, 99, 8, 44, 6, 71, 3, 94, 7, 51, 0, 63, 2, 35, 1, 62, 5, 94
  };
  const int q4361[] = {
    9, 9, // Number of jobs and machines
    3, 75, 1, 74, 4, 81, 8, 36, 5, 62, 7, 42, 6, 63, 2, 27, 0, 80, 
    5, 84, 3,  7, 0, 86, 8, 82, 7, 47, 6, 77, 4, 54, 1, 84, 2,  2, 
    0, 87, 1, 33, 3, 92, 6, 31, 8, 34, 5, 37, 2, 74, 7, 52, 4, 63, 
    0, 75, 8, 68, 3, 77, 5, 42, 1, 24, 2,  6, 6, 38, 7, 24, 4, 85, 
    1, 45, 3, 44, 2, 41, 0, 66, 7, 27, 5, 84, 4, 69, 8, 68, 6, 29, 
    1, 63, 3, 24, 0, 34, 6, 17, 4,  2, 7, 77, 8, 69, 2, 55, 5, 79, 
    4, 78, 8, 82, 0,  3, 1, 92, 3, 78, 5, 66, 2, 63, 6, 35, 7,  5, 
    4, 35, 0, 63, 8, 85, 7, 10, 1, 55, 2, 37, 6, 23, 3, 23, 5, 75, 
    4, 31, 6, 91, 3, 30, 7, 46, 1, 86, 8, 67, 5, 10, 2, 74, 0, 53
  };
  const int q4362[] = {
    9, 9, // Number of jobs and machines
    6, 14, 7, 68, 2, 18, 4, 27, 5, 42, 8, 47, 3, 12, 1, 54, 0, 89, 
    4, 43, 0, 83, 3, 22, 7,  4, 1, 98, 6, 62, 2, 95, 8, 81, 5, 41, 
    6, 24, 1, 29, 0, 46, 8, 28, 2, 16, 4, 37, 7, 49, 5, 66, 3,  2, 
    3, 76, 6, 46, 7, 75, 5, 91, 4, 62, 2, 33, 0, 27, 8, 97, 1, 15, 
    5, 18, 8, 56, 7, 58, 2, 44, 0, 80, 4, 34, 3, 82, 1, 61, 6, 36, 
    7, 56, 4, 61, 6, 41, 8, 98, 3, 35, 2, 88, 0, 41, 5, 76, 1, 66, 
    4,  8, 1, 11, 5, 30, 6, 32, 3, 42, 2, 19, 7, 74, 8, 15, 0, 59, 
    5,  8, 0, 32, 3, 71, 8, 94, 2, 46, 7, 39, 4, 93, 1, 48, 6, 29, 
    4, 30, 5, 15, 8, 17, 6, 13, 1, 68, 2, 58, 7, 33, 0, 99, 3,  5
  };
  const int q4363[] = {
    9, 9, // Number of jobs and machines
    8, 33, 1, 55, 5, 30, 3, 57, 0,  5, 4,  6, 2, 98, 6, 31, 7, 87, 
    6, 80, 4, 66, 2, 73, 0, 89, 3,  5, 5, 67, 7, 82, 8, 50, 1, 84, 
    2, 14, 5, 54, 7, 25, 4, 22, 8,  4, 0, 23, 1, 18, 6, 10, 3, 63, 
    4,  3, 5, 45, 6, 34, 1, 41, 8, 33, 0, 43, 3, 24, 7, 72, 2, 92, 
    0, 25, 1, 33, 4, 59, 7, 10, 5, 22, 8, 31, 2, 52, 6, 95, 3,  2, 
    2, 35, 7, 93, 4, 10, 8, 84, 0, 17, 5, 68, 6, 78, 1, 42, 3, 55, 
    3, 55, 8, 69, 4,  5, 6, 41, 7,  6, 5, 10, 0, 75, 1, 55, 2, 41, 
    3, 70, 8, 59, 4, 17, 6, 28, 5, 95, 2, 85, 7, 12, 0, 18, 1, 79, 
    8, 95, 5, 19, 1, 15, 7, 39, 6, 14, 3, 98, 2, 33, 4, 20, 0, 89
  };
  const int q4364[] = {
    9, 9, // Number of jobs and machines
    6, 15, 8, 16, 5, 96, 7, 99, 2, 39, 1, 77, 0, 91, 3, 81, 4, 30, 
    3, 11, 1,  6, 8, 23, 7, 45, 0, 35, 4,  8, 2, 27, 6, 52, 5, 43, 
    2,  3, 3, 72, 6, 73, 7, 61, 5, 35, 8, 57, 0, 42, 1, 36, 4, 46, 
    6, 19, 4, 41, 0, 59, 1, 59, 5, 97, 3, 56, 8, 64, 2, 17, 7, 35, 
    5, 43, 8, 62, 0, 26, 6, 42, 7, 11, 3, 73, 4, 95, 1, 36, 2, 93, 
    8, 30, 2, 15, 0, 32, 7, 20, 4, 96, 5, 67, 3, 12, 1, 95, 6, 46, 
    5, 78, 0, 28, 1, 10, 2, 44, 4, 69, 6, 92, 7,  9, 3, 51, 8,  4, 
    1, 46, 7, 91, 5, 97, 0, 84, 2,  3, 6, 87, 3, 16, 4, 50, 8, 58, 
    4, 95, 2, 19, 3, 35, 7, 12, 6, 78, 5, 35, 0, 82, 8, 55, 1,  4
  };
  const int q4365[] = {
    9, 9, // Number of jobs and machines
    1, 97, 3, 70, 4, 68, 0, 94, 6, 52, 7, 98, 2, 79, 8, 81, 5, 50, 
    3, 30, 8, 73, 2, 97, 5, 52, 6,  2, 4, 20, 7, 99, 1, 79, 0, 38, 
    7, 85, 1,  3, 0, 23, 6, 82, 8, 18, 4, 92, 3, 81, 5, 87, 2, 33, 
    6,  5, 0, 17, 1, 83, 4, 15, 2, 55, 3, 35, 7, 81, 8,  8, 5, 91, 
    1, 13, 0, 88, 8, 18, 3, 17, 5, 18, 6, 96, 4, 64, 7, 46, 2, 47, 
    1, 76, 5, 82, 6,  3, 2, 58, 3, 69, 8, 67, 7, 63, 4, 79, 0, 67, 
    6, 77, 2, 97, 3, 14, 5, 67, 8, 80, 0, 12, 7, 52, 1, 75, 4, 19, 
    8, 78, 7, 71, 1, 34, 0, 52, 6,  5, 2, 79, 5, 22, 3, 50, 4, 12, 
    1, 88, 5, 44, 6, 11, 3, 55, 0, 75, 2, 48, 7,  5, 8, 66, 4, 79
  };
  const int q4366[] = {
    9, 9, // Number of jobs and machines
    5, 69, 1, 42, 4, 87, 3, 39, 6, 65, 0, 54, 7, 49, 2, 13, 8, 34, 
    8, 21, 2, 85, 5, 69, 1, 12, 4, 81, 3, 50, 7, 42, 0, 12, 6, 32, 
    5, 19, 8, 85, 6, 29, 2, 51, 0, 46, 3, 62, 4, 75, 1, 98, 7, 15, 
    5, 29, 6, 68, 1, 38, 8, 37, 0, 28, 2, 39, 7, 69, 3, 47, 4, 52, 
    0, 87, 7,  2, 8, 15, 3, 21, 4, 84, 1, 91, 2, 68, 5, 24, 6, 51, 
    1, 40, 7, 72, 6, 74, 5, 69, 8, 92, 4, 23, 2, 81, 3, 47, 0, 28, 
    4, 29, 3, 28, 7, 86, 2, 18, 6, 23, 1, 35, 0,  1, 5, 32, 8, 81, 
    3, 86, 6, 46, 1, 65, 2, 89, 0, 19, 4, 77, 8, 94, 5, 76, 7, 56, 
    1, 94, 3, 97, 0, 73, 4, 18, 8, 80, 2, 64, 5, 33, 7, 78, 6, 86
  };
  const int q4367[] = {
    9, 9, // Number of jobs and machines
    8, 72, 0, 75, 4, 14, 5, 60, 7, 43, 1, 61, 3, 30, 6, 80, 2, 14, 
    4, 34, 3,  3, 7, 50, 8, 11, 6, 79, 1, 17, 0,  1, 5, 40, 2, 44, 
    4, 64, 1, 94, 3, 56, 2, 89, 7, 30, 6, 33, 8, 71, 5, 27, 0, 57, 
    2, 65, 5, 31, 4,  3, 6, 72, 0, 87, 1, 64, 8, 69, 7, 18, 3,  8, 
    0,  8, 3, 24, 6, 22, 4, 61, 2, 63, 5, 19, 7, 29, 1, 36, 8, 25, 
    3, 55, 7, 47, 4, 25, 1, 74, 8, 61, 6, 32, 0, 79, 5, 13, 2, 77, 
    6, 34, 0, 11, 7, 97, 2, 71, 4, 56, 5, 90, 8, 87, 1, 73, 3, 96, 
    5, 78, 7, 45, 1, 34, 2, 59, 3, 65, 6, 94, 8, 83, 0,  2, 4,  8, 
    0, 43, 7, 74, 1, 24, 2, 44, 3, 26, 6, 75, 4, 71, 8, 64, 5, 49
  };
  const int q4368[] = {
    9, 9, // Number of jobs and machines
    2, 61, 7, 23, 6, 95, 4, 24, 0, 17, 3, 88, 8, 99, 1, 68, 5,  1, 
    2, 77, 4, 21, 0, 67, 8, 90, 5, 11, 7, 59, 6, 76, 3, 61, 1, 72, 
    4, 25, 8,  3, 3, 78, 6, 67, 5, 52, 7, 86, 0, 27, 1, 91, 2, 80, 
    1, 83, 7,  6, 2, 23, 6, 89, 3, 93, 4, 68, 5, 43, 8, 86, 0, 75, 
    8, 72, 5, 86, 7, 46, 2, 85, 0, 49, 3, 29, 1, 66, 4, 16, 6, 51, 
    0, 59, 3, 56, 6,  5, 5, 50, 7, 18, 4, 71, 1, 17, 8, 27, 2,  7, 
    4, 93, 6, 67, 1, 48, 7, 44, 3, 52, 0, 80, 2, 40, 5, 74, 8, 47, 
    0, 20, 8, 43, 5, 16, 1, 37, 6, 97, 7, 38, 4, 72, 2, 74, 3, 90, 
    3, 73, 5, 91, 8,  2, 1, 54, 7,  2, 0, 60, 6, 30, 2, 82, 4, 69
  };
  const int q4369[] = {
    9, 9, // Number of jobs and machines
    1, 66, 2, 49, 4,  6, 8, 26, 0,  8, 7, 59, 6, 15, 5,  9, 3, 78, 
    1, 76, 7,  9, 0,  4, 4,  9, 5, 88, 3, 93, 8, 10, 2, 24, 6, 40, 
    3, 43, 1, 24, 6, 59, 2, 15, 7,  9, 4, 18, 5, 16, 8, 14, 0, 11, 
    6, 17, 8, 15, 2, 30, 4,  1, 7, 21, 1, 44, 0, 48, 3, 52, 5, 58, 
    3, 62, 4, 46, 5, 50, 0, 19, 8, 95, 6, 78, 7, 76, 2, 25, 1, 64, 
    8, 45, 2,  9, 1, 59, 7,  6, 5, 17, 4, 24, 3, 71, 6, 80, 0, 26, 
    2, 36, 8, 93, 7, 28, 6, 70, 4, 37, 5, 99, 1, 53, 0, 13, 3, 33, 
    5, 78, 6, 95, 7, 53, 1, 73, 4,  4, 3, 42, 8, 92, 2, 46, 0, 87, 
    3, 50, 4, 37, 6, 40, 1, 66, 8, 41, 0, 36, 5, 88, 2, 64, 7, 64
  };
  const int q4370[] = {
    9, 9, // Number of jobs and machines
    1, 78, 8, 84, 4,  2, 0, 38, 7, 70, 2, 54, 3, 79, 5, 89, 6, 92, 
    6, 44, 0, 99, 4, 75, 3, 83, 5, 68, 2, 53, 8, 21, 1, 50, 7, 96, 
    4, 69, 7, 82, 1, 57, 0, 92, 5,  1, 2, 36, 6, 55, 8, 83, 3, 58, 
    7, 88, 3, 64, 1,  4, 4, 77, 0, 10, 2, 66, 5, 48, 8, 86, 6, 85, 
    0, 98, 4, 75, 2, 96, 5, 74, 7, 32, 8, 20, 6, 21, 1, 66, 3, 99, 
    5, 24, 1, 34, 8, 95, 0, 52, 2, 21, 3, 19, 6, 96, 4, 89, 7, 15, 
    8, 71, 2, 25, 6, 19, 7, 54, 4, 15, 3, 60, 1, 71, 5, 97, 0, 19, 
    4, 12, 8, 17, 2, 38, 1, 53, 3, 88, 0, 66, 6, 80, 5, 65, 7, 41, 
    8, 46, 7, 68, 1, 32, 3, 79, 5, 19, 2, 93, 6, 12, 4, 75, 0, 19
  };
  const int q4371[] = {
    9, 9, // Number of jobs and machines
    6, 72, 1,  2, 0, 20, 7, 65, 5, 82, 8, 56, 4, 34, 2, 38, 3, 13, 
    8,  7, 0, 26, 3, 53, 2, 22, 1, 87, 4, 83, 6, 89, 5, 78, 7, 82, 
    3, 75, 8, 13, 0,  3, 1, 58, 6, 38, 4, 60, 5, 24, 2, 67, 7, 66, 
    2, 11, 1, 53, 0, 15, 4, 69, 7, 71, 5, 75, 8,  6, 6, 68, 3, 69, 
    6, 63, 1, 28, 5, 79, 2, 60, 7, 46, 4,  5, 8, 98, 0, 34, 3, 55, 
    4,  1, 1, 22, 6, 58, 0, 69, 2, 72, 3,  4, 7, 22, 8, 36, 5, 14, 
    8, 69, 4,  7, 0, 15, 2, 15, 3, 72, 5, 59, 6, 37, 7, 18, 1, 24, 
    8, 39, 4, 45, 7, 92, 2, 18, 5, 76, 6,  7, 0, 59, 1, 84, 3, 20, 
    4, 44, 1, 78, 3, 86, 0, 22, 8, 36, 2, 90, 7, 19, 5, 90, 6, 94
  };
  const int q4372[] = {
    9, 9, // Number of jobs and machines
    8, 47, 1, 67, 2, 48, 7, 37, 0, 99, 6, 87, 3, 59, 4, 77, 5, 75, 
    1, 24, 2,  6, 0, 51, 5, 22, 4, 16, 8, 66, 3, 70, 7, 34, 6, 62, 
    0, 63, 7, 88, 1,  2, 5, 74, 6,  8, 4, 93, 2, 87, 8,  5, 3, 98, 
    7, 49, 2, 16, 4, 41, 8, 85, 0, 54, 5, 97, 6, 80, 1, 74, 3, 22, 
    6,  6, 7, 79, 1, 48, 3, 33, 4,  7, 8, 19, 2, 69, 0, 62, 5, 41, 
    8, 64, 3, 17, 4, 10, 2, 18, 6, 75, 1, 92, 7, 38, 5, 92, 0, 82, 
    6, 39, 3, 24, 4, 38, 1, 85, 2, 52, 7, 28, 8, 67, 5, 97, 0, 57, 
    7, 29, 4, 43, 1, 37, 0, 26, 2, 71, 5, 12, 6, 52, 8, 59, 3, 14, 
    3, 45, 1, 90, 5, 38, 2, 12, 7, 29, 8,  4, 0, 94, 6, 23, 4, 22
  };
  const int q4373[] = {
    9, 9, // Number of jobs and machines
    7, 44, 4, 19, 1,  4, 5, 19, 2, 20, 3, 95, 0, 76, 8, 70, 6, 95, 
    1, 51, 2, 40, 3, 48, 8, 18, 5, 82, 0, 87, 7,  7, 4, 88, 6, 12, 
    2, 25, 1, 36, 0, 94, 4, 77, 6, 34, 5, 62, 8, 76, 7,  1, 3, 42, 
    0, 60, 5, 94, 7, 21, 6, 19, 4, 22, 3, 58, 8, 34, 2, 30, 1, 57, 
    7, 94, 0, 53, 3, 13, 5, 51, 1, 42, 8, 84, 2,  9, 6, 23, 4, 71, 
    1, 11, 3, 15, 6, 84, 2, 35, 4, 69, 5, 62, 0, 18, 7, 17, 8, 30, 
    2, 40, 5, 12, 4, 77, 1, 52, 6, 63, 7, 66, 3, 95, 0, 15, 8, 55, 
    0, 66, 4, 40, 8, 85, 5, 93, 6, 40, 3, 19, 7, 71, 2, 21, 1, 88, 
    5, 99, 3, 77, 8, 77, 0, 36, 1, 24, 7,  4, 4, 36, 2, 77, 6,  6
  };
  const int q4374[] = {
    9, 9, // Number of jobs and machines
    1, 13, 7, 75, 4, 91, 5, 83, 3, 71, 0, 48, 2, 18, 8, 53, 6, 91, 
    8, 95, 0, 20, 7, 87, 1, 80, 5, 54, 4, 62, 6, 56, 3, 30, 2, 30, 
    6,  7, 8, 96, 7,  7, 3, 21, 4, 38, 0, 63, 1, 78, 5, 90, 2, 76, 
    0, 69, 6, 41, 3, 93, 4, 89, 2, 62, 7, 70, 1,  9, 8, 74, 5, 70, 
    0,  8, 6, 34, 3, 32, 5, 20, 2, 80, 4, 21, 7, 66, 1, 10, 8, 64, 
    6, 57, 3, 93, 4, 47, 5, 68, 7, 13, 8,  3, 1, 94, 2, 12, 0, 29, 
    2, 83, 5, 11, 4, 40, 7, 70, 0, 70, 3, 17, 1, 63, 6, 61, 8, 10, 
    5, 36, 4, 37, 1, 54, 3, 92, 6, 41, 0,  7, 8, 87, 7, 36, 2, 26, 
    2, 59, 6, 52, 4, 58, 0, 13, 7, 66, 8,  7, 1, 85, 3, 14, 5, 78
  };
  const int q4375[] = {
    9, 9, // Number of jobs and machines
    8, 56, 0, 72, 1, 43, 7, 57, 5, 80, 6, 60, 2, 99, 3,  5, 4, 26, 
    1, 33, 8, 58, 6, 53, 5, 40, 7,  7, 0, 15, 4, 58, 2, 72, 3, 15, 
    2, 21, 8, 42, 4,  8, 0, 77, 6, 83, 7, 83, 3, 29, 1, 49, 5, 36, 
    8, 71, 3, 13, 5, 54, 7, 42, 2, 84, 1, 38, 0, 32, 4, 23, 6, 57, 
    6, 50, 4, 26, 7, 72, 0, 48, 8, 30, 5, 82, 1, 15, 2, 99, 3, 25, 
    1, 83, 0, 89, 3, 26, 8, 23, 6,  9, 5, 60, 7, 45, 4, 41, 2, 47, 
    1,  8, 2, 74, 7, 10, 8, 45, 4, 27, 5, 66, 6, 88, 0, 70, 3, 30, 
    6, 43, 5, 73, 2, 11, 3, 26, 0, 20, 1, 28, 8, 51, 7,  6, 4, 29, 
    3, 37, 5, 42, 6, 48, 0, 68, 2, 64, 7, 26, 1,  6, 8, 51, 4, 79
  };
  const int q4376[] = {
    9, 9, // Number of jobs and machines
    6, 84, 3, 18, 7, 19, 2, 55, 1,  5, 8, 71, 4, 23, 5, 31, 0, 69, 
    3,  3, 7, 21, 5, 75, 2,  8, 6, 80, 1, 60, 4, 40, 8, 20, 0, 42, 
    1, 63, 4, 56, 6, 83, 2, 13, 0, 41, 5, 68, 8, 74, 3, 96, 7, 73, 
    4, 26, 7, 60, 0, 52, 3, 45, 8, 98, 5, 16, 1, 95, 2, 80, 6, 15, 
    0, 83, 1, 66, 8, 69, 3, 73, 7, 16, 2, 44, 5,  8, 6, 82, 4, 92, 
    5, 72, 0, 63, 3, 18, 8, 61, 1, 82, 6, 19, 4, 93, 7, 40, 2, 55, 
    6, 41, 1, 22, 5, 51, 0, 19, 8, 15, 7, 53, 3, 26, 2, 25, 4, 27, 
    3, 25, 4, 27, 6,  7, 5, 73, 0, 72, 2, 61, 7, 20, 1, 56, 8, 16, 
    3, 12, 2, 67, 7, 10, 6, 59, 4, 69, 1, 90, 0, 63, 5, 56, 8, 64
  };
  const int q4377[] = {
    9, 9, // Number of jobs and machines
    0, 19, 5, 60, 7, 19, 3, 40, 4, 28, 6, 54, 8, 62, 1, 38, 2, 38, 
    3, 77, 7, 25, 0, 12, 6, 33, 4, 13, 8,  6, 5,  2, 2, 63, 1, 72, 
    2, 45, 3, 35, 5, 10, 4, 45, 0, 97, 1, 35, 8, 39, 6,  1, 7, 11, 
    5, 76, 4, 87, 8, 12, 1, 66, 7, 37, 6, 31, 2, 12, 3, 57, 0, 82, 
    7, 30, 6, 14, 8, 31, 4, 61, 5, 20, 2, 47, 3, 50, 0, 56, 1,  3, 
    1, 90, 0, 23, 2, 24, 4, 10, 6, 59, 5, 58, 7,  5, 8, 76, 3, 29, 
    8, 12, 6, 33, 7, 65, 0, 30, 3, 91, 4, 47, 2, 32, 5, 43, 1, 71, 
    1, 64, 4, 51, 2, 80, 6, 76, 0,  2, 8, 54, 7, 34, 3,  7, 5,  3, 
    8, 59, 1, 51, 5, 96, 0, 82, 4, 34, 6, 42, 3, 72, 7, 70, 2, 71
  };
  const int q4378[] = {
    9, 9, // Number of jobs and machines
    5, 46, 1, 37, 7, 22, 8, 12, 4, 50, 0, 19, 6, 43, 3, 28, 2, 41, 
    2, 76, 5, 19, 1,  7, 8, 20, 3, 73, 4, 87, 0, 64, 6,  6, 7, 51, 
    4, 79, 0, 90, 2, 20, 6, 56, 5, 91, 7, 96, 1, 93, 3,  5, 8, 45, 
    6, 74, 8, 43, 4, 56, 2,  9, 7, 40, 5, 91, 3, 70, 1, 92, 0, 72, 
    4, 69, 6, 41, 5, 75, 1, 33, 0, 80, 8, 55, 3, 39, 2, 70, 7, 79, 
    1, 59, 0, 13, 7, 33, 3,  7, 8, 68, 2,  4, 4, 29, 5, 63, 6, 10, 
    6, 58, 8, 16, 4,  3, 2, 48, 3, 16, 0, 29, 1, 63, 5, 96, 7, 82, 
    7, 23, 3, 35, 8, 80, 2, 17, 5, 32, 6, 92, 0, 61, 4, 96, 1, 10, 
    0, 35, 7, 47, 6, 57, 4, 45, 5, 83, 1, 68, 3, 47, 8, 22, 2, 98
  };
  const int q4379[] = {
    9, 9, // Number of jobs and machines
    1, 29, 4, 66, 2, 19, 8, 64, 0, 20, 7, 77, 5, 96, 6, 48, 3, 64, 
    7, 69, 6, 46, 1, 99, 5, 65, 4, 31, 8, 23, 3, 53, 2, 28, 0, 13, 
    7, 86, 3, 73, 0, 40, 6, 26, 5, 63, 1, 29, 4, 57, 8, 50, 2, 87, 
    5, 51, 0, 19, 6, 57, 7, 62, 2,  8, 1, 15, 4, 12, 3, 45, 8, 84, 
    2, 65, 0,  4, 4, 53, 3, 49, 7, 41, 6,  7, 1, 32, 8, 62, 5, 54, 
    3, 18, 4, 94, 8, 91, 1, 55, 5, 60, 6, 10, 7, 54, 0, 59, 2, 90, 
    7, 43, 0, 35, 8, 39, 4, 92, 2, 25, 1, 69, 3, 17, 5, 15, 6, 11, 
    7, 94, 5, 52, 6, 12, 4, 24, 8, 66, 3, 92, 2, 60, 0,  2, 1, 62, 
    7, 86, 4, 46, 5, 74, 1, 20, 0, 36, 2, 23, 3, 23, 6, 49, 8, 50
  };
  const int q4380[] = {
    9, 9, // Number of jobs and machines
    3, 71, 0, 13, 4, 86, 2, 31, 6, 85, 8,  6, 7, 80, 1, 58, 5, 10, 
    3, 28, 8, 85, 1, 66, 5, 11, 2, 36, 0, 19, 7,  2, 4, 50, 6, 96, 
    0, 39, 7, 45, 6, 70, 5, 95, 8, 76, 4, 48, 2, 77, 3, 61, 1, 55, 
    3, 23, 8, 29, 0, 29, 2, 11, 1, 98, 5, 23, 4, 76, 7, 95, 6, 13, 
    6, 24, 0,  7, 4, 27, 3, 24, 2, 56, 1, 50, 7, 68, 8, 74, 5, 43, 
    2, 83, 3, 14, 6,  5, 7, 45, 1, 70, 0, 83, 8, 64, 5, 49, 4, 67, 
    3, 31, 1, 12, 2, 34, 7, 21, 8, 18, 6, 76, 4, 18, 0, 85, 5, 96, 
    5, 29, 8, 57, 1, 11, 7, 83, 0, 43, 6, 82, 3,  7, 2, 73, 4, 88, 
    5, 79, 3, 89, 4, 78, 1, 62, 0, 42, 7, 33, 6, 36, 8, 81, 2, 18
  };
  const int q4381[] = {
    9, 9, // Number of jobs and machines
    4, 48, 7, 32, 5, 83, 3, 60, 2, 86, 6, 10, 8, 99, 0, 52, 1, 10, 
    5, 97, 8, 25, 4, 78, 3, 57, 2, 52, 0, 86, 6, 67, 1, 53, 7, 76, 
    5, 82, 0, 22, 8, 26, 3,  5, 1, 40, 2, 31, 4, 32, 7, 87, 6, 73, 
    1, 62, 4, 58, 7, 97, 5, 50, 6, 56, 0, 19, 2, 38, 8, 83, 3, 17, 
    5, 28, 2, 60, 6, 69, 1, 31, 7, 74, 4, 89, 8, 31, 3, 49, 0, 45, 
    0, 68, 6, 16, 8, 17, 2,  1, 5, 67, 3, 25, 4, 78, 1, 71, 7, 29, 
    8, 16, 5, 20, 2, 52, 0,  8, 6, 21, 1, 12, 3, 80, 7, 93, 4, 33, 
    6, 83, 0,  5, 5, 68, 2, 18, 1, 57, 3, 37, 4,  9, 8, 82, 7, 60, 
    1, 71, 2, 58, 0, 90, 6, 50, 3, 23, 4, 20, 5, 34, 7, 65, 8, 28
  };
  const int q4382[] = {
    9, 9, // Number of jobs and machines
    2, 82, 8, 76, 6, 99, 1, 90, 3, 32, 5, 16, 0, 95, 7,  6, 4, 57, 
    7, 69, 2, 49, 0, 86, 3, 17, 8,  1, 4, 66, 6, 90, 5, 83, 1, 27, 
    8, 73, 7,  9, 0, 99, 3, 93, 4, 69, 5, 58, 2, 41, 6, 41, 1, 82, 
    3, 58, 0, 19, 8, 91, 7, 40, 4, 10, 5, 45, 6,  9, 1, 86, 2,  4, 
    6, 95, 1, 58, 3, 44, 2, 71, 8, 26, 5, 39, 7, 69, 4, 36, 0, 84, 
    5, 35, 7, 19, 8, 47, 0, 51, 3, 70, 2,  9, 4, 64, 1, 17, 6, 23, 
    3, 88, 6, 49, 5,  6, 0, 65, 1, 62, 8, 80, 2,  8, 4, 71, 7,  8, 
    5, 54, 0, 19, 4, 87, 1, 25, 7, 84, 8, 62, 3, 90, 2, 71, 6, 56, 
    5, 81, 2, 40, 6, 39, 0, 19, 4, 77, 1, 14, 3, 27, 8, 63, 7, 18
  };
  const int q4383[] = {
    9, 9, // Number of jobs and machines
    3, 39, 1,  2, 6, 50, 2, 97, 0, 47, 4, 31, 5,  7, 8, 48, 7, 71, 
    6, 27, 2, 69, 4, 81, 7, 34, 8,  4, 0, 41, 5, 58, 1, 31, 3, 22, 
    8, 91, 5, 74, 4, 36, 2, 17, 6, 98, 3, 33, 7, 53, 1, 44, 0, 33, 
    0,  1, 8,  4, 6, 41, 7, 42, 5, 71, 4, 30, 3, 61, 1, 54, 2, 47, 
    0, 79, 7, 32, 3, 37, 8, 94, 1, 70, 5, 22, 6, 22, 4, 52, 2, 30, 
    6, 18, 8, 71, 0, 32, 2, 62, 4, 96, 3, 12, 1, 24, 7, 11, 5, 24, 
    4, 98, 2, 46, 7, 15, 6, 87, 3, 97, 8, 48, 5, 40, 1,  9, 0,  6, 
    6,  6, 4, 19, 2,  9, 3, 95, 0, 45, 7, 40, 8, 73, 1, 87, 5, 47, 
    4,  6, 6, 16, 0, 14, 1, 93, 8, 97, 3, 19, 2, 75, 5, 73, 7, 93
  };
  const int q4384[] = {
    9, 9, // Number of jobs and machines
    0, 41, 2, 51, 3, 33, 8, 10, 1, 44, 5, 49, 6, 43, 4, 65, 7, 71, 
    6, 82, 2, 57, 1, 43, 7, 56, 0, 53, 8, 80, 5, 51, 3, 14, 4, 67, 
    6,  2, 1, 77, 0,  1, 2, 70, 4, 63, 8, 11, 7,  1, 5, 11, 3, 71, 
    7, 55, 4, 48, 3, 24, 8, 19, 6, 29, 0, 59, 1, 44, 2, 30, 5,  4, 
    5, 95, 8, 17, 4, 56, 2, 16, 1, 10, 0, 33, 3, 32, 7, 55, 6, 89, 
    0, 24, 3, 86, 2, 19, 5, 38, 7,  6, 6, 28, 1, 49, 4, 37, 8, 37, 
    5, 98, 4, 95, 1, 74, 8,  3, 0, 26, 2, 47, 6, 15, 7, 43, 3, 55, 
    3, 64, 8, 95, 6, 40, 2, 58, 4, 87, 5, 11, 0, 87, 7, 45, 1,  5, 
    8, 81, 0,  2, 2, 53, 3, 81, 7, 78, 4, 82, 6, 14, 5, 31, 1, 62
  };
  const int q4385[] = {
    9, 9, // Number of jobs and machines
    7, 60, 4,  5, 8, 61, 5, 75, 2, 16, 0, 87, 6, 42, 1, 90, 3, 88, 
    7,  7, 3, 32, 8, 69, 6, 24, 4,  5, 1, 65, 2, 91, 5, 68, 0, 38, 
    8, 23, 1, 29, 2, 77, 7, 16, 5, 58, 6,  8, 3, 21, 4, 99, 0, 87, 
    5, 24, 1, 45, 2, 29, 6,  2, 7, 93, 4, 99, 8, 72, 0, 15, 3, 24, 
    4, 36, 5, 58, 1, 74, 6, 64, 7, 65, 2, 72, 3, 57, 0, 60, 8, 82, 
    5, 29, 0, 14, 1, 20, 3, 55, 2, 32, 6, 89, 7, 80, 8, 19, 4, 57, 
    2, 72, 8, 36, 7,  8, 5, 50, 1, 22, 4, 23, 0, 47, 6, 69, 3, 61, 
    4,  3, 3, 67, 6, 19, 1, 60, 2, 91, 5, 48, 7, 46, 8, 70, 0, 69, 
    3, 65, 7, 36, 4,  2, 5, 86, 8, 59, 0, 60, 6,  6, 2, 92, 1, 94
  };
  const int q4386[] = {
    9, 9, // Number of jobs and machines
    6, 87, 7, 46, 5, 10, 2, 99, 8, 43, 1, 39, 4, 58, 0, 61, 3,  9, 
    7,  3, 3, 72, 0,  5, 4, 10, 1, 74, 6, 78, 8, 73, 5, 48, 2, 26, 
    1, 51, 0, 35, 5, 93, 4, 18, 6, 14, 3, 35, 7, 28, 2, 72, 8, 72, 
    1, 34, 7, 39, 4, 63, 5, 48, 3, 45, 8, 98, 6, 87, 0, 58, 2, 27, 
    1, 30, 6,  3, 2, 98, 7, 81, 8, 66, 3, 14, 4, 80, 5, 86, 0, 59, 
    0,  7, 6,  7, 4, 71, 7, 63, 1, 92, 8, 89, 2, 93, 3, 97, 5, 98, 
    5, 24, 3, 61, 8, 90, 1, 86, 6, 38, 4, 84, 2, 86, 7, 99, 0, 86, 
    0, 16, 3, 90, 6, 80, 7, 67, 1, 29, 8, 73, 2, 22, 5, 31, 4, 74, 
    6, 12, 5, 95, 3, 44, 7, 73, 1, 76, 2, 13, 0, 90, 4, 80, 8,  1
  };
  const int q4387[] = {
    9, 9, // Number of jobs and machines
    6, 94, 5, 35, 2, 40, 4, 55, 3, 25, 7, 10, 8, 11, 0, 28, 1, 67, 
    7, 64, 6,  7, 3, 49, 4, 13, 8, 60, 0, 94, 5, 58, 1, 59, 2, 91, 
    7, 43, 5, 31, 0, 19, 2, 51, 4,  8, 8, 70, 3,  4, 1, 36, 6, 92, 
    3, 45, 2, 62, 5, 80, 6,  7, 8, 77, 4, 18, 0, 51, 1,  4, 7, 83, 
    1, 38, 7, 72, 4, 78, 0,  8, 2, 69, 6, 35, 5, 80, 8, 28, 3, 54, 
    0,  7, 1, 33, 7, 92, 5, 41, 6, 62, 8, 15, 2, 71, 3, 78, 4, 60, 
    3, 91, 1, 29, 7, 32, 2, 37, 4, 67, 5, 26, 0, 22, 6,  4, 8, 95, 
    8, 78, 3, 46, 5, 68, 7, 59, 6, 98, 1, 75, 2, 35, 4, 69, 0, 55, 
    3, 49, 4,  4, 8, 28, 2, 69, 1,  2, 0, 59, 6, 23, 5, 58, 7, 34
  };
  const int q4388[] = {
    9, 9, // Number of jobs and machines
    5, 56, 3, 87, 0, 60, 8, 47, 1,  8, 4, 26, 6, 32, 7, 11, 2, 98, 
    1, 87, 2, 70, 3,  2, 7, 20, 6, 94, 8, 60, 4, 54, 5, 76, 0, 74, 
    2, 93, 7, 68, 4, 58, 0, 36, 8, 85, 6, 31, 3,  7, 5,  5, 1, 37, 
    7, 23, 8, 65, 2, 10, 5, 59, 3, 32, 4, 34, 1, 30, 0, 95, 6, 79, 
    7, 26, 0, 56, 8, 64, 6, 42, 3,  8, 4, 29, 1, 46, 2, 99, 5, 11, 
    5, 52, 1, 25, 2, 39, 0, 30, 3, 71, 4, 48, 8,  7, 7,  7, 6, 35, 
    4, 78, 5, 59, 0, 30, 1, 13, 6,  7, 2, 38, 3, 61, 8, 86, 7, 63, 
    3, 51, 8, 97, 6, 50, 5, 72, 2, 80, 1, 66, 4, 42, 0,  7, 7, 75, 
    6, 27, 8,  6, 7, 54, 2, 42, 3, 26, 4, 15, 0, 22, 5, 14, 1,  9
  };
  const int q4389[] = {
    9, 9, // Number of jobs and machines
    4, 24, 1, 14, 3, 32, 7, 47, 5, 31, 8, 18, 0,  8, 6, 13, 2, 36, 
    4, 25, 2, 31, 0, 49, 1, 25, 5, 42, 7, 79, 3, 98, 8, 19, 6, 10, 
    7, 12, 5, 13, 2, 69, 3, 88, 4, 92, 8, 46, 1, 45, 6, 74, 0, 49, 
    1, 41, 2, 61, 7, 89, 6, 43, 4, 91, 3, 46, 0, 33, 5,  7, 8, 89, 
    5, 11, 1, 43, 6, 35, 7, 58, 3, 57, 2, 38, 8, 23, 0, 70, 4, 88, 
    0, 71, 5, 35, 1, 50, 2, 81, 8, 26, 4, 82, 7,  2, 6, 77, 3, 86, 
    0, 15, 5, 78, 1, 76, 8, 11, 2, 64, 4, 25, 3, 68, 6, 52, 7, 56, 
    3, 77, 7, 96, 6, 86, 5, 58, 1, 34, 2, 53, 4, 64, 8, 84, 0, 51, 
    8, 51, 5, 99, 7, 32, 0, 63, 4, 80, 1,  8, 2,  6, 3, 28, 6, 28
  };
  const int q4390[] = {
    9, 9, // Number of jobs and machines
    0, 95, 7, 42, 2, 58, 4, 13, 8, 76, 6, 82, 5, 97, 3, 77, 1, 26, 
    5, 82, 8, 13, 1, 87, 2, 18, 3, 22, 0, 26, 6, 50, 7, 50, 4, 93, 
    4, 47, 3, 70, 0, 56, 5, 79, 2, 67, 1, 89, 6, 36, 7, 37, 8,  5, 
    4, 48, 3, 79, 7, 10, 8, 91, 5, 14, 2, 82, 0, 69, 6, 89, 1, 17, 
    7, 47, 3, 57, 1, 35, 6, 35, 5, 22, 2, 33, 0, 48, 8, 32, 4, 66, 
    8, 90, 5,  7, 4, 19, 2, 27, 1, 34, 6, 77, 7, 15, 0,  1, 3, 82, 
    1, 95, 4, 84, 3, 79, 5, 60, 6, 53, 0,  7, 7, 37, 8, 19, 2, 89, 
    3, 47, 1, 68, 8, 66, 0,  7, 7, 87, 4, 44, 6, 30, 2, 73, 5, 43, 
    5, 61, 4, 70, 8, 13, 6, 92, 7, 95, 3, 45, 1, 65, 0, 88, 2, 13
  };
  const int q4391[] = {
    9, 9, // Number of jobs and machines
    8, 24, 5, 52, 1, 67, 3, 77, 0, 46, 7, 66, 2, 35, 6, 24, 4, 95, 
    2, 50, 0, 17, 6, 40, 4, 99, 7, 17, 3,  8, 8, 90, 1, 66, 5, 57, 
    7, 90, 1, 92, 5, 57, 6, 33, 0,  1, 2, 85, 8, 59, 3, 38, 4, 93, 
    1, 41, 5,  5, 4, 77, 6, 94, 8, 41, 3, 17, 7, 57, 2, 37, 0, 38, 
    7, 15, 3, 39, 8, 77, 5, 29, 6, 20, 0, 56, 4, 31, 1, 77, 2,  2, 
    7, 73, 5, 81, 0, 15, 2, 88, 4, 42, 8, 13, 6,  7, 3, 97, 1, 99, 
    2, 64, 5, 25, 7, 16, 1, 41, 4, 53, 8, 16, 6, 97, 3, 86, 0, 91, 
    0, 68, 6, 25, 1, 98, 2, 56, 7, 33, 8, 89, 4, 20, 3, 88, 5, 86, 
    2, 61, 7, 94, 4,  4, 3, 16, 1, 48, 6, 19, 0,  2, 8, 55, 5, 67
  };
  const int q4392[] = {
    9, 9, // Number of jobs and machines
    8, 69, 7, 72, 5, 31, 2, 56, 6, 28, 4, 10, 1, 69, 3, 18, 0, 19, 
    3, 11, 4, 49, 1, 46, 7, 64, 6, 99, 5, 31, 0, 25, 2, 22, 8,  3, 
    2, 27, 8, 36, 1, 85, 5,  1, 3, 25, 6, 78, 0, 86, 7, 21, 4, 51, 
    4, 73, 2, 67, 6, 44, 0, 15, 8, 42, 3, 48, 5,  7, 7, 60, 1, 80, 
    2,  4, 4, 11, 8, 32, 0, 56, 5, 54, 1,  2, 7, 96, 6, 63, 3, 21, 
    5, 29, 8, 13, 3, 59, 2, 76, 0, 31, 1, 63, 7, 57, 4, 60, 6, 88, 
    3, 47, 8,  2, 7,  7, 4, 29, 1, 86, 0, 80, 5,  8, 6, 90, 2, 31, 
    8, 89, 2, 38, 0, 44, 6, 84, 5, 16, 1, 27, 4, 51, 7, 65, 3, 28, 
    3, 94, 0, 24, 4, 78, 2, 37, 1, 64, 6, 59, 5, 83, 8, 48, 7,  5
  };
  const int q4393[] = {
    9, 9, // Number of jobs and machines
    1, 94, 4, 65, 6,  6, 3, 35, 2, 21, 8, 38, 7, 48, 5, 60, 0, 50, 
    7, 35, 4, 84, 0, 87, 3, 85, 2, 73, 5, 95, 1, 98, 8, 36, 6,  9, 
    3, 24, 1, 57, 7, 46, 8, 77, 5,  4, 6, 82, 4, 62, 2, 25, 0, 22, 
    5, 36, 3, 81, 2, 43, 8, 12, 0, 12, 4, 49, 6,  6, 1, 50, 7, 64, 
    2, 92, 0, 89, 1, 35, 6, 18, 4, 51, 8, 31, 3, 86, 7, 69, 5, 66, 
    1, 69, 7, 92, 4, 99, 2, 30, 5, 24, 3, 46, 0, 22, 6, 89, 8, 50, 
    8, 97, 3, 63, 1, 19, 6,  6, 4, 17, 5, 39, 7, 34, 2, 20, 0, 13, 
    8, 48, 7, 93, 2, 50, 3, 78, 4, 62, 1, 96, 5, 80, 6, 89, 0, 77, 
    3, 97, 5, 22, 6, 28, 8,  7, 0, 13, 7, 92, 2,  8, 4, 71, 1, 68
  };
  const int q4394[] = {
    9, 9, // Number of jobs and machines
    3, 88, 5, 98, 4, 20, 1, 34, 2, 77, 6, 49, 8, 47, 0, 14, 7, 44, 
    1, 43, 7, 46, 5,  1, 4, 25, 3, 10, 8, 81, 6, 23, 2, 71, 0, 37, 
    4, 49, 8, 89, 0, 12, 5, 68, 2, 64, 3, 11, 1, 44, 7, 41, 6, 96, 
    3, 19, 5, 92, 1,  3, 4, 20, 0,  5, 7,  7, 2, 18, 8, 16, 6, 75, 
    0, 52, 3, 29, 4, 94, 2, 75, 8, 95, 5, 14, 1, 67, 6, 83, 7, 56, 
    5, 45, 8, 61, 3, 57, 6, 85, 1, 92, 7, 13, 0, 39, 2, 53, 4, 24, 
    2, 32, 1, 29, 7, 64, 6, 65, 3, 88, 4, 32, 8, 79, 0, 42, 5, 91, 
    3, 40, 0, 63, 6, 81, 1, 79, 4, 35, 5,  3, 2, 92, 7, 73, 8, 44, 
    0, 15, 4, 42, 8, 66, 1, 72, 6,  7, 5, 24, 3, 43, 2, 60, 7, 40
  };
  const int q4395[] = {
    9, 9, // Number of jobs and machines
    7, 85, 8, 42, 6,  2, 2, 15, 0, 44, 5,  2, 3, 28, 4, 81, 1, 79, 
    7, 59, 0,  5, 8, 86, 5, 40, 3, 69, 2, 56, 1, 99, 4, 51, 6, 49, 
    6, 65, 3, 54, 2,  8, 7, 68, 4,  9, 1, 25, 0, 43, 8, 42, 5, 75, 
    1, 20, 6,  2, 4, 95, 0, 94, 8, 50, 2, 11, 3, 38, 5, 98, 7, 63, 
    7, 37, 4, 15, 5, 61, 0, 20, 2, 49, 3, 92, 6, 54, 1, 21, 8, 82, 
    0, 75, 8, 80, 2, 58, 3, 98, 7, 45, 4,  3, 6, 65, 5,  7, 1, 27, 
    5, 20, 4, 37, 6, 52, 8, 13, 0, 21, 7, 56, 1, 41, 2, 83, 3, 97, 
    0, 55, 6, 37, 3, 71, 5, 95, 7, 36, 8, 11, 4,  4, 1, 39, 2, 40, 
    4, 16, 6, 14, 5, 66, 2, 18, 8, 42, 7, 67, 3, 64, 0, 76, 1, 51
  };
  const int q4396[] = {
    9, 9, // Number of jobs and machines
    1, 98, 6, 34, 4, 10, 5, 49, 7, 45, 3, 24, 0, 86, 8, 59, 2, 11, 
    6, 17, 7, 56, 0, 63, 1, 86, 5, 43, 4, 50, 8, 89, 2, 82, 3, 64, 
    7, 41, 0, 21, 4, 49, 6, 11, 3, 92, 2, 71, 1, 11, 5, 81, 8, 80, 
    2, 46, 8,  8, 6, 79, 1, 76, 5, 16, 3, 50, 4, 52, 0, 12, 7, 77, 
    0, 96, 8, 66, 4, 25, 5, 12, 3, 43, 2, 29, 7, 87, 1, 29, 6, 84, 
    6,  6, 8, 97, 5, 99, 1, 54, 2, 14, 0, 58, 7, 98, 4,  6, 3, 25, 
    4, 48, 8, 62, 1, 64, 5, 22, 6, 93, 7, 44, 0, 17, 2, 29, 3, 32, 
    5, 31, 2, 48, 0, 13, 6, 21, 1, 83, 7, 89, 4, 83, 8, 19, 3, 50, 
    2, 46, 1, 87, 8, 25, 5, 99, 3, 96, 4, 88, 7, 96, 6, 30, 0, 67
  };
  const int q4397[] = {
    9, 9, // Number of jobs and machines
    8, 23, 4, 87, 3, 30, 1, 66, 6, 17, 7, 94, 5, 55, 0, 33, 2, 48, 
    6, 82, 0, 13, 7, 70, 3, 38, 4, 16, 5, 89, 8, 78, 1, 63, 2, 95, 
    4,  5, 8, 16, 1,  9, 2, 66, 6,  1, 7, 13, 5, 80, 0, 89, 3, 70, 
    2, 21, 6, 13, 0, 93, 3, 10, 4, 47, 7, 63, 5, 64, 8, 96, 1, 70, 
    8, 24, 1, 48, 5, 91, 3, 59, 7,  5, 4, 85, 0, 93, 6, 19, 2, 84, 
    6, 91, 0, 61, 8, 17, 1, 73, 5, 49, 3, 97, 7, 62, 2, 96, 4,  6, 
    5, 10, 0, 53, 6, 65, 2, 21, 1, 79, 7, 28, 4, 17, 3,  4, 8, 37, 
    3, 26, 7, 32, 8, 68, 0, 14, 5, 31, 6, 29, 4, 22, 1, 82, 2, 87, 
    3, 46, 7, 22, 8,  1, 1, 78, 5,  2, 4, 10, 0, 68, 6, 32, 2,  8
  };
  const int q4398[] = {
    9, 9, // Number of jobs and machines
    6, 65, 4,  9, 0, 62, 7, 41, 1, 23, 2, 59, 3,  7, 8, 21, 5, 69, 
    6, 90, 1, 32, 0,  1, 8, 12, 5, 33, 2, 72, 4, 64, 3, 74, 7, 12, 
    1, 35, 4, 28, 8, 84, 5, 43, 7, 23, 3, 88, 0, 85, 6, 47, 2, 44, 
    6, 51, 5,  2, 2, 42, 0, 52, 1, 99, 3, 93, 7, 73, 4, 45, 8, 83, 
    3, 71, 5, 96, 0, 35, 4, 47, 1, 34, 8, 39, 6, 69, 7, 30, 2, 42, 
    6, 78, 0, 35, 1, 96, 7, 39, 4, 35, 5, 23, 3, 81, 2, 93, 8, 80, 
    7,  4, 5, 67, 2, 71, 6, 82, 4, 85, 3, 77, 0, 11, 8, 62, 1, 62, 
    4,  4, 0, 97, 8, 76, 7, 66, 3, 72, 2, 25, 1, 16, 5, 79, 6, 31, 
    0, 13, 3, 55, 6, 32, 8, 31, 1, 47, 7, 67, 2, 45, 5, 31, 4, 79
  };
  const int q4399[] = {
    9, 9, // Number of jobs and machines
    4, 86, 7, 74, 8, 89, 1,  1, 6, 65, 2, 29, 3,  9, 0, 35, 5, 50, 
    8, 25, 0, 98, 1,  2, 6, 66, 2, 64, 5, 76, 3,  6, 7, 53, 4, 54, 
    2, 65, 5, 65, 3, 10, 7, 81, 4, 62, 1, 81, 0, 29, 6, 26, 8, 65, 
    1, 57, 5,  5, 7, 72, 8, 76, 2, 57, 6, 36, 4, 98, 0, 29, 3, 51, 
    0, 88, 5, 65, 1, 77, 7, 19, 4, 17, 8, 27, 6, 75, 3, 71, 2, 80, 
    5,  4, 8, 81, 1, 90, 6, 20, 4, 55, 0,  5, 3, 25, 2,  4, 7, 48, 
    8, 78, 6, 59, 5, 41, 7, 68, 1, 81, 2, 77, 4, 13, 0, 14, 3, 44, 
    5, 29, 1, 81, 7, 91, 4, 55, 8, 29, 0, 64, 3,  5, 2, 21, 6, 73, 
    5, 72, 1, 88, 3, 87, 8,  3, 2, 11, 4, 85, 6, 35, 7, 77, 0, 42
  };
  const int q4400[] = {
    9, 9, // Number of jobs and machines
    2, 96, 8, 63, 6,  6, 7, 41, 5, 94, 3, 82, 1, 94, 4, 15, 0,  5, 
    1, 38, 5, 79, 2, 28, 7, 45, 8, 64, 0, 73, 4, 72, 3, 49, 6, 98, 
    6, 50, 7, 45, 3, 53, 4,  1, 8, 55, 2, 77, 1, 16, 0, 21, 5, 98, 
    3, 31, 8, 29, 5, 51, 2, 53, 7, 46, 6, 48, 4, 17, 0, 33, 1, 83, 
    5, 81, 2, 63, 3, 31, 6, 49, 7, 43, 4, 79, 1,  9, 0, 76, 8, 94, 
    3, 28, 8, 60, 5, 16, 6,  1, 4, 71, 0, 48, 7, 76, 2, 65, 1, 61, 
    4, 11, 3, 72, 7, 12, 0, 24, 5, 68, 2, 58, 6, 95, 8, 31, 1, 89, 
    2, 20, 6,  6, 7, 44, 4, 26, 1, 73, 0,  9, 3, 78, 5, 11, 8, 14, 
    2, 50, 7, 49, 3, 54, 5, 22, 1, 58, 8, 65, 4, 74, 6, 62, 0,  8
  };
  const int q4401[] = {
    9, 9, // Number of jobs and machines
    6, 15, 7, 22, 2, 66, 1, 80, 0,  2, 4, 93, 3, 79, 8, 70, 5,  9, 
    0, 26, 2, 68, 1,  2, 6, 99, 3, 34, 5, 91, 4, 25, 7, 23, 8, 59, 
    3, 76, 0, 46, 2, 22, 4,  8, 6, 33, 5, 57, 8, 93, 7, 25, 1, 12, 
    2, 83, 1, 57, 0, 10, 7, 30, 3, 40, 6, 87, 8, 26, 5, 13, 4, 27, 
    2, 61, 8, 30, 7, 96, 6, 92, 5, 23, 4, 69, 3, 48, 1, 69, 0, 89, 
    2, 84, 3, 14, 8, 83, 5, 21, 7, 82, 0, 45, 1, 72, 6,  9, 4, 16, 
    8, 71, 7, 72, 6, 46, 3, 62, 0, 39, 5,  1, 1, 55, 4,  3, 2, 21, 
    1, 67, 3, 64, 8, 31, 2, 76, 6, 67, 0, 85, 4, 37, 5, 21, 7, 78, 
    1, 38, 2, 91, 6, 63, 4, 92, 3, 12, 0, 73, 7, 38, 5, 83, 8, 89
  };
  const int q4402[] = {
    9, 9, // Number of jobs and machines
    4, 43, 5, 46, 7, 88, 1, 14, 8, 49, 2, 63, 3,  1, 6, 23, 0, 37, 
    2, 37, 1, 44, 6, 27, 5, 90, 7, 68, 3, 74, 0, 67, 8, 99, 4, 36, 
    3,  6, 6, 84, 4, 86, 0, 59, 2, 53, 8,  8, 5, 69, 7, 29, 1, 87, 
    1, 70, 5, 76, 8, 64, 0, 69, 4,  1, 7, 39, 3,  8, 2, 71, 6, 25, 
    0, 51, 8, 58, 1, 39, 6, 27, 4, 92, 5, 54, 2, 84, 7, 23, 3, 79, 
    5, 48, 8, 12, 7, 46, 2, 20, 6, 17, 3,  7, 1, 77, 0, 13, 4, 43, 
    7, 58, 5, 70, 0, 65, 2, 36, 3,  9, 4, 71, 8,  7, 1, 92, 6, 22, 
    6, 68, 4,  2, 1, 93, 2,  5, 5,  2, 7, 20, 0, 22, 8, 10, 3, 52, 
    0,  3, 3, 28, 5, 99, 4, 64, 8, 54, 1, 78, 2, 59, 6, 42, 7, 50
  };
  const int q4403[] = {
    9, 9, // Number of jobs and machines
    7, 15, 3, 64, 8, 78, 6, 22, 1, 37, 4, 37, 5, 78, 2, 36, 0, 63, 
    5, 40, 6, 43, 2, 49, 1, 39, 4, 50, 8, 81, 3, 16, 0,  7, 7, 37, 
    7, 60, 4, 27, 2, 84, 0, 31, 1, 13, 6, 44, 3,  5, 8, 91, 5, 58, 
    3, 54, 0, 34, 1, 32, 8, 88, 4, 12, 7, 65, 5, 47, 6, 78, 2, 23, 
    8,  9, 2, 20, 5,  9, 1, 62, 0, 81, 7, 22, 4, 62, 6, 71, 3, 13, 
    1, 28, 6, 69, 3, 11, 0, 24, 4, 38, 7, 56, 8, 56, 5, 91, 2, 55, 
    8, 90, 7, 89, 4, 40, 1, 11, 5, 19, 6, 15, 0, 72, 2, 92, 3, 41, 
    0, 98, 2, 72, 6, 48, 4, 18, 1, 46, 5, 72, 3, 26, 8,  3, 7, 83, 
    8, 46, 0, 65, 2, 35, 6, 44, 4, 63, 1, 31, 3, 78, 5, 97, 7, 76
  };
  const int q4404[] = {
    9, 9, // Number of jobs and machines
    7,  5, 0, 55, 6, 85, 5, 82, 2, 63, 3, 65, 8, 98, 4, 25, 1, 11, 
    7,  4, 8,  6, 0, 46, 3, 33, 1, 70, 6, 97, 2, 60, 5, 86, 4, 16, 
    7, 44, 2, 73, 6, 60, 0, 86, 1, 73, 3, 56, 4, 18, 8, 87, 5, 76, 
    1, 10, 8, 33, 0, 60, 7, 40, 6, 52, 3, 15, 2, 93, 4, 28, 5, 96, 
    2, 40, 8,  4, 0, 87, 1, 16, 5, 82, 6, 41, 4, 96, 3,  2, 7, 43, 
    5, 86, 2, 23, 7, 82, 8, 38, 4, 70, 1, 59, 0, 95, 3, 95, 6, 19, 
    3, 52, 7, 89, 1, 28, 0, 61, 5, 23, 8, 46, 2, 29, 6, 90, 4, 84, 
    5, 96, 2, 77, 7, 63, 4, 90, 3, 79, 8, 57, 1, 87, 6, 72, 0, 75, 
    1, 48, 6, 43, 0, 16, 5, 35, 4, 95, 2, 43, 3, 37, 7, 72, 8, 56
  };
  const int q4405[] = {
    9, 9, // Number of jobs and machines
    8, 90, 7, 10, 5, 19, 3, 66, 1, 60, 0, 45, 6,  7, 2, 87, 4, 11, 
    5, 10, 4, 15, 0, 98, 6, 93, 2, 29, 3, 27, 1, 58, 8, 45, 7, 70, 
    8, 62, 0, 17, 2, 68, 7, 19, 1, 93, 3, 66, 4, 78, 5, 94, 6, 91, 
    1,  2, 4, 16, 7, 47, 0, 96, 2, 33, 5,  1, 8, 43, 3, 34, 6, 30, 
    3, 92, 6, 59, 7, 53, 4, 80, 0, 89, 8, 37, 1, 85, 2, 36, 5, 22, 
    3, 65, 4,  1, 2, 99, 7, 88, 0, 28, 5,  6, 1, 92, 8, 35, 6,  6, 
    0, 95, 3, 66, 8, 29, 7, 89, 4, 20, 5, 33, 6,  6, 2, 95, 1, 75, 
    8, 84, 7, 72, 2, 66, 4, 26, 6, 52, 1, 32, 3, 64, 5, 72, 0, 95, 
    1, 68, 6, 35, 3,  4, 2, 21, 5, 85, 0, 46, 8, 14, 4, 24, 7, 29
  };
  const int q4406[] = {
    9, 9, // Number of jobs and machines
    6, 77, 0,  2, 8, 52, 5, 52, 1, 41, 2, 10, 4, 59, 7, 40, 3,  6, 
    3, 55, 8, 73, 7, 84, 4, 95, 2, 76, 5, 16, 0, 30, 6, 85, 1, 80, 
    7, 45, 6, 21, 4, 55, 5, 30, 3, 78, 2, 39, 1, 61, 0, 12, 8, 48, 
    8, 15, 7, 23, 2, 55, 1, 67, 3, 84, 0, 33, 4, 55, 6, 81, 5, 91, 
    4, 67, 0, 40, 1, 52, 2, 71, 8, 17, 5, 47, 7, 24, 3, 99, 6, 35, 
    8, 58, 4, 91, 3, 90, 1, 95, 5, 55, 7, 93, 6, 30, 2, 46, 0, 22, 
    7, 14, 4, 85, 1, 56, 5, 16, 2, 48, 3, 63, 8, 39, 0, 26, 6, 23, 
    6,  1, 7, 70, 0,  1, 2, 54, 4, 70, 3,  9, 5, 37, 1,  6, 8, 23, 
    0, 17, 7, 42, 4, 31, 8, 27, 3, 95, 6, 51, 2,  2, 1, 59, 5, 65
  };
  const int q4407[] = {
    9, 9, // Number of jobs and machines
    8, 51, 2, 15, 6, 16, 4, 24, 5, 34, 3, 99, 7, 49, 1,  3, 0, 92, 
    0, 63, 3, 16, 4, 68, 2, 12, 6, 97, 1, 83, 7, 44, 8, 19, 5, 52, 
    2,  5, 3, 57, 5, 22, 7, 95, 6, 62, 1, 31, 0, 42, 8, 52, 4, 28, 
    5, 39, 7, 30, 6,  4, 2, 96, 4, 37, 1, 31, 3, 94, 0, 37, 8,  1, 
    7, 44, 8, 60, 0,  1, 4, 90, 5, 82, 1, 46, 2, 45, 3, 70, 6, 90, 
    6, 18, 8, 23, 4, 28, 1, 24, 5, 48, 3, 95, 7, 68, 2, 78, 0, 53, 
    2, 93, 7, 83, 0, 13, 5,  7, 6, 15, 1, 73, 4, 38, 8, 76, 3, 67, 
    6, 77, 7, 62, 2, 71, 3, 66, 5, 81, 4, 64, 8, 39, 0, 36, 1, 20, 
    3, 33, 1, 84, 2, 40, 6, 65, 5,  7, 8, 71, 4, 86, 0, 71, 7, 48
  };
  const int q4408[] = {
    9, 9, // Number of jobs and machines
    6, 65, 7, 55, 5,  5, 0, 90, 4, 62, 8, 96, 3, 52, 1, 19, 2, 46, 
    5,  5, 3, 47, 4, 77, 8, 93, 7, 34, 0, 43, 1,  3, 2, 29, 6, 41, 
    0, 76, 1, 77, 6, 25, 3, 59, 8, 32, 5, 51, 4,  5, 7, 33, 2, 65, 
    2, 81, 0, 73, 4, 73, 3, 43, 7, 62, 8, 45, 1, 34, 5, 75, 6, 80, 
    3, 55, 6, 81, 7, 57, 1, 91, 2, 65, 8,  3, 5, 73, 0, 89, 4, 34, 
    0,  5, 6, 40, 2, 86, 5, 10, 4, 97, 1, 70, 8, 81, 7, 96, 3, 53, 
    8, 34, 6, 14, 3, 94, 7, 48, 1, 18, 5, 36, 2, 13, 0,  9, 4, 89, 
    5,  7, 0, 33, 1, 89, 7, 25, 8, 12, 2,  7, 4, 94, 6, 74, 3, 36, 
    2, 53, 7, 58, 0, 45, 6, 86, 3, 85, 4, 21, 1, 85, 8, 73, 5, 31
  };
  const int q4409[] = {
    9, 9, // Number of jobs and machines
    3, 71, 8, 60, 0, 43, 1, 67, 4, 33, 7, 90, 2, 40, 5, 57, 6, 15, 
    6, 12, 1, 88, 0, 71, 2, 74, 5, 50, 8, 57, 7, 70, 3, 81, 4, 44, 
    1, 58, 0, 51, 4, 57, 7, 92, 2, 71, 6, 40, 3, 36, 5, 34, 8, 70, 
    4, 76, 7, 84, 5,  4, 2, 73, 8, 13, 1,  9, 3, 70, 6, 78, 0, 89, 
    8,  7, 7, 79, 4, 33, 6, 15, 5, 25, 1, 24, 3, 99, 0, 35, 2,  2, 
    0, 99, 8, 18, 4, 44, 1, 22, 5, 73, 6, 97, 7, 41, 2,  4, 3, 23, 
    5, 25, 0, 62, 6, 62, 2, 43, 7, 24, 4,  9, 1, 16, 8, 33, 3, 82, 
    7, 87, 5, 40, 1,  7, 2, 88, 4, 61, 6, 94, 8, 66, 0, 71, 3, 56, 
    0, 15, 4, 32, 5, 13, 3, 66, 8, 60, 1, 56, 6, 73, 7, 47, 2, 19
  };
  const int q4410[] = {
    9, 9, // Number of jobs and machines
    2, 70, 7, 92, 4, 48, 8, 65, 1, 51, 5, 73, 3, 21, 6, 77, 0, 95, 
    8, 19, 5, 87, 3, 27, 0, 11, 4, 84, 1, 11, 7, 28, 6, 47, 2, 31, 
    2,  5, 3, 42, 7, 44, 6, 58, 4, 97, 1, 28, 8, 40, 5, 93, 0, 84, 
    2, 29, 3, 58, 0, 19, 4,  5, 1, 51, 7, 72, 8, 85, 5, 26, 6, 59, 
    7, 69, 0, 64, 1, 53, 8,  8, 6,  4, 2, 19, 5, 12, 3, 57, 4, 68, 
    8, 97, 4, 25, 3, 22, 6, 62, 0,  9, 7, 79, 5, 66, 2, 67, 1, 98, 
    7, 36, 5, 26, 8, 15, 6,  3, 3,  7, 0, 53, 1,  8, 4, 12, 2,  5, 
    5, 96, 8,  9, 6, 96, 4, 29, 1, 24, 7, 40, 0, 17, 3, 65, 2, 65, 
    1, 42, 4, 50, 2, 57, 7,  6, 8, 85, 5, 11, 6, 42, 0, 67, 3, 27
  };
  const int q4411[] = {
    9, 9, // Number of jobs and machines
    4, 39, 5, 24, 6, 60, 8,  3, 2, 18, 0, 24, 3, 38, 7,  8, 1, 36, 
    6, 83, 1, 73, 7, 60, 4, 13, 5, 67, 2, 78, 0, 52, 8, 59, 3, 63, 
    4, 37, 0, 23, 1, 31, 7,  2, 3, 40, 5, 98, 8, 86, 2, 85, 6, 98, 
    3, 56, 4, 14, 8, 87, 2, 39, 7, 26, 0, 19, 6, 96, 1, 65, 5, 37, 
    4, 98, 0, 56, 7, 40, 2, 50, 3, 14, 1, 70, 6, 18, 5, 80, 8, 62, 
    4, 18, 8, 91, 5, 19, 3, 30, 1, 78, 7, 65, 0, 91, 6, 67, 2, 37, 
    2, 18, 8, 42, 4, 94, 0, 76, 6, 32, 1, 54, 3, 41, 7, 52, 5,  6, 
    1, 64, 8, 73, 4, 39, 5, 63, 7,  1, 2, 42, 0, 70, 6, 83, 3, 45, 
    0, 79, 5, 63, 3, 87, 7, 41, 4, 26, 8, 54, 6, 55, 2, 15, 1, 73
  };
  const int q4412[] = {
    9, 9, // Number of jobs and machines
    7, 99, 2, 17, 1,  6, 8, 21, 0, 87, 3, 64, 4, 36, 6, 45, 5,  2, 
    4, 65, 1, 34, 8, 83, 5, 10, 3, 46, 2, 57, 6, 95, 7, 56, 0, 22, 
    6, 63, 1, 61, 5, 67, 3, 91, 7,  6, 2, 16, 8, 63, 0, 94, 4, 55, 
    6, 49, 5, 45, 8, 12, 7, 40, 2, 25, 4, 24, 1, 21, 3, 47, 0, 25, 
    5, 55, 8, 20, 6, 78, 7,  3, 0, 76, 4, 70, 3, 39, 2, 15, 1,  7, 
    8, 51, 7, 37, 3,  4, 0, 89, 2, 53, 5, 41, 6, 86, 1,  2, 4, 47, 
    4, 98, 0, 30, 5, 70, 8, 36, 6, 83, 2, 28, 1,  2, 3, 16, 7, 14, 
    0, 54, 3, 52, 7, 54, 1,  4, 8, 22, 4, 64, 6, 10, 5, 64, 2, 21, 
    3,  1, 0, 22, 1, 65, 6, 68, 2, 59, 5, 66, 4,  6, 7, 26, 8, 95
  };
  const int q4413[] = {
    9, 9, // Number of jobs and machines
    0, 43, 5, 53, 2, 13, 3, 85, 8, 65, 7, 21, 4, 94, 6, 94, 1, 23, 
    2, 17, 6, 70, 8, 42, 0, 53, 1, 28, 7, 92, 4, 13, 3,  6, 5,  8, 
    0, 79, 4, 32, 3, 93, 8,  3, 7, 64, 1, 21, 6, 22, 5, 38, 2, 95, 
    2, 98, 8, 53, 1, 20, 3, 72, 4,  8, 6, 13, 7,  7, 0, 99, 5, 36, 
    1, 42, 0, 97, 5, 24, 3, 48, 6, 86, 7, 81, 2, 62, 4, 97, 8, 63, 
    8, 80, 5, 68, 0, 81, 1, 94, 2, 40, 7, 27, 3, 31, 6, 80, 4,  7, 
    5, 63, 0, 99, 1,  1, 6, 68, 7, 10, 4, 63, 2, 60, 8, 19, 3, 86, 
    6, 61, 2, 96, 7, 80, 4,  5, 5, 32, 3, 26, 0, 88, 1, 85, 8,  9, 
    1, 84, 7, 47, 5, 81, 8, 94, 4, 47, 6, 78, 0, 23, 3, 75, 2, 10
  };
  const int q4414[] = {
    9, 9, // Number of jobs and machines
    3, 43, 8,  7, 1, 48, 7, 38, 4, 39, 5, 51, 0, 33, 6,  7, 2, 79, 
    8, 51, 1, 35, 2, 64, 5, 92, 6, 28, 3, 45, 7, 67, 4, 21, 0, 96, 
    1,  6, 2, 44, 6, 68, 4, 71, 8, 39, 5, 55, 7, 30, 0, 75, 3, 89, 
    3, 82, 4, 55, 0, 45, 8, 57, 6, 43, 7,  1, 1, 45, 5, 84, 2, 70, 
    3, 75, 6, 38, 1, 98, 4, 37, 7, 81, 8, 78, 0, 88, 2,  3, 5, 56, 
    7,  9, 8, 36, 3, 25, 6, 75, 1, 55, 0, 23, 4, 72, 2, 90, 5, 82, 
    2,  2, 6, 93, 8, 97, 4, 10, 5, 68, 7, 59, 3, 98, 1, 69, 0, 12, 
    7, 82, 4, 94, 2, 76, 6, 47, 0, 68, 3, 50, 1, 29, 8, 46, 5, 97, 
    5, 91, 6, 73, 1, 68, 0, 78, 8, 85, 3, 62, 7, 61, 4, 81, 2, 81
  };
  const int q4415[] = {
    9, 9, // Number of jobs and machines
    4, 36, 5,  5, 1, 77, 0, 71, 7, 66, 6, 83, 2,  5, 8, 31, 3, 11, 
    1, 89, 6, 55, 8, 99, 2, 24, 5, 56, 4, 35, 3, 34, 7, 33, 0, 40, 
    7, 96, 1, 19, 5, 57, 3, 68, 2, 81, 0, 82, 8, 74, 4, 73, 6, 65, 
    2, 12, 8, 27, 4, 36, 3, 90, 1, 24, 6, 64, 7, 46, 0,  9, 5, 73, 
    6, 73, 3, 25, 4,  5, 1, 44, 8, 41, 5, 57, 7, 28, 2, 16, 0, 91, 
    3, 61, 5, 12, 1, 26, 7, 83, 0, 25, 2, 39, 8, 99, 6,  4, 4, 31, 
    2, 40, 3,  4, 0,  4, 6, 65, 4, 77, 1, 84, 5, 51, 7, 86, 8, 53, 
    1, 80, 5, 25, 2, 66, 8, 73, 0, 84, 4, 58, 7,  1, 3, 78, 6,  3, 
    6, 59, 2, 13, 1, 33, 4, 66, 5, 74, 8, 54, 7,  9, 3, 79, 0, 20
  };
  const int q4416[] = {
    9, 9, // Number of jobs and machines
    2, 23, 5, 71, 4, 97, 1, 84, 3, 92, 6, 87, 8, 64, 7, 87, 0, 99, 
    0,  6, 2, 21, 8, 71, 7, 71, 5, 51, 4, 77, 6, 53, 1, 95, 3, 50, 
    1, 58, 4, 33, 8, 40, 3, 55, 0,  4, 7, 80, 6, 33, 5, 54, 2, 74, 
    2, 36, 1, 57, 7, 76, 3, 98, 4, 55, 8, 93, 5, 48, 6, 69, 0, 22, 
    6, 27, 0, 61, 8, 90, 1, 18, 3, 82, 4, 82, 2, 56, 5, 48, 7, 56, 
    3, 16, 0, 97, 2, 83, 4, 51, 1,  6, 6, 23, 5, 20, 7, 99, 8, 13, 
    4, 83, 5, 24, 2, 46, 8, 29, 6,  8, 3, 64, 7, 12, 0, 19, 1, 16, 
    2, 66, 7, 78, 3,  7, 1, 75, 8, 71, 5, 46, 6, 19, 0, 33, 4, 72, 
    0, 56, 2, 72, 6, 58, 5, 63, 8, 22, 1, 99, 3, 87, 7, 26, 4, 78
  };
  const int q4417[] = {
    9, 9, // Number of jobs and machines
    6, 59, 2, 14, 1, 21, 8, 65, 7, 44, 4, 68, 0, 36, 5, 24, 3, 74, 
    2, 44, 1, 76, 4, 32, 3, 13, 8, 38, 6, 14, 5, 93, 0, 55, 7, 99, 
    7, 78, 0, 14, 6, 37, 3, 30, 5, 97, 1, 59, 2, 94, 8, 48, 4, 74, 
    1, 13, 7, 64, 6, 90, 3, 99, 5, 23, 8, 96, 4, 42, 2,  7, 0, 34, 
    4, 53, 0, 77, 6, 89, 1, 97, 2, 62, 3,  9, 5, 94, 7, 27, 8, 76, 
    7, 67, 6, 63, 8, 19, 1, 71, 5, 89, 2, 82, 4, 42, 3, 97, 0, 84, 
    4,  2, 0, 76, 1, 93, 5,  1, 8, 53, 2, 30, 7, 80, 6, 37, 3, 86, 
    8, 27, 4, 57, 3, 43, 7, 86, 2, 41, 6, 43, 1, 79, 0, 77, 5, 59, 
    1, 51, 8, 99, 2,  4, 4, 28, 3, 46, 6, 28, 7, 17, 5,  2, 0, 41
  };
  const int q4418[] = {
    9, 9, // Number of jobs and machines
    4, 78, 0, 66, 8,  2, 5, 82, 2, 89, 3, 22, 6, 74, 1, 22, 7, 89, 
    7, 77, 3, 84, 2, 37, 4, 44, 0, 67, 8, 57, 6, 19, 5, 53, 1, 14, 
    8,  5, 0, 96, 1, 23, 3, 84, 4, 42, 2, 81, 6, 37, 7, 47, 5, 64, 
    7,  9, 8, 64, 5, 20, 0, 45, 1,  8, 6, 33, 4, 19, 2, 70, 3, 49, 
    1, 60, 4, 23, 6, 62, 5, 38, 0, 20, 2, 11, 3, 57, 7, 98, 8, 23, 
    3, 64, 5, 93, 7, 39, 6, 98, 4, 52, 0, 78, 8, 53, 2, 67, 1, 17, 
    1, 85, 6, 64, 4, 83, 7, 74, 5, 73, 8,  6, 3, 22, 2, 44, 0, 29, 
    2, 35, 4, 34, 1, 28, 8, 76, 5, 84, 6, 96, 3, 67, 0, 26, 7, 60, 
    5, 73, 3,  8, 4, 39, 1, 27, 7, 25, 2, 71, 6, 31, 8, 85, 0, 20
  };
  const int q4419[] = {
    9, 9, // Number of jobs and machines
    2, 32, 3, 82, 5, 11, 7, 25, 4, 73, 8, 10, 1,  9, 0,  7, 6, 78, 
    3, 15, 5, 61, 1, 99, 2, 87, 6, 23, 4, 65, 0, 18, 8, 29, 7, 90, 
    4, 51, 8,  4, 1, 57, 2, 73, 6, 64, 0, 18, 3, 55, 5, 36, 7, 75, 
    5, 83, 7, 68, 8, 38, 3, 36, 4,  9, 0, 86, 2, 71, 6, 51, 1, 99, 
    3, 72, 1, 74, 7, 30, 6, 96, 5, 42, 8, 11, 0, 78, 4, 53, 2, 15, 
    5, 54, 3, 13, 2, 14, 8, 27, 1, 80, 7, 10, 6, 79, 0, 99, 4, 30, 
    1, 35, 2, 67, 7, 28, 5, 80, 0, 42, 8, 89, 3, 93, 4, 42, 6, 61, 
    2, 54, 0, 25, 5, 76, 8,  5, 4, 20, 6, 31, 3, 94, 7,  3, 1, 95, 
    3, 51, 7, 72, 6, 33, 5, 44, 0, 39, 4, 86, 8, 24, 2, 21, 1, 47
  };
  const int q4420[] = {
    9, 9, // Number of jobs and machines
    4, 11, 3, 71, 7, 12, 1, 17, 8, 24, 5, 43, 2, 37, 6, 27, 0, 33, 
    6, 92, 1, 27, 2, 14, 3, 56, 0, 38, 7, 48, 5, 56, 4, 15, 8, 68, 
    7, 50, 5, 83, 1, 92, 2, 37, 4, 37, 6, 69, 8,  3, 3, 83, 0, 77, 
    4, 32, 0, 39, 7, 72, 6, 53, 1, 77, 3, 65, 8, 79, 2, 10, 5, 65, 
    3, 65, 0, 41, 5, 40, 1, 45, 8, 12, 4, 35, 2, 28, 6, 47, 7, 91, 
    0, 10, 4, 30, 1, 30, 8, 58, 5, 23, 2, 58, 3, 15, 6, 21, 7, 13, 
    0, 64, 3, 80, 2, 60, 7, 85, 6, 89, 4, 74, 5, 57, 8, 56, 1,  3, 
    2, 76, 6, 11, 3, 51, 7, 21, 0,  3, 8, 10, 5, 81, 4, 76, 1, 67, 
    1,  1, 0, 37, 8, 64, 7, 50, 3, 80, 4, 14, 5, 40, 6, 93, 2,  8
  };
  const int q4421[] = {
    9, 9, // Number of jobs and machines
    4, 19, 3, 62, 1, 32, 6, 52, 8, 19, 2, 18, 0, 60, 7, 85, 5, 42, 
    1, 81, 4, 46, 7, 87, 2, 43, 5, 95, 3, 29, 6, 97, 0, 38, 8,  9, 
    6, 40, 3, 53, 1, 87, 4, 98, 0, 50, 7, 78, 2, 11, 5, 75, 8, 75, 
    5, 47, 7, 80, 2,  2, 3, 87, 1, 73, 8,  6, 0, 90, 4, 35, 6, 88, 
    2, 36, 6, 17, 5, 63, 8, 15, 7, 93, 1, 50, 4, 17, 0, 13, 3, 60, 
    1, 42, 4, 87, 0, 37, 2, 36, 7, 89, 3, 59, 6, 10, 5, 65, 8, 29, 
    7, 34, 4, 85, 6, 18, 3, 72, 5, 62, 1, 81, 0, 19, 2, 99, 8,  4, 
    5, 36, 7, 65, 2,  4, 3,  3, 4, 67, 1,  8, 6, 66, 0, 83, 8, 84, 
    0, 18, 2, 81, 3, 42, 8, 97, 1, 50, 7, 34, 4, 57, 6, 99, 5, 94
  };
  const int q4422[] = {
    9, 9, // Number of jobs and machines
    1, 22, 6, 46, 2, 63, 7, 98, 4, 62, 5, 10, 0, 52, 3, 80, 8, 91, 
    1, 87, 6, 62, 7, 35, 8, 19, 2, 86, 5, 54, 3,  4, 4, 77, 0, 86, 
    1, 69, 6, 92, 3,  6, 8, 64, 7, 31, 2, 29, 5, 64, 4, 93, 0, 44, 
    2, 91, 7, 78, 3, 97, 6, 48, 5, 62, 8, 27, 1, 86, 0, 54, 4, 24, 
    8, 56, 7,  8, 3, 60, 5, 30, 0,  9, 2, 73, 6, 41, 1, 61, 4, 29, 
    5, 74, 0, 33, 2, 21, 4, 94, 8, 58, 3, 99, 1, 31, 6, 84, 7, 94, 
    6,  6, 3, 85, 0, 76, 4, 75, 7, 45, 8, 22, 5, 47, 1, 77, 2, 62, 
    1, 72, 6, 33, 8, 21, 4, 99, 0, 79, 3, 30, 7, 46, 2, 34, 5, 20, 
    5, 77, 7,  9, 1, 14, 4, 51, 3, 21, 8, 97, 0, 57, 2, 67, 6, 48
  };
  const int q4423[] = {
    9, 9, // Number of jobs and machines
    3, 25, 6,  7, 5,  4, 1, 37, 7, 60, 0, 14, 8, 44, 2, 29, 4, 32, 
    0, 18, 6, 79, 7, 96, 2, 70, 1, 83, 4, 73, 8, 35, 5, 61, 3, 61, 
    7, 14, 4, 56, 5, 98, 2, 13, 1, 13, 6, 45, 0, 77, 8, 15, 3, 43, 
    7, 98, 2, 42, 1, 53, 8, 26, 5, 62, 3, 92, 0, 61, 4, 34, 6, 37, 
    4, 13, 8, 69, 6, 27, 5, 43, 7, 17, 1, 71, 2,  6, 0, 10, 3, 34, 
    4, 55, 8, 18, 3, 93, 1, 15, 6, 36, 5, 93, 0, 23, 7, 32, 2, 41, 
    8,  5, 2, 36, 7, 95, 6, 93, 1, 93, 0, 64, 5,  2, 4,  9, 3, 84, 
    5, 27, 1, 68, 3, 85, 7, 73, 4, 53, 8, 49, 2, 18, 0, 29, 6, 93, 
    2, 20, 8, 13, 0, 40, 3, 36, 1, 89, 5, 25, 7, 52, 4, 37, 6, 36
  };
  const int q4424[] = {
    9, 9, // Number of jobs and machines
    5, 61, 8,  9, 0, 16, 2,  3, 1, 96, 6, 68, 7,  3, 3,  6, 4, 62, 
    2, 65, 3, 85, 0, 77, 6, 25, 8, 93, 5, 31, 1, 30, 7,  9, 4, 14, 
    1, 52, 7, 18, 5, 67, 0, 49, 4, 96, 2, 60, 8, 86, 6, 56, 3, 78, 
    2, 35, 1, 61, 5, 21, 6, 33, 7, 38, 0, 32, 3, 31, 4, 69, 8, 21, 
    2, 36, 7, 32, 8, 36, 4, 30, 3, 46, 0, 44, 1, 25, 5, 21, 6, 93, 
    5, 63, 6, 48, 0, 66, 8, 96, 1, 82, 2, 95, 4, 83, 7, 64, 3, 95, 
    8, 29, 3, 70, 0, 41, 5, 32, 1, 69, 4, 51, 2, 94, 6, 35, 7, 27, 
    2, 41, 3, 30, 1, 17, 5, 74, 8, 79, 6, 15, 0, 52, 7, 56, 4, 55, 
    3, 66, 8, 71, 5, 90, 7, 28, 2, 42, 4, 45, 6, 93, 1, 51, 0, 34
  };
  const int q4425[] = {
    9, 9, // Number of jobs and machines
    7, 90, 5,  9, 8, 76, 0, 86, 4, 68, 6, 92, 2,  1, 3, 48, 1, 67, 
    7, 28, 1, 42, 2, 17, 6,  6, 8, 51, 3, 98, 4, 86, 0, 72, 5, 18, 
    5, 30, 8, 27, 0, 85, 4, 29, 6, 35, 3,  3, 1, 48, 7, 65, 2, 76, 
    3, 36, 6, 76, 8, 27, 0, 61, 5, 48, 7, 29, 4, 25, 2, 74, 1, 70, 
    2, 77, 7, 37, 3, 10, 8, 19, 6, 25, 5, 49, 0, 16, 1, 42, 4, 74, 
    4, 79, 2, 99, 3, 77, 8, 12, 0, 35, 7, 40, 1, 43, 6, 31, 5, 85, 
    6,  4, 4, 67, 7, 33, 2,  4, 8, 89, 0, 50, 5, 90, 3, 81, 1, 36, 
    4, 35, 8, 61, 5, 16, 3, 75, 0, 32, 6,  4, 7, 48, 1, 91, 2, 91, 
    7, 11, 0,  1, 8, 22, 2, 90, 4, 40, 6, 18, 1, 41, 5, 78, 3, 77
  };
  const int q4426[] = {
    9, 9, // Number of jobs and machines
    4, 64, 8, 38, 7,  6, 2,  4, 6, 11, 1, 86, 0, 66, 3, 79, 5, 62, 
    2, 53, 1, 25, 3, 17, 8, 36, 6, 64, 0, 41, 4, 10, 7, 88, 5, 53, 
    1, 47, 6, 47, 5, 38, 8, 11, 2, 52, 7, 60, 4, 13, 3, 55, 0, 43, 
    3, 44, 5, 85, 8, 40, 7, 49, 1, 85, 2, 25, 0, 63, 4, 77, 6, 49, 
    8, 28, 5, 77, 0, 42, 2, 61, 6, 85, 1,  3, 3, 89, 4, 43, 7, 90, 
    3, 46, 6, 72, 5, 29, 8,  5, 0, 67, 2, 70, 4, 90, 1, 21, 7, 84, 
    6, 34, 4, 93, 8, 24, 1, 59, 7, 60, 3, 86, 2, 77, 0, 86, 5, 44, 
    8,  6, 3, 74, 5, 64, 6, 48, 2, 62, 0, 62, 1, 24, 7, 20, 4, 33, 
    5, 99, 0, 58, 8, 56, 7, 56, 1, 70, 3, 79, 4, 84, 6, 75, 2, 46
  };
  const int q4427[] = {
    9, 9, // Number of jobs and machines
    0, 41, 4, 46, 5, 31, 3, 66, 8, 28, 2, 54, 6,  6, 1, 93, 7, 99, 
    7, 92, 0, 98, 8, 39, 4,  7, 6,  8, 2, 35, 3, 79, 5, 85, 1, 21, 
    8,  1, 1, 74, 6, 12, 2, 58, 5, 52, 7, 10, 0,  5, 4, 63, 3, 49, 
    2, 21, 3, 50, 5, 15, 6, 59, 0, 90, 7, 68, 8, 18, 4, 26, 1, 71, 
    0, 27, 2, 84, 1, 72, 8,  6, 5, 96, 3, 97, 6, 99, 7, 71, 4, 59, 
    2, 76, 0, 25, 1, 37, 4, 63, 5,  9, 3, 26, 8, 23, 7, 13, 6, 52, 
    2, 90, 5, 57, 8, 70, 7, 57, 6, 93, 0, 60, 3, 94, 4, 83, 1, 78, 
    2, 73, 5, 17, 7, 94, 3, 94, 4, 47, 1, 19, 0, 82, 6, 56, 8, 33, 
    7, 81, 8,  6, 3, 63, 2,  8, 6, 20, 4, 96, 5, 11, 1, 64, 0, 69
  };
  const int q4428[] = {
    9, 9, // Number of jobs and machines
    6, 45, 4,  7, 5,  1, 0, 83, 3, 79, 1, 13, 2,  4, 7, 27, 8, 27, 
    5, 86, 2, 75, 7, 78, 8, 33, 1,  6, 0, 21, 6, 39, 3, 69, 4, 21, 
    8, 18, 1, 37, 4, 99, 5, 38, 0, 19, 3, 91, 6, 73, 7, 70, 2, 78, 
    1, 68, 5, 52, 3, 40, 4, 90, 0, 90, 7, 75, 2, 34, 6,  6, 8, 87, 
    8, 23, 2,  5, 5,  1, 6, 92, 4, 36, 0, 84, 1, 29, 3, 36, 7, 74, 
    6, 27, 1, 51, 7, 40, 0, 55, 3, 80, 5, 80, 4, 39, 8, 32, 2, 40, 
    8, 48, 2, 18, 4, 54, 1, 53, 6, 27, 3, 85, 0, 66, 5, 35, 7, 81, 
    1, 79, 6, 52, 2, 95, 3, 32, 7, 61, 8, 39, 0, 72, 5, 85, 4, 64, 
    2, 28, 8, 10, 0, 10, 7, 67, 6, 75, 5, 91, 4, 37, 3, 82, 1, 78
  };
  const int q4429[] = {
    9, 9, // Number of jobs and machines
    1,  5, 5, 56, 3, 50, 6, 15, 7, 32, 0, 57, 4, 69, 8, 14, 2, 41, 
    1, 52, 2,  3, 4, 78, 8, 73, 5, 24, 3, 86, 6, 76, 0, 93, 7, 16, 
    8, 13, 4, 22, 0, 72, 3, 96, 5, 49, 7, 20, 2, 17, 1, 72, 6, 30, 
    4, 18, 5, 90, 1, 37, 6, 69, 0, 72, 7, 38, 3,  9, 8, 31, 2, 87, 
    3, 95, 8, 24, 4, 86, 1, 63, 7, 27, 5, 66, 2, 71, 6, 30, 0, 79, 
    5, 30, 8, 75, 7, 69, 1, 71, 3, 20, 6, 40, 0, 30, 2, 78, 4, 59, 
    7, 60, 5, 93, 8, 86, 3, 88, 1, 27, 2,  5, 0, 30, 6, 68, 4, 77, 
    6, 90, 3, 13, 2, 92, 1, 96, 5, 48, 8,  4, 4, 69, 0, 69, 7, 94, 
    5, 53, 4, 42, 7,  1, 0, 77, 6, 96, 8, 65, 3, 26, 1, 56, 2,  2
  };
  const int q4430[] = {
    9, 9, // Number of jobs and machines
    1, 49, 6, 67, 0, 58, 8, 52, 2, 15, 3, 91, 5, 50, 4, 98, 7, 41, 
    1, 68, 6, 84, 3, 59, 5, 32, 8, 99, 7, 45, 0, 97, 4, 12, 2, 75, 
    2, 62, 3, 41, 1, 90, 8, 43, 7, 56, 4, 93, 0, 88, 6, 91, 5, 51, 
    8, 88, 0, 40, 4, 78, 6, 39, 1, 61, 7, 63, 5, 39, 3,  7, 2, 92, 
    3, 94, 7, 12, 5,  7, 2, 24, 8, 26, 6, 70, 0, 22, 1, 48, 4, 17, 
    8, 74, 2, 43, 6, 45, 5, 97, 3, 82, 4, 12, 7, 29, 0, 71, 1, 15, 
    1,  4, 6, 45, 0, 50, 7, 44, 4, 88, 2, 60, 3,  2, 5, 89, 8, 46, 
    1, 32, 6, 54, 3,  9, 2,  4, 7, 32, 5, 93, 4, 89, 0, 79, 8, 38, 
    1, 63, 8, 64, 4, 89, 5, 27, 2,  6, 6, 74, 0, 36, 3,  6, 7, 30
  };
  const int q4431[] = {
    9, 9, // Number of jobs and machines
    4, 88, 2, 88, 5, 14, 7, 69, 3, 80, 6, 34, 0, 31, 8, 33, 1, 43, 
    7, 95, 6, 29, 1, 69, 5, 96, 2, 20, 4, 23, 3, 11, 0, 20, 8, 69, 
    4, 82, 6, 18, 1, 44, 5, 40, 2, 75, 3, 51, 7, 64, 0, 74, 8, 37, 
    1, 48, 8, 41, 5,  4, 6, 78, 0, 12, 2, 66, 4, 74, 3,  9, 7,  5, 
    2, 58, 7, 81, 1, 38, 5, 72, 4, 46, 3, 21, 6, 46, 8, 20, 0, 86, 
    3, 92, 0, 73, 5, 63, 7, 44, 6, 95, 8,  8, 2,  1, 1, 56, 4, 24, 
    2, 97, 0, 72, 8, 72, 6, 80, 5, 50, 4, 14, 3, 54, 1, 97, 7, 73, 
    2, 76, 0, 97, 6, 14, 1, 18, 3, 43, 5, 63, 7, 92, 4,  3, 8, 45, 
    6, 40, 1, 95, 5, 23, 4,  1, 8, 21, 7,  7, 3, 52, 0, 82, 2, 64
  };
  const int q4432[] = {
    9, 9, // Number of jobs and machines
    7, 39, 5, 83, 2, 27, 3, 70, 8, 67, 1, 86, 4, 50, 6, 12, 0, 74, 
    5, 73, 0, 15, 2, 98, 8, 19, 1, 31, 4,  6, 7, 65, 6, 40, 3, 79, 
    2, 10, 7, 35, 1, 78, 4, 63, 5, 74, 6, 23, 0, 50, 8, 24, 3, 73, 
    8, 75, 4, 78, 7, 31, 3, 82, 5,  7, 6, 63, 2, 16, 0, 75, 1,  1, 
    7, 22, 4, 50, 6, 40, 3, 16, 2, 28, 5, 45, 8, 49, 0, 49, 1, 66, 
    1, 53, 4,  2, 0, 89, 8, 32, 5, 20, 7, 63, 3, 53, 2, 97, 6, 76, 
    6, 37, 1, 81, 0,  7, 8, 12, 7,  5, 4, 32, 3, 86, 5, 33, 2,  6, 
    1, 73, 0,  3, 4,  3, 2, 52, 7, 58, 6, 84, 5, 75, 8, 65, 3,  2, 
    2, 67, 6, 87, 4, 73, 0, 54, 1, 19, 5, 37, 7, 91, 8, 71, 3, 20
  };
  const int q4433[] = {
    9, 9, // Number of jobs and machines
    4, 11, 2, 96, 8, 41, 7, 18, 5, 60, 3, 67, 0, 30, 6, 24, 1, 75, 
    8,  9, 6, 52, 0, 59, 5, 55, 4, 87, 7, 75, 2, 38, 3, 43, 1,  3, 
    7, 11, 4, 76, 1, 59, 8,  2, 2, 44, 5, 31, 3, 77, 0, 62, 6, 36, 
    3, 80, 0, 33, 8, 66, 2, 93, 7,  5, 4, 33, 5, 43, 1,  4, 6, 26, 
    2, 22, 8, 55, 1, 43, 7, 47, 5, 62, 4,  4, 0, 73, 3,  5, 6, 40, 
    5, 30, 7, 69, 4, 84, 3, 13, 1, 14, 6, 35, 0,  8, 8, 28, 2, 14, 
    2, 91, 8, 54, 7, 45, 6, 76, 0, 34, 3, 87, 5, 94, 1, 32, 4, 83, 
    1,  3, 6, 58, 7,  8, 2, 78, 5,  9, 4, 63, 3, 64, 0, 59, 8, 85, 
    6,  4, 7, 90, 0, 31, 3, 69, 8, 60, 5, 49, 1, 26, 2, 71, 4,  6
  };
  const int q4434[] = {
    9, 9, // Number of jobs and machines
    5, 16, 7, 29, 2, 67, 0, 52, 8, 45, 3, 25, 6, 20, 4, 80, 1,  3, 
    7, 15, 2, 66, 0, 69, 1,  5, 3, 10, 6, 59, 5,  2, 8, 75, 4, 10, 
    8, 42, 4, 53, 6, 26, 7, 37, 0, 39, 1, 98, 3, 48, 5, 57, 2, 95, 
    1, 42, 8,  3, 6, 12, 2, 67, 3, 58, 5, 12, 4, 31, 7, 84, 0, 98, 
    0, 98, 6, 69, 7, 72, 2, 72, 3, 12, 1, 18, 4, 93, 8, 21, 5, 10, 
    1, 23, 7, 92, 4, 30, 5, 11, 0, 97, 3, 41, 2, 54, 6, 71, 8, 71, 
    0, 67, 8, 51, 2, 69, 4,  2, 3, 85, 7, 12, 5, 75, 6, 79, 1, 45, 
    1, 96, 8, 97, 0, 44, 2, 85, 4, 72, 3, 46, 7, 39, 5, 20, 6, 31, 
    0, 56, 1,  8, 6,  5, 7, 68, 2,  9, 5, 98, 8, 13, 3,  8, 4, 97
  };
  const int q4435[] = {
    9, 9, // Number of jobs and machines
    1, 83, 7, 59, 6, 12, 2, 76, 3, 59, 5, 35, 4, 45, 0, 91, 8, 54, 
    3, 42, 8, 29, 4, 76, 6, 67, 5, 84, 1, 22, 2, 69, 7, 29, 0, 91, 
    8, 60, 6, 75, 1, 83, 4, 73, 0, 12, 2, 68, 7, 75, 3, 63, 5, 17, 
    6, 70, 4, 35, 2, 94, 5, 16, 1, 18, 7, 42, 3, 69, 0, 50, 8, 68, 
    7, 59, 0, 35, 8, 83, 5, 13, 3, 53, 2, 74, 6, 84, 1, 16, 4, 41, 
    5, 68, 0, 55, 4, 60, 8, 63, 3, 15, 7, 89, 1, 20, 6, 68, 2, 63, 
    2, 31, 3, 33, 6, 63, 1, 11, 7, 57, 5, 19, 4, 21, 8, 96, 0, 96, 
    7, 43, 6, 94, 3, 35, 1, 62, 0, 84, 8, 66, 4, 76, 2, 76, 5, 16, 
    3, 35, 5, 79, 1, 79, 7, 72, 0, 78, 8,  5, 6, 90, 4, 49, 2, 99
  };
  const int q4436[] = {
    9, 9, // Number of jobs and machines
    8,  4, 2, 21, 7, 52, 6, 40, 4,  9, 5, 75, 0,  8, 1, 99, 3, 20, 
    0, 44, 8, 97, 4, 18, 6, 56, 1, 88, 2, 48, 7, 96, 5, 67, 3, 73, 
    3, 80, 5, 51, 6, 76, 1, 62, 4, 86, 8, 39, 0, 56, 2, 76, 7,  1, 
    0, 40, 5, 27, 1, 39, 4, 61, 2, 96, 8,  3, 3, 50, 7, 18, 6, 75, 
    2, 70, 3, 60, 8, 37, 7, 84, 0, 77, 6, 65, 1, 36, 5, 44, 4, 97, 
    5, 14, 7, 60, 1, 28, 2, 67, 4, 60, 3, 72, 6,  8, 0, 46, 8, 57, 
    1, 12, 2, 89, 0, 14, 5, 67, 7,  7, 8, 86, 3, 46, 4, 43, 6, 40, 
    7, 29, 6, 10, 3, 85, 5, 59, 8, 98, 4, 62, 1, 47, 2, 47, 0, 64, 
    4, 91, 7, 30, 5, 28, 3, 13, 6, 80, 1, 15, 0, 29, 8, 37, 2, 12
  };
  const int q4437[] = {
    9, 9, // Number of jobs and machines
    6, 57, 1, 25, 0, 30, 2, 90, 4,  2, 7, 63, 5, 59, 3, 13, 8, 18, 
    2, 10, 1,  1, 3, 95, 5, 88, 4, 14, 8, 53, 7, 96, 0, 87, 6, 52, 
    3, 96, 5,  1, 4, 86, 6, 20, 7, 59, 0, 45, 8, 80, 2, 42, 1, 57, 
    7, 37, 6, 86, 4, 93, 1, 34, 3, 34, 2, 85, 0, 96, 8, 95, 5, 27, 
    1, 59, 6, 69, 7, 97, 2,  9, 4, 67, 5, 53, 8, 92, 0, 13, 3, 91, 
    0, 76, 5, 35, 6, 49, 8, 38, 7, 17, 3, 29, 1, 46, 4, 83, 2, 17, 
    8, 10, 6, 53, 5, 77, 4, 57, 2, 80, 1, 38, 3, 24, 0, 40, 7, 93, 
    4, 31, 7, 70, 8, 56, 5,  4, 6, 37, 2, 66, 0, 22, 1, 72, 3, 14, 
    8, 42, 6, 42, 0, 49, 2, 15, 5, 20, 1, 86, 4, 66, 3, 73, 7,  4
  };
  const int q4438[] = {
    9, 9, // Number of jobs and machines
    3, 48, 5, 24, 7, 97, 8, 50, 2, 80, 0, 29, 1,  6, 6, 37, 4, 69, 
    0, 49, 5, 51, 4, 67, 2, 69, 3, 21, 1, 52, 6,  2, 8, 48, 7, 94, 
    2,  5, 3, 54, 8,  6, 5, 60, 1, 12, 0, 82, 7, 20, 6, 38, 4, 43, 
    5, 94, 3, 43, 2, 23, 6, 25, 4, 12, 1, 37, 0, 21, 7, 31, 8,  1, 
    8,  2, 0, 36, 5, 95, 6, 97, 2, 21, 3, 82, 7, 11, 4, 82, 1, 27, 
    1, 20, 6, 51, 4, 28, 7, 87, 8, 54, 0, 58, 5, 35, 2, 22, 3, 38, 
    3, 96, 1, 86, 8,  3, 4, 54, 6, 51, 0, 24, 7, 39, 2, 23, 5, 73, 
    6, 96, 0, 72, 4, 36, 7, 95, 3, 92, 1,  5, 5, 45, 2, 18, 8, 25, 
    1, 95, 4,  4, 8, 27, 5, 59, 7, 42, 0, 70, 3, 73, 6, 47, 2, 14
  };
  const int q4439[] = {
    9, 9, // Number of jobs and machines
    6, 62, 7,  5, 5,  4, 3, 25, 0, 54, 1, 86, 2, 56, 4, 69, 8, 89, 
    7, 24, 3, 60, 1, 23, 0, 82, 8, 91, 5, 20, 6, 68, 4, 56, 2, 53, 
    0, 86, 3,  9, 5, 41, 7, 57, 6, 65, 4, 63, 1, 15, 8, 54, 2, 66, 
    4, 29, 5, 45, 3, 99, 1, 92, 7, 26, 2, 30, 6,  2, 8,  7, 0, 55, 
    0, 57, 1, 35, 4, 69, 5, 95, 7, 45, 3, 91, 6, 43, 8,  5, 2, 60, 
    3, 38, 2, 64, 5, 70, 4, 55, 8,  8, 7, 97, 1, 52, 6, 83, 0, 66, 
    1, 15, 7, 19, 3, 59, 0,  4, 6, 77, 5, 16, 2, 77, 4, 54, 8, 46, 
    4, 98, 5, 58, 6, 17, 2, 60, 8, 79, 1, 36, 7,  2, 0, 28, 3, 28, 
    5, 73, 8, 75, 4, 52, 6, 14, 1, 62, 7, 38, 0, 75, 3, 37, 2, 97
  };
  const int q4440[] = {
    9, 9, // Number of jobs and machines
    1, 70, 0,  2, 3, 25, 5, 85, 6, 25, 2, 64, 8, 25, 7, 51, 4, 96, 
    1, 23, 8, 53, 5, 57, 4, 76, 3, 74, 6, 61, 7, 58, 2, 41, 0, 46, 
    5, 22, 2, 66, 4, 36, 3, 26, 6, 64, 0,  8, 8, 96, 1, 24, 7, 70, 
    0, 16, 5, 41, 6, 47, 4, 54, 7, 81, 3, 20, 2, 45, 8, 60, 1,  3, 
    2, 11, 3, 75, 7, 31, 0, 51, 8, 17, 4,  1, 5, 53, 6, 75, 1, 80, 
    5, 92, 0, 67, 8, 93, 3,  5, 7, 59, 1, 72, 6, 38, 4, 67, 2, 87, 
    2, 91, 3, 84, 6, 13, 0, 44, 8, 94, 5, 55, 4, 13, 1, 43, 7, 72, 
    3, 19, 0, 65, 5, 79, 1, 71, 6,  5, 7, 48, 4, 14, 2, 27, 8, 47, 
    2,  2, 1, 95, 0, 54, 7, 59, 8, 46, 3, 96, 4, 33, 6, 90, 5, 51
  };
  const int q4441[] = {
    9, 9, // Number of jobs and machines
    2, 78, 0, 76, 1, 61, 8, 17, 6,  7, 7, 97, 4, 32, 5, 97, 3, 94, 
    8, 47, 1, 87, 2, 54, 3, 62, 0, 76, 6,  3, 4, 84, 5, 13, 7, 43, 
    4, 78, 8,  6, 6, 21, 5, 83, 3, 89, 7, 92, 2,  7, 0, 36, 1, 35, 
    8,  5, 5, 67, 3,  5, 2, 39, 0, 25, 7, 67, 4, 13, 1, 10, 6, 95, 
    0, 23, 3, 72, 6, 97, 4, 84, 1, 29, 2, 69, 5, 30, 8, 21, 7,  3, 
    5,  9, 1, 48, 6,  6, 4, 56, 7, 44, 2, 17, 8, 77, 0, 34, 3, 63, 
    6, 67, 8, 11, 4, 64, 5, 55, 3, 42, 1, 58, 0, 91, 7, 46, 2, 97, 
    3, 90, 8, 80, 5, 53, 7, 43, 2, 92, 4, 87, 0, 37, 1, 13, 6, 95, 
    3, 53, 0, 92, 8,  1, 4, 40, 2, 38, 1,  9, 6, 61, 5,  5, 7, 95
  };
  const int q4442[] = {
    9, 9, // Number of jobs and machines
    2, 86, 1, 21, 7, 99, 3, 67, 6, 67, 5, 88, 4, 59, 8, 68, 0, 64, 
    8, 36, 7, 74, 4, 61, 6, 57, 3, 78, 0, 48, 2, 33, 1, 42, 5, 71, 
    2, 95, 5, 40, 3, 76, 6, 74, 4, 33, 0,  1, 8,  2, 7, 48, 1, 10, 
    1, 65, 8, 70, 5, 44, 2, 40, 6, 88, 7,  6, 4, 58, 0, 62, 3, 68, 
    6, 43, 2, 45, 5, 73, 0, 93, 3,  6, 8, 34, 7, 42, 1,  6, 4, 11, 
    6, 50, 3, 24, 8, 73, 0, 15, 2, 34, 5, 16, 1, 95, 7, 91, 4, 77, 
    2, 10, 3, 58, 7, 90, 4, 49, 6, 28, 5, 91, 1, 98, 0, 45, 8, 84, 
    7, 55, 6, 29, 8, 11, 4, 70, 1, 91, 3, 20, 5, 80, 2, 97, 0,  5, 
    7, 71, 8, 69, 2, 32, 0, 49, 4, 69, 1, 88, 3,  2, 6, 28, 5, 90
  };
  const int q4443[] = {
    9, 9, // Number of jobs and machines
    4, 86, 2,  4, 5, 71, 1, 85, 8, 15, 7, 76, 0, 80, 3, 69, 6, 68, 
    7, 27, 4, 39, 3, 54, 6, 47, 0, 22, 8, 24, 1, 55, 2, 68, 5, 11, 
    5, 46, 1, 83, 0, 52, 3, 76, 6, 61, 8, 56, 2, 10, 7, 20, 4, 78, 
    3, 38, 7, 44, 8, 45, 5, 96, 6, 69, 2, 81, 0, 16, 1, 43, 4, 55, 
    0, 99, 5, 13, 6,  4, 3, 18, 4, 95, 2, 30, 8, 74, 1, 15, 7, 45, 
    4, 49, 2, 90, 0,  5, 3, 48, 5, 89, 8, 22, 6, 39, 7, 98, 1, 52, 
    0, 90, 3, 80, 4, 32, 1, 38, 7, 92, 8, 28, 2,  9, 6, 55, 5, 56, 
    0, 69, 4, 99, 2, 80, 7, 29, 1, 17, 6, 29, 3, 85, 5, 76, 8, 90, 
    3, 18, 1, 27, 8, 44, 6, 19, 4, 76, 5, 78, 0, 76, 2, 54, 7, 48
  };
  const int q4444[] = {
    9, 9, // Number of jobs and machines
    8, 67, 0,  7, 4, 80, 2, 85, 7, 81, 5, 35, 6, 67, 1, 67, 3, 85, 
    0, 57, 2, 11, 4, 66, 5, 69, 1, 67, 6, 53, 8, 53, 3, 67, 7, 40, 
    5, 64, 0, 98, 2, 65, 1, 84, 6,  6, 4, 50, 3,  4, 7, 12, 8, 65, 
    6, 80, 4, 88, 2, 85, 3, 56, 8, 73, 7, 52, 5, 64, 1, 42, 0, 33, 
    1, 47, 8, 20, 0, 66, 4, 20, 5, 72, 7, 24, 6, 67, 3, 70, 2, 23, 
    6, 66, 5, 96, 2, 87, 7, 89, 1, 57, 8, 58, 4, 81, 3, 31, 0, 51, 
    4, 91, 2, 85, 7, 12, 3,  9, 5, 79, 0,  7, 6, 83, 8, 53, 1, 20, 
    7, 32, 1, 60, 0, 95, 3, 10, 6, 16, 5, 89, 8, 38, 2, 61, 4, 13, 
    7, 19, 5,  3, 0, 35, 4, 99, 3, 13, 8, 99, 6,  6, 2, 51, 1, 24
  };
  const int q4445[] = {
    9, 9, // Number of jobs and machines
    4, 40, 3, 70, 0, 85, 6, 35, 7, 38, 5, 98, 2,  2, 1, 43, 8, 88, 
    8, 37, 4, 86, 6, 12, 2, 89, 5, 96, 0, 38, 3, 53, 7, 40, 1, 53, 
    5, 98, 7, 97, 1, 72, 2, 44, 4, 59, 3, 75, 6, 80, 0, 30, 8, 38, 
    3, 74, 2, 98, 1, 49, 0, 18, 5, 46, 4, 99, 6, 56, 8, 29, 7, 45, 
    3, 36, 4, 98, 0, 49, 6, 34, 5, 58, 1, 67, 7, 64, 8, 69, 2, 83, 
    2, 20, 0, 62, 4, 35, 3, 27, 6, 25, 8, 53, 7, 15, 1, 85, 5, 68, 
    8, 47, 4, 26, 3, 10, 1, 48, 6, 63, 2, 44, 7, 10, 5, 10, 0, 83, 
    3, 57, 1, 66, 2,  1, 4, 14, 8, 94, 5, 97, 6, 70, 0, 17, 7, 79, 
    7, 12, 0, 34, 2, 31, 4, 83, 5, 71, 6, 90, 3, 21, 1, 65, 8, 45
  };
  const int q4446[] = {
    9, 9, // Number of jobs and machines
    8, 66, 4, 48, 2, 49, 5, 53, 0,  6, 7, 19, 1,  7, 3, 16, 6, 27, 
    2, 59, 4, 52, 3, 63, 0, 70, 1, 68, 7, 29, 5, 36, 8, 19, 6, 41, 
    7, 70, 2, 32, 5,  1, 8, 67, 6,  4, 3, 25, 0, 16, 1, 93, 4, 59, 
    4, 60, 1, 25, 8, 69, 2, 14, 3, 40, 6, 69, 0, 30, 7, 91, 5, 91, 
    6, 62, 7, 72, 0, 52, 5, 67, 1, 70, 2,  5, 3, 65, 8, 82, 4,  6, 
    8, 85, 2, 38, 0, 43, 5, 34, 1, 32, 6, 50, 4, 98, 3, 72, 7, 73, 
    8, 44, 5, 87, 4, 93, 0, 88, 2,  5, 1, 97, 7, 44, 3, 64, 6, 55, 
    5, 27, 7, 12, 0, 58, 2, 75, 3, 72, 4, 15, 8, 68, 6, 17, 1, 33, 
    3, 26, 5, 41, 2, 44, 0, 95, 8, 62, 4, 64, 7, 84, 6, 82, 1, 82
  };
  const int q4447[] = {
    9, 9, // Number of jobs and machines
    0, 25, 5, 75, 3, 97, 8, 88, 6, 56, 2, 82, 7, 81, 1, 90, 4,  8, 
    5, 45, 4, 60, 1, 43, 3, 56, 8, 52, 7,  9, 2, 53, 6, 84, 0, 40, 
    1, 19, 4, 88, 6, 31, 7,  3, 8, 27, 5, 42, 2, 71, 0, 80, 3,  8, 
    7, 36, 1, 59, 3, 90, 0, 38, 2, 50, 6, 97, 5, 92, 8, 50, 4, 15, 
    1,  5, 3, 48, 5, 78, 6, 73, 0, 54, 7, 12, 4, 39, 2, 88, 8, 74, 
    0, 82, 2, 97, 3, 76, 7, 63, 5, 81, 6, 85, 4, 43, 1, 14, 8, 45, 
    4, 23, 8, 56, 7, 27, 5, 79, 3, 16, 2, 45, 0,  5, 6, 94, 1, 36, 
    5, 37, 4, 26, 1, 20, 3, 76, 7,  9, 6, 57, 0,  8, 2, 99, 8, 94, 
    0, 63, 6, 34, 3, 52, 7, 33, 8, 87, 1,  4, 4, 47, 5, 31, 2,  5
  };
  const int q4448[] = {
    9, 9, // Number of jobs and machines
    4, 62, 5, 21, 1,  4, 6, 70, 0, 29, 7, 58, 8, 27, 3, 43, 2, 23, 
    4, 96, 1, 62, 3,  1, 6, 37, 0, 55, 8, 98, 2, 37, 7,  8, 5,  4, 
    4, 80, 3, 53, 6,  8, 1, 66, 7, 93, 8, 24, 2, 60, 0, 12, 5, 36, 
    8, 12, 5, 68, 0,  3, 7, 76, 1, 72, 4, 12, 2, 60, 3, 79, 6, 91, 
    3, 16, 6, 75, 5, 86, 8, 39, 4, 27, 7, 59, 0, 65, 1, 22, 2, 32, 
    1, 50, 6,  5, 4, 19, 7, 86, 2, 38, 3, 94, 0, 92, 5, 94, 8, 50, 
    0,  3, 1, 99, 8, 86, 6, 23, 4, 51, 7, 38, 2, 36, 3, 84, 5, 58, 
    6, 83, 4, 15, 7, 25, 5, 30, 2, 60, 3, 56, 1, 83, 8, 85, 0, 28, 
    2, 51, 6, 15, 1, 41, 4, 42, 5, 15, 8, 25, 3, 50, 7, 42, 0, 41
  };
  const int q4449[] = {
    9, 9, // Number of jobs and machines
    8, 40, 0,  6, 5, 85, 4, 98, 1, 62, 7, 20, 3, 31, 2, 19, 6, 84, 
    6, 15, 7, 23, 3, 78, 0, 95, 1, 44, 4, 97, 2, 55, 5, 41, 8, 63, 
    7, 36, 4, 28, 1, 98, 3, 41, 6, 77, 8, 76, 0, 49, 2, 75, 5, 61, 
    0, 59, 1,  2, 2, 47, 6, 93, 7, 32, 3, 63, 8, 67, 4, 37, 5, 14, 
    7, 43, 2, 99, 1, 48, 0, 56, 6, 43, 5, 75, 3, 68, 8, 23, 4, 19, 
    2, 39, 7, 19, 0, 60, 8, 46, 1, 95, 3, 14, 6, 81, 4, 54, 5, 18, 
    1, 69, 7, 93, 4, 95, 5, 12, 2, 77, 3, 33, 8, 13, 6, 69, 0, 38, 
    3, 76, 4, 71, 5, 95, 0, 63, 1,  4, 2, 67, 7, 95, 8, 82, 6, 48, 
    7, 93, 5, 85, 3, 98, 4,  9, 8, 90, 0, 29, 2, 78, 1, 83, 6, 15
  };
  const int q4450[] = {
    9, 9, // Number of jobs and machines
    7, 54, 1, 51, 6, 54, 0, 17, 2, 82, 4,  1, 5, 59, 8, 45, 3, 16, 
    1, 15, 4, 19, 7, 24, 5,  1, 6,  8, 2, 41, 3, 21, 0,  4, 8,  2, 
    4,  3, 1, 82, 6, 62, 8, 64, 5, 39, 0, 24, 2, 13, 3, 42, 7, 52, 
    5, 28, 6, 95, 7, 93, 1, 14, 0, 60, 4, 67, 2, 94, 8, 38, 3,  1, 
    8,  9, 4, 39, 1, 24, 6, 62, 3,  2, 0,  4, 2, 36, 5, 38, 7, 29, 
    4, 83, 3, 23, 2, 99, 5, 37, 7, 48, 1, 34, 8, 30, 0, 56, 6, 15, 
    4, 23, 1, 45, 5, 61, 6, 67, 7, 22, 3, 34, 0, 62, 2, 19, 8, 12, 
    6, 27, 1, 69, 5, 63, 7, 13, 8, 78, 4, 83, 2, 22, 0, 27, 3, 32, 
    6, 78, 2, 16, 8, 57, 5, 19, 0, 57, 3, 55, 7, 55, 1, 92, 4, 19
  };
  const int q4451[] = {
    9, 9, // Number of jobs and machines
    2, 14, 4, 93, 1, 45, 0,  2, 5, 31, 8, 52, 7, 35, 6, 72, 3, 96, 
    1, 45, 8, 22, 6, 43, 7,  6, 3, 46, 5, 53, 4, 93, 2, 47, 0, 49, 
    6, 40, 0, 31, 3, 79, 7, 68, 5, 52, 1, 82, 8, 82, 4, 27, 2, 72, 
    6, 70, 7, 21, 3, 51, 0, 98, 2, 79, 5, 67, 1,  1, 8, 62, 4, 60, 
    4, 38, 0, 28, 5, 56, 8, 27, 1, 15, 2, 42, 3, 66, 7, 85, 6, 16, 
    1, 44, 7, 66, 4, 23, 2, 98, 8, 47, 0, 48, 6, 67, 5, 36, 3, 37, 
    1, 62, 0,  6, 2, 41, 8, 85, 7, 77, 3, 90, 5, 31, 6, 27, 4, 84, 
    8, 82, 2, 51, 0, 56, 4, 45, 6, 28, 7, 28, 1, 79, 3, 14, 5,  1, 
    3, 44, 1, 12, 7, 61, 4, 52, 5, 51, 2,  6, 6, 80, 0, 30, 8, 60
  };
  const int q4452[] = {
    9, 9, // Number of jobs and machines
    4, 83, 1, 85, 7, 66, 0, 82, 8, 88, 5, 54, 6, 12, 3, 40, 2, 14, 
    0, 77, 6, 70, 2, 97, 4, 62, 8, 97, 1, 67, 7, 47, 3, 91, 5, 79, 
    1, 48, 4,  3, 2, 45, 0,  3, 3, 59, 6, 66, 7, 59, 8, 85, 5, 63, 
    2, 91, 5, 30, 3, 98, 0, 99, 8, 97, 1, 28, 7, 12, 6, 59, 4, 72, 
    0, 98, 7, 97, 6, 79, 2, 18, 3, 79, 5, 27, 4, 86, 1,  7, 8, 41, 
    4, 49, 5, 43, 7, 61, 1, 47, 2, 67, 3, 96, 8, 25, 6, 45, 0, 92, 
    7, 43, 1, 33, 6, 11, 2, 28, 0, 40, 3, 31, 4, 30, 8, 35, 5, 31, 
    7, 59, 4, 61, 6, 32, 1, 37, 5, 71, 2, 97, 3, 97, 8, 92, 0,  3, 
    1, 61, 4, 84, 0, 23, 3, 42, 7, 35, 6, 21, 5, 24, 2, 56, 8, 43
  };
  const int q4453[] = {
    9, 9, // Number of jobs and machines
    8, 85, 3, 29, 1, 45, 5, 60, 4, 84, 0, 98, 2, 15, 7, 43, 6, 98, 
    0, 53, 3, 74, 5, 96, 7, 95, 2, 57, 1, 87, 8,  4, 6, 88, 4, 37, 
    8,  1, 6, 11, 2, 95, 7, 48, 0, 18, 5, 28, 3, 62, 4, 94, 1,  4, 
    5, 82, 4, 85, 8, 21, 6, 54, 2, 32, 3, 18, 0, 62, 7, 22, 1, 41, 
    8, 71, 7, 67, 6, 42, 1, 56, 5, 24, 2, 95, 4, 52, 3, 32, 0, 85, 
    2, 14, 1, 72, 8, 82, 5, 39, 4, 90, 6, 51, 3, 92, 0, 95, 7, 87, 
    3, 40, 6, 22, 8, 83, 4, 20, 7, 36, 5, 56, 2, 55, 0, 16, 1, 90, 
    6, 89, 7, 23, 5, 15, 4,  8, 3, 54, 8, 20, 1, 16, 0, 71, 2, 53, 
    0, 81, 1,  7, 2, 59, 8, 31, 5, 62, 7, 97, 6, 71, 3,  5, 4, 39
  };
  const int q4454[] = {
    9, 9, // Number of jobs and machines
    6, 79, 7, 39, 2, 54, 5, 71, 8, 63, 0, 42, 1, 97, 4, 17, 3, 62, 
    8, 88, 7, 42, 3, 60, 1,  8, 6, 16, 2, 99, 5, 53, 0, 18, 4,  4, 
    4, 57, 2, 73, 8, 18, 0, 21, 3,  6, 5, 74, 1, 47, 7, 27, 6, 98, 
    4,  5, 8, 56, 6, 27, 0, 36, 7, 60, 5, 84, 3, 39, 2, 25, 1, 77, 
    8, 79, 6,  9, 5, 93, 2, 58, 7, 84, 3,  2, 1, 64, 0, 30, 4, 44, 
    6, 13, 3, 61, 8, 59, 4, 72, 0,  6, 1, 67, 7, 51, 2, 37, 5,  9, 
    6, 62, 8, 99, 2, 95, 0, 44, 7, 91, 1, 50, 3, 25, 4, 62, 5, 93, 
    0, 75, 7, 57, 5, 43, 2, 97, 6, 55, 8, 43, 4, 67, 3, 24, 1, 19, 
    7, 92, 3,  2, 0, 27, 4, 35, 2, 55, 8, 84, 5, 92, 6, 65, 1, 97
  };
  const int q4455[] = {
    9, 9, // Number of jobs and machines
    0,  5, 1, 79, 2, 84, 4, 45, 5, 17, 6,  6, 3, 42, 8, 33, 7,  9, 
    7, 34, 6, 10, 0, 22, 4, 26, 2, 21, 1, 77, 3, 43, 5, 13, 8, 68, 
    6, 89, 3, 94, 2, 91, 7, 35, 4, 70, 0, 66, 5, 51, 8, 19, 1, 49, 
    3, 51, 6, 42, 4, 91, 5, 96, 8, 55, 1,  6, 7, 32, 2, 57, 0, 45, 
    1, 39, 0, 13, 2, 66, 3, 85, 8, 33, 7, 65, 6, 21, 5, 63, 4, 47, 
    3, 10, 0, 67, 4, 15, 2, 31, 5, 39, 7,  1, 8, 65, 6, 83, 1, 69, 
    5, 80, 7, 78, 6, 45, 4, 89, 3, 92, 2,  8, 0,  3, 8, 13, 1, 94, 
    4, 55, 0,  3, 5, 87, 7,  1, 3, 39, 8, 68, 1,  2, 6, 91, 2, 85, 
    1, 50, 4,  6, 2,  8, 6, 74, 8, 67, 5, 54, 0, 33, 7, 41, 3,  4
  };
  const int q4456[] = {
    9, 9, // Number of jobs and machines
    0, 66, 5, 74, 8, 55, 6, 20, 3, 44, 1, 55, 7, 19, 4, 65, 2, 40, 
    0,  1, 5, 15, 1, 54, 7, 48, 2, 41, 3, 82, 8, 51, 4, 89, 6, 68, 
    8, 13, 7,  2, 2, 35, 0, 75, 4, 49, 1, 32, 5, 39, 3, 17, 6,  1, 
    3, 38, 0,  2, 4, 19, 1, 79, 7, 89, 6, 23, 5, 98, 8, 75, 2, 80, 
    6, 49, 4, 13, 7, 17, 2,  4, 3, 63, 8, 13, 5, 11, 1, 98, 0,  6, 
    5, 25, 8, 59, 0, 72, 4, 87, 1, 35, 3, 51, 6, 31, 7, 76, 2, 47, 
    4, 18, 0, 53, 5, 73, 2, 24, 3, 56, 8,  1, 1, 16, 7, 65, 6, 88, 
    1, 51, 3, 86, 7, 91, 4, 81, 6, 90, 5, 85, 0, 24, 8, 19, 2, 37, 
    1, 27, 0, 10, 4, 50, 8, 54, 5, 92, 2, 68, 7, 41, 3, 83, 6, 35
  };
  const int q4457[] = {
    9, 9, // Number of jobs and machines
    6, 32, 4, 87, 5, 65, 7,  2, 2, 78, 0, 68, 1, 33, 3, 76, 8, 85, 
    7, 72, 0, 97, 5, 36, 2, 55, 3, 32, 4, 79, 6, 65, 1, 69, 8,  8, 
    2, 93, 5, 85, 7, 45, 4, 49, 6, 89, 3, 91, 0, 40, 8,  2, 1, 85, 
    7,  9, 4,  9, 3, 82, 1, 87, 5, 48, 0, 91, 8, 90, 2, 79, 6,  8, 
    8, 78, 4, 63, 0, 69, 3, 16, 7, 64, 1, 50, 5, 90, 6, 41, 2, 42, 
    2, 33, 8, 27, 1, 70, 7,  6, 6, 50, 0, 42, 3, 38, 4, 53, 5, 87, 
    5, 25, 8, 27, 7, 35, 4, 35, 2, 73, 6, 58, 3, 22, 1, 97, 0, 28, 
    5, 61, 4, 16, 2, 76, 8, 29, 1, 21, 6, 86, 3, 23, 7,  2, 0, 44, 
    3, 19, 1, 92, 0, 84, 8, 55, 4, 25, 2, 93, 6, 45, 5, 76, 7,  1
  };
  const int q4458[] = {
    9, 9, // Number of jobs and machines
    2,  2, 1, 94, 6, 70, 3, 57, 5,  6, 4, 51, 8, 93, 7, 49, 0, 85, 
    7,  9, 0, 27, 6, 32, 3, 31, 8, 10, 2, 12, 5, 71, 1, 81, 4, 64, 
    3, 21, 4, 53, 2, 78, 7, 63, 6, 95, 5, 56, 0, 62, 1, 28, 8, 53, 
    4, 66, 0, 74, 1, 69, 2, 65, 7, 52, 5, 15, 3, 59, 8, 49, 6, 60, 
    2, 24, 0, 45, 6, 41, 8, 40, 5, 96, 3, 49, 7, 48, 1, 93, 4, 29, 
    8, 72, 2, 10, 3, 81, 1, 63, 0, 63, 5, 27, 7, 78, 4, 50, 6, 13, 
    3,  8, 5, 96, 8, 10, 2, 46, 1, 43, 7, 74, 4, 78, 0, 85, 6, 26, 
    0, 50, 5, 21, 3,  1, 1, 10, 2, 39, 8, 63, 6, 92, 4,  2, 7, 56, 
    0, 23, 8, 39, 5, 13, 1, 41, 6, 15, 4, 53, 7, 44, 2, 33, 3, 58
  };
  const int q4459[] = {
    9, 9, // Number of jobs and machines
    2, 86, 6, 52, 0, 40, 7, 51, 5, 75, 8, 58, 4, 69, 3, 84, 1, 71, 
    2, 27, 8,  8, 0, 86, 7, 78, 1, 20, 4, 93, 6, 10, 5, 71, 3, 43, 
    6, 90, 5, 61, 1, 37, 8, 15, 3, 83, 4, 52, 0, 16, 7,  3, 2, 61, 
    5, 72, 8, 19, 4, 23, 7, 53, 3, 73, 6, 20, 2, 16, 0, 53, 1, 21, 
    4, 59, 8, 49, 3, 36, 2, 63, 6,  4, 1,  7, 5, 45, 7, 96, 0, 55, 
    2,  5, 0, 37, 1, 37, 7, 29, 8, 99, 6, 91, 3, 58, 5, 36, 4, 81, 
    7, 84, 1, 45, 4, 59, 2, 46, 3, 30, 0, 35, 6, 96, 8, 27, 5, 51, 
    8, 75, 2, 89, 3, 12, 6, 68, 4, 72, 5, 97, 1, 35, 7, 62, 0, 79, 
    0, 29, 7, 87, 6, 16, 1, 22, 5, 89, 3, 86, 2, 66, 8, 94, 4, 89
  };
  const int q4460[] = {
    9, 9, // Number of jobs and machines
    1,  2, 6, 30, 7, 39, 4, 54, 3, 70, 2, 26, 8, 82, 5, 60, 0, 19, 
    3, 84, 8, 56, 4, 22, 1, 29, 6, 29, 5, 58, 2,  6, 0, 77, 7, 90, 
    3, 64, 0, 87, 8, 99, 2, 26, 1, 20, 6, 37, 5, 36, 4, 34, 7, 16, 
    0, 51, 1, 24, 5, 42, 2, 92, 7, 98, 4, 23, 6, 17, 3, 98, 8, 14, 
    3, 86, 7, 31, 1, 28, 8, 45, 5, 27, 6, 42, 2, 57, 4,  1, 0, 25, 
    3, 92, 7, 52, 6, 76, 5, 28, 1, 20, 8, 41, 2, 26, 4, 53, 0,  6, 
    5, 70, 1, 78, 3, 16, 4, 95, 2, 53, 7, 15, 0, 70, 8, 53, 6, 89, 
    1, 26, 7, 98, 3, 53, 6, 79, 4, 20, 8, 74, 5, 27, 0, 17, 2, 13, 
    7, 28, 3, 46, 1, 82, 2, 23, 6, 92, 4, 52, 8,  2, 5, 60, 0, 37
  };
  const int q4461[] = {
    9, 9, // Number of jobs and machines
    5, 58, 7,  1, 2, 84, 8, 53, 3, 89, 6, 15, 0, 48, 4, 40, 1, 47, 
    8, 62, 0, 58, 4,  3, 5, 98, 2, 62, 3, 67, 6, 99, 7, 63, 1, 24, 
    6, 83, 3, 79, 1, 27, 7, 80, 4,  1, 0, 43, 8, 86, 2, 25, 5, 24, 
    6,  5, 0, 57, 2, 96, 7, 17, 5, 83, 3, 25, 4, 34, 1, 10, 8, 56, 
    3, 60, 0, 15, 7, 59, 6,  3, 4, 79, 5, 93, 2, 44, 1, 18, 8, 92, 
    2, 83, 5, 41, 3, 71, 0, 84, 8, 83, 6, 25, 4, 90, 1, 35, 7, 91, 
    6, 59, 3, 57, 8, 91, 1, 93, 4, 54, 2, 49, 5, 70, 0, 20, 7, 57, 
    4, 27, 6, 56, 7, 16, 0, 62, 3, 79, 5, 25, 2, 78, 1, 36, 8, 41, 
    4, 77, 1, 51, 0, 34, 3, 26, 7, 20, 6, 33, 5, 53, 2, 18, 8, 34
  };
  const int q4462[] = {
    9, 9, // Number of jobs and machines
    6, 27, 0, 31, 8, 94, 3, 35, 5, 50, 1, 13, 7,  2, 2, 96, 4, 98, 
    1,  7, 0, 29, 6, 55, 3, 15, 4, 87, 2, 25, 7, 16, 5, 66, 8, 14, 
    4, 86, 6, 91, 3, 47, 1, 46, 8, 87, 7, 58, 2, 15, 0,  1, 5, 80, 
    5, 48, 4, 54, 7, 75, 2, 20, 1, 47, 0, 85, 8, 92, 3, 56, 6, 14, 
    4, 64, 7, 88, 8, 59, 6, 62, 0, 63, 3, 78, 5, 59, 2, 15, 1, 66, 
    3, 36, 8, 27, 2, 30, 4, 73, 0, 41, 5, 34, 6, 62, 1, 58, 7, 72, 
    1, 34, 8, 43, 6, 36, 7, 60, 2, 16, 4, 47, 0, 77, 5, 82, 3, 59, 
    6, 74, 0, 76, 4, 75, 1, 36, 7, 42, 8, 87, 2, 10, 3, 75, 5, 26, 
    1, 25, 3, 58, 8, 54, 0, 31, 2, 24, 5, 89, 6, 97, 7, 26, 4, 85
  };
  const int q4463[] = {
    9, 9, // Number of jobs and machines
    5, 86, 3, 79, 1, 92, 8, 44, 2, 41, 4, 89, 7, 98, 6, 23, 0, 70, 
    1, 93, 6, 55, 2, 97, 0, 72, 5, 66, 3, 59, 4,  1, 8, 64, 7, 61, 
    7, 62, 2,  2, 8, 61, 4, 22, 3, 46, 0,  1, 5, 46, 6, 56, 1, 42, 
    0, 51, 5, 40, 8, 96, 4, 69, 2, 77, 1,  8, 7, 21, 3, 74, 6,  4, 
    2, 55, 4, 63, 8, 64, 0, 16, 6, 77, 3, 69, 7, 92, 5,  2, 1, 69, 
    0, 38, 4, 50, 3, 91, 1, 74, 5,  7, 7, 42, 2, 14, 6, 60, 8, 49, 
    1, 10, 2, 89, 6, 95, 5, 74, 0, 51, 4, 67, 7, 19, 3, 18, 8, 98, 
    7, 33, 6, 59, 1, 26, 3, 53, 0, 43, 4, 30, 2, 53, 8, 47, 5, 71, 
    5, 41, 0, 53, 2, 18, 4,  5, 3, 39, 6, 77, 8, 33, 1, 16, 7, 23
  };
  const int q4464[] = {
    9, 9, // Number of jobs and machines
    1, 36, 0,  3, 7, 91, 4, 97, 8, 16, 3,  1, 2, 25, 5, 97, 6, 18, 
    5, 67, 4, 41, 0, 24, 3, 67, 8, 88, 1, 72, 6, 86, 7, 94, 2, 74, 
    1, 56, 4, 81, 5, 18, 8,  6, 7, 32, 2, 89, 3, 98, 6, 40, 0, 94, 
    6, 52, 5,  4, 8, 58, 2, 10, 7,  7, 4, 64, 1, 38, 0, 61, 3, 52, 
    3, 98, 2, 27, 8,  2, 7,  7, 1, 82, 4,  7, 5, 72, 0, 22, 6, 70, 
    5, 59, 8, 32, 0, 73, 4, 96, 6, 55, 1, 36, 2, 33, 7, 85, 3, 72, 
    3, 57, 7, 70, 0, 88, 1,  4, 8, 22, 6, 27, 5, 19, 4, 66, 2, 91, 
    1,  9, 8, 47, 0, 21, 3,  9, 2, 52, 6, 81, 5,  5, 7, 24, 4, 47, 
    7, 47, 5, 41, 0, 80, 8, 54, 3, 49, 6, 91, 1, 52, 4, 59, 2,  3
  };
  const int q4465[] = {
    9, 9, // Number of jobs and machines
    2, 91, 7, 55, 8, 44, 0, 91, 6, 75, 1, 85, 5,  8, 3, 46, 4, 17, 
    2, 93, 7, 71, 4, 91, 0,  3, 3, 39, 5, 85, 1, 29, 6, 65, 8, 24, 
    0,  6, 4, 55, 2, 76, 1, 24, 5, 65, 3, 64, 8, 71, 6, 98, 7, 26, 
    3, 50, 0, 22, 4, 17, 7, 25, 8, 22, 1, 78, 2, 67, 5, 42, 6,  2, 
    3, 64, 6, 34, 4, 68, 8, 42, 5, 17, 2, 19, 0,  6, 1, 79, 7, 21, 
    8, 86, 4, 30, 1, 59, 2, 26, 5, 68, 6, 54, 7, 81, 3, 11, 0, 88, 
    1, 43, 5,  4, 4, 27, 2, 49, 3,  8, 8, 25, 7, 78, 0, 42, 6, 53, 
    4, 20, 5, 23, 8, 71, 6, 71, 0, 81, 1, 91, 2, 69, 7, 39, 3, 81, 
    4, 67, 8, 58, 7, 21, 1, 75, 0, 19, 5, 81, 2, 73, 6, 71, 3, 54
  };
  const int q4466[] = {
    9, 9, // Number of jobs and machines
    5, 39, 3, 71, 4, 35, 6, 77, 8, 45, 1, 78, 0, 14, 7, 68, 2, 61, 
    8,  4, 5, 70, 4,  9, 6, 82, 3, 90, 1, 14, 7, 86, 2, 53, 0,  6, 
    3, 17, 0, 26, 5, 58, 8, 96, 4, 49, 2, 93, 1, 67, 6, 10, 7, 12, 
    3, 45, 7, 59, 5, 22, 1, 50, 6,  1, 0, 37, 8, 93, 2,  1, 4, 92, 
    8,  5, 4, 86, 1, 85, 0, 60, 6, 10, 7, 54, 5,  5, 3, 80, 2, 62, 
    3, 46, 6, 33, 2, 35, 1, 66, 4, 80, 5, 31, 0, 94, 8, 41, 7, 41, 
    3, 82, 1, 70, 2, 46, 5, 95, 8,  3, 4, 84, 0, 42, 6, 85, 7, 38, 
    2, 34, 6, 36, 0, 51, 4, 93, 1, 17, 5, 29, 8, 44, 7, 50, 3, 56, 
    6, 82, 3, 29, 7, 58, 0, 97, 5, 85, 1, 79, 8,  7, 4,  1, 2, 88
  };
  const int q4467[] = {
    9, 9, // Number of jobs and machines
    5, 68, 2, 95, 7, 29, 8,  4, 1, 64, 4, 92, 0, 24, 3, 92, 6, 64, 
    5, 42, 6, 55, 0, 44, 1, 77, 3, 54, 8, 88, 2, 42, 4, 27, 7, 54, 
    8, 45, 3, 42, 5, 50, 4, 61, 2, 25, 7, 54, 0, 82, 1, 45, 6, 24, 
    3, 80, 2, 75, 0, 83, 4, 53, 5, 35, 7, 51, 1, 82, 8, 69, 6, 75, 
    3, 85, 1, 63, 0, 50, 5,  2, 7, 20, 6, 90, 2, 47, 4, 16, 8, 78, 
    5, 80, 3, 91, 2, 71, 0, 94, 1,  8, 7, 86, 6, 95, 4,  7, 8, 15, 
    7, 57, 3,  3, 2, 57, 1, 54, 6, 92, 5, 35, 8, 98, 4, 93, 0, 58, 
    8, 40, 7, 60, 5, 96, 4, 12, 3, 37, 2, 46, 1, 53, 0, 21, 6, 77, 
    3, 50, 2, 57, 0, 80, 4, 48, 6, 15, 5, 40, 8, 49, 1,  8, 7, 68
  };
  const int q4468[] = {
    9, 9, // Number of jobs and machines
    3, 80, 5, 44, 7, 94, 0, 83, 8, 57, 6, 20, 4, 53, 2, 78, 1, 43, 
    1, 26, 5,  3, 0, 22, 4, 70, 6, 91, 8, 76, 3, 54, 7, 35, 2, 70, 
    0, 20, 8, 77, 5, 37, 1, 65, 2, 39, 3, 93, 7, 68, 4, 75, 6, 20, 
    5, 70, 0, 86, 1, 30, 4, 94, 7, 84, 8, 76, 6,  3, 2, 83, 3, 69, 
    3, 19, 7, 82, 2, 28, 5, 47, 1, 56, 0, 94, 8, 59, 4, 78, 6, 42, 
    7,  8, 5, 55, 1, 21, 3, 56, 0, 27, 8, 62, 2, 59, 6,  5, 4, 83, 
    1, 53, 8, 81, 7, 51, 2, 34, 0,  7, 3,  9, 5, 48, 6, 60, 4, 87, 
    8, 93, 2, 53, 0, 23, 4, 25, 5,  3, 7, 68, 6, 24, 3, 35, 1, 15, 
    4, 69, 2, 34, 3, 31, 8, 97, 5, 97, 1,  8, 7, 29, 0, 94, 6, 70
  };
  const int q4469[] = {
    9, 9, // Number of jobs and machines
    0, 38, 8, 47, 5, 86, 3, 42, 6, 98, 4, 48, 7,  8, 1,  9, 2, 73, 
    6, 66, 3, 49, 7, 25, 2, 78, 5, 15, 0, 23, 1, 59, 4, 56, 8, 11, 
    1, 29, 5, 49, 4, 16, 0, 15, 7, 14, 2, 68, 3, 73, 8, 38, 6, 54, 
    6, 48, 4, 74, 7, 59, 8, 89, 3, 77, 1, 81, 0, 54, 5, 15, 2, 94, 
    7, 78, 0, 63, 2, 27, 3, 22, 8, 88, 5, 68, 4, 19, 6, 97, 1, 64, 
    5, 62, 4,  8, 1, 90, 6, 80, 3, 88, 0, 88, 2, 28, 8, 84, 7, 88, 
    0, 87, 5, 75, 1, 32, 7, 56, 4, 94, 6, 59, 8, 55, 2, 65, 3, 35, 
    0, 90, 4, 65, 6, 14, 1, 42, 7, 32, 8, 26, 3, 25, 2, 26, 5, 12, 
    6, 49, 4, 84, 1, 40, 7, 22, 0, 18, 3, 41, 5, 96, 2, 36, 8, 89
  };
  const int q4470[] = {
    9, 9, // Number of jobs and machines
    3, 79, 4, 67, 7, 49, 6, 85, 0, 54, 5, 16, 2, 91, 8, 60, 1, 31, 
    5, 40, 1, 11, 7,  8, 6, 50, 2, 44, 8, 22, 4,  7, 3, 25, 0, 92, 
    0, 66, 3, 99, 5, 17, 7, 69, 8, 26, 4, 52, 1, 94, 2, 61, 6, 11, 
    6, 96, 0,  1, 1, 12, 7, 36, 4, 70, 5, 53, 2, 82, 3, 54, 8,  1, 
    2, 37, 6, 19, 8, 15, 5, 69, 0, 60, 1, 87, 3, 54, 7, 97, 4, 65, 
    5,  6, 3, 89, 7, 74, 0, 56, 8, 59, 4, 81, 1,  8, 6, 88, 2, 16, 
    4, 12, 3, 62, 7, 56, 8, 81, 2, 60, 5, 56, 0, 35, 1, 78, 6, 45, 
    7, 77, 8, 95, 5, 69, 4, 30, 2, 15, 3, 57, 6, 71, 1, 27, 0, 52, 
    6, 95, 0, 60, 5, 76, 1, 42, 4, 68, 3, 12, 8, 34, 2, 55, 7, 55
  };
  const int q4471[] = {
    9, 9, // Number of jobs and machines
    2, 91, 0, 42, 4, 23, 3, 22, 1, 11, 8,  7, 5, 36, 6, 80, 7, 76, 
    5, 48, 1, 52, 7, 32, 6, 90, 0, 97, 3,  4, 8, 88, 4, 22, 2, 63, 
    4,  9, 0, 41, 6, 50, 3, 19, 5, 94, 2, 72, 7,  5, 1, 23, 8, 14, 
    2, 36, 7, 11, 5, 53, 3, 11, 6, 78, 1,  1, 4, 35, 0, 40, 8, 37, 
    2, 42, 6, 76, 7, 33, 8, 53, 1, 75, 4, 57, 5, 46, 3, 47, 0, 53, 
    5, 61, 4, 47, 7, 23, 2, 96, 0, 69, 1, 89, 8, 90, 6, 96, 3, 69, 
    3, 54, 4, 82, 5, 95, 6,  3, 7, 69, 0, 69, 1, 83, 8,  8, 2, 17, 
    0, 33, 2, 10, 4, 52, 3, 90, 8, 64, 7, 45, 5, 41, 1, 12, 6, 18, 
    7, 79, 6, 44, 1, 96, 0, 51, 8, 63, 3,  6, 5, 82, 4, 13, 2, 58
  };
  const int q4472[] = {
    9, 9, // Number of jobs and machines
    5, 92, 4,  5, 6, 33, 2, 59, 7, 85, 3, 53, 1, 21, 0, 44, 8,  8, 
    7, 64, 3, 23, 1, 12, 0, 90, 5, 25, 4, 90, 6, 36, 8, 19, 2, 18, 
    8, 59, 1, 15, 7, 29, 0, 32, 5, 29, 4, 60, 2, 49, 3, 74, 6, 79, 
    2, 51, 1, 19, 6, 89, 4, 32, 5, 41, 8, 25, 0, 15, 3, 20, 7, 85, 
    3, 36, 8, 72, 5, 81, 0, 42, 7, 79, 2, 68, 1, 69, 4, 39, 6, 62, 
    8, 29, 5, 58, 4, 64, 3, 19, 1, 34, 2, 99, 6, 14, 7, 78, 0, 69, 
    8, 81, 4, 55, 6, 77, 3, 29, 0, 76, 7, 53, 5, 98, 1, 90, 2, 35, 
    4, 73, 2,  4, 1, 81, 3, 90, 6, 76, 5, 77, 7, 63, 0, 47, 8, 73, 
    8, 85, 2, 79, 5, 61, 3,  6, 6, 13, 0, 15, 7,  3, 4,  1, 1, 59
  };
  const int q4473[] = {
    9, 9, // Number of jobs and machines
    8, 87, 6,  3, 0, 82, 1, 24, 2, 48, 5, 61, 3, 10, 4, 57, 7, 98, 
    1, 24, 2, 12, 8, 69, 6, 53, 0, 56, 4, 34, 7, 40, 5, 74, 3, 61, 
    3, 10, 0, 19, 6, 48, 7, 22, 5, 22, 1, 56, 8, 53, 4, 72, 2, 59, 
    7, 20, 3, 73, 6, 70, 5, 92, 8, 59, 2, 23, 4, 36, 0, 34, 1, 50, 
    5, 49, 6, 22, 0, 98, 3, 40, 1, 81, 7, 48, 8, 81, 4, 58, 2, 70, 
    4, 78, 6, 42, 5, 32, 1, 90, 3, 62, 7, 76, 0, 57, 8, 71, 2, 72, 
    0, 59, 7, 23, 6, 58, 4, 73, 1, 73, 8, 33, 3,  5, 2, 78, 5, 86, 
    8, 79, 7, 29, 2, 42, 0, 27, 4, 21, 3, 89, 5,  7, 6, 94, 1, 83, 
    0, 94, 3, 81, 4, 72, 8, 37, 5, 11, 6, 81, 7, 54, 1, 54, 2,  2
  };
  const int q4474[] = {
    9, 9, // Number of jobs and machines
    6, 92, 8, 37, 3,  6, 4, 84, 5, 22, 1, 58, 2, 58, 0, 59, 7,  3, 
    6, 20, 4, 80, 2, 79, 3, 96, 1, 86, 8, 86, 0,  1, 5, 71, 7,  5, 
    4, 52, 1, 14, 6, 45, 0, 59, 8, 81, 2, 75, 5, 60, 7, 16, 3, 71, 
    7, 86, 3, 70, 6, 77, 4, 75, 5, 68, 1,  3, 0, 90, 8, 89, 2, 43, 
    4, 41, 5, 26, 7, 28, 8, 77, 6, 95, 2, 39, 3, 94, 0, 71, 1, 25, 
    7, 66, 3, 93, 8, 75, 5, 86, 6, 43, 4, 69, 2, 34, 1, 42, 0, 61, 
    3, 21, 5, 30, 8,  2, 0,  9, 4,  7, 1, 94, 2, 38, 7, 47, 6, 46, 
    0,  8, 4, 92, 1, 49, 8, 63, 5, 90, 2, 26, 3, 53, 7,  6, 6, 53, 
    4, 62, 5, 29, 7, 73, 1, 87, 2, 83, 8, 28, 3,  6, 0, 37, 6, 86
  };
  const int q4475[] = {
    9, 9, // Number of jobs and machines
    7, 99, 3, 24, 2, 37, 8, 80, 0, 98, 6, 78, 1, 88, 4, 34, 5, 89, 
    4, 83, 2, 57, 1, 27, 0, 42, 5, 95, 3, 85, 6, 35, 8, 51, 7, 39, 
    2, 91, 3, 24, 7, 97, 8, 26, 1, 63, 5, 76, 0, 73, 4, 36, 6, 24, 
    4, 83, 8, 95, 2, 15, 1, 33, 7, 49, 5, 10, 6, 97, 3, 27, 0, 96, 
    6, 50, 8, 54, 1, 35, 5, 48, 2, 18, 0,  2, 3, 51, 7, 43, 4, 67, 
    5, 18, 8,  9, 2, 65, 6, 66, 3, 69, 7, 53, 1, 67, 0, 91, 4, 20, 
    4, 87, 5, 54, 6,  7, 8, 91, 7, 79, 0, 54, 2, 71, 3, 70, 1, 49, 
    8, 59, 6, 69, 3, 99, 4, 53, 5, 72, 7, 85, 2, 50, 1, 75, 0, 27, 
    8, 58, 2, 29, 5, 29, 4, 96, 3, 78, 6, 84, 0, 69, 7, 39, 1, 65
  };
  const int q4476[] = {
    9, 9, // Number of jobs and machines
    3, 61, 5, 81, 6, 98, 4, 61, 0, 35, 8, 85, 7, 94, 1, 15, 2, 90, 
    0, 92, 1, 59, 7,  3, 3, 61, 6, 43, 5, 75, 2, 99, 4, 87, 8,  6, 
    1, 51, 6,  3, 8, 18, 0, 29, 3, 41, 2, 37, 7, 91, 5, 49, 4, 13, 
    5, 99, 7, 25, 3, 22, 6,  9, 0, 77, 4, 37, 8, 76, 2, 73, 1, 16, 
    4, 45, 0,  9, 7,  7, 8, 73, 2, 58, 6, 44, 1, 98, 5, 59, 3, 89, 
    1, 69, 2, 18, 4, 28, 0, 33, 7, 77, 3, 32, 5, 74, 6, 13, 8, 53, 
    2, 67, 5, 42, 0, 50, 1,  8, 6, 96, 8, 50, 7, 57, 3,  5, 4, 35, 
    8, 48, 5, 27, 1,  9, 2, 62, 3, 97, 4, 36, 0, 39, 6,  1, 7, 11, 
    1, 30, 8, 81, 4, 68, 2, 50, 5, 21, 3,  2, 7, 65, 0, 83, 6,  5
  };
  const int q4477[] = {
    9, 9, // Number of jobs and machines
    6, 18, 4, 13, 5, 54, 0, 65, 3, 67, 7, 23, 2, 27, 1, 20, 8, 13, 
    4, 54, 3, 53, 2, 54, 6, 39, 8, 70, 7, 16, 5, 22, 1, 22, 0, 27, 
    5, 38, 1, 96, 4,  1, 6, 48, 2, 35, 8, 45, 7, 90, 3, 87, 0, 98, 
    2,  9, 1, 54, 5, 54, 8,  4, 3, 57, 7, 45, 6, 93, 0, 21, 4, 31, 
    3, 71, 1, 16, 5,  3, 7, 32, 2, 51, 6, 27, 4, 14, 0, 12, 8, 93, 
    2, 40, 6, 65, 1,  9, 0, 50, 7, 96, 3,  9, 5, 92, 8, 53, 4, 50, 
    7, 53, 8, 81, 4, 97, 2, 51, 3, 52, 5, 79, 0, 68, 6, 21, 1, 98, 
    0, 58, 4, 67, 2, 25, 7, 48, 5, 44, 8, 78, 1, 67, 3, 98, 6, 20, 
    4,  2, 5, 14, 1, 66, 2, 76, 0, 16, 7, 17, 6, 77, 3, 28, 8, 21
  };
  const int q4478[] = {
    9, 9, // Number of jobs and machines
    7, 18, 4, 20, 5, 16, 0,  4, 8, 84, 3, 47, 6, 32, 2, 60, 1, 93, 
    4, 60, 2, 16, 0, 17, 8, 39, 5, 22, 1, 33, 7, 87, 6,  7, 3, 22, 
    0, 12, 8, 45, 2, 82, 5, 46, 4, 41, 7, 87, 3, 22, 6, 11, 1, 61, 
    2, 29, 1, 22, 4, 58, 0, 48, 7, 22, 6, 14, 8, 51, 3,  3, 5, 62, 
    2,  1, 0, 10, 1, 59, 8, 56, 3, 57, 5, 71, 7, 81, 4, 24, 6, 62, 
    0, 65, 7, 70, 8, 64, 2, 13, 6, 68, 5, 98, 3, 60, 1, 61, 4, 77, 
    3, 52, 2,  9, 4, 84, 1, 43, 7, 27, 8, 64, 5, 76, 0, 95, 6, 25, 
    7, 77, 5, 88, 4, 42, 0, 65, 3, 14, 8, 79, 2, 59, 1, 47, 6, 25, 
    0, 65, 2, 29, 1,  8, 3, 55, 6,  8, 8, 44, 4, 48, 7, 52, 5, 25
  };
  const int q4479[] = {
    9, 9, // Number of jobs and machines
    2, 19, 8, 18, 7, 51, 5, 29, 0, 52, 6, 23, 4, 98, 3, 48, 1, 48, 
    0, 64, 4, 29, 8,  3, 1,  7, 5, 90, 7, 71, 2, 61, 6, 78, 3, 99, 
    4, 21, 0, 41, 1, 38, 6, 30, 8, 49, 2, 99, 7, 82, 3, 91, 5, 88, 
    8, 86, 7, 77, 1, 79, 4, 80, 3, 52, 0, 98, 5, 34, 2, 82, 6, 86, 
    1, 98, 0, 80, 5, 66, 8,  5, 6, 53, 3, 66, 7, 88, 2, 43, 4, 50, 
    3, 60, 4, 65, 0, 81, 1, 57, 6, 14, 7, 56, 8, 18, 2, 92, 5, 35, 
    0, 57, 5, 32, 1, 27, 6, 66, 2, 52, 8, 94, 4, 32, 3, 41, 7, 87, 
    6, 91, 7,  7, 4, 38, 2, 12, 5, 43, 3, 17, 1, 15, 0, 80, 8, 40, 
    7,  4, 0, 85, 3, 45, 5,  8, 6, 80, 8, 10, 1,  3, 2, 63, 4, 44
  };
  const int q4480[] = {
    9, 9, // Number of jobs and machines
    0, 22, 7, 70, 1, 56, 3, 72, 5, 46, 2, 32, 6, 81, 8, 42, 4, 22, 
    0, 31, 8, 96, 4, 14, 1,  1, 3, 94, 7, 92, 2, 45, 5, 23, 6, 60, 
    7, 66, 2, 70, 6, 56, 3, 75, 8, 80, 4, 55, 1, 97, 5, 70, 0,  6, 
    2, 34, 1, 37, 7, 74, 8, 83, 0, 55, 4, 44, 6, 67, 3, 96, 5,  7, 
    8, 27, 6, 15, 5, 42, 0, 87, 4, 69, 7, 72, 3, 27, 2, 37, 1, 30, 
    2,  7, 6, 79, 3,  5, 7, 74, 1,  1, 5, 44, 0, 19, 4, 50, 8, 35, 
    1, 44, 5, 75, 8, 93, 0,  8, 2, 31, 7, 39, 6, 47, 4, 13, 3, 41, 
    5, 96, 4, 19, 2, 11, 7, 46, 0, 76, 8, 44, 3, 53, 6, 26, 1, 87, 
    5,  5, 1, 10, 2, 88, 0, 91, 6, 34, 7,  8, 3, 88, 8, 94, 4,  5
  };
  const int q4481[] = {
    9, 9, // Number of jobs and machines
    4, 17, 5, 12, 0, 19, 3, 59, 6, 14, 7, 12, 1, 45, 8, 73, 2, 73, 
    4, 86, 6, 48, 7, 67, 8, 97, 5, 15, 2, 59, 3,  7, 1, 34, 0, 48, 
    3, 98, 2, 65, 8, 86, 1, 91, 0, 73, 5, 99, 4,  2, 6, 94, 7, 40, 
    7, 12, 3, 68, 8, 23, 2, 67, 4, 82, 0, 74, 6,  6, 1, 94, 5, 87, 
    8,  8, 3, 59, 2, 65, 5, 12, 1, 47, 4, 77, 7, 79, 6, 17, 0, 69, 
    7, 68, 2, 37, 8, 89, 0, 84, 6,  3, 4, 92, 5, 50, 3, 84, 1, 25, 
    2, 40, 7, 91, 8, 68, 5, 47, 4, 29, 0, 26, 1, 61, 3, 40, 6, 94, 
    2, 59, 8, 94, 1, 34, 5, 85, 6, 39, 0, 76, 3, 58, 4, 59, 7, 82, 
    7, 43, 2, 18, 5, 37, 4, 92, 3, 82, 0, 78, 1, 89, 8, 50, 6, 76
  };
  const int q4482[] = {
    9, 9, // Number of jobs and machines
    2, 47, 8, 78, 5, 96, 0, 85, 3, 10, 6, 68, 7, 32, 4, 75, 1, 61, 
    5, 61, 0, 88, 1, 24, 7, 51, 2, 93, 6, 49, 8, 20, 3, 61, 4, 45, 
    0,  2, 3, 13, 8, 27, 4, 15, 5, 99, 1, 90, 6, 14, 2, 12, 7, 61, 
    6, 11, 5, 48, 0, 56, 4, 26, 3, 27, 7, 25, 2, 62, 1,  5, 8, 75, 
    6, 58, 3, 20, 0, 91, 7, 17, 8, 90, 1, 29, 2, 95, 5, 24, 4, 47, 
    5, 68, 0, 28, 2, 15, 8, 43, 7, 63, 4, 27, 1, 85, 6, 22, 3, 11, 
    4, 39, 1, 20, 5, 17, 2, 45, 6, 85, 7, 23, 8, 39, 0, 91, 3, 88, 
    8, 23, 7,  2, 4, 91, 3,  1, 2, 48, 5,  9, 6, 39, 1, 74, 0, 37, 
    5, 81, 4, 28, 3, 81, 2, 66, 7, 65, 1, 85, 8, 59, 6, 57, 0, 94
  };
  const int q4483[] = {
    9, 9, // Number of jobs and machines
    6, 65, 1,  5, 2, 29, 3, 16, 7, 25, 5, 28, 0, 49, 4, 33, 8, 30, 
    1, 64, 3, 15, 0, 84, 7, 58, 2, 91, 4, 68, 6, 77, 5, 51, 8, 54, 
    6, 94, 4, 64, 2,  6, 5, 38, 0, 22, 3, 18, 1, 13, 7, 62, 8, 37, 
    7, 11, 6, 74, 5, 18, 1, 41, 4, 48, 8, 67, 2, 82, 0, 23, 3, 29, 
    4, 69, 8, 95, 1,  8, 5, 51, 7, 84, 6, 69, 3, 95, 0, 24, 2, 70, 
    4, 42, 6, 59, 8, 68, 5, 50, 3, 42, 7, 66, 2, 94, 0, 34, 1, 73, 
    0, 61, 5, 82, 2, 35, 7, 88, 4, 44, 6, 15, 8, 85, 1, 71, 3, 54, 
    2, 40, 7, 66, 3, 71, 0, 25, 6, 24, 4, 63, 1, 34, 5,  3, 8, 37, 
    8, 44, 0, 57, 5, 18, 6, 92, 4, 17, 2, 68, 1, 49, 3, 31, 7, 17
  };
  const int q4484[] = {
    9, 9, // Number of jobs and machines
    3,  6, 1, 71, 0, 64, 5, 86, 2, 59, 6,  7, 8,  1, 4, 19, 7, 94, 
    0, 71, 8, 91, 2, 17, 5, 52, 6, 82, 7, 18, 1, 45, 3, 35, 4, 67, 
    3, 72, 5, 77, 7, 62, 4, 39, 6, 55, 0, 98, 1, 40, 2, 35, 8, 67, 
    8, 84, 0, 17, 7, 74, 3, 76, 4, 68, 2, 40, 5, 96, 6,  2, 1, 53, 
    8, 17, 3, 88, 6, 29, 5, 71, 1, 20, 7, 40, 0, 79, 2, 35, 4, 12, 
    5, 37, 8, 17, 7, 84, 6, 57, 0, 23, 3,  6, 1, 76, 4, 76, 2, 20, 
    5, 99, 7, 49, 8, 52, 6, 18, 3, 15, 1, 62, 2, 92, 4, 74, 0, 11, 
    2, 89, 7, 83, 8, 66, 5, 63, 3, 72, 0, 13, 1, 53, 6, 71, 4, 78, 
    3, 54, 4, 14, 6,  8, 1, 17, 8, 59, 2, 46, 0, 96, 5, 22, 7, 29
  };
  const int q4485[] = {
    9, 9, // Number of jobs and machines
    8, 46, 4, 49, 0, 53, 6, 44, 7, 84, 2, 30, 1,  7, 5, 85, 3, 83, 
    3, 47, 0, 99, 7, 47, 5, 27, 1, 69, 6, 37, 4, 67, 8, 47, 2, 48, 
    4, 14, 7, 23, 1, 11, 0, 74, 8, 39, 5, 52, 2,  5, 6, 34, 3, 30, 
    5, 93, 2, 28, 1, 49, 4, 24, 0, 76, 8, 36, 6, 95, 3, 33, 7, 68, 
    8, 63, 1, 75, 2, 77, 5, 71, 7, 43, 6, 71, 4, 94, 0,  9, 3, 71, 
    2, 29, 3, 99, 1, 62, 8, 90, 6, 63, 4, 42, 5, 16, 0, 77, 7, 70, 
    5, 66, 7, 86, 8, 76, 4, 59, 0, 30, 6, 56, 3, 83, 2, 79, 1, 90, 
    8, 30, 3, 11, 0, 89, 7, 86, 6, 67, 1, 52, 2, 42, 5, 68, 4, 76, 
    3, 97, 5, 48, 7, 52, 4, 86, 8, 82, 2, 90, 0, 90, 1, 20, 6,  6
  };
  const int q4486[] = {
    9, 9, // Number of jobs and machines
    0, 63, 3, 28, 5, 12, 8, 46, 6, 53, 2, 81, 1, 59, 7, 34, 4,  5, 
    8,  5, 4, 65, 7, 53, 1, 71, 5, 78, 2, 91, 3, 21, 0, 21, 6, 44, 
    7, 71, 6, 97, 8, 90, 0, 61, 1, 85, 2, 98, 4, 61, 5,  6, 3, 85, 
    8, 52, 6, 57, 1, 91, 2, 17, 3, 32, 0, 59, 7, 98, 4,  1, 5, 97, 
    1, 47, 6, 16, 4, 59, 3,  7, 2, 21, 0, 88, 7, 78, 8, 71, 5, 98, 
    3, 86, 7, 88, 5, 63, 1, 45, 0, 92, 2, 56, 4, 73, 8, 19, 6, 62, 
    0, 62, 2, 97, 7, 23, 5, 81, 8, 60, 3, 57, 6, 11, 1, 26, 4, 52, 
    6, 70, 1, 16, 8, 94, 2, 42, 4, 63, 7, 51, 5, 97, 3, 72, 0, 17, 
    7, 45, 2, 56, 5, 73, 4, 54, 0, 53, 3, 34, 8, 91, 1, 34, 6, 33
  };
  const int q4487[] = {
    9, 9, // Number of jobs and machines
    5, 36, 8, 77, 3, 32, 2, 16, 7, 30, 4, 85, 1, 90, 0,  2, 6, 43, 
    0, 22, 5, 35, 6, 44, 3, 89, 7,  6, 1,  6, 2, 40, 4, 27, 8, 34, 
    0, 45, 6, 28, 7, 19, 1, 12, 4,  7, 2, 36, 5, 76, 3, 68, 8, 63, 
    6, 50, 2,  1, 0, 39, 8, 65, 5, 47, 7, 99, 4, 65, 3, 95, 1, 74, 
    7, 82, 0, 23, 8, 77, 4, 13, 5, 30, 2, 69, 1, 46, 3, 81, 6, 57, 
    7, 44, 0, 56, 3, 23, 2, 57, 4, 92, 8,  5, 1, 37, 6, 95, 5, 11, 
    7, 26, 6,  2, 0, 98, 5, 21, 2, 62, 3, 24, 8, 71, 1, 98, 4,  3, 
    6,  3, 4, 12, 1,  3, 7, 57, 8,  4, 3, 95, 2, 57, 0, 78, 5,  6, 
    1, 83, 2, 66, 8, 46, 7, 96, 3, 81, 6, 98, 4, 12, 5,  4, 0, 60
  };
  const int q4488[] = {
    9, 9, // Number of jobs and machines
    1, 10, 7, 10, 4, 33, 2, 96, 3, 86, 8, 96, 0, 66, 6, 39, 5, 23, 
    4, 95, 6, 78, 2, 26, 3, 45, 0, 51, 1, 17, 7, 12, 5, 54, 8, 20, 
    6, 43, 8, 32, 5, 14, 3, 63, 7, 49, 1, 34, 2, 63, 4, 45, 0, 50, 
    8, 10, 6, 35, 7,  7, 3, 50, 2,  8, 1, 47, 0,  1, 5, 75, 4, 47, 
    1, 93, 6, 89, 2, 21, 5, 21, 8, 75, 0,  9, 4,  9, 7, 86, 3,  6, 
    4, 72, 0, 34, 5, 22, 3, 13, 8, 72, 7, 74, 2, 21, 6, 60, 1, 11, 
    0, 67, 1,  1, 3, 21, 5, 25, 7, 89, 4, 85, 2, 36, 8, 82, 6, 89, 
    4, 56, 1, 90, 8, 74, 0, 93, 3, 19, 2, 13, 6, 53, 7, 85, 5,  1, 
    8, 14, 1, 41, 6, 51, 0, 28, 7, 41, 4, 97, 5, 17, 3, 86, 2, 98
  };
  const int q4489[] = {
    9, 9, // Number of jobs and machines
    3, 39, 7, 57, 1, 51, 2, 44, 5, 39, 8, 79, 6, 53, 4,  3, 0, 80, 
    8, 36, 6, 17, 1, 79, 2, 10, 5, 70, 0, 71, 7, 67, 4, 36, 3, 84, 
    4, 66, 1, 73, 3, 72, 6, 65, 2, 51, 7, 82, 8, 21, 0, 27, 5, 83, 
    5, 31, 4, 41, 0, 12, 2, 46, 3, 40, 7,  5, 8, 21, 1, 62, 6,  7, 
    8, 49, 6, 54, 3, 56, 2, 28, 0, 41, 5, 35, 1, 25, 7, 33, 4, 21, 
    8, 86, 5, 84, 6, 14, 1, 16, 2, 27, 7, 58, 0, 17, 4, 68, 3, 44, 
    0, 84, 4, 31, 5,  6, 3, 76, 6, 64, 2,  2, 1, 42, 8, 22, 7, 46, 
    1, 74, 3, 67, 4, 65, 6, 44, 8, 88, 5, 95, 0,  4, 7, 80, 2, 64, 
    5, 24, 2, 79, 0, 59, 4, 30, 8, 19, 7, 98, 3, 15, 1, 46, 6, 78
  };
  const int q4490[] = {
    9, 9, // Number of jobs and machines
    2,  2, 5, 42, 3, 81, 1, 84, 4, 81, 6,  8, 0, 52, 8,  3, 7, 91, 
    2, 29, 4,  5, 7, 44, 1, 21, 5, 48, 6, 78, 3, 15, 8, 23, 0,  9, 
    7, 38, 5, 62, 1, 76, 4, 44, 6, 16, 0, 87, 3, 54, 8, 78, 2, 34, 
    5, 94, 3, 73, 2, 11, 7, 31, 8, 34, 0, 55, 1, 42, 4, 61, 6, 92, 
    6, 53, 0,  1, 4, 43, 5, 99, 1, 33, 2, 60, 3, 58, 7, 15, 8, 85, 
    5, 86, 7, 42, 3, 71, 0, 82, 8, 66, 4, 50, 6, 71, 2, 34, 1,  4, 
    6, 71, 2, 32, 7, 37, 1, 64, 3, 20, 4, 30, 8, 63, 5, 99, 0, 76, 
    5,  2, 8, 39, 3, 53, 4, 21, 2, 52, 0, 63, 1, 55, 6, 46, 7, 93, 
    3, 23, 0, 67, 8, 17, 4, 35, 2, 52, 6, 92, 7, 10, 1, 62, 5, 10
  };
  const int q4491[] = {
    9, 9, // Number of jobs and machines
    8, 97, 6, 78, 1, 83, 5, 95, 4, 95, 0,  3, 3, 17, 2, 70, 7, 98, 
    5, 83, 8, 97, 3, 54, 2, 28, 6, 28, 0, 19, 7, 45, 4, 32, 1, 72, 
    2, 72, 8, 33, 3, 54, 5, 36, 4, 31, 6, 63, 0, 74, 7, 37, 1, 40, 
    1, 66, 4, 63, 5, 44, 7, 28, 3, 74, 0, 31, 8,  7, 6, 24, 2, 35, 
    2, 62, 5, 62, 1, 96, 0, 76, 8, 35, 4, 21, 3, 28, 7, 97, 6, 69, 
    6, 61, 7, 76, 4, 98, 3,  8, 5, 70, 2, 36, 8, 54, 1, 22, 0,  5, 
    2,  5, 7, 59, 1, 39, 0, 18, 4, 30, 3, 10, 8, 35, 6, 59, 5, 12, 
    7,  5, 5, 36, 2, 78, 1, 74, 0, 96, 6, 87, 4, 30, 8, 29, 3, 41, 
    2, 69, 0, 12, 6, 85, 5,  9, 8, 36, 4, 46, 1, 46, 7, 54, 3, 54
  };
  const int q4492[] = {
    9, 9, // Number of jobs and machines
    1,  5, 0, 70, 2, 54, 7, 30, 4,  9, 5,  1, 3, 17, 6, 91, 8, 51, 
    1, 49, 6, 34, 7, 14, 8, 31, 5, 75, 2,  3, 0, 10, 3, 63, 4, 52, 
    2, 38, 7, 62, 0, 69, 5, 17, 8, 98, 4, 83, 6, 20, 1, 43, 3, 65, 
    5, 18, 0, 22, 1,  8, 7, 23, 4, 37, 3, 36, 2, 83, 8, 17, 6, 55, 
    7, 77, 3, 49, 2, 37, 1, 34, 0, 14, 6, 65, 8, 40, 4, 17, 5, 21, 
    4, 57, 1, 50, 0,  2, 3, 42, 5, 68, 2, 50, 8, 50, 7, 14, 6, 47, 
    3, 53, 8, 48, 7, 16, 4, 30, 2, 21, 6, 10, 1, 97, 5, 38, 0, 58, 
    3, 15, 6, 77, 2,  1, 7, 58, 0, 10, 5,  9, 1, 67, 4, 83, 8, 72, 
    1,  3, 7, 20, 8, 76, 4,  3, 5, 78, 3, 51, 0, 23, 2, 24, 6, 65
  };
  const int q4493[] = {
    9, 9, // Number of jobs and machines
    2, 23, 5, 20, 6, 21, 0, 98, 8, 36, 4,  5, 7, 69, 1, 37, 3, 89, 
    2, 44, 1, 66, 5, 15, 7, 86, 8, 83, 0, 21, 4, 24, 6, 67, 3, 42, 
    1, 70, 5, 10, 8, 64, 0, 31, 2, 78, 4, 37, 7, 64, 6, 94, 3, 70, 
    1,  6, 0, 55, 4, 28, 5, 52, 8, 77, 2, 28, 7, 86, 6, 29, 3,  3, 
    6, 60, 4, 59, 5, 77, 0, 95, 7, 15, 3, 31, 8, 46, 1, 66, 2, 17, 
    2, 24, 5, 92, 6, 97, 7, 19, 1, 25, 3, 94, 0, 14, 8, 77, 4, 73, 
    3, 45, 0, 82, 6, 43, 4, 65, 2,  5, 5, 55, 1, 36, 7, 22, 8, 25, 
    4, 47, 3, 32, 5,  5, 8, 21, 2, 19, 6, 21, 1, 32, 7, 33, 0, 89, 
    3, 20, 7, 20, 6, 32, 1, 52, 2, 31, 5,  5, 8, 92, 0, 24, 4, 40
  };
  const int q4494[] = {
    9, 9, // Number of jobs and machines
    2, 94, 7, 15, 0, 87, 5, 81, 3, 65, 8, 82, 1, 59, 6, 48, 4, 90, 
    2, 43, 1, 95, 6, 73, 0,  6, 5, 44, 3, 18, 8, 67, 4, 27, 7, 97, 
    2, 12, 3, 30, 4, 38, 1, 51, 0, 96, 5, 42, 8, 32, 6, 42, 7,  5, 
    7, 41, 2, 34, 8, 88, 1, 37, 0, 14, 5, 49, 4, 59, 3, 36, 6, 87, 
    3, 34, 7, 51, 6, 64, 4, 67, 1, 56, 0, 64, 5, 54, 2, 59, 8, 71, 
    7, 47, 0, 35, 5, 27, 8, 44, 2, 80, 1, 44, 4, 61, 3,  6, 6,  5, 
    1, 61, 5, 21, 4, 28, 7, 75, 0, 52, 3, 53, 6, 93, 2, 62, 8, 73, 
    5, 38, 2, 54, 1, 36, 8, 57, 6, 21, 4, 82, 3, 29, 7, 57, 0, 94, 
    6, 98, 8, 59, 1, 33, 7, 28, 2, 65, 3, 25, 4, 39, 0,  7, 5, 32
  };
  const int q4495[] = {
    9, 9, // Number of jobs and machines
    0, 22, 4, 13, 6,  5, 7, 72, 8, 65, 3, 86, 1,  5, 2, 27, 5, 85, 
    2, 36, 3, 87, 0, 71, 1, 75, 5, 36, 7, 87, 8, 91, 4, 84, 6, 63, 
    6, 39, 3, 13, 7, 21, 1, 60, 4,  7, 5, 90, 8, 57, 0, 67, 2, 49, 
    7, 13, 5, 71, 0, 15, 2, 17, 8, 41, 6, 14, 1, 17, 3, 97, 4, 93, 
    8, 58, 0, 31, 5, 61, 3, 89, 2, 83, 1, 74, 6, 64, 7, 42, 4, 19, 
    2, 32, 5, 29, 3, 41, 7, 25, 4, 22, 0, 12, 8, 89, 6, 67, 1, 92, 
    5, 39, 1, 15, 6, 73, 4, 57, 0, 92, 8, 42, 7, 14, 3, 69, 2, 53, 
    5, 43, 6, 20, 4, 89, 8, 10, 1, 27, 0, 27, 2, 82, 3, 21, 7, 55, 
    3, 66, 8, 82, 4, 96, 6,  5, 0, 30, 2, 87, 1, 74, 5, 68, 7, 61
  };
  const int q4496[] = {
    9, 9, // Number of jobs and machines
    3, 94, 5, 14, 1, 15, 2, 12, 8, 25, 7, 62, 0, 42, 6, 31, 4, 60, 
    5,  7, 6, 30, 4, 23, 8, 34, 1, 24, 3, 56, 2, 46, 7, 78, 0, 50, 
    6, 89, 8, 84, 4,  1, 1, 28, 2, 21, 0, 85, 3,  1, 5, 52, 7, 62, 
    3, 82, 7, 30, 6, 92, 5, 72, 8, 46, 1, 58, 2, 94, 0, 88, 4, 92, 
    7, 14, 8, 75, 2, 80, 6, 10, 3, 13, 4, 64, 0, 72, 1,  3, 5, 35, 
    7, 27, 4, 60, 1, 51, 2, 84, 0, 25, 6, 62, 5, 16, 3, 96, 8, 36, 
    1, 12, 8, 64, 5, 99, 6, 54, 7,  2, 4, 65, 3, 75, 0, 89, 2, 62, 
    5, 19, 0, 33, 2, 90, 1, 66, 6, 63, 4, 67, 3, 70, 7, 48, 8, 34, 
    2, 26, 4, 67, 0, 72, 1, 78, 5, 54, 7, 35, 8, 72, 3, 99, 6,  6
  };
  const int q4497[] = {
    9, 9, // Number of jobs and machines
    3, 91, 7, 72, 5, 95, 8, 41, 1, 92, 0, 79, 2, 43, 6, 70, 4, 43, 
    2, 88, 3,  8, 4, 17, 5,  8, 0, 57, 7, 26, 1,  9, 8, 48, 6, 14, 
    5,  2, 6, 30, 4, 23, 3, 53, 2, 71, 1, 99, 0, 18, 7, 41, 8, 80, 
    2, 43, 8, 43, 3, 45, 7, 24, 6, 79, 1, 73, 4, 93, 5, 22, 0, 67, 
    7, 55, 4, 74, 5, 17, 2, 20, 8, 31, 0, 30, 3, 50, 1, 80, 6, 26, 
    5, 61, 8,  2, 6,  4, 4, 34, 2, 67, 0, 60, 7, 11, 3, 90, 1, 13, 
    8, 62, 2, 96, 0, 62, 4, 33, 3, 50, 7, 12, 1, 58, 6, 13, 5, 20, 
    5, 68, 3, 79, 8, 88, 1,  3, 4, 94, 0, 53, 6, 28, 2, 99, 7, 51, 
    6,  6, 3,  1, 8, 64, 7, 27, 5, 75, 0, 20, 1, 75, 4, 21, 2, 33
  };
  const int q4498[] = {
    9, 9, // Number of jobs and machines
    2, 46, 1,  2, 5, 49, 6, 83, 4, 92, 3, 82, 0, 97, 8, 32, 7, 93, 
    3, 46, 1, 53, 4, 63, 6,  9, 7,  4, 2, 98, 0, 66, 8,  1, 5, 25, 
    7,  9, 1, 49, 8, 36, 4, 32, 2, 22, 5, 64, 3, 93, 0, 62, 6, 13, 
    0, 21, 8, 23, 5, 49, 4, 33, 6, 95, 3, 88, 2, 36, 7, 69, 1, 48, 
    6, 89, 7, 22, 4, 24, 0, 10, 5, 17, 8,  5, 3, 64, 1, 43, 2,  2, 
    1, 46, 6, 42, 7, 34, 5, 95, 2, 16, 3, 60, 0, 59, 4, 44, 8, 56, 
    8, 84, 0, 28, 3, 47, 1, 33, 5, 59, 6, 78, 4, 55, 2, 15, 7, 91, 
    3, 41, 0, 44, 2, 11, 8, 43, 6, 33, 5, 27, 4, 67, 1, 85, 7, 77, 
    0, 81, 8, 71, 2, 69, 5, 62, 3, 94, 1, 85, 4, 38, 7, 85, 6, 59
  };
  const int q4499[] = {
    9, 9, // Number of jobs and machines
    5, 40, 0, 67, 3, 52, 8,  6, 4, 36, 7, 54, 6, 45, 1,  2, 2, 13, 
    7, 46, 1, 80, 2, 94, 5, 80, 6, 93, 0, 38, 4, 98, 8, 56, 3, 13, 
    6, 95, 7, 68, 3, 74, 4, 76, 2,  6, 0,  7, 8, 85, 1,  3, 5, 33, 
    6, 89, 1, 91, 8, 63, 7, 58, 5, 28, 4, 29, 3, 23, 2, 24, 0, 57, 
    7, 58, 5, 28, 3, 48, 8, 97, 0, 50, 2, 60, 4, 60, 1, 99, 6, 45, 
    0, 53, 3, 50, 2, 69, 6, 32, 7, 97, 8, 30, 4, 56, 5, 87, 1, 51, 
    2, 94, 0, 33, 7, 50, 3, 74, 5, 19, 1, 69, 6, 35, 4, 25, 8, 89, 
    2, 77, 0, 14, 1, 97, 5, 86, 3, 61, 8, 68, 4, 12, 7, 88, 6, 75, 
    3, 99, 1, 81, 6, 29, 8,  5, 5, 91, 2, 86, 4, 67, 7, 27, 0, 77
  };
  const int q4500[] = {
    9, 9, // Number of jobs and machines
    6, 29, 4, 49, 5, 18, 0, 79, 2, 44, 7, 77, 8, 11, 3, 15, 1, 24, 
    2, 15, 8, 51, 7, 29, 5, 90, 6, 38, 1, 68, 3, 24, 4, 49, 0,  2, 
    5, 19, 8, 44, 1, 18, 4, 67, 7, 98, 6, 72, 2,  1, 0, 89, 3, 73, 
    3, 92, 0, 12, 7, 45, 2, 46, 4, 68, 1, 24, 6, 12, 8, 63, 5, 67, 
    2, 33, 1, 30, 6, 10, 0, 41, 8, 31, 3, 84, 4, 47, 7, 69, 5, 84, 
    5, 79, 3, 49, 4, 49, 7, 79, 8, 71, 1, 57, 6, 80, 2, 51, 0, 70, 
    0, 15, 2, 66, 1, 50, 5, 91, 6, 81, 4, 43, 7, 12, 3, 23, 8, 16, 
    2, 53, 8, 69, 4, 24, 5, 62, 1, 86, 6, 19, 3, 69, 7, 59, 0, 25, 
    7, 57, 3, 41, 2, 25, 0, 76, 8, 37, 1, 13, 4, 73, 5, 23, 6, 14
  };
  const int q4501[] = {
    9, 9, // Number of jobs and machines
    2, 72, 1, 61, 8, 62, 3, 92, 7, 68, 4, 39, 5, 42, 0, 33, 6, 77, 
    0, 28, 4, 53, 7, 96, 2, 91, 1, 14, 5, 15, 3, 34, 6, 52, 8, 19, 
    2, 73, 1, 52, 3, 39, 8, 89, 0,  3, 5, 51, 7,  1, 4, 15, 6, 45, 
    7, 66, 0, 69, 4, 33, 5, 29, 2, 84, 6, 23, 1,  8, 8, 90, 3, 57, 
    0, 29, 8, 42, 4, 15, 5, 64, 2, 76, 1, 56, 3, 20, 7, 42, 6,  9, 
    4, 87, 3, 80, 6, 83, 5, 72, 7, 11, 2, 16, 0, 66, 8,  2, 1, 60, 
    1, 73, 3, 73, 2, 55, 7, 29, 6, 62, 5, 16, 8, 92, 0, 52, 4, 66, 
    0, 64, 4, 11, 1, 78, 8, 51, 7, 82, 6, 69, 5, 59, 3,  8, 2, 25, 
    4, 85, 8, 60, 7,  2, 2, 80, 0, 90, 3, 41, 5, 43, 1,  9, 6, 23
  };
  const int q4502[] = {
    9, 9, // Number of jobs and machines
    3, 39, 2, 22, 7, 81, 0, 95, 4,  9, 6, 96, 1, 45, 5, 61, 8, 61, 
    0, 94, 6, 62, 7, 25, 8,  6, 4, 72, 2, 76, 5, 43, 3, 37, 1, 97, 
    4, 18, 5,  2, 7, 84, 0, 16, 1, 51, 3, 74, 2, 26, 8, 35, 6, 50, 
    3, 85, 5, 10, 2, 93, 0, 85, 4, 62, 7, 66, 1, 12, 6, 20, 8, 46, 
    6,  2, 5, 70, 2, 58, 4, 85, 0, 62, 8, 36, 3, 72, 7, 19, 1, 55, 
    8, 79, 7, 50, 6, 25, 5, 21, 2, 34, 0, 49, 3, 80, 4, 26, 1, 53, 
    1, 84, 7, 24, 5,  7, 4, 15, 0, 76, 2, 24, 8,  7, 6, 79, 3, 59, 
    4, 11, 6, 10, 7, 83, 0, 34, 8, 64, 3, 17, 5, 84, 1, 57, 2, 10, 
    7, 62, 6, 45, 8,  7, 0, 28, 3, 14, 2, 42, 4, 78, 5, 22, 1, 54
  };
  const int q4503[] = {
    9, 9, // Number of jobs and machines
    2, 19, 5, 92, 1, 71, 4, 55, 7, 13, 8, 22, 3, 60, 0,  9, 6, 40, 
    7, 77, 3, 19, 6, 28, 0, 90, 4, 30, 2, 27, 1, 61, 5, 96, 8, 87, 
    4, 56, 3, 75, 0, 60, 2, 64, 1, 42, 5, 18, 7, 92, 8, 62, 6, 54, 
    0, 24, 7, 12, 2, 84, 3, 35, 4, 57, 1, 23, 6, 82, 8, 59, 5, 88, 
    7, 77, 5, 63, 8, 77, 4, 15, 1, 23, 2, 84, 6,  9, 3, 17, 0,  6, 
    1, 47, 4, 23, 6, 58, 2, 68, 7, 61, 0, 94, 8, 97, 5, 93, 3, 81, 
    7, 16, 2, 33, 3, 91, 1,  7, 5, 51, 6, 26, 8, 56, 0, 22, 4, 88, 
    7, 26, 2, 65, 0, 66, 3, 45, 5, 42, 6, 62, 4, 55, 8, 89, 1, 44, 
    8, 57, 4, 93, 0, 14, 1, 35, 2, 33, 6, 69, 7, 24, 3, 85, 5, 37
  };
  const int q4504[] = {
    9, 9, // Number of jobs and machines
    8, 79, 1, 42, 7, 57, 2, 11, 4, 49, 5, 54, 0, 21, 6, 61, 3, 64, 
    8, 91, 3, 49, 5, 40, 7, 24, 0, 56, 6, 32, 2, 56, 1, 60, 4, 49, 
    6, 84, 3, 61, 5, 21, 8,  7, 7, 91, 1, 48, 2, 73, 0, 84, 4, 16, 
    0,  3, 2, 40, 8,  1, 7, 54, 4, 66, 1, 65, 3, 19, 5, 72, 6, 25, 
    1, 56, 0, 84, 7, 63, 3, 69, 4, 35, 8, 31, 2, 85, 5, 66, 6, 42, 
    1, 18, 2, 43, 3, 60, 6, 86, 5, 14, 7, 58, 0, 65, 8, 85, 4, 32, 
    1, 81, 2, 59, 5, 85, 6, 88, 8, 28, 7, 39, 4, 91, 0, 82, 3, 62, 
    4, 49, 2, 95, 3, 61, 6, 88, 0, 37, 5, 37, 1, 22, 7, 68, 8, 79, 
    2, 31, 5, 26, 6, 59, 1, 71, 3, 94, 4, 80, 7, 83, 0, 64, 8, 74
  };
  const int q4505[] = {
    9, 9, // Number of jobs and machines
    5, 47, 6, 16, 1, 59, 0,  8, 4, 24, 3, 77, 8, 34, 7, 47, 2, 82, 
    3, 50, 2, 58, 7, 96, 5,  4, 8, 79, 1, 71, 4, 96, 0, 35, 6, 98, 
    2, 10, 3, 35, 8, 51, 5, 75, 6, 38, 0, 80, 4, 13, 7, 42, 1, 80, 
    7, 75, 0, 31, 4,  4, 1, 99, 6, 75, 5, 52, 8, 77, 2, 43, 3, 89, 
    7, 17, 2, 78, 3, 50, 6, 37, 5,  7, 4, 22, 0, 18, 8, 57, 1, 33, 
    0, 89, 4, 35, 7, 49, 2, 87, 3, 17, 8, 97, 6, 59, 1, 73, 5, 24, 
    3, 42, 2, 67, 6,  9, 8, 65, 5, 54, 0, 58, 4, 12, 7, 37, 1, 13, 
    5, 66, 6, 62, 7, 95, 4, 70, 1, 98, 3, 58, 8, 82, 0, 78, 2, 63, 
    2, 79, 7, 15, 4, 50, 5, 60, 0, 96, 3, 26, 1, 69, 6, 73, 8, 22
  };
  const int q4506[] = {
    9, 9, // Number of jobs and machines
    8, 78, 4,  9, 1, 80, 3,  5, 2, 38, 7, 74, 6, 29, 0, 79, 5, 45, 
    1, 73, 6, 75, 3, 88, 2,  9, 7, 16, 4, 75, 5, 65, 8, 35, 0, 96, 
    2, 83, 7, 50, 8, 84, 6, 31, 4, 42, 1, 34, 5, 21, 0, 53, 3, 73, 
    6,  5, 5, 40, 1, 67, 0,  6, 4, 93, 8, 74, 2,  9, 7, 86, 3,  5, 
    3, 27, 6,  8, 8, 45, 7,  5, 4, 18, 5, 97, 0, 46, 2, 70, 1, 57, 
    5, 48, 6,  3, 4, 32, 2, 99, 8,  2, 3, 25, 7, 30, 1, 14, 0, 67, 
    1, 94, 2, 47, 8, 85, 3, 84, 6, 15, 5, 95, 4, 78, 7, 50, 0, 43, 
    6,  8, 4, 45, 1, 44, 3, 14, 0,  4, 2, 77, 7, 10, 5, 81, 8, 92, 
    7,  4, 5, 13, 4, 71, 1, 66, 6, 99, 0, 42, 2, 48, 8, 78, 3, 24
  };
  const int q4507[] = {
    9, 9, // Number of jobs and machines
    2, 41, 4, 80, 1, 10, 6, 42, 7, 58, 3, 75, 0, 44, 5, 33, 8, 83, 
    3,  4, 6, 57, 0, 14, 2, 60, 7,  2, 4, 98, 5, 35, 1,  4, 8, 81, 
    8, 63, 3, 79, 2, 72, 5, 32, 6, 96, 7, 29, 1, 99, 4, 95, 0,  3, 
    1, 97, 3, 41, 2, 76, 7, 34, 8, 97, 4, 26, 6, 36, 0, 59, 5, 87, 
    6, 27, 3, 77, 8,  6, 2, 60, 1,  5, 5, 67, 0, 85, 4, 65, 7, 31, 
    1, 10, 6, 38, 3, 46, 2,  3, 7, 89, 8, 99, 0, 76, 4, 42, 5, 32, 
    0, 85, 2, 71, 8, 38, 1, 30, 6, 44, 5, 87, 7, 61, 4, 19, 3, 73, 
    7, 53, 8, 89, 6, 27, 2, 83, 0,  9, 1, 23, 3, 30, 4, 51, 5, 20, 
    4, 87, 2, 93, 5, 45, 8, 24, 6, 88, 3, 22, 1, 39, 7, 86, 0, 91
  };
  const int q4508[] = {
    9, 9, // Number of jobs and machines
    7,  6, 6, 91, 3, 37, 4, 93, 8, 21, 0, 36, 1,  1, 2, 90, 5, 77, 
    2, 12, 0, 98, 4, 31, 1, 67, 3, 23, 5, 57, 6, 84, 8, 67, 7,  5, 
    8, 15, 4, 39, 7, 14, 5, 25, 2, 22, 1, 17, 3, 56, 6, 51, 0, 99, 
    7,  2, 2, 97, 3, 15, 0, 15, 8, 82, 5, 66, 4, 43, 1, 17, 6, 31, 
    4, 58, 7, 51, 0, 13, 2, 56, 8, 38, 3, 91, 1, 98, 6, 65, 5, 75, 
    8, 21, 1, 16, 3, 48, 2, 27, 0, 75, 5, 20, 6, 42, 4, 88, 7, 63, 
    7, 10, 2, 49, 6, 34, 5, 71, 3, 56, 0, 20, 4, 69, 1, 68, 8, 43, 
    6, 24, 0, 35, 3, 27, 1, 29, 7, 65, 4, 79, 5, 28, 8, 19, 2, 20, 
    2, 77, 5, 17, 1, 92, 6, 29, 3, 88, 7, 89, 0, 99, 8, 35, 4, 28
  };
  const int q4509[] = {
    9, 9, // Number of jobs and machines
    4, 26, 7, 80, 3, 31, 1, 80, 8, 40, 2,  4, 5,  6, 0, 12, 6, 86, 
    3, 61, 2, 87, 8, 20, 1, 14, 0, 14, 5, 31, 4,  6, 6, 86, 7, 67, 
    0, 74, 7, 18, 8, 47, 2, 53, 3, 23, 6, 56, 1, 78, 5, 14, 4, 20, 
    1, 86, 4, 32, 0, 35, 2, 63, 7, 84, 3,  9, 5, 50, 6, 75, 8, 62, 
    2, 61, 1, 54, 0, 43, 6, 48, 7, 88, 5, 93, 3, 26, 4, 38, 8, 47, 
    2, 24, 6, 26, 4, 83, 8, 61, 7, 57, 1, 15, 0, 90, 5, 99, 3, 99, 
    6, 30, 3, 45, 5, 56, 2,  9, 7, 41, 8, 51, 1, 91, 4, 26, 0, 40, 
    1, 89, 4,  3, 7, 61, 5, 34, 8, 14, 0, 28, 6,  4, 2, 67, 3, 52, 
    4,  8, 0, 22, 1,  4, 5, 89, 6, 58, 2, 17, 3, 61, 8, 77, 7, 29
  };
  const int q4510[] = {
    9, 9, // Number of jobs and machines
    6, 58, 8, 44, 0, 14, 5,  6, 1, 41, 7, 47, 3, 41, 4, 44, 2, 23, 
    0, 22, 7, 56, 3, 63, 2, 80, 5, 10, 1, 10, 6, 92, 8,  4, 4, 93, 
    4, 34, 0, 77, 5, 92, 7, 65, 2, 47, 8, 78, 1, 83, 3, 43, 6,  5, 
    6, 98, 0, 68, 2,  3, 3, 29, 4, 62, 7, 26, 8, 10, 5, 68, 1, 27, 
    1, 15, 2, 21, 5, 95, 3,  2, 6, 12, 0, 89, 4, 49, 7, 70, 8, 45, 
    3, 98, 1, 38, 8, 20, 7, 69, 2, 73, 0,  2, 5, 91, 6, 41, 4, 29, 
    1, 54, 6, 10, 3, 44, 5, 82, 8, 47, 2,  1, 7, 36, 0, 79, 4, 72, 
    2, 85, 6, 77, 5, 29, 1, 91, 7, 16, 0, 64, 8, 96, 3, 73, 4, 19, 
    7, 49, 0, 90, 6, 70, 3, 25, 5, 54, 1, 59, 2, 87, 4, 95, 8, 10
  };
  const int q4511[] = {
    9, 9, // Number of jobs and machines
    0, 19, 6, 98, 1, 76, 5, 25, 2, 37, 7, 62, 3, 81, 8, 26, 4, 67, 
    0, 86, 3, 85, 7, 82, 6, 29, 1, 34, 2,  7, 8,  3, 5, 45, 4, 50, 
    4, 53, 1, 11, 2, 90, 3, 62, 8, 76, 5, 86, 7, 63, 0, 52, 6, 43, 
    6, 94, 8, 23, 4,  3, 1, 45, 0, 97, 5, 31, 7, 52, 2, 56, 3, 25, 
    1, 37, 5, 74, 8, 37, 4, 94, 6, 40, 7, 19, 3, 36, 0, 75, 2, 70, 
    5, 73, 0, 30, 4, 78, 2, 98, 1, 81, 7, 19, 3, 49, 6, 13, 8, 88, 
    6, 72, 1, 52, 2, 82, 0, 96, 3,  1, 5, 66, 7, 13, 8,  9, 4, 77, 
    7, 72, 3, 78, 2, 98, 8, 76, 0, 66, 6, 63, 5, 54, 1, 20, 4, 50, 
    4, 13, 8, 15, 0, 68, 6, 38, 7, 25, 5, 92, 3, 92, 1, 91, 2, 97
  };
  const int q4512[] = {
    9, 9, // Number of jobs and machines
    8, 45, 2, 41, 4, 99, 3, 84, 7, 28, 0, 10, 1, 68, 6, 78, 5, 68, 
    0, 80, 8, 57, 7,  5, 4, 46, 1, 30, 6,  6, 5,  3, 2, 94, 3, 20, 
    2, 22, 5, 43, 3, 24, 4, 71, 0, 33, 6, 78, 1, 64, 8, 41, 7, 55, 
    0, 23, 2, 52, 4, 82, 6, 68, 3, 11, 5, 12, 7, 58, 8, 15, 1, 92, 
    3, 20, 5, 47, 6, 77, 2, 96, 0, 56, 7, 82, 4, 79, 1, 42, 8, 35, 
    1, 53, 6, 16, 3, 53, 0, 57, 8, 82, 2, 18, 7, 70, 5, 20, 4, 81, 
    8, 68, 2, 39, 3, 40, 6,  3, 5, 15, 0, 69, 1, 83, 4, 40, 7, 78, 
    1, 40, 2,  3, 5, 33, 0, 15, 7, 31, 3, 32, 4, 10, 8, 81, 6, 13, 
    7, 77, 8, 47, 6, 27, 3, 24, 5, 60, 4, 63, 2, 55, 0, 77, 1, 11
  };
  const int q4513[] = {
    9, 9, // Number of jobs and machines
    5, 83, 0, 81, 3, 47, 6, 95, 4, 18, 8, 28, 2, 18, 1, 83, 7, 41, 
    0, 28, 8, 47, 5, 97, 7, 55, 6, 29, 1, 65, 3, 49, 2, 98, 4, 87, 
    3, 97, 5, 89, 6, 35, 0, 88, 2, 94, 7, 43, 1, 52, 4, 27, 8, 43, 
    2, 30, 1, 53, 4, 28, 6, 16, 5, 38, 3, 57, 7, 94, 0, 83, 8, 98, 
    6, 24, 5, 72, 2, 71, 8, 40, 0, 80, 3, 78, 1, 44, 7, 14, 4, 30, 
    7, 73, 0, 36, 3, 55, 6, 80, 5, 12, 8, 67, 1, 58, 4, 16, 2, 44, 
    0, 84, 3, 57, 8, 43, 6, 64, 2, 92, 1, 92, 4, 50, 5, 60, 7, 96, 
    4, 97, 3, 61, 2, 87, 8, 50, 0, 52, 7, 97, 6, 75, 1, 85, 5, 40, 
    2, 39, 3, 54, 5, 17, 1, 74, 6, 20, 7, 43, 0,  2, 4, 94, 8, 62
  };
  const int q4514[] = {
    9, 9, // Number of jobs and machines
    0, 47, 8, 70, 3, 23, 5, 89, 2, 34, 1, 31, 7, 94, 6, 27, 4, 65, 
    7, 66, 8, 98, 5, 16, 2, 13, 3, 58, 4, 11, 1, 54, 0, 51, 6, 94, 
    0, 52, 7, 82, 3, 43, 2, 49, 1, 76, 6, 16, 5, 60, 8, 42, 4, 82, 
    7, 72, 0, 24, 5, 67, 2, 25, 3, 18, 4, 16, 6, 65, 1, 20, 8, 49, 
    0,  5, 1, 63, 5, 87, 8, 70, 2, 42, 3, 89, 6, 67, 4, 18, 7, 55, 
    5, 65, 6, 84, 4, 31, 7, 51, 2,  3, 8, 23, 3, 94, 1, 14, 0, 41, 
    3,  7, 1, 57, 0, 87, 2,  1, 5, 70, 4,  5, 8, 36, 7, 40, 6, 50, 
    5, 92, 4, 84, 2, 89, 8, 73, 0, 75, 1, 59, 6, 65, 7, 55, 3, 68, 
    8, 10, 7, 97, 0,  8, 1, 75, 3, 11, 6, 43, 5, 16, 4, 86, 2, 89
  };
  const int q4515[] = {
    9, 9, // Number of jobs and machines
    1, 40, 4,  3, 0,  7, 5, 89, 3, 89, 7, 54, 8, 89, 2, 52, 6,  9, 
    7, 48, 8, 56, 1, 62, 4, 71, 0,  5, 2,  7, 3, 20, 6, 70, 5, 20, 
    2,  1, 6, 73, 4, 53, 5, 60, 7,  6, 1, 52, 8, 59, 3, 98, 0, 64, 
    1, 12, 4, 44, 8,  9, 2, 22, 3, 84, 5, 85, 0, 84, 7, 66, 6, 62, 
    0,  1, 4, 54, 7, 32, 6, 45, 3, 38, 8, 34, 1, 24, 2, 67, 5, 52, 
    3, 71, 4, 33, 7, 69, 2, 62, 6, 90, 1, 79, 5, 89, 0, 22, 8, 10, 
    4, 35, 5, 57, 3, 38, 1, 40, 7, 62, 0, 93, 2, 74, 6, 12, 8, 37, 
    6, 94, 4, 20, 1, 44, 8, 53, 5, 34, 3, 66, 0, 91, 2,  8, 7, 25, 
    3, 41, 8, 40, 6, 75, 5, 70, 4, 16, 7, 96, 0, 76, 2, 52, 1, 22
  };
  const int q4516[] = {
    9, 9, // Number of jobs and machines
    4, 38, 3, 50, 7, 32, 5,  6, 8, 15, 2, 61, 0,  5, 1, 78, 6, 48, 
    1, 23, 3, 38, 0,  5, 8, 68, 2, 87, 5, 62, 6, 54, 7, 80, 4, 32, 
    1, 63, 6, 89, 5, 65, 8, 65, 3, 47, 2,  3, 0, 46, 4, 35, 7, 51, 
    0, 92, 6, 78, 1, 54, 7, 61, 5, 71, 3, 93, 4, 27, 2,  8, 8, 72, 
    3, 93, 0, 70, 8, 58, 1, 12, 6, 40, 2, 34, 5, 89, 4, 84, 7, 18, 
    0, 18, 1, 51, 6, 74, 8,  3, 3, 74, 4, 51, 7, 39, 5,  4, 2, 45, 
    1, 17, 2, 12, 0, 78, 7, 11, 6, 93, 5, 51, 8, 39, 3, 48, 4,  4, 
    1, 45, 0, 22, 2, 30, 5, 68, 7, 16, 8, 42, 3, 78, 6, 80, 4, 14, 
    4,  4, 5, 89, 0, 54, 1, 19, 7, 36, 6, 75, 8, 86, 3, 19, 2,  5
  };
  const int q4517[] = {
    9, 9, // Number of jobs and machines
    3, 96, 7, 86, 5, 68, 6, 89, 0, 87, 1, 20, 8, 18, 2, 41, 4, 83, 
    0, 29, 3, 82, 4, 86, 6, 57, 8,  3, 2, 77, 5, 29, 1, 56, 7, 48, 
    5, 66, 1, 29, 0, 51, 4, 42, 8, 24, 3, 15, 7, 20, 6,  5, 2, 54, 
    2, 21, 0, 55, 1, 54, 3,  3, 8, 36, 5, 51, 4, 26, 6, 20, 7,  9, 
    0, 40, 1, 54, 6,  2, 5, 46, 8, 46, 2, 64, 7, 92, 3, 61, 4, 35, 
    3,  8, 1, 38, 4, 86, 7, 62, 6, 66, 2, 97, 0, 17, 5, 28, 8, 85, 
    4, 79, 6, 70, 0, 88, 2,  4, 1, 34, 5, 96, 7,  8, 3, 70, 8, 98, 
    4, 13, 1, 47, 0, 21, 5, 65, 3,  6, 7, 97, 2, 78, 6, 72, 8, 64, 
    1, 36, 5, 15, 4, 46, 0, 69, 7,  8, 6, 98, 8, 66, 3, 61, 2, 91
  };
  const int q4518[] = {
    9, 9, // Number of jobs and machines
    2, 75, 6, 81, 7, 79, 1, 79, 8, 13, 0,  9, 4, 49, 3, 21, 5, 62, 
    1,  5, 2, 55, 6, 60, 8, 13, 3, 31, 5, 64, 7, 12, 4, 84, 0,  3, 
    6,  1, 3, 62, 0, 91, 8, 63, 7, 47, 1, 38, 2, 25, 4, 34, 5, 92, 
    1, 10, 7, 43, 6, 52, 0, 83, 3, 97, 2, 39, 5,  2, 4, 54, 8,  1, 
    5, 97, 6, 45, 8, 58, 0, 33, 1, 71, 2, 91, 3, 97, 7, 85, 4, 85, 
    8, 65, 4, 21, 1, 26, 0, 55, 2, 28, 6, 58, 7, 56, 5,  1, 3, 69, 
    1, 45, 3, 64, 6, 77, 2, 50, 0, 80, 8, 57, 5, 36, 7, 39, 4, 62, 
    1, 68, 4, 78, 0, 71, 7, 83, 8, 79, 2, 21, 5, 16, 6, 62, 3,  8, 
    8, 58, 1, 27, 4, 63, 0, 64, 7, 73, 3, 60, 2, 40, 5, 70, 6, 72
  };
  const int q4519[] = {
    9, 9, // Number of jobs and machines
    2, 78, 4, 68, 8, 84, 0, 74, 5, 83, 3, 54, 7, 52, 6, 11, 1, 91, 
    5, 54, 3, 15, 7, 61, 8, 37, 4, 36, 1, 12, 2, 53, 6, 51, 0, 78, 
    6, 13, 0, 11, 1, 93, 4, 98, 8, 64, 7, 18, 5, 48, 2, 21, 3, 85, 
    4, 16, 1, 56, 8, 34, 0, 64, 6, 16, 7, 39, 2, 20, 3, 57, 5, 39, 
    7,  7, 0,  5, 2, 42, 6, 30, 1, 62, 8, 19, 3, 32, 5, 76, 4, 72, 
    7, 60, 3,  4, 4, 56, 0, 87, 6, 86, 1, 60, 8, 54, 5, 66, 2, 79, 
    3,  6, 4,  9, 2, 31, 1, 56, 0, 35, 8, 98, 5, 63, 7, 20, 6, 62, 
    3, 64, 2, 78, 6, 48, 4, 71, 5, 12, 8, 41, 0, 64, 1, 35, 7, 20, 
    7, 56, 6, 62, 4, 38, 1, 54, 0,  2, 3,  9, 8, 82, 5, 49, 2, 66
  };
  const int q4520[] = {
    9, 9, // Number of jobs and machines
    5, 37, 1, 43, 3, 30, 7, 71, 8, 90, 4, 59, 6, 26, 0, 95, 2, 19, 
    3, 49, 8, 15, 6, 75, 1,  7, 2, 89, 4, 80, 0, 49, 7, 65, 5,  4, 
    3, 36, 2, 13, 0, 11, 1, 62, 6, 86, 5, 31, 4, 53, 8, 16, 7,  1, 
    3, 86, 7, 24, 2,  5, 5, 53, 0, 67, 8, 87, 1, 91, 6, 46, 4, 32, 
    2, 70, 3, 17, 0, 26, 5, 54, 7, 73, 8, 60, 1, 95, 4, 75, 6, 32, 
    6, 61, 4,  1, 2, 20, 5, 65, 8, 78, 3, 76, 7, 69, 0, 63, 1, 30, 
    4, 53, 0, 81, 8, 84, 6, 91, 7, 10, 2, 28, 5, 89, 1, 36, 3, 28, 
    0, 83, 8, 86, 4, 27, 7, 22, 5, 68, 1, 89, 6, 74, 3, 28, 2, 16, 
    5, 62, 0, 74, 3, 60, 8, 49, 2, 40, 4, 58, 1, 89, 7, 26, 6, 57
  };
  const int q4521[] = {
    9, 9, // Number of jobs and machines
    3, 22, 8, 94, 5, 83, 0, 99, 4, 21, 2, 80, 6,  8, 1, 33, 7, 51, 
    8, 92, 3, 62, 5, 35, 1, 58, 7, 79, 0, 42, 4, 80, 6, 33, 2, 42, 
    5, 16, 3, 97, 0, 12, 7, 38, 4, 28, 8, 17, 1, 71, 6, 98, 2, 51, 
    6, 42, 1,  1, 3, 10, 4, 36, 8, 71, 2,  7, 0, 81, 7, 54, 5, 90, 
    0, 64, 7, 72, 8, 16, 5, 23, 1, 12, 2, 63, 3, 66, 4, 19, 6, 72, 
    8, 68, 5, 55, 2, 27, 0, 98, 1, 76, 3, 66, 4, 40, 6, 10, 7, 20, 
    6, 16, 4, 86, 0, 90, 3, 71, 1, 77, 7, 80, 2, 51, 5, 90, 8, 24, 
    1, 21, 5, 17, 4, 57, 3, 78, 6, 16, 8, 92, 0,  3, 7, 13, 2, 29, 
    0, 20, 7, 29, 5, 78, 4, 37, 3, 88, 1, 27, 6, 47, 2, 43, 8, 72
  };
  const int q4522[] = {
    9, 9, // Number of jobs and machines
    1, 25, 8, 84, 2, 41, 7, 61, 6, 70, 5, 85, 0, 55, 3, 37, 4, 26, 
    6, 21, 1, 99, 8, 47, 4,  5, 2,  1, 0, 30, 7, 43, 5, 65, 3,  6, 
    4,  6, 5,  8, 6, 67, 2, 44, 0, 70, 3, 42, 1, 57, 8,  4, 7, 24, 
    7, 36, 0, 39, 2, 98, 5, 73, 4, 83, 1, 78, 3, 50, 6, 41, 8, 49, 
    0, 59, 1, 96, 5, 60, 2, 80, 6, 19, 7, 72, 4, 50, 3, 35, 8, 69, 
    0, 89, 6, 98, 5, 32, 2,  5, 7, 98, 1, 94, 4, 62, 3, 36, 8,  4, 
    8, 11, 2, 23, 5, 29, 6, 94, 7, 41, 4, 75, 1, 66, 3, 32, 0, 82, 
    5, 72, 4, 39, 8, 97, 0, 13, 1, 95, 3, 31, 6, 51, 7, 67, 2, 23, 
    3, 39, 0,  2, 8, 53, 2, 17, 4, 38, 7, 16, 6, 25, 1, 92, 5, 66
  };
  const int q4523[] = {
    9, 9, // Number of jobs and machines
    4, 15, 5, 19, 8, 25, 1, 73, 2, 68, 7, 54, 3, 58, 6, 82, 0,  8, 
    0, 75, 5, 37, 4, 78, 6, 80, 1, 99, 2, 37, 7, 12, 3, 81, 8,  6, 
    1, 30, 4, 17, 7, 13, 3, 23, 0,  4, 6, 21, 8, 66, 5, 21, 2, 32, 
    7, 56, 0, 92, 5, 65, 2, 44, 1, 33, 3,  1, 8, 66, 6, 67, 4, 57, 
    6, 29, 0, 89, 1, 15, 3, 19, 7,  6, 4, 65, 2, 64, 5, 26, 8,  6, 
    1, 21, 7,  1, 5, 43, 6, 50, 0, 58, 8, 69, 3, 38, 2, 22, 4,  2, 
    6, 52, 3, 95, 1, 78, 2, 47, 5, 76, 7, 58, 4, 90, 8, 31, 0, 26, 
    4,  5, 1, 34, 8,  3, 0, 54, 3, 23, 2, 95, 5, 18, 6, 80, 7, 80, 
    7, 19, 1, 94, 2, 64, 4, 76, 5, 27, 8,  4, 0, 23, 6, 66, 3, 85
  };
  const int q4524[] = {
    9, 9, // Number of jobs and machines
    1, 84, 6, 50, 3, 58, 4, 18, 2, 26, 7, 44, 5, 17, 8, 46, 0, 19, 
    5, 78, 6, 75, 3, 44, 2, 27, 7, 86, 4, 30, 8, 30, 0, 60, 1, 19, 
    5, 83, 2, 29, 8, 38, 1, 45, 4, 79, 0, 75, 6, 20, 7, 43, 3, 18, 
    2, 70, 8, 50, 0, 45, 5, 70, 3, 34, 7, 91, 1, 31, 6, 99, 4, 10, 
    4, 14, 5, 78, 1, 47, 7, 47, 2, 25, 0, 42, 8, 26, 6, 78, 3, 96, 
    6, 18, 1, 86, 4, 44, 3,  2, 2, 42, 7, 63, 8, 34, 5, 28, 0, 19, 
    5, 69, 3, 14, 1, 38, 6, 43, 4, 77, 2, 49, 7, 98, 0,  5, 8, 36, 
    0, 85, 3, 27, 2, 21, 5, 56, 8, 76, 7, 54, 1, 19, 6, 63, 4, 24, 
    0, 68, 7, 12, 3, 17, 8, 57, 5, 91, 6, 62, 4, 95, 2, 38, 1, 97
  };
  const int q4525[] = {
    9, 9, // Number of jobs and machines
    7, 16, 1, 75, 5, 12, 8, 14, 2, 62, 4, 54, 6, 83, 3, 43, 0, 68, 
    8, 24, 5, 29, 3,  8, 0, 59, 4, 45, 2, 46, 6,  1, 1, 52, 7, 54, 
    8, 85, 0, 60, 2, 27, 3, 14, 4, 95, 7, 34, 6, 41, 1, 27, 5, 76, 
    8, 33, 4, 96, 3, 10, 2, 31, 1, 11, 0, 59, 6,  8, 5,  4, 7, 21, 
    8, 29, 5, 62, 4, 37, 3, 77, 6, 28, 7, 35, 2, 83, 1, 80, 0, 55, 
    0, 93, 6, 80, 5, 52, 1, 33, 8, 50, 4, 92, 2, 19, 3, 10, 7, 88, 
    8, 39, 0, 13, 6, 13, 4, 62, 5, 89, 3, 55, 7, 90, 1, 83, 2, 71, 
    2, 74, 3, 52, 5, 32, 4, 91, 6, 59, 8, 94, 1, 17, 0, 58, 7, 36, 
    1, 67, 2, 91, 5, 22, 8, 51, 3, 93, 6, 18, 4, 15, 0, 73, 7, 67
  };
  const int q4526[] = {
    9, 9, // Number of jobs and machines
    5, 18, 0,  6, 8, 34, 1, 56, 6, 41, 3, 92, 7, 14, 2, 50, 4, 12, 
    2, 40, 7, 70, 3, 70, 4, 27, 1, 66, 8, 55, 6, 90, 0, 44, 5, 20, 
    1, 26, 8, 64, 6, 97, 4, 24, 7, 91, 5, 96, 3, 20, 0, 76, 2, 69, 
    8, 15, 1, 72, 7, 18, 5, 80, 4, 90, 2, 17, 0, 31, 3, 11, 6, 22, 
    1, 62, 6, 47, 0, 14, 4, 82, 7, 58, 3, 13, 5, 78, 8, 94, 2, 59, 
    1, 31, 5, 72, 8, 70, 3, 62, 0, 53, 4, 46, 7, 23, 2, 72, 6, 75, 
    7, 12, 6, 51, 5, 60, 8, 44, 4, 22, 0, 68, 1,  4, 2, 63, 3, 85, 
    1, 32, 0, 99, 6,  6, 4, 70, 8, 85, 2, 32, 7, 43, 3, 67, 5, 87, 
    7, 96, 6, 52, 5, 45, 4, 45, 8,  3, 3, 73, 0,  3, 1, 61, 2, 61
  };
  const int q4527[] = {
    9, 9, // Number of jobs and machines
    4, 64, 2, 36, 3, 85, 1, 96, 7, 71, 5,  5, 6, 76, 8, 52, 0, 12, 
    0, 92, 6, 90, 8, 51, 3, 87, 2, 58, 5, 34, 7, 26, 4,  1, 1, 41, 
    8, 89, 6, 67, 0, 23, 7, 92, 1, 76, 5, 64, 4, 97, 2, 13, 3, 57, 
    2,  2, 1, 76, 0, 42, 5, 53, 3, 87, 8, 39, 4, 74, 6, 75, 7, 97, 
    0, 11, 6, 76, 7, 10, 1, 43, 3, 80, 5,  4, 8, 12, 4, 11, 2, 63, 
    2, 59, 4, 61, 8, 64, 3, 12, 7, 18, 5, 41, 1, 38, 6, 68, 0, 67, 
    7, 39, 8, 12, 5, 45, 1, 15, 3, 78, 0, 45, 2, 39, 4, 58, 6, 25, 
    4, 98, 3, 10, 6, 63, 2, 52, 8, 81, 5, 28, 1, 11, 7, 63, 0, 73, 
    0, 12, 3,  7, 6, 69, 7,  5, 4, 65, 1, 38, 8, 43, 2, 31, 5, 38
  };
  const int q4528[] = {
    9, 9, // Number of jobs and machines
    6, 37, 0, 38, 4, 34, 5, 40, 8, 74, 7, 54, 2, 89, 3, 70, 1, 93, 
    5, 70, 8, 66, 0, 15, 2, 61, 6, 69, 3, 75, 4, 99, 7, 74, 1,  4, 
    5, 10, 6, 67, 2, 63, 7, 72, 1, 25, 4, 75, 3,  1, 0, 13, 8, 72, 
    7, 58, 1, 35, 5, 63, 6, 96, 0,  6, 4, 60, 3, 92, 8, 27, 2, 47, 
    0, 80, 8, 56, 7, 32, 3, 19, 4, 41, 1, 24, 5, 78, 6, 55, 2, 23, 
    5,  6, 3, 99, 1, 25, 2, 62, 6, 83, 0, 22, 8, 43, 4, 29, 7, 86, 
    2, 67, 7, 96, 8, 82, 3, 16, 0, 65, 6, 79, 5, 36, 4, 89, 1, 66, 
    6, 69, 7, 95, 4,  6, 3, 97, 0, 98, 1, 48, 2, 19, 8, 43, 5,  4, 
    0, 60, 3, 52, 1, 86, 6, 92, 8, 62, 4, 75, 5, 97, 2, 11, 7, 60
  };
  const int q4529[] = {
    9, 9, // Number of jobs and machines
    6, 25, 7, 40, 4, 16, 2, 79, 5, 75, 1, 45, 8, 13, 0, 70, 3, 91, 
    1, 42, 5, 29, 2, 61, 6,  8, 3, 39, 8, 47, 7, 16, 4,  3, 0, 24, 
    0, 26, 6, 33, 5, 51, 7, 63, 4, 47, 3, 80, 8, 91, 1, 54, 2, 18, 
    4, 85, 8, 86, 0, 57, 3, 43, 2, 98, 6, 43, 1, 85, 7, 13, 5, 96, 
    1, 95, 7, 54, 3, 46, 8, 19, 2, 85, 4, 27, 6, 98, 0, 29, 5, 31, 
    0, 90, 8, 13, 3, 68, 2, 67, 7, 77, 5, 67, 4, 66, 6, 69, 1, 75, 
    1, 41, 6, 19, 5, 59, 0, 68, 2, 43, 7, 38, 3, 69, 8, 82, 4, 68, 
    8, 95, 1, 75, 5, 20, 4, 47, 7, 39, 0, 43, 2, 88, 3, 47, 6, 58, 
    3, 50, 2,  5, 7, 38, 0, 85, 8, 18, 4, 73, 5, 69, 6, 63, 1, 14
  };
  const int q4530[] = {
    9, 9, // Number of jobs and machines
    1, 79, 8, 16, 6, 98, 5, 15, 3, 17, 4, 69, 0, 10, 7, 38, 2, 50, 
    3, 46, 2, 32, 6,  3, 0, 49, 8, 47, 5, 57, 1, 76, 4, 26, 7, 78, 
    0,  4, 2, 30, 4, 43, 3, 72, 5,  4, 7, 72, 1, 20, 8, 98, 6, 51, 
    5, 57, 8, 91, 3, 54, 7,  3, 2, 54, 0, 92, 4, 49, 6, 12, 1, 50, 
    1,  8, 3,  9, 5, 26, 2, 48, 7, 17, 4, 56, 6, 65, 0,  4, 8, 32, 
    5, 89, 3, 91, 7, 23, 4, 60, 8, 46, 0, 11, 1, 95, 2,  4, 6, 99, 
    8, 54, 7, 58, 6, 27, 3, 54, 5, 95, 0, 44, 4,  1, 2, 20, 1, 98, 
    6, 12, 7, 70, 1, 59, 2, 34, 0, 48, 8,  9, 5, 33, 3,  8, 4, 92, 
    5, 53, 7, 43, 3, 53, 2, 64, 6, 95, 8,  8, 0, 58, 4, 48, 1, 94
  };
  const int q4531[] = {
    9, 9, // Number of jobs and machines
    0, 25, 8, 62, 6, 79, 5, 25, 1, 67, 2, 89, 3, 34, 7,  1, 4, 63, 
    5, 37, 0, 55, 1,  2, 3, 85, 4, 98, 6, 79, 8,  6, 7, 54, 2, 16, 
    2, 65, 1, 50, 3, 10, 4, 55, 6, 57, 5, 13, 0,  5, 8, 72, 7, 95, 
    4, 67, 7, 99, 3, 85, 2, 76, 8, 73, 0, 17, 6, 10, 1, 56, 5, 23, 
    3, 27, 8, 86, 7, 73, 5, 90, 2, 42, 6, 45, 1, 84, 4, 16, 0, 12, 
    4, 39, 3, 66, 1, 27, 8, 54, 0, 63, 2, 62, 5, 15, 6, 81, 7,  1, 
    3, 74, 1, 47, 5, 73, 8, 96, 0, 60, 7, 82, 4,  7, 6, 16, 2, 13, 
    0, 20, 1, 60, 7, 42, 4, 24, 8, 69, 5, 66, 6,  1, 3,  8, 2, 83, 
    6, 72, 3, 71, 7, 41, 5, 99, 4,  5, 8, 13, 2, 26, 1, 77, 0, 28
  };
  const int q4532[] = {
    9, 9, // Number of jobs and machines
    5, 22, 8, 89, 4, 50, 3, 27, 6, 60, 1, 54, 7,  8, 0, 71, 2, 23, 
    7, 73, 2, 56, 1, 84, 5, 28, 3, 41, 0,  9, 4, 72, 8, 93, 6, 90, 
    2, 25, 0, 12, 8, 86, 4,  4, 5, 26, 7, 41, 3, 10, 1, 10, 6, 36, 
    7, 61, 0, 79, 4, 32, 1, 43, 6, 76, 8, 43, 3, 44, 2, 30, 5, 63, 
    2, 59, 7, 23, 6, 92, 8, 51, 3,  6, 5, 18, 1, 52, 4, 78, 0, 77, 
    8, 29, 3, 14, 5, 21, 2, 15, 0, 32, 7, 87, 4, 73, 6, 85, 1, 77, 
    2, 29, 4, 75, 5, 81, 0, 74, 3, 72, 1, 84, 6, 21, 8, 97, 7, 29, 
    6, 88, 5, 89, 3, 15, 0, 78, 8, 49, 4,  7, 1, 42, 7, 31, 2, 90, 
    0, 70, 5, 36, 8, 95, 7, 11, 6, 15, 3, 95, 4, 18, 2, 71, 1, 49
  };
  const int q4533[] = {
    9, 9, // Number of jobs and machines
    6, 27, 4, 42, 7, 25, 2, 65, 5, 51, 0,  2, 3, 89, 8, 40, 1, 57, 
    8, 93, 5, 25, 7, 15, 0, 24, 6, 86, 1, 39, 4, 92, 2, 54, 3, 80, 
    8, 75, 0,  2, 6, 17, 5, 76, 3, 13, 2, 27, 4,  4, 7, 17, 1, 18, 
    3, 18, 5, 36, 2, 60, 1, 11, 0, 43, 4, 36, 7, 12, 6, 71, 8, 65, 
    1, 22, 0, 41, 5, 45, 3, 71, 7, 98, 4, 58, 2, 66, 6, 41, 8, 27, 
    6, 49, 1, 25, 2, 38, 4, 82, 7, 89, 3, 63, 5, 63, 0, 72, 8, 20, 
    4, 39, 3,  4, 1, 26, 2, 94, 6, 35, 8, 44, 5, 13, 7, 89, 0,  4, 
    4, 85, 0, 80, 5, 33, 8, 59, 3, 67, 7, 86, 6, 82, 1, 51, 2, 50, 
    8, 71, 1, 48, 3, 95, 5, 53, 4, 89, 0, 25, 2, 24, 6, 92, 7, 32
  };
  const int q4534[] = {
    9, 9, // Number of jobs and machines
    3, 69, 6, 22, 5, 74, 1, 41, 0, 71, 2, 28, 7, 80, 8, 98, 4, 28, 
    3, 98, 2, 38, 4, 57, 8, 17, 5, 42, 0, 32, 6, 94, 1,  1, 7, 92, 
    5, 46, 1, 30, 7, 54, 6, 27, 8, 85, 4, 48, 3, 59, 0, 83, 2, 16, 
    4, 68, 8, 34, 6, 12, 5, 72, 3, 37, 7, 89, 2, 58, 0, 20, 1, 40, 
    2, 19, 1, 82, 0, 90, 8, 58, 7, 56, 4, 60, 6, 14, 3, 87, 5,  8, 
    4, 62, 3,  8, 5, 64, 0, 67, 7,  8, 1, 11, 2, 83, 6,  2, 8, 46, 
    2,  6, 3, 70, 8, 99, 6, 83, 7, 30, 4, 95, 5, 66, 0, 86, 1, 55, 
    1, 67, 4,  6, 0, 63, 7, 88, 5, 28, 3, 42, 2, 68, 8, 87, 6, 13, 
    7, 63, 4, 67, 3, 55, 0, 62, 5, 78, 8, 64, 1, 16, 6,  7, 2, 78
  };
  const int q4535[] = {
    9, 9, // Number of jobs and machines
    5, 55, 0, 78, 2, 62, 1,  7, 7, 56, 4, 94, 3, 83, 6, 24, 8, 11, 
    1, 66, 5, 77, 7,  8, 2,  6, 6, 93, 3, 49, 0, 30, 8, 31, 4, 88, 
    1, 74, 8, 37, 2, 55, 0, 22, 6, 54, 5, 24, 7, 20, 3, 53, 4, 97, 
    5, 60, 8, 50, 1,  9, 7,  6, 2, 40, 4, 88, 3, 96, 6, 79, 0, 46, 
    2, 66, 0, 29, 7, 68, 4, 27, 8, 73, 1, 55, 6, 91, 5, 40, 3, 13, 
    4, 66, 8, 97, 7, 67, 0, 86, 1, 83, 5, 80, 6, 97, 2, 13, 3, 90, 
    0, 72, 5, 41, 8, 81, 2, 32, 3, 70, 7, 87, 4, 55, 1, 48, 6, 19, 
    5, 27, 3, 36, 8, 93, 0, 26, 1, 41, 2, 73, 7, 80, 6, 20, 4,  9, 
    6, 40, 0, 80, 7, 20, 5, 75, 2,  7, 1, 58, 4, 53, 8, 30, 3, 52
  };
  const int q4536[] = {
    9, 9, // Number of jobs and machines
    3, 84, 1, 74, 2, 40, 5, 98, 6,  4, 7, 16, 8, 70, 0, 10, 4, 10, 
    1, 76, 0, 93, 2, 25, 4, 22, 3, 45, 7, 12, 6, 50, 5, 92, 8,  3, 
    4, 82, 0, 41, 3, 63, 1, 18, 2, 91, 6, 32, 8, 75, 5, 25, 7, 56, 
    1, 25, 6, 70, 3, 15, 8, 27, 0,  8, 7, 94, 2, 86, 5, 84, 4, 84, 
    4, 29, 6, 66, 1, 51, 8, 46, 2, 89, 7, 46, 0, 89, 3, 42, 5, 34, 
    7, 20, 5, 71, 3, 91, 0, 85, 2, 37, 8, 24, 6,  1, 1, 14, 4, 90, 
    7, 42, 5, 98, 6,  2, 4, 31, 1, 81, 2, 97, 0, 12, 8, 79, 3, 12, 
    5, 48, 3, 66, 1, 88, 0, 67, 2, 79, 4, 15, 6, 55, 7, 70, 8, 69, 
    6, 19, 5, 67, 1, 26, 3, 37, 8, 21, 0, 14, 4, 71, 2, 35, 7, 85
  };
  const int q4537[] = {
    9, 9, // Number of jobs and machines
    6, 52, 2, 38, 0,  5, 7, 59, 4, 52, 3, 51, 5, 32, 8, 32, 1, 52, 
    7,  8, 0, 98, 3, 28, 6, 46, 4, 88, 1, 26, 2, 35, 5, 96, 8, 40, 
    8, 16, 3, 16, 0, 50, 7, 68, 6, 11, 5, 20, 1, 50, 2, 86, 4, 35, 
    8, 43, 1, 77, 3, 88, 2, 25, 5, 32, 7, 99, 6, 13, 4, 66, 0,  6, 
    5, 43, 1, 69, 3, 84, 4, 48, 7, 34, 2, 17, 6, 11, 8, 86, 0, 62, 
    6, 39, 1, 21, 0, 42, 2, 56, 4,  6, 7, 78, 3,  6, 8, 10, 5, 12, 
    3,  6, 4, 87, 7, 33, 8, 98, 1, 40, 5, 15, 2, 41, 6, 88, 0, 96, 
    4,  9, 8, 70, 1, 67, 5,  1, 0, 83, 3, 26, 7,  7, 2, 12, 6, 77, 
    7, 15, 4, 66, 0, 22, 3, 32, 8, 79, 2, 78, 6, 80, 5, 43, 1,  1
  };
  const int q4538[] = {
    9, 9, // Number of jobs and machines
    8,  7, 3, 13, 6, 22, 5, 19, 7, 45, 0, 17, 1, 67, 4, 96, 2, 32, 
    8, 93, 0, 67, 2, 51, 4, 54, 7, 31, 3, 55, 5, 27, 6, 85, 1, 30, 
    0, 99, 4, 58, 1, 56, 2, 84, 7, 35, 5,  7, 8, 58, 6, 74, 3, 58, 
    4, 50, 5, 91, 6, 89, 2, 94, 8, 68, 0, 26, 1, 60, 3, 73, 7, 13, 
    8, 68, 4, 63, 6, 99, 2, 28, 7,  8, 1,  6, 0, 11, 3, 92, 5, 77, 
    8, 66, 1, 18, 6, 63, 4, 41, 0,  3, 7, 11, 2, 49, 5, 24, 3, 17, 
    3, 46, 0, 22, 1, 61, 5, 70, 4, 95, 7, 59, 6, 48, 2, 61, 8, 13, 
    7, 59, 5, 11, 8, 85, 6, 89, 0, 71, 2, 62, 4, 16, 3, 98, 1, 21, 
    0, 54, 3, 82, 4, 86, 2, 21, 5, 24, 6, 28, 1, 12, 7, 24, 8, 60
  };
  const int q4539[] = {
    9, 9, // Number of jobs and machines
    6, 35, 7, 41, 1, 27, 0, 84, 5, 85, 4, 95, 2,  3, 3, 33, 8, 77, 
    6, 71, 2, 21, 0, 38, 7, 70, 5, 62, 4, 37, 1, 34, 3, 92, 8, 80, 
    3, 15, 2, 34, 7, 33, 4, 35, 8, 27, 0, 27, 1,  4, 5, 53, 6, 76, 
    4, 51, 1, 20, 5, 39, 0, 21, 7, 66, 6, 24, 8, 47, 2, 54, 3, 49, 
    0, 59, 2, 95, 1, 73, 7, 17, 8, 24, 6, 18, 3, 19, 5, 55, 4, 56, 
    3, 82, 4, 84, 6, 31, 8, 35, 0, 66, 2, 69, 7,  9, 5, 25, 1, 72, 
    8, 48, 7, 37, 4, 96, 1, 25, 6, 46, 5, 96, 2,  7, 3, 41, 0, 97, 
    8, 67, 4, 19, 5, 96, 3, 63, 6, 22, 0, 73, 7, 53, 1, 54, 2, 57, 
    0,  2, 5, 61, 8, 34, 2, 12, 7, 78, 3, 89, 6, 88, 4, 81, 1, 49
  };
  const int q4540[] = {
    9, 9, // Number of jobs and machines
    3, 45, 0,  1, 2, 79, 8, 19, 1, 59, 4, 75, 6, 75, 5,  2, 7, 24, 
    2, 14, 8, 52, 5, 62, 1, 13, 0, 36, 4,  3, 3, 58, 6, 26, 7, 77, 
    3, 53, 2, 34, 0, 24, 8, 43, 4, 86, 5, 56, 7, 60, 6, 48, 1, 35, 
    5, 52, 1, 52, 6, 64, 7, 50, 3, 52, 4, 41, 2, 82, 8, 31, 0, 40, 
    7, 63, 6,  5, 3, 20, 1, 45, 5, 94, 4, 60, 8, 43, 0, 39, 2, 11, 
    0, 59, 1, 40, 3, 78, 2, 96, 8,  8, 5, 10, 6, 53, 4,  3, 7, 23, 
    2, 54, 6,  3, 3, 39, 4, 82, 8, 71, 1, 71, 5, 63, 0, 68, 7, 60, 
    4, 45, 0,  1, 8,  5, 7, 74, 1, 82, 5, 70, 3, 57, 6, 52, 2, 95, 
    5,  9, 7, 46, 8, 29, 3, 20, 0, 36, 1,  2, 2, 33, 4, 91, 6, 95
  };
  const int q4541[] = {
    9, 9, // Number of jobs and machines
    7, 56, 8, 70, 2, 33, 1, 25, 4, 67, 5, 63, 0, 78, 6, 74, 3, 46, 
    8, 56, 7, 36, 0, 25, 2, 23, 4, 37, 3, 99, 6, 45, 5, 78, 1, 50, 
    7, 13, 1, 26, 0, 54, 3, 23, 5,  8, 4, 22, 8, 10, 6, 65, 2, 54, 
    8,  4, 6, 57, 2, 78, 3,  5, 7, 75, 5, 26, 1,  9, 4, 70, 0, 18, 
    7, 63, 3, 79, 5, 77, 1,  4, 4, 61, 6, 46, 8, 84, 2, 96, 0, 38, 
    2, 24, 3, 75, 0, 21, 8, 88, 7, 49, 4, 89, 5, 72, 6, 92, 1, 25, 
    6,  8, 4, 29, 3, 46, 5, 83, 8, 32, 7, 69, 1, 65, 0, 41, 2, 38, 
    1, 12, 7, 44, 0, 18, 8, 27, 4, 96, 5, 44, 2, 54, 3, 10, 6,  4, 
    6, 57, 1, 73, 7, 78, 2, 92, 4, 98, 5, 16, 0, 67, 8, 16, 3, 10
  };
  const int q4542[] = {
    9, 9, // Number of jobs and machines
    2, 89, 4, 58, 7, 96, 0,  9, 5, 74, 6, 33, 1, 78, 3, 57, 8, 35, 
    3, 63, 7, 73, 2, 89, 6, 62, 8, 92, 5, 50, 1, 18, 4, 51, 0, 23, 
    4, 13, 8,  5, 7, 99, 5, 29, 3, 59, 6, 35, 0, 21, 2, 22, 1, 21, 
    7, 47, 2, 48, 0, 19, 3, 99, 6, 81, 5, 41, 8, 83, 4, 76, 1, 67, 
    6, 34, 3, 31, 5, 98, 0, 84, 4, 79, 8, 83, 1, 64, 7, 73, 2, 69, 
    5, 30, 1, 25, 6,  4, 7, 46, 0, 59, 4, 99, 8, 85, 2, 80, 3, 65, 
    8, 52, 4, 53, 7, 40, 3, 86, 1, 56, 6, 85, 5, 53, 0, 51, 2, 52, 
    7, 64, 2,  8, 8, 58, 4, 26, 0, 19, 5, 92, 6,  9, 1, 90, 3, 55, 
    3, 43, 5, 41, 2, 65, 8,  9, 1, 44, 0, 23, 4, 22, 7, 80, 6, 88
  };
  const int q4543[] = {
    9, 9, // Number of jobs and machines
    0, 56, 7, 82, 5, 62, 1, 51, 2, 28, 3, 92, 4, 23, 8,  8, 6, 71, 
    3,  1, 0, 14, 4, 65, 6,  4, 8, 55, 5, 23, 1, 50, 2, 70, 7, 36, 
    3, 46, 0, 78, 1, 26, 2, 44, 5, 30, 7, 56, 4, 22, 6, 83, 8, 26, 
    0, 83, 5, 68, 8, 63, 2, 17, 4, 98, 7, 71, 1, 89, 3,  1, 6,  3, 
    0, 50, 5, 88, 8, 93, 4, 76, 6, 99, 7, 89, 1, 87, 3, 40, 2, 33, 
    4, 62, 8, 99, 7, 33, 2, 55, 1, 57, 3, 64, 6, 47, 0, 88, 5, 38, 
    3, 93, 6, 67, 2, 69, 5, 96, 4, 82, 1, 33, 0, 36, 7, 78, 8, 43, 
    6, 99, 3, 73, 1, 13, 7, 46, 0, 64, 4, 33, 8, 55, 2, 27, 5, 52, 
    4, 52, 1, 72, 2, 85, 0, 86, 8, 61, 3, 90, 7, 28, 5, 12, 6, 83
  };
  const int q4544[] = {
    9, 9, // Number of jobs and machines
    3, 14, 2, 47, 4, 25, 0, 12, 1, 15, 5, 35, 6, 24, 8, 76, 7, 23, 
    2, 65, 4, 10, 1, 34, 0, 61, 5, 49, 3, 66, 7, 30, 6, 92, 8, 40, 
    8, 65, 0,  9, 6, 74, 4, 33, 3, 10, 1, 91, 2, 47, 7, 50, 5, 95, 
    4, 83, 3, 57, 2, 80, 7, 53, 8, 54, 0, 38, 5,  2, 1, 70, 6, 67, 
    8, 87, 2, 21, 5, 71, 1, 28, 6, 36, 7, 69, 3, 74, 0, 37, 4, 44, 
    0, 90, 3, 66, 5,  9, 4, 34, 1, 99, 6, 82, 2, 77, 7, 86, 8, 86, 
    5, 88, 0, 67, 2, 26, 6, 76, 3, 16, 4, 21, 1, 59, 7, 74, 8, 93, 
    5, 84, 2, 23, 6, 76, 3, 89, 4, 83, 0, 49, 8, 79, 7, 81, 1, 67, 
    0, 45, 6, 84, 3, 75, 8, 28, 2, 96, 7, 48, 4, 38, 5, 81, 1, 38
  };
  const int q4545[] = {
    9, 9, // Number of jobs and machines
    2, 47, 5, 46, 6,  8, 0, 93, 7, 77, 4, 31, 1, 85, 3,  7, 8, 10, 
    1, 73, 0, 64, 4, 35, 5, 61, 3, 39, 6, 48, 7, 78, 8, 51, 2, 95, 
    7, 93, 2, 10, 1,  3, 5, 41, 6, 41, 3, 30, 0, 82, 4, 79, 8, 48, 
    6, 29, 0, 45, 5, 83, 4, 20, 2, 71, 8, 57, 1, 61, 3, 45, 7, 44, 
    2, 33, 8, 95, 3, 24, 6, 49, 0, 19, 5, 57, 7, 89, 1,  5, 4, 37, 
    5, 86, 7, 32, 0,  7, 4, 82, 1, 59, 2, 59, 3, 80, 6, 98, 8, 67, 
    3, 53, 1, 11, 7, 74, 4, 59, 8, 37, 5, 55, 2, 31, 6, 97, 0, 59, 
    2, 73, 3, 77, 6, 49, 0, 30, 5, 52, 8, 53, 1, 14, 4, 43, 7, 43, 
    5, 29, 1, 70, 3, 94, 7, 54, 0, 29, 2, 42, 8,  8, 4, 48, 6,  5
  };
  const int q4546[] = {
    9, 9, // Number of jobs and machines
    8, 93, 5, 61, 7, 41, 3,  1, 0, 85, 4,  4, 2, 51, 6, 41, 1, 72, 
    4,  5, 1, 18, 3, 80, 6, 32, 7, 67, 5, 37, 0, 27, 2, 99, 8, 30, 
    7, 43, 5, 28, 0, 47, 2,  4, 3,  8, 1, 41, 6, 47, 8, 93, 4, 28, 
    4, 49, 5, 33, 1, 64, 3,  3, 7, 43, 2, 86, 8, 45, 0, 76, 6, 35, 
    2, 54, 0, 68, 5, 64, 4, 49, 8, 34, 7, 43, 3, 67, 6, 64, 1, 63, 
    6, 99, 0, 80, 3, 72, 4, 65, 1,  9, 2,  1, 5,  3, 8, 83, 7, 26, 
    1, 96, 8, 83, 7, 86, 5, 59, 0, 44, 2, 57, 6, 53, 4, 55, 3, 11, 
    7, 64, 0, 76, 2, 93, 5, 54, 6, 39, 1, 71, 8, 18, 3, 51, 4, 40, 
    8, 87, 3, 46, 0, 48, 2, 41, 7, 88, 4, 20, 6, 36, 5, 73, 1, 68
  };
  const int q4547[] = {
    9, 9, // Number of jobs and machines
    3, 79, 0, 86, 1, 84, 6, 47, 8, 53, 7, 10, 5, 94, 4, 12, 2, 42, 
    0, 16, 1, 26, 4,  7, 3, 97, 5, 65, 2, 75, 8, 36, 7, 38, 6, 36, 
    4, 78, 3, 36, 8, 48, 6, 86, 0, 55, 2, 31, 5,  7, 7, 41, 1, 78, 
    6, 53, 8,  1, 3, 70, 5, 27, 7, 28, 1, 75, 0, 22, 2, 40, 4, 89, 
    4, 15, 3, 50, 6, 94, 0, 81, 2, 76, 1, 15, 5, 86, 8, 19, 7, 45, 
    5, 53, 0, 30, 3, 40, 2, 59, 7, 70, 4, 52, 6, 52, 8, 84, 1, 89, 
    1, 40, 7, 46, 3, 63, 4, 57, 8, 27, 0, 25, 2, 60, 6, 43, 5, 23, 
    1,  6, 4, 89, 7, 93, 2, 32, 0, 11, 5, 65, 8, 28, 3,  3, 6, 89, 
    2, 56, 1, 85, 7, 40, 5, 12, 4, 43, 6, 34, 0, 28, 3, 56, 8, 70
  };
  const int q4548[] = {
    9, 9, // Number of jobs and machines
    4, 26, 8, 88, 3, 17, 5, 51, 2, 65, 7,  1, 1, 22, 6, 34, 0, 81, 
    0, 35, 4, 58, 8,  6, 5, 38, 1, 59, 6, 31, 3, 71, 2, 48, 7,  2, 
    4, 22, 3, 22, 1, 72, 2, 65, 7, 22, 0, 54, 6, 64, 8,  4, 5,  4, 
    5, 61, 8, 55, 3, 88, 7,  3, 6, 48, 2, 22, 0, 89, 4, 93, 1, 34, 
    6, 47, 3, 46, 7, 55, 0, 34, 5, 21, 8, 76, 1, 31, 2, 59, 4, 38, 
    5,  1, 4, 82, 1, 73, 2, 92, 8, 39, 7,  3, 6, 74, 3, 51, 0, 45, 
    7, 96, 6, 14, 4, 19, 0, 86, 2, 52, 3, 22, 1,  3, 8,  4, 5, 53, 
    2, 12, 4, 13, 6, 45, 5, 64, 7, 59, 0, 34, 1, 97, 8, 99, 3, 22, 
    5, 64, 8, 42, 0, 56, 6, 58, 1,  6, 4, 65, 2, 25, 3, 71, 7, 30
  };
  const int q4549[] = {
    9, 9, // Number of jobs and machines
    7, 55, 4,  1, 2, 45, 6, 61, 8,  4, 5, 84, 1, 85, 0,  3, 3,  4, 
    7, 59, 8, 90, 6, 88, 0, 82, 5,  9, 2, 24, 4, 63, 3, 34, 1, 21, 
    8, 94, 5, 52, 0, 26, 7, 44, 2, 25, 3, 17, 4, 38, 6, 52, 1,  4, 
    7, 35, 2, 90, 6, 35, 5, 66, 3,  8, 0, 55, 8, 34, 4, 80, 1, 77, 
    0, 15, 4, 96, 7, 98, 2, 48, 8, 86, 5, 18, 3,  3, 1, 57, 6,  3, 
    3, 97, 2, 13, 8,  2, 1, 30, 5, 52, 7, 23, 0, 52, 6, 87, 4, 86, 
    2, 62, 0, 61, 6, 56, 8, 50, 1, 78, 7,  5, 3,  1, 4, 52, 5,  6, 
    8, 22, 2, 20, 3, 13, 1, 26, 5, 38, 4, 85, 0, 36, 6, 73, 7, 37, 
    5, 19, 1, 51, 0, 49, 4, 29, 2, 54, 3, 21, 8, 57, 6, 83, 7,  8
  };
  const int q4550[] = {
    9, 9, // Number of jobs and machines
    5, 73, 7, 40, 1, 55, 4, 83, 2, 25, 0, 11, 8, 80, 6, 82, 3, 22, 
    3,  4, 1,  1, 5, 94, 0, 42, 2, 34, 7, 58, 8, 46, 6, 86, 4, 18, 
    6, 39, 4, 82, 2, 39, 1,  8, 3, 58, 7,  8, 5, 93, 0, 53, 8, 51, 
    8, 20, 4, 96, 0, 34, 6, 42, 5, 66, 2, 72, 3, 77, 1, 77, 7, 58, 
    1, 65, 5, 64, 4, 59, 7, 59, 8, 97, 3, 84, 6, 73, 0, 57, 2, 36, 
    1, 57, 0, 88, 2, 85, 8, 78, 5, 18, 6, 83, 7, 29, 3, 89, 4, 64, 
    3, 35, 1, 99, 5, 83, 4, 36, 7, 13, 2,  2, 0, 99, 8, 18, 6, 70, 
    6, 66, 1,  5, 2,  3, 8,  9, 4, 64, 3, 87, 0, 49, 7, 88, 5, 88, 
    6, 30, 4, 66, 0,  7, 3,  6, 8, 20, 1, 95, 7, 54, 5, 71, 2, 37
  };
  const int q4551[] = {
    9, 9, // Number of jobs and machines
    3, 74, 6, 15, 4, 49, 5, 87, 2, 93, 1, 24, 0, 93, 7, 69, 8, 93, 
    6, 47, 3, 22, 7, 19, 0, 31, 2, 59, 5, 69, 1, 88, 8, 51, 4, 44, 
    1,  7, 7, 29, 4, 30, 5, 65, 2, 70, 6,  3, 3, 58, 0, 56, 8, 79, 
    8, 57, 0, 66, 3, 26, 4, 65, 2, 35, 5, 90, 6, 87, 7, 21, 1, 41, 
    3, 36, 0, 65, 2, 67, 4,  7, 8,  6, 6, 43, 5, 20, 1, 74, 7, 92, 
    1, 57, 6, 86, 2, 62, 5, 53, 7, 99, 3, 22, 0, 55, 4, 19, 8, 50, 
    4, 83, 7, 86, 5, 49, 2, 36, 0, 51, 6, 65, 3, 86, 8, 59, 1, 55, 
    0, 64, 4, 71, 6, 21, 7, 42, 2, 63, 3, 19, 5, 57, 8, 30, 1, 97, 
    0, 86, 7, 57, 8, 72, 1, 16, 6, 92, 4, 12, 2, 90, 3, 42, 5, 77
  };
  const int q4552[] = {
    9, 9, // Number of jobs and machines
    2, 67, 6, 71, 3, 62, 0, 78, 5, 23, 7,  1, 8,  1, 4, 79, 1, 37, 
    0, 80, 6, 60, 4, 87, 8, 49, 7,  2, 5, 37, 1, 88, 3,  9, 2, 36, 
    0, 41, 6, 11, 3,  6, 7, 85, 5, 18, 4,  4, 1, 62, 2, 37, 8, 74, 
    3, 85, 8, 63, 2, 62, 1, 85, 6, 98, 4, 55, 0, 22, 5, 49, 7, 10, 
    3, 26, 8, 49, 6, 29, 0, 81, 1, 18, 2, 24, 5, 28, 4, 76, 7, 80, 
    8, 21, 4, 14, 6, 89, 0, 21, 1, 79, 7, 41, 3,  2, 5, 75, 2, 29, 
    6, 78, 8, 72, 2, 34, 1, 59, 0, 44, 5, 16, 7, 80, 3, 31, 4, 96, 
    1, 22, 6,  3, 7,  3, 3, 12, 0, 88, 4, 58, 2, 94, 8, 74, 5, 73, 
    8,  9, 1, 63, 5,  4, 7, 23, 4, 31, 3,  9, 2, 81, 0, 90, 6, 65
  };
  const int q4553[] = {
    9, 9, // Number of jobs and machines
    3, 48, 0, 59, 4, 58, 7, 32, 5,  2, 6, 80, 8,  7, 2, 25, 1, 11, 
    5, 63, 6, 34, 8, 27, 1, 87, 4, 67, 2, 92, 7, 47, 3, 75, 0, 35, 
    3, 16, 4, 94, 6,  2, 2, 81, 7, 49, 5, 79, 8, 56, 0, 39, 1, 51, 
    3, 23, 8,  2, 0, 31, 7, 26, 6, 79, 5, 79, 4, 32, 2, 94, 1, 54, 
    0, 14, 3, 78, 4, 28, 8, 82, 7, 63, 5, 83, 2, 91, 6, 24, 1, 12, 
    4, 84, 3, 37, 8, 19, 5, 97, 6, 73, 0, 46, 7, 57, 1, 37, 2, 87, 
    8, 94, 5, 59, 3, 84, 7, 48, 4, 20, 6, 32, 2, 43, 0, 22, 1, 89, 
    6, 47, 3, 24, 7, 71, 0, 19, 1,  7, 2, 20, 5, 16, 4, 13, 8, 24, 
    8, 50, 3, 99, 1, 96, 2, 90, 0, 34, 6, 59, 4, 22, 5, 77, 7, 23
  };
  const int q4554[] = {
    9, 9, // Number of jobs and machines
    3, 44, 0, 59, 5, 23, 8,  6, 6, 93, 1, 38, 7, 26, 4, 99, 2, 58, 
    4, 47, 6, 10, 0, 56, 3, 25, 5, 52, 8, 40, 2, 78, 1, 20, 7, 36, 
    6, 17, 1,  8, 5, 21, 8, 26, 0,  1, 2, 14, 4, 40, 7, 35, 3, 31, 
    3, 53, 4, 26, 1, 69, 7, 55, 5,  4, 2, 39, 6, 41, 0, 53, 8, 35, 
    4, 27, 2, 48, 6, 87, 0, 81, 1, 13, 7, 30, 5, 11, 8, 25, 3, 98, 
    2, 59, 5, 47, 4, 83, 1,  5, 7,  2, 3, 71, 8, 92, 6, 65, 0, 35, 
    1, 94, 2,  5, 5, 32, 8, 67, 6, 39, 0, 92, 7, 24, 3, 94, 4, 56, 
    2, 73, 5, 83, 1, 55, 8, 51, 0, 30, 6, 72, 3, 99, 4, 71, 7, 97, 
    4, 59, 2, 79, 1, 52, 7, 67, 3, 89, 0, 22, 5, 58, 6, 75, 8, 25
  };
  const int q4555[] = {
    9, 9, // Number of jobs and machines
    8, 98, 7, 11, 0, 55, 3, 24, 1, 70, 2, 87, 6, 88, 4,  4, 5, 61, 
    6,  3, 1, 39, 4, 66, 2, 27, 3, 41, 7, 44, 5, 35, 0, 77, 8, 96, 
    7, 14, 2, 47, 6, 42, 1, 16, 4, 59, 0, 97, 3,  6, 5, 88, 8, 73, 
    3,  4, 1, 84, 6, 41, 4, 73, 8,  3, 0, 10, 2, 99, 5, 36, 7, 53, 
    2, 38, 0, 68, 7, 74, 3, 95, 4, 60, 1, 47, 5,  9, 6, 56, 8, 77, 
    1, 44, 2, 88, 3, 36, 4, 12, 8,  6, 5, 71, 0, 90, 6, 32, 7, 19, 
    0,  3, 7, 84, 1, 15, 3, 59, 6, 35, 2,  3, 4,  3, 5, 22, 8,  3, 
    8, 14, 5, 80, 2,  7, 4,  6, 3, 30, 0, 98, 7, 80, 6, 26, 1, 91, 
    1, 41, 8, 95, 0, 94, 7, 20, 6, 11, 2,  4, 4, 19, 3, 12, 5, 78
  };
  const int q4556[] = {
    9, 9, // Number of jobs and machines
    8, 41, 7,  4, 4, 73, 1, 64, 6, 27, 3, 18, 5, 81, 0, 25, 2, 61, 
    2, 77, 5, 75, 1, 49, 0, 66, 4, 62, 3, 60, 8, 46, 7, 17, 6,  4, 
    7, 28, 8, 82, 3, 15, 6, 84, 2, 40, 0, 89, 5, 69, 1, 59, 4, 20, 
    6, 37, 0, 61, 4, 73, 2, 88, 5, 43, 7, 10, 3, 57, 8, 93, 1, 99, 
    0,  9, 2, 10, 6, 19, 7, 59, 5, 69, 8, 48, 3, 28, 1, 51, 4, 35, 
    1,  9, 5, 70, 8, 90, 7, 30, 2, 92, 0, 27, 4, 99, 6, 51, 3, 14, 
    5, 44, 2, 99, 3, 90, 8, 63, 0, 58, 7, 54, 6,  6, 4, 85, 1, 17, 
    4, 21, 0,  4, 2, 34, 7, 99, 6, 64, 1, 19, 3, 93, 8, 85, 5, 48, 
    8, 24, 2, 62, 3, 29, 6, 56, 1, 74, 7, 12, 5, 59, 4, 78, 0, 28
  };
  const int q4557[] = {
    9, 9, // Number of jobs and machines
    4, 61, 2, 66, 6, 92, 7, 90, 5, 48, 1, 44, 0, 84, 3, 38, 8, 36, 
    1, 42, 8, 52, 0, 45, 6,  6, 3, 32, 2, 90, 4, 58, 7, 64, 5, 94, 
    2, 83, 8, 94, 6, 15, 1, 72, 3,  9, 5, 86, 4, 92, 7, 22, 0, 43, 
    0, 87, 5, 24, 8, 75, 4, 35, 7, 22, 1, 85, 6, 21, 2, 53, 3, 39, 
    7, 81, 2, 94, 6, 86, 3, 13, 5, 59, 0, 88, 8, 89, 1, 76, 4, 64, 
    5, 73, 3, 32, 8, 71, 4, 29, 6, 32, 7,  8, 0, 71, 1, 42, 2,  1, 
    7, 85, 8, 39, 6, 24, 2, 29, 5, 60, 3, 62, 1, 76, 4,  5, 0, 21, 
    0, 69, 4,  4, 8, 54, 7, 49, 2, 61, 3, 15, 1, 52, 5, 19, 6, 77, 
    1, 15, 0, 44, 3,  6, 8, 36, 5, 57, 7,  3, 4, 22, 6, 33, 2, 64
  };
  const int q4558[] = {
    9, 9, // Number of jobs and machines
    6, 32, 7,  9, 3, 29, 1, 19, 5, 98, 0, 39, 8, 74, 4, 83, 2, 15, 
    3, 84, 0, 49, 2,  8, 8, 74, 6, 18, 5, 12, 7, 44, 1, 81, 4, 82, 
    4,  6, 7, 53, 0, 69, 3, 63, 8, 46, 6, 50, 2, 30, 5, 56, 1, 99, 
    4, 97, 5, 78, 6, 93, 7, 88, 8, 86, 0, 35, 2, 38, 1, 23, 3, 65, 
    8, 33, 4, 75, 7, 67, 5, 89, 2, 13, 0, 76, 1, 36, 6, 29, 3, 70, 
    7, 75, 0, 61, 5, 65, 3, 80, 4, 58, 6, 14, 1, 72, 2, 31, 8, 87, 
    7, 37, 0, 18, 3, 18, 2,  2, 6, 90, 4, 51, 1, 56, 5, 13, 8, 25, 
    8, 97, 3,  2, 1, 89, 6, 38, 0, 40, 5, 64, 7,  6, 2, 88, 4, 54, 
    3, 48, 6, 64, 5, 12, 7, 53, 0, 64, 8, 69, 2, 25, 4, 24, 1, 92
  };
  const int q4559[] = {
    9, 9, // Number of jobs and machines
    1,  5, 7, 82, 3, 76, 4, 25, 5, 76, 2, 85, 6, 61, 0, 82, 8, 94, 
    0,  1, 4, 71, 8, 88, 6, 99, 7, 31, 2,  7, 5, 61, 1, 24, 3, 50, 
    8, 21, 5, 47, 6, 96, 0, 71, 4,  4, 7, 32, 2, 16, 3, 10, 1,  5, 
    2, 46, 8, 47, 7, 67, 4, 57, 1, 68, 6, 77, 0, 83, 5, 97, 3,  9, 
    4, 12, 5, 80, 8, 62, 6, 23, 1, 26, 0, 31, 3, 43, 7, 37, 2, 54, 
    1, 41, 8, 99, 6, 10, 4, 98, 5, 70, 0, 28, 7, 43, 3,  1, 2, 70, 
    3, 55, 7,  5, 0, 44, 4, 12, 6, 98, 8,  6, 2, 13, 1, 47, 5, 72, 
    7, 77, 3, 26, 6, 36, 4, 63, 0, 19, 1, 53, 2, 56, 8, 18, 5, 53, 
    6, 81, 3, 11, 2, 76, 7, 51, 8,  1, 0, 52, 5, 16, 1, 54, 4, 60
  };
  const int q4560[] = {
    9, 9, // Number of jobs and machines
    8, 89, 7, 37, 4, 28, 1,  1, 0, 31, 6, 36, 2, 68, 3, 75, 5, 20, 
    0, 14, 3,  8, 5, 71, 7,  2, 8, 82, 4, 54, 2, 55, 1, 17, 6, 28, 
    2, 43, 7, 99, 6, 38, 8, 97, 1, 68, 5, 73, 0, 20, 3, 61, 4, 34, 
    3,  9, 2, 90, 0, 44, 8,  9, 5, 11, 7, 84, 1, 99, 4, 92, 6, 45, 
    8, 78, 3, 19, 4, 98, 7, 82, 0, 79, 2, 57, 5, 88, 1, 87, 6, 62, 
    3, 12, 6, 56, 0, 78, 5, 92, 7, 70, 2,  1, 4, 63, 8, 62, 1, 39, 
    8, 84, 4, 19, 6,  1, 1, 42, 0, 88, 3, 68, 7, 50, 2, 84, 5, 55, 
    3, 27, 5, 51, 0, 24, 1, 69, 8, 94, 2, 97, 4,  2, 7, 57, 6, 83, 
    1, 55, 6, 39, 7, 17, 8, 11, 3,  1, 5, 82, 2, 60, 4, 66, 0, 62
  };
  const int q4561[] = {
    9, 9, // Number of jobs and machines
    1, 29, 6, 97, 8, 61, 0, 46, 5,  4, 2, 17, 4, 74, 7, 39, 3, 17, 
    8, 91, 6, 24, 7, 34, 2, 72, 4, 55, 0, 25, 3, 13, 1, 14, 5, 34, 
    4, 58, 1, 90, 7, 13, 0, 65, 3, 46, 8,  3, 5, 80, 2, 17, 6, 13, 
    6, 78, 1, 44, 2, 17, 7, 17, 8, 70, 0,  2, 4, 75, 5, 41, 3, 12, 
    4, 70, 8, 89, 3, 77, 2, 41, 0, 48, 7,  4, 5,  6, 6, 20, 1, 70, 
    6, 50, 1, 79, 8, 57, 3, 68, 4, 14, 5,  1, 0, 53, 7, 80, 2, 97, 
    3, 53, 5, 80, 0, 40, 7, 18, 4, 51, 2, 48, 8, 30, 6, 33, 1, 46, 
    2, 91, 5, 87, 4, 58, 3, 29, 8, 48, 0, 19, 7, 36, 1, 18, 6, 24, 
    3, 82, 7, 32, 1, 27, 2, 81, 4, 92, 0, 62, 8, 46, 5, 40, 6, 96
  };
  const int q4562[] = {
    9, 9, // Number of jobs and machines
    6, 75, 7, 66, 1, 14, 0, 28, 5, 67, 2, 63, 8,  8, 3, 12, 4,  3, 
    3, 78, 8, 27, 6, 96, 5, 75, 7, 52, 4, 41, 0, 60, 1, 38, 2, 32, 
    3, 66, 7, 33, 0, 32, 5, 60, 2, 65, 1, 49, 8,  2, 4, 19, 6, 27, 
    3, 41, 0, 75, 4, 59, 1, 19, 6, 62, 5, 77, 2,  3, 7, 40, 8, 92, 
    0, 62, 5, 75, 4, 16, 1, 89, 7, 10, 6, 69, 8, 44, 2, 83, 3, 50, 
    0, 44, 7, 87, 5, 81, 8, 65, 1, 86, 4, 76, 6, 93, 3, 27, 2, 92, 
    0, 36, 8, 70, 2, 24, 6,  8, 5, 63, 3, 83, 4, 51, 7, 11, 1, 22, 
    2, 27, 0, 50, 7, 39, 3, 69, 6, 71, 1, 77, 5, 82, 4, 73, 8, 88, 
    4, 89, 2, 81, 3, 44, 0, 81, 6, 58, 7, 80, 5, 37, 1,  8, 8, 20
  };
  const int q4563[] = {
    9, 9, // Number of jobs and machines
    4, 92, 0, 25, 5,  8, 8, 36, 7, 27, 1,  4, 6, 20, 2, 99, 3, 84, 
    1, 68, 6, 80, 7, 86, 8, 67, 5, 41, 2, 55, 3, 65, 0, 52, 4, 90, 
    4, 90, 6, 45, 3, 23, 0, 11, 2, 96, 8, 31, 1, 63, 7, 18, 5, 22, 
    2, 73, 4, 97, 6, 14, 3, 98, 7, 54, 1, 65, 0, 84, 8, 91, 5, 12, 
    4,  7, 0, 23, 5, 64, 1, 27, 6, 40, 7, 75, 2, 55, 8, 62, 3, 22, 
    0, 62, 2, 21, 7, 78, 3, 60, 8, 33, 6, 45, 1, 39, 4, 49, 5, 80, 
    5, 30, 0, 17, 8, 22, 4, 10, 7, 82, 2, 13, 3, 36, 1, 96, 6, 88, 
    5, 32, 3, 14, 6, 17, 1, 62, 4, 46, 8, 50, 2, 32, 7, 12, 0,  2, 
    5, 13, 2, 35, 1, 44, 6, 42, 4, 41, 0, 13, 7, 59, 8, 96, 3, 95
  };
  const int q4564[] = {
    9, 9, // Number of jobs and machines
    3, 46, 7, 80, 5, 64, 8, 89, 6, 35, 1,  3, 2, 94, 0,  4, 4, 82, 
    7, 76, 2, 98, 4, 24, 5, 54, 1, 58, 8, 34, 0, 50, 6,  4, 3, 95, 
    2, 91, 0, 86, 5, 51, 8, 81, 7, 15, 6,  4, 1, 12, 3,  9, 4, 39, 
    5, 28, 8, 95, 6, 32, 0, 16, 7, 42, 1, 16, 3, 83, 4, 28, 2, 99, 
    8, 90, 4, 13, 5, 67, 2, 15, 0, 82, 7, 32, 1, 82, 6, 16, 3, 89, 
    2, 19, 3, 87, 8, 64, 1, 80, 0, 33, 5, 91, 6, 55, 7, 46, 4, 26, 
    3, 78, 4, 99, 2, 23, 1, 22, 7, 33, 5, 65, 0, 66, 6, 19, 8, 58, 
    7,  6, 4, 91, 0,  8, 2, 38, 1, 15, 3, 40, 6, 51, 5, 35, 8, 85, 
    5, 36, 3, 31, 2, 55, 6,  3, 7, 47, 0, 78, 4, 10, 1, 11, 8, 12
  };
  const int q4565[] = {
    9, 9, // Number of jobs and machines
    3,  2, 2, 29, 0, 97, 8, 66, 7, 67, 5,  7, 4, 88, 6, 75, 1, 59, 
    6, 80, 4, 63, 5, 71, 3, 40, 8, 88, 1, 69, 7, 18, 2, 97, 0, 47, 
    3, 21, 0, 91, 5, 45, 4, 20, 6, 35, 7, 34, 2, 82, 1, 14, 8, 59, 
    4, 29, 8, 37, 7, 12, 2, 23, 6, 28, 0, 88, 3, 11, 1, 17, 5,  9, 
    5, 85, 8, 55, 3, 97, 0, 84, 6,  2, 2, 76, 1, 50, 7, 25, 4, 31, 
    7, 11, 3, 94, 6, 90, 8, 41, 1,  5, 4, 54, 0,  1, 2, 22, 5,  3, 
    2, 39, 1, 59, 0, 93, 7, 44, 4, 76, 8,  1, 6, 47, 3, 74, 5, 74, 
    7, 74, 1,  8, 6, 31, 0, 93, 8, 55, 2, 92, 4, 21, 5, 31, 3, 94, 
    4, 83, 8, 23, 5, 84, 2, 80, 0, 25, 3, 28, 7, 32, 1, 73, 6, 60
  };
  const int q4566[] = {
    9, 9, // Number of jobs and machines
    7, 10, 1,  5, 8, 10, 0, 57, 2, 28, 3, 48, 4, 71, 5, 28, 6, 31, 
    1, 62, 8, 97, 5, 47, 7, 75, 3, 73, 4, 66, 6, 30, 0, 75, 2, 38, 
    8, 49, 2, 89, 4, 50, 6, 64, 7, 44, 3, 28, 1, 91, 5, 50, 0, 89, 
    0, 89, 7, 47, 2, 18, 3, 56, 5, 10, 1, 60, 6,  4, 8, 73, 4, 28, 
    5, 47, 2, 62, 0,  2, 3, 90, 7,  8, 8, 22, 6, 62, 4, 24, 1, 46, 
    5, 50, 4, 73, 2, 74, 7, 27, 3,  2, 1, 84, 8, 10, 6, 71, 0, 91, 
    3, 36, 8, 65, 2, 28, 4, 18, 5,  2, 7, 59, 6, 14, 0, 70, 1, 38, 
    4, 49, 5, 99, 3,  3, 8, 10, 2, 88, 0, 79, 6, 18, 1, 67, 7, 49, 
    4, 28, 8, 31, 7, 19, 3, 86, 5, 41, 0, 44, 2, 70, 1, 80, 6, 84
  };
  const int q4567[] = {
    9, 9, // Number of jobs and machines
    6, 54, 1, 46, 5, 98, 7, 97, 0, 83, 4, 50, 2, 97, 3, 35, 8, 89, 
    2, 79, 1, 90, 4, 78, 6, 52, 7, 14, 8, 11, 3, 75, 5, 24, 0, 21, 
    5, 48, 2,  6, 3, 13, 0, 90, 1, 51, 4, 87, 7,  8, 6,  6, 8, 27, 
    5,  2, 4, 39, 8, 32, 6, 14, 3, 38, 0, 10, 7, 91, 1, 65, 2, 50, 
    0, 71, 7, 62, 4, 17, 3, 80, 5, 43, 1, 64, 8,  3, 6, 11, 2, 23, 
    2, 90, 4, 39, 1, 65, 3, 20, 0, 57, 6, 41, 8, 72, 5, 72, 7, 79, 
    7, 92, 6, 88, 5, 43, 3, 52, 2, 95, 4, 43, 8, 47, 1, 37, 0, 61, 
    4, 24, 3, 33, 6, 51, 0, 51, 7, 26, 1, 89, 5, 42, 2, 90, 8,  7, 
    8, 28, 0, 65, 2, 32, 7, 48, 3, 52, 4, 11, 6, 43, 5, 99, 1, 54
  };
  const int q4568[] = {
    9, 9, // Number of jobs and machines
    0, 88, 8, 41, 6, 30, 5, 98, 3, 37, 4, 92, 2, 92, 1, 46, 7, 53, 
    1, 81, 6, 84, 2, 59, 7, 87, 5, 43, 4, 19, 3, 36, 0, 87, 8, 87, 
    1,  3, 5, 23, 6, 31, 3, 98, 0, 33, 7, 40, 8, 38, 2, 31, 4, 25, 
    0, 72, 7, 72, 6, 89, 5, 31, 4, 29, 1, 16, 2, 58, 3, 55, 8, 54, 
    6, 60, 8, 70, 5, 50, 2, 79, 7, 38, 4, 63, 0, 20, 1, 56, 3, 79, 
    5, 83, 3, 73, 6, 61, 7, 87, 8, 65, 4, 98, 2, 72, 1, 84, 0, 61, 
    4, 64, 8, 55, 2, 10, 7, 78, 5, 45, 0, 53, 3, 88, 1, 78, 6, 62, 
    0, 38, 3, 55, 4, 35, 6, 51, 8, 68, 1, 99, 2, 88, 7, 30, 5, 41, 
    0, 22, 7, 27, 1, 72, 5, 39, 3, 91, 2, 57, 6, 62, 4, 18, 8, 21
  };
  const int q4569[] = {
    9, 9, // Number of jobs and machines
    8, 17, 3, 19, 1, 19, 7, 80, 2, 38, 6, 66, 5, 21, 0, 18, 4,  4, 
    4,  7, 5, 20, 3, 37, 2, 36, 6, 60, 7, 21, 0, 21, 8, 80, 1, 33, 
    2, 56, 7, 60, 6,  1, 0, 52, 4, 71, 1, 22, 3, 65, 5, 94, 8, 16, 
    0, 57, 6, 59, 7, 84, 4, 91, 8, 34, 2, 32, 3, 14, 1, 67, 5, 47, 
    5, 40, 7, 57, 1, 33, 2, 91, 3, 11, 6, 98, 8, 64, 4, 34, 0, 25, 
    2, 68, 3, 97, 0, 89, 8, 19, 4,  4, 7, 61, 5, 76, 6, 61, 1, 80, 
    7, 97, 0, 33, 2, 49, 3, 37, 6, 83, 1, 88, 8, 77, 4, 80, 5, 53, 
    0, 62, 4, 66, 8, 13, 1, 54, 6, 88, 3,  5, 7, 89, 2, 85, 5, 54, 
    4,  5, 2, 45, 1, 73, 3, 49, 7, 72, 0, 36, 6, 44, 5, 14, 8, 31
  };
  const int q4570[] = {
    9, 9, // Number of jobs and machines
    7, 29, 6, 40, 0, 36, 1, 48, 5, 44, 2, 91, 8, 14, 3, 98, 4, 72, 
    6, 84, 8, 26, 3, 64, 0, 62, 1, 91, 4, 63, 5, 64, 2, 91, 7, 26, 
    7, 40, 6, 69, 8,  3, 0, 70, 2,  2, 1, 48, 4, 19, 3, 79, 5, 95, 
    7, 91, 4, 83, 6, 24, 3, 29, 8, 67, 2, 68, 5,  4, 1, 75, 0, 77, 
    0, 49, 8, 11, 2, 62, 6, 53, 3, 11, 1, 87, 5, 99, 4, 98, 7, 94, 
    3, 73, 6, 39, 5, 74, 0, 96, 1, 21, 7, 85, 2, 80, 4, 96, 8, 74, 
    7, 53, 0, 46, 8, 62, 3, 79, 6, 94, 1, 96, 5, 57, 2, 34, 4, 68, 
    8, 92, 1, 64, 6, 36, 2, 52, 5, 79, 4, 38, 7, 53, 0, 51, 3, 81, 
    5, 45, 7, 83, 1, 38, 0, 50, 6, 72, 2, 83, 8,  3, 3, 36, 4, 35
  };
  const int q4571[] = {
    9, 9, // Number of jobs and machines
    0, 46, 3, 91, 7,  2, 5, 91, 6, 92, 8, 21, 1, 74, 4, 16, 2, 89, 
    4, 12, 2, 30, 5, 95, 7,  5, 8, 23, 0, 32, 3, 99, 1, 25, 6, 83, 
    6, 15, 8, 15, 0, 99, 1, 32, 7, 56, 5,  4, 4, 54, 2,  5, 3, 51, 
    5, 64, 4, 20, 3, 24, 1,  7, 7, 73, 0, 29, 2, 54, 6, 65, 8,  1, 
    7, 45, 8,  4, 2, 49, 3, 24, 0,  3, 5, 39, 6, 22, 4, 45, 1,  1, 
    1,  4, 7, 82, 0, 24, 2, 45, 5, 10, 3, 30, 8, 94, 6, 64, 4, 26, 
    0, 39, 1, 65, 2, 48, 3, 54, 6, 68, 5, 85, 8, 50, 4,  8, 7,  7, 
    4, 17, 2, 98, 7, 58, 5, 57, 8, 41, 0, 68, 1, 60, 6, 94, 3, 29, 
    6, 83, 5, 55, 0, 82, 8, 76, 2, 52, 7, 58, 1, 51, 3, 40, 4, 27
  };
  const int q4572[] = {
    9, 9, // Number of jobs and machines
    7, 43, 3, 58, 4, 25, 0, 10, 6, 29, 1,  1, 8, 57, 2, 85, 5, 65, 
    1, 61, 6, 94, 2, 64, 4, 35, 3, 27, 7, 30, 0, 35, 5, 41, 8,  9, 
    5, 66, 3, 77, 2,  8, 4, 44, 0, 78, 6, 48, 8, 77, 7, 20, 1, 97, 
    2, 44, 8, 91, 0, 88, 3, 45, 4, 83, 7, 69, 1, 69, 5, 65, 6, 80, 
    5, 59, 3, 80, 0, 53, 2, 47, 6, 41, 4, 55, 1, 25, 8, 93, 7, 32, 
    7, 37, 4, 33, 0,  8, 5, 24, 3, 27, 1,  6, 6, 80, 8,  8, 2, 94, 
    5, 87, 4, 33, 3,  8, 1, 51, 0, 78, 8, 69, 2, 35, 7, 42, 6, 26, 
    3, 26, 4,  9, 2, 90, 6, 86, 0, 16, 8,  9, 5, 15, 7, 58, 1,  3, 
    1, 42, 8,  1, 5, 21, 2, 99, 4, 47, 3, 68, 0, 23, 7, 17, 6,  1
  };
  const int q4573[] = {
    9, 9, // Number of jobs and machines
    1, 72, 3, 13, 8, 42, 7, 96, 5, 32, 0, 38, 2, 18, 6, 33, 4, 37, 
    0, 46, 8, 77, 7, 27, 4, 18, 6, 76, 1, 96, 2, 39, 3, 77, 5,  2, 
    2, 47, 5, 65, 7, 31, 4, 69, 0,  8, 8, 62, 1, 79, 6,  7, 3, 97, 
    6, 42, 4, 33, 7,  3, 1, 45, 3, 45, 5, 74, 8, 52, 2, 60, 0, 13, 
    7, 34, 1, 90, 6, 17, 2, 45, 8, 79, 5, 90, 4, 74, 3, 35, 0, 25, 
    7,  6, 5, 44, 3, 50, 8, 26, 0, 27, 4, 90, 6, 36, 2, 77, 1, 67, 
    8,  5, 6, 95, 7, 82, 5, 21, 2, 65, 1, 61, 3, 86, 4, 39, 0, 28, 
    3, 40, 2, 85, 5, 84, 7, 91, 4,  6, 8,  7, 1, 85, 6, 52, 0, 95, 
    5, 35, 4, 69, 3, 76, 8,  2, 1, 75, 6, 59, 7, 86, 0, 75, 2, 52
  };
  const int q4574[] = {
    9, 9, // Number of jobs and machines
    0, 66, 3, 15, 7, 31, 5, 12, 1, 29, 4, 53, 6, 21, 8, 61, 2, 38, 
    2, 53, 6, 27, 1,  8, 3, 37, 4,  7, 7, 46, 8, 36, 0, 65, 5, 38, 
    8, 16, 3, 12, 7, 14, 1, 16, 0, 13, 6, 36, 4, 91, 2, 37, 5, 15, 
    0, 46, 7, 61, 4, 36, 1, 91, 2, 35, 8, 27, 3, 66, 6, 46, 5, 21, 
    1, 99, 2, 53, 6, 12, 3, 11, 8, 82, 7, 47, 4, 20, 0,  8, 5, 24, 
    5, 52, 2, 11, 8, 46, 7,  3, 1, 65, 4, 53, 6, 99, 3, 86, 0, 74, 
    8, 70, 1, 88, 2, 33, 3, 33, 5, 12, 6, 88, 0, 15, 7, 91, 4, 36, 
    2, 63, 8, 17, 4, 88, 6, 26, 0, 56, 7, 81, 1, 27, 5, 34, 3, 50, 
    3, 13, 5, 47, 2, 55, 0,  3, 6, 41, 4, 15, 7, 10, 1, 62, 8, 33
  };
  const int q4575[] = {
    9, 9, // Number of jobs and machines
    0, 78, 4, 51, 3, 90, 1, 32, 5, 20, 2, 45, 6, 13, 8,  6, 7, 35, 
    6, 64, 0,  5, 3, 85, 2, 14, 5, 95, 1,  5, 4, 70, 8, 91, 7, 10, 
    1, 82, 5,  3, 2, 96, 7, 80, 4, 89, 3, 15, 6, 62, 8, 58, 0, 10, 
    1, 67, 8, 77, 6,  8, 4, 39, 7, 62, 0, 21, 2, 15, 3, 26, 5, 59, 
    6, 76, 7, 89, 8, 38, 4, 74, 2, 29, 3, 72, 5, 73, 1, 55, 0, 15, 
    8, 22, 5, 92, 7, 56, 1, 91, 3, 30, 6, 16, 2, 40, 4, 55, 0, 39, 
    8, 89, 7, 60, 3, 18, 4, 22, 1, 96, 6, 83, 2, 47, 5, 41, 0, 94, 
    7, 50, 2,  5, 5, 89, 3, 74, 0, 49, 4, 91, 1, 69, 8, 80, 6, 89, 
    5, 28, 0, 28, 7, 97, 8, 28, 4, 82, 6, 70, 1, 41, 2, 38, 3,  6
  };
  const int q4576[] = {
    9, 9, // Number of jobs and machines
    7, 16, 4, 68, 6, 16, 8, 43, 1, 63, 5, 18, 0, 82, 2, 69, 3, 61, 
    8, 34, 2, 78, 7, 61, 3, 27, 5, 87, 6, 18, 0, 71, 4, 71, 1, 95, 
    6, 30, 2, 63, 0, 72, 4, 46, 3, 58, 1, 82, 7,  3, 5, 73, 8, 49, 
    0, 11, 5, 76, 3, 38, 4, 68, 8, 59, 1, 59, 7, 37, 2, 40, 6, 96, 
    8, 83, 0, 99, 2, 66, 1, 47, 5, 23, 3, 75, 7, 95, 6, 33, 4, 96, 
    5, 70, 0, 12, 2, 33, 8, 67, 7, 15, 3, 46, 1, 62, 6, 86, 4, 18, 
    4,  1, 5, 50, 3, 39, 8, 93, 6, 99, 2,  1, 0, 77, 1, 40, 7, 34, 
    7, 83, 4, 48, 3, 65, 6, 89, 0, 91, 2, 46, 1,  8, 5, 77, 8, 25, 
    6, 19, 2, 47, 4, 27, 3, 40, 8, 46, 5, 41, 0, 18, 7, 36, 1, 60
  };
  const int q4577[] = {
    9, 9, // Number of jobs and machines
    8, 68, 3, 67, 0, 61, 4, 20, 1, 20, 5, 50, 7, 43, 2, 48, 6, 85, 
    7, 10, 1, 98, 2, 48, 0, 33, 4, 68, 5, 61, 3, 54, 6, 62, 8, 58, 
    1, 54, 8, 56, 7, 94, 6, 70, 0, 76, 3, 61, 2, 50, 5, 45, 4, 44, 
    7, 56, 4, 93, 8, 32, 3, 71, 5, 55, 2, 25, 0, 73, 6, 88, 1, 69, 
    7, 16, 6, 43, 3, 64, 1, 23, 5, 61, 8, 25, 2, 80, 0, 44, 4, 69, 
    3, 38, 7, 40, 0, 95, 8, 47, 4, 10, 1, 79, 2, 76, 6, 94, 5, 10, 
    7, 21, 6, 75, 8, 91, 1, 21, 3, 26, 5, 33, 4, 93, 2,  6, 0, 52, 
    0, 54, 3, 61, 8, 29, 5, 18, 1, 35, 2, 25, 4, 99, 6,  6, 7, 92, 
    8, 19, 3, 95, 6, 30, 1, 47, 2, 61, 4, 57, 5, 13, 0, 18, 7,  2
  };
  const int q4578[] = {
    9, 9, // Number of jobs and machines
    8, 33, 2, 50, 5,  2, 3, 15, 0, 74, 7, 11, 4, 85, 6, 30, 1, 75, 
    7, 84, 4, 70, 0, 48, 6, 71, 8, 40, 2, 81, 5, 46, 1, 91, 3, 87, 
    4, 92, 1, 59, 7, 40, 5, 52, 3,  5, 2, 74, 0, 37, 6, 87, 8, 87, 
    2, 10, 3,  5, 8, 75, 0, 80, 4, 92, 5, 38, 7, 99, 6, 92, 1, 72, 
    4, 38, 5, 70, 6, 57, 2, 30, 1, 72, 7,  1, 3, 47, 0, 79, 8, 73, 
    3, 67, 5, 24, 6,  1, 2, 63, 0, 27, 8, 91, 4, 23, 7, 53, 1, 36, 
    1, 84, 2, 75, 7,  6, 8, 74, 6, 26, 3, 24, 4, 91, 5, 99, 0, 73, 
    7, 11, 8, 51, 3, 41, 2, 53, 6, 45, 5, 32, 0, 47, 4, 38, 1, 35, 
    1, 23, 8, 54, 3, 53, 0, 25, 6,  4, 2, 68, 5, 54, 7, 14, 4, 83
  };
  const int q4579[] = {
    9, 9, // Number of jobs and machines
    5, 44, 1, 32, 0, 21, 4, 14, 7, 17, 8, 65, 6, 10, 2, 86, 3, 28, 
    1, 34, 6, 70, 2, 62, 7,  8, 3, 51, 8, 65, 5, 31, 4, 52, 0,  3, 
    8, 70, 0, 15, 6, 31, 4, 65, 3, 29, 5, 15, 7, 22, 1, 76, 2, 61, 
    8, 69, 3, 88, 2, 87, 0, 89, 4, 98, 5, 74, 6, 91, 1, 28, 7, 16, 
    0, 14, 5,  7, 7, 49, 4, 90, 1, 69, 2, 47, 8, 52, 3, 60, 6, 26, 
    0, 32, 3, 35, 4, 83, 8, 73, 5, 76, 1, 15, 6,  2, 2, 40, 7, 80, 
    5, 72, 0, 26, 1, 86, 6, 72, 3,  1, 2, 97, 7, 97, 8, 78, 4, 67, 
    2, 14, 7, 68, 4, 57, 1, 72, 5,  3, 6, 12, 3, 36, 0, 23, 8, 51, 
    8, 53, 4, 89, 7,  7, 5, 55, 6,  8, 1, 15, 2, 38, 0, 10, 3, 67
  };
  const int q4580[] = {
    9, 9, // Number of jobs and machines
    1, 51, 7, 14, 5, 92, 0,  9, 8, 65, 2, 54, 6, 63, 4, 75, 3, 57, 
    1, 88, 4, 57, 2, 19, 6, 29, 3, 21, 0, 65, 7, 66, 5, 13, 8,  6, 
    7, 44, 3, 62, 0, 78, 4, 26, 1, 97, 5, 89, 6, 79, 8, 87, 2, 36, 
    6,  3, 0, 96, 7, 36, 1, 78, 4, 31, 2, 74, 5, 30, 3,  8, 8, 36, 
    8, 65, 4, 94, 6,  3, 1, 60, 2, 82, 3, 10, 5, 34, 7, 85, 0, 86, 
    3, 97, 1, 60, 0, 98, 2, 26, 8, 36, 4, 45, 7, 61, 6, 21, 5, 67, 
    0, 24, 8, 79, 4, 62, 7, 69, 1, 68, 2, 24, 3, 69, 5, 98, 6, 67, 
    2, 34, 7, 88, 3, 19, 4, 28, 6, 40, 8, 22, 5, 55, 0, 52, 1, 81, 
    6, 69, 2, 25, 5, 91, 4, 14, 3, 85, 8, 31, 0, 79, 1,  1, 7, 50
  };
  const int q4581[] = {
    9, 9, // Number of jobs and machines
    2,  5, 0, 65, 8,  3, 6, 46, 7, 57, 4, 44, 3, 67, 1, 10, 5, 82, 
    3, 25, 8, 92, 5, 23, 6, 32, 4, 24, 0,  4, 7, 95, 1, 62, 2, 19, 
    4, 36, 8, 15, 5, 93, 1, 52, 0, 83, 7, 77, 3, 32, 6, 95, 2, 21, 
    0,  1, 3, 81, 4, 80, 1, 47, 5, 36, 7,  9, 8, 67, 2, 61, 6, 49, 
    8, 74, 5, 24, 2, 63, 6, 16, 3, 42, 0, 75, 4, 64, 7, 79, 1, 41, 
    1, 38, 2, 57, 4, 98, 8, 36, 0, 75, 3, 27, 6, 72, 5, 75, 7, 43, 
    5,  3, 0, 28, 1, 75, 4, 25, 7,  5, 8, 65, 3, 73, 6, 76, 2, 80, 
    7, 35, 5, 31, 1, 60, 2, 41, 6, 85, 0, 37, 3, 38, 8, 23, 4,  1, 
    8, 19, 1, 62, 2, 94, 3, 37, 4, 58, 6, 70, 0, 99, 5, 34, 7, 23
  };
  const int q4582[] = {
    9, 9, // Number of jobs and machines
    0, 46, 4, 82, 2, 65, 7, 17, 5, 59, 8, 39, 1, 48, 6, 33, 3, 34, 
    8, 32, 3, 20, 7, 28, 5, 59, 0, 54, 6, 76, 1, 23, 4,  9, 2, 21, 
    8,  7, 3, 24, 2,  9, 7, 97, 5, 25, 4, 23, 6, 36, 1, 97, 0, 73, 
    1,  6, 6, 32, 0, 26, 2,  9, 7, 97, 5, 89, 8, 40, 3, 49, 4, 77, 
    6, 21, 8, 86, 1, 98, 7, 98, 5, 75, 2, 24, 3, 84, 0,  8, 4, 23, 
    4, 33, 7, 25, 0, 39, 6, 35, 2, 98, 8, 38, 1, 98, 5, 88, 3, 80, 
    3, 91, 4, 66, 7, 84, 5, 70, 0, 85, 8, 91, 2, 56, 6, 83, 1, 98, 
    4, 68, 6,  6, 3, 27, 5,  9, 2, 49, 7, 82, 1, 69, 0, 96, 8, 10, 
    5,  7, 2, 68, 7, 29, 6,  8, 4, 20, 8, 87, 1,  8, 3,  8, 0, 90
  };
  const int q4583[] = {
    9, 9, // Number of jobs and machines
    3, 52, 2, 82, 6, 61, 0, 86, 4, 61, 7, 97, 5, 62, 8, 98, 1, 72, 
    1, 41, 5, 68, 3, 30, 2, 70, 0,  9, 8, 17, 7, 32, 4, 26, 6, 64, 
    1,  3, 4, 36, 3, 16, 6, 36, 8, 27, 2, 56, 7, 66, 0, 14, 5, 36, 
    6, 55, 8, 56, 5,  1, 1, 31, 2, 31, 7, 95, 4, 65, 0, 85, 3, 15, 
    1, 81, 6,  3, 0, 38, 5, 27, 2, 39, 3, 10, 8, 99, 7, 33, 4, 57, 
    6, 86, 4,  3, 5, 82, 1, 50, 0, 38, 2, 60, 8,  2, 7, 81, 3, 30, 
    5, 21, 2, 93, 1, 12, 3,  3, 7, 42, 6, 17, 4, 80, 0, 12, 8, 24, 
    1, 97, 3, 45, 4, 47, 0, 68, 6,  9, 2, 68, 8, 23, 5,  7, 7, 15, 
    0, 82, 7, 24, 8,  8, 5, 26, 3, 45, 4, 83, 2,  1, 6, 24, 1, 13
  };
  const int q4584[] = {
    9, 9, // Number of jobs and machines
    8, 67, 3,  1, 0, 60, 4, 64, 1, 33, 2, 42, 7, 65, 5, 78, 6, 83, 
    1, 39, 8, 65, 6, 72, 3, 31, 7, 64, 0, 64, 5, 27, 2, 60, 4, 66, 
    2, 27, 5,  1, 6,  9, 8, 77, 3, 26, 0, 50, 1, 94, 4, 54, 7, 49, 
    0,  2, 8, 14, 7,  3, 2, 85, 6, 81, 5, 12, 4, 45, 3, 22, 1, 20, 
    7, 37, 8,  8, 5, 70, 2, 30, 6, 65, 1, 62, 4,  8, 0, 50, 3, 28, 
    8, 66, 2, 51, 1, 95, 7, 97, 3, 75, 5, 61, 0, 30, 6, 19, 4, 32, 
    1, 59, 3, 75, 5, 39, 8, 10, 2, 68, 4, 80, 0, 42, 7,  1, 6, 18, 
    7, 41, 6, 36, 3, 49, 1, 21, 2, 77, 5, 92, 8, 88, 4, 80, 0, 27, 
    1, 49, 6, 83, 3, 66, 2, 26, 0, 37, 4, 91, 8, 66, 7, 27, 5, 10
  };
  const int q4585[] = {
    9, 9, // Number of jobs and machines
    2, 21, 0, 70, 8, 83, 1, 70, 4,  5, 7, 10, 5, 96, 3, 38, 6, 91, 
    0, 46, 3, 79, 5, 62, 7, 90, 6, 86, 1, 20, 2, 65, 8, 33, 4, 75, 
    1, 27, 5, 32, 3, 82, 4, 30, 7, 28, 2,  7, 0, 53, 8, 68, 6, 36, 
    3, 73, 8, 26, 1, 67, 4, 80, 5, 82, 2, 15, 6, 15, 0, 83, 7, 16, 
    2, 51, 8, 92, 4, 75, 5, 92, 6, 21, 1, 11, 3, 81, 0, 11, 7, 17, 
    0, 86, 8, 80, 4, 35, 7, 10, 6, 22, 2, 65, 5, 48, 3, 62, 1, 72, 
    0, 80, 7, 87, 3,  8, 2, 46, 6, 72, 5, 94, 1, 46, 8, 73, 4,  5, 
    8,  6, 2, 51, 1, 12, 3,  9, 6, 73, 4, 29, 0, 31, 5, 11, 7, 63, 
    3, 56, 5, 10, 1, 14, 7, 68, 2, 65, 0, 21, 8, 89, 6, 86, 4, 67
  };
  const int q4586[] = {
    9, 9, // Number of jobs and machines
    4, 94, 1,  5, 5, 97, 0, 33, 2, 45, 8, 74, 3, 24, 6, 55, 7, 64, 
    6, 20, 4, 88, 3, 73, 0, 97, 2, 43, 7, 98, 8, 89, 1, 59, 5, 10, 
    7, 28, 8, 24, 3, 81, 4, 12, 1, 58, 5,  3, 6, 50, 0, 80, 2, 11, 
    3, 18, 6,  4, 5, 46, 1, 98, 7, 98, 8, 98, 4, 89, 2, 12, 0, 57, 
    1, 50, 4, 11, 5, 54, 2, 58, 7, 82, 0, 43, 6, 54, 8, 64, 3, 59, 
    3, 27, 1, 29, 0, 74, 4, 26, 5, 84, 6, 56, 2, 92, 8, 45, 7, 50, 
    8, 90, 2, 32, 3, 49, 5, 80, 6, 79, 1, 20, 7, 90, 0, 10, 4, 71, 
    2, 54, 0, 51, 5, 18, 4, 62, 7,  4, 1, 60, 6, 42, 3, 63, 8, 11, 
    6, 40, 3,  7, 4, 97, 8, 53, 7, 99, 5, 72, 2, 92, 0, 29, 1, 78
  };
  const int q4587[] = {
    9, 9, // Number of jobs and machines
    3, 21, 5, 24, 7, 77, 4, 75, 1, 53, 8, 50, 2, 60, 6, 56, 0, 65, 
    0, 71, 3, 96, 4,  2, 5, 45, 8, 12, 6, 98, 7, 30, 2, 23, 1, 54, 
    7, 37, 2,  5, 3,  8, 1, 21, 0, 64, 4, 69, 6, 43, 5, 50, 8,  3, 
    6, 43, 3, 66, 7, 19, 8, 46, 2, 57, 4,  6, 5, 33, 0, 94, 1, 23, 
    8, 34, 0, 13, 2, 99, 4, 69, 6, 42, 5, 69, 3,  1, 7, 87, 1, 99, 
    3,  3, 7,  3, 5, 72, 0,  5, 2, 22, 8, 91, 1, 34, 4, 74, 6, 98, 
    2, 96, 1, 13, 4, 21, 7, 76, 3, 17, 6, 39, 5, 22, 8, 92, 0, 83, 
    7, 80, 0, 97, 2, 35, 6, 61, 1, 69, 4, 14, 5, 66, 3, 10, 8, 14, 
    5, 22, 2, 44, 0, 72, 6, 32, 7, 36, 1,  3, 8, 15, 3, 64, 4, 96
  };
  const int q4588[] = {
    9, 9, // Number of jobs and machines
    7, 39, 0,  1, 8, 10, 5, 55, 2, 51, 6,  7, 3, 45, 1, 35, 4, 61, 
    4, 41, 2, 12, 7, 56, 5, 90, 1,  2, 8, 60, 0,  5, 3, 85, 6, 11, 
    4, 88, 7, 75, 6, 84, 3, 46, 1, 18, 0, 15, 2, 96, 8, 29, 5, 67, 
    7, 68, 1, 79, 8, 33, 0, 96, 6, 21, 2, 17, 4, 28, 3, 69, 5,  5, 
    5, 26, 2, 62, 1, 93, 8, 70, 0, 46, 7,  6, 6, 24, 4, 13, 3, 76, 
    5, 64, 4, 63, 1, 51, 2, 89, 6, 83, 8, 97, 7, 18, 0, 32, 3,  8, 
    2, 56, 3, 24, 6, 50, 1,  8, 7, 99, 8, 59, 0, 36, 5,  7, 4, 54, 
    0, 70, 5, 62, 1, 46, 7,  2, 6, 49, 4, 52, 3, 18, 2, 20, 8, 79, 
    3, 29, 1, 19, 6, 21, 5, 36, 2, 73, 0, 43, 4, 23, 8, 28, 7, 26
  };
  const int q4589[] = {
    9, 9, // Number of jobs and machines
    3, 89, 8, 44, 7, 71, 0,  5, 4, 70, 1, 96, 2, 77, 5, 32, 6, 73, 
    3, 41, 5, 82, 0, 93, 2, 90, 4, 29, 6, 52, 8, 83, 7, 67, 1, 37, 
    8, 72, 1, 74, 3, 52, 6,  5, 7, 99, 4, 69, 5, 76, 0,  5, 2, 44, 
    7, 62, 4, 92, 8,  7, 1, 77, 6, 71, 2, 17, 5, 35, 3, 40, 0, 67, 
    4, 89, 3,  1, 0, 87, 8, 13, 7, 94, 2, 20, 1, 91, 6, 58, 5, 69, 
    4, 67, 2, 69, 7, 52, 1, 35, 6, 70, 0, 39, 3, 40, 8, 78, 5, 44, 
    5, 24, 8, 57, 4,  2, 1, 70, 0, 48, 2,  6, 7, 39, 6, 47, 3, 66, 
    1, 47, 4, 54, 3, 62, 8, 44, 6, 32, 5, 28, 2, 28, 0, 36, 7, 91, 
    8, 17, 5, 43, 1, 46, 0, 11, 6, 16, 3, 52, 7, 27, 4, 52, 2, 62
  };
  const int q4590[] = {
    9, 9, // Number of jobs and machines
    1, 15, 5, 84, 7, 56, 2, 44, 0,  8, 3, 80, 4, 93, 8, 93, 6, 80, 
    6, 22, 8, 17, 2, 66, 0, 71, 1, 19, 4, 48, 5, 91, 7,  2, 3, 16, 
    2,  7, 3,  9, 0, 53, 8, 19, 1, 61, 7, 51, 4, 39, 6, 98, 5, 65, 
    0, 26, 8, 43, 2, 97, 3, 89, 5, 74, 7, 60, 1, 71, 4, 79, 6, 37, 
    0, 61, 2, 30, 4, 87, 7, 30, 3, 10, 6, 15, 8, 13, 1,  2, 5,  1, 
    6, 22, 4, 37, 8, 27, 0, 66, 5, 21, 7, 98, 1, 55, 2, 13, 3, 16, 
    5,  8, 8, 64, 7, 57, 0, 98, 1, 78, 4, 37, 3, 70, 2, 38, 6, 65, 
    4, 50, 2, 79, 8, 26, 5, 54, 3, 30, 0,  7, 7, 21, 6, 53, 1, 92, 
    8, 92, 3, 87, 0, 82, 6, 61, 2, 95, 5, 82, 4, 68, 7, 86, 1, 19
  };
  const int q4591[] = {
    9, 9, // Number of jobs and machines
    1, 63, 0, 20, 4, 19, 3, 93, 2, 25, 7, 43, 8, 72, 6, 31, 5, 44, 
    1,  3, 0, 99, 6, 41, 3, 32, 7, 44, 8,  1, 4, 32, 5, 80, 2, 89, 
    8, 49, 0, 49, 3, 49, 5, 62, 7,  4, 2, 27, 6, 26, 4, 87, 1, 41, 
    6, 66, 0, 48, 2, 30, 4,  5, 8, 46, 1, 69, 5, 67, 3, 58, 7,  5, 
    7, 73, 2,  9, 0, 84, 1, 10, 5, 37, 8, 13, 6, 47, 3, 99, 4, 52, 
    4, 41, 2, 26, 0, 55, 3, 34, 6, 84, 1, 19, 7, 69, 5, 60, 8, 68, 
    1, 40, 5, 84, 0, 93, 6, 64, 8, 16, 2, 11, 7, 11, 4, 98, 3, 54, 
    2, 23, 4, 77, 8, 81, 5,  1, 6, 65, 0, 71, 3, 88, 7, 33, 1, 87, 
    2, 70, 5, 27, 8, 68, 7, 18, 3, 28, 0, 50, 4, 80, 1, 81, 6, 35
  };
  const int q4592[] = {
    9, 9, // Number of jobs and machines
    4, 38, 2, 41, 7, 16, 3, 24, 5, 63, 8, 17, 0, 92, 1, 20, 6, 81, 
    7,  6, 0, 46, 5, 29, 3, 45, 2, 68, 8, 58, 1, 82, 6, 33, 4, 43, 
    6, 92, 3, 50, 0, 71, 1, 27, 5, 36, 8, 34, 2, 42, 7, 96, 4,  7, 
    0, 41, 2, 53, 6, 20, 4,  4, 8, 92, 7, 21, 1, 43, 5,  6, 3, 66, 
    8, 40, 1, 38, 6, 59, 5, 68, 7, 27, 2,  6, 0,  4, 3, 25, 4, 55, 
    1, 35, 3, 28, 2, 93, 5, 51, 7, 93, 8, 29, 6, 98, 4, 26, 0, 90, 
    5, 30, 2, 95, 1, 29, 0, 70, 7, 47, 4, 97, 3, 20, 8, 71, 6, 51, 
    0, 28, 6, 75, 3, 42, 7, 94, 8,  8, 1, 18, 4, 60, 5, 89, 2, 51, 
    5, 96, 6,  8, 7, 22, 3, 74, 1, 45, 4, 36, 2, 82, 0, 40, 8, 24
  };
  const int q4593[] = {
    9, 9, // Number of jobs and machines
    3,  5, 7, 53, 6, 80, 1, 37, 5, 57, 4, 27, 8, 69, 0, 47, 2, 53, 
    1, 40, 7, 35, 8, 65, 3, 77, 4, 15, 0, 54, 5, 64, 6, 54, 2, 49, 
    8, 65, 3, 21, 6, 19, 2, 43, 0, 85, 7, 29, 4,  5, 5, 62, 1, 52, 
    7, 13, 2, 12, 1, 80, 4, 41, 8, 60, 3, 11, 6, 84, 5, 46, 0, 58, 
    6, 26, 5, 46, 0, 38, 7,  6, 3, 30, 4,  8, 2, 82, 8, 87, 1, 35, 
    7, 40, 0, 92, 6,  5, 1, 47, 5, 60, 4, 80, 2, 30, 8, 51, 3, 94, 
    5, 91, 6, 18, 1, 48, 7, 42, 3, 13, 4, 59, 8, 65, 2, 55, 0, 25, 
    3, 30, 6, 82, 7, 63, 4, 35, 8, 32, 0,  2, 5, 63, 2, 14, 1, 24, 
    6, 34, 1, 64, 8, 21, 3, 42, 7, 46, 5, 62, 0, 13, 4, 15, 2, 57
  };
  const int q4594[] = {
    9, 9, // Number of jobs and machines
    6, 19, 1, 91, 0, 98, 8, 40, 3, 84, 5, 82, 4, 87, 2, 79, 7, 26, 
    7, 61, 0, 49, 5, 45, 8, 48, 2, 80, 4,  5, 6, 25, 3, 65, 1,  5, 
    5, 70, 3, 34, 8, 53, 6, 38, 0, 20, 7, 79, 4, 32, 1, 45, 2,  4, 
    4, 42, 1, 85, 6,  3, 7, 16, 8, 70, 2, 30, 0, 69, 3, 64, 5, 38, 
    6, 77, 2, 85, 4, 37, 3, 54, 0, 28, 7, 11, 8, 70, 1, 41, 5, 40, 
    8, 58, 1, 17, 4, 60, 2,  3, 5, 91, 7, 32, 6, 41, 3, 46, 0, 30, 
    6, 49, 3, 74, 8,  9, 1, 82, 2, 19, 7, 82, 5, 65, 4, 77, 0, 84, 
    8, 63, 1, 18, 7, 12, 0,  3, 6, 53, 3,  2, 4, 49, 5, 63, 2, 51, 
    8, 38, 7, 47, 2, 27, 6, 24, 0, 90, 1, 55, 3, 58, 4, 79, 5, 20
  };
  const int q4595[] = {
    9, 9, // Number of jobs and machines
    8, 55, 6, 20, 2, 13, 4, 27, 3, 66, 1, 54, 7, 42, 5, 22, 0, 49, 
    1, 32, 3, 10, 5, 77, 2, 14, 4, 31, 7, 88, 6, 33, 0, 85, 8, 94, 
    3, 63, 1, 75, 6, 82, 5, 54, 0, 19, 2, 93, 7, 95, 4,  1, 8, 53, 
    1, 10, 0, 76, 8, 12, 6, 59, 7, 21, 3, 65, 5, 22, 4, 91, 2, 68, 
    6, 96, 5, 16, 1, 56, 7, 24, 2, 99, 3, 28, 0, 93, 8, 34, 4, 74, 
    6, 38, 3, 86, 8, 27, 2, 86, 5, 50, 7, 37, 1, 68, 4, 43, 0, 87, 
    6, 34, 5, 42, 1, 73, 7,  2, 0, 72, 8, 98, 4, 35, 3, 22, 2, 37, 
    0,  3, 3, 53, 1,  6, 5, 55, 2, 34, 8, 72, 6, 79, 7,  9, 4, 91, 
    5,  6, 4, 51, 0, 32, 8, 35, 1, 13, 2, 22, 6, 60, 3, 29, 7, 22
  };
  const int q4596[] = {
    9, 9, // Number of jobs and machines
    7, 20, 0, 56, 2, 36, 5, 25, 1, 95, 3, 68, 6, 91, 8, 38, 4, 65, 
    6, 66, 3, 79, 5, 55, 0, 49, 1,  1, 2, 96, 7, 95, 8, 43, 4, 58, 
    7, 56, 0, 89, 3, 49, 4, 23, 6, 92, 5, 34, 2, 93, 1, 11, 8, 91, 
    4, 77, 0, 20, 1, 46, 8, 78, 2, 30, 7, 41, 3, 87, 6, 10, 5, 52, 
    5, 59, 1, 59, 4, 97, 3, 64, 8, 72, 7, 45, 2, 43, 0,  3, 6, 93, 
    6, 27, 3, 97, 2, 74, 7, 72, 1, 92, 4, 35, 8, 56, 5,  2, 0, 68, 
    7, 11, 0, 93, 4, 82, 8, 49, 6, 40, 2, 40, 3, 58, 1, 38, 5, 98, 
    5, 61, 2, 43, 6, 76, 8,  5, 0, 90, 1, 16, 3, 74, 4, 76, 7, 39, 
    1, 88, 5, 62, 4, 42, 2, 58, 3, 25, 8, 49, 6, 27, 7, 64, 0, 79
  };
  const int q4597[] = {
    9, 9, // Number of jobs and machines
    5, 73, 3, 50, 0, 30, 8, 17, 6,  9, 4, 91, 1, 80, 2, 82, 7, 85, 
    5, 13, 0, 70, 7, 16, 2, 16, 3, 33, 4,  7, 8, 34, 6, 80, 1, 85, 
    2, 93, 5, 63, 6, 53, 8, 10, 4, 19, 0, 91, 1, 55, 3, 63, 7, 98, 
    4, 71, 1, 10, 6, 32, 3, 78, 2, 55, 0, 93, 8, 52, 5, 84, 7, 94, 
    1, 99, 4, 85, 6, 56, 8, 64, 3, 56, 5,  3, 0, 21, 2, 96, 7, 53, 
    3, 60, 0, 87, 4, 62, 6, 76, 5, 68, 7, 95, 8, 70, 2, 56, 1, 68, 
    7, 84, 1,  4, 0, 34, 6,  1, 2, 26, 4, 62, 8, 78, 3, 32, 5, 34, 
    5, 52, 7, 81, 1,  4, 0, 80, 2, 55, 3, 94, 8, 85, 4, 42, 6, 76, 
    4, 79, 6, 38, 0, 50, 5, 77, 1, 72, 8, 72, 3, 92, 7, 17, 2, 52
  };
  const int q4598[] = {
    9, 9, // Number of jobs and machines
    1, 26, 5, 65, 8, 58, 4, 43, 2, 21, 7, 86, 6, 74, 3, 41, 0, 62, 
    4, 35, 0, 57, 5, 55, 7, 52, 3, 42, 6, 12, 8, 59, 2, 49, 1, 16, 
    7, 88, 8, 50, 5, 78, 2, 13, 1, 99, 6, 88, 0, 29, 4,  7, 3, 24, 
    6, 63, 7, 53, 8, 31, 4, 20, 2, 61, 1, 33, 5, 24, 0, 88, 3, 31, 
    3, 74, 7, 60, 0,  1, 4, 54, 2, 11, 1, 68, 6, 29, 8, 86, 5, 63, 
    0, 84, 4, 41, 2, 97, 7, 62, 5, 54, 6, 99, 3,  8, 8, 97, 1, 70, 
    3, 74, 7, 55, 0, 82, 8, 64, 6, 18, 1, 71, 5, 41, 4, 38, 2, 44, 
    0,  9, 7, 21, 4, 27, 3,  5, 5, 35, 6, 11, 8, 11, 1, 56, 2, 71, 
    3, 68, 2, 55, 8, 30, 7, 92, 6, 74, 4, 19, 5, 90, 1, 10, 0, 59
  };
  const int q4599[] = {
    9, 9, // Number of jobs and machines
    5, 57, 6, 40, 0, 19, 3, 34, 7, 81, 2, 11, 1, 34, 8, 39, 4, 75, 
    7, 55, 8, 60, 3,  1, 4, 68, 6, 96, 2,  6, 1, 96, 0, 23, 5, 94, 
    6, 34, 5, 32, 8,  4, 3, 80, 7, 76, 1,  7, 2,  4, 0, 65, 4, 89, 
    6, 62, 1, 55, 0, 91, 3, 77, 7, 38, 4, 46, 2, 82, 5, 71, 8, 40, 
    4, 76, 5, 29, 8, 83, 7, 86, 3, 32, 1, 24, 2, 17, 6, 62, 0,  5, 
    8, 86, 5, 55, 6, 86, 1, 20, 2,  9, 0, 14, 4, 36, 3, 70, 7, 99, 
    8, 43, 4, 73, 1, 39, 2, 98, 7, 23, 0, 42, 3,  6, 5, 81, 6, 27, 
    0, 99, 4, 69, 8, 12, 7, 10, 2, 60, 5, 52, 1, 41, 6, 25, 3, 21, 
    6, 77, 4, 43, 3, 34, 5, 80, 0, 24, 8, 74, 1, 83, 2, 56, 7, 71
  };
  const int q4600[] = {
    9, 9, // Number of jobs and machines
    1, 10, 4, 88, 0,  8, 7, 70, 5, 70, 3, 12, 6, 71, 8, 84, 2,  1, 
    8, 47, 1, 24, 5, 20, 3, 38, 0, 24, 6, 17, 4, 30, 2,  5, 7, 78, 
    7, 99, 3, 37, 5, 71, 1, 90, 2, 18, 0, 15, 4, 70, 6, 95, 8, 94, 
    1, 40, 6, 64, 2, 80, 3, 37, 5,  3, 7, 35, 0, 73, 8,  8, 4, 90, 
    5, 27, 4, 21, 2, 96, 1, 26, 6,  7, 7, 59, 0, 19, 8, 73, 3, 38, 
    4, 99, 7, 66, 3,  9, 5, 10, 1, 96, 0, 49, 6, 52, 2, 93, 8, 15, 
    5, 50, 7, 64, 4, 97, 6, 19, 0, 32, 1,  9, 8, 10, 3, 23, 2, 14, 
    3, 96, 4, 33, 7, 49, 8, 55, 1, 79, 2, 80, 5, 88, 6, 50, 0, 37, 
    4, 30, 3, 77, 6, 55, 1,  2, 5, 52, 8, 18, 0, 64, 7,  2, 2, 24
  };
  const int q4601[] = {
    9, 9, // Number of jobs and machines
    7, 84, 4, 37, 6, 23, 5, 94, 0, 42, 2, 33, 3,  9, 8, 59, 1, 37, 
    8, 78, 4,  5, 5, 20, 2, 99, 3, 89, 1, 51, 0, 78, 7, 55, 6, 56, 
    2,  6, 8, 31, 4, 25, 3, 83, 0, 47, 5, 48, 6, 82, 7,  2, 1, 36, 
    0, 53, 8,  7, 1, 23, 6, 64, 4, 21, 3, 80, 2, 99, 5, 58, 7, 49, 
    8, 70, 1, 20, 2, 76, 3, 10, 0, 13, 7, 52, 5, 22, 6, 59, 4, 14, 
    5, 58, 3, 24, 8, 79, 2, 42, 7, 64, 6, 46, 4, 15, 1, 31, 0, 81, 
    4, 26, 2, 84, 8, 25, 6,  1, 7, 77, 0, 23, 5, 13, 3, 16, 1, 98, 
    3,  5, 6, 36, 2, 70, 7, 83, 0, 79, 5, 32, 4, 94, 1, 37, 8, 52, 
    7, 34, 6, 66, 4, 71, 1, 53, 3, 29, 5, 68, 0, 33, 8, 55, 2, 77
  };
  const int q4602[] = {
    9, 9, // Number of jobs and machines
    6, 75, 7, 89, 1, 97, 2, 59, 4, 17, 0, 73, 3, 69, 5, 80, 8, 24, 
    2,  8, 7, 40, 0, 67, 5, 17, 1, 39, 3, 35, 8, 69, 4, 33, 6, 12, 
    6, 80, 4, 38, 2, 14, 3, 79, 1, 55, 7,  5, 8,  2, 0, 66, 5,  3, 
    0, 46, 7, 72, 2, 47, 1, 58, 8, 24, 4, 75, 3, 92, 5, 62, 6,  5, 
    6, 62, 3, 90, 5,  7, 0, 16, 7, 31, 2, 80, 4,  3, 8, 58, 1, 20, 
    0, 93, 5, 29, 3, 18, 6, 87, 8, 71, 2, 42, 7, 58, 1,  7, 4, 89, 
    5, 53, 3, 96, 4, 15, 2, 27, 0, 97, 8, 95, 6, 32, 1, 17, 7, 93, 
    0, 29, 2, 66, 4, 60, 3, 52, 8, 81, 6,  8, 5,  9, 7, 56, 1,  9, 
    0, 67, 4, 33, 3, 13, 8, 90, 1, 98, 7, 75, 6, 43, 2, 74, 5, 47
  };
  const int q4603[] = {
    9, 9, // Number of jobs and machines
    8, 36, 7,  8, 1, 92, 0, 95, 3, 80, 6, 91, 4, 47, 2,  2, 5, 66, 
    4, 11, 0, 42, 7,  5, 3, 36, 8, 78, 6, 62, 1, 40, 2,  2, 5, 46, 
    3, 37, 7, 50, 6, 12, 8, 68, 4, 26, 0, 99, 1, 15, 2, 54, 5, 10, 
    0, 30, 3, 48, 8, 22, 4, 13, 5, 92, 6, 81, 1, 27, 7, 11, 2,  5, 
    1, 37, 5, 98, 7, 66, 6, 69, 8,  2, 3, 46, 2, 11, 0, 57, 4, 39, 
    4,  9, 3, 23, 1, 47, 7, 56, 0, 47, 6, 54, 2, 29, 8, 84, 5, 23, 
    7, 22, 3,  2, 4, 27, 2, 29, 8, 25, 1, 30, 5, 57, 6, 16, 0, 69, 
    7, 90, 8, 29, 5, 90, 0, 36, 6, 91, 3, 21, 4, 50, 1, 92, 2, 24, 
    0, 37, 5, 34, 1,  2, 2, 77, 6, 95, 7, 32, 8, 79, 4, 75, 3, 99
  };
  const int q4604[] = {
    9, 9, // Number of jobs and machines
    0, 25, 3, 66, 5, 28, 8, 29, 6, 22, 4, 54, 1, 31, 7, 47, 2, 37, 
    6, 18, 8, 15, 3, 97, 0, 18, 7, 36, 1, 82, 4, 29, 5, 21, 2, 81, 
    2,  8, 8, 24, 5, 79, 0, 30, 1, 36, 7, 85, 6, 30, 4, 84, 3, 61, 
    0, 78, 7, 42, 5, 33, 8, 34, 3, 13, 2, 93, 6, 31, 1, 86, 4, 13, 
    0, 29, 7, 19, 8, 73, 5,  4, 2, 63, 3, 77, 4, 37, 6, 39, 1,  7, 
    2, 32, 8, 15, 1, 25, 4, 74, 3, 27, 0, 94, 6, 93, 7, 74, 5, 36, 
    7, 56, 1, 85, 5, 80, 0, 37, 8,  9, 2, 54, 3, 13, 6, 89, 4, 82, 
    5, 82, 2, 77, 6, 28, 7, 96, 3, 34, 4, 33, 0, 85, 8,  9, 1, 27, 
    2, 33, 8, 92, 7,  2, 6, 80, 0, 25, 4, 25, 1, 15, 5, 90, 3, 55
  };
  const int q4605[] = {
    9, 9, // Number of jobs and machines
    5, 60, 7, 60, 4,  5, 3, 87, 8, 39, 2,  4, 0, 99, 6, 51, 1, 39, 
    5, 21, 8, 67, 7, 66, 1, 63, 6, 81, 4, 80, 3, 95, 0,  9, 2, 34, 
    8, 46, 6, 83, 5,  5, 7, 66, 3, 35, 1, 77, 4, 84, 0, 58, 2, 55, 
    3, 40, 2, 38, 4, 42, 7, 12, 1, 64, 6, 43, 0, 78, 5, 59, 8,  7, 
    8, 67, 7, 36, 2, 64, 0, 62, 1,  7, 4, 44, 6,  9, 5, 74, 3, 38, 
    7, 74, 1, 66, 5, 52, 3, 11, 6, 11, 2, 48, 4, 91, 8, 19, 0, 35, 
    8, 40, 4, 31, 6, 70, 0, 67, 7, 29, 3, 66, 2, 34, 1, 59, 5, 45, 
    6,  2, 8, 59, 7,  4, 4, 95, 3, 29, 0, 64, 2, 15, 1, 70, 5, 38, 
    1, 35, 6, 61, 5, 21, 8, 17, 7, 96, 0, 56, 4, 47, 3, 97, 2, 74
  };
  const int q4606[] = {
    9, 9, // Number of jobs and machines
    0, 82, 7, 73, 1, 37, 5, 57, 4, 91, 6, 70, 2, 11, 8, 65, 3, 82, 
    7, 62, 6, 21, 1, 88, 0, 10, 8, 84, 2, 11, 3, 22, 4, 18, 5, 18, 
    0,  6, 8, 54, 7, 96, 2, 62, 5, 72, 6, 41, 3, 29, 1,  3, 4, 70, 
    6, 50, 0, 47, 7, 50, 5, 32, 2, 16, 3, 51, 1, 14, 4, 13, 8, 37, 
    2, 20, 4, 44, 5, 28, 6, 93, 7, 42, 1,  4, 0, 39, 8,  2, 3, 15, 
    2,  8, 5, 16, 7, 95, 1, 82, 0, 66, 4, 38, 3, 86, 6, 80, 8, 42, 
    5, 42, 2, 25, 7, 45, 8, 84, 3, 83, 1, 30, 4, 78, 0,  8, 6,  9, 
    2, 50, 4, 55, 5,  3, 6, 92, 1, 39, 7, 47, 3, 24, 8, 80, 0, 60, 
    6, 55, 3, 29, 1, 62, 8, 85, 0, 55, 5, 65, 4, 29, 7, 24, 2, 42
  };
  const int q4607[] = {
    9, 9, // Number of jobs and machines
    1, 89, 8, 76, 0, 68, 2, 43, 7,  7, 3, 30, 5, 12, 4,  1, 6, 32, 
    4, 91, 1,  2, 6, 48, 7, 19, 0, 66, 3, 78, 2, 56, 8, 96, 5, 12, 
    4, 16, 0, 57, 8, 80, 6, 99, 7, 56, 3, 77, 1, 37, 5, 19, 2, 29, 
    6, 69, 7, 21, 2, 79, 4, 15, 0, 83, 5, 98, 3,  5, 8, 37, 1, 52, 
    5, 60, 2, 66, 8, 99, 4, 59, 1, 94, 0,  3, 3, 21, 6,  2, 7, 16, 
    8, 54, 0, 29, 2, 65, 1, 88, 6, 46, 7, 50, 5, 93, 3, 77, 4, 29, 
    3, 37, 1, 38, 5, 32, 4, 62, 6,  8, 7, 62, 2, 33, 0, 79, 8, 45, 
    8, 73, 0, 61, 3, 44, 6, 29, 5, 19, 1, 89, 7, 51, 4, 28, 2, 57, 
    6, 75, 8,  8, 2, 69, 7, 96, 3, 32, 5,  2, 1, 42, 4, 40, 0, 79
  };
  const int q4608[] = {
    9, 9, // Number of jobs and machines
    4, 41, 1, 35, 3, 84, 7, 73, 8, 50, 5, 71, 0, 19, 6, 15, 2, 99, 
    5, 80, 7, 26, 6, 48, 2, 12, 8, 32, 0,  2, 4, 48, 1, 90, 3, 50, 
    2, 91, 1, 10, 0, 35, 6,  2, 7, 56, 5, 13, 4, 89, 3, 35, 8, 17, 
    3, 98, 5, 13, 0, 65, 8, 32, 1, 43, 7, 89, 4, 67, 6, 41, 2, 70, 
    2, 43, 3, 67, 6, 10, 4, 11, 5, 93, 7, 97, 1, 78, 0, 99, 8, 61, 
    5, 19, 0, 60, 4, 89, 2, 84, 8, 62, 1, 17, 6, 95, 3, 54, 7, 45, 
    2, 23, 4, 18, 3, 19, 8, 31, 7, 31, 1, 44, 0, 67, 6, 63, 5, 58, 
    0, 79, 4, 32, 1,  6, 3, 43, 8, 13, 7, 30, 2, 14, 5, 34, 6, 96, 
    2,  7, 3, 13, 1, 22, 7, 45, 4, 20, 0, 33, 8, 85, 5,  1, 6,  7
  };
  const int q4609[] = {
    9, 9, // Number of jobs and machines
    6, 16, 8, 83, 2, 10, 5, 86, 4, 50, 0,  8, 7, 44, 3, 51, 1, 62, 
    4, 10, 7,  8, 3, 98, 0, 89, 1, 85, 2, 75, 8, 51, 5, 87, 6, 43, 
    6,  5, 2, 13, 7, 94, 1, 76, 8, 28, 3, 83, 4, 80, 0, 71, 5, 44, 
    2, 37, 6, 36, 1, 83, 4, 66, 0, 80, 8,  6, 3, 84, 5, 48, 7,  8, 
    1, 36, 6, 17, 3, 95, 4, 29, 5,  1, 0, 71, 8, 19, 2, 48, 7, 62, 
    2, 45, 8, 47, 0,  6, 7, 62, 5, 43, 6, 98, 3, 27, 1, 54, 4, 36, 
    4, 98, 1, 42, 2, 69, 6, 13, 0, 47, 5, 72, 8,  9, 3, 60, 7, 29, 
    4, 51, 0, 50, 6, 10, 3, 45, 2, 44, 8, 24, 1, 57, 7, 51, 5, 61, 
    6, 56, 3, 41, 5, 33, 2, 52, 0,  1, 7, 66, 8, 92, 1, 44, 4, 73
  };
  const int q4610[] = {
    9, 9, // Number of jobs and machines
    8, 89, 0, 61, 3,  4, 7, 99, 2, 75, 4, 98, 5, 87, 1, 74, 6, 31, 
    8, 66, 4, 17, 1, 39, 2, 70, 0, 36, 5, 58, 6, 37, 7, 33, 3, 76, 
    5, 48, 4, 40, 0, 42, 6, 70, 3,  5, 1, 85, 7, 16, 8, 20, 2, 45, 
    5, 38, 8, 12, 0, 42, 2, 91, 6, 98, 3, 96, 4, 23, 1, 85, 7, 49, 
    6, 95, 8, 35, 1, 64, 5, 31, 4, 62, 2, 61, 0, 26, 3, 41, 7, 71, 
    8, 33, 7, 15, 3, 40, 4, 47, 5, 56, 1, 30, 2, 28, 0, 53, 6, 57, 
    3, 70, 4, 19, 1,  7, 5, 14, 6, 81, 7, 40, 2,  8, 8, 30, 0, 20, 
    2, 34, 4, 10, 8, 61, 5,  4, 7, 97, 1, 78, 3, 42, 6, 36, 0, 92, 
    3, 34, 1, 30, 7, 63, 0, 46, 5, 13, 6, 95, 8, 44, 2, 45, 4, 83
  };
  const int q4611[] = {
    9, 9, // Number of jobs and machines
    1, 63, 3, 89, 2, 62, 5, 19, 7, 77, 6, 51, 0, 90, 8, 82, 4, 25, 
    3, 79, 5, 73, 0, 40, 8, 96, 1, 39, 7, 50, 4, 87, 6, 65, 2, 48, 
    1, 62, 2, 31, 6,  1, 8, 82, 4, 36, 0, 70, 3, 81, 5, 20, 7, 76, 
    8, 20, 5, 64, 7, 91, 0, 72, 6, 81, 4, 23, 1, 88, 3, 57, 2, 57, 
    4, 73, 8, 10, 7, 23, 5, 99, 1, 46, 3, 71, 6, 73, 2, 46, 0, 71, 
    4,  5, 0,  5, 5, 65, 6, 59, 7, 97, 2, 44, 3,  1, 8, 81, 1, 39, 
    8,  2, 3, 21, 0, 79, 5, 79, 4, 73, 1, 27, 6, 31, 2, 36, 7, 34, 
    1, 39, 6, 30, 0, 95, 8,  1, 5,  3, 2, 31, 7, 67, 3, 10, 4, 16, 
    1, 62, 3, 93, 7, 26, 4, 88, 8, 91, 2, 62, 5, 92, 0, 13, 6, 56
  };
  const int q4612[] = {
    9, 9, // Number of jobs and machines
    4, 60, 2, 56, 5, 68, 3,  8, 6,  1, 8, 29, 1,  4, 0, 92, 7, 55, 
    8, 64, 6, 46, 2, 98, 5, 54, 7, 36, 4, 73, 3, 20, 1, 94, 0, 28, 
    0, 20, 7, 91, 1, 93, 5, 67, 4, 34, 2, 51, 8, 81, 6, 43, 3, 11, 
    2,  7, 0, 84, 5, 77, 1, 63, 8, 60, 6, 59, 4,  2, 7, 79, 3,  4, 
    4, 60, 6, 56, 1, 42, 3, 25, 5, 67, 7, 19, 0,  6, 2, 30, 8, 21, 
    3, 35, 5, 78, 8, 66, 7, 75, 4, 89, 0, 62, 2, 77, 6, 55, 1, 54, 
    3, 42, 4, 25, 8, 49, 7, 78, 5, 34, 0, 67, 1, 94, 2, 25, 6, 57, 
    6, 70, 3, 60, 2, 27, 1, 92, 7, 29, 8, 23, 5,  8, 0, 26, 4, 67, 
    4,  4, 5, 67, 8, 60, 2, 21, 7, 97, 3, 53, 6, 96, 1,  3, 0, 89
  };
  const int q4613[] = {
    9, 9, // Number of jobs and machines
    0, 79, 7, 53, 3, 61, 5, 65, 8,  9, 1, 28, 4, 34, 2, 65, 6, 81, 
    4, 13, 3, 40, 6, 99, 0,  6, 7, 78, 8, 91, 2, 56, 1, 48, 5, 64, 
    2, 22, 1, 46, 4, 42, 0, 55, 3, 46, 7,  1, 6, 11, 5, 91, 8, 81, 
    7, 45, 8, 27, 3, 29, 0, 14, 2, 87, 4, 36, 1, 17, 6, 79, 5, 64, 
    3, 12, 0, 57, 8, 28, 2, 67, 6, 57, 4, 34, 1, 90, 7,  2, 5, 91, 
    7, 61, 4, 49, 0, 36, 8,  2, 3, 68, 5, 12, 1, 83, 2, 60, 6,  7, 
    7, 55, 1, 63, 6, 10, 4, 69, 0, 75, 2, 87, 8, 74, 5, 36, 3, 59, 
    1, 53, 4, 98, 0, 60, 8, 25, 3,  1, 5, 13, 2, 71, 7, 63, 6,  8, 
    7, 27, 0, 49, 6, 60, 5, 94, 2, 61, 8, 34, 4, 64, 1,  4, 3, 42
  };
  const int q4614[] = {
    9, 9, // Number of jobs and machines
    5, 54, 7, 22, 0, 41, 8, 37, 3, 40, 2, 97, 4, 91, 1,  3, 6, 49, 
    3, 71, 6, 12, 1, 21, 7,  4, 5, 73, 4, 30, 8, 49, 2, 43, 0, 60, 
    2, 82, 8, 64, 0, 98, 4,  5, 5, 47, 6, 32, 7, 43, 3, 52, 1, 63, 
    0, 32, 3, 11, 6, 55, 7, 10, 2,  7, 4, 56, 8, 73, 5, 95, 1, 78, 
    3, 28, 6, 74, 1, 84, 7, 51, 4, 38, 0, 72, 2, 55, 5, 15, 8, 67, 
    4, 52, 7, 25, 0, 94, 5, 42, 2, 18, 8, 48, 1, 64, 6, 83, 3, 65, 
    3, 39, 4, 11, 2, 59, 0, 70, 5, 61, 7, 19, 6, 47, 1, 22, 8, 27, 
    0,  2, 3, 39, 8, 71, 7, 92, 2, 62, 6, 47, 1, 67, 4, 47, 5, 36, 
    7, 93, 5, 29, 4, 29, 0, 45, 8, 70, 1,  3, 2, 12, 3, 98, 6, 96
  };
  const int q4615[] = {
    9, 9, // Number of jobs and machines
    2, 72, 7, 56, 4, 17, 1, 39, 3,  2, 5, 58, 8, 48, 6,  9, 0, 80, 
    0, 98, 1, 79, 2, 83, 6, 40, 4, 24, 7, 16, 5, 57, 3, 90, 8, 61, 
    4, 24, 2, 23, 0, 43, 1, 67, 3, 21, 8, 38, 5, 95, 6, 37, 7,  6, 
    4, 38, 3, 25, 6, 23, 1, 72, 0, 61, 5, 76, 8, 91, 7, 55, 2, 25, 
    6, 92, 5, 44, 8, 77, 7, 89, 2, 60, 0, 99, 1, 89, 4, 60, 3, 66, 
    6, 67, 3, 81, 2, 62, 8, 18, 1, 18, 7, 14, 4, 48, 5, 14, 0, 21, 
    7, 44, 8, 60, 4, 55, 5, 20, 0, 81, 2, 53, 3, 47, 1,  9, 6, 37, 
    7, 25, 1, 15, 8, 93, 2, 20, 3, 49, 0, 33, 4, 33, 5, 56, 6, 66, 
    6, 24, 4,  3, 7, 24, 3, 91, 5, 63, 8, 87, 0, 59, 2, 61, 1, 73
  };
  const int q4616[] = {
    9, 9, // Number of jobs and machines
    7, 63, 6, 61, 3, 87, 0, 39, 8, 59, 4, 42, 1, 67, 5, 68, 2, 40, 
    0, 85, 1, 30, 6, 17, 2, 71, 4,  3, 7, 23, 8, 21, 5, 91, 3, 10, 
    7, 36, 6, 85, 3, 72, 0, 17, 2, 42, 1, 50, 4, 78, 8, 73, 5, 34, 
    3, 66, 1,  8, 6, 36, 8, 90, 2, 69, 4, 49, 7, 36, 5, 95, 0, 24, 
    1, 37, 8, 91, 7, 20, 3, 77, 2, 65, 0, 22, 4, 20, 5, 46, 6, 62, 
    7, 25, 6, 57, 0, 18, 2, 87, 1, 39, 3, 38, 5, 71, 4, 39, 8, 41, 
    1, 23, 2,  5, 6,  9, 3, 60, 8,  4, 7, 34, 5, 91, 4,  5, 0, 44, 
    8, 46, 3, 83, 7, 77, 2, 47, 0, 32, 4, 38, 1, 26, 6, 71, 5, 11, 
    8, 75, 7, 92, 1, 51, 6,  8, 3, 35, 4, 65, 5, 66, 2, 61, 0, 47
  };
  const int q4617[] = {
    9, 9, // Number of jobs and machines
    2, 95, 3, 13, 0, 29, 5, 97, 6, 90, 7, 11, 1, 19, 4, 39, 8, 44, 
    1, 76, 7, 87, 5, 59, 8, 80, 0, 66, 2, 31, 3, 80, 4, 51, 6, 97, 
    5, 51, 3,  8, 8, 35, 1, 57, 7, 51, 4, 88, 2, 24, 6, 29, 0, 40, 
    3, 16, 6,  4, 7, 39, 8, 46, 0, 72, 1,  7, 5, 20, 2,  5, 4, 45, 
    5, 30, 1, 29, 7, 17, 3,  9, 0, 92, 6, 27, 4, 57, 8, 15, 2, 93, 
    5, 55, 1, 34, 8, 24, 0, 23, 3, 39, 6, 41, 7, 78, 4, 87, 2, 46, 
    6, 25, 0, 58, 5, 85, 1, 92, 2, 43, 3, 66, 7, 62, 4, 44, 8, 27, 
    8, 85, 2, 84, 6, 65, 5, 90, 3, 92, 7, 82, 4, 72, 0,  1, 1,  4, 
    0, 40, 4, 37, 5, 12, 3, 63, 6,  6, 2, 13, 7,  3, 1, 25, 8, 82
  };
  const int q4618[] = {
    9, 9, // Number of jobs and machines
    8, 73, 0, 62, 2, 84, 6, 13, 7, 12, 3, 87, 1, 11, 5, 50, 4, 34, 
    0, 43, 5, 75, 4,  9, 2, 68, 8, 66, 6, 46, 3, 58, 1, 13, 7, 47, 
    7, 30, 8, 87, 5, 85, 3, 27, 2, 34, 6, 20, 4, 69, 1,  1, 0, 79, 
    5, 28, 2, 40, 1, 58, 0, 85, 7, 61, 4, 57, 8, 51, 6, 66, 3, 68, 
    3, 37, 5, 18, 1,  9, 4, 49, 6, 81, 7, 10, 0, 73, 2, 85, 8, 71, 
    0, 63, 5, 43, 6, 76, 3, 37, 8, 32, 4,  2, 1, 49, 2, 86, 7, 82, 
    5,  2, 3, 89, 4, 30, 8, 59, 2, 64, 6, 58, 1, 58, 0, 97, 7, 91, 
    7, 46, 8, 54, 1, 27, 6, 46, 0, 85, 2, 46, 5, 55, 4, 47, 3, 55, 
    6, 31, 2, 15, 1, 44, 3, 69, 0, 46, 7, 63, 8, 88, 4, 31, 5, 29
  };
  const int q4619[] = {
    9, 9, // Number of jobs and machines
    5, 53, 3, 25, 8, 12, 4, 30, 6, 91, 7, 96, 0, 63, 2, 68, 1, 27, 
    0, 76, 4, 39, 5, 64, 3, 73, 7, 28, 2, 33, 8, 96, 6, 82, 1, 93, 
    8, 12, 4, 68, 0, 37, 6, 76, 1, 12, 2, 49, 3, 43, 5,  9, 7, 59, 
    2,  6, 6, 42, 3, 98, 0, 44, 5,  9, 7, 99, 8, 34, 1, 25, 4, 73, 
    2, 91, 4, 20, 1, 69, 5, 48, 0, 62, 6, 38, 7, 25, 8, 28, 3, 38, 
    3, 52, 5, 74, 1, 47, 0, 34, 2, 86, 8, 32, 6, 58, 4,  6, 7, 80, 
    4,  9, 5, 21, 2, 30, 3, 98, 1, 72, 6, 32, 7, 62, 8, 61, 0, 95, 
    1, 98, 8, 93, 4, 37, 6, 67, 7, 69, 5, 77, 2, 47, 0, 85, 3,  7, 
    0, 36, 8, 23, 6, 36, 2, 77, 4, 41, 3,  4, 1, 12, 5, 65, 7, 43
  };
  const int q4620[] = {
    9, 9, // Number of jobs and machines
    6, 38, 5, 14, 0, 23, 2, 47, 4,  9, 3, 92, 1, 21, 7, 21, 8, 73, 
    4, 44, 0, 83, 3, 85, 5, 43, 7, 58, 2, 61, 8, 18, 1,  4, 6, 29, 
    0,  1, 4, 81, 1, 14, 5, 37, 8, 44, 3, 48, 2, 95, 6, 82, 7, 16, 
    2, 99, 1, 32, 5, 11, 3, 85, 4, 76, 8, 59, 6, 43, 7, 88, 0, 24, 
    3, 15, 4, 75, 7, 63, 2, 45, 8, 43, 5, 89, 0, 28, 1, 91, 6, 19, 
    1, 82, 2, 85, 3, 71, 8, 93, 0, 23, 4, 10, 5, 12, 7, 45, 6,  7, 
    1, 54, 3, 77, 5, 44, 8, 43, 7, 17, 2, 32, 0, 16, 4, 34, 6, 41, 
    4, 75, 8, 90, 6, 68, 0, 44, 5, 78, 2, 34, 7, 72, 1, 75, 3, 11, 
    8, 75, 2, 33, 1, 72, 4, 61, 0, 12, 5, 30, 3,  3, 6, 29, 7, 60
  };
  const int q4621[] = {
    9, 9, // Number of jobs and machines
    6, 94, 1, 10, 8, 62, 3, 16, 5, 26, 4, 99, 7, 94, 0, 20, 2,  4, 
    3, 48, 7, 70, 5, 49, 8, 85, 2, 48, 0, 61, 4, 57, 6, 63, 1, 14, 
    7, 77, 0, 26, 4, 47, 5, 15, 2,  4, 3, 58, 1, 60, 8, 44, 6, 93, 
    7, 97, 4, 35, 2,  6, 0, 36, 5, 16, 8, 34, 1, 28, 6, 28, 3, 76, 
    0, 41, 3, 75, 4, 51, 7, 46, 1, 13, 8,  9, 6, 80, 5, 66, 2, 45, 
    0, 28, 7, 50, 2, 71, 8, 68, 6,  8, 5, 15, 3, 84, 4, 18, 1, 33, 
    5, 44, 6, 84, 4, 76, 7, 91, 2, 40, 1, 33, 3, 34, 0, 56, 8, 74, 
    4, 94, 6, 39, 2, 61, 1, 73, 8, 78, 0, 98, 5, 74, 3, 71, 7, 72, 
    4, 72, 2, 20, 1,  3, 7, 68, 5, 93, 3, 19, 8, 97, 0, 81, 6, 74
  };
  const int q4622[] = {
    9, 9, // Number of jobs and machines
    3, 87, 4, 34, 7, 76, 8,  2, 6, 63, 0, 52, 2, 67, 5, 34, 1, 69, 
    8, 59, 1, 36, 0, 14, 5, 92, 4, 59, 6, 22, 3, 72, 7, 37, 2, 68, 
    5, 87, 0, 93, 8, 93, 6, 62, 2, 29, 1, 90, 4, 66, 7, 43, 3, 72, 
    4, 99, 7, 72, 3, 62, 0, 22, 5, 63, 6, 80, 1, 72, 2, 67, 8, 44, 
    4, 17, 1, 11, 5, 25, 2, 56, 8, 46, 3, 44, 0, 23, 6, 14, 7, 37, 
    1, 74, 3, 59, 5, 86, 6, 58, 8, 29, 0, 87, 2, 26, 4, 38, 7, 92, 
    0, 91, 7, 98, 4, 30, 3, 12, 1,  7, 6, 41, 2, 37, 5, 80, 8, 86, 
    3, 13, 2, 16, 4, 94, 0, 76, 6, 33, 7, 53, 5, 18, 8, 91, 1, 48, 
    4, 65, 3, 76, 5, 50, 8, 64, 0, 57, 6, 68, 2, 24, 1, 15, 7, 35
  };
  const int q4623[] = {
    9, 9, // Number of jobs and machines
    1, 68, 3, 12, 5, 39, 6, 11, 8, 80, 7,  8, 0, 14, 4, 77, 2,  4, 
    8, 81, 2, 68, 0, 51, 7, 38, 3, 51, 6, 94, 5, 47, 4,  2, 1, 40, 
    1,  5, 5, 46, 6, 83, 4, 41, 0, 70, 8, 79, 7, 61, 3, 19, 2, 14, 
    1, 55, 0, 26, 5, 67, 3, 66, 8, 76, 4, 26, 6, 34, 2, 91, 7, 23, 
    2, 10, 6, 16, 3, 43, 5, 83, 8, 93, 7, 80, 4, 93, 1, 46, 0, 58, 
    3, 90, 6, 13, 4, 88, 0, 22, 1, 26, 7, 22, 2, 39, 8, 55, 5, 77, 
    0, 90, 5, 29, 2, 71, 4, 81, 1, 54, 3, 80, 6, 72, 7, 18, 8, 45, 
    5, 82, 0, 70, 1, 15, 4, 49, 6, 74, 7, 48, 3, 14, 8, 37, 2, 66, 
    4, 13, 7, 36, 5, 71, 0, 66, 3, 83, 8, 34, 2, 28, 1, 80, 6, 17
  };
  const int q4624[] = {
    9, 9, // Number of jobs and machines
    5,  5, 7, 26, 4, 66, 0, 52, 2, 11, 3, 37, 6, 77, 1, 31, 8, 25, 
    3, 53, 7, 32, 4, 69, 5, 67, 1, 44, 2, 90, 0, 74, 6,  1, 8, 24, 
    0, 59, 4, 56, 7,  8, 6, 17, 1, 95, 5, 66, 3, 32, 8, 66, 2, 78, 
    1, 67, 0, 86, 5, 71, 7, 43, 6, 15, 4, 97, 8,  2, 3, 98, 2, 14, 
    5,  1, 0, 41, 8,  2, 3, 61, 7, 48, 6, 21, 1, 25, 2, 28, 4, 51, 
    1, 39, 5, 36, 6,  7, 2, 70, 8, 54, 7, 14, 3, 65, 0, 58, 4, 25, 
    2, 43, 6, 57, 0,  8, 3, 56, 1, 54, 8, 18, 4, 59, 5, 61, 7,  6, 
    0, 37, 7, 32, 5, 71, 3,  7, 1, 44, 6,  8, 8, 55, 4, 35, 2, 67, 
    1, 86, 2, 52, 5, 20, 3, 18, 6, 31, 8, 59, 0, 18, 4,  8, 7,  1
  };
  const int q4625[] = {
    9, 9, // Number of jobs and machines
    8, 72, 6, 52, 7, 11, 3, 77, 4, 75, 2, 99, 0, 34, 5, 31, 1, 62, 
    3, 34, 0, 53, 6, 56, 1, 89, 5, 92, 2,  1, 8, 68, 4, 56, 7, 94, 
    1, 36, 2, 72, 5, 64, 3, 33, 4,  1, 8, 73, 6, 92, 0, 23, 7, 30, 
    3, 90, 1, 16, 8,  9, 2, 44, 0, 28, 5, 58, 7, 25, 4, 39, 6, 80, 
    7, 84, 5, 72, 1,  4, 6, 31, 3, 85, 2, 56, 0, 12, 4, 19, 8, 10, 
    6, 43, 5, 34, 4, 50, 1, 35, 8, 75, 7, 68, 2, 23, 3, 54, 0, 69, 
    5, 52, 7, 53, 1, 14, 3, 87, 4, 15, 2, 10, 6, 45, 8, 69, 0, 17, 
    4, 12, 7, 67, 5, 95, 6, 16, 2, 20, 1, 42, 8, 76, 0, 33, 3, 79, 
    5, 28, 8, 50, 7, 68, 0, 65, 4, 25, 6, 75, 2,  6, 1, 58, 3, 73
  };
  const int q4626[] = {
    9, 9, // Number of jobs and machines
    6, 59, 7, 55, 8, 58, 3, 36, 1, 64, 5,  8, 0, 19, 4, 63, 2, 84, 
    7,  8, 8, 87, 0, 71, 3, 30, 5, 27, 4, 31, 2, 61, 6, 39, 1, 36, 
    2, 28, 4, 94, 7, 15, 8, 43, 5, 90, 1, 66, 6, 15, 3, 30, 0, 17, 
    5, 31, 8, 15, 1, 44, 7,  9, 3, 97, 4, 74, 0, 69, 2, 30, 6, 50, 
    8, 43, 7, 11, 2, 80, 4, 35, 0, 67, 5, 17, 6,  8, 3, 84, 1, 96, 
    2, 20, 5, 13, 0, 38, 1, 44, 8, 89, 4,  6, 3, 55, 6, 58, 7, 66, 
    3, 94, 0, 33, 8, 60, 7, 63, 5, 11, 1, 62, 6, 17, 2, 51, 4, 88, 
    3,  2, 1, 25, 7, 28, 0, 70, 6, 56, 4, 76, 5, 51, 8, 89, 2, 95, 
    4, 93, 3, 52, 2, 24, 0, 24, 5, 36, 6, 54, 1, 97, 8, 91, 7, 56
  };
  const int q4627[] = {
    9, 9, // Number of jobs and machines
    4, 75, 0, 76, 7, 77, 2, 46, 8, 76, 3, 32, 6, 38, 5, 34, 1, 33, 
    3, 39, 7, 14, 2, 49, 0, 14, 1, 69, 5, 24, 8,  6, 4, 67, 6, 20, 
    6, 97, 3, 60, 4, 23, 2, 18, 0,  5, 8, 18, 5, 39, 7, 78, 1, 21, 
    6, 28, 0,  9, 7, 39, 2, 93, 1, 97, 4,  9, 8, 60, 3, 93, 5, 25, 
    7, 98, 3, 87, 1, 12, 4,  5, 6, 30, 2, 83, 5, 78, 8, 66, 0, 88, 
    1,  9, 8, 59, 6, 70, 7,  8, 2, 91, 3, 61, 4, 81, 0,  8, 5, 85, 
    2,  2, 7, 71, 0, 33, 5, 53, 6, 60, 4, 59, 3, 66, 8, 86, 1, 38, 
    6, 16, 7, 17, 3, 66, 4,  4, 5, 99, 1, 70, 0, 41, 2, 22, 8, 84, 
    4, 71, 3, 20, 8,  4, 0, 91, 6, 57, 1, 16, 7, 28, 2, 32, 5, 27
  };
  const int q4628[] = {
    9, 9, // Number of jobs and machines
    7, 66, 1, 23, 8, 37, 3, 44, 6, 70, 0, 72, 5, 29, 4, 33, 2, 77, 
    6, 46, 3, 17, 5, 57, 2, 48, 0, 11, 1, 17, 8, 90, 4,  5, 7, 76, 
    4, 45, 1, 86, 2, 71, 5, 65, 8, 31, 7, 47, 0, 91, 6,  9, 3, 51, 
    7, 36, 6, 61, 1, 42, 5,  2, 3, 35, 4, 41, 2, 68, 8, 99, 0, 21, 
    0, 44, 1, 30, 2, 23, 4, 50, 3,  5, 5, 46, 6, 51, 7, 76, 8, 97, 
    2, 46, 6, 64, 0, 38, 7, 85, 5,  3, 3, 59, 1, 81, 4,  1, 8, 80, 
    7, 17, 0, 43, 3, 66, 8, 31, 4, 62, 5, 64, 1, 94, 6, 57, 2, 88, 
    5, 70, 3, 30, 4, 87, 6, 70, 2,  6, 8, 53, 7, 42, 1, 61, 0, 30, 
    8, 33, 5, 82, 0, 47, 7, 74, 6,  8, 4, 14, 1, 76, 3, 94, 2, 79
  };
  const int q4629[] = {
    9, 9, // Number of jobs and machines
    1, 99, 0, 51, 8, 31, 3, 22, 2, 81, 7, 33, 5, 18, 6,  9, 4, 20, 
    7,  8, 1, 67, 8, 17, 2, 26, 4, 45, 3, 79, 0, 24, 6, 34, 5, 92, 
    6, 73, 2, 93, 8, 58, 4, 89, 5, 84, 0, 54, 7, 63, 1, 38, 3, 29, 
    3, 23, 4, 17, 7, 40, 8,  1, 6, 70, 0, 14, 2, 74, 5, 73, 1, 86, 
    2, 30, 6, 13, 7, 87, 4, 50, 5, 61, 8, 56, 1, 25, 3, 44, 0, 11, 
    7, 53, 2, 86, 8, 49, 5, 70, 3, 76, 1, 48, 4, 79, 6, 60, 0, 45, 
    6, 58, 8, 86, 5, 68, 1, 92, 0, 87, 7, 59, 4,  8, 2, 44, 3, 25, 
    6,  1, 0, 37, 8, 36, 4, 47, 7, 70, 3, 55, 1,  6, 5, 78, 2, 96, 
    7, 11, 0, 44, 2, 69, 1, 73, 3, 61, 8, 97, 5, 53, 6, 37, 4, 34
  };
  const int q4630[] = {
    9, 9, // Number of jobs and machines
    2, 81, 8,  2, 3, 53, 5, 38, 7, 70, 1, 58, 6, 44, 0, 98, 4,  7, 
    1, 18, 0, 89, 5, 23, 6,  8, 3, 25, 2, 95, 4, 10, 7, 22, 8, 49, 
    7, 19, 8, 79, 2, 27, 5, 92, 6, 54, 1,  2, 3, 28, 4, 82, 0, 59, 
    5, 13, 2, 16, 3, 81, 1, 80, 8, 11, 4, 82, 0, 40, 7, 75, 6, 38, 
    1, 81, 2, 65, 4, 51, 3,  6, 6, 30, 5, 47, 0, 65, 7,  9, 8, 94, 
    3, 82, 6, 53, 0, 89, 5, 41, 1, 58, 2, 90, 4, 71, 7, 23, 8,  7, 
    5, 29, 8, 35, 7, 90, 2, 61, 3,  2, 1, 43, 0, 53, 4, 12, 6, 19, 
    0, 71, 5, 42, 7, 81, 8,  6, 1, 68, 4, 50, 6, 83, 3,  8, 2, 25, 
    4, 11, 3,  2, 1, 78, 8, 46, 7, 15, 6, 56, 2, 48, 0, 90, 5, 85
  };
  const int q4631[] = {
    9, 9, // Number of jobs and machines
    4, 86, 6, 34, 2, 85, 8, 18, 7, 26, 5, 25, 1, 30, 3, 20, 0, 78, 
    4,  5, 0, 89, 3, 20, 8, 25, 2, 36, 6, 71, 7, 63, 1, 13, 5, 63, 
    3, 22, 5, 73, 1, 82, 4, 24, 8, 16, 0, 33, 7, 70, 2, 68, 6, 99, 
    2, 93, 8, 99, 7, 88, 3, 21, 5, 94, 6, 39, 4, 75, 1, 16, 0,  8, 
    7, 56, 4, 38, 0, 29, 6, 66, 2, 73, 5, 89, 8, 99, 3, 75, 1, 99, 
    8, 99, 5,  8, 4, 60, 1, 87, 3, 13, 6, 19, 7, 10, 2, 34, 0, 30, 
    3, 17, 4, 66, 8,  2, 5, 48, 7, 82, 0, 94, 6,  4, 1, 68, 2, 98, 
    2, 57, 4, 75, 0, 95, 1, 23, 6, 14, 5, 61, 8, 28, 3, 76, 7, 33, 
    2, 62, 7, 69, 8, 65, 5, 45, 6, 79, 1, 53, 4, 47, 3, 97, 0, 11
  };
  const int q4632[] = {
    9, 9, // Number of jobs and machines
    4, 36, 6, 58, 8,  8, 0, 35, 1, 29, 7, 71, 5, 18, 2, 14, 3, 60, 
    5, 71, 3,  1, 8,  4, 1, 16, 6, 56, 2, 12, 4, 22, 7, 51, 0, 23, 
    6, 53, 4, 45, 2, 57, 7, 62, 5, 54, 3, 55, 8, 17, 1,  1, 0, 40, 
    1, 55, 8, 97, 4, 74, 0, 93, 5, 55, 7, 71, 2, 39, 6, 19, 3, 77, 
    2, 72, 6, 18, 5, 98, 7, 57, 1, 74, 3, 45, 4,  7, 8,  2, 0, 55, 
    2, 47, 0, 18, 3, 67, 7, 55, 4, 99, 6, 91, 1, 43, 5,  3, 8, 14, 
    2, 75, 4,  8, 0, 41, 8, 32, 3,  1, 6, 36, 1, 26, 7, 43, 5, 70, 
    0, 53, 1, 89, 5, 35, 7, 90, 3, 48, 4, 98, 8, 46, 6, 21, 2, 84, 
    3, 90, 4, 61, 2, 14, 5, 22, 0, 82, 1, 50, 7, 49, 8, 11, 6, 52
  };
  const int q4633[] = {
    9, 9, // Number of jobs and machines
    2, 44, 3, 72, 0, 36, 4, 59, 8, 15, 6, 46, 1, 17, 7, 75, 5,  7, 
    0, 70, 4,  9, 1, 56, 6, 26, 5,  2, 8, 43, 2, 70, 7, 66, 3, 21, 
    5, 75, 4, 41, 6, 44, 2, 80, 7, 81, 1,  4, 0, 27, 8, 29, 3, 79, 
    8, 31, 7, 68, 2, 79, 0, 30, 5, 84, 1, 71, 3,  7, 6, 25, 4, 75, 
    0, 97, 1, 67, 6, 14, 8, 27, 2, 97, 4,  2, 7, 83, 3, 63, 5, 31, 
    6, 76, 8, 28, 3, 61, 0, 29, 5, 94, 2, 85, 7, 98, 1, 93, 4, 25, 
    2, 16, 6, 40, 4, 64, 8, 21, 0, 83, 7, 62, 5, 24, 1, 89, 3, 81, 
    4,  7, 1, 77, 7, 14, 5, 83, 6, 95, 8, 38, 0,  5, 3,  3, 2, 91, 
    0,  7, 2, 14, 3, 39, 6,  3, 8, 15, 5, 57, 1, 47, 7, 21, 4, 88
  };
  const int q4634[] = {
    9, 9, // Number of jobs and machines
    7, 52, 5, 56, 2, 37, 1, 74, 8, 77, 0, 62, 6, 57, 3, 70, 4, 31, 
    4, 17, 2, 65, 3, 38, 6, 86, 8,  8, 0, 86, 7, 85, 5, 95, 1, 81, 
    7, 60, 8, 94, 3, 89, 4, 81, 2, 67, 5, 37, 1,  4, 0, 30, 6, 44, 
    3, 37, 6, 86, 4, 38, 7,  3, 1, 81, 2, 72, 0, 17, 5, 56, 8, 14, 
    0, 85, 4, 69, 7, 65, 3, 78, 1, 91, 6, 54, 8, 84, 5, 68, 2, 80, 
    0, 24, 2,  8, 4, 96, 1,  9, 3, 82, 5, 42, 8, 74, 6, 74, 7, 50, 
    0, 75, 4, 84, 5, 84, 1, 95, 8, 90, 3, 75, 7, 38, 2, 56, 6, 68, 
    6, 31, 8, 75, 7, 35, 5, 11, 3, 82, 4, 69, 2, 97, 1, 45, 0, 51, 
    1, 23, 3, 93, 6, 45, 0, 23, 8, 63, 4, 27, 7,  5, 5, 38, 2, 92
  };
  const int q4635[] = {
    9, 9, // Number of jobs and machines
    3, 61, 2, 15, 7, 19, 0, 54, 1, 13, 4, 87, 6, 40, 5, 67, 8, 34, 
    8, 98, 0, 65, 3, 85, 5, 25, 6, 50, 4, 18, 7, 19, 2, 44, 1, 20, 
    0, 67, 5, 95, 3, 83, 8, 94, 4, 42, 2, 64, 1, 93, 7, 55, 6, 73, 
    2, 31, 8, 20, 6, 97, 4, 33, 3, 42, 0, 10, 1,  8, 5, 77, 7, 83, 
    1, 41, 8, 15, 5, 87, 7, 26, 2, 15, 6, 75, 4, 82, 0, 26, 3, 20, 
    0, 36, 6, 46, 2, 17, 8, 57, 4, 42, 3, 55, 1, 55, 5, 51, 7, 86, 
    1, 76, 0, 32, 4, 57, 3, 49, 8, 75, 5, 65, 2, 59, 6, 22, 7, 70, 
    2, 76, 0, 32, 5, 82, 7, 39, 6, 80, 4, 38, 3, 15, 1, 61, 8, 71, 
    0, 17, 2, 63, 5, 20, 7, 10, 4, 36, 8, 35, 1, 36, 6,  3, 3, 15
  };
  const int q4636[] = {
    9, 9, // Number of jobs and machines
    3, 95, 0, 69, 8, 97, 5, 80, 7, 61, 4, 89, 2, 65, 6, 71, 1, 95, 
    0, 16, 7, 91, 5, 54, 3, 88, 6, 38, 4, 63, 2, 21, 8, 21, 1, 10, 
    6, 66, 5, 56, 2, 62, 8, 49, 1, 55, 0, 78, 7, 72, 3, 44, 4, 15, 
    8, 23, 3, 11, 0, 35, 5, 84, 2, 69, 4,  3, 7, 50, 1, 92, 6, 92, 
    4, 91, 6, 27, 8, 40, 7, 65, 1, 74, 5,  2, 2, 42, 0, 72, 3, 90, 
    4, 57, 8, 61, 1, 33, 0, 38, 5, 53, 6, 65, 7, 78, 2, 31, 3, 88, 
    1, 56, 4,  9, 2, 15, 5, 85, 3, 27, 0,  3, 7,  7, 6, 90, 8,  2, 
    2, 96, 7, 89, 5, 27, 6, 99, 8, 21, 0, 39, 1, 37, 4, 81, 3, 70, 
    2, 47, 5, 90, 0, 44, 7, 87, 1, 58, 6, 28, 4, 32, 3, 88, 8, 88
  };
  const int q4637[] = {
    9, 9, // Number of jobs and machines
    2, 34, 5, 27, 0, 39, 6, 33, 3, 58, 8, 13, 4, 65, 7, 87, 1, 72, 
    2, 56, 5, 51, 7, 27, 8, 85, 1, 76, 4, 59, 0, 81, 6, 61, 3, 49, 
    4, 83, 5, 10, 1,  2, 7,  8, 3, 72, 8, 27, 6, 19, 0, 64, 2, 82, 
    7, 12, 8, 68, 5,  3, 4, 66, 0, 34, 3, 40, 1, 92, 6, 78, 2,  5, 
    2, 11, 5, 31, 3, 32, 8,  8, 7, 73, 4, 11, 1, 46, 0,  7, 6, 87, 
    6, 85, 7, 29, 5, 85, 8, 13, 3, 63, 0, 32, 4, 63, 2, 24, 1, 14, 
    2, 38, 3, 18, 5, 10, 1, 24, 8, 15, 0,  7, 6,  6, 4, 38, 7, 23, 
    2, 85, 3, 84, 1, 34, 4, 21, 8, 59, 0, 97, 6, 35, 7, 37, 5, 10, 
    1, 43, 2, 50, 7,  9, 6,  9, 0, 26, 4,  2, 8, 62, 3,  2, 5, 85
  };
  const int q4638[] = {
    9, 9, // Number of jobs and machines
    3, 60, 7, 28, 8, 46, 6, 66, 5, 81, 2, 15, 1, 34, 4, 17, 0, 29, 
    4, 39, 2, 47, 0, 29, 8, 20, 7,  6, 3, 27, 5, 80, 1, 98, 6, 56, 
    2,  3, 1, 10, 8, 70, 7, 39, 3, 89, 0, 41, 6, 29, 5, 52, 4, 40, 
    2, 48, 5, 91, 8, 37, 7, 67, 6, 72, 1, 82, 3, 86, 0, 84, 4, 77, 
    6, 16, 7, 77, 8, 44, 3, 17, 4, 14, 5, 37, 1, 25, 0, 36, 2, 58, 
    5, 24, 3, 36, 1, 14, 2, 14, 4, 42, 0, 93, 6, 55, 7, 15, 8, 58, 
    7, 11, 3, 20, 2, 38, 5, 31, 6, 85, 0, 80, 8,  9, 4, 63, 1, 61, 
    2, 40, 4, 56, 5, 10, 0, 98, 8, 15, 3, 97, 7, 91, 6, 20, 1, 95, 
    1, 41, 0, 27, 2, 36, 8, 17, 7, 37, 6, 98, 5, 95, 3, 86, 4, 35
  };
  const int q4639[] = {
    9, 9, // Number of jobs and machines
    7, 99, 8, 54, 2, 82, 4, 52, 6,  1, 5, 32, 1, 54, 3,  9, 0, 50, 
    6, 70, 0, 57, 1, 54, 2,  9, 5, 66, 7, 38, 3, 53, 8, 50, 4, 34, 
    4, 10, 8, 87, 6, 48, 3, 56, 2, 72, 5, 32, 7, 87, 0, 92, 1, 92, 
    6, 81, 2, 47, 3,  2, 8,  3, 0, 91, 1, 66, 4, 33, 5, 84, 7, 86, 
    6, 81, 4, 56, 3,  5, 0, 41, 2, 50, 7,  6, 1, 28, 8, 27, 5, 73, 
    7, 88, 5, 32, 3,  1, 8, 24, 2, 36, 1, 87, 6, 13, 4, 44, 0, 27, 
    0, 70, 3, 77, 6, 50, 1, 13, 7, 42, 8, 32, 4, 72, 2, 26, 5, 34, 
    2, 20, 1, 35, 8, 90, 6, 86, 3, 48, 0, 28, 4, 36, 5, 77, 7,  7, 
    6,  3, 7, 68, 4, 53, 8, 70, 2,  5, 3, 16, 0, 89, 5, 80, 1,  5
  };
  const int q4640[] = {
    9, 9, // Number of jobs and machines
    5, 62, 0, 36, 6, 98, 2, 24, 4, 41, 1, 42, 7, 20, 8, 36, 3,  8, 
    0, 65, 3, 84, 7,  2, 2,  2, 1, 24, 6, 73, 4, 98, 8, 47, 5, 41, 
    6, 49, 5, 30, 0,  7, 3, 17, 7, 53, 8, 70, 1, 51, 4, 89, 2, 92, 
    1, 16, 3, 12, 6,  8, 4, 37, 5, 40, 7, 83, 2, 64, 0,  6, 8, 34, 
    5, 21, 3, 65, 2, 62, 4, 16, 1, 28, 0, 49, 6,  7, 7, 54, 8, 50, 
    3, 77, 7, 55, 8, 19, 4, 91, 5, 79, 1, 41, 6, 43, 0, 21, 2, 94, 
    6, 34, 1, 11, 7, 68, 5, 12, 3, 36, 0, 12, 4, 64, 2, 91, 8, 56, 
    7,  6, 2, 82, 5, 51, 8, 17, 3, 56, 1, 62, 0, 19, 4, 85, 6,  8, 
    4, 41, 7, 70, 3, 20, 1, 42, 2, 73, 8, 96, 5, 98, 0, 89, 6, 68
  };
  const int q4641[] = {
    9, 9, // Number of jobs and machines
    0, 17, 8, 85, 5, 35, 1, 67, 6, 83, 3, 56, 7, 89, 4, 27, 2, 42, 
    1, 18, 0, 71, 2, 49, 6, 73, 4, 70, 8, 98, 3, 68, 5, 71, 7, 77, 
    2, 66, 0, 64, 8, 73, 3, 17, 5, 18, 4,  2, 6, 29, 1,  3, 7, 58, 
    6, 69, 2, 59, 0, 60, 8, 56, 7, 23, 1, 14, 3, 10, 4, 35, 5, 31, 
    2, 57, 7, 20, 0, 45, 3, 10, 6,  5, 5, 86, 4, 93, 1, 40, 8, 10, 
    0, 30, 3, 20, 8, 88, 7, 33, 5,  5, 1, 21, 6, 76, 4, 58, 2, 80, 
    3, 53, 1, 51, 7, 60, 5, 94, 4, 47, 0, 68, 6, 99, 2, 48, 8, 37, 
    7, 70, 3, 74, 2, 98, 1, 53, 0, 65, 5, 98, 6, 10, 4, 91, 8, 52, 
    7, 92, 1, 20, 8, 13, 3,  3, 0,  9, 5, 64, 4, 83, 2, 49, 6, 96
  };
  const int q4642[] = {
    9, 9, // Number of jobs and machines
    1, 49, 3, 98, 5, 45, 4, 44, 2, 60, 8, 92, 7, 17, 6, 96, 0, 51, 
    2, 38, 8, 23, 3, 64, 1, 12, 6, 35, 0, 57, 5, 92, 4, 76, 7, 66, 
    0, 17, 1, 85, 6, 38, 2, 42, 5, 96, 3, 68, 8, 19, 7, 30, 4, 18, 
    8, 52, 4, 51, 6, 11, 3, 13, 0,  7, 7, 84, 1, 56, 2, 93, 5, 57, 
    0, 23, 1, 17, 5,  3, 7, 41, 8, 35, 6, 80, 2, 35, 3, 86, 4, 72, 
    3, 38, 2, 25, 0, 13, 7, 82, 5, 65, 4, 64, 1, 53, 8,  6, 6, 41, 
    3, 17, 6, 36, 1, 92, 5, 32, 0, 60, 2, 77, 7, 57, 4,  1, 8, 48, 
    6,  9, 7, 23, 3, 10, 2, 61, 0, 53, 5, 47, 8, 45, 4, 65, 1, 63, 
    2, 92, 1, 87, 3,  6, 5, 44, 0, 57, 7, 37, 8, 28, 6, 79, 4,  4
  };
  const int q4643[] = {
    9, 9, // Number of jobs and machines
    7, 59, 4, 98, 3, 21, 5, 64, 6, 29, 8, 80, 2, 35, 0, 53, 1,  8, 
    1, 93, 7, 50, 2,  6, 5, 68, 3, 19, 4,  8, 8, 92, 6, 70, 0,  8, 
    7, 35, 3, 62, 0, 29, 8,  4, 6,  8, 5, 99, 2, 99, 1, 83, 4, 29, 
    2, 48, 3, 65, 0, 93, 5, 16, 6, 64, 4, 85, 7, 27, 1, 83, 8, 23, 
    5, 99, 7, 51, 1, 79, 0,  8, 6,  5, 3,  5, 2, 17, 8, 57, 4, 90, 
    4, 39, 1, 42, 7, 44, 8, 99, 5, 23, 0, 94, 6,  2, 2, 22, 3,  2, 
    4, 38, 6, 86, 8, 43, 0, 95, 1, 78, 7, 79, 3, 66, 5, 50, 2, 60, 
    5, 14, 7, 71, 6,  4, 4,  8, 2, 16, 3,  4, 1, 33, 8, 63, 0, 94, 
    1, 93, 6, 52, 3, 74, 5, 84, 0, 64, 8, 64, 2, 50, 7, 49, 4, 57
  };
  const int q4644[] = {
    9, 9, // Number of jobs and machines
    7, 78, 3, 21, 8, 66, 5, 73, 0, 16, 2, 23, 1, 49, 6, 91, 4, 37, 
    8, 13, 2, 19, 3,  6, 5, 71, 0, 58, 6, 93, 1, 74, 4, 79, 7, 98, 
    4, 40, 1, 92, 3, 13, 6, 33, 8, 81, 5, 12, 0, 71, 7, 75, 2, 73, 
    6, 93, 8, 38, 1, 83, 2,  5, 0, 76, 3, 26, 4, 55, 7, 20, 5,  8, 
    4,  5, 5, 40, 2, 57, 6, 55, 8, 68, 1, 72, 0, 66, 3, 94, 7, 31, 
    2, 28, 4, 10, 7, 96, 5, 81, 1,  7, 8,  5, 0, 61, 3, 40, 6,  4, 
    2, 81, 1, 60, 8, 55, 5, 78, 3, 84, 6, 84, 4, 54, 0, 11, 7, 45, 
    3, 43, 1, 73, 2, 52, 6, 18, 0, 40, 7, 12, 4, 98, 5, 27, 8, 36, 
    7, 38, 8, 50, 5, 64, 4, 84, 6, 35, 0, 55, 2, 82, 1, 21, 3, 48
  };
  const int q4645[] = {
    9, 9, // Number of jobs and machines
    4, 30, 8, 27, 0, 14, 6, 67, 1, 36, 2, 95, 7, 99, 3, 10, 5,  5, 
    3, 30, 2, 48, 8, 94, 7, 54, 6, 97, 4, 76, 0,  7, 5, 79, 1, 42, 
    1, 72, 8, 57, 0, 14, 2,  1, 7,  1, 5, 73, 3, 47, 4, 54, 6, 25, 
    0, 91, 5, 85, 4, 62, 2, 36, 7, 13, 6, 78, 8,  6, 3, 84, 1, 63, 
    0, 38, 4, 58, 5, 83, 6, 15, 3, 75, 7, 65, 1, 43, 2, 59, 8, 67, 
    8, 73, 2, 26, 5, 36, 7, 83, 0, 31, 3, 22, 6, 27, 4, 77, 1, 76, 
    7, 80, 0,  6, 6, 27, 1, 72, 3, 18, 5, 75, 8, 93, 2,  4, 4, 57, 
    2, 33, 5, 23, 6, 73, 0, 51, 7, 81, 1, 11, 3, 44, 4,  6, 8, 65, 
    2, 13, 0, 17, 7, 93, 5, 63, 3, 13, 4, 68, 1, 72, 6, 67, 8,  9
  };
  const int q4646[] = {
    9, 9, // Number of jobs and machines
    8, 25, 3, 17, 4, 17, 1, 71, 0,  3, 7,  2, 5, 34, 6, 90, 2, 38, 
    1, 20, 6, 73, 0,  3, 2, 50, 7, 93, 8, 20, 4, 44, 5, 63, 3, 30, 
    3, 23, 4, 31, 5, 54, 6, 73, 7, 19, 0, 19, 8, 59, 1, 17, 2, 19, 
    2, 31, 3, 76, 7, 57, 4, 99, 1, 77, 6, 38, 8, 25, 0, 57, 5, 68, 
    1, 28, 6, 86, 0, 23, 5, 88, 2, 27, 3, 90, 7, 77, 4, 82, 8, 94, 
    3, 38, 8, 12, 7, 21, 4, 20, 5, 17, 2, 22, 1, 40, 0, 42, 6, 58, 
    0, 74, 4,  2, 1, 42, 8, 23, 7, 76, 2, 74, 3, 48, 6, 51, 5, 61, 
    8, 58, 6, 78, 5, 38, 1, 70, 4, 89, 7, 63, 0, 18, 3,  3, 2, 44, 
    6, 57, 3,  7, 1, 30, 2, 48, 8, 20, 7, 70, 0, 17, 5, 97, 4, 61
  };
  const int q4647[] = {
    9, 9, // Number of jobs and machines
    4, 34, 5, 72, 2,  2, 8, 59, 0, 69, 1, 60, 3, 90, 6, 27, 7, 87, 
    0, 17, 4, 92, 6,  2, 2, 17, 7, 57, 8, 20, 1, 23, 5, 76, 3, 39, 
    3, 32, 7, 73, 2, 50, 4, 36, 8,  9, 1, 64, 0, 49, 6, 77, 5,  7, 
    0, 45, 7, 19, 8, 67, 3, 16, 1,  7, 2, 85, 5, 75, 6, 47, 4, 28, 
    6, 43, 4, 95, 2, 40, 8, 36, 1,  4, 5, 25, 7, 36, 3, 63, 0, 33, 
    4, 57, 7,  2, 5, 94, 0, 77, 2,  7, 1, 93, 3,  6, 8, 27, 6, 44, 
    6, 56, 2, 46, 4, 69, 7, 25, 1, 94, 8,  2, 0, 63, 3, 21, 5,  6, 
    0,  4, 2, 84, 6, 21, 7, 65, 3, 39, 1, 32, 4, 45, 8, 78, 5, 64, 
    7, 54, 5,  6, 2, 36, 6, 27, 8, 33, 1, 38, 3, 47, 0,  7, 4, 41
  };
  const int q4648[] = {
    9, 9, // Number of jobs and machines
    1, 89, 5, 83, 7, 88, 6, 19, 8, 28, 0, 76, 3, 82, 4, 75, 2, 47, 
    5, 33, 6, 46, 2, 22, 1, 43, 8, 31, 7, 37, 0, 80, 3, 46, 4, 14, 
    8, 46, 3, 94, 0, 60, 1, 73, 5, 64, 6,  1, 7, 86, 4, 37, 2, 97, 
    7, 85, 6, 34, 1, 56, 8, 88, 2, 35, 0, 61, 3, 74, 4, 81, 5, 87, 
    4, 76, 0, 64, 6, 43, 8, 77, 7, 23, 5, 50, 2, 52, 1,  3, 3, 61, 
    8, 33, 2,  5, 6, 92, 1, 42, 0,  6, 4, 85, 7, 76, 3,  5, 5, 52, 
    5, 43, 0, 44, 8, 46, 2,  7, 7, 50, 6, 11, 3, 11, 4, 79, 1, 45, 
    8, 11, 2, 49, 1, 71, 7, 54, 5, 34, 4,  7, 0, 12, 6, 11, 3, 24, 
    2, 29, 5, 48, 1, 39, 0, 64, 3, 22, 7, 65, 6, 73, 4, 79, 8, 86
  };
  const int q4649[] = {
    9, 9, // Number of jobs and machines
    3, 48, 7, 89, 0, 93, 5, 86, 4, 87, 6, 53, 2, 37, 8, 40, 1, 89, 
    1, 94, 3, 85, 6, 84, 2, 24, 8, 94, 0, 69, 5, 28, 7, 79, 4, 11, 
    1, 57, 3, 65, 0, 34, 8, 39, 7, 81, 2, 30, 4, 34, 5, 84, 6,  4, 
    4, 59, 0, 85, 2, 17, 6, 84, 8, 97, 3, 92, 1,  8, 5, 28, 7, 55, 
    3, 85, 0, 34, 8, 53, 5, 78, 6, 29, 2, 38, 4,  5, 7, 37, 1, 28, 
    6, 36, 5, 16, 8, 78, 3, 79, 7, 90, 0, 18, 2, 71, 1, 55, 4, 30, 
    7, 16, 8, 97, 1, 51, 3, 91, 4, 75, 5, 93, 0, 41, 6, 20, 2, 86, 
    8, 18, 6, 49, 4, 76, 7, 51, 3, 83, 0, 32, 1, 79, 5, 98, 2, 23, 
    4, 13, 7, 50, 6, 31, 2, 42, 0, 67, 5, 69, 8, 49, 3, 89, 1, 94
  };
  const int q4650[] = {
    9, 9, // Number of jobs and machines
    0, 23, 6, 78, 1, 28, 3, 98, 4, 60, 5, 61, 8, 44, 7, 19, 2, 31, 
    7, 10, 2, 97, 4, 92, 8, 98, 5, 74, 0, 49, 3, 77, 1, 54, 6, 20, 
    5, 54, 1, 83, 3, 73, 7, 74, 4, 80, 2,  1, 0, 26, 8, 66, 6, 43, 
    3, 97, 8, 24, 1, 20, 7, 16, 2, 11, 6, 49, 4, 68, 5, 54, 0, 67, 
    6, 61, 4,  2, 8, 13, 3, 78, 2, 24, 1,  2, 5, 31, 7, 13, 0, 87, 
    5, 72, 6, 58, 8, 49, 4, 73, 2, 76, 3, 83, 0, 51, 1, 36, 7, 94, 
    4, 99, 6, 44, 5, 22, 0, 47, 2, 97, 1, 65, 3, 77, 8, 13, 7, 91, 
    5, 82, 4, 21, 6, 52, 2, 20, 0, 34, 3,  4, 8, 16, 1, 97, 7, 39, 
    8, 25, 0, 91, 7, 13, 2,  9, 4,  7, 5, 62, 3, 48, 1, 87, 6, 51
  };
  const int q4651[] = {
    9, 9, // Number of jobs and machines
    8, 70, 4, 39, 7, 49, 1, 24, 3, 44, 6, 79, 0, 38, 2,  9, 5, 53, 
    7, 45, 5, 27, 1, 35, 3, 39, 4,  1, 2,  8, 8, 35, 6,  1, 0, 15, 
    5, 62, 7, 22, 3, 58, 6, 32, 1, 38, 8,  8, 4, 81, 0,  1, 2, 33, 
    7, 91, 8, 62, 1, 67, 4, 58, 2, 54, 6, 71, 5,  4, 0,  5, 3,  8, 
    3, 65, 7,  8, 6, 19, 5, 24, 8, 39, 1, 64, 0, 88, 2, 91, 4, 48, 
    0, 14, 6, 98, 3,  6, 1, 52, 8,  9, 7, 93, 5, 53, 4, 71, 2, 26, 
    4, 14, 6, 41, 2, 64, 0, 95, 8, 24, 3, 96, 7, 93, 5, 55, 1, 18, 
    7, 54, 4,  8, 2, 72, 6, 71, 1,  7, 3, 35, 0, 54, 5, 97, 8, 18, 
    8, 45, 6, 95, 5, 29, 3, 78, 7, 69, 0,  8, 1, 18, 2, 70, 4, 96
  };
  const int q4652[] = {
    9, 9, // Number of jobs and machines
    8, 19, 0, 83, 5, 41, 4, 51, 2,  5, 7, 48, 6, 98, 1, 48, 3, 42, 
    0, 45, 3,  8, 8, 74, 5,  4, 4, 53, 6, 39, 2, 55, 7, 96, 1, 23, 
    7, 92, 5,  9, 2, 19, 1, 64, 8, 92, 0, 90, 6, 67, 3, 70, 4, 43, 
    5, 23, 7, 49, 4, 54, 2, 13, 3, 76, 8, 50, 0, 37, 6,  2, 1, 27, 
    6, 97, 3, 20, 1, 97, 7, 18, 8, 24, 4, 65, 5, 52, 2, 37, 0,  6, 
    2, 54, 8, 46, 7, 58, 1, 52, 4, 85, 0, 71, 3, 70, 6, 15, 5, 53, 
    3, 99, 0,  3, 7, 83, 6, 85, 5, 13, 1, 27, 8, 24, 2, 37, 4,  5, 
    5, 59, 7, 23, 6, 55, 4, 28, 2, 22, 0, 40, 1, 80, 3, 45, 8, 17, 
    5, 66, 4, 47, 1, 53, 2, 40, 8, 59, 7, 72, 0, 43, 3, 24, 6, 70
  };
  const int q4653[] = {
    9, 9, // Number of jobs and machines
    3, 89, 0, 58, 1, 92, 6, 19, 2, 58, 7, 15, 5, 56, 4, 97, 8,  7, 
    7, 65, 4, 66, 5, 66, 8, 55, 1, 32, 3, 62, 2, 58, 0, 84, 6, 57, 
    7, 56, 1, 96, 5, 42, 8, 83, 2, 55, 3, 46, 6, 98, 0,  7, 4, 61, 
    4, 11, 1, 57, 8, 30, 5, 51, 2, 70, 6, 45, 7,  8, 3, 69, 0, 76, 
    6, 94, 7,  8, 0, 39, 5, 46, 2, 74, 4, 38, 8, 14, 1,  4, 3,  7, 
    3, 13, 8,  2, 1, 79, 5, 60, 0, 98, 4, 63, 2, 77, 7, 68, 6, 47, 
    4, 34, 2, 15, 0, 66, 3, 98, 8, 11, 1, 40, 6, 99, 5, 68, 7, 82, 
    0, 71, 4, 25, 7, 57, 1, 65, 3, 15, 2, 60, 8, 38, 5, 43, 6, 49, 
    2, 98, 0, 73, 7, 89, 4, 94, 6, 42, 1, 98, 3,  3, 8, 71, 5, 35
  };
  const int q4654[] = {
    9, 9, // Number of jobs and machines
    3, 92, 7, 39, 4, 44, 8, 95, 0, 56, 6, 28, 1, 55, 5, 85, 2, 99, 
    3, 30, 2, 19, 1, 42, 6, 78, 0, 62, 8, 85, 5, 84, 7, 96, 4, 53, 
    4, 68, 7, 66, 6, 11, 2, 32, 1, 18, 8, 88, 0, 23, 5, 25, 3, 74, 
    8, 49, 2,  6, 1, 77, 6, 84, 3, 98, 5, 14, 7, 28, 0, 38, 4, 50, 
    2, 93, 3, 86, 5, 28, 8, 55, 4, 69, 7,  7, 1, 35, 6, 70, 0, 73, 
    6, 85, 5, 70, 7, 21, 1, 73, 2, 77, 4, 19, 8, 72, 3, 31, 0, 45, 
    4, 84, 5, 11, 8, 84, 0,  2, 6, 42, 2,  7, 3, 18, 1, 30, 7,  1, 
    1, 25, 6, 72, 3, 56, 5, 12, 0,  8, 7, 24, 2, 56, 4, 58, 8, 98, 
    5, 42, 7, 82, 3,  6, 0, 46, 2,  1, 6, 55, 1, 21, 8, 65, 4, 73
  };
  const int q4655[] = {
    9, 9, // Number of jobs and machines
    2, 26, 7, 32, 8, 47, 5, 34, 6, 86, 1, 91, 0, 21, 4, 90, 3, 71, 
    5, 23, 7, 99, 8, 26, 3, 82, 0, 22, 4, 90, 1,  5, 6, 92, 2, 15, 
    2, 10, 0, 38, 3, 84, 5, 55, 7, 72, 8, 67, 1, 10, 4, 63, 6,  7, 
    8,  1, 6, 41, 2, 21, 7, 81, 0, 69, 5, 72, 1, 22, 3, 88, 4, 33, 
    0, 40, 2, 51, 6, 71, 3, 92, 4, 15, 8, 93, 1, 82, 7, 51, 5, 15, 
    7, 97, 6, 32, 3, 74, 1, 93, 2, 30, 4, 35, 0, 12, 8, 71, 5, 56, 
    6, 52, 3, 30, 1, 98, 8, 97, 5, 15, 2, 19, 7, 31, 4, 84, 0, 78, 
    3, 75, 4, 95, 7, 53, 6, 60, 8, 62, 0, 54, 2, 33, 1, 85, 5, 82, 
    8, 38, 4, 49, 2, 58, 5, 50, 6, 66, 0, 99, 3, 93, 7, 53, 1, 56
  };
  const int q4656[] = {
    9, 9, // Number of jobs and machines
    3, 70, 2, 16, 8, 43, 5, 72, 7, 80, 1, 24, 0, 57, 4, 57, 6, 71, 
    0, 78, 2, 14, 7,  4, 4, 71, 5, 59, 1, 22, 8,  4, 3, 78, 6, 53, 
    6,  1, 2, 48, 7, 36, 5, 52, 0,  5, 1, 10, 4, 98, 8, 20, 3, 31, 
    5, 75, 2, 31, 6, 88, 3, 96, 4, 72, 0, 34, 1, 32, 7, 60, 8, 33, 
    8, 68, 0,  8, 5, 68, 1, 44, 2, 16, 4,  2, 7, 17, 3, 74, 6, 62, 
    7, 48, 3, 24, 5, 93, 6, 50, 2, 94, 8, 99, 0,  3, 1, 16, 4, 32, 
    3, 62, 5, 76, 1, 44, 8, 23, 6, 94, 7, 46, 4,  1, 2, 59, 0, 20, 
    0, 85, 2, 58, 3, 36, 1, 85, 5, 53, 6,  8, 4, 32, 8, 61, 7, 31, 
    5, 46, 1,  9, 3, 51, 8, 50, 4, 67, 2, 53, 0, 74, 6, 53, 7, 64
  };
  const int q4657[] = {
    9, 9, // Number of jobs and machines
    6,  9, 5, 81, 4, 78, 8, 37, 3,  5, 7, 48, 0, 89, 2, 90, 1, 70, 
    5, 20, 7, 44, 4, 55, 2, 58, 8, 20, 0, 68, 3,  7, 6, 52, 1, 55, 
    8, 75, 7, 80, 3, 55, 6,  4, 5, 97, 2, 51, 4, 78, 0, 23, 1, 29, 
    0, 82, 6, 38, 5, 11, 1, 41, 7, 96, 2, 85, 3, 75, 4, 80, 8, 85, 
    5, 43, 4, 94, 2, 30, 0, 92, 7, 12, 1, 25, 6, 95, 8, 44, 3,  4, 
    1, 38, 7, 27, 2, 23, 4, 40, 0, 83, 6, 46, 8, 69, 3, 27, 5, 88, 
    3, 23, 7, 51, 5,  3, 6, 78, 8, 98, 4, 13, 2, 12, 1, 68, 0, 75, 
    3, 29, 2, 62, 1, 97, 4, 27, 7, 82, 0, 25, 6, 88, 8, 85, 5, 99, 
    5, 20, 3, 98, 6, 93, 7, 77, 1, 48, 2, 25, 4, 76, 0, 78, 8, 33
  };
  const int q4658[] = {
    9, 9, // Number of jobs and machines
    1, 83, 4, 50, 0, 99, 5, 14, 2, 58, 7, 47, 6, 61, 3, 77, 8, 63, 
    2, 30, 1, 86, 3, 61, 5, 15, 4, 47, 8, 52, 0, 54, 7, 52, 6, 66, 
    3, 91, 4, 18, 7, 89, 2, 46, 5, 12, 6, 18, 8, 62, 1, 50, 0, 67, 
    0, 46, 2, 70, 1, 38, 7, 66, 6, 86, 5, 63, 4, 65, 8, 32, 3, 11, 
    3, 35, 7, 82, 6, 93, 1, 32, 5, 85, 4, 33, 2, 78, 8, 54, 0, 73, 
    4, 82, 8, 61, 5,  9, 1, 63, 0, 99, 3, 42, 6, 64, 7,  7, 2, 42, 
    5, 25, 0, 17, 4, 59, 8, 29, 1, 31, 3, 15, 7, 35, 6, 64, 2, 26, 
    5, 11, 4, 86, 1, 65, 6, 24, 7, 98, 0, 93, 8, 28, 2, 13, 3, 61, 
    3, 15, 6, 81, 0, 25, 1, 40, 4, 59, 8, 22, 7, 34, 5, 80, 2, 30
  };
  const int q4659[] = {
    9, 9, // Number of jobs and machines
    3, 24, 0, 45, 6, 64, 5, 24, 2, 67, 7, 51, 4, 43, 8, 31, 1, 77, 
    7, 16, 1, 79, 4,  7, 0,  4, 6, 67, 3, 26, 2, 73, 5, 41, 8, 36, 
    0, 60, 6, 26, 3, 91, 2,  6, 4, 93, 7, 23, 1, 28, 8, 45, 5, 91, 
    2,  5, 5, 39, 7, 56, 4, 46, 8, 91, 6, 51, 1, 33, 0, 14, 3, 33, 
    5, 40, 3, 59, 2, 72, 6, 86, 8, 62, 1, 59, 7, 14, 0, 65, 4, 96, 
    6, 69, 8, 17, 7, 36, 5, 62, 0, 80, 1, 10, 2, 73, 4, 50, 3, 63, 
    5, 36, 4, 12, 1,  1, 2, 92, 8, 60, 6, 31, 3, 86, 0, 76, 7, 68, 
    6, 48, 4, 53, 2, 68, 7, 33, 1, 48, 8, 72, 5, 96, 0, 22, 3,  5, 
    4, 52, 6, 31, 5, 66, 3, 62, 1, 45, 0, 61, 8, 84, 7, 58, 2, 94
  };
  const int q4660[] = {
    9, 9, // Number of jobs and machines
    7, 20, 6, 51, 4, 76, 2, 79, 0, 23, 8, 99, 1, 18, 5,  5, 3, 42, 
    7, 48, 8, 53, 5, 81, 0, 21, 3, 56, 4, 48, 2, 29, 6, 61, 1, 83, 
    3, 11, 1, 70, 7, 63, 0, 66, 5, 67, 2, 50, 4, 93, 6, 47, 8, 99, 
    5, 78, 0, 39, 1, 50, 7, 50, 2, 97, 3, 63, 8,  1, 6, 77, 4, 80, 
    3, 96, 5, 49, 7, 99, 0, 70, 1, 66, 8,  3, 6, 49, 4, 93, 2, 22, 
    5, 48, 4, 80, 0,  3, 6, 23, 7, 53, 8, 19, 1, 78, 3, 52, 2, 30, 
    5, 21, 4, 83, 7, 46, 1, 22, 3,  9, 2, 76, 0, 12, 6,  3, 8, 28, 
    1, 81, 3, 65, 2, 97, 7, 94, 6, 41, 0, 64, 4, 87, 8, 42, 5, 73, 
    6, 55, 7, 53, 5, 23, 3, 73, 2, 73, 0, 90, 1, 81, 4, 60, 8, 97
  };
  const int q4661[] = {
    9, 9, // Number of jobs and machines
    6, 77, 8, 69, 2, 51, 3, 86, 1,  5, 5, 20, 4, 31, 0, 31, 7, 89, 
    7, 47, 0, 96, 4, 81, 8, 81, 6, 12, 1,  2, 5, 34, 3, 93, 2, 63, 
    7, 16, 8, 72, 3,  8, 4, 63, 1, 32, 6, 29, 5, 69, 2, 52, 0, 82, 
    1, 87, 6, 92, 5, 33, 7, 25, 3, 81, 4, 52, 8, 29, 2, 46, 0, 54, 
    1, 55, 8, 56, 0,  2, 4, 45, 6, 23, 3, 77, 2, 34, 7, 34, 5, 20, 
    1, 25, 4, 72, 5, 31, 0, 33, 7, 41, 6, 72, 8, 44, 2, 42, 3, 19, 
    3, 30, 5, 64, 7, 19, 0, 74, 8, 94, 4, 33, 1, 76, 2, 48, 6, 51, 
    4, 10, 8, 57, 0, 28, 1, 22, 6, 74, 7, 78, 5, 18, 3, 46, 2, 28, 
    7, 28, 4, 56, 1,  7, 2, 76, 0, 66, 3, 56, 8, 28, 5, 17, 6, 48
  };
  const int q4662[] = {
    9, 9, // Number of jobs and machines
    7, 66, 6, 29, 1, 54, 4, 23, 3, 17, 2, 12, 0, 53, 5, 25, 8, 45, 
    7, 71, 1, 63, 8, 93, 2, 56, 3, 83, 0, 27, 6, 48, 4, 53, 5, 67, 
    4, 64, 1, 51, 5, 61, 0,  6, 6, 24, 3, 57, 8, 31, 2, 39, 7, 18, 
    1, 49, 7, 55, 5, 85, 6, 51, 0, 62, 4, 98, 8, 99, 2, 79, 3, 18, 
    1,  7, 6, 75, 8, 92, 5,  2, 3, 75, 2, 24, 7, 80, 4, 16, 0, 43, 
    0, 99, 5, 79, 4, 73, 6, 79, 8, 31, 2,  6, 7, 61, 3, 77, 1, 18, 
    7, 80, 2, 31, 1, 60, 8, 68, 4, 55, 0, 92, 3, 19, 6, 54, 5, 33, 
    4,  4, 0, 94, 8, 87, 6, 27, 5, 95, 7, 73, 3, 33, 1, 50, 2, 45, 
    1, 49, 4, 36, 2, 59, 7, 91, 3, 97, 8, 57, 0, 60, 6,  8, 5, 10
  };
  const int q4663[] = {
    9, 9, // Number of jobs and machines
    6, 86, 7, 86, 1, 32, 0, 64, 8, 31, 3, 90, 5, 99, 4, 55, 2, 78, 
    4, 85, 6,  7, 1, 44, 2, 86, 8, 94, 7, 58, 0, 15, 3, 78, 5, 83, 
    3, 40, 7, 87, 8, 70, 4, 23, 5, 79, 1, 21, 0, 23, 2, 56, 6, 99, 
    1, 36, 4, 43, 2, 95, 5, 31, 6, 91, 8, 14, 0, 43, 3,  6, 7, 82, 
    6,  8, 8, 88, 3, 47, 4, 45, 1, 24, 0, 90, 7, 59, 5, 45, 2, 21, 
    8, 88, 5, 86, 4, 82, 3, 67, 2, 65, 1, 97, 0, 46, 6, 13, 7, 30, 
    8, 30, 6, 49, 2, 15, 1, 33, 0, 61, 7, 27, 3, 90, 5, 67, 4, 63, 
    3, 46, 8, 64, 7,  9, 5, 66, 4,  9, 6, 95, 2, 40, 0, 43, 1, 24, 
    7, 45, 1, 41, 5, 58, 0, 81, 6, 64, 2, 59, 4,  9, 3, 47, 8, 28
  };
  const int q4664[] = {
    9, 9, // Number of jobs and machines
    1, 80, 7, 78, 5, 25, 3, 70, 0, 65, 2, 26, 8, 16, 4, 51, 6, 28, 
    0, 19, 1, 83, 8, 24, 2,  3, 4, 61, 3, 87, 6, 89, 5, 44, 7, 85, 
    4, 41, 6,  1, 2, 18, 5, 95, 1, 68, 7, 59, 8, 22, 0, 65, 3, 22, 
    4, 35, 1,  8, 8, 77, 0, 38, 3, 45, 2, 74, 5, 14, 6, 79, 7, 55, 
    0, 83, 5, 86, 7, 61, 6, 86, 2, 84, 1, 72, 4, 36, 8, 61, 3, 10, 
    2, 56, 4, 31, 5, 26, 7, 85, 6, 98, 0, 94, 1, 57, 8, 62, 3, 51, 
    8, 44, 1, 95, 7, 13, 6, 66, 2, 73, 3, 19, 5, 97, 4, 98, 0, 90, 
    3,  9, 2, 40, 5, 50, 0, 32, 1, 42, 7, 37, 6,  7, 8, 33, 4, 18, 
    0, 67, 4, 53, 3, 21, 5, 86, 2, 60, 8, 42, 6, 94, 7, 65, 1, 76
  };
  const int q4665[] = {
    9, 9, // Number of jobs and machines
    7, 57, 2, 69, 1, 34, 8, 48, 5, 53, 0, 33, 4, 55, 6, 41, 3, 84, 
    1, 13, 6, 38, 8,  5, 7, 10, 2, 87, 3, 76, 4, 88, 5, 78, 0, 30, 
    8, 99, 5, 70, 7, 61, 3, 53, 1, 94, 6, 67, 4, 76, 2, 48, 0, 48, 
    0, 47, 7, 75, 6, 61, 3, 64, 2, 96, 5, 83, 8, 16, 1, 75, 4, 55, 
    3, 28, 1, 56, 6, 14, 0, 89, 2, 46, 8, 24, 5, 81, 7, 34, 4, 16, 
    3, 62, 1, 69, 8, 37, 2, 84, 6, 30, 0, 93, 4, 91, 5, 57, 7, 75, 
    2, 75, 4, 75, 0, 22, 3, 34, 6, 21, 1, 24, 7, 38, 8, 29, 5, 27, 
    8, 67, 6, 31, 4, 31, 3, 24, 5, 16, 2, 53, 0, 17, 1, 51, 7, 35, 
    4, 85, 8, 59, 2, 43, 5, 38, 6,  1, 3, 22, 1,  4, 7,  3, 0, 94
  };
  const int q4666[] = {
    9, 9, // Number of jobs and machines
    1, 82, 2, 89, 3, 22, 6, 65, 8, 85, 7, 52, 4, 90, 0, 55, 5, 96, 
    3, 24, 1, 39, 7, 96, 5, 98, 2, 64, 4, 50, 6, 15, 0, 25, 8, 49, 
    4, 15, 7, 80, 8, 54, 0, 91, 5, 19, 2, 30, 3, 45, 1, 20, 6, 75, 
    3, 59, 1, 84, 2, 78, 4, 28, 6, 84, 0, 87, 8, 42, 5, 20, 7, 34, 
    4, 97, 2, 22, 3, 71, 6, 26, 8, 67, 1, 59, 7, 67, 0, 41, 5, 87, 
    4, 89, 2, 56, 0, 73, 8, 68, 6, 14, 7, 13, 3, 37, 1, 83, 5, 28, 
    4, 92, 8, 26, 6, 21, 2, 98, 0, 23, 3, 54, 5, 36, 1, 96, 7, 52, 
    6, 57, 3, 61, 2, 16, 8, 11, 5, 73, 7,  6, 0, 35, 4, 24, 1,  1, 
    2, 24, 0, 96, 7, 91, 8, 73, 4, 38, 1, 93, 5, 72, 3, 23, 6, 83
  };
  const int q4667[] = {
    9, 9, // Number of jobs and machines
    8, 62, 4,  7, 3,  6, 5, 91, 7, 87, 1, 23, 0, 59, 6, 47, 2,  6, 
    3, 24, 4, 34, 2, 29, 1, 91, 7, 55, 0, 99, 6, 25, 5, 58, 8, 91, 
    8, 61, 5, 71, 0, 90, 7, 22, 4, 50, 2, 34, 3, 99, 6, 96, 1, 57, 
    0, 91, 3, 50, 8, 18, 4, 51, 6, 27, 2, 39, 7, 36, 5, 52, 1, 55, 
    2, 97, 7, 95, 3, 31, 1, 23, 5, 33, 6, 79, 0, 94, 8, 12, 4, 70, 
    0, 60, 6, 89, 8, 28, 2, 35, 7, 13, 1, 49, 4, 12, 5, 14, 3, 92, 
    6, 80, 3, 52, 2, 73, 5, 29, 1, 85, 7, 93, 4, 89, 8, 96, 0,  3, 
    4, 46, 0,  5, 8, 10, 6, 37, 5, 21, 7, 35, 2, 26, 3, 45, 1, 18, 
    7, 24, 2, 61, 5, 33, 3, 63, 8, 72, 1, 34, 4, 31, 0,  2, 6, 61
  };
  const int q4668[] = {
    9, 9, // Number of jobs and machines
    6, 15, 4, 82, 3, 35, 7, 87, 0, 39, 8, 34, 1, 33, 5, 41, 2, 15, 
    8, 55, 4, 74, 5, 75, 1, 74, 0, 51, 7, 46, 3, 95, 6, 59, 2, 62, 
    5, 91, 1, 38, 4, 20, 7, 75, 6, 23, 0, 85, 8, 31, 3, 68, 2,  1, 
    4, 74, 5, 91, 0, 33, 8,  3, 2, 22, 1, 62, 7, 58, 6, 73, 3, 45, 
    8, 10, 2, 33, 7, 36, 0, 64, 4, 20, 3, 27, 5, 99, 6, 58, 1, 75, 
    4, 99, 0, 55, 3, 95, 7, 91, 2, 56, 1, 32, 8, 61, 5, 83, 6, 54, 
    6, 45, 1, 69, 2,  2, 8,  8, 0, 98, 5, 27, 7, 95, 3, 38, 4, 87, 
    3, 62, 0, 58, 8,  8, 1, 87, 7, 81, 5, 10, 6, 11, 4, 70, 2, 77, 
    0, 45, 6, 15, 4, 43, 7,  8, 1, 24, 2,  7, 3, 51, 5, 23, 8, 89
  };
  const int q4669[] = {
    9, 9, // Number of jobs and machines
    5, 35, 2, 77, 3, 27, 4, 54, 0, 65, 8, 91, 7, 18, 6, 60, 1, 66, 
    1, 80, 0,  6, 2, 17, 6, 61, 7, 90, 4, 12, 5, 12, 3, 16, 8, 42, 
    4, 33, 5, 25, 8, 87, 3, 65, 0, 93, 2, 55, 6, 62, 7, 42, 1, 83, 
    3, 93, 5, 28, 7, 16, 6, 29, 1, 15, 8, 35, 2, 37, 4,  9, 0, 20, 
    2,  9, 7, 84, 5, 75, 8, 27, 4, 87, 6, 45, 0, 56, 3, 36, 1,  8, 
    6, 66, 0, 87, 8, 13, 3, 80, 1,  3, 5, 29, 4, 16, 7, 93, 2, 87, 
    3, 95, 4, 39, 5, 69, 0, 35, 6, 21, 7, 38, 8, 19, 1, 36, 2, 77, 
    5, 30, 3, 36, 6, 23, 2,  1, 7, 56, 8, 60, 1, 14, 4, 61, 0, 45, 
    3, 98, 5, 17, 2, 26, 0, 88, 4,  5, 1, 59, 8,  4, 7,  5, 6, 14
  };
  const int q4670[] = {
    9, 9, // Number of jobs and machines
    3, 36, 6, 69, 7, 83, 1, 68, 2, 41, 8, 50, 0, 44, 4, 42, 5, 76, 
    4, 64, 8,  1, 7, 36, 3, 61, 0, 57, 1, 86, 5, 28, 2, 98, 6,  2, 
    3, 83, 4, 74, 0, 13, 6, 71, 8, 97, 2, 96, 1, 49, 7, 65, 5, 54, 
    3, 99, 4, 10, 1, 80, 2, 65, 0, 97, 8, 52, 6, 34, 7, 58, 5,  4, 
    1, 40, 4, 12, 0, 94, 6, 87, 8, 18, 5, 30, 3, 67, 7,  2, 2, 15, 
    5, 28, 2, 17, 3, 74, 1, 63, 0, 80, 8, 27, 6, 74, 7, 25, 4, 44, 
    2, 50, 3, 55, 4, 48, 6, 69, 8, 34, 7, 48, 1, 87, 5, 59, 0, 72, 
    3, 56, 0, 46, 7, 86, 5, 92, 4, 26, 8, 30, 1,  2, 2, 74, 6, 31, 
    2, 76, 3, 12, 4, 27, 6, 10, 5,  2, 0, 11, 1, 52, 8, 11, 7,  3
  };
  const int q4671[] = {
    9, 9, // Number of jobs and machines
    6, 79, 2, 74, 7, 35, 3,  4, 8, 15, 4, 45, 1, 78, 0, 26, 5, 91, 
    4, 19, 3, 94, 0, 15, 8, 65, 2, 90, 5, 72, 7, 82, 1, 38, 6, 47, 
    7, 74, 2, 47, 1, 37, 4, 39, 6, 80, 5, 10, 8, 64, 0, 49, 3, 93, 
    5,  4, 1, 20, 2,  4, 4, 19, 8, 89, 7, 63, 3, 38, 0, 50, 6, 96, 
    3, 33, 2, 89, 8, 17, 4, 89, 7, 28, 1,  6, 0, 18, 6, 19, 5, 89, 
    8, 34, 5, 58, 2, 11, 0, 94, 6, 52, 4, 89, 7, 32, 3, 52, 1, 57, 
    0, 35, 2, 68, 1, 26, 4, 40, 5, 43, 7, 30, 3, 28, 6, 71, 8, 80, 
    1,  5, 7, 55, 4, 77, 8, 37, 5, 97, 6, 61, 3, 34, 0, 35, 2, 94, 
    5, 14, 3, 92, 0, 52, 8, 45, 7, 14, 6, 55, 1, 59, 4, 58, 2, 32
  };
  const int q4672[] = {
    9, 9, // Number of jobs and machines
    3, 33, 0, 51, 4, 19, 7, 30, 6, 73, 8, 19, 1, 50, 2, 97, 5, 60, 
    7, 42, 4, 91, 1, 48, 0, 30, 2, 64, 6, 41, 8, 70, 3, 14, 5, 62, 
    3, 29, 1, 89, 5, 92, 7, 34, 4, 39, 8, 72, 0, 86, 2, 39, 6, 12, 
    4,  8, 8, 73, 3,  1, 2, 26, 7, 24, 0,  8, 6, 15, 5, 28, 1, 61, 
    7,  7, 3, 79, 8, 18, 6, 33, 5, 84, 1,  9, 0, 13, 4, 82, 2, 87, 
    6, 62, 8, 44, 4, 95, 2,  6, 0, 28, 1, 84, 5, 41, 7, 52, 3, 23, 
    1, 53, 6, 43, 8, 97, 2, 79, 5, 39, 3, 76, 0, 66, 4, 19, 7, 45, 
    2, 50, 5, 79, 4, 40, 3, 86, 7, 47, 6, 43, 1, 32, 8, 48, 0, 96, 
    5, 68, 1,  3, 3, 42, 6, 37, 8,  5, 0, 96, 2, 97, 7, 72, 4, 54
  };
  const int q4673[] = {
    9, 9, // Number of jobs and machines
    8, 88, 7, 49, 1, 73, 6, 58, 2, 49, 5, 38, 0, 85, 3, 76, 4, 72, 
    4, 75, 3, 73, 6, 42, 1, 12, 7, 46, 2, 18, 5, 75, 8, 30, 0, 94, 
    7, 93, 0, 36, 2,  8, 6, 64, 5,  2, 8,  6, 3, 44, 1, 44, 4, 30, 
    2, 84, 7, 13, 5, 74, 8, 98, 6, 96, 3, 64, 1, 61, 0, 12, 4, 72, 
    4,  1, 1, 61, 6, 13, 0, 34, 2,  3, 7, 92, 8, 53, 5, 23, 3, 11, 
    4, 19, 2, 12, 7, 16, 6, 63, 8, 71, 3, 61, 1, 44, 5, 83, 0, 80, 
    1, 49, 0, 52, 3, 60, 2, 70, 7, 75, 4, 78, 8, 75, 5, 39, 6,  1, 
    1, 54, 0, 74, 6, 69, 5, 99, 4, 27, 8, 88, 7, 64, 3, 13, 2,  8, 
    8, 23, 4, 27, 1, 28, 2, 59, 5, 85, 7, 73, 3, 22, 6,  8, 0, 21
  };
  const int q4674[] = {
    9, 9, // Number of jobs and machines
    2, 35, 0, 79, 5, 89, 3, 12, 8, 62, 7, 95, 4, 45, 6, 15, 1, 32, 
    1, 78, 5, 19, 7, 73, 3, 58, 6, 69, 0,  2, 8, 72, 4, 75, 2, 83, 
    0, 44, 7, 42, 5, 44, 8, 90, 2, 68, 4, 41, 1, 26, 3, 88, 6, 23, 
    4, 82, 2, 85, 6, 52, 8, 40, 1, 58, 7, 81, 5,  5, 3, 31, 0, 82, 
    8, 30, 3, 82, 7,  3, 2, 24, 4, 78, 6, 57, 5,  5, 1, 25, 0, 22, 
    6, 92, 5,  1, 1, 24, 3, 59, 0, 39, 8, 52, 2, 67, 7, 95, 4, 98, 
    1, 16, 2, 86, 4, 24, 7, 15, 6, 62, 3, 49, 0, 13, 5, 90, 8, 54, 
    1, 27, 0, 65, 2, 37, 7, 93, 8, 28, 3, 24, 6, 93, 4, 55, 5, 12, 
    0, 46, 3, 31, 8, 67, 7, 50, 1, 91, 6, 62, 2, 34, 4, 88, 5, 63
  };
  const int q4675[] = {
    9, 9, // Number of jobs and machines
    1, 24, 6, 19, 7, 83, 0, 91, 5,  3, 4, 49, 3, 13, 8, 38, 2, 32, 
    2, 43, 7, 22, 8, 77, 0, 25, 6, 60, 3, 76, 5, 85, 4, 76, 1, 89, 
    3, 89, 8,  9, 5, 21, 1, 70, 4, 38, 0, 80, 6, 94, 2, 69, 7, 37, 
    6,  3, 7, 84, 2, 89, 1, 20, 3, 75, 5, 86, 8, 16, 0, 47, 4, 44, 
    2, 65, 0, 80, 8, 98, 5, 87, 7, 57, 6, 24, 3, 53, 1, 42, 4, 27, 
    6, 17, 7, 30, 3, 21, 4, 60, 1, 38, 0, 70, 8, 75, 2, 87, 5, 35, 
    6, 44, 7, 93, 1, 51, 2, 97, 5, 42, 4, 63, 8, 47, 3, 38, 0,  4, 
    4, 53, 1,  6, 7,  3, 8, 44, 6,  8, 5, 92, 3, 55, 2, 71, 0, 55, 
    3, 35, 4, 10, 8, 81, 2, 73, 6, 62, 0,  5, 7, 85, 1, 38, 5, 80
  };
  const int q4676[] = {
    9, 9, // Number of jobs and machines
    8, 46, 6, 36, 5, 64, 0, 30, 1, 67, 4, 27, 7, 81, 2, 56, 3, 45, 
    1, 80, 8, 49, 7, 22, 6, 63, 0, 56, 4, 81, 5, 21, 2, 21, 3, 13, 
    5, 87, 2, 32, 0, 56, 6, 29, 8, 31, 1, 92, 4, 83, 7, 42, 3, 66, 
    1, 55, 0, 57, 4, 43, 6, 56, 7, 53, 3, 84, 8, 56, 5, 47, 2, 41, 
    3, 57, 1, 36, 0, 23, 4, 53, 8, 23, 7, 86, 2, 11, 5, 59, 6,  9, 
    1, 27, 7, 72, 3, 70, 5, 73, 4, 91, 6, 80, 0, 84, 2, 85, 8, 73, 
    5, 37, 6, 50, 8, 64, 0, 15, 2, 92, 7, 90, 4, 21, 1, 16, 3, 98, 
    8, 78, 1,  6, 6, 46, 2, 23, 5, 83, 7, 17, 4, 61, 0,  6, 3,  6, 
    6, 25, 8, 50, 1, 84, 7, 66, 4, 56, 0, 65, 2, 52, 3,  3, 5, 12
  };
  const int q4677[] = {
    9, 9, // Number of jobs and machines
    0, 58, 6, 18, 7, 23, 5, 11, 4, 30, 2, 94, 3, 35, 1, 88, 8, 38, 
    8, 30, 2, 51, 7, 34, 6, 39, 0,  8, 4,  7, 5, 22, 1, 33, 3,  1, 
    1, 71, 6, 84, 3, 90, 4, 85, 0, 14, 8, 29, 7, 31, 5, 64, 2, 12, 
    7, 49, 6, 83, 2, 35, 5, 70, 4, 95, 3, 84, 1, 93, 0,  1, 8, 13, 
    5, 83, 2, 45, 0, 42, 3, 63, 1, 43, 8, 33, 4, 32, 6, 30, 7, 87, 
    4, 43, 3, 37, 6, 95, 8, 64, 5, 51, 2, 16, 1, 37, 0, 87, 7, 85, 
    5, 44, 8, 67, 0, 56, 1, 78, 3, 30, 6, 27, 7, 87, 4,  4, 2, 80, 
    1, 86, 8, 33, 0, 83, 7, 48, 5, 22, 3, 50, 2, 65, 4, 31, 6, 18, 
    7,  2, 5, 73, 3,  6, 6, 29, 2, 11, 1, 84, 0, 71, 8, 61, 4, 66
  };
  const int q4678[] = {
    9, 9, // Number of jobs and machines
    1, 82, 3, 50, 7, 63, 6, 96, 8, 19, 0, 44, 4, 89, 5, 25, 2, 79, 
    2, 24, 5, 59, 0, 79, 4,  4, 6, 32, 7, 13, 3, 38, 1, 38, 8, 92, 
    0, 44, 7, 72, 3,  1, 5, 43, 2, 60, 1, 15, 8, 78, 4, 29, 6, 74, 
    1, 38, 0, 37, 8,  9, 7, 37, 2, 87, 3, 79, 5, 26, 6, 71, 4, 16, 
    2, 17, 6, 92, 4, 82, 5, 29, 0, 78, 8, 64, 1, 44, 7, 30, 3,  3, 
    0, 12, 4, 16, 2, 13, 3, 87, 1, 67, 6, 39, 7, 10, 8, 25, 5, 71, 
    3,  8, 4, 60, 5, 54, 7, 47, 1, 43, 8, 69, 2, 14, 6, 10, 0, 93, 
    3, 66, 1, 29, 0, 82, 2, 26, 6, 51, 7, 64, 4,  6, 8,  4, 5, 83, 
    5, 38, 6, 87, 4, 26, 3, 51, 1, 23, 2, 43, 7, 70, 8, 42, 0, 29
  };
  const int q4679[] = {
    9, 9, // Number of jobs and machines
    5, 75, 2, 62, 0, 24, 7, 11, 3,  6, 6, 93, 1, 55, 8, 62, 4, 80, 
    2, 80, 1, 56, 6, 37, 3,  4, 0, 67, 4,  6, 8, 84, 7, 51, 5, 73, 
    8, 76, 2, 70, 4,  8, 0, 61, 5, 53, 1, 53, 3, 61, 6, 48, 7, 52, 
    7, 88, 5, 20, 3, 37, 8, 49, 1, 72, 4, 76, 2, 39, 6, 79, 0, 84, 
    7, 16, 0, 50, 2,  6, 8, 36, 4, 53, 5, 23, 1, 49, 6, 40, 3, 99, 
    3, 74, 7, 37, 5, 30, 1, 24, 6, 89, 8, 21, 4, 22, 2, 69, 0, 98, 
    3, 17, 7, 12, 4, 60, 6, 96, 8, 63, 2, 68, 0, 88, 1, 43, 5,  1, 
    5, 30, 0, 65, 7, 96, 2, 93, 3, 28, 1,  7, 8, 66, 6, 13, 4, 32, 
    4, 35, 7, 94, 8, 12, 2, 45, 1, 11, 3, 20, 5, 46, 0, 21, 6, 45
  };
  const int q4680[] = {
    9, 9, // Number of jobs and machines
    6,  4, 7, 66, 8, 47, 5, 89, 1, 10, 2, 74, 4, 65, 3,  2, 0, 13, 
    2, 68, 4, 69, 6, 69, 7, 28, 5, 11, 8, 48, 0, 70, 1, 83, 3, 79, 
    6, 61, 4, 37, 2, 10, 1, 64, 3, 70, 8, 33, 0, 61, 7, 80, 5, 29, 
    2, 49, 3, 26, 7,  5, 6, 61, 4,  4, 5, 20, 1, 49, 0, 74, 8, 76, 
    0, 34, 7, 43, 1, 63, 5, 72, 8, 88, 4, 26, 2, 82, 3,  9, 6, 44, 
    4, 95, 2, 40, 3,  8, 0, 89, 5, 10, 7, 27, 8, 87, 6, 45, 1, 56, 
    2, 23, 4, 85, 3, 89, 1, 39, 5,  2, 7, 21, 6, 40, 0, 53, 8, 29, 
    7, 14, 5, 69, 1, 18, 4, 51, 3, 41, 6, 86, 2, 91, 0, 95, 8, 91, 
    1, 67, 4, 26, 5, 51, 0, 81, 2, 92, 7, 13, 3, 48, 8, 91, 6, 34
  };
  const int q4681[] = {
    9, 9, // Number of jobs and machines
    7, 37, 8, 89, 4, 41, 0, 76, 3, 32, 5, 56, 6, 37, 1, 64, 2, 83, 
    1, 87, 6, 20, 0, 88, 3, 98, 8, 96, 2, 89, 5, 23, 4, 41, 7, 69, 
    6, 29, 4, 82, 7, 20, 3, 97, 5, 30, 0, 40, 1, 63, 8, 74, 2, 37, 
    1, 40, 6, 51, 4, 40, 0, 99, 3, 42, 7, 34, 2, 43, 8, 33, 5, 20, 
    5, 81, 0, 19, 2, 83, 1,  2, 8,  1, 6, 58, 3, 44, 7, 36, 4, 32, 
    5, 42, 1, 89, 3, 80, 2, 38, 7, 79, 4, 61, 6, 48, 0, 55, 8, 13, 
    6, 96, 0, 40, 2, 49, 7, 36, 4, 86, 5, 11, 1, 40, 3, 73, 8,  5, 
    3, 15, 0, 73, 5, 33, 1, 84, 2, 86, 6, 68, 8, 42, 4, 76, 7, 31, 
    0, 84, 3, 84, 1, 75, 6, 31, 4, 55, 2,  2, 8, 59, 5, 86, 7, 66
  };
  const int q4682[] = {
    9, 9, // Number of jobs and machines
    6, 67, 8, 18, 1, 17, 0, 70, 4, 10, 3, 91, 5, 36, 7, 11, 2, 57, 
    2, 41, 5, 95, 4, 74, 6, 42, 0, 97, 1, 96, 3, 43, 8, 80, 7, 12, 
    8, 56, 4, 44, 2,  4, 5, 93, 7, 24, 6, 97, 1, 29, 3, 18, 0, 89, 
    1, 65, 6, 64, 3,  7, 4, 86, 7, 62, 8,  7, 2, 71, 0, 85, 5,  1, 
    3, 50, 2, 73, 6, 37, 0, 68, 4, 99, 5, 80, 8,  3, 7, 89, 1, 92, 
    3, 70, 1, 33, 5, 97, 8, 32, 4, 25, 0, 28, 2, 74, 7, 22, 6, 64, 
    6, 37, 5,  9, 0, 62, 1, 23, 8, 33, 4, 94, 3, 56, 7, 94, 2, 72, 
    0, 47, 1,  1, 8,  5, 3, 16, 5, 74, 2, 81, 6, 73, 7,  8, 4, 42, 
    2, 90, 1, 71, 3, 57, 4, 11, 7, 22, 8, 28, 5,  6, 6, 10, 0, 42
  };
  const int q4683[] = {
    9, 9, // Number of jobs and machines
    3, 56, 2, 66, 4, 14, 1, 75, 5, 48, 6, 96, 0, 23, 8, 27, 7,  9, 
    1, 94, 0, 85, 7, 34, 5, 79, 4, 45, 3,  9, 8, 27, 6, 51, 2, 18, 
    4, 75, 1,  3, 5, 73, 8, 23, 6, 72, 7, 35, 2, 61, 3, 46, 0, 73, 
    2, 47, 0, 34, 8, 36, 4, 76, 7, 66, 5, 76, 3, 85, 6, 51, 1,  5, 
    3, 88, 8, 60, 5, 19, 6, 71, 1, 72, 0, 46, 4,  5, 7, 63, 2, 30, 
    4, 26, 2, 15, 8, 36, 3, 71, 7, 98, 5, 15, 1, 81, 6, 74, 0, 30, 
    3, 62, 8, 43, 2, 45, 1, 92, 0, 14, 4, 12, 7, 93, 6, 23, 5, 68, 
    7, 34, 3,  5, 1, 50, 6, 86, 5,  9, 4,  1, 2,  8, 8, 21, 0, 20, 
    0, 32, 7, 97, 3, 23, 1, 38, 8, 94, 2, 36, 4, 43, 5,  4, 6, 76
  };
  const int q4684[] = {
    9, 9, // Number of jobs and machines
    6, 52, 8,  1, 5, 75, 0, 95, 4, 47, 2, 90, 3, 27, 1, 44, 7, 35, 
    2,  6, 7,  8, 8, 85, 4, 73, 0, 13, 3,  9, 5, 55, 6,  5, 1, 50, 
    6, 40, 1, 78, 7, 51, 5, 34, 4, 76, 3, 36, 8, 55, 2, 56, 0, 54, 
    6, 49, 4, 40, 3, 32, 5, 67, 7, 82, 1, 12, 0, 94, 2, 54, 8, 50, 
    3, 72, 6, 47, 2, 14, 5, 33, 4, 79, 0, 44, 1, 46, 8, 36, 7, 86, 
    7, 93, 8, 27, 3, 17, 1, 62, 4, 72, 6, 41, 5, 92, 2, 66, 0, 70, 
    7, 94, 6, 16, 5, 44, 1, 26, 8, 39, 3, 51, 2, 89, 0, 10, 4, 15, 
    3, 88, 6, 84, 2, 55, 7, 16, 4, 93, 5, 75, 8, 61, 1, 62, 0, 77, 
    0, 99, 7, 71, 4,  6, 3, 86, 2, 69, 1, 52, 5, 55, 6, 40, 8, 64
  };
  const int q4685[] = {
    9, 9, // Number of jobs and machines
    5, 70, 0, 81, 6, 55, 2, 70, 8, 81, 7, 50, 4, 66, 3, 91, 1, 47, 
    6, 72, 5, 34, 0, 25, 7, 96, 1, 69, 4, 49, 2, 45, 8, 24, 3,  5, 
    3, 35, 7, 57, 4, 20, 1, 59, 5, 12, 2, 55, 0, 83, 6, 19, 8,  4, 
    1, 81, 0, 97, 6, 30, 7, 33, 3, 45, 2, 62, 4, 30, 8, 58, 5, 70, 
    8, 81, 5, 91, 3, 52, 6, 21, 0, 34, 7, 32, 1, 39, 4, 96, 2, 54, 
    1, 51, 7, 65, 6, 81, 3, 34, 0, 76, 2, 10, 4, 58, 8, 40, 5, 92, 
    2, 59, 8, 29, 1, 10, 6,  5, 7, 47, 4, 93, 0, 29, 5, 93, 3, 25, 
    7, 67, 1, 23, 4, 90, 2, 32, 6, 98, 0, 80, 8, 13, 5, 35, 3, 24, 
    6, 70, 8, 70, 4, 35, 1, 35, 7, 91, 2,  8, 0, 80, 5, 69, 3, 78
  };
  const int q4686[] = {
    9, 9, // Number of jobs and machines
    5, 34, 3, 85, 0, 58, 4, 85, 1, 44, 6, 42, 7, 27, 2, 37, 8, 47, 
    8, 41, 4, 19, 5, 72, 1, 11, 7, 78, 6, 65, 0, 29, 2, 93, 3, 20, 
    8, 19, 4, 79, 6, 76, 5, 46, 0, 62, 1,  8, 2, 85, 7, 49, 3, 67, 
    0, 85, 4, 56, 1, 53, 3, 63, 8, 47, 6, 37, 5, 70, 2, 75, 7, 59, 
    3, 59, 1, 46, 8,  7, 6, 62, 7, 93, 0, 53, 2, 37, 4, 81, 5, 62, 
    3, 26, 5, 73, 7,  1, 6, 21, 4, 72, 0, 58, 1, 70, 2, 44, 8, 45, 
    4, 36, 2, 80, 3, 85, 7, 21, 1, 26, 8,  6, 0, 91, 6, 62, 5, 96, 
    5, 23, 1, 54, 0, 79, 2, 33, 4, 69, 3,  6, 6,  1, 7, 85, 8, 79, 
    0, 92, 6, 51, 3, 68, 1, 24, 7,  2, 4, 95, 5,  8, 8, 17, 2, 63
  };
  const int q4687[] = {
    9, 9, // Number of jobs and machines
    5, 43, 7, 11, 2, 70, 6, 37, 8, 70, 0, 62, 4, 71, 1, 31, 3, 70, 
    3, 75, 4, 20, 0, 12, 5, 98, 1, 53, 8, 44, 7, 16, 6, 90, 2, 10, 
    8, 30, 1, 20, 4, 57, 0, 91, 6, 95, 3, 47, 5, 72, 7,  9, 2, 94, 
    5, 44, 1, 86, 4, 11, 2, 90, 3, 12, 6, 81, 7, 38, 0, 22, 8, 40, 
    1, 70, 6,  3, 4, 77, 3, 44, 0, 92, 8, 53, 5, 55, 7, 98, 2, 10, 
    7, 31, 2,  7, 8, 62, 4, 16, 6, 22, 3, 70, 1, 89, 5,  8, 0, 71, 
    7, 10, 6,  4, 8, 86, 5, 52, 2, 34, 4, 82, 0, 92, 1, 54, 3,  5, 
    1, 63, 5, 32, 4, 43, 2, 20, 8, 54, 7, 11, 3, 93, 0, 58, 6, 36, 
    5, 31, 2,  7, 3, 58, 0, 68, 6, 65, 8, 20, 4, 89, 7,  8, 1,  2
  };
  const int q4688[] = {
    9, 9, // Number of jobs and machines
    4, 54, 6, 92, 1, 60, 8, 94, 5, 81, 0,  3, 2, 72, 3, 50, 7, 17, 
    4, 67, 5, 49, 3, 15, 8, 91, 6, 14, 2, 55, 0, 90, 7,  1, 1, 21, 
    4, 95, 3, 87, 0, 73, 1,  2, 6, 30, 8, 50, 7, 47, 5,  3, 2, 14, 
    7, 45, 8, 88, 3, 67, 2, 25, 5, 65, 6, 26, 1, 55, 4, 57, 0, 21, 
    1, 70, 4, 21, 0, 20, 5, 46, 8, 24, 2, 23, 6, 29, 3,  6, 7, 87, 
    3, 65, 2, 65, 5, 36, 6, 76, 1, 85, 7, 27, 8, 13, 0, 34, 4, 57, 
    2, 39, 4, 68, 3, 21, 7, 27, 8, 92, 5, 89, 6, 85, 0, 87, 1, 48, 
    2, 90, 5, 50, 6, 13, 4, 38, 8, 55, 0, 36, 3, 91, 7, 94, 1, 66, 
    4, 68, 1, 10, 3, 43, 0, 75, 5, 59, 7, 77, 8,  5, 2, 66, 6, 23
  };
  const int q4689[] = {
    9, 9, // Number of jobs and machines
    0, 57, 3, 92, 1, 95, 7, 58, 6, 47, 2, 15, 5, 43, 4,  7, 8, 16, 
    7, 26, 1, 67, 2, 91, 6, 97, 4, 68, 3, 42, 5, 31, 8, 72, 0, 19, 
    2, 62, 0, 33, 3, 33, 1, 59, 4, 80, 6, 32, 5, 13, 8, 49, 7, 81, 
    2, 26, 8, 50, 1, 14, 6, 36, 5, 45, 0, 15, 7, 37, 3, 94, 4, 65, 
    6, 90, 2, 10, 4, 34, 8,  5, 0, 38, 5, 99, 7,  9, 3, 46, 1, 73, 
    0, 29, 3, 42, 8, 29, 5, 62, 1, 26, 2,  5, 4, 96, 6, 43, 7, 51, 
    8, 71, 0, 95, 6, 61, 2, 30, 4, 64, 3, 48, 7, 14, 5, 70, 1, 64, 
    8,  8, 7, 83, 5, 44, 2, 76, 3, 41, 4, 61, 0, 75, 6, 97, 1, 69, 
    7, 34, 1, 59, 5, 33, 0, 35, 2,  7, 8, 84, 3, 69, 6, 84, 4, 30
  };
  const int q4690[] = {
    9, 9, // Number of jobs and machines
    2, 81, 0,  4, 8, 43, 3, 84, 1, 31, 4, 56, 6, 90, 7, 66, 5, 51, 
    8,  7, 5, 39, 1, 86, 4, 58, 3, 64, 6, 41, 7, 48, 0, 33, 2,  9, 
    2, 14, 1, 47, 8, 50, 7, 39, 5, 43, 3, 97, 4, 39, 0, 64, 6, 62, 
    7, 45, 6, 90, 5, 17, 3, 92, 1, 94, 8, 27, 0, 35, 2, 38, 4, 22, 
    5, 45, 2, 48, 4, 47, 7, 15, 3, 13, 6, 84, 8, 12, 1, 64, 0, 64, 
    6, 46, 4, 26, 7,  1, 3, 75, 1, 19, 8, 44, 2, 70, 5, 25, 0, 17, 
    7, 78, 1, 29, 5, 37, 3, 96, 4, 32, 0, 23, 8, 43, 2, 81, 6, 90, 
    0,  1, 3, 89, 6, 32, 2, 86, 1, 64, 7, 96, 5, 82, 8, 42, 4, 22, 
    7, 14, 8, 92, 6, 13, 2, 50, 0, 10, 5, 70, 1, 75, 3, 47, 4, 90
  };
  const int q4691[] = {
    9, 9, // Number of jobs and machines
    3, 40, 5, 26, 0, 60, 2, 81, 1, 48, 8, 41, 6, 68, 7, 72, 4, 21, 
    7, 81, 1, 94, 3,  2, 0,  1, 8, 77, 2, 69, 6, 58, 5, 69, 4,  1, 
    3, 60, 4, 34, 5, 97, 6, 94, 1, 18, 2, 15, 8, 32, 7, 72, 0, 97, 
    4, 27, 5, 74, 8, 62, 0, 65, 2, 17, 3, 40, 6, 76, 7, 30, 1, 48, 
    4, 57, 6, 80, 2, 49, 1, 56, 5, 53, 0, 19, 8, 35, 7, 83, 3, 79, 
    6, 44, 5, 66, 0, 68, 3, 78, 7, 61, 1, 98, 2, 24, 8, 79, 4, 27, 
    1, 98, 6,  2, 7, 26, 0, 41, 8, 67, 2,  5, 5, 97, 4, 29, 3, 72, 
    3, 32, 7, 60, 0, 43, 2, 88, 4, 65, 6, 51, 1, 24, 8, 20, 5, 34, 
    3, 94, 8, 88, 6, 30, 1, 30, 2, 68, 4, 45, 0, 57, 7, 79, 5, 80
  };
  const int q4692[] = {
    9, 9, // Number of jobs and machines
    7, 57, 3, 94, 1, 36, 5, 76, 2, 61, 0, 98, 6, 65, 4, 20, 8, 57, 
    8, 36, 1, 80, 4,  3, 2, 99, 3, 32, 0, 63, 5, 61, 7, 76, 6, 47, 
    2, 61, 7, 39, 5, 96, 1,  1, 0, 33, 3, 18, 4,  5, 6, 97, 8, 10, 
    5, 55, 6, 41, 1, 90, 3, 99, 0, 59, 2, 75, 7, 94, 4, 47, 8, 38, 
    8, 63, 6, 52, 0, 92, 2, 75, 4, 70, 7, 58, 1, 51, 5, 61, 3, 77, 
    7, 66, 2, 73, 6, 15, 5, 19, 0, 72, 4, 99, 8, 87, 1, 35, 3, 24, 
    6, 96, 5, 52, 2, 58, 7, 58, 4, 70, 3, 60, 1, 47, 8,  9, 0, 63, 
    7, 96, 0, 64, 8, 91, 3, 63, 2, 17, 4, 86, 6, 71, 1, 27, 5, 30, 
    7, 55, 2, 31, 4, 45, 3, 45, 6, 22, 0, 93, 8, 57, 1, 81, 5, 93
  };
  const int q4693[] = {
    9, 9, // Number of jobs and machines
    3, 23, 1, 25, 4, 81, 7, 80, 0, 80, 2, 46, 6,  6, 8, 47, 5, 53, 
    0, 72, 8, 25, 5, 58, 3, 70, 6, 65, 4, 66, 7, 64, 1, 24, 2, 42, 
    8, 11, 7,  2, 2, 33, 5, 73, 0, 95, 3, 21, 4, 69, 1, 35, 6, 28, 
    1, 33, 7, 34, 6, 48, 3, 87, 0, 35, 5, 17, 8, 50, 4, 25, 2, 94, 
    8, 91, 0, 50, 2, 87, 4, 14, 3, 15, 6,  9, 1, 39, 7, 24, 5,  7, 
    8, 71, 2, 20, 6, 18, 3, 57, 4, 10, 0, 99, 1, 79, 7, 30, 5, 36, 
    6, 92, 1, 77, 3, 91, 4, 10, 7, 63, 0, 75, 5, 12, 2, 50, 8,  1, 
    8, 32, 5, 70, 0, 30, 1, 36, 7, 33, 4, 94, 3, 23, 2, 75, 6, 82, 
    6,  4, 2, 63, 0, 50, 8, 12, 4, 13, 5, 40, 1, 26, 3, 29, 7, 74
  };
  const int q4694[] = {
    9, 9, // Number of jobs and machines
    2, 25, 4,  7, 3, 97, 0, 95, 7, 55, 5,  9, 6, 55, 1, 35, 8, 95, 
    4, 47, 6, 72, 7, 14, 1, 79, 2, 66, 3, 88, 8, 64, 0, 19, 5, 64, 
    5, 19, 2, 70, 0, 78, 8, 28, 4,  3, 1, 93, 7, 75, 6, 77, 3, 42, 
    4, 60, 5, 40, 8, 99, 7, 44, 3, 44, 2, 64, 0,  5, 6, 13, 1,  7, 
    8, 87, 4, 26, 7, 30, 1, 79, 3, 33, 5, 59, 2, 62, 6, 46, 0, 82, 
    0, 22, 6, 33, 3, 75, 5, 92, 8, 88, 1, 56, 7, 28, 2, 66, 4, 88, 
    7, 57, 4, 20, 3, 75, 1, 30, 6, 71, 2, 57, 5,  8, 0, 54, 8, 35, 
    6, 88, 4, 51, 2, 86, 0, 35, 3, 37, 1, 49, 5, 90, 7, 94, 8, 74, 
    6, 57, 1, 10, 5, 65, 2, 99, 7, 59, 3, 64, 8, 76, 0,  7, 4,  4
  };
  const int q4695[] = {
    9, 9, // Number of jobs and machines
    4, 70, 2, 53, 7, 53, 8, 21, 3, 77, 6, 11, 5, 75, 0, 57, 1, 76, 
    0, 88, 1, 58, 7,  8, 2, 30, 6, 82, 3, 52, 8, 31, 4, 77, 5, 72, 
    5, 92, 2, 91, 6, 59, 4, 59, 3, 44, 1, 11, 8,  5, 0, 88, 7, 43, 
    0, 77, 1, 64, 2, 65, 8, 58, 7, 74, 3,  2, 6, 67, 4, 99, 5, 60, 
    8, 22, 7, 64, 2, 32, 3, 23, 1, 82, 6, 27, 4, 47, 0, 28, 5, 23, 
    1, 79, 0, 68, 8, 52, 6, 60, 5, 24, 2, 92, 4,  3, 7, 61, 3, 95, 
    3, 63, 8, 96, 0, 45, 2, 38, 7, 63, 6, 64, 5, 10, 1, 93, 4, 36, 
    3, 78, 8, 96, 4, 66, 6,  1, 7, 66, 5, 17, 0, 83, 2, 15, 1, 93, 
    0, 30, 8, 90, 7, 19, 5, 24, 2, 21, 1, 85, 6, 28, 3, 29, 4,  7
  };
  const int q4696[] = {
    9, 9, // Number of jobs and machines
    5, 61, 1, 27, 4, 70, 8, 79, 2, 25, 0,  3, 7, 64, 3, 88, 6, 55, 
    6, 34, 4, 88, 7, 16, 0, 75, 2, 59, 8, 22, 1, 16, 3, 47, 5, 71, 
    3, 24, 8, 25, 2, 68, 7, 91, 6, 65, 0, 45, 5, 26, 4, 62, 1, 71, 
    6, 45, 5, 25, 4, 87, 1, 71, 7, 21, 2,  8, 3, 36, 8,  5, 0, 64, 
    8,  8, 2, 14, 7, 30, 4, 49, 0,  6, 5, 93, 3, 58, 6, 37, 1,  9, 
    4, 51, 2, 25, 8, 74, 0, 71, 1, 97, 7, 98, 3, 10, 5, 86, 6, 63, 
    7, 52, 6, 88, 4, 68, 3, 40, 1, 18, 5, 23, 2, 13, 8, 96, 0, 25, 
    7,  9, 2, 66, 1,  8, 0, 85, 6, 68, 5, 30, 8, 31, 3, 81, 4, 74, 
    8, 80, 6, 94, 0, 50, 4, 22, 7, 48, 2, 45, 1, 19, 5, 72, 3, 33
  };
  const int q4697[] = {
    9, 9, // Number of jobs and machines
    7, 67, 6, 20, 0, 32, 4, 44, 2, 34, 8,  3, 5, 46, 1, 61, 3, 82, 
    1, 98, 5, 26, 6, 73, 4, 17, 7, 22, 8, 26, 2, 65, 3, 24, 0, 49, 
    2, 58, 3, 83, 0, 18, 8, 49, 7, 68, 5, 52, 6, 27, 4, 90, 1, 33, 
    4, 54, 1, 46, 5, 16, 0, 64, 2, 18, 8,  2, 6, 89, 7, 13, 3, 17, 
    5, 38, 7, 57, 4, 98, 2, 31, 0, 63, 6, 79, 1, 90, 8, 15, 3, 58, 
    4, 13, 0, 13, 3,  6, 1, 81, 5, 92, 8,  6, 6, 18, 2, 84, 7, 97, 
    2, 70, 0, 25, 1, 66, 8, 22, 6, 58, 4, 24, 7, 68, 5, 50, 3, 24, 
    2, 29, 7, 63, 3, 24, 8, 20, 6, 78, 4, 52, 0,  8, 5,  9, 1, 10, 
    3, 24, 4,  2, 8, 84, 6, 13, 2, 53, 1, 38, 5, 23, 7, 69, 0, 23
  };
  const int q4698[] = {
    9, 9, // Number of jobs and machines
    3, 37, 8, 31, 2, 73, 5, 94, 6, 10, 7, 65, 1, 46, 4, 34, 0, 35, 
    6, 92, 4, 67, 2, 92, 7, 61, 3, 11, 1, 56, 8, 74, 5, 95, 0, 47, 
    5, 25, 8, 42, 2, 92, 6, 54, 1, 34, 0, 33, 3, 53, 7, 63, 4, 82, 
    5, 82, 0,  6, 6, 36, 2, 75, 3, 39, 7, 95, 1, 48, 4, 88, 8, 94, 
    3, 72, 7, 34, 6, 42, 0, 30, 1,  3, 2, 60, 5, 45, 4, 15, 8, 32, 
    0, 53, 6, 28, 8, 42, 1, 38, 3, 21, 4, 69, 7, 44, 5, 27, 2, 50, 
    3, 61, 7, 73, 1, 40, 6, 45, 0, 30, 2, 93, 5, 39, 8, 40, 4, 95, 
    3,  8, 0, 27, 6, 95, 2,  4, 1, 93, 8, 60, 4, 19, 7, 23, 5, 91, 
    6, 68, 0, 39, 4, 40, 2, 12, 3, 96, 5, 53, 1, 56, 8,  5, 7, 50
  };
  const int q4699[] = {
    9, 9, // Number of jobs and machines
    6, 90, 4, 31, 2, 89, 3, 52, 5, 32, 7, 28, 0, 95, 8, 82, 1, 26, 
    5, 59, 8, 63, 3, 29, 4, 24, 0, 37, 1, 75, 7, 72, 6, 89, 2, 84, 
    6, 17, 8, 13, 3, 31, 4, 83, 7, 86, 5, 53, 0, 81, 1, 46, 2, 32, 
    4, 49, 1, 90, 5, 60, 3, 47, 8,  8, 0, 45, 7,  2, 6, 39, 2, 41, 
    1, 87, 5, 78, 4, 20, 7, 30, 6, 14, 2, 41, 8, 34, 3, 46, 0, 14, 
    2,  9, 3, 29, 1,  3, 6, 55, 4, 38, 5, 35, 8,  8, 0, 11, 7, 61, 
    5, 19, 4, 35, 7,  3, 0,  5, 2, 89, 6, 42, 1,  1, 3, 71, 8, 36, 
    4, 66, 1, 82, 2, 41, 6, 16, 5, 61, 8, 54, 0, 67, 3, 85, 7, 38, 
    4, 42, 0, 96, 6, 56, 5, 32, 2, 42, 8, 51, 7, 23, 1,  1, 3, 94
  };
  const int q4700[] = {
    9, 9, // Number of jobs and machines
    8, 99, 0, 72, 7, 51, 1, 26, 6, 54, 4, 99, 5, 18, 2, 24, 3, 85, 
    1, 94, 4, 85, 2, 95, 8, 61, 3, 56, 0, 52, 6,  7, 5, 94, 7,  3, 
    1, 80, 5, 41, 3, 20, 7, 88, 4, 29, 8, 29, 0, 25, 2, 39, 6, 58, 
    8, 86, 0, 99, 1, 69, 7, 83, 6,  4, 4, 74, 5, 45, 3, 66, 2, 22, 
    2, 74, 5, 16, 7, 92, 6, 48, 3, 72, 8,  8, 0, 93, 4, 99, 1, 56, 
    1, 11, 0, 65, 2, 49, 7, 96, 5, 11, 8, 81, 3, 34, 4, 23, 6, 95, 
    3, 71, 6, 32, 4, 45, 0, 93, 1, 70, 7, 75, 2, 28, 5,  8, 8, 30, 
    0, 66, 7, 65, 2, 94, 8, 19, 4, 40, 3, 60, 1,  7, 6, 22, 5, 82, 
    7, 45, 1, 93, 2, 74, 4, 77, 5, 81, 3, 29, 8, 65, 6, 49, 0, 18
  };
  const int q4701[] = {
    9, 9, // Number of jobs and machines
    0, 67, 4, 60, 7, 82, 5, 83, 1, 50, 8,  1, 2, 24, 6, 28, 3, 98, 
    4, 83, 0, 30, 7, 89, 6, 36, 5, 79, 8, 27, 1, 20, 3, 54, 2, 57, 
    5, 64, 0, 71, 1, 42, 2, 96, 7, 27, 4,  2, 8, 68, 3, 59, 6, 40, 
    8, 97, 4, 10, 7, 87, 0, 50, 5, 40, 2, 66, 3, 90, 6,  9, 1, 42, 
    3, 34, 5, 61, 7, 20, 2, 92, 4, 52, 0,  2, 6, 65, 8, 86, 1, 13, 
    7, 86, 3, 53, 1, 93, 6, 24, 2, 41, 5, 68, 0, 35, 4, 37, 8, 17, 
    7, 45, 3, 88, 6, 98, 5, 77, 2, 76, 0, 41, 4, 65, 8, 65, 1, 54, 
    1, 83, 2,  1, 4, 45, 5, 87, 0, 94, 7, 32, 8, 68, 3, 55, 6, 39, 
    6, 92, 1, 90, 7, 20, 0, 46, 4, 46, 8, 57, 5, 67, 3, 18, 2, 80
  };
  const int q4702[] = {
    9, 9, // Number of jobs and machines
    7, 51, 1, 79, 5, 33, 6, 28, 4,  4, 2, 85, 3, 13, 0,  6, 8, 15, 
    8, 31, 5, 76, 0, 11, 4, 36, 1, 24, 6, 99, 7, 36, 3, 33, 2, 12, 
    5, 75, 7, 89, 1, 85, 3, 80, 6, 65, 4, 79, 8, 28, 0, 33, 2, 96, 
    3, 81, 2, 75, 0, 76, 5, 86, 1, 76, 4, 18, 6,  3, 7, 37, 8, 62, 
    6, 76, 3,  3, 2, 86, 4, 66, 1,  1, 7, 55, 0, 72, 8, 75, 5, 49, 
    2, 84, 5, 59, 4, 98, 3, 15, 8, 82, 7, 89, 6, 21, 1, 35, 0, 43, 
    3, 26, 7,  4, 6, 25, 4, 34, 2, 46, 8, 29, 1,  2, 0, 87, 5, 55, 
    6, 19, 0, 66, 5, 95, 3, 22, 8, 75, 7, 86, 4, 60, 2, 13, 1,  6, 
    2, 69, 1,  1, 5, 78, 7, 31, 6, 66, 3, 23, 4, 38, 0, 33, 8, 91
  };
  const int q4703[] = {
    9, 9, // Number of jobs and machines
    0, 66, 4, 15, 5, 52, 2, 64, 6, 77, 1, 91, 3, 30, 7,  2, 8, 59, 
    2, 17, 6, 11, 0, 41, 4, 56, 5, 24, 1, 49, 7, 58, 3, 91, 8,  9, 
    0, 98, 5, 61, 1,  1, 3, 58, 4, 65, 7, 49, 6, 40, 8, 56, 2, 88, 
    1, 15, 7, 99, 6, 53, 4, 95, 0, 62, 5, 53, 8, 89, 2, 54, 3,  1, 
    1, 51, 5, 84, 3,  1, 8, 60, 7,  6, 2, 50, 6, 54, 0, 54, 4, 97, 
    0, 37, 5, 98, 6, 49, 7, 23, 3, 30, 1, 38, 8, 63, 2,  6, 4, 67, 
    6, 91, 3,  1, 8, 24, 0, 55, 2, 98, 1, 32, 4, 26, 7, 38, 5, 93, 
    2,  3, 3, 97, 6, 34, 7, 37, 4,  5, 1, 25, 0,  3, 8, 53, 5, 45, 
    8, 82, 0, 19, 2, 72, 5, 97, 7, 31, 4, 86, 3, 60, 1, 45, 6, 66
  };
  const int q4704[] = {
    9, 9, // Number of jobs and machines
    7, 78, 5, 11, 2, 79, 8, 31, 3,  2, 1, 44, 4, 49, 6, 37, 0, 53, 
    3, 68, 0, 60, 4, 14, 2, 85, 6, 93, 7, 10, 1, 19, 5, 18, 8, 56, 
    6, 28, 3, 22, 7, 31, 8, 24, 5, 64, 1, 44, 4, 58, 2, 13, 0, 85, 
    0, 72, 2, 97, 6, 97, 7, 12, 8,  7, 4, 41, 3, 76, 5, 81, 1,  9, 
    4, 52, 0, 25, 2, 17, 7, 78, 8, 31, 6, 36, 3, 94, 1, 94, 5, 80, 
    2, 86, 6, 57, 8, 13, 3, 85, 7, 40, 1, 24, 0,  6, 4, 89, 5, 52, 
    7, 92, 2, 85, 1, 68, 5, 71, 4, 63, 3, 92, 8, 24, 0, 55, 6, 12, 
    7, 16, 5, 85, 3, 60, 4, 24, 0,  4, 6, 65, 2, 33, 8, 87, 1, 38, 
    7, 25, 0, 73, 1, 10, 5,  8, 3, 55, 6, 42, 4, 93, 8, 50, 2, 12
  };
  const int q4705[] = {
    9, 9, // Number of jobs and machines
    5, 46, 8, 17, 2,  1, 4, 23, 7, 52, 1, 25, 3, 45, 0, 53, 6, 72, 
    6, 56, 7, 24, 2, 30, 4, 31, 5, 59, 8, 45, 0, 65, 3, 66, 1, 49, 
    8, 73, 6, 10, 2,  5, 0, 65, 4, 55, 3, 36, 5, 28, 1, 32, 7, 67, 
    0, 25, 5, 93, 8,  9, 4, 27, 7, 86, 2, 95, 1, 46, 6, 48, 3, 72, 
    5, 67, 1, 26, 3, 13, 8, 31, 7, 35, 6, 20, 2, 36, 0, 99, 4, 30, 
    4,  6, 8, 15, 5, 27, 1, 28, 3, 28, 2, 46, 7, 17, 6, 83, 0, 68, 
    1, 42, 0, 81, 7, 26, 6, 38, 5, 88, 8, 48, 4, 43, 2, 35, 3, 10, 
    8, 46, 6, 92, 1, 98, 0, 42, 4, 56, 5, 53, 2, 71, 7, 34, 3, 61, 
    3, 82, 7, 60, 4, 59, 6, 56, 8, 41, 0, 41, 2,  6, 5, 71, 1, 58
  };
  const int q4706[] = {
    9, 9, // Number of jobs and machines
    8, 56, 0, 51, 6, 74, 7, 86, 2, 21, 3, 98, 1, 60, 5, 56, 4, 89, 
    5, 22, 3, 65, 8, 75, 0, 65, 2, 37, 6, 74, 7,  4, 1, 60, 4, 36, 
    4, 48, 7, 58, 2, 45, 5, 47, 3, 81, 6,  5, 1, 83, 8, 25, 0,  7, 
    6, 10, 0, 36, 1, 52, 3, 43, 5, 61, 8, 58, 7, 12, 4, 60, 2, 91, 
    0, 84, 5, 97, 6, 74, 7, 70, 2, 44, 1, 92, 3, 17, 4, 21, 8, 33, 
    4,  5, 8, 27, 0, 57, 2, 93, 5, 10, 7, 19, 1, 60, 3, 72, 6, 80, 
    7, 68, 4, 76, 2, 33, 3,  1, 1, 34, 6, 54, 8, 95, 5,  1, 0, 42, 
    7, 60, 4, 63, 5, 50, 0, 39, 8,  3, 3,  1, 2, 45, 6, 30, 1, 13, 
    7, 93, 3, 56, 4, 46, 2, 32, 5, 38, 1, 44, 0, 78, 6, 56, 8, 18
  };
  const int q4707[] = {
    9, 9, // Number of jobs and machines
    5, 77, 6,  9, 7, 49, 8,  6, 0, 29, 2, 60, 4, 13, 1, 71, 3, 99, 
    1, 35, 7, 36, 6, 13, 4, 37, 0, 42, 3, 15, 8, 55, 2, 33, 5,  6, 
    2,  5, 0, 68, 3, 82, 4, 97, 7, 69, 8, 84, 5,  3, 1, 45, 6, 74, 
    5, 77, 4, 58, 1, 83, 3, 54, 0, 33, 8, 53, 7,  8, 6, 86, 2, 44, 
    3, 96, 6, 16, 5, 51, 1, 17, 4, 21, 7, 91, 8, 35, 0, 37, 2, 63, 
    4, 37, 6, 84, 5,  7, 1, 34, 7, 38, 8, 31, 0, 24, 2, 98, 3, 40, 
    2, 79, 5, 28, 3, 45, 6, 92, 1, 25, 4, 64, 7,  3, 0, 66, 8, 65, 
    6, 21, 5, 83, 7, 44, 8, 27, 1, 13, 4, 30, 0, 28, 2, 23, 3, 48, 
    4, 19, 8, 80, 3, 54, 1, 49, 6, 23, 0, 27, 7, 46, 2, 96, 5, 32
  };
  const int q4708[] = {
    9, 9, // Number of jobs and machines
    4, 15, 0,  5, 3, 62, 5, 46, 6, 27, 7, 56, 8, 74, 2, 88, 1, 35, 
    6, 22, 8,  3, 3, 11, 7, 43, 1,  6, 4, 39, 2, 53, 5, 72, 0, 26, 
    7, 78, 8, 10, 1, 48, 0, 73, 2, 59, 6, 17, 4, 60, 5, 43, 3, 23, 
    5, 67, 1, 70, 3, 27, 0, 95, 2, 76, 7, 86, 6, 99, 4, 81, 8, 28, 
    0, 40, 1, 15, 7, 69, 3,  9, 4,  9, 2, 30, 5, 55, 6, 53, 8, 86, 
    0, 72, 8, 52, 4, 55, 3, 48, 1, 38, 6,  9, 2, 18, 7, 58, 5, 86, 
    3, 78, 4, 58, 7, 21, 8, 89, 0, 81, 5, 33, 1, 43, 2, 11, 6,  2, 
    1, 12, 6, 83, 2, 42, 8, 74, 4, 50, 7, 84, 5, 88, 0, 76, 3, 43, 
    3, 85, 5, 59, 2, 53, 7, 32, 4, 45, 6, 13, 1, 83, 0, 47, 8, 42
  };
  const int q4709[] = {
    9, 9, // Number of jobs and machines
    1, 72, 2, 85, 8, 64, 6, 44, 0, 16, 5, 63, 7, 49, 3, 62, 4, 87, 
    1, 52, 0, 58, 2, 52, 6, 74, 8, 63, 5, 58, 3, 25, 4, 86, 7, 74, 
    7, 29, 6,  1, 3, 26, 5, 86, 4, 32, 0, 98, 2, 51, 1, 51, 8, 51, 
    3, 69, 1, 68, 8, 25, 2,  1, 7, 60, 0, 98, 6, 12, 4, 22, 5, 73, 
    8,  3, 4, 88, 7, 24, 0, 62, 6, 24, 5, 75, 3, 31, 1, 12, 2,  3, 
    8, 99, 7, 20, 2, 41, 0, 10, 1, 36, 4, 78, 3,  7, 6,  7, 5, 27, 
    5, 33, 1, 43, 8, 84, 3, 24, 0, 16, 7, 71, 4, 93, 2, 30, 6, 60, 
    0, 83, 6, 50, 5, 30, 4, 37, 1, 11, 3, 43, 2, 23, 7, 75, 8, 86, 
    1, 33, 8, 47, 3, 97, 2, 47, 7, 47, 4, 29, 0, 68, 6, 91, 5, 25
  };
  const int q4710[] = {
    9, 9, // Number of jobs and machines
    5, 71, 7, 66, 1, 24, 4, 17, 6, 53, 0, 90, 8, 50, 3,  2, 2, 37, 
    8, 98, 6, 54, 0, 29, 7, 88, 3, 36, 1, 91, 4, 20, 5,  8, 2, 46, 
    4, 16, 6, 63, 5, 19, 2,  7, 0, 46, 3, 18, 7, 50, 8, 34, 1, 31, 
    6, 14, 4, 92, 3, 98, 8, 40, 5, 90, 7, 57, 0, 64, 2, 75, 1, 64, 
    7,  2, 4, 21, 6,  1, 3, 72, 1, 77, 0, 49, 8, 43, 5, 59, 2, 87, 
    0, 24, 5, 72, 2, 55, 4, 67, 7, 74, 6, 43, 3, 95, 1, 30, 8, 84, 
    3, 59, 6, 31, 5, 85, 8, 26, 7, 76, 2, 39, 1, 86, 4, 17, 0,  9, 
    7, 87, 2, 46, 8, 16, 1, 21, 5, 92, 4, 51, 0, 42, 6, 59, 3, 96, 
    5, 41, 0, 14, 2, 91, 1, 43, 7, 82, 6, 90, 8, 81, 4, 15, 3, 80
  };
  const int q4711[] = {
    9, 9, // Number of jobs and machines
    2, 30, 5,  1, 3, 10, 7, 50, 8, 50, 0, 56, 6,  7, 1, 59, 4, 13, 
    4, 64, 2, 96, 1, 60, 0, 38, 5, 18, 3, 72, 6, 21, 8, 99, 7, 43, 
    0,  8, 5, 33, 3, 42, 4, 88, 8, 70, 7, 18, 6,  1, 1, 63, 2, 59, 
    5, 33, 0, 77, 2, 67, 4, 72, 6, 67, 3, 94, 8, 59, 1, 72, 7, 56, 
    2, 86, 4, 70, 8,  3, 0,  2, 1, 72, 6,  9, 5, 84, 3, 37, 7, 13, 
    8, 71, 1, 22, 2, 58, 5, 45, 6, 80, 4, 15, 7, 69, 0, 43, 3, 10, 
    5, 83, 4, 81, 0, 96, 1, 88, 7,  2, 2, 43, 6, 43, 8, 86, 3, 41, 
    5, 85, 4, 97, 1, 45, 2, 81, 8, 84, 3, 70, 7, 69, 6, 62, 0, 20, 
    3, 64, 5, 44, 2, 37, 0, 41, 1, 64, 6, 52, 4, 26, 8, 56, 7, 41
  };
  const int q4712[] = {
    9, 9, // Number of jobs and machines
    0, 33, 5, 72, 2,  7, 1, 75, 3,  5, 6, 40, 8, 46, 7, 37, 4,  7, 
    3, 55, 8,  2, 6,  5, 4, 49, 2, 77, 7, 43, 5, 19, 1, 25, 0, 61, 
    3, 14, 1, 67, 6, 46, 4, 67, 7, 55, 0, 75, 5, 24, 8, 25, 2, 94, 
    2, 25, 7,  4, 3,  8, 1, 33, 4, 89, 0, 64, 5, 87, 6, 14, 8, 90, 
    1, 81, 5, 86, 8, 34, 2, 98, 4, 53, 3, 95, 6, 60, 7, 93, 0, 95, 
    5, 21, 4, 67, 6, 46, 2, 44, 0, 87, 8, 29, 1, 68, 7, 57, 3, 95, 
    4, 66, 8, 37, 3, 93, 7, 34, 6, 10, 1, 64, 2, 26, 5,  5, 0, 71, 
    7, 67, 8, 63, 3, 51, 2, 25, 6, 18, 4, 51, 5,  6, 1, 64, 0, 15, 
    1, 48, 7, 38, 5, 51, 4, 64, 0, 86, 2, 65, 8, 94, 6, 42, 3, 63
  };
  const int q4713[] = {
    9, 9, // Number of jobs and machines
    8, 84, 4, 72, 6, 57, 2, 19, 7, 35, 1, 10, 3, 23, 5, 53, 0, 11, 
    5, 78, 2, 35, 8, 10, 6, 46, 3, 43, 1, 77, 0,  2, 7, 33, 4, 23, 
    4,  6, 8, 94, 5, 49, 7, 11, 3, 34, 2, 52, 0, 75, 1, 46, 6, 83, 
    3, 97, 6, 67, 0, 27, 1, 86, 4, 66, 8, 77, 5, 26, 2, 14, 7, 87, 
    5, 81, 6, 88, 3, 64, 7, 77, 2, 65, 1, 46, 0, 17, 4, 30, 8, 81, 
    0, 16, 6, 90, 4, 69, 7, 51, 8, 16, 2, 77, 1, 19, 5, 83, 3,  4, 
    7, 87, 4, 31, 0, 91, 2, 49, 3, 67, 1, 59, 6, 38, 8, 39, 5,  5, 
    3, 26, 6,  5, 7, 31, 0, 98, 4, 66, 5, 31, 2, 29, 8, 24, 1, 72, 
    8, 96, 6, 63, 2, 13, 0, 16, 3, 38, 5, 36, 7, 77, 4, 35, 1, 59
  };
  const int q4714[] = {
    9, 9, // Number of jobs and machines
    5, 86, 2, 52, 0, 79, 1, 17, 7, 48, 4, 87, 6, 18, 3, 59, 8, 63, 
    8, 83, 2, 89, 1, 75, 0, 16, 5, 27, 7, 83, 3, 38, 6, 45, 4, 11, 
    7, 51, 3, 95, 5, 25, 2, 72, 6, 30, 8, 35, 1, 69, 0, 12, 4,  7, 
    7, 44, 8, 84, 6, 62, 2, 47, 4,  4, 3, 85, 0, 98, 5, 34, 1, 68, 
    2, 15, 4,  3, 7, 35, 0, 98, 5, 45, 1, 96, 6, 86, 3, 66, 8, 63, 
    7, 21, 5, 34, 4, 64, 2, 39, 3, 80, 6, 79, 0, 41, 8, 25, 1, 30, 
    5, 72, 7, 48, 1, 38, 0, 22, 3, 81, 4, 59, 6, 96, 8, 35, 2, 57, 
    6, 14, 3, 59, 7, 39, 2, 12, 0, 86, 1, 29, 4, 75, 8, 97, 5,  1, 
    7, 35, 6, 91, 3, 15, 4, 81, 1, 58, 8, 68, 5, 48, 0, 51, 2, 11
  };
  const int q4715[] = {
    9, 9, // Number of jobs and machines
    0, 99, 8, 14, 2, 37, 4,  4, 7, 75, 5, 17, 1,  7, 3,  6, 6, 53, 
    7, 74, 4, 94, 5, 57, 2, 38, 1, 13, 8, 62, 3,  8, 6, 19, 0, 41, 
    3, 26, 0, 13, 6, 61, 1, 95, 8, 88, 2, 32, 7, 99, 5, 55, 4, 62, 
    5, 96, 2, 16, 7, 86, 8,  6, 4,  7, 0, 94, 1, 51, 3, 14, 6,  3, 
    1, 27, 6, 80, 7, 57, 0, 16, 3, 43, 2, 46, 5, 47, 8, 91, 4, 47, 
    7, 73, 8, 63, 1,  9, 2, 93, 0, 21, 5, 30, 6, 77, 4, 38, 3, 16, 
    3, 49, 5,  2, 6, 46, 0, 72, 7, 69, 8, 39, 2, 50, 1, 87, 4, 43, 
    7, 22, 8, 48, 4, 44, 6, 17, 0, 26, 1, 19, 2, 33, 3, 42, 5, 72, 
    0,  2, 8, 10, 1, 19, 3, 45, 5, 13, 4, 54, 2, 43, 6, 77, 7, 87
  };
  const int q4716[] = {
    9, 9, // Number of jobs and machines
    4, 57, 3, 82, 7, 74, 6, 80, 5, 41, 8, 28, 1, 49, 2, 92, 0, 13, 
    3, 18, 7, 80, 0, 79, 1, 49, 2,  3, 6, 79, 8, 68, 4,  3, 5, 29, 
    7,  5, 1, 50, 8, 15, 3, 47, 0, 60, 5, 48, 4, 13, 2, 10, 6, 97, 
    3, 70, 6,  3, 5, 36, 8, 73, 4, 28, 7, 41, 1, 19, 0, 52, 2, 77, 
    4, 56, 3, 24, 1, 73, 7, 41, 0, 41, 2, 76, 8, 61, 6, 54, 5, 50, 
    1, 94, 8, 66, 3, 50, 4, 55, 6, 84, 2, 56, 7,  8, 5, 84, 0, 41, 
    8, 40, 3, 59, 5, 14, 0, 20, 4, 95, 6, 15, 1, 92, 7, 71, 2, 29, 
    1, 78, 6,  7, 2, 78, 3, 61, 4, 16, 8, 76, 5, 94, 7, 57, 0, 58, 
    2, 18, 3, 26, 1, 84, 0, 89, 4, 69, 8, 82, 6, 43, 7, 51, 5, 20
  };
  const int q4717[] = {
    9, 9, // Number of jobs and machines
    4, 20, 1, 88, 5, 23, 2, 83, 6, 32, 3,  5, 7, 32, 0, 47, 8, 15, 
    7, 87, 3,  1, 6, 42, 1, 57, 5, 28, 4, 23, 2, 52, 0,  9, 8, 95, 
    6, 79, 2, 38, 7, 97, 4, 90, 8,  4, 3, 55, 0, 86, 5, 71, 1, 43, 
    7, 78, 8, 35, 2, 91, 5, 19, 6, 42, 0, 36, 3, 65, 1, 54, 4, 63, 
    2, 57, 1, 81, 4, 11, 0, 14, 7, 97, 3, 40, 5, 36, 8, 61, 6, 36, 
    4, 94, 7, 90, 1, 44, 8,  2, 5, 10, 3, 14, 0, 41, 2, 86, 6,  3, 
    1, 44, 6, 45, 3, 48, 7, 37, 2, 75, 4, 78, 8, 10, 0, 34, 5,  9, 
    1, 78, 5,  4, 2, 15, 3, 59, 0, 11, 6, 41, 4,  9, 8, 91, 7, 23, 
    0, 11, 5, 88, 4, 73, 2, 85, 3, 89, 1,  4, 6, 38, 7, 61, 8, 38
  };
  const int q4718[] = {
    9, 9, // Number of jobs and machines
    5,  6, 1, 82, 7, 74, 8, 49, 4, 16, 3, 76, 0,  1, 2, 96, 6, 41, 
    5, 61, 1, 33, 7, 67, 3, 28, 2, 14, 8, 21, 0, 20, 4, 73, 6, 88, 
    2, 31, 7, 41, 8, 79, 6, 47, 0, 55, 3, 98, 4, 49, 5, 25, 1, 86, 
    6, 99, 8, 86, 5, 85, 7, 90, 2, 84, 0, 34, 3, 16, 1, 69, 4, 29, 
    8, 64, 4, 60, 0, 55, 5, 82, 6, 75, 1,  4, 3, 13, 7, 36, 2, 46, 
    2, 60, 4, 84, 1, 64, 6, 73, 7, 74, 8,  8, 3, 14, 0, 55, 5, 61, 
    5, 38, 7, 25, 0, 33, 1, 39, 3, 60, 8, 29, 4, 33, 6, 41, 2, 47, 
    2, 53, 5, 62, 0, 69, 1, 60, 8, 34, 7, 34, 3, 66, 4, 59, 6,  4, 
    7, 14, 1, 66, 3,  9, 0, 79, 6, 37, 2, 90, 4, 83, 8, 73, 5, 86
  };
  const int q4719[] = {
    9, 9, // Number of jobs and machines
    6, 70, 8, 91, 5, 43, 2, 92, 3, 42, 4, 35, 0, 76, 7, 81, 1, 35, 
    3, 96, 2, 46, 1, 75, 6, 95, 7,  2, 4, 87, 5, 12, 8, 98, 0, 32, 
    1, 54, 2, 12, 4, 62, 7, 39, 5, 21, 0, 70, 3, 45, 6, 61, 8, 75, 
    0, 12, 2, 74, 5, 49, 6, 78, 8, 70, 7, 80, 3,  8, 4, 13, 1, 80, 
    8, 99, 6,  2, 0, 11, 4, 25, 7, 15, 2, 48, 3, 31, 5, 48, 1, 69, 
    4, 36, 6, 67, 2, 96, 7, 73, 3, 89, 0, 37, 8, 78, 5, 88, 1, 76, 
    6, 47, 4, 72, 0, 38, 2, 25, 5, 22, 8, 90, 1, 90, 7, 48, 3, 70, 
    5,  1, 3, 47, 4, 49, 2,  5, 8, 23, 7, 74, 0, 20, 6, 79, 1, 49, 
    8, 51, 1, 62, 7, 10, 5, 91, 2, 38, 0, 43, 6, 67, 4, 63, 3, 41
  };
  const int q4720[] = {
    9, 9, // Number of jobs and machines
    7, 69, 5, 42, 6, 54, 1, 18, 0, 40, 8, 77, 4, 63, 3, 36, 2, 59, 
    1, 67, 8, 78, 2, 18, 4, 75, 0,  6, 7, 51, 5, 81, 6, 28, 3, 38, 
    0, 89, 7,  5, 5, 29, 2, 15, 6, 28, 3, 65, 8, 93, 4, 77, 1, 33, 
    5, 31, 1, 60, 7, 75, 3, 59, 8, 69, 0, 52, 6, 26, 2, 15, 4, 13, 
    6, 65, 2, 66, 7, 34, 5, 92, 4, 63, 8, 68, 3, 36, 1, 76, 0, 81, 
    4, 15, 6, 56, 3, 90, 2, 23, 8, 95, 5, 15, 7, 32, 0, 77, 1, 51, 
    2, 82, 7, 63, 4, 12, 3, 20, 1, 69, 8, 65, 6, 86, 5, 44, 0, 99, 
    8, 69, 7, 59, 1, 26, 2, 91, 4, 88, 6, 37, 3, 70, 0, 92, 5, 94, 
    4, 62, 8, 52, 6, 71, 3, 84, 1, 99, 0, 95, 7, 83, 2, 18, 5, 76
  };
  const int q4721[] = {
    9, 9, // Number of jobs and machines
    3, 83, 7, 18, 5, 76, 2, 56, 4, 33, 8, 45, 6, 40, 1, 12, 0, 57, 
    5, 88, 8,  9, 7,  6, 2, 46, 4, 39, 0, 85, 3, 45, 6, 41, 1, 28, 
    7, 39, 8, 94, 5, 63, 2, 78, 1, 42, 3, 47, 6, 81, 4, 55, 0, 98, 
    4, 26, 2, 35, 0, 92, 7, 96, 6, 10, 1, 99, 5, 70, 3, 73, 8, 10, 
    0, 60, 3, 92, 7, 19, 1, 98, 6, 67, 4, 80, 2, 83, 8, 82, 5, 86, 
    1,  5, 5, 57, 0, 79, 8, 38, 3, 41, 6, 95, 4, 56, 2, 94, 7, 27, 
    2, 91, 5, 50, 3, 84, 4, 20, 7, 31, 6, 35, 1, 28, 8,  5, 0, 96, 
    4, 44, 1, 26, 5, 11, 0, 18, 7, 25, 6, 93, 2, 54, 3, 83, 8, 82, 
    4, 71, 6, 54, 8, 72, 3, 82, 7, 50, 1, 87, 0, 95, 5, 16, 2,  1
  };
  const int q4722[] = {
    9, 9, // Number of jobs and machines
    1, 98, 4, 89, 6, 43, 8, 98, 0, 74, 7, 19, 2, 62, 5, 75, 3, 28, 
    4, 63, 7, 20, 3, 60, 6, 44, 1, 46, 5, 45, 2, 99, 0, 92, 8, 15, 
    3, 77, 6, 98, 7, 15, 5, 29, 0, 89, 1, 53, 2, 36, 4, 20, 8, 81, 
    8, 93, 1, 28, 2, 79, 6, 97, 4,  7, 7, 74, 3, 57, 0, 51, 5, 27, 
    3, 19, 4, 62, 5, 14, 2, 33, 8,  5, 1, 22, 7, 92, 6, 52, 0, 97, 
    4, 17, 2, 79, 0,  9, 3, 56, 5, 52, 8,  5, 6, 67, 1,  1, 7, 39, 
    8, 92, 3, 29, 4, 46, 6, 74, 1, 78, 7,  6, 2, 64, 0, 40, 5, 51, 
    1, 98, 0, 70, 2, 70, 7,  8, 8, 74, 6, 14, 5, 64, 3,  9, 4, 47, 
    0, 18, 3, 84, 4, 23, 1, 59, 7, 63, 6, 34, 5, 88, 2, 62, 8,  9
  };
  const int q4723[] = {
    9, 9, // Number of jobs and machines
    5,  9, 1, 70, 3, 21, 4, 61, 0, 56, 6, 28, 7, 53, 8, 33, 2, 39, 
    2, 43, 8, 26, 7, 58, 6, 69, 0, 98, 1, 21, 4, 28, 5, 87, 3, 52, 
    0, 85, 5, 81, 6, 81, 2, 56, 4, 61, 3, 93, 8, 19, 7, 30, 1, 48, 
    6, 62, 1, 48, 4, 77, 7, 75, 2, 68, 5, 52, 8, 20, 0, 67, 3, 64, 
    3, 87, 4, 19, 0,  4, 7, 79, 5, 61, 1, 91, 6, 43, 8, 36, 2, 25, 
    3, 87, 1, 58, 7, 55, 6, 90, 0, 56, 8, 57, 5, 27, 4, 83, 2, 42, 
    3, 78, 7, 31, 1, 70, 5, 91, 6, 23, 4, 91, 8, 22, 2, 90, 0, 24, 
    7, 16, 5, 92, 4, 63, 6, 60, 8, 42, 1, 69, 3, 12, 2, 83, 0, 13, 
    5, 96, 4, 27, 6, 15, 0, 72, 2, 48, 8, 87, 7, 68, 3, 89, 1, 82
  };
  const int q4724[] = {
    9, 9, // Number of jobs and machines
    2, 48, 1, 15, 3, 24, 6, 93, 7, 80, 0, 93, 8, 35, 5, 17, 4, 91, 
    4, 81, 8, 17, 0, 64, 3, 70, 6, 64, 2, 78, 7, 22, 5, 46, 1, 64, 
    3, 21, 4, 24, 7, 53, 0, 94, 5, 73, 2, 46, 1, 29, 6, 85, 8, 23, 
    7, 42, 4, 12, 8, 86, 6, 21, 0, 16, 1, 43, 2, 37, 3, 84, 5, 41, 
    6, 67, 5, 42, 8, 50, 0, 92, 1, 38, 4, 59, 7,  4, 3, 49, 2,  4, 
    2, 90, 5, 48, 8, 33, 0, 31, 1, 20, 4, 29, 6, 35, 3, 49, 7, 58, 
    2, 11, 3, 41, 5, 54, 4, 90, 0, 67, 8, 32, 1, 59, 7, 53, 6, 87, 
    2,  2, 3, 71, 4, 66, 1, 20, 7, 37, 5, 19, 0, 91, 8, 92, 6, 41, 
    6, 85, 2, 78, 3, 57, 4, 51, 1, 46, 5, 73, 8, 55, 0, 72, 7, 23
  };
  const int q4725[] = {
    9, 9, // Number of jobs and machines
    3, 19, 8, 40, 1, 45, 7, 26, 5, 68, 4, 88, 6, 19, 2, 48, 0, 77, 
    7, 78, 6, 64, 2, 19, 0, 41, 1,  5, 4, 55, 5, 41, 3, 30, 8, 72, 
    2, 65, 6,  2, 0, 11, 8, 15, 1, 80, 5, 90, 3, 12, 4, 44, 7, 88, 
    3, 25, 6, 26, 2,  1, 8, 18, 4, 31, 7, 34, 1, 37, 0, 72, 5, 57, 
    8, 20, 1, 95, 4, 18, 3, 32, 5, 26, 6, 60, 2,  3, 7, 63, 0, 19, 
    1, 33, 7, 34, 0, 96, 4, 64, 8, 63, 6, 43, 3, 98, 2, 13, 5, 17, 
    5, 10, 0, 36, 3, 10, 6, 33, 4, 30, 8, 18, 1, 65, 7, 33, 2, 32, 
    1, 80, 3, 53, 6, 18, 0, 71, 2, 71, 5, 34, 4, 76, 7, 61, 8, 60, 
    7, 70, 2, 78, 4, 86, 0, 81, 5, 19, 8, 76, 3,  5, 6, 89, 1,  1
  };
  const int q4726[] = {
    9, 9, // Number of jobs and machines
    1, 67, 5, 50, 4, 85, 2, 41, 3, 18, 7, 43, 6,  1, 8, 16, 0, 51, 
    2, 32, 8, 83, 5, 76, 4, 35, 1, 63, 3, 85, 6, 69, 0, 16, 7, 45, 
    3, 20, 1, 66, 7, 13, 5, 40, 4, 60, 8, 12, 2, 82, 0, 50, 6, 11, 
    7, 65, 6, 27, 1,  6, 4, 53, 8, 61, 2, 73, 0, 89, 3, 99, 5, 76, 
    6,  3, 3, 27, 8, 22, 0,  8, 2, 58, 7, 75, 1,  6, 5, 96, 4, 81, 
    6, 60, 1,  3, 7, 58, 8, 76, 5, 82, 4, 46, 0, 58, 2, 58, 3, 49, 
    0, 27, 3, 65, 6, 99, 1,  5, 2,  3, 7, 51, 5, 50, 4, 46, 8, 20, 
    2, 15, 6, 89, 4, 44, 7, 56, 0, 11, 3, 56, 1,  7, 5, 25, 8, 23, 
    0, 16, 3, 20, 8, 60, 7, 92, 5, 43, 2, 14, 6, 36, 1,  4, 4, 87
  };
  const int q4727[] = {
    9, 9, // Number of jobs and machines
    6, 61, 3, 17, 4, 56, 8, 60, 0, 27, 7, 92, 1, 33, 5, 40, 2, 50, 
    5, 95, 7, 66, 3, 10, 0, 54, 2,  8, 6, 66, 4, 72, 8, 44, 1,  6, 
    3, 86, 2, 56, 4, 35, 8, 82, 6, 92, 7, 98, 1,  2, 5, 56, 0, 32, 
    0,  5, 4, 64, 2, 16, 6, 55, 1, 55, 8,  3, 3, 98, 5, 77, 7, 22, 
    7, 12, 5, 56, 0, 52, 4, 44, 8, 28, 3, 11, 6, 31, 2, 82, 1, 12, 
    6, 59, 1, 35, 8, 84, 2, 45, 7,  5, 3, 56, 4, 69, 5, 68, 0, 88, 
    3, 90, 2, 72, 6, 22, 7, 14, 5, 41, 8, 12, 1, 56, 4,  8, 0, 10, 
    7, 70, 3, 64, 4, 74, 8, 39, 2, 27, 6,  7, 1, 37, 5, 23, 0, 73, 
    2, 66, 0, 21, 7, 88, 6, 32, 1, 57, 5, 66, 8,  4, 3, 38, 4, 92
  };
  const int q4728[] = {
    9, 9, // Number of jobs and machines
    3, 54, 4, 67, 5, 77, 8, 70, 6, 73, 2, 40, 0, 75, 7, 92, 1, 55, 
    2, 68, 0, 49, 8, 31, 3, 97, 1, 96, 6, 56, 7, 90, 4, 60, 5, 43, 
    2, 53, 0,  9, 4, 65, 5, 93, 3, 87, 8, 47, 7, 82, 1, 77, 6, 74, 
    6, 14, 5, 59, 2,  9, 7, 89, 4,  9, 3, 93, 1, 71, 0, 64, 8, 92, 
    7,  3, 6, 72, 2, 97, 5, 65, 1, 46, 3, 21, 0, 35, 8, 87, 4, 74, 
    3, 43, 1, 86, 8, 82, 7, 44, 5,  7, 4, 65, 2, 54, 0, 22, 6, 26, 
    5, 86, 0, 46, 1, 26, 8, 37, 6, 38, 4, 12, 3, 31, 2, 45, 7, 24, 
    7, 54, 8, 62, 1, 29, 5, 77, 4, 76, 3, 38, 0, 41, 6, 65, 2, 39, 
    6, 76, 3,  6, 0, 54, 1, 57, 4, 90, 8, 40, 2, 57, 7, 49, 5, 99
  };
  const int q4729[] = {
    9, 9, // Number of jobs and machines
    1, 98, 8,  9, 4, 85, 2, 23, 3, 75, 5, 55, 6, 20, 7, 31, 0, 49, 
    1, 99, 8, 17, 5, 42, 2, 53, 7, 56, 3, 28, 4, 54, 6, 77, 0,  9, 
    0, 99, 3, 89, 1, 66, 4, 13, 6, 89, 5, 73, 2, 31, 8, 96, 7, 38, 
    8, 61, 4, 77, 2, 85, 7, 28, 6, 76, 0, 88, 1, 27, 3,  7, 5,  6, 
    5,  9, 6, 26, 0,  6, 1, 49, 7, 98, 3, 48, 4, 20, 8, 84, 2, 21, 
    8, 44, 7, 57, 6, 40, 5, 38, 2, 79, 4, 51, 1,  3, 0, 73, 3, 15, 
    2, 30, 1, 72, 0, 67, 8, 83, 3, 42, 5, 29, 4, 60, 6, 97, 7, 68, 
    7, 28, 8,  7, 4, 80, 2, 92, 1, 22, 5, 73, 0, 39, 3, 72, 6,  1, 
    3, 87, 0, 68, 8, 14, 4, 21, 6, 56, 5, 23, 7, 44, 2, 19, 1, 38
  };
  const int q4730[] = {
    9, 9, // Number of jobs and machines
    1, 67, 5, 25, 4, 16, 0, 37, 7, 20, 6, 52, 3, 67, 8,  3, 2, 28, 
    2, 14, 0, 52, 6, 59, 3,  1, 5, 27, 4, 24, 7, 92, 1, 33, 8, 79, 
    6, 34, 5,  2, 2, 59, 3,  5, 4, 79, 8, 33, 0, 45, 1, 28, 7, 28, 
    2, 84, 6, 37, 3, 64, 1, 94, 4, 46, 5, 40, 8, 95, 7, 62, 0, 92, 
    2, 69, 5,  1, 6, 95, 4, 19, 1,  6, 0, 27, 3,  6, 7, 72, 8, 75, 
    2, 23, 5, 91, 7,  8, 1, 66, 0,  8, 6, 10, 8, 32, 4, 68, 3, 23, 
    8, 92, 5, 99, 3, 54, 0, 28, 7, 51, 4, 21, 2, 46, 6, 30, 1, 78, 
    8, 23, 3, 82, 5, 38, 6, 98, 0, 20, 7, 65, 1, 64, 4,  1, 2, 59, 
    3, 80, 1, 11, 2, 92, 4, 38, 7, 24, 6, 57, 0,  1, 8, 47, 5, 76
  };
  const int q4731[] = {
    9, 9, // Number of jobs and machines
    2, 21, 1, 30, 3, 26, 7, 15, 5, 67, 8, 53, 0, 46, 6, 20, 4, 73, 
    7, 56, 8, 30, 3, 12, 1, 92, 2, 26, 0, 34, 5, 32, 6, 55, 4, 81, 
    5, 52, 7, 39, 1, 57, 8, 41, 4, 26, 6, 85, 3, 75, 2, 83, 0, 72, 
    6,  3, 3, 78, 7, 14, 5, 85, 8, 86, 4, 28, 2, 45, 0, 51, 1, 14, 
    3,  4, 5, 71, 8, 40, 7, 61, 0, 63, 4, 90, 6,  6, 1, 25, 2, 47, 
    6, 10, 2, 39, 8, 61, 7, 78, 0, 40, 4, 42, 3, 81, 5, 51, 1, 11, 
    2, 29, 1, 30, 3, 21, 8, 75, 0, 18, 6, 31, 4, 17, 5, 27, 7, 43, 
    2, 60, 8, 12, 7, 25, 6, 44, 5, 11, 3, 45, 1, 21, 0, 51, 4, 15, 
    7, 49, 4, 56, 1, 10, 2, 52, 5, 45, 6, 71, 8, 69, 3, 74, 0, 66
  };
  const int q4732[] = {
    9, 9, // Number of jobs and machines
    3, 90, 1, 19, 0,  1, 6, 29, 7, 59, 5, 41, 8, 16, 4, 62, 2, 65, 
    0, 30, 6, 79, 2, 55, 7, 20, 4, 92, 1, 63, 3, 82, 8, 51, 5, 76, 
    5, 38, 6, 72, 8, 93, 2, 71, 0, 70, 4, 47, 3, 56, 7, 22, 1, 74, 
    5, 74, 0, 82, 8, 40, 4, 75, 3, 45, 6, 17, 1, 64, 7, 14, 2, 80, 
    5, 24, 8, 71, 1, 81, 6, 80, 4, 88, 7, 28, 3,  8, 0, 14, 2, 89, 
    3, 27, 5,  7, 1, 85, 0, 10, 7, 90, 4, 56, 8, 77, 2, 50, 6, 73, 
    3, 77, 8, 37, 1, 65, 0, 86, 4, 36, 2, 68, 6, 63, 7, 94, 5, 29, 
    5, 18, 7, 63, 6, 79, 3, 31, 8,  6, 1, 44, 0, 18, 4, 47, 2, 95, 
    8,  4, 6, 61, 7, 73, 4, 81, 2, 30, 3, 49, 0, 56, 5, 92, 1, 85
  };
  const int q4733[] = {
    9, 9, // Number of jobs and machines
    2, 98, 7, 89, 0, 82, 5, 40, 3, 83, 4, 99, 1, 89, 6, 97, 8, 16, 
    6, 10, 4, 95, 5, 12, 0, 16, 8, 16, 3, 49, 1, 29, 2, 23, 7, 22, 
    8, 53, 3, 87, 0, 77, 2, 86, 7, 20, 4, 13, 5, 21, 1, 24, 6,  5, 
    8, 99, 7, 37, 6,  4, 0, 23, 2, 97, 4, 68, 1,  8, 5, 59, 3, 47, 
    8, 46, 3, 94, 6, 90, 7, 25, 0,  4, 1, 26, 5, 55, 2, 12, 4, 90, 
    0, 93, 1, 24, 3, 98, 2, 40, 4, 92, 8, 60, 7, 20, 5, 62, 6, 77, 
    5, 72, 7, 50, 2, 75, 6, 63, 3, 25, 0, 84, 8, 21, 4, 90, 1, 24, 
    5, 71, 7,  7, 6, 74, 3, 63, 0, 64, 1, 39, 2, 85, 4, 59, 8, 50, 
    1, 25, 7, 27, 0, 72, 6, 30, 3,  7, 4, 90, 2,  7, 5,  6, 8, 70
  };
  const int q4734[] = {
    9, 9, // Number of jobs and machines
    3, 71, 2, 96, 4, 84, 6, 41, 0, 16, 1, 69, 8, 56, 5,  6, 7, 73, 
    7, 68, 6, 45, 2,  7, 8, 34, 5,  8, 0, 47, 1,  6, 3, 50, 4, 91, 
    6, 53, 5, 51, 1, 29, 7, 40, 2, 34, 4, 63, 3, 59, 0,  8, 8, 31, 
    8, 39, 6, 21, 5, 64, 0, 55, 4, 43, 2, 84, 7, 32, 3, 12, 1, 76, 
    5, 46, 7, 42, 0, 22, 1, 96, 4, 27, 3, 82, 6, 17, 2, 87, 8, 86, 
    0, 89, 3, 51, 1, 75, 5, 46, 4, 36, 6, 71, 7, 77, 8, 67, 2,  7, 
    3, 30, 8, 32, 4, 62, 1, 57, 5, 23, 7, 25, 0, 77, 6, 49, 2, 52, 
    5, 90, 1, 51, 8, 11, 2, 57, 7, 70, 6, 44, 0, 37, 3, 24, 4, 36, 
    7, 88, 0, 37, 1, 84, 5, 31, 4, 44, 8, 46, 3, 34, 6, 27, 2,  5
  };
  const int q4735[] = {
    9, 9, // Number of jobs and machines
    3, 97, 6, 90, 4, 70, 5, 37, 7, 34, 8, 20, 0,  9, 1, 10, 2, 83, 
    2, 33, 8, 96, 6,  7, 1, 35, 5, 76, 0, 40, 3, 80, 4, 83, 7, 96, 
    8, 86, 2, 49, 7, 83, 3, 64, 1, 81, 4, 77, 6, 71, 5, 61, 0, 11, 
    4, 43, 5, 71, 2, 62, 6,  5, 1, 89, 7, 83, 3, 32, 0, 72, 8, 54, 
    0, 60, 2, 12, 1, 73, 8, 25, 6, 55, 5, 41, 4, 86, 7, 90, 3, 44, 
    7, 88, 3, 95, 6,  2, 1, 41, 8, 22, 4, 47, 5, 76, 0, 56, 2, 27, 
    2, 60, 6, 79, 8, 74, 7, 78, 3, 61, 4, 86, 1, 62, 0, 82, 5, 33, 
    4, 45, 7, 96, 0, 39, 6, 60, 3, 31, 5, 46, 8, 11, 2, 30, 1, 34, 
    2, 57, 3, 59, 4, 23, 7, 61, 6, 96, 1, 21, 8, 73, 0, 53, 5, 50
  };
  const int q4736[] = {
    9, 9, // Number of jobs and machines
    8, 53, 7, 96, 1, 33, 5, 73, 4,  6, 3, 15, 2, 79, 0, 46, 6, 36, 
    1, 42, 6, 18, 3, 59, 2, 18, 5, 84, 8, 67, 0, 39, 4,  9, 7, 56, 
    1, 43, 5, 46, 7, 46, 6, 93, 4, 20, 8, 95, 3, 58, 0, 90, 2, 91, 
    8, 57, 7, 68, 0, 89, 4, 76, 2, 91, 3, 65, 1, 65, 5, 10, 6, 46, 
    2,  5, 1, 83, 4, 74, 5, 47, 3,  9, 8, 59, 0, 42, 7,  7, 6, 84, 
    4, 11, 1, 86, 5, 19, 7, 80, 3, 82, 0, 30, 2, 51, 8, 59, 6, 73, 
    7, 50, 0, 54, 6, 68, 3, 67, 1, 27, 4, 50, 8, 11, 2,  5, 5, 14, 
    2, 71, 0, 85, 5, 29, 8, 31, 4, 86, 3,  9, 6, 31, 1, 35, 7, 33, 
    7, 56, 8, 73, 5, 45, 2, 24, 3, 99, 6, 35, 4, 25, 0, 86, 1, 24
  };
  const int q4737[] = {
    9, 9, // Number of jobs and machines
    5, 20, 2, 87, 6, 93, 1, 87, 8, 16, 4, 84, 7, 66, 3, 31, 0, 67, 
    4, 31, 2, 13, 7, 20, 8,  1, 5, 46, 0, 25, 1,  2, 3, 36, 6, 94, 
    0, 86, 5, 71, 8,  6, 7, 71, 2, 47, 4, 25, 3,  9, 6, 11, 1, 94, 
    6, 88, 7, 20, 8, 96, 2, 44, 1, 85, 3, 70, 0, 73, 4, 86, 5, 53, 
    2,  6, 4, 72, 1, 83, 5, 71, 3, 38, 7, 31, 6, 90, 0, 26, 8, 79, 
    3, 22, 0,  5, 4, 56, 1,  5, 2, 82, 8,  4, 6, 84, 5, 97, 7, 79, 
    2, 99, 1, 86, 5, 38, 6, 98, 7, 70, 8, 73, 0, 66, 4, 45, 3, 40, 
    6, 29, 3,  7, 8, 19, 4, 65, 0, 65, 1, 42, 2, 38, 5, 20, 7, 88, 
    8, 23, 5, 65, 0, 40, 6, 41, 3, 66, 1, 51, 7, 31, 2, 48, 4, 16
  };
  const int q4738[] = {
    9, 9, // Number of jobs and machines
    1, 73, 7, 62, 5, 71, 0, 33, 3, 30, 8, 14, 6, 15, 2, 27, 4, 35, 
    3, 97, 1,  3, 2, 38, 5, 89, 7, 61, 6, 32, 8, 17, 4, 73, 0, 23, 
    4, 49, 2, 59, 7, 45, 8, 31, 1, 41, 3, 30, 5, 32, 0, 67, 6, 94, 
    3, 93, 8, 82, 0, 95, 4, 24, 5, 82, 7, 41, 1, 69, 6, 21, 2, 41, 
    4, 53, 7, 56, 2, 34, 1, 76, 3, 78, 6, 57, 5, 50, 0, 38, 8, 86, 
    7,  4, 3, 35, 8, 55, 6, 91, 4, 30, 5, 29, 0, 99, 2, 81, 1, 24, 
    2, 44, 0, 63, 7, 39, 6, 83, 4, 88, 8, 56, 1, 54, 3, 19, 5, 89, 
    0, 11, 2, 64, 1, 69, 8, 57, 7, 73, 4, 29, 5, 21, 3, 78, 6,  1, 
    1, 24, 0, 61, 2, 44, 3, 64, 6, 82, 5, 61, 7, 42, 4, 63, 8, 99
  };
  const int q4739[] = {
    9, 9, // Number of jobs and machines
    0, 57, 7, 26, 5,  7, 4,  2, 1, 32, 8, 46, 3,  8, 6, 69, 2,  9, 
    5, 30, 3,  6, 7, 63, 0, 95, 8, 44, 1, 30, 2, 55, 4,  6, 6, 74, 
    1, 96, 4, 61, 0, 57, 8, 13, 6, 48, 5, 80, 3, 65, 7, 79, 2, 14, 
    2, 24, 1, 35, 7, 77, 4, 77, 0, 71, 6, 73, 5, 37, 8, 86, 3, 65, 
    5, 51, 2, 94, 8, 72, 3, 10, 0, 23, 1, 31, 6, 69, 4, 79, 7, 30, 
    6, 79, 4, 57, 3, 11, 5, 30, 8, 98, 7, 73, 0, 30, 2, 47, 1,  6, 
    4, 89, 3, 66, 0, 70, 2, 16, 6, 50, 5, 95, 8, 57, 1, 11, 7, 37, 
    7, 50, 0, 40, 5,  6, 4, 50, 3, 82, 8,  6, 2, 55, 1, 35, 6, 45, 
    6, 49, 2, 80, 1, 98, 5, 22, 0, 22, 8, 34, 7, 56, 3, 10, 4, 16
  };
  const int q4740[] = {
    9, 9, // Number of jobs and machines
    5, 94, 8, 19, 1, 83, 2, 76, 3, 15, 0, 79, 7, 80, 6, 17, 4, 88, 
    8, 89, 6, 97, 5, 13, 2, 37, 1, 50, 3, 35, 7, 36, 4, 52, 0, 80, 
    7,  8, 1, 34, 2,  9, 6,  6, 5, 24, 8, 93, 0, 54, 3, 52, 4, 29, 
    7, 13, 8, 27, 4, 50, 3,  2, 6, 28, 1, 94, 5, 89, 2, 43, 0, 10, 
    6,  5, 5, 64, 1, 12, 2, 84, 8, 36, 3, 76, 0, 64, 7, 12, 4, 10, 
    3,  5, 8, 53, 5, 26, 7, 66, 2, 11, 1, 40, 4, 84, 6,  5, 0,  7, 
    2,  3, 8, 55, 4, 15, 7, 25, 3, 26, 1, 85, 6,  8, 5, 23, 0, 89, 
    6, 10, 8,  8, 7, 19, 5, 15, 1,  9, 0,  4, 3, 70, 4,  7, 2, 74, 
    3, 35, 8, 72, 0, 34, 1, 63, 2,  5, 6,  6, 5, 51, 7, 45, 4, 67
  };
  const int q4741[] = {
    9, 9, // Number of jobs and machines
    4, 36, 3, 39, 1,  8, 6, 98, 2, 75, 8, 74, 0, 83, 5, 45, 7, 64, 
    2, 31, 1, 30, 5, 72, 4, 21, 3, 33, 8, 59, 6, 54, 0, 54, 7, 60, 
    0, 28, 6,  4, 1, 71, 3, 10, 5, 36, 8, 45, 7, 87, 4, 84, 2, 70, 
    4, 30, 0, 20, 2, 72, 7, 94, 6, 22, 1, 25, 5,  4, 8, 34, 3, 40, 
    7, 30, 6, 85, 5, 78, 3,  3, 1, 54, 8, 30, 0, 62, 4, 38, 2, 48, 
    6, 31, 3, 10, 2, 81, 4, 89, 0, 97, 5, 65, 1, 91, 7, 46, 8, 70, 
    6,  3, 0, 28, 3, 53, 1, 22, 7, 47, 5, 16, 4,  5, 8, 43, 2, 56, 
    8,  5, 7, 17, 5, 96, 3, 94, 2, 91, 6, 98, 4, 37, 0, 65, 1, 55, 
    5, 72, 3, 80, 7, 26, 1, 51, 6, 26, 4, 91, 0, 86, 2, 59, 8, 58
  };
  const int q4742[] = {
    9, 9, // Number of jobs and machines
    4, 78, 7, 67, 3, 54, 1, 15, 0, 92, 2, 58, 6, 44, 8, 72, 5, 64, 
    8, 99, 2, 22, 1, 73, 5, 50, 6, 71, 7, 45, 4,  1, 0, 75, 3, 25, 
    6, 77, 8, 14, 0, 23, 7, 37, 2, 59, 5, 59, 4, 23, 3, 61, 1, 18, 
    2, 73, 8,  7, 5, 23, 6, 98, 1, 60, 7, 25, 0, 29, 3, 63, 4, 24, 
    2, 81, 6, 51, 7, 20, 1, 15, 0, 27, 4, 11, 8, 38, 3,  6, 5, 56, 
    8, 43, 1, 30, 6, 15, 3, 36, 0, 51, 2, 80, 4, 22, 7,  7, 5, 72, 
    6, 34, 3, 11, 5, 35, 4, 36, 8, 48, 1, 15, 0, 52, 7, 35, 2, 64, 
    2, 48, 6,  6, 8, 73, 0, 72, 1, 73, 7, 40, 3, 46, 4, 42, 5, 99, 
    6, 73, 3, 44, 4, 35, 1, 43, 7, 67, 2,  8, 5, 48, 0,  2, 8, 14
  };
  const int q4743[] = {
    9, 9, // Number of jobs and machines
    3, 59, 5, 73, 0, 38, 4, 62, 6, 20, 8, 71, 7,  6, 2, 68, 1,  3, 
    3, 29, 6, 16, 4, 83, 5, 18, 1, 61, 2, 97, 0, 19, 8,  8, 7, 84, 
    7, 37, 8, 61, 6, 84, 3,  9, 2, 24, 4, 30, 0, 36, 1, 65, 5, 43, 
    4,  7, 3, 36, 2, 71, 5, 17, 0, 30, 6, 27, 1,  1, 7,  6, 8, 47, 
    2, 95, 7, 95, 6, 58, 3, 71, 5,  1, 8,  6, 1, 57, 0, 50, 4,  8, 
    1,  7, 8, 48, 6, 86, 3, 85, 7, 31, 0,  1, 2,  1, 4, 19, 5, 63, 
    7, 15, 0, 55, 8, 99, 6, 48, 5, 52, 3, 22, 1, 20, 2, 32, 4, 21, 
    4, 12, 7, 53, 3, 71, 0, 42, 8, 29, 6, 69, 1, 42, 2, 56, 5, 93, 
    7, 73, 8, 83, 1, 96, 4, 91, 2, 93, 0, 12, 5, 17, 6, 62, 3, 21
  };
  const int q4744[] = {
    9, 9, // Number of jobs and machines
    5, 85, 3,  4, 7, 99, 1, 36, 8, 60, 4, 99, 0, 34, 2, 26, 6, 93, 
    6, 36, 0,  2, 7, 65, 5, 51, 4, 78, 1, 95, 8, 75, 3,  4, 2, 64, 
    1, 24, 8, 41, 0, 29, 5, 35, 7,  9, 2, 26, 6, 53, 4, 21, 3, 68, 
    7, 19, 8, 27, 1, 29, 4, 99, 6, 65, 3, 69, 2, 95, 0, 59, 5, 91, 
    3, 40, 8, 13, 1, 70, 5, 55, 6, 85, 7, 61, 0, 18, 2, 50, 4, 46, 
    8, 57, 6, 99, 5, 46, 2,  9, 1,  8, 3, 88, 4, 52, 7, 19, 0, 14, 
    5, 82, 3, 52, 0, 72, 4, 90, 1, 78, 2, 79, 6, 47, 8, 94, 7, 13, 
    1, 25, 4, 53, 8, 92, 3,  6, 7, 66, 2, 87, 5, 87, 6, 17, 0, 89, 
    4, 61, 2, 79, 7, 96, 0,  2, 8, 54, 6, 79, 3, 95, 1, 83, 5, 34
  };
  const int q4745[] = {
    9, 9, // Number of jobs and machines
    2, 42, 3, 80, 5, 57, 1, 35, 6, 40, 8, 65, 4, 30, 7, 86, 0, 58, 
    4, 16, 8, 52, 1, 54, 0, 59, 5, 46, 2, 53, 3, 94, 7, 28, 6, 52, 
    8, 12, 5, 37, 0, 81, 3, 80, 2, 98, 6, 61, 7, 46, 4, 66, 1, 18, 
    1,  8, 8, 75, 7, 23, 4, 67, 5, 14, 2, 49, 0, 80, 3,  1, 6, 27, 
    7, 33, 3, 36, 5, 94, 0, 34, 2, 54, 1, 40, 6, 17, 8, 78, 4, 59, 
    8, 22, 3, 40, 0, 16, 6, 50, 1, 60, 4, 42, 2, 62, 5, 86, 7, 90, 
    6, 83, 7, 50, 1, 53, 5, 91, 2, 70, 4,  5, 8, 27, 3, 57, 0,  8, 
    2, 75, 1, 95, 0, 82, 6, 84, 8, 68, 4, 37, 7, 11, 3, 31, 5, 61, 
    1, 34, 6, 58, 3,  8, 0, 60, 4, 41, 8, 26, 7, 35, 2, 70, 5, 54
  };
  const int q4746[] = {
    9, 9, // Number of jobs and machines
    7, 55, 2, 27, 8, 55, 0, 11, 3,  8, 6, 81, 4, 57, 5, 24, 1, 43, 
    7, 43, 8, 33, 5, 59, 3, 88, 4, 33, 1, 72, 6, 92, 2, 65, 0, 90, 
    0, 30, 6, 70, 7, 89, 1, 96, 3, 56, 5, 49, 4, 96, 2, 25, 8,  5, 
    3, 50, 2, 30, 5, 22, 8, 90, 7, 26, 0, 33, 6, 63, 1, 59, 4, 54, 
    6, 88, 8, 29, 4, 80, 0, 60, 5, 25, 7, 75, 1, 26, 3, 14, 2, 61, 
    6, 41, 8, 35, 5, 20, 0, 10, 3, 79, 4, 70, 7, 91, 1, 77, 2,  2, 
    8, 88, 1, 46, 3, 29, 4,  9, 6, 91, 5, 37, 0,  7, 2, 42, 7, 57, 
    0, 65, 8, 76, 1, 63, 5, 45, 4, 97, 6, 71, 3, 17, 7, 59, 2, 39, 
    5, 52, 4, 15, 6, 55, 7, 66, 8, 28, 1, 47, 0, 50, 3, 66, 2, 85
  };
  const int q4747[] = {
    9, 9, // Number of jobs and machines
    7,  6, 4, 67, 5, 72, 6, 13, 2, 92, 8, 67, 1, 73, 3, 73, 0, 79, 
    5, 13, 2, 30, 8, 40, 7, 16, 3, 71, 1, 84, 0, 67, 6, 48, 4,  8, 
    7, 78, 8, 63, 1, 44, 4, 68, 2, 44, 6,  1, 3, 81, 5, 67, 0, 54, 
    2, 58, 0,  4, 8, 25, 3, 92, 6, 92, 1, 73, 5, 90, 7, 41, 4,  3, 
    3,  8, 0,  8, 7, 66, 2, 13, 4, 46, 6, 52, 5, 95, 8, 31, 1, 33, 
    5, 16, 8, 25, 1, 39, 2, 55, 6, 49, 3, 48, 0, 25, 4, 76, 7, 29, 
    6, 51, 5, 84, 7, 48, 4, 71, 3, 16, 0, 81, 8, 27, 1, 99, 2, 20, 
    8, 55, 6,  6, 4, 96, 2, 50, 0, 61, 5, 53, 3,  9, 1, 41, 7, 26, 
    6, 59, 3, 69, 8, 25, 4, 34, 7, 63, 5, 79, 2, 37, 1, 17, 0,  4
  };
  const int q4748[] = {
    9, 9, // Number of jobs and machines
    0, 88, 5, 36, 7, 65, 8, 45, 3, 98, 6, 13, 1, 82, 2, 46, 4, 23, 
    2, 83, 0, 13, 1, 20, 3, 99, 5, 26, 8, 97, 6, 12, 4, 56, 7, 30, 
    8, 32, 2, 93, 0, 29, 1, 89, 6, 77, 4, 52, 7, 61, 3, 52, 5, 94, 
    6, 42, 5, 23, 4, 11, 2, 63, 8, 96, 7, 24, 0, 61, 3, 24, 1, 96, 
    7,  5, 6,  9, 8, 95, 2, 11, 1, 12, 0, 98, 4,  1, 3, 40, 5, 59, 
    3, 40, 7, 33, 5,  4, 2,  7, 8, 62, 1, 56, 4, 19, 6, 84, 0, 94, 
    0, 74, 5, 85, 2, 59, 8, 97, 3, 29, 4,  2, 1, 75, 6, 29, 7, 60, 
    0, 50, 4, 48, 6, 10, 3, 77, 1, 96, 8, 22, 7, 28, 5, 99, 2,  5, 
    3, 69, 8, 30, 4, 73, 5, 83, 6, 62, 1, 88, 2, 60, 7, 67, 0, 76
  };
  const int q4749[] = {
    9, 9, // Number of jobs and machines
    5, 77, 6, 14, 0, 24, 4, 87, 1, 11, 3, 90, 8, 42, 7, 91, 2, 11, 
    3, 19, 7, 32, 5, 41, 8,  9, 2, 64, 6, 37, 1, 77, 4, 27, 0,  4, 
    2, 28, 6, 90, 8, 34, 5, 67, 1, 57, 0, 98, 7, 57, 4,  7, 3, 69, 
    0, 70, 3,  3, 7, 81, 5, 66, 4, 34, 1, 72, 6, 62, 2, 44, 8, 55, 
    0, 75, 3, 18, 8, 84, 7, 83, 4, 90, 6, 24, 1, 61, 5, 66, 2, 36, 
    8, 62, 1, 83, 4, 34, 7, 89, 3, 39, 6, 50, 5, 20, 0, 56, 2, 98, 
    3, 72, 1, 71, 8, 80, 0, 14, 5, 89, 4, 53, 2, 71, 7,  7, 6, 21, 
    2, 79, 0, 19, 3, 93, 4, 64, 7, 55, 5, 78, 6, 35, 1, 62, 8, 66, 
    3, 19, 8, 61, 1, 56, 4, 67, 0, 79, 5, 86, 7, 84, 2, 54, 6,  6
  };
  const int q4750[] = {
    9, 9, // Number of jobs and machines
    7, 52, 2, 88, 4, 90, 1, 36, 3, 73, 6, 42, 5,  1, 0, 97, 8, 33, 
    0, 51, 3, 53, 6, 47, 4, 91, 1, 23, 7, 99, 2,  4, 8, 14, 5,  9, 
    2,  7, 3, 75, 0, 32, 5, 57, 8, 77, 6, 28, 4, 41, 7,  1, 1, 94, 
    4, 98, 2, 34, 1, 54, 8, 90, 0, 24, 3, 76, 6, 14, 5, 62, 7, 22, 
    6,  6, 2,  6, 4, 67, 1,  9, 8, 51, 3, 32, 5, 96, 0, 80, 7, 33, 
    1, 94, 5, 66, 2, 74, 3, 25, 8, 48, 6, 31, 7, 24, 4, 57, 0, 97, 
    8, 36, 5, 52, 7, 86, 6, 74, 2, 32, 0, 49, 3, 27, 1, 50, 4, 80, 
    3, 33, 4, 91, 5, 28, 6, 40, 2, 78, 7, 30, 8, 17, 0, 64, 1, 25, 
    8, 41, 2, 96, 6, 26, 7, 75, 1, 83, 3, 56, 0, 39, 4, 28, 5, 94
  };
  const int q4751[] = {
    9, 9, // Number of jobs and machines
    3, 16, 5, 45, 0, 18, 7, 68, 2, 93, 6, 34, 1, 59, 8,  7, 4, 12, 
    5, 37, 3, 46, 1, 80, 6, 47, 0, 45, 2, 35, 7, 45, 8, 79, 4, 73, 
    1, 53, 7, 83, 8, 35, 5, 39, 0, 12, 2, 38, 4, 48, 6, 41, 3, 12, 
    0, 54, 1, 27, 6, 95, 7, 59, 4, 46, 2,  7, 3,  5, 5, 56, 8, 61, 
    5, 45, 4, 58, 3, 19, 6,  6, 8,  9, 0, 86, 7, 46, 2, 96, 1, 23, 
    7, 54, 1, 93, 0, 34, 2, 79, 5, 71, 3,  6, 4, 85, 6, 28, 8, 88, 
    2,  8, 8, 71, 4, 30, 7, 20, 1, 56, 5, 12, 6, 40, 3, 33, 0, 97, 
    5, 82, 2, 17, 0, 52, 7, 15, 3, 98, 4, 94, 8,  8, 1, 21, 6,  3, 
    1,  8, 0,  6, 5, 27, 6, 38, 2, 90, 3, 15, 4, 44, 8, 84, 7,  8
  };
  const int q4752[] = {
    9, 9, // Number of jobs and machines
    6, 12, 4, 71, 5, 45, 8, 70, 0, 10, 1, 65, 3, 17, 7, 85, 2, 38, 
    3, 39, 8, 38, 5,  5, 6, 68, 4, 62, 0,  9, 2, 72, 1, 83, 7, 18, 
    5, 13, 6, 43, 3, 94, 0, 12, 2, 48, 1, 71, 8,  6, 4, 69, 7,  8, 
    3, 78, 6, 98, 2, 35, 5, 75, 1, 13, 4, 60, 8, 97, 0, 10, 7, 77, 
    3, 14, 7, 63, 4, 97, 5, 50, 8, 22, 2, 43, 0, 69, 6, 22, 1, 76, 
    2, 50, 3, 47, 5, 27, 4, 21, 1, 66, 6, 15, 8, 46, 0, 22, 7, 84, 
    6, 86, 8,  5, 7, 67, 1,  7, 0, 98, 2, 14, 5, 65, 3,  1, 4, 52, 
    1, 54, 2,  2, 3, 74, 7, 49, 6, 38, 8, 90, 0, 18, 4, 80, 5, 20, 
    8, 64, 1, 37, 0, 20, 7, 25, 3, 19, 6, 61, 2, 50, 4,  4, 5, 22
  };
  const int q4753[] = {
    9, 9, // Number of jobs and machines
    8, 45, 1, 55, 6, 72, 0, 55, 5, 15, 4, 20, 3, 18, 2, 76, 7, 57, 
    1, 71, 7, 73, 0, 73, 4, 75, 2, 22, 5, 63, 8, 39, 3, 15, 6, 68, 
    4, 19, 6, 85, 8, 65, 0, 23, 3,  5, 5, 43, 1, 14, 2, 42, 7, 78, 
    8, 11, 3,  1, 1, 54, 6, 25, 4, 57, 2, 93, 7, 47, 0, 75, 5, 19, 
    0, 29, 8,  8, 5, 77, 6, 60, 4, 95, 7, 54, 3, 22, 1, 70, 2, 38, 
    1, 27, 6, 61, 5, 77, 8,  2, 3, 76, 0,  4, 4, 69, 2,  7, 7,  8, 
    5, 22, 4, 21, 1, 68, 7, 65, 3, 64, 8, 82, 6, 96, 2, 87, 0, 89, 
    8, 10, 1, 58, 7, 97, 3, 33, 5, 55, 2, 33, 6, 10, 0, 26, 4, 58, 
    2, 46, 3, 76, 5, 89, 0, 61, 7, 49, 8, 99, 1, 74, 6, 48, 4, 19
  };
  const int q4754[] = {
    9, 9, // Number of jobs and machines
    5, 40, 2,  8, 4, 19, 0, 17, 6, 67, 1, 19, 8, 25, 3, 81, 7, 87, 
    1,  3, 0, 16, 6, 15, 2, 17, 4, 59, 7, 43, 3, 79, 5, 99, 8, 92, 
    2, 36, 5, 78, 7, 54, 4, 74, 6, 26, 8,  3, 0, 38, 1, 74, 3, 44, 
    4, 64, 0, 96, 7, 84, 3,  5, 8, 17, 2, 76, 5,  9, 1, 28, 6, 48, 
    0, 57, 5, 57, 3, 65, 2,  8, 1, 56, 4, 22, 7, 57, 6, 90, 8, 68, 
    4, 42, 2, 62, 7, 13, 5, 11, 0,  3, 1, 35, 3, 61, 8, 11, 6, 69, 
    6, 94, 8, 41, 7, 82, 1,  7, 2, 17, 0, 97, 3, 87, 4,  7, 5,  1, 
    3, 46, 7, 50, 5, 65, 1, 32, 6, 40, 2, 87, 0, 30, 4, 76, 8,  4, 
    5,  2, 6, 14, 2, 33, 4, 52, 1, 22, 8, 33, 0, 92, 7, 31, 3, 43
  };
  const int q4755[] = {
    9, 9, // Number of jobs and machines
    0, 10, 7, 49, 4, 21, 3, 19, 8, 21, 6, 27, 1, 30, 5, 99, 2, 98, 
    2, 67, 7, 31, 6, 89, 3, 32, 0, 48, 8, 89, 1,  3, 5, 38, 4, 29, 
    8, 17, 5, 19, 4, 44, 0, 44, 1, 21, 2, 27, 7, 51, 3, 33, 6, 37, 
    6, 92, 7, 69, 1, 40, 4, 14, 0, 75, 3, 75, 8, 16, 2, 98, 5, 95, 
    4,  4, 2, 69, 3, 36, 1, 90, 6, 97, 0, 21, 7, 64, 8, 46, 5, 46, 
    0, 78, 7, 84, 5, 36, 3, 51, 6, 60, 1, 95, 4, 15, 2, 35, 8, 13, 
    8, 56, 0, 21, 7, 56, 5, 48, 1, 96, 4, 33, 3, 86, 6,  5, 2, 11, 
    2,  5, 0, 26, 4, 77, 8, 65, 3, 67, 1, 92, 5, 81, 7, 85, 6, 48, 
    1, 86, 0, 32, 7, 91, 5, 63, 3, 93, 2, 90, 8,  1, 4, 77, 6, 70
  };
  const int q4756[] = {
    9, 9, // Number of jobs and machines
    6, 74, 1, 92, 8, 23, 3, 41, 0, 73, 7, 47, 2, 49, 4, 76, 5, 50, 
    7, 76, 3, 96, 6,  3, 5, 74, 2,  1, 8, 32, 1, 68, 0, 81, 4, 27, 
    3, 12, 1, 40, 0, 62, 7, 80, 8, 79, 6, 25, 5, 73, 2, 32, 4, 35, 
    5,  4, 3,  3, 2, 97, 8, 27, 0, 79, 1, 15, 7, 97, 4, 18, 6, 17, 
    1, 20, 3, 11, 4, 45, 5, 74, 0, 65, 8, 73, 6, 87, 7, 57, 2, 27, 
    2, 73, 4, 95, 3, 93, 7, 54, 6, 67, 1, 68, 0, 96, 8, 54, 5, 38, 
    8, 23, 4, 90, 2, 23, 6, 57, 0, 89, 3, 95, 1, 82, 7, 35, 5, 29, 
    6, 27, 7, 45, 4, 27, 0, 85, 5, 97, 3, 75, 8, 31, 1, 40, 2, 39, 
    8, 24, 4, 17, 7, 73, 2, 52, 6,  8, 1, 83, 5, 49, 3, 83, 0, 39
  };
  const int q4757[] = {
    9, 9, // Number of jobs and machines
    4, 16, 0, 84, 2, 43, 3, 61, 7, 80, 8, 82, 6, 44, 1, 52, 5, 55, 
    8, 40, 0, 75, 3, 13, 5, 24, 1, 74, 6,  6, 7,  2, 4, 43, 2, 28, 
    2,  7, 0, 22, 3, 15, 7, 98, 8, 47, 1, 76, 6, 18, 4,  6, 5, 38, 
    4, 63, 3, 69, 0, 26, 5, 82, 6, 28, 1, 93, 2, 43, 8, 39, 7, 99, 
    0, 40, 5, 48, 8, 92, 2,  9, 7, 26, 6, 45, 3,  2, 1,  6, 4, 81, 
    0, 76, 8, 96, 1, 82, 4, 81, 7, 76, 3, 31, 6, 44, 2, 73, 5, 72, 
    5, 53, 2, 10, 0, 75, 1, 39, 7,  8, 8,  2, 6,  2, 3, 79, 4,  5, 
    7, 87, 0, 56, 3, 81, 8, 14, 4, 17, 6, 89, 1, 98, 5, 77, 2, 74, 
    2, 36, 1, 24, 3, 96, 6, 32, 4, 11, 8, 76, 7, 61, 5, 62, 0, 82
  };
  const int q4758[] = {
    9, 9, // Number of jobs and machines
    2, 65, 7, 35, 0, 21, 4, 42, 1, 81, 5, 88, 6, 32, 8, 14, 3, 97, 
    8, 52, 7, 88, 3, 93, 4, 17, 5, 90, 2, 63, 6, 93, 1, 77, 0, 61, 
    1, 27, 0, 89, 5, 10, 4,  1, 8, 23, 2, 87, 3, 50, 6, 55, 7, 88, 
    2,  7, 0, 82, 8, 80, 4, 18, 5,  7, 7, 22, 1, 79, 3, 59, 6, 30, 
    8, 61, 0, 94, 7, 93, 1,  4, 4, 73, 3, 82, 2,  8, 5, 41, 6, 10, 
    6,  9, 1, 97, 0, 53, 7, 90, 2, 24, 3, 71, 4, 28, 5, 86, 8, 66, 
    3, 30, 8, 15, 5, 38, 2, 48, 0, 30, 4, 88, 1, 23, 6, 86, 7, 57, 
    1, 63, 5, 73, 4, 10, 6, 21, 2, 66, 3, 93, 8, 91, 0, 45, 7, 50, 
    8, 70, 5, 27, 6, 72, 1, 12, 0, 70, 7, 30, 2, 96, 4, 55, 3, 78
  };
  const int q4759[] = {
    9, 9, // Number of jobs and machines
    8, 85, 1, 21, 0, 43, 6, 18, 7, 98, 4, 23, 2, 30, 3, 57, 5, 97, 
    3, 15, 2, 24, 6, 43, 8, 50, 7, 78, 0,  7, 5,  8, 1, 31, 4, 12, 
    8, 87, 2, 70, 7, 10, 6, 19, 1, 40, 0, 17, 4, 16, 5, 79, 3, 46, 
    1, 78, 4, 35, 6, 45, 0, 86, 8, 47, 7, 49, 2, 82, 3, 43, 5, 13, 
    0,  9, 1, 99, 3, 99, 2, 94, 6, 65, 8, 86, 7, 32, 4, 44, 5,  9, 
    0, 62, 6, 56, 4, 92, 2, 61, 8, 36, 5, 69, 1, 26, 7, 78, 3, 52, 
    2, 47, 8, 47, 1, 82, 7, 65, 6, 88, 0, 25, 4, 96, 5, 71, 3, 93, 
    7, 53, 1, 63, 4, 16, 6, 61, 0, 52, 8, 97, 5, 45, 2, 12, 3, 87, 
    8,  8, 4, 68, 5, 76, 2, 20, 0,  6, 7, 96, 1,  7, 6, 99, 3, 41
  };
  const int q4760[] = {
    9, 9, // Number of jobs and machines
    5, 44, 1, 51, 4, 97, 3,  3, 2, 65, 0, 31, 8, 33, 6, 35, 7, 86, 
    6, 84, 0, 13, 3,  9, 1, 44, 4, 70, 8, 62, 5, 74, 7, 37, 2, 33, 
    6, 60, 5, 39, 0, 61, 3, 84, 7, 98, 8, 85, 1, 94, 2, 98, 4, 43, 
    7,  8, 3, 47, 4, 31, 5, 59, 2,  9, 0, 51, 1, 47, 8, 97, 6, 38, 
    6, 85, 1, 85, 5,  8, 4, 98, 0, 28, 2, 21, 7, 13, 3, 26, 8, 31, 
    4, 81, 3, 35, 6, 82, 1, 71, 2, 35, 0, 17, 5,  8, 8, 36, 7, 39, 
    8, 58, 1, 81, 7, 47, 0,  8, 4, 53, 3, 50, 2,  5, 6, 41, 5, 97, 
    4, 85, 0, 97, 3, 90, 8, 34, 1, 13, 5, 36, 7, 18, 2, 32, 6, 70, 
    5,  3, 2,  2, 0, 92, 8, 23, 6, 31, 3, 26, 1, 99, 7, 49, 4, 31
  };
  const int q4761[] = {
    9, 9, // Number of jobs and machines
    1, 69, 0, 52, 4, 48, 3, 54, 2, 94, 6, 86, 7, 56, 5, 35, 8, 25, 
    3, 58, 8, 84, 6, 67, 0, 79, 7, 21, 5,  5, 1, 86, 4, 28, 2, 87, 
    0, 50, 2, 74, 3, 41, 7, 45, 4, 22, 1, 57, 8, 48, 5, 70, 6,  1, 
    6, 74, 5, 26, 7, 74, 4, 82, 2, 77, 1, 67, 0, 19, 3, 64, 8, 72, 
    3, 99, 1, 56, 4, 89, 6, 60, 2, 46, 8, 99, 0, 84, 7, 72, 5, 19, 
    1, 24, 4, 27, 0, 10, 6, 64, 2, 48, 7, 25, 5, 10, 3, 73, 8, 95, 
    0, 69, 6, 37, 1, 73, 5, 98, 8, 97, 7, 49, 4, 91, 3, 33, 2, 13, 
    8, 62, 3, 18, 1, 47, 5, 92, 2, 34, 6, 80, 7, 58, 0, 88, 4, 26, 
    7, 55, 2, 53, 1, 82, 8, 90, 6, 93, 0, 37, 5, 45, 3, 52, 4, 36
  };
  const int q4762[] = {
    9, 9, // Number of jobs and machines
    6, 91, 2, 90, 8, 48, 3, 62, 1, 85, 4, 77, 7,  7, 5,  7, 0, 31, 
    8, 60, 3, 24, 0, 36, 4, 24, 5, 23, 7, 55, 1, 96, 2, 21, 6, 90, 
    7, 85, 0, 51, 3, 14, 5, 81, 4, 33, 8, 85, 2, 31, 1, 29, 6, 59, 
    4, 34, 6,  1, 7, 18, 2, 15, 5, 34, 1, 62, 3, 92, 0, 70, 8, 55, 
    8, 71, 4, 22, 1, 18, 0, 28, 2,  3, 7, 87, 6,  4, 5, 29, 3, 14, 
    6, 80, 7, 87, 8, 23, 5,  8, 3, 18, 1, 10, 4, 80, 2, 44, 0, 11, 
    4, 99, 5, 13, 0, 90, 2, 95, 7, 30, 3, 70, 6, 65, 1, 64, 8, 35, 
    4,  9, 1, 78, 0, 72, 3, 50, 7, 46, 5, 60, 6, 20, 8, 41, 2, 43, 
    8, 69, 1, 31, 5, 58, 4, 41, 7, 22, 6, 15, 0, 91, 3,  3, 2,  2
  };
  const int q4763[] = {
    9, 9, // Number of jobs and machines
    5,  5, 6, 35, 3, 65, 4, 61, 2, 67, 0, 32, 7, 77, 8, 68, 1, 42, 
    1, 62, 4, 25, 5, 31, 3,  3, 7, 52, 0, 55, 8, 82, 6, 18, 2, 45, 
    5, 41, 6, 72, 0, 48, 2, 49, 4, 91, 3, 19, 7, 42, 1, 71, 8, 53, 
    1, 54, 8, 74, 5, 22, 7, 98, 3, 18, 4, 52, 0, 42, 2, 22, 6, 31, 
    4, 82, 0, 37, 3, 69, 8, 70, 7, 38, 5, 18, 1, 59, 6, 44, 2, 67, 
    0, 18, 1, 30, 2, 27, 4, 85, 6, 70, 7, 13, 3, 66, 8, 60, 5, 27, 
    2,  4, 7, 40, 3, 69, 4, 18, 6, 51, 0, 33, 8, 36, 5, 16, 1,  6, 
    1, 67, 5, 87, 0, 63, 8, 39, 4, 22, 6, 34, 2, 84, 3, 40, 7, 95, 
    2, 10, 6, 57, 3, 37, 4, 19, 8, 43, 7, 80, 1, 93, 0, 25, 5, 40
  };
  const int q4764[] = {
    9, 9, // Number of jobs and machines
    4, 67, 8, 75, 0, 62, 6, 98, 3, 42, 2, 42, 1, 34, 7, 35, 5, 10, 
    0, 40, 7, 38, 6, 92, 1,  2, 3, 55, 8, 96, 5, 32, 4,  6, 2, 90, 
    1, 66, 6, 78, 2, 97, 8, 24, 0, 88, 7, 46, 5, 90, 3, 32, 4, 23, 
    8, 61, 7, 54, 4, 33, 2, 20, 0, 82, 1, 15, 5, 60, 3,  2, 6, 36, 
    0, 86, 6, 15, 8, 50, 2, 65, 7,  3, 5,  3, 3, 37, 1, 91, 4,  7, 
    4, 41, 3, 45, 7, 52, 1, 88, 5, 55, 8,  6, 2, 55, 0, 68, 6, 15, 
    3, 32, 0, 67, 7, 91, 4, 28, 6, 75, 2, 42, 5, 48, 8, 58, 1, 50, 
    8, 93, 3, 24, 4, 25, 0, 98, 2,  5, 7, 31, 6, 29, 1, 56, 5, 30, 
    0, 88, 1, 78, 7, 63, 8, 56, 5, 72, 2, 95, 4, 98, 6, 72, 3, 45
  };
  const int q4765[] = {
    9, 9, // Number of jobs and machines
    7, 97, 0, 30, 3, 42, 2, 77, 1,  9, 8, 90, 5, 40, 6, 70, 4, 39, 
    5, 37, 2, 33, 1, 81, 8, 98, 0, 44, 3, 33, 7, 27, 4, 90, 6, 71, 
    7, 56, 5, 44, 8, 64, 0, 58, 3, 53, 4, 43, 2, 38, 1, 88, 6, 43, 
    2, 68, 4, 80, 1, 44, 8, 15, 0,  7, 3, 64, 7, 16, 6, 61, 5, 98, 
    5,  3, 3, 69, 2, 12, 0,  9, 4, 48, 6, 70, 7, 61, 8, 68, 1, 96, 
    2, 81, 1, 71, 7, 33, 8, 69, 3, 73, 6,  6, 5, 66, 4, 44, 0, 52, 
    3, 79, 1, 37, 2, 50, 8, 56, 6, 90, 7, 17, 5, 27, 4, 17, 0, 36, 
    2, 48, 7, 25, 3, 56, 8, 75, 4, 78, 6, 55, 1,  4, 5, 81, 0, 88, 
    8, 99, 2, 86, 0, 37, 6, 57, 5, 31, 7, 21, 4, 48, 3, 42, 1, 35
  };
  const int q4766[] = {
    9, 9, // Number of jobs and machines
    4, 59, 7, 71, 6, 75, 2, 30, 3, 90, 8, 90, 1, 76, 0, 13, 5, 10, 
    1, 49, 7, 61, 6, 17, 5, 61, 2, 75, 8, 21, 4, 16, 0, 33, 3, 88, 
    4, 51, 8, 90, 7, 74, 1, 64, 0, 30, 5, 62, 2, 79, 6, 14, 3, 48, 
    0, 93, 7, 24, 6, 64, 3, 59, 2, 10, 8, 62, 5, 20, 1, 18, 4, 90, 
    7, 77, 0, 29, 5,  5, 3, 45, 1, 91, 4, 31, 8, 91, 2, 56, 6, 99, 
    3, 26, 2, 59, 4, 69, 5, 41, 0, 25, 8,  2, 6, 15, 7, 48, 1, 85, 
    3, 47, 5, 95, 4, 78, 1, 78, 0, 73, 2, 69, 7, 40, 6,  3, 8, 75, 
    2, 36, 1, 99, 8, 24, 3, 32, 4, 77, 7, 29, 5, 31, 6, 66, 0, 79, 
    1, 66, 5, 37, 2, 10, 6, 43, 3, 38, 8, 47, 0, 46, 4, 63, 7, 81
  };
  const int q4767[] = {
    9, 9, // Number of jobs and machines
    3, 97, 0,  7, 7, 75, 4, 27, 6, 63, 1, 14, 2, 14, 8,  7, 5, 59, 
    0,  4, 2,  2, 4, 86, 7, 77, 8, 35, 3, 35, 1, 20, 6, 82, 5, 97, 
    8, 62, 0, 90, 2, 17, 6, 62, 4, 67, 1, 39, 5, 63, 3, 89, 7, 92, 
    5, 26, 4, 87, 2,  4, 1, 10, 7, 92, 0, 99, 8, 12, 3, 93, 6, 95, 
    8, 39, 1, 70, 7,  5, 5, 79, 4,  9, 0, 78, 2, 68, 3, 73, 6, 28, 
    2,  1, 7, 80, 1, 92, 0, 57, 4, 54, 3, 38, 6, 47, 5, 22, 8, 52, 
    5, 84, 7, 66, 4, 77, 1, 23, 2, 86, 8, 24, 3, 23, 0, 78, 6, 26, 
    8, 67, 5, 90, 6, 30, 0, 80, 7, 40, 2, 65, 4, 10, 1, 11, 3,  2, 
    1, 47, 6, 36, 4, 78, 7, 25, 5, 54, 0, 98, 2, 70, 3,  8, 8, 81
  };
  const int q4768[] = {
    9, 9, // Number of jobs and machines
    0, 38, 8, 23, 6, 44, 2, 42, 3, 35, 5, 40, 1, 78, 4, 28, 7, 32, 
    2, 54, 1, 32, 7, 56, 5, 99, 3, 62, 4,  1, 6, 68, 0, 22, 8, 89, 
    6, 42, 4, 55, 2, 66, 5, 38, 1, 14, 3,  8, 0, 58, 7, 11, 8, 43, 
    1, 47, 7, 62, 4, 70, 5,  6, 2, 60, 6, 99, 0, 24, 3,  5, 8, 65, 
    1, 44, 3,  7, 2, 52, 4, 28, 6,  2, 5, 56, 7, 36, 0, 52, 8,  9, 
    2, 11, 7, 87, 8, 37, 3, 12, 0,  6, 4, 93, 1, 15, 6, 82, 5, 50, 
    5, 39, 8, 71, 2, 34, 7, 73, 6, 52, 4, 92, 1, 68, 0, 94, 3, 93, 
    6,  4, 3, 69, 7, 64, 4, 27, 8, 84, 1, 89, 5,  8, 2, 32, 0, 48, 
    7, 52, 5, 86, 6, 70, 4, 76, 0, 42, 1, 32, 3, 11, 8,  8, 2, 40
  };
  const int q4769[] = {
    9, 9, // Number of jobs and machines
    3, 82, 7, 17, 5, 96, 2, 77, 6, 78, 8, 94, 4, 64, 1, 79, 0, 14, 
    4, 16, 7, 22, 3, 12, 6, 15, 5, 50, 2, 36, 0, 14, 1, 98, 8, 12, 
    7, 21, 8, 95, 1, 62, 3, 84, 4, 87, 2, 50, 6, 32, 0, 27, 5, 75, 
    7, 24, 8,  5, 4, 57, 5, 59, 2, 45, 6, 61, 3, 70, 1, 44, 0, 83, 
    2, 38, 5, 86, 1, 62, 8, 59, 4, 79, 3, 10, 6, 63, 7, 53, 0, 66, 
    4, 84, 2, 72, 1, 47, 7, 73, 0, 57, 6, 99, 3, 54, 8, 23, 5, 14, 
    1, 15, 7, 11, 4, 81, 2, 44, 3, 49, 0, 49, 8, 84, 6, 74, 5, 22, 
    0, 74, 2, 61, 3, 35, 7, 90, 5, 67, 1, 53, 4,  6, 6, 24, 8, 77, 
    5, 99, 3,  6, 4, 18, 2, 84, 8, 71, 0, 68, 7, 68, 1, 48, 6,  9
  };
  const int q4770[] = {
    9, 9, // Number of jobs and machines
    6, 97, 2, 58, 3, 33, 1, 30, 4, 39, 0, 63, 7, 13, 8, 29, 5, 47, 
    5, 76, 2, 94, 8, 70, 6, 78, 7, 81, 1, 79, 3, 33, 4, 53, 0, 83, 
    5, 41, 3,  6, 2, 55, 7, 28, 0, 89, 6, 70, 1, 63, 8, 33, 4, 92, 
    5, 31, 1, 24, 7, 17, 8, 49, 3, 32, 4, 50, 0, 78, 6, 21, 2,  2, 
    5, 51, 0, 97, 6, 44, 1, 56, 3, 57, 7, 24, 2, 92, 8, 99, 4,  3, 
    7, 88, 4, 77, 3, 32, 0, 13, 8, 30, 1, 59, 2, 26, 6, 51, 5, 39, 
    1, 93, 5, 26, 3, 72, 2, 11, 8, 15, 4, 85, 0, 64, 6, 23, 7, 75, 
    5, 51, 4, 63, 3, 75, 7, 67, 6, 31, 8, 42, 1,  5, 2, 83, 0, 54, 
    7, 49, 6, 72, 2, 59, 0, 88, 1, 31, 4, 83, 5, 81, 3,  7, 8, 88
  };
  const int q4771[] = {
    9, 9, // Number of jobs and machines
    7, 10, 4, 13, 2, 36, 0, 46, 6, 77, 1, 71, 5, 64, 3, 45, 8, 29, 
    7, 87, 3, 49, 8, 95, 2,  8, 1,  6, 6,  9, 0, 63, 4, 12, 5, 68, 
    6, 73, 8, 34, 5, 40, 0, 27, 7, 48, 4, 38, 2, 83, 1,  2, 3, 66, 
    2, 18, 3, 64, 6, 90, 0,  8, 4, 26, 7, 79, 5, 31, 8, 29, 1, 61, 
    3, 55, 8, 79, 4, 89, 1, 24, 0, 85, 6, 38, 2, 41, 5, 73, 7, 36, 
    8, 15, 7, 36, 6, 16, 1, 11, 0, 36, 4, 96, 2, 34, 5, 41, 3, 31, 
    6, 40, 3, 62, 0, 93, 7, 30, 4, 13, 5, 58, 1, 57, 2, 19, 8, 81, 
    8, 60, 2, 77, 7, 22, 1, 64, 0, 96, 6,  5, 4, 21, 5, 15, 3, 77, 
    5, 83, 8, 95, 3, 51, 4, 17, 6, 25, 1, 17, 0, 81, 2, 73, 7, 41
  };
  const int q4772[] = {
    9, 9, // Number of jobs and machines
    1, 71, 6, 32, 2,  6, 5, 55, 3, 61, 7, 99, 4,  1, 0, 47, 8, 88, 
    1,  1, 2, 87, 6, 82, 4, 56, 5,  6, 8, 83, 7, 52, 3, 89, 0, 86, 
    3, 95, 0,  5, 6, 49, 7, 96, 8, 61, 1, 42, 4, 15, 2, 12, 5,  4, 
    3, 47, 1, 57, 0, 18, 4, 62, 5, 19, 8, 31, 6, 85, 7, 63, 2, 11, 
    6, 37, 1, 34, 7, 27, 4, 48, 8, 73, 2, 29, 3, 94, 0, 81, 5,  6, 
    2, 31, 0, 41, 1, 73, 3, 39, 4, 72, 5, 81, 8, 76, 7, 47, 6, 32, 
    3,  8, 4, 95, 5, 50, 8, 10, 6, 91, 0, 98, 2, 50, 1, 82, 7, 15, 
    2, 41, 0, 30, 3, 28, 1, 52, 7, 81, 8, 70, 6, 19, 4, 64, 5, 43, 
    2, 59, 5,  5, 4, 57, 6, 46, 7, 29, 0, 20, 3, 55, 1, 91, 8, 78
  };
  const int q4773[] = {
    9, 9, // Number of jobs and machines
    1, 84, 4, 15, 0, 25, 3,  7, 6, 17, 2, 93, 8, 15, 7, 64, 5, 20, 
    0, 20, 2, 74, 5, 89, 4, 94, 3, 94, 8, 13, 7, 48, 1, 65, 6,  4, 
    5, 27, 8, 36, 2,  1, 1, 89, 6, 25, 7, 31, 4, 43, 3, 91, 0, 11, 
    5,  4, 3, 36, 1,  6, 7, 66, 2, 79, 4, 22, 8,  9, 6, 38, 0, 44, 
    7, 48, 1, 84, 0, 78, 3, 89, 6, 43, 5, 51, 2, 66, 8, 52, 4, 48, 
    1,  8, 2, 53, 7,  7, 8, 49, 3, 53, 6, 35, 0, 23, 4, 29, 5, 32, 
    5, 53, 8, 95, 4, 96, 1, 68, 3, 21, 2, 70, 7, 27, 0, 86, 6, 48, 
    4, 18, 3, 86, 7, 46, 0, 47, 2, 11, 5, 23, 8, 44, 1, 96, 6, 25, 
    7, 29, 3, 68, 0, 42, 5, 79, 1, 51, 2, 79, 4, 96, 8, 20, 6, 67
  };
  const int q4774[] = {
    9, 9, // Number of jobs and machines
    3, 29, 8, 97, 2, 61, 0, 77, 5, 53, 1, 22, 7, 83, 4, 62, 6, 22, 
    1, 99, 8, 20, 0, 49, 5, 10, 7, 48, 3, 89, 4, 53, 2, 82, 6, 92, 
    4, 22, 3, 20, 5,  4, 6, 58, 2, 98, 7, 17, 0, 12, 1, 65, 8, 43, 
    2, 55, 6, 92, 7, 10, 1, 39, 3, 26, 5, 40, 4,  5, 0, 20, 8, 58, 
    2,  7, 7, 75, 6, 37, 3, 21, 0, 55, 5, 89, 8, 20, 4, 53, 1, 75, 
    7, 99, 1, 51, 6, 25, 0, 49, 4, 51, 5, 91, 8, 77, 2, 96, 3, 82, 
    0, 78, 5, 48, 8, 94, 2, 95, 1, 76, 3, 55, 6,  9, 4, 58, 7, 57, 
    5, 97, 8, 59, 7, 48, 6, 86, 0, 53, 2, 51, 3, 89, 4, 19, 1, 43, 
    8, 10, 1, 17, 6,  4, 5, 28, 2, 53, 7, 45, 0, 44, 3, 64, 4, 56
  };
  const int q4775[] = {
    9, 9, // Number of jobs and machines
    3,  2, 4, 41, 5,  4, 7, 66, 2, 45, 8, 77, 1, 57, 0, 39, 6, 60, 
    7, 66, 1, 74, 4, 84, 6, 47, 0, 92, 3, 83, 5, 32, 8, 75, 2, 87, 
    6, 95, 2, 92, 7, 52, 0, 71, 3, 69, 4, 94, 1, 20, 8, 42, 5, 45, 
    5, 44, 2, 29, 8, 89, 3, 65, 4, 65, 1, 10, 7, 29, 0, 55, 6, 67, 
    4, 56, 7, 82, 8, 81, 3, 17, 2, 44, 5, 46, 6, 71, 1, 77, 0, 16, 
    1, 39, 7, 23, 0, 17, 4, 15, 8, 82, 6, 14, 2, 66, 3, 58, 5, 16, 
    0, 46, 3, 16, 2, 15, 6, 32, 1, 57, 7, 23, 5, 87, 4, 91, 8, 47, 
    6, 24, 8, 35, 4, 75, 5, 10, 0, 11, 1, 13, 3, 21, 7, 47, 2, 66, 
    8, 15, 0, 21, 7, 50, 3, 15, 6, 93, 2, 74, 5, 95, 4, 33, 1, 31
  };
  const int q4776[] = {
    9, 9, // Number of jobs and machines
    0, 51, 8, 33, 2, 11, 7, 84, 4, 66, 1, 60, 3, 47, 6, 97, 5, 25, 
    8, 60, 6, 74, 2, 29, 3, 21, 4, 58, 0, 40, 1, 48, 7, 16, 5, 89, 
    1, 56, 8, 44, 5, 38, 6, 84, 7, 26, 2, 36, 0, 91, 3, 12, 4,  2, 
    5, 76, 1, 34, 8, 72, 0, 97, 6, 76, 4, 74, 2, 67, 3, 30, 7, 35, 
    4, 41, 5, 47, 0, 26, 6, 99, 2,  7, 1, 78, 3, 35, 7, 38, 8,  5, 
    5, 45, 0, 43, 8, 77, 4, 45, 2, 68, 1, 57, 7, 29, 6, 24, 3, 46, 
    7, 71, 4, 29, 8, 71, 0,  4, 6, 57, 2, 68, 5, 41, 1, 68, 3, 90, 
    1, 26, 0, 83, 4,  5, 7, 63, 2, 62, 8,  2, 3,  7, 6, 81, 5, 64, 
    7, 33, 2,  6, 8, 61, 4, 72, 3,  2, 5, 30, 6, 82, 1, 19, 0,  8
  };
  const int q4777[] = {
    9, 9, // Number of jobs and machines
    4, 97, 2, 23, 8, 77, 5, 80, 7, 45, 0, 13, 6, 80, 1, 50, 3, 88, 
    1, 43, 8, 80, 4, 52, 7, 81, 5, 21, 3, 74, 6, 51, 2, 91, 0, 92, 
    2, 97, 4, 51, 0, 82, 1, 71, 3, 69, 8,  8, 7, 60, 5, 30, 6,  6, 
    0, 10, 3, 45, 1, 76, 2, 26, 8, 33, 7, 33, 4,  7, 5, 55, 6, 78, 
    0, 97, 1, 59, 5, 39, 2, 54, 6, 57, 3, 99, 7, 71, 4, 68, 8, 53, 
    6, 26, 0, 35, 4, 14, 2, 35, 1,  6, 5, 49, 7, 52, 3, 17, 8, 87, 
    0, 45, 4, 30, 3, 73, 8, 89, 2, 87, 7, 66, 1, 25, 5, 64, 6, 75, 
    3, 27, 4, 50, 1, 90, 5, 40, 6, 52, 0, 86, 7, 31, 8, 75, 2, 60, 
    7, 24, 2, 16, 4, 17, 6, 15, 5, 18, 1, 49, 3, 62, 0, 96, 8, 74
  };
  const int q4778[] = {
    9, 9, // Number of jobs and machines
    6, 47, 4, 57, 1, 24, 7, 36, 0, 59, 3, 91, 2, 63, 5, 73, 8, 78, 
    7, 25, 0, 96, 5,  8, 6,  1, 3, 58, 2, 69, 4, 53, 8, 33, 1, 81, 
    4,  4, 7, 56, 0, 92, 8, 44, 1, 14, 5, 82, 3, 69, 2, 12, 6, 78, 
    7, 79, 0, 13, 2, 66, 3, 59, 8, 15, 5, 84, 6, 15, 4, 79, 1, 13, 
    8, 31, 1, 89, 7, 97, 6, 91, 5, 91, 3, 34, 0, 65, 4,  5, 2, 24, 
    1, 83, 6, 28, 8, 26, 2, 21, 7, 38, 0, 77, 3, 63, 5, 80, 4, 29, 
    4, 33, 6, 64, 3,  2, 1, 71, 2, 31, 0, 98, 5,  1, 7, 91, 8, 50, 
    8, 35, 1, 27, 6, 34, 7, 29, 4, 48, 2, 12, 5,  1, 3, 80, 0, 96, 
    5, 81, 6, 88, 0, 88, 4, 90, 8,  8, 3,  4, 7, 74, 2, 16, 1, 44
  };
  const int q4779[] = {
    9, 9, // Number of jobs and machines
    8, 99, 7, 25, 6, 96, 1, 35, 3, 12, 5, 80, 0, 38, 4, 69, 2, 38, 
    2, 29, 0, 77, 4, 69, 7, 20, 1,  9, 3, 23, 5, 55, 6, 22, 8, 57, 
    4, 47, 6, 88, 5, 69, 0, 31, 3, 37, 8, 12, 2, 56, 1, 82, 7, 84, 
    0, 22, 7, 69, 5, 65, 4, 57, 8, 29, 2, 56, 6, 32, 1, 43, 3, 58, 
    4, 24, 7, 40, 5, 32, 1, 61, 2, 71, 0, 93, 6, 45, 3, 11, 8,  9, 
    7, 39, 6, 19, 0,  6, 4, 70, 5, 84, 1, 56, 3, 22, 2, 52, 8, 44, 
    2, 79, 7, 94, 3, 22, 5, 86, 8, 80, 6, 17, 1,  6, 0, 88, 4, 87, 
    3, 31, 6, 56, 8,  6, 5, 38, 0, 41, 4, 69, 2, 18, 7, 70, 1, 34, 
    4, 47, 8, 36, 5, 73, 1, 14, 7, 37, 2, 31, 3,  9, 0, 94, 6, 74
  };
  const int q4780[] = {
    9, 9, // Number of jobs and machines
    6, 80, 3, 62, 2, 33, 1, 13, 5, 81, 8, 28, 4, 85, 7, 21, 0, 46, 
    3, 66, 4, 47, 7, 75, 5, 41, 0, 68, 8, 19, 6, 26, 1, 35, 2, 79, 
    8, 99, 6, 58, 3, 98, 5, 73, 4, 35, 0, 42, 7, 15, 2,  9, 1, 21, 
    1, 67, 2, 83, 4, 56, 6, 88, 8, 65, 0, 84, 3, 33, 5, 41, 7, 90, 
    3, 84, 4, 23, 1, 22, 7, 26, 5, 51, 6, 23, 8, 77, 2, 99, 0, 64, 
    3,  2, 7,  4, 2,  5, 1, 66, 6, 51, 5, 24, 0, 68, 8, 37, 4,  6, 
    7, 93, 5, 44, 4, 33, 3, 30, 2, 93, 6, 69, 0, 56, 1, 42, 8, 19, 
    3, 36, 8, 73, 4, 52, 5, 66, 0, 28, 6, 24, 7,  7, 1, 19, 2, 51, 
    7, 26, 4, 74, 8, 75, 6, 38, 3, 29, 0, 80, 2, 49, 5, 31, 1, 76
  };
  const int q4781[] = {
    9, 9, // Number of jobs and machines
    0, 12, 7, 73, 1, 56, 3, 13, 6, 26, 8, 24, 4, 46, 5, 75, 2, 52, 
    8, 60, 3, 40, 0, 43, 2, 35, 1, 33, 5, 42, 7, 98, 4, 11, 6, 40, 
    4, 29, 1, 94, 7, 36, 8,  9, 0,  8, 6, 21, 3, 73, 5, 78, 2, 52, 
    0, 19, 6,  1, 4, 87, 3, 86, 2, 66, 8, 62, 7, 12, 5, 99, 1, 65, 
    5,  9, 6, 63, 1,  3, 4, 24, 0, 58, 8, 86, 7, 59, 3, 53, 2, 11, 
    3, 50, 5, 10, 8, 57, 2, 72, 6, 51, 1, 92, 4, 74, 0, 44, 7, 70, 
    7, 31, 3, 91, 0, 45, 6, 66, 4, 80, 8, 17, 1, 47, 2, 75, 5,  1, 
    2,  1, 8, 48, 7, 18, 0, 77, 4, 97, 5, 51, 3, 38, 1, 62, 6, 54, 
    6, 92, 1, 90, 5, 31, 0, 46, 3, 14, 8, 27, 4, 55, 2, 91, 7, 41
  };
  const int q4782[] = {
    9, 9, // Number of jobs and machines
    4, 85, 1, 13, 6, 83, 5, 41, 7, 15, 3, 78, 8, 67, 0, 36, 2, 50, 
    0, 83, 7,  9, 5, 85, 6, 51, 2, 64, 4, 78, 1, 55, 3, 42, 8, 62, 
    6, 71, 5, 20, 4, 82, 3, 66, 8, 21, 7, 41, 2, 73, 1, 61, 0, 22, 
    2,  1, 6, 26, 4, 38, 8, 57, 3, 74, 0, 80, 7, 67, 5, 40, 1,  6, 
    7, 65, 8, 42, 0, 74, 5, 25, 6, 95, 3, 37, 4, 39, 2, 98, 1, 85, 
    6, 39, 4, 67, 0, 98, 8, 39, 2, 29, 3, 79, 7, 52, 5, 67, 1, 30, 
    2, 79, 1, 89, 0, 75, 8,  5, 7, 83, 6, 83, 3, 22, 4, 33, 5, 21, 
    7,  3, 0, 88, 6, 33, 4, 63, 8, 80, 3, 59, 1, 32, 5, 83, 2, 60, 
    2,  4, 5, 76, 6, 81, 7, 97, 3, 13, 4, 32, 1, 15, 8, 28, 0, 51
  };
  const int q4783[] = {
    9, 9, // Number of jobs and machines
    2, 61, 3, 51, 5, 80, 0, 54, 1, 57, 4, 79, 6,  3, 7, 90, 8, 71, 
    8, 47, 0, 99, 6, 30, 2, 26, 1, 68, 7, 90, 5, 49, 4, 91, 3, 31, 
    4, 49, 7, 37, 6, 60, 5,  7, 1, 68, 8, 88, 0, 18, 3, 92, 2, 16, 
    6, 98, 2, 19, 4, 25, 0, 63, 3, 21, 8, 54, 1, 74, 7, 17, 5, 70, 
    6, 41, 2, 16, 1, 75, 5, 81, 0, 23, 4, 86, 8, 69, 3,  3, 7, 62, 
    6, 42, 3,  7, 1, 66, 5, 56, 2, 22, 8, 12, 0, 53, 7, 42, 4, 12, 
    0,  4, 4, 65, 8, 87, 7, 16, 1, 88, 5,  1, 2, 73, 3, 82, 6, 43, 
    8, 38, 5,  7, 2, 64, 7, 46, 4, 77, 1, 10, 0, 94, 3,  3, 6, 28, 
    4, 67, 8, 70, 6, 88, 0, 20, 2, 37, 1, 58, 7, 33, 5, 24, 3, 92
  };
  const int q4784[] = {
    9, 9, // Number of jobs and machines
    1, 84, 0, 71, 8, 37, 4, 25, 3, 20, 2, 25, 6, 82, 5,  2, 7, 76, 
    7, 87, 1, 73, 4, 34, 0, 97, 2, 42, 8,  2, 6, 41, 5,  1, 3, 39, 
    4, 32, 2, 88, 6, 49, 8, 66, 7, 27, 3, 68, 5,  8, 1, 41, 0, 15, 
    5, 19, 1, 11, 3,  1, 7, 25, 2,  5, 6,  8, 4, 56, 0, 94, 8, 72, 
    5, 59, 4, 95, 8, 81, 0, 42, 2, 52, 1, 81, 6, 57, 7, 51, 3, 31, 
    6, 27, 7,  2, 5, 75, 3, 66, 0, 97, 8, 95, 4, 23, 1, 43, 2, 30, 
    3, 30, 8, 45, 6, 75, 7, 85, 4, 34, 5, 67, 1,  2, 0, 23, 2,  2, 
    6, 67, 5, 32, 0,  7, 7, 73, 8, 22, 4, 14, 1, 91, 2, 35, 3, 55, 
    8, 84, 5, 68, 6, 20, 1, 85, 2, 63, 0, 25, 4, 59, 3,  1, 7, 10
  };
  const int q4785[] = {
    9, 9, // Number of jobs and machines
    8, 84, 0, 45, 2, 23, 5, 31, 7, 57, 3, 52, 4, 42, 1, 83, 6, 79, 
    0, 33, 2, 98, 4, 92, 1, 12, 6, 23, 8, 36, 5, 49, 3, 88, 7, 63, 
    5, 15, 2, 60, 4, 26, 3, 32, 7, 22, 0, 29, 1, 35, 6, 63, 8, 91, 
    2, 94, 7, 86, 8, 31, 6, 94, 3, 78, 5, 16, 0, 80, 4, 19, 1, 91, 
    8, 78, 2, 85, 3, 28, 4, 41, 5, 55, 0, 21, 7, 78, 1, 53, 6, 73, 
    2, 28, 7, 34, 4, 97, 3, 18, 6, 72, 1, 13, 5,  3, 0, 94, 8, 97, 
    6, 95, 1, 36, 7,  4, 8, 43, 3, 35, 4, 18, 2, 64, 0, 93, 5, 65, 
    0, 39, 2, 34, 3,  6, 5, 11, 1, 44, 8, 25, 7, 50, 4,  9, 6,  1, 
    3, 79, 7, 43, 1, 15, 4, 92, 0, 10, 5, 28, 6, 80, 2, 78, 8,  4
  };
  const int q4786[] = {
    9, 9, // Number of jobs and machines
    0, 45, 3, 76, 7, 91, 5, 54, 1, 91, 4, 13, 2, 24, 8, 49, 6, 56, 
    0, 39, 4, 78, 5,  9, 6, 48, 8, 65, 7, 96, 2, 19, 3, 72, 1, 35, 
    1, 77, 7,  7, 6,  6, 3, 12, 8, 85, 2, 38, 4, 41, 5, 80, 0, 31, 
    6,  5, 7,  5, 4,  2, 2, 35, 1, 44, 0, 88, 8, 44, 3, 71, 5, 45, 
    7, 22, 1,  7, 3, 54, 4, 28, 0,  6, 8,  9, 2, 91, 6, 87, 5, 58, 
    2, 35, 8, 65, 6, 13, 3, 92, 0, 85, 5, 32, 4, 13, 1, 14, 7, 87, 
    4, 99, 5,  4, 7, 11, 6, 10, 1, 89, 3, 57, 0, 37, 8, 98, 2,  8, 
    5, 50, 8, 29, 3, 22, 4, 81, 2, 72, 1, 52, 7, 48, 0, 76, 6, 84, 
    3,  5, 2, 98, 5, 48, 8, 23, 4, 47, 1, 80, 7, 99, 6, 17, 0, 92
  };
  const int q4787[] = {
    9, 9, // Number of jobs and machines
    3, 10, 5,  1, 2, 72, 4, 43, 7,  7, 6, 55, 0, 22, 8, 99, 1, 72, 
    6, 30, 5, 52, 4, 73, 1, 69, 8, 61, 0, 35, 7, 48, 3, 29, 2, 37, 
    6, 19, 8,  9, 0, 18, 4,  8, 3, 99, 2, 93, 5, 21, 1, 81, 7, 96, 
    1, 80, 6, 30, 5, 31, 4, 20, 8, 34, 7, 53, 0, 41, 2, 68, 3, 56, 
    7, 74, 0, 91, 5,  5, 1, 31, 4, 13, 8, 29, 2, 74, 3, 22, 6, 52, 
    2, 10, 8, 64, 3, 69, 5, 28, 0, 88, 6, 32, 7,  2, 1, 83, 4, 90, 
    8, 36, 3, 89, 5, 30, 7, 62, 2,  4, 6, 74, 1, 32, 0, 80, 4, 90, 
    2, 57, 4, 85, 1, 31, 5,  4, 8, 37, 7, 64, 6, 52, 3, 48, 0, 35, 
    6, 46, 7, 48, 0, 19, 2, 61, 8, 42, 4, 83, 3, 25, 5, 13, 1, 63
  };
  const int q4788[] = {
    9, 9, // Number of jobs and machines
    3, 25, 0, 92, 1, 10, 4, 92, 7, 84, 2, 85, 8, 73, 5, 38, 6, 10, 
    2, 27, 6, 97, 0, 28, 8, 67, 1, 35, 5, 51, 3, 68, 7, 98, 4, 81, 
    7,  3, 6, 58, 3, 80, 1, 29, 8, 94, 2,  7, 5, 13, 0, 90, 4, 92, 
    3, 68, 6, 37, 1, 45, 0, 67, 2, 45, 8, 18, 7, 13, 5, 58, 4, 47, 
    5, 45, 4, 39, 7, 24, 3, 48, 2,  6, 1, 62, 0, 31, 6, 61, 8, 50, 
    3, 40, 6, 64, 4, 44, 0,  8, 8, 52, 2, 61, 7, 95, 1, 48, 5, 98, 
    6, 26, 2, 49, 8, 94, 7, 72, 5, 95, 4,  4, 3, 95, 0,  4, 1, 11, 
    1, 53, 2,  5, 6, 98, 4, 43, 5, 84, 3, 32, 7, 41, 8, 86, 0,  5, 
    3, 54, 2, 71, 0, 69, 4, 48, 7, 52, 1, 46, 8, 48, 6, 85, 5, 17
  };
  const int q4789[] = {
    9, 9, // Number of jobs and machines
    7, 40, 1, 58, 5, 60, 3, 97, 8, 56, 2, 65, 0, 44, 4, 72, 6, 99, 
    4, 25, 5, 69, 6, 46, 2, 59, 7, 50, 1, 94, 0, 32, 8, 53, 3, 88, 
    0, 42, 5,  6, 4, 82, 2, 88, 8, 30, 3,  4, 7, 95, 6, 18, 1, 30, 
    1, 73, 5, 54, 7, 47, 0, 58, 8, 34, 4, 99, 2, 48, 6, 72, 3, 54, 
    4,  1, 0, 18, 6, 19, 8, 44, 5, 42, 1, 82, 3, 15, 2, 26, 7, 26, 
    4, 99, 2, 85, 8, 14, 1, 86, 5, 86, 7, 47, 0, 16, 3, 10, 6, 93, 
    7, 36, 2, 71, 3, 57, 0, 52, 5, 64, 6,  4, 8, 69, 4, 97, 1, 15, 
    0, 99, 6, 65, 7, 57, 3, 67, 2, 12, 4, 58, 1, 78, 5, 61, 8, 38, 
    3,  4, 8,  8, 0, 18, 4, 45, 1, 45, 7, 53, 6, 66, 2, 31, 5, 50
  };
  const int q4790[] = {
    9, 9, // Number of jobs and machines
    2,  7, 1, 29, 0,  5, 6, 13, 8, 96, 4,  1, 5, 31, 3, 65, 7, 28, 
    5, 12, 4, 58, 0, 61, 8, 65, 6, 17, 1, 54, 2, 81, 3, 81, 7, 16, 
    2, 70, 4, 63, 5, 79, 3, 25, 6, 85, 0, 86, 7,  7, 8, 11, 1, 55, 
    4,  2, 7, 55, 2, 69, 3, 21, 0,  2, 1,  7, 5, 49, 6, 36, 8, 48, 
    5,  9, 8, 13, 6, 81, 3, 12, 1, 59, 7, 73, 0, 49, 2, 10, 4, 71, 
    3,  3, 5, 43, 8, 80, 2, 73, 7, 90, 1, 58, 4, 45, 0, 66, 6,  4, 
    0, 94, 4,  6, 1, 77, 7, 26, 6, 60, 2, 42, 8, 34, 3,  1, 5, 24, 
    5, 77, 4, 16, 8, 85, 1, 48, 0, 53, 2, 54, 6, 55, 7, 74, 3, 16, 
    6, 40, 4, 15, 8, 36, 7, 45, 1, 13, 0, 69, 2, 17, 5,  6, 3, 76
  };
  const int q4791[] = {
    9, 9, // Number of jobs and machines
    1, 94, 6, 14, 7,  5, 0, 86, 3, 34, 4,  7, 8, 18, 2, 39, 5, 41, 
    1, 29, 4, 59, 5, 21, 2,  1, 8, 75, 0, 68, 3, 51, 7, 66, 6, 93, 
    2, 97, 0, 71, 3, 54, 1, 73, 6, 11, 8, 35, 4, 44, 5, 25, 7, 12, 
    1, 86, 4, 87, 0, 45, 6, 57, 5,  4, 7, 31, 3, 70, 2, 32, 8, 83, 
    1, 89, 0, 43, 5,  2, 4, 99, 3, 64, 8, 49, 7, 14, 2, 22, 6, 54, 
    0, 91, 7, 78, 8,  1, 6, 64, 5, 14, 4, 49, 3, 88, 2, 27, 1,  6, 
    0, 32, 3, 78, 1, 34, 5, 37, 6, 35, 7, 89, 4, 45, 8, 38, 2, 39, 
    7, 76, 2, 40, 1, 70, 4, 86, 3, 62, 5, 38, 8, 56, 0, 55, 6, 42, 
    0, 96, 3, 20, 6, 55, 5,  9, 4, 28, 8, 24, 1, 74, 2, 36, 7, 54
  };
  const int q4792[] = {
    9, 9, // Number of jobs and machines
    2, 52, 1, 53, 3, 82, 8, 53, 0, 82, 4, 23, 5, 55, 7, 69, 6, 31, 
    5,  3, 0, 94, 6, 42, 2,  1, 7, 93, 3, 50, 1, 19, 8,  1, 4, 18, 
    4,  9, 5, 31, 0, 92, 3,  2, 1, 66, 6, 64, 7, 92, 8, 29, 2, 40, 
    5, 50, 6, 68, 3, 31, 1, 97, 4,  1, 2, 83, 0, 11, 8, 98, 7, 35, 
    2, 12, 8, 34, 0,  9, 4, 11, 6, 18, 7, 26, 1, 97, 3, 33, 5, 16, 
    0, 74, 5, 13, 4,  1, 3, 96, 6, 14, 2, 12, 8,  9, 7, 76, 1, 67, 
    8, 17, 4, 72, 3, 68, 2, 93, 0, 76, 1,  1, 6, 41, 7, 88, 5, 78, 
    1, 10, 2, 84, 8,  9, 4, 90, 0, 89, 3, 58, 6, 92, 7, 42, 5, 12, 
    7, 62, 1, 56, 6, 27, 8, 40, 4,  9, 2,  7, 3, 43, 5, 67, 0, 36
  };
  const int q4793[] = {
    9, 9, // Number of jobs and machines
    4, 79, 1, 64, 0, 25, 6, 47, 5, 36, 2, 85, 3, 39, 8, 95, 7, 99, 
    5,  9, 4,  6, 7, 66, 6, 77, 1, 38, 2, 64, 3, 24, 0, 60, 8, 79, 
    5, 35, 1, 65, 6,  4, 7, 49, 4, 98, 3, 79, 8, 96, 0, 46, 2, 64, 
    7, 77, 0, 51, 3, 39, 4, 67, 8, 97, 6,  8, 2, 77, 1, 96, 5, 33, 
    6, 57, 8, 32, 5, 92, 1, 87, 4, 92, 3, 35, 0, 83, 2, 18, 7, 52, 
    4, 41, 5, 79, 8, 98, 6, 79, 3, 31, 1, 52, 7, 56, 0, 18, 2, 11, 
    2, 63, 6, 13, 1, 17, 5, 88, 0,  5, 7, 90, 4, 86, 3, 94, 8, 54, 
    1, 44, 2, 58, 3, 61, 6, 36, 5, 18, 0, 54, 4, 93, 7, 52, 8,  4, 
    8, 14, 7, 29, 6, 80, 5, 50, 1, 10, 3, 47, 2, 18, 0, 87, 4, 18
  };
  const int q4794[] = {
    9, 9, // Number of jobs and machines
    5, 24, 4, 61, 2, 52, 0, 36, 7, 50, 6, 45, 3, 71, 8, 49, 1, 33, 
    1, 90, 7, 10, 6, 24, 4, 58, 0, 72, 3, 55, 8, 29, 2, 24, 5, 60, 
    4, 11, 0, 57, 1, 11, 8, 95, 2, 76, 6,  1, 3, 24, 7, 62, 5, 95, 
    5, 41, 7, 79, 4, 16, 0, 17, 2, 79, 8, 33, 6, 22, 3, 81, 1, 40, 
    2, 75, 1, 41, 5,  5, 4, 18, 7, 63, 8, 82, 0, 66, 3, 98, 6, 91, 
    6, 17, 4, 11, 0, 17, 2, 17, 1, 16, 5, 34, 7, 87, 3, 55, 8, 98, 
    3, 56, 7, 35, 4,  1, 0, 22, 8, 95, 2,  6, 5, 18, 1, 18, 6, 96, 
    6, 81, 4, 72, 1, 74, 0, 29, 8, 29, 3, 62, 7, 29, 2, 32, 5, 60, 
    8, 51, 1, 71, 0, 94, 7, 32, 2, 55, 6, 80, 3, 34, 5, 17, 4, 84
  };
  const int q4795[] = {
    9, 9, // Number of jobs and machines
    4, 45, 3, 38, 7, 39, 0, 81, 6, 24, 2, 99, 1, 40, 8, 46, 5, 19, 
    5, 76, 8, 61, 3,  4, 1, 22, 4,  9, 6, 80, 2, 38, 7, 38, 0, 77, 
    5, 35, 1,  7, 4,  4, 7, 33, 0, 34, 8, 80, 6, 78, 3, 68, 2, 91, 
    7, 41, 6, 71, 2, 95, 5, 56, 3, 68, 0, 15, 8, 77, 4, 97, 1, 53, 
    8, 28, 2, 96, 6, 39, 4, 40, 0, 67, 3,  1, 7,  2, 5, 15, 1,  2, 
    5, 26, 2, 76, 0, 19, 3, 84, 6, 41, 7, 28, 4, 90, 1, 69, 8, 24, 
    4, 69, 6, 78, 5, 43, 0, 12, 8, 30, 7, 65, 3,  4, 1, 11, 2,  4, 
    2, 38, 6, 65, 7, 27, 3,  3, 5, 89, 8, 41, 1, 80, 0, 25, 4, 97, 
    0, 42, 5, 13, 4, 91, 6, 46, 1, 95, 8,  8, 7, 88, 3,  5, 2, 29
  };
  const int q4796[] = {
    9, 9, // Number of jobs and machines
    7, 32, 6, 35, 1, 14, 2, 53, 8, 26, 0, 10, 3, 35, 4,  6, 5, 97, 
    2, 30, 3, 71, 7, 34, 4, 39, 5, 82, 6, 78, 0, 95, 8, 38, 1,  9, 
    7, 80, 6, 30, 3, 34, 0, 26, 2, 64, 5, 32, 1, 87, 8, 11, 4,  6, 
    5, 97, 8, 80, 4, 66, 7,  6, 6, 51, 2, 32, 1, 20, 0, 32, 3, 93, 
    8, 47, 0, 35, 2, 92, 6, 32, 4, 84, 5, 86, 7, 48, 1, 64, 3, 83, 
    5, 70, 4,  8, 2, 98, 3, 53, 1, 86, 7, 55, 6, 50, 0, 31, 8, 22, 
    8, 25, 0, 76, 3, 38, 4, 73, 6, 56, 1, 74, 2, 98, 5, 97, 7, 96, 
    1, 59, 8, 93, 4, 98, 3, 41, 5, 59, 6, 89, 0, 51, 2, 11, 7,  5, 
    7, 24, 6, 53, 1, 86, 2, 80, 4,  5, 0, 81, 8, 96, 3, 30, 5, 32
  };
  const int q4797[] = {
    9, 9, // Number of jobs and machines
    2, 31, 8, 95, 1, 60, 7, 56, 6, 25, 0, 83, 4, 82, 3,  6, 5, 30, 
    6,  4, 4, 61, 0, 77, 8, 33, 2, 63, 1, 41, 5, 10, 7, 44, 3, 66, 
    3, 23, 4, 72, 2, 15, 0, 43, 1, 30, 5, 32, 8,  9, 6, 47, 7, 65, 
    2, 81, 5, 34, 6, 57, 8, 82, 1, 31, 7, 81, 0, 61, 3, 14, 4, 56, 
    1, 35, 3, 85, 5,  6, 7, 20, 6, 89, 8, 92, 4,  1, 2, 48, 0, 22, 
    8, 52, 4, 55, 2, 98, 0,  4, 1, 32, 5, 30, 6, 65, 3, 16, 7, 28, 
    3, 37, 4, 97, 1, 98, 7, 50, 6, 36, 0, 22, 5, 82, 2, 44, 8, 36, 
    6, 27, 0, 79, 2, 20, 5, 52, 3, 76, 8, 16, 1, 68, 7, 71, 4, 15, 
    2, 46, 1, 17, 8, 48, 4, 66, 3, 82, 5, 34, 0, 44, 6, 25, 7, 93
  };
  const int q4798[] = {
    9, 9, // Number of jobs and machines
    3, 54, 7, 52, 6, 18, 4,  7, 8, 45, 5, 28, 2, 62, 0, 63, 1, 25, 
    3, 56, 1, 82, 6, 11, 5, 89, 8, 11, 0, 32, 7, 22, 2, 38, 4,  7, 
    2,  9, 1, 28, 3, 92, 8, 43, 0, 16, 6, 39, 4, 81, 5, 59, 7, 91, 
    4, 97, 2, 69, 6, 63, 0, 53, 8, 90, 1, 51, 3, 68, 5, 25, 7, 51, 
    8, 88, 4, 73, 5, 68, 0, 17, 7, 50, 1, 58, 6, 92, 2, 13, 3,  5, 
    6, 90, 2, 18, 7, 46, 5,  9, 0, 34, 8, 36, 3,  7, 1, 36, 4, 81, 
    7, 60, 4, 90, 0, 41, 8, 30, 2, 27, 1, 46, 3,  8, 6, 63, 5, 89, 
    5, 31, 1, 43, 8, 80, 6, 39, 2, 17, 0, 39, 7, 80, 3,  5, 4, 53, 
    5, 31, 1,  5, 8, 15, 0, 61, 4, 45, 2, 50, 7, 51, 3, 92, 6, 80
  };
  const int q4799[] = {
    9, 9, // Number of jobs and machines
    3, 59, 0, 12, 7, 65, 1, 77, 2, 64, 6, 42, 5, 49, 8, 21, 4, 25, 
    1, 94, 8, 35, 7, 33, 4, 33, 6, 20, 2, 98, 3, 21, 0, 91, 5, 56, 
    5, 62, 6, 73, 7,  9, 8, 15, 4, 16, 2, 44, 0, 65, 1, 85, 3, 45, 
    0, 58, 6, 12, 1, 26, 7, 25, 3, 76, 2, 32, 5, 71, 8, 30, 4, 57, 
    5, 44, 1, 43, 2, 59, 7, 54, 0, 77, 4, 79, 3,  7, 8, 64, 6, 66, 
    5, 60, 8, 88, 0, 17, 2,  7, 3, 52, 6,  3, 1, 85, 7, 65, 4, 75, 
    2, 94, 7, 27, 3, 69, 6, 23, 8, 22, 5, 22, 0, 35, 1, 56, 4, 81, 
    1, 43, 4, 61, 8, 25, 5, 61, 3, 58, 6, 83, 2, 74, 7, 11, 0, 82, 
    6, 25, 1, 81, 3, 35, 2, 59, 7, 80, 8, 92, 5, 35, 0, 38, 4, 91
  };
  const int q4800[] = {
    9, 9, // Number of jobs and machines
    1, 60, 7, 18, 0, 12, 5, 20, 6, 22, 4, 20, 2, 43, 8, 11, 3, 30, 
    4, 94, 0, 12, 2, 45, 6, 35, 1, 18, 8, 85, 5, 99, 3, 82, 7, 28, 
    6, 95, 1, 37, 2, 47, 7, 49, 0, 79, 3, 87, 5,  7, 8, 67, 4, 43, 
    2, 27, 1, 38, 7, 14, 6, 23, 8, 69, 5, 70, 4, 88, 0, 53, 3, 77, 
    0,  2, 4, 14, 2, 26, 8, 24, 1, 71, 7, 79, 6, 18, 3, 12, 5, 54, 
    7, 84, 0, 24, 3, 32, 6, 22, 5, 34, 2, 85, 4, 36, 8,  8, 1, 30, 
    0,  7, 1, 59, 4, 11, 5, 83, 3, 40, 7, 11, 6, 91, 8, 53, 2, 89, 
    7, 69, 4, 24, 2, 12, 3, 71, 1, 93, 0, 21, 6, 29, 5,  8, 8,  8, 
    6,  7, 1, 46, 8,  8, 3,  2, 5, 28, 4, 21, 2, 98, 0,  1, 7, 37
  };
  const int q4801[] = {
    9, 9, // Number of jobs and machines
    4, 87, 6, 16, 7, 92, 3, 35, 8, 29, 0, 94, 5, 32, 2,  4, 1, 82, 
    6, 73, 7, 29, 1, 35, 2,  3, 8, 86, 3, 44, 5, 28, 4, 80, 0, 64, 
    7, 88, 6, 10, 8, 52, 4,  1, 0, 31, 2, 89, 1, 20, 3, 74, 5, 45, 
    3, 86, 6,  6, 4, 97, 7, 90, 0, 33, 1, 25, 5, 63, 8, 72, 2, 50, 
    3, 66, 2, 40, 7, 19, 8, 85, 4, 58, 5, 19, 0, 48, 6, 25, 1, 71, 
    7, 54, 2,  7, 6, 17, 8, 23, 1, 61, 3, 25, 0, 45, 5, 78, 4, 22, 
    6, 64, 7, 29, 0, 39, 3, 37, 4, 53, 2, 55, 8, 29, 1, 39, 5, 74, 
    3, 37, 7, 46, 4, 39, 0, 76, 5,  8, 6, 84, 1, 50, 8, 45, 2, 74, 
    4, 61, 0, 80, 5, 56, 6, 70, 7, 66, 2, 14, 1, 36, 3, 31, 8, 67
  };
  const int q4802[] = {
    9, 9, // Number of jobs and machines
    1, 33, 7, 31, 0, 82, 6, 35, 8, 15, 2, 81, 4, 62, 5, 36, 3, 94, 
    6, 52, 1,  4, 0, 26, 5, 18, 2, 65, 7,  6, 4, 14, 3, 17, 8, 21, 
    5, 48, 4, 44, 3, 60, 6, 42, 7, 40, 2, 31, 8, 73, 0, 90, 1, 21, 
    0, 11, 2, 96, 6, 56, 4, 34, 7, 22, 1, 37, 3, 41, 8, 86, 5, 49, 
    1, 22, 5, 59, 4, 48, 3, 71, 7, 99, 6, 32, 0, 59, 2, 33, 8, 13, 
    7, 44, 2, 49, 8, 74, 5, 60, 3, 32, 4, 39, 0,  9, 1, 88, 6,  4, 
    8, 65, 0, 26, 3, 12, 6, 79, 7, 42, 5, 93, 1, 66, 2,  7, 4, 61, 
    2, 83, 1, 53, 5, 39, 6, 95, 8, 81, 7, 43, 4, 50, 3, 22, 0, 95, 
    0,  7, 6, 83, 3, 59, 1, 48, 8, 64, 4, 54, 5, 87, 2, 20, 7, 29
  };
  const int q4803[] = {
    9, 9, // Number of jobs and machines
    7, 82, 0, 36, 3, 77, 2, 40, 5, 10, 8, 83, 6, 84, 4, 28, 1, 42, 
    7, 48, 1, 62, 8, 78, 6, 68, 2, 99, 4, 41, 0,  2, 5, 11, 3, 33, 
    0, 57, 2, 18, 3, 54, 8, 81, 6, 98, 1, 50, 5, 74, 7, 28, 4, 35, 
    8, 39, 6, 73, 4, 85, 1, 81, 5,  7, 7, 66, 0, 33, 3, 88, 2,  1, 
    8, 21, 2, 27, 6, 37, 5, 74, 7, 69, 1, 87, 0,  5, 4, 36, 3, 55, 
    0, 38, 8, 49, 6, 57, 5, 67, 2, 69, 1, 81, 4, 90, 7,  9, 3,  1, 
    5, 70, 0, 88, 3, 31, 8, 51, 7, 53, 4, 52, 1, 85, 2, 67, 6, 31, 
    4, 65, 0, 61, 6, 70, 5, 10, 8, 30, 7, 65, 2, 13, 3, 94, 1, 34, 
    8, 25, 4, 23, 7, 70, 1, 65, 0, 68, 6, 65, 3, 14, 5, 13, 2, 48
  };
  const int q4804[] = {
    9, 9, // Number of jobs and machines
    3, 70, 4, 15, 1, 13, 0, 24, 2, 28, 6, 29, 8, 32, 7, 54, 5, 13, 
    6, 68, 5, 10, 3, 14, 7, 45, 2, 62, 4, 27, 0, 36, 1,  2, 8, 16, 
    0, 17, 8, 32, 6, 25, 3, 24, 2, 23, 1, 67, 7,  5, 5, 80, 4, 22, 
    5, 27, 1, 54, 4, 79, 8,  1, 3, 65, 2, 53, 6, 41, 7,  4, 0, 65, 
    1, 60, 8, 15, 4, 62, 3,  9, 0, 86, 7,  6, 2, 41, 6, 91, 5, 81, 
    8, 73, 1, 36, 5, 83, 2, 78, 4, 53, 3, 51, 6, 91, 0, 70, 7, 58, 
    7, 76, 2,  1, 5, 69, 0, 79, 3, 89, 1, 87, 4, 35, 8, 79, 6, 64, 
    0, 29, 8, 81, 1,  4, 2, 74, 4, 50, 7, 69, 5, 16, 6, 77, 3, 17, 
    7, 49, 3,  5, 1, 50, 2, 83, 6, 65, 4, 19, 0, 66, 5, 47, 8, 94
  };
  const int q4805[] = {
    9, 9, // Number of jobs and machines
    2, 91, 1, 45, 4, 90, 3, 82, 5, 96, 8, 89, 7, 46, 6, 63, 0, 27, 
    2,  6, 4, 40, 1, 97, 5, 37, 8, 71, 3, 83, 0, 12, 6, 11, 7, 31, 
    1, 70, 5, 26, 4, 91, 6, 21, 2, 95, 8, 12, 3, 98, 7, 34, 0, 81, 
    7, 14, 8, 60, 1, 75, 6, 45, 4, 90, 2, 80, 5, 52, 0, 53, 3, 32, 
    1, 54, 6, 95, 2, 53, 4, 36, 5, 85, 0,  8, 7, 83, 3, 92, 8, 54, 
    7,  4, 1, 42, 0,  4, 4, 38, 3, 16, 2, 38, 5, 88, 6, 19, 8, 66, 
    3, 17, 4, 43, 1, 99, 7, 76, 6, 64, 8, 12, 5,  8, 2, 43, 0, 68, 
    2, 68, 3, 22, 6, 25, 5, 40, 1, 71, 4, 53, 0,  4, 7, 82, 8, 25, 
    8, 17, 1, 51, 5, 88, 2,  8, 6, 43, 3, 79, 0, 97, 4, 71, 7, 33
  };
  const int q4806[] = {
    9, 9, // Number of jobs and machines
    5,  4, 0,  5, 6,  9, 2, 91, 4, 91, 8, 69, 7, 83, 3, 22, 1, 40, 
    6, 38, 8, 36, 4, 93, 1,  1, 0, 58, 2,  5, 5, 17, 7,  8, 3, 57, 
    2, 24, 0, 46, 5, 95, 6, 93, 3, 13, 1, 67, 7, 77, 4,  5, 8,  2, 
    5,  9, 2, 80, 7, 88, 6,  7, 3, 29, 8, 62, 1, 71, 0, 67, 4, 95, 
    3, 65, 5, 80, 6, 43, 8, 72, 0, 21, 2, 26, 4, 99, 1, 75, 7, 52, 
    5, 95, 2, 53, 6, 18, 3, 45, 7,  8, 0, 94, 8, 31, 4, 34, 1, 23, 
    5, 89, 2, 47, 6, 63, 4, 88, 3, 60, 8, 16, 1, 71, 7, 39, 0, 80, 
    8, 78, 1, 64, 4, 25, 3, 90, 0, 58, 2, 80, 7, 11, 6, 20, 5, 96, 
    6, 39, 8, 76, 2, 73, 1, 30, 7, 10, 0, 88, 3, 77, 5, 75, 4, 45
  };
  const int q4807[] = {
    9, 9, // Number of jobs and machines
    0, 37, 1, 71, 5, 65, 3, 43, 6, 15, 7, 67, 2, 10, 4, 18, 8, 68, 
    3, 76, 8, 68, 2, 53, 7, 70, 0, 39, 4,  7, 5, 19, 6, 52, 1, 80, 
    8, 63, 6, 72, 7, 28, 0,  2, 3, 29, 1, 92, 2, 60, 4, 52, 5, 47, 
    8, 99, 2, 39, 4, 91, 7, 67, 0, 58, 1, 50, 3, 19, 5, 46, 6,  3, 
    4, 14, 3, 47, 1, 39, 8, 93, 6, 99, 0, 30, 2, 87, 7, 84, 5, 98, 
    2, 23, 6, 96, 4, 21, 5, 63, 1, 75, 7, 95, 8, 19, 3, 72, 0, 25, 
    7,  9, 0, 12, 1, 35, 5, 99, 8, 19, 4, 57, 6, 76, 3, 72, 2, 89, 
    7, 70, 2, 78, 4, 59, 5, 15, 1, 50, 0, 37, 3, 11, 6, 56, 8, 36, 
    2, 21, 7, 34, 0, 83, 4, 88, 3, 93, 6, 55, 5, 63, 8, 58, 1,  5
  };
  const int q4808[] = {
    9, 9, // Number of jobs and machines
    3, 64, 2, 15, 7, 62, 0, 63, 1, 99, 5, 56, 4, 82, 8, 89, 6,  7, 
    8, 14, 5, 67, 2, 93, 3, 17, 4, 87, 6, 20, 7, 34, 1, 72, 0, 25, 
    5, 92, 4, 53, 8, 24, 6, 66, 3, 91, 1, 97, 0,  3, 7, 93, 2, 34, 
    1, 60, 5, 20, 7,  9, 8, 19, 3, 51, 0,  8, 2, 95, 6, 51, 4, 92, 
    4, 84, 2, 81, 6, 52, 3, 96, 8, 24, 1, 12, 0, 33, 7, 85, 5, 88, 
    3, 86, 0, 94, 6, 33, 1, 84, 4, 75, 2, 28, 5, 49, 8, 57, 7, 98, 
    5, 42, 2, 31, 3, 87, 7, 31, 0, 64, 4, 91, 8, 40, 6, 12, 1, 61, 
    8, 56, 4,  5, 3, 48, 1, 98, 7, 61, 2,  5, 6,  5, 5, 16, 0, 39, 
    0, 88, 5, 32, 3,  7, 4, 47, 8, 81, 7, 97, 2, 29, 1, 27, 6, 27
  };
  const int q4809[] = {
    9, 9, // Number of jobs and machines
    7, 66, 2, 33, 1, 57, 3, 39, 4, 36, 8, 94, 6, 51, 5, 98, 0, 36, 
    5, 31, 0,  2, 3,  3, 6, 42, 1, 33, 2,  2, 4, 49, 7, 48, 8, 88, 
    4, 58, 8, 23, 0, 32, 5, 93, 7, 14, 1, 93, 6,  8, 2, 28, 3, 54, 
    5, 26, 2,  9, 0, 79, 6, 98, 1, 33, 7, 59, 4, 99, 8, 61, 3, 21, 
    0, 78, 6, 78, 4, 19, 1, 24, 2, 26, 8, 29, 7, 38, 3, 72, 5, 53, 
    6,  9, 4, 45, 8, 73, 7, 64, 0, 92, 2, 30, 1,  4, 3, 66, 5, 19, 
    7, 79, 8, 26, 6, 43, 3, 75, 5, 22, 0, 22, 4, 16, 1, 60, 2, 36, 
    5, 50, 7, 48, 8,  1, 6, 35, 2, 52, 0, 86, 1, 25, 4, 64, 3, 96, 
    5, 68, 0, 41, 6, 16, 3, 85, 1, 35, 7,  7, 2, 48, 8, 97, 4, 18
  };
  const int q4810[] = {
    9, 9, // Number of jobs and machines
    0,  2, 1, 14, 6, 16, 8, 82, 2, 49, 7, 94, 5, 54, 3, 43, 4, 40, 
    7, 97, 6, 90, 1, 30, 5, 21, 0, 89, 3, 63, 2, 73, 4, 21, 8,  7, 
    1, 34, 7,  5, 5, 47, 2,  5, 4,  9, 3, 55, 0, 71, 8, 24, 6, 93, 
    3, 71, 1,  4, 7, 19, 6, 77, 4,  6, 8, 29, 0, 78, 2, 47, 5, 32, 
    0, 90, 8, 39, 1, 72, 6,  3, 7, 82, 4, 44, 5, 98, 3, 94, 2, 81, 
    4,  8, 5, 96, 2, 41, 3, 25, 7, 58, 1, 37, 0, 71, 6, 20, 8, 29, 
    0, 25, 6, 56, 2, 77, 3, 99, 4, 39, 1, 80, 8, 40, 5, 96, 7,  6, 
    6, 55, 3, 81, 0, 82, 7, 74, 5,  8, 4, 82, 1, 22, 8,  9, 2, 98, 
    0, 54, 4, 55, 3, 93, 6, 24, 2, 81, 7, 92, 8, 16, 1, 11, 5, 55
  };
  const int q4811[] = {
    9, 9, // Number of jobs and machines
    6, 26, 5, 91, 4,  7, 0, 58, 2, 65, 7, 60, 1, 91, 3, 93, 8, 95, 
    2, 82, 6, 45, 1, 35, 5, 40, 3, 71, 0,  3, 4,  2, 7, 79, 8, 74, 
    4, 59, 1, 14, 6, 12, 3, 78, 8, 68, 2, 75, 5, 96, 7, 78, 0, 96, 
    0, 61, 7, 49, 4, 98, 3, 51, 1, 67, 2, 58, 6,  5, 8, 43, 5, 43, 
    6, 23, 4, 91, 8, 11, 1, 86, 7, 87, 5, 46, 2, 75, 3, 88, 0, 15, 
    3, 62, 2, 46, 1, 17, 7, 87, 0, 34, 8, 98, 6, 15, 4, 51, 5, 72, 
    0, 80, 2,  3, 5, 62, 6, 64, 3, 34, 7, 12, 8, 31, 4, 23, 1, 86, 
    3, 16, 7, 82, 0,  9, 1, 90, 2, 51, 8, 64, 5, 32, 6, 10, 4, 89, 
    1, 20, 6, 88, 8, 73, 2, 96, 7, 81, 4, 11, 3, 65, 0, 78, 5, 33
  };
  const int q4812[] = {
    9, 9, // Number of jobs and machines
    0, 96, 5, 40, 2, 24, 7, 90, 6, 43, 8, 57, 3, 41, 4, 42, 1, 60, 
    6,  4, 1, 50, 3, 27, 5, 71, 8, 37, 2, 76, 0,  9, 7, 14, 4, 23, 
    6, 77, 4, 22, 3, 25, 1, 61, 5,  5, 2, 38, 8, 74, 7, 47, 0, 33, 
    1, 85, 5,  5, 7, 79, 2, 19, 0, 90, 3, 78, 6, 16, 4, 11, 8, 70, 
    7, 58, 8, 75, 1, 14, 4, 50, 2, 96, 6, 24, 3, 50, 0, 92, 5, 83, 
    1, 77, 0, 47, 6,  8, 8, 70, 4, 28, 3, 20, 5, 30, 2, 32, 7, 76, 
    3, 64, 0, 98, 2, 13, 5, 59, 4, 99, 1, 37, 8,  2, 7, 14, 6, 44, 
    2, 59, 5, 61, 4, 34, 1,  5, 8, 73, 0, 45, 7, 21, 6, 92, 3, 89, 
    7, 80, 6, 80, 4, 90, 0, 83, 8, 91, 1, 69, 2, 25, 3, 92, 5, 74
  };
  const int q4813[] = {
    9, 9, // Number of jobs and machines
    2, 77, 1, 74, 7, 44, 0, 39, 3, 58, 4, 61, 8, 86, 5, 62, 6, 78, 
    8, 49, 5, 43, 1, 26, 3, 18, 0, 19, 6, 68, 2, 79, 7,  9, 4, 94, 
    0, 28, 8, 71, 7, 87, 2, 89, 4,  4, 6, 53, 5, 39, 1, 14, 3, 32, 
    2, 99, 7,  6, 0, 19, 3, 87, 5, 79, 1, 45, 8, 14, 4, 42, 6, 33, 
    7, 27, 4, 84, 2, 86, 8,  2, 5, 39, 1, 27, 0,  7, 3, 39, 6, 81, 
    2, 95, 5, 96, 6, 85, 3, 89, 7, 97, 1, 85, 4, 23, 0, 32, 8, 48, 
    6, 50, 5, 42, 1, 34, 4,  2, 7, 85, 3, 71, 0, 43, 8, 66, 2,  4, 
    0, 49, 8, 20, 3, 58, 7, 74, 1, 60, 5, 97, 2, 95, 4, 54, 6, 24, 
    4, 88, 6, 98, 8, 40, 3, 19, 1, 21, 0, 92, 2, 95, 5, 24, 7, 24
  };
  const int q4814[] = {
    9, 9, // Number of jobs and machines
    5, 62, 4, 62, 0,  7, 8, 32, 6, 62, 2, 12, 7, 37, 1, 98, 3, 76, 
    6, 10, 0, 37, 7, 94, 4, 61, 1, 32, 3, 62, 2, 56, 5, 28, 8, 45, 
    4, 63, 0, 63, 1, 81, 8,  1, 7, 55, 5, 95, 3, 63, 6, 34, 2, 41, 
    1, 47, 4, 12, 0, 73, 8, 10, 2, 76, 6,  2, 5, 59, 7, 58, 3, 68, 
    5, 23, 3, 67, 2, 39, 0, 29, 8, 56, 6, 91, 4, 25, 7, 61, 1, 51, 
    5, 91, 8,  5, 3, 63, 0,  6, 1, 40, 4, 95, 7, 87, 6, 37, 2, 55, 
    5, 32, 2, 98, 8, 36, 4, 66, 7, 34, 6, 83, 0,  4, 3, 86, 1, 62, 
    7, 75, 3, 11, 2, 30, 6, 96, 4, 17, 5, 15, 0,  4, 1, 82, 8, 66, 
    8,  8, 6, 35, 3, 28, 1, 32, 7, 59, 0, 62, 4, 32, 5, 45, 2, 14
  };
  const int q4815[] = {
    9, 9, // Number of jobs and machines
    1, 70, 2, 51, 5, 52, 6, 59, 8, 66, 7, 50, 4, 22, 0, 28, 3, 10, 
    7, 42, 0, 51, 8,  8, 6, 79, 1, 40, 5,  3, 2, 73, 3, 53, 4, 76, 
    7, 32, 0, 37, 4, 81, 5, 30, 3, 42, 6, 51, 2, 42, 8, 95, 1, 89, 
    3, 53, 5, 29, 0, 79, 6, 75, 8, 72, 7, 30, 2, 19, 1, 32, 4, 29, 
    2, 35, 4, 66, 5, 99, 8, 17, 0, 31, 7, 28, 1,  4, 3,  4, 6, 21, 
    6, 92, 4, 79, 5, 51, 1, 31, 8, 88, 3, 57, 0, 26, 2, 85, 7, 36, 
    5, 26, 6,  2, 3, 28, 2, 54, 7, 23, 4, 35, 8, 72, 0, 63, 1, 13, 
    5, 83, 6, 94, 7, 82, 8,  6, 2,  6, 4, 36, 3, 48, 1, 18, 0, 74, 
    0, 89, 8, 76, 2, 38, 3, 75, 5, 11, 1, 88, 4, 58, 6, 45, 7, 59
  };
  const int q4816[] = {
    9, 9, // Number of jobs and machines
    3, 70, 1, 89, 0, 24, 5, 71, 2, 64, 4, 99, 7, 52, 6, 29, 8, 19, 
    6,  5, 5, 10, 1, 90, 0, 58, 7, 91, 3, 71, 4, 27, 2, 52, 8, 74, 
    7, 56, 3, 45, 6, 32, 0, 46, 2, 94, 5,  3, 1, 82, 4, 84, 8, 62, 
    7, 63, 0, 13, 6, 43, 2, 73, 5, 21, 8, 84, 4, 37, 3, 63, 1, 42, 
    6, 43, 0, 36, 3,  7, 5, 88, 8, 23, 1, 94, 7, 28, 2, 13, 4, 34, 
    0, 99, 1, 95, 5, 49, 6, 96, 8, 95, 3, 86, 7, 33, 2,  7, 4, 15, 
    2,  9, 6,  9, 3, 95, 0, 83, 8, 23, 4, 89, 7, 31, 5, 82, 1, 90, 
    2, 16, 5, 21, 7, 25, 8, 10, 3, 67, 0, 66, 1, 38, 6, 60, 4, 11, 
    3, 22, 8,  4, 1, 79, 2, 48, 6, 40, 5, 49, 4, 81, 0, 19, 7, 71
  };
  const int q4817[] = {
    9, 9, // Number of jobs and machines
    0,  3, 1, 17, 8, 93, 4, 33, 3, 78, 7, 93, 2,  9, 6, 12, 5, 68, 
    8, 34, 0, 42, 4, 25, 5, 65, 7, 44, 2, 79, 6,  2, 3, 51, 1, 68, 
    6,  5, 1, 11, 5,  1, 8, 11, 0, 43, 3, 33, 2, 62, 7, 12, 4, 96, 
    2, 54, 1, 21, 7, 61, 8, 49, 6, 66, 5, 14, 0, 11, 3, 91, 4,  4, 
    1,  4, 4, 54, 0, 14, 3,  6, 5, 30, 8, 69, 7, 83, 2, 63, 6, 68, 
    2, 33, 5, 47, 7, 55, 1, 55, 6, 89, 3, 16, 0, 49, 4,  3, 8, 85, 
    0, 63, 4, 53, 3, 48, 1, 60, 7, 29, 6, 49, 2, 71, 8,  7, 5, 35, 
    4, 99, 7, 48, 6, 92, 5, 57, 1, 88, 3, 78, 2, 61, 0, 24, 8, 68, 
    4, 60, 2, 80, 8, 98, 1, 64, 7, 17, 0, 22, 5, 12, 3, 59, 6, 82
  };
  const int q4818[] = {
    9, 9, // Number of jobs and machines
    4, 23, 8, 69, 6, 73, 1, 90, 2, 27, 0, 45, 5,  6, 3, 89, 7,  1, 
    5, 28, 1,  9, 6, 66, 8, 86, 3, 39, 0, 65, 7, 95, 2, 87, 4, 70, 
    1, 53, 5, 30, 7, 71, 6, 44, 4, 15, 3, 98, 0, 55, 8, 45, 2,  6, 
    4, 47, 7, 84, 3, 32, 1, 63, 2, 49, 0, 12, 5, 36, 6, 55, 8, 99, 
    7, 27, 2, 64, 1, 67, 6, 90, 0, 92, 5, 65, 4,  7, 3, 48, 8, 29, 
    5,  1, 2, 63, 3, 17, 6, 42, 7, 57, 0, 42, 8,  6, 4, 29, 1, 73, 
    6, 85, 7,  3, 3, 16, 4, 34, 8,  6, 5,  1, 0, 87, 1, 36, 2, 12, 
    8, 52, 0, 18, 3, 93, 1, 95, 5, 62, 7, 67, 4, 16, 2, 14, 6, 11, 
    7,  5, 0, 96, 2, 40, 6, 11, 8, 56, 4,  4, 5, 87, 1, 98, 3, 91
  };
  const int q4819[] = {
    9, 9, // Number of jobs and machines
    3, 47, 2, 32, 7, 15, 6, 88, 8, 77, 5, 27, 1, 23, 0, 44, 4, 24, 
    7, 45, 2, 43, 5, 48, 4,  8, 1, 52, 8, 87, 6, 10, 0, 92, 3, 94, 
    7, 41, 6, 13, 2, 80, 3, 58, 8, 75, 0, 82, 1,  6, 4, 95, 5, 42, 
    6, 37, 4, 42, 3, 19, 2, 57, 5, 13, 0,  8, 1, 17, 8,  6, 7, 56, 
    8,  6, 4, 59, 2, 28, 0, 90, 5, 37, 3, 18, 7, 86, 6, 82, 1, 49, 
    3, 55, 4, 44, 2, 98, 7,  8, 0, 31, 1, 79, 8, 71, 6,  6, 5, 88, 
    5, 68, 2, 61, 0, 51, 1, 24, 6, 19, 4, 11, 8, 83, 3, 10, 7, 39, 
    4, 52, 0, 11, 3, 78, 2, 16, 5, 85, 1, 76, 8, 69, 7, 54, 6, 61, 
    1, 72, 5,  1, 7,  6, 8, 24, 4, 33, 3, 92, 0, 46, 6, 38, 2,  4
  };
  const int q4820[] = {
    9, 9, // Number of jobs and machines
    1, 75, 6, 74, 0,  5, 5, 94, 4, 90, 7, 11, 2, 92, 8, 11, 3, 30, 
    1, 63, 0, 91, 3, 74, 5, 40, 8, 45, 2,  6, 4, 73, 6, 99, 7, 30, 
    2, 26, 5, 17, 4, 93, 6, 29, 1, 90, 0, 26, 7, 86, 3, 74, 8, 63, 
    0, 52, 2, 28, 8, 50, 5,  9, 4,  9, 7, 15, 3, 72, 6,  3, 1, 83, 
    8, 11, 0, 41, 4, 96, 1, 44, 6, 89, 7, 32, 2, 85, 5, 71, 3, 28, 
    1, 29, 0, 57, 5, 57, 2, 47, 8, 40, 3, 77, 4, 33, 7, 89, 6, 87, 
    3, 98, 0,  3, 7, 34, 5, 60, 4, 81, 2, 52, 1, 12, 6, 98, 8, 87, 
    8, 69, 6,  7, 7, 44, 2,  9, 1,  3, 5, 86, 4,  3, 0, 88, 3, 27, 
    6, 61, 1, 70, 3, 40, 0, 98, 4, 80, 2, 65, 7, 32, 8, 37, 5, 65
  };
  const int q4821[] = {
    9, 9, // Number of jobs and machines
    1, 16, 0, 12, 5, 71, 3,  3, 6, 85, 7, 95, 8, 32, 4, 98, 2, 39, 
    6,  7, 0, 59, 8, 55, 2, 18, 4, 13, 1, 54, 5, 91, 3, 46, 7, 64, 
    8, 43, 5, 11, 0, 40, 6, 69, 1,  3, 7, 42, 2, 26, 3, 16, 4, 89, 
    7, 54, 5, 80, 0,  4, 2, 86, 1, 75, 8, 89, 4, 37, 6, 26, 3, 49, 
    5, 88, 8, 11, 4, 90, 7, 55, 3, 70, 1, 40, 6, 97, 2, 65, 0,  8, 
    3, 59, 7, 50, 2, 34, 4, 32, 8, 10, 1, 66, 5, 56, 0, 44, 6, 56, 
    2, 78, 4, 78, 7, 47, 5, 14, 1, 75, 8, 91, 0, 80, 6, 71, 3, 83, 
    4, 29, 7, 11, 1, 26, 6, 80, 8, 63, 3, 51, 0, 34, 5, 38, 2, 17, 
    6, 50, 3, 13, 0, 15, 2, 59, 7, 97, 8, 66, 5, 78, 4, 22, 1, 70
  };
  const int q4822[] = {
    9, 9, // Number of jobs and machines
    0, 68, 3, 52, 7, 17, 1, 91, 6, 18, 5, 71, 2, 18, 4, 59, 8, 21, 
    5, 96, 7,  1, 3, 55, 0, 75, 4, 43, 2, 52, 6, 39, 1, 44, 8, 19, 
    5, 47, 8, 29, 6, 70, 4, 54, 2, 90, 1, 88, 7, 45, 0, 72, 3, 96, 
    0, 44, 1, 38, 7, 37, 8, 10, 3, 34, 2, 19, 5, 36, 4, 81, 6, 61, 
    7,  2, 8, 79, 4, 31, 5, 46, 3, 85, 2, 16, 0, 99, 1, 46, 6,  3, 
    5, 97, 4, 29, 0, 19, 7, 71, 2, 71, 1, 99, 3, 83, 8, 86, 6, 58, 
    3,  9, 4, 86, 8, 96, 1, 49, 7, 31, 5, 32, 0, 66, 6, 30, 2,  2, 
    4, 34, 7, 11, 2, 74, 6, 81, 1, 73, 3, 56, 8, 26, 0, 68, 5, 51, 
    0, 64, 5, 31, 8, 82, 2, 35, 6, 91, 3, 19, 4, 66, 1, 20, 7, 71
  };
  const int q4823[] = {
    9, 9, // Number of jobs and machines
    3,  7, 8, 14, 0,  8, 7, 69, 4, 70, 2, 71, 6, 30, 5,  8, 1, 59, 
    0, 63, 4, 34, 6, 51, 3, 48, 2, 88, 5, 86, 1, 73, 7, 56, 8, 85, 
    6, 85, 8,  5, 2, 50, 4, 20, 0, 82, 7,  2, 5, 75, 1, 96, 3, 38, 
    7, 23, 8, 21, 5, 36, 1, 66, 2,  5, 6,  2, 4, 75, 0, 37, 3, 27, 
    0, 91, 2,  7, 6, 12, 8, 91, 5, 68, 1, 85, 3, 22, 7, 10, 4, 33, 
    5, 10, 3, 33, 2, 93, 7, 79, 8,  4, 6, 30, 4, 90, 0,  5, 1, 96, 
    0, 58, 6, 35, 3, 95, 5,  3, 2, 14, 1, 58, 4, 93, 8, 11, 7, 66, 
    4,  4, 1, 33, 3, 43, 0, 26, 6,  8, 8, 44, 5, 23, 7, 91, 2, 80, 
    2, 37, 4, 81, 3, 57, 1, 33, 7,  7, 5, 26, 6, 38, 0, 41, 8,  4
  };
  const int q4824[] = {
    9, 9, // Number of jobs and machines
    4,  6, 3, 55, 0, 55, 2, 63, 6, 88, 5, 65, 1, 71, 7, 45, 8,  4, 
    6, 14, 2, 74, 3, 61, 5, 46, 0,  6, 8, 74, 1, 58, 7, 29, 4, 63, 
    2,  6, 6,  5, 7, 82, 5, 90, 1, 34, 8, 41, 4, 58, 3,  3, 0, 32, 
    7, 91, 6, 87, 0, 22, 3, 97, 4, 62, 2, 64, 5, 10, 1, 28, 8, 10, 
    7, 20, 2, 14, 8, 91, 1, 63, 6, 18, 3, 54, 4, 35, 0, 75, 5, 31, 
    6, 19, 8, 42, 3, 30, 1, 99, 0, 21, 4, 74, 7, 53, 5, 40, 2, 86, 
    5, 94, 8, 25, 6, 60, 0, 39, 1, 40, 2, 13, 7, 39, 4,  4, 3, 56, 
    6, 21, 2, 79, 3,  6, 0, 98, 4, 92, 8, 29, 5, 33, 7, 61, 1, 89, 
    0, 12, 1, 96, 4, 73, 7, 74, 8, 56, 6, 71, 2, 34, 5, 16, 3, 50
  };
  const int q4825[] = {
    9, 9, // Number of jobs and machines
    4, 69, 6, 25, 2, 70, 8, 63, 5, 76, 0, 41, 7, 72, 1, 37, 3, 97, 
    5, 41, 7, 64, 4, 60, 0, 86, 3, 44, 1, 45, 6, 99, 8, 11, 2, 61, 
    1, 32, 7,  2, 8, 59, 0,  1, 6, 73, 5, 19, 3, 88, 2, 11, 4,  7, 
    8, 49, 7, 23, 1, 84, 0, 79, 6, 56, 3, 98, 5, 23, 2,  3, 4, 61, 
    0, 26, 1, 44, 8, 21, 2, 25, 5, 85, 7, 90, 4,  2, 3, 64, 6, 95, 
    5, 97, 4, 23, 6, 88, 1,  2, 2, 93, 8, 80, 0, 18, 3,  7, 7, 67, 
    4,  7, 7, 40, 2, 13, 5, 14, 1, 58, 6, 84, 3, 73, 8, 90, 0, 72, 
    0, 34, 8, 44, 6, 43, 2, 90, 4, 74, 7, 48, 3, 75, 1, 72, 5, 97, 
    1, 37, 3, 17, 0,  5, 7, 55, 8,  4, 6, 23, 5, 28, 2, 62, 4, 12
  };
  const int q4826[] = {
    9, 9, // Number of jobs and machines
    7, 75, 4, 93, 8,  8, 6, 72, 0,  2, 3, 35, 2, 22, 5, 43, 1, 90, 
    4, 82, 6,  1, 8,  9, 0,  7, 3, 66, 7, 20, 1, 28, 2, 76, 5, 59, 
    8, 98, 7, 82, 4, 72, 5, 69, 2, 58, 0, 55, 3, 85, 6, 11, 1, 52, 
    1, 47, 0, 46, 3, 44, 8, 15, 2,  7, 6, 70, 4, 16, 7, 26, 5, 94, 
    0,  8, 5,  9, 3, 64, 1, 54, 6,  7, 8,  1, 4, 16, 2, 54, 7, 35, 
    7, 75, 6,  8, 5, 25, 4, 44, 1, 56, 8, 87, 3, 36, 2, 88, 0, 92, 
    8, 58, 1, 74, 3, 96, 7, 76, 5, 49, 6, 88, 4, 56, 2, 89, 0, 40, 
    7, 44, 6, 21, 1, 40, 3, 47, 2, 86, 8, 11, 5, 82, 4, 59, 0, 72, 
    8, 30, 3, 61, 7, 73, 6, 72, 0, 81, 5, 56, 2, 38, 4, 17, 1, 31
  };
  const int q4827[] = {
    9, 9, // Number of jobs and machines
    8, 71, 5, 80, 1,  2, 2, 57, 3, 46, 4, 21, 7, 80, 6, 50, 0,  1, 
    1, 55, 7, 19, 4, 17, 8, 43, 3,  1, 6, 99, 2, 87, 0, 43, 5,  7, 
    6,  7, 1, 62, 0, 99, 5,  2, 2, 92, 8, 50, 3,  3, 4,  5, 7, 54, 
    8, 57, 1, 36, 0,  4, 3, 85, 4, 30, 5, 52, 7, 65, 2, 26, 6, 20, 
    4, 19, 1, 93, 6, 29, 0, 73, 8, 28, 3, 84, 2, 82, 5, 75, 7, 11, 
    1, 11, 5, 15, 6, 56, 4, 90, 3, 15, 8, 21, 7, 33, 0, 23, 2, 92, 
    4, 16, 5, 47, 0, 11, 3, 34, 8,  1, 7, 60, 1, 99, 6,  2, 2, 33, 
    6, 27, 4, 15, 7, 19, 2, 20, 1, 83, 8, 23, 0, 51, 5, 65, 3, 31, 
    3, 23, 6, 73, 0, 26, 5, 89, 8, 62, 2, 20, 4, 75, 1, 94, 7, 38
  };
  const int q4828[] = {
    9, 9, // Number of jobs and machines
    0, 66, 2, 19, 5,  3, 6, 64, 1, 61, 7, 90, 8, 11, 4, 88, 3, 17, 
    3, 39, 2, 85, 7, 98, 5, 41, 0, 37, 8, 50, 6, 68, 4, 15, 1,  7, 
    8, 11, 4,  6, 0,  4, 5, 63, 3, 29, 2, 35, 6, 23, 1, 89, 7, 80, 
    4, 32, 5,  9, 0, 89, 1, 72, 8, 10, 3, 72, 6, 17, 2, 33, 7, 14, 
    3, 28, 4, 55, 6, 88, 2,  1, 7,  9, 0, 49, 8, 83, 1, 16, 5, 34, 
    0, 78, 5, 32, 2,  4, 3, 16, 1, 12, 8, 16, 6, 40, 4, 97, 7, 76, 
    7, 85, 2, 82, 8, 26, 3, 31, 6, 41, 4, 16, 0, 30, 5, 35, 1, 22, 
    4, 66, 2,  9, 7, 95, 0, 87, 5, 56, 6, 59, 3, 26, 1, 84, 8, 85, 
    8, 83, 2, 64, 4, 89, 0, 55, 1, 79, 5,  5, 3, 68, 7, 69, 6,  7
  };
  const int q4829[] = {
    9, 9, // Number of jobs and machines
    7, 70, 1,  9, 5, 41, 0, 28, 2, 92, 3, 92, 6, 67, 4, 73, 8, 46, 
    7, 87, 2, 61, 8, 31, 4, 91, 5, 74, 6, 10, 0, 48, 1, 10, 3, 57, 
    0, 57, 1, 90, 5, 21, 8, 48, 6, 13, 3, 62, 2, 96, 7, 17, 4, 77, 
    7, 84, 5, 25, 6, 13, 8, 99, 1, 46, 4, 65, 0, 82, 3, 71, 2, 86, 
    4, 45, 6, 31, 7, 34, 1, 35, 5, 12, 3, 90, 8, 44, 2, 68, 0, 44, 
    5, 53, 4, 67, 7, 60, 8, 17, 6, 88, 1, 26, 0, 78, 3,  7, 2, 32, 
    3, 37, 7, 12, 0, 93, 1, 34, 4, 78, 8, 54, 6, 67, 5, 76, 2, 90, 
    8, 16, 5, 25, 0, 43, 2, 93, 1, 84, 3, 87, 4, 37, 7, 67, 6, 77, 
    7, 47, 4,  6, 1, 20, 0, 26, 6, 67, 2, 91, 5, 49, 8, 61, 3, 51
  };
  const int q4830[] = {
    9, 9, // Number of jobs and machines
    2, 95, 1, 28, 0, 66, 7, 21, 6, 46, 5,  5, 3, 34, 8,  6, 4, 74, 
    8, 31, 5, 38, 7, 34, 2, 74, 3, 89, 1, 18, 4, 31, 0, 75, 6, 34, 
    5, 58, 0, 80, 6, 91, 3, 85, 4, 70, 7, 58, 2, 28, 1, 19, 8, 56, 
    1, 30, 7, 29, 5, 81, 4, 83, 3, 46, 6, 39, 2, 94, 0, 91, 8, 31, 
    0, 91, 8, 59, 1, 45, 3, 16, 5, 46, 6, 76, 2, 78, 4, 70, 7, 42, 
    6, 57, 3, 53, 7, 76, 2, 20, 5, 93, 1, 62, 8,  1, 0, 84, 4, 78, 
    1, 50, 7,  9, 0, 98, 5, 20, 6, 78, 8, 16, 2, 87, 4, 35, 3, 34, 
    5,  9, 8, 66, 3, 88, 1, 18, 7, 61, 0, 45, 4, 91, 2, 63, 6, 55, 
    2, 15, 6, 26, 1, 19, 3, 49, 7, 51, 0,  8, 5, 17, 8, 61, 4, 61
  };
  const int q4831[] = {
    9, 9, // Number of jobs and machines
    8, 95, 0, 46, 5, 62, 1, 61, 4, 19, 2, 86, 7, 11, 6, 40, 3, 92, 
    5, 87, 1, 12, 6, 33, 3, 22, 7, 38, 4, 87, 0, 36, 2, 61, 8, 56, 
    2, 11, 4, 68, 1,  9, 7, 13, 5, 56, 8, 56, 0, 14, 3, 83, 6, 24, 
    5, 85, 8, 45, 4, 50, 3, 56, 2, 91, 1, 94, 7, 29, 6, 93, 0, 30, 
    5, 60, 1,  6, 0, 82, 2, 86, 7, 79, 6, 48, 4, 52, 8, 64, 3, 35, 
    7, 83, 0, 93, 6, 26, 8, 50, 3, 24, 2, 54, 4, 21, 1, 96, 5, 56, 
    2, 56, 6, 72, 8, 83, 3, 38, 0, 42, 7, 99, 5, 17, 1, 77, 4, 28, 
    0, 95, 5, 22, 6, 54, 8, 55, 7, 58, 3, 42, 2,  3, 1, 56, 4, 64, 
    5,  2, 0, 55, 1,  5, 8, 57, 3, 61, 6, 25, 7, 81, 2, 15, 4, 90
  };
  const int q4832[] = {
    9, 9, // Number of jobs and machines
    7, 20, 8, 41, 1, 37, 4, 99, 3, 79, 6, 90, 0, 95, 2, 73, 5, 24, 
    3, 78, 0, 31, 8, 23, 4, 70, 1, 86, 7, 30, 6, 30, 2, 24, 5, 64, 
    2, 41, 3, 68, 4, 27, 6, 55, 1,  7, 7, 31, 8, 22, 5, 32, 0, 47, 
    4, 51, 2, 83, 8, 61, 7, 15, 5, 94, 3, 21, 6, 23, 1, 69, 0, 46, 
    4, 85, 6, 66, 2, 61, 5, 28, 0, 76, 1, 53, 8, 26, 3,  5, 7, 60, 
    7, 54, 1, 33, 3, 75, 0, 35, 2, 63, 5, 24, 6, 12, 8, 41, 4, 71, 
    2, 81, 5, 96, 3, 61, 4, 90, 8, 20, 7,  8, 0, 17, 6, 91, 1, 20, 
    0, 18, 4, 19, 5, 17, 8, 54, 2, 38, 6,  8, 7,  4, 1, 22, 3, 76, 
    6, 28, 5, 36, 8, 21, 3, 77, 7, 67, 1, 34, 4, 88, 2,  9, 0, 52
  };
  const int q4833[] = {
    9, 9, // Number of jobs and machines
    8, 40, 1, 41, 5, 57, 2, 10, 4, 67, 6, 42, 7, 34, 0, 27, 3, 47, 
    3, 56, 7, 49, 6, 50, 8, 41, 2, 76, 5,  9, 1,  3, 4, 17, 0, 71, 
    7, 41, 1, 88, 8, 38, 2, 47, 3, 75, 4, 51, 0, 22, 6, 41, 5, 78, 
    7, 20, 5, 45, 2, 99, 3, 38, 1, 18, 4, 74, 8,  4, 6, 56, 0, 30, 
    1, 37, 7, 87, 3, 18, 0, 30, 5, 60, 6, 83, 8, 38, 2, 79, 4, 35, 
    1, 65, 2, 59, 7, 40, 3,  4, 5, 27, 6,  7, 8, 42, 0, 38, 4, 94, 
    7, 22, 3, 53, 0, 55, 4, 52, 1, 46, 8, 19, 5, 44, 2, 42, 6, 33, 
    8, 58, 5, 77, 0, 23, 2, 56, 1, 92, 6, 79, 7, 60, 3, 26, 4,  1, 
    1, 17, 8, 42, 4, 22, 3, 44, 6, 44, 7, 49, 2, 95, 0, 33, 5, 24
  };
  const int q4834[] = {
    9, 9, // Number of jobs and machines
    5, 67, 4, 33, 3,  8, 0, 59, 8, 19, 1, 87, 2, 12, 7, 39, 6, 32, 
    8, 91, 6, 25, 3, 13, 0, 53, 7, 23, 4,  6, 1, 30, 5, 29, 2,  5, 
    1, 53, 5, 69, 8, 73, 4, 56, 7, 47, 0, 83, 3, 80, 2, 79, 6, 81, 
    0, 39, 5, 52, 3, 31, 2, 18, 4, 45, 8, 36, 6, 27, 1, 19, 7, 33, 
    4, 98, 5, 86, 3, 82, 6, 25, 0, 26, 2,  5, 1, 75, 8, 23, 7, 15, 
    0, 70, 2, 77, 1, 82, 3, 80, 4, 40, 7, 45, 6, 97, 8, 73, 5,  5, 
    8, 38, 3, 39, 6,  4, 0, 59, 2, 67, 7, 15, 1, 61, 5, 72, 4, 58, 
    2, 93, 6,  5, 0, 26, 5,  8, 8, 33, 1, 12, 7, 92, 3, 99, 4, 92, 
    4, 70, 5, 23, 2, 54, 1, 59, 0, 16, 6, 34, 3, 96, 7, 51, 8, 44
  };
  const int q4835[] = {
    9, 9, // Number of jobs and machines
    1, 99, 6, 13, 2, 57, 3, 38, 7, 96, 4, 34, 5, 23, 8, 78, 0, 65, 
    5, 99, 1, 36, 8, 48, 6, 20, 0, 18, 2, 61, 4, 70, 3, 71, 7, 38, 
    6, 49, 0, 75, 5,  4, 1, 90, 3, 69, 7,  3, 8, 71, 4,  5, 2, 20, 
    7,  4, 8, 66, 1, 34, 3, 31, 4, 50, 6, 63, 0, 12, 5, 47, 2,  6, 
    1, 44, 6, 82, 4,  8, 8, 48, 7, 86, 3, 54, 0,  4, 5, 24, 2, 59, 
    0, 13, 5, 86, 6, 38, 4, 58, 1, 64, 3, 48, 2, 50, 8, 85, 7, 87, 
    8, 34, 1, 61, 0, 82, 3,  2, 7, 97, 2, 29, 4, 95, 6,  7, 5, 10, 
    2, 84, 1, 48, 7, 78, 3, 91, 8,  3, 5, 45, 6, 68, 4, 23, 0, 64, 
    6, 13, 7, 30, 0, 99, 1, 30, 4, 68, 2,  2, 8, 57, 3, 15, 5, 51
  };
  const int q4836[] = {
    9, 9, // Number of jobs and machines
    0, 33, 6, 11, 2,  1, 5, 38, 4, 93, 8, 46, 1, 97, 3, 50, 7,  3, 
    4, 61, 7, 67, 0, 71, 8, 46, 2, 36, 1, 78, 5, 84, 6, 84, 3, 42, 
    7, 73, 5, 77, 1, 49, 0, 39, 8, 90, 4, 80, 6, 39, 3, 86, 2, 11, 
    3,  3, 0, 22, 4, 41, 7, 98, 8, 55, 5, 94, 2, 25, 1, 53, 6, 31, 
    1, 50, 4, 18, 5, 77, 7, 23, 8, 40, 2,  4, 0, 86, 6, 25, 3, 72, 
    4, 49, 6, 48, 5,  4, 1, 62, 8, 35, 7, 49, 0, 87, 3,  6, 2, 90, 
    8, 98, 6, 76, 7,  1, 4, 56, 1,  1, 0, 41, 3, 35, 5, 36, 2, 91, 
    3, 93, 6, 40, 5, 87, 4, 42, 0, 13, 7, 71, 1, 12, 2, 99, 8, 24, 
    1, 88, 2, 54, 8,  6, 5, 77, 3, 15, 6, 39, 7,  1, 4, 11, 0, 83
  };
  const int q4837[] = {
    9, 9, // Number of jobs and machines
    6, 36, 8, 49, 4, 17, 2,  3, 1, 46, 3, 93, 5, 16, 7, 40, 0, 54, 
    6, 27, 7, 34, 4, 27, 2, 56, 5, 33, 8, 98, 3, 67, 1, 93, 0, 10, 
    8, 17, 6, 34, 5, 25, 2, 99, 7, 31, 3, 35, 4, 89, 0, 58, 1, 78, 
    3, 60, 0, 95, 6, 84, 8, 79, 7, 75, 5, 30, 4, 10, 1, 14, 2,  4, 
    7, 62, 0, 37, 5, 70, 4, 68, 1, 54, 6, 61, 2, 53, 8, 32, 3, 54, 
    2,  6, 0, 40, 6, 59, 4, 60, 5, 50, 7, 24, 8, 74, 1, 16, 3, 26, 
    8, 37, 5, 18, 4, 21, 7, 21, 6, 83, 0, 20, 3, 66, 1, 36, 2, 21, 
    7, 17, 3, 71, 6, 33, 0, 46, 8,  6, 2, 21, 5, 59, 1, 13, 4, 64, 
    6, 58, 8, 79, 2, 88, 1, 83, 0, 52, 5, 46, 4, 40, 7, 58, 3, 55
  };
  const int q4838[] = {
    9, 9, // Number of jobs and machines
    8, 89, 1, 56, 6, 68, 7, 85, 3, 81, 0, 45, 4, 95, 5, 38, 2, 98, 
    1,  4, 8, 26, 5, 85, 0,  9, 7, 61, 2, 86, 6, 31, 4, 32, 3, 64, 
    8, 72, 1, 82, 5, 39, 2, 16, 7, 83, 4, 36, 3, 57, 0, 91, 6, 47, 
    6, 52, 2, 27, 1, 67, 4, 79, 7, 37, 5, 91, 0, 42, 3, 90, 8, 99, 
    3, 53, 6, 72, 1, 66, 5, 11, 0,  1, 8, 96, 2, 40, 4,  9, 7, 27, 
    2, 92, 0,  9, 3, 60, 4, 55, 7, 42, 6, 80, 1, 44, 8, 82, 5, 35, 
    8, 46, 3,  2, 0, 89, 1, 92, 5, 11, 6,  6, 2,  2, 4, 85, 7, 95, 
    3, 86, 1, 82, 7, 14, 2, 84, 0, 75, 5, 11, 8, 61, 4, 30, 6, 60, 
    7, 61, 8, 30, 3, 42, 0, 30, 6, 87, 2, 10, 5, 69, 1, 73, 4, 14
  };
  const int q4839[] = {
    9, 9, // Number of jobs and machines
    6, 79, 1, 31, 4, 77, 0, 33, 2,  5, 8, 38, 7, 28, 3, 41, 5, 23, 
    6, 84, 0, 85, 1, 88, 2, 94, 7, 94, 4, 19, 3, 80, 5, 73, 8, 94, 
    4, 64, 5, 20, 6, 81, 1, 99, 8, 84, 7, 99, 2, 31, 3, 83, 0, 35, 
    0, 57, 7, 25, 2, 24, 4, 84, 5,  4, 6, 10, 1, 45, 3, 30, 8, 67, 
    0,  3, 7, 29, 2, 47, 1, 67, 6, 90, 4, 30, 8, 74, 3, 63, 5, 58, 
    2, 19, 5, 11, 4, 41, 7, 58, 3, 51, 6, 81, 0, 41, 8, 88, 1, 62, 
    1, 28, 0, 62, 6, 85, 3, 82, 2, 99, 7, 72, 4, 82, 5, 41, 8, 48, 
    0, 16, 4, 59, 5, 17, 2, 17, 8, 13, 1, 70, 7, 42, 6, 30, 3, 37, 
    2, 71, 1, 92, 0, 47, 4, 36, 3, 49, 6, 17, 8, 15, 7, 83, 5, 53
  };
  const int q4840[] = {
    9, 9, // Number of jobs and machines
    1, 64, 5, 48, 3, 68, 4, 35, 7, 54, 2, 88, 6, 64, 0, 42, 8, 44, 
    0, 26, 7, 72, 5, 90, 4, 69, 8, 77, 6, 92, 1, 44, 2, 52, 3, 31, 
    0, 79, 2, 63, 3, 36, 1, 79, 7, 78, 4, 60, 5, 43, 8, 20, 6, 85, 
    0, 26, 8, 61, 7, 10, 2, 52, 4, 97, 3, 73, 5, 52, 6, 27, 1, 95, 
    8, 44, 0, 73, 6,  5, 5, 77, 1, 99, 7,  6, 2, 87, 4, 60, 3, 82, 
    0,  6, 1, 58, 5, 80, 4, 87, 6, 88, 7, 67, 8, 85, 3, 12, 2, 14, 
    2, 84, 3, 55, 7, 58, 1, 93, 6, 46, 4, 83, 0, 73, 8, 25, 5, 12, 
    7, 10, 3, 99, 5, 54, 2, 61, 0, 28, 6, 84, 1, 98, 4, 76, 8, 59, 
    0, 87, 2, 70, 7, 68, 6, 56, 4, 34, 5, 57, 3, 83, 8, 13, 1, 19
  };
  const int q4841[] = {
    9, 9, // Number of jobs and machines
    1, 63, 3, 52, 5, 46, 7, 81, 4, 89, 2, 87, 6, 52, 0, 86, 8, 48, 
    2, 21, 3, 87, 4, 91, 7, 91, 1, 60, 6,  7, 8, 37, 5,  9, 0, 96, 
    2, 26, 4, 17, 6, 15, 5, 96, 0, 77, 8, 55, 7, 40, 1, 58, 3, 63, 
    8,  3, 4, 29, 3,  4, 5, 89, 6, 42, 1, 48, 0, 97, 7, 69, 2, 84, 
    5, 55, 8, 70, 7, 85, 1, 64, 6, 80, 2, 30, 0, 71, 3, 30, 4, 74, 
    1, 44, 8, 19, 0, 58, 7, 91, 2, 24, 4, 38, 6, 59, 5, 42, 3, 27, 
    7, 58, 5, 28, 3, 79, 1, 31, 0, 63, 8, 96, 2, 65, 4, 17, 6, 23, 
    0, 62, 7,  8, 3, 91, 5,  7, 4, 43, 1, 70, 6,  6, 2, 14, 8, 87, 
    7, 94, 6, 46, 3, 12, 0, 63, 1,  9, 5, 19, 4, 58, 2, 89, 8,  6
  };
  const int q4842[] = {
    9, 9, // Number of jobs and machines
    3, 93, 1, 72, 0, 10, 6,  3, 8, 90, 5, 45, 2, 29, 7, 86, 4, 43, 
    0, 18, 6,  2, 8,  4, 4, 18, 5, 88, 7, 33, 2, 18, 3, 66, 1, 43, 
    7, 26, 5, 24, 4, 21, 3, 72, 0, 35, 8, 66, 1, 86, 2, 33, 6, 35, 
    4, 81, 3,  4, 2, 46, 8, 61, 7, 82, 0, 10, 5, 87, 1, 17, 6, 90, 
    3, 23, 4, 32, 7, 50, 1, 75, 0, 29, 5, 41, 2, 48, 6, 47, 8, 78, 
    2, 70, 1, 24, 5,  7, 4, 73, 7, 12, 8, 66, 0, 92, 3, 13, 6, 74, 
    7, 55, 2, 74, 8,  5, 0, 13, 6,  1, 3, 37, 1, 35, 4, 64, 5,  7, 
    3, 11, 6, 71, 8,  5, 1, 70, 0, 42, 7, 65, 4, 95, 5,  3, 2, 59, 
    4,  8, 2, 88, 7, 22, 1, 71, 5, 24, 0, 24, 8, 49, 6, 44, 3, 16
  };
  const int q4843[] = {
    9, 9, // Number of jobs and machines
    4, 21, 7, 58, 1, 49, 3, 13, 8, 28, 5, 77, 6,  1, 0, 97, 2, 51, 
    1, 63, 6, 90, 4, 72, 3, 63, 2,  9, 0, 35, 8, 40, 7,  3, 5, 25, 
    2, 91, 0, 98, 7,  6, 3, 40, 4, 97, 6, 39, 5, 16, 8, 91, 1, 29, 
    4, 14, 3, 55, 1, 90, 6, 96, 2, 29, 8, 57, 0,  5, 7, 48, 5,  2, 
    6, 20, 2,  4, 8, 58, 1, 62, 7, 98, 3, 50, 0, 52, 4, 48, 5, 46, 
    8, 29, 5, 83, 6,  7, 0, 87, 4, 31, 2, 35, 7, 55, 3, 96, 1, 37, 
    7, 86, 3, 74, 0, 59, 1, 24, 6, 37, 8, 42, 2, 58, 5, 53, 4, 44, 
    2, 85, 4, 88, 7, 87, 5, 71, 0, 86, 1, 54, 6, 22, 8, 18, 3, 41, 
    4, 27, 2, 22, 5, 49, 7, 39, 0, 98, 1, 18, 6, 92, 8, 47, 3, 54
  };
  const int q4844[] = {
    9, 9, // Number of jobs and machines
    1, 23, 0, 72, 7, 86, 3, 17, 8, 60, 2, 83, 5, 11, 6, 49, 4,  6, 
    5, 91, 2,  9, 1, 38, 4, 26, 8, 52, 0, 94, 3, 82, 7, 96, 6,  3, 
    5,  5, 3, 50, 6, 11, 2, 58, 0, 42, 1, 27, 8, 34, 4, 54, 7, 20, 
    4, 80, 1, 48, 2, 40, 3, 83, 6, 95, 5, 84, 0, 97, 7, 46, 8, 71, 
    6, 12, 8, 21, 1, 47, 2, 66, 7, 50, 4, 51, 3, 82, 0, 31, 5, 72, 
    6, 96, 3, 17, 1, 55, 0, 11, 4, 40, 7, 25, 8, 77, 2, 82, 5, 50, 
    0, 37, 2, 43, 3, 65, 8, 29, 5, 75, 7, 55, 6, 87, 4, 97, 1, 62, 
    3, 62, 0, 46, 2, 95, 5, 42, 8, 75, 4, 75, 6, 43, 7, 85, 1, 69, 
    3, 29, 7, 43, 6, 30, 4,  6, 1, 61, 0, 30, 8, 59, 2, 49, 5, 24
  };
  const int q4845[] = {
    9, 9, // Number of jobs and machines
    3, 26, 0, 89, 8, 99, 6, 18, 2,  9, 5, 56, 4, 70, 1,  7, 7, 79, 
    8, 85, 0, 43, 4, 47, 6,  7, 1, 85, 7,  7, 2, 22, 3, 79, 5, 52, 
    6, 57, 1, 39, 4, 95, 0, 63, 5, 67, 8, 41, 2, 13, 7, 11, 3, 49, 
    8, 13, 1,  1, 5, 72, 4, 53, 6, 84, 7,  6, 3, 75, 2, 18, 0, 32, 
    8, 24, 7, 44, 3, 96, 1, 46, 6, 65, 0, 81, 4, 18, 2, 55, 5, 35, 
    4, 74, 7, 85, 1,  1, 8, 19, 6, 43, 2, 49, 0, 32, 3, 18, 5, 58, 
    1,  6, 2, 74, 7, 98, 5, 70, 4, 32, 3, 13, 6, 63, 8, 55, 0, 77, 
    2, 37, 4, 87, 5, 36, 1, 70, 3, 72, 8, 98, 0, 52, 6,  5, 7, 90, 
    0, 97, 8, 63, 5, 57, 4, 47, 3,  7, 1, 45, 7, 79, 2,  8, 6, 49
  };
  const int q4846[] = {
    9, 9, // Number of jobs and machines
    8, 36, 5, 62, 2, 44, 3, 55, 7, 95, 4,  4, 1, 80, 0, 64, 6, 65, 
    2,  1, 1, 52, 6,  6, 3, 85, 8, 32, 5, 24, 0, 91, 7, 14, 4, 48, 
    3, 34, 6, 68, 2, 86, 1, 95, 5, 55, 7, 99, 4, 59, 8, 61, 0, 33, 
    1, 22, 8, 55, 7, 20, 5, 42, 0, 34, 3, 68, 2,  4, 4, 14, 6,  4, 
    8,  2, 6, 30, 1, 70, 4, 13, 3, 14, 0, 82, 2, 84, 5, 45, 7, 97, 
    8, 72, 5, 34, 0, 12, 7,  3, 2, 77, 4, 40, 6, 66, 1, 70, 3, 73, 
    4,  8, 8, 64, 6, 16, 5, 26, 2, 43, 7, 17, 3, 92, 0, 19, 1, 72, 
    6,  6, 7, 58, 2, 14, 8, 65, 1, 32, 3,  9, 4, 10, 0, 79, 5, 66, 
    6, 11, 8, 29, 1, 35, 7, 98, 4, 90, 5, 65, 3, 10, 0, 36, 2,  6
  };
  const int q4847[] = {
    9, 9, // Number of jobs and machines
    4, 18, 7, 47, 5, 89, 0, 77, 3, 61, 1, 78, 2, 75, 8, 81, 6,  5, 
    0,  4, 2, 14, 1, 68, 5, 53, 7, 83, 6, 81, 4,  6, 8, 80, 3, 11, 
    0, 45, 7, 41, 5, 61, 3, 27, 2, 19, 1, 90, 4, 18, 6, 40, 8,  7, 
    5, 71, 3, 75, 2, 98, 4,  9, 1, 48, 8, 22, 6, 19, 0, 85, 7, 46, 
    8, 98, 5, 19, 1, 20, 0, 57, 3, 46, 6, 69, 7, 19, 2, 82, 4, 65, 
    1,  5, 7,  9, 0, 16, 3,  8, 6,  6, 2,  6, 5, 13, 4, 73, 8, 20, 
    8, 47, 5, 91, 2,  3, 0, 82, 1, 82, 3, 75, 4, 55, 7, 26, 6, 38, 
    6, 50, 0, 16, 4, 15, 3, 63, 2, 31, 7, 62, 1, 89, 5, 61, 8, 57, 
    0,  8, 3, 64, 8, 88, 4, 36, 5, 30, 6, 77, 1, 21, 7, 46, 2, 81
  };
  const int q4848[] = {
    9, 9, // Number of jobs and machines
    5, 61, 7, 80, 3, 67, 2, 71, 4, 44, 1, 80, 0, 56, 8, 98, 6, 57, 
    0, 34, 1, 31, 7, 55, 4, 34, 2,  1, 8, 52, 6, 85, 5, 64, 3, 43, 
    5, 65, 2, 68, 4, 80, 0, 11, 8, 57, 3, 74, 6, 73, 7, 45, 1,  2, 
    8, 81, 2, 40, 0, 76, 4, 68, 1, 16, 7, 91, 5, 93, 3, 93, 6, 57, 
    5, 57, 0, 90, 1, 30, 2, 11, 6, 33, 7, 57, 3, 54, 4, 20, 8, 52, 
    6, 26, 2, 86, 1, 57, 0, 80, 4, 35, 3, 50, 5, 28, 7, 50, 8, 39, 
    3, 33, 6, 13, 7, 58, 2, 26, 0, 13, 4, 24, 5, 90, 8, 34, 1, 70, 
    2, 21, 8, 55, 3, 50, 1, 76, 6, 65, 0, 58, 5, 26, 4, 75, 7, 20, 
    0, 76, 5, 64, 3, 66, 4, 19, 8, 27, 2, 20, 1, 73, 7, 54, 6, 63
  };
  const int q4849[] = {
    9, 9, // Number of jobs and machines
    1,  2, 7, 30, 3, 40, 2, 67, 6, 61, 5,  9, 8, 96, 0, 41, 4, 89, 
    7, 22, 8, 60, 4, 71, 6, 66, 2, 25, 0, 80, 5, 30, 1, 99, 3,  9, 
    8, 94, 3,  4, 4, 24, 7, 90, 5, 11, 0,  4, 1,  9, 6, 36, 2, 83, 
    7, 56, 3, 85, 8, 93, 1, 14, 6, 85, 4, 64, 2, 25, 0, 55, 5, 29, 
    0, 35, 5, 51, 2, 73, 4, 46, 6, 81, 7, 31, 8, 72, 1,  4, 3, 84, 
    1,  7, 0, 80, 2, 63, 7,  8, 8, 34, 5,  5, 4, 41, 3, 41, 6, 19, 
    4, 67, 8,  4, 6, 84, 2, 78, 0, 21, 1, 22, 7, 18, 5, 75, 3, 74, 
    2, 91, 0, 61, 8, 38, 6, 87, 4,  8, 7, 18, 3, 64, 5, 89, 1, 73, 
    8, 91, 4, 26, 0, 43, 6, 52, 3, 49, 7, 13, 5, 13, 1, 96, 2, 47
  };
  const int q4850[] = {
    9, 9, // Number of jobs and machines
    0, 25, 5, 94, 3,  4, 2, 83, 1, 35, 7,  8, 6, 36, 8, 32, 4, 78, 
    7, 74, 6, 67, 2, 57, 0, 31, 5, 61, 1, 43, 3, 35, 8, 89, 4,  2, 
    8, 75, 2, 90, 0, 90, 7, 91, 5, 78, 1,  2, 4, 43, 3, 76, 6, 10, 
    3, 93, 7, 12, 4, 78, 8, 63, 2,  5, 6, 56, 5, 16, 0, 43, 1, 14, 
    0, 19, 7, 53, 3, 60, 4, 66, 5, 22, 1, 72, 2, 16, 6, 11, 8,  7, 
    7, 32, 1, 73, 6, 22, 8, 90, 5, 95, 2, 81, 3, 19, 4, 94, 0, 16, 
    2, 89, 8, 89, 5, 36, 7, 56, 3, 91, 1, 78, 4, 21, 6, 16, 0, 66, 
    8, 30, 2, 11, 3, 80, 4, 29, 1,  7, 7, 58, 6, 50, 0, 99, 5, 16, 
    7, 97, 0, 22, 5, 57, 3, 93, 8, 65, 4, 52, 6, 64, 2, 84, 1, 58
  };
  const int q4851[] = {
    9, 9, // Number of jobs and machines
    6, 60, 5,  2, 7, 74, 2, 50, 1, 29, 3,  7, 4, 32, 0, 69, 8, 42, 
    6,  3, 0, 43, 2, 20, 5, 22, 1, 14, 8, 29, 4,  6, 3,  1, 7, 61, 
    2, 99, 7, 74, 6, 13, 3, 95, 4, 30, 0, 68, 8, 36, 1, 77, 5, 95, 
    3, 67, 1, 81, 8, 96, 2, 49, 5, 26, 6, 91, 0, 18, 4,  8, 7,  5, 
    0, 72, 2, 22, 7, 95, 5, 70, 1, 32, 3, 64, 4, 74, 8, 66, 6, 31, 
    7, 36, 6, 23, 3, 41, 4, 81, 1, 62, 0, 32, 5, 12, 8, 13, 2, 40, 
    1,  3, 6, 28, 3, 15, 7, 71, 2, 78, 5, 97, 8,  9, 0, 76, 4, 96, 
    0, 61, 1, 98, 7, 81, 2, 10, 3,  5, 4,  1, 5, 13, 8, 82, 6, 39, 
    0, 24, 7, 34, 6, 17, 2, 19, 5, 99, 1, 38, 8,  1, 4, 75, 3,  5
  };
  const int q4852[] = {
    9, 9, // Number of jobs and machines
    6, 55, 2, 26, 8, 82, 4, 11, 1, 66, 0, 33, 5, 93, 3, 60, 7, 27, 
    8, 17, 0, 41, 7, 14, 2, 73, 1, 75, 6, 61, 3, 28, 4,  9, 5,  3, 
    1, 85, 4, 79, 0, 63, 2, 94, 6, 52, 3, 10, 5, 10, 8, 83, 7, 21, 
    1,  9, 2, 37, 8, 51, 4, 25, 0, 45, 7, 12, 6, 26, 3, 79, 5, 43, 
    3, 92, 8, 38, 0, 93, 1, 98, 7, 59, 6, 12, 4, 15, 5, 29, 2, 26, 
    3, 66, 2, 69, 6, 28, 5, 42, 1, 25, 7, 20, 4, 62, 8, 98, 0, 92, 
    1, 45, 6, 50, 5, 71, 0, 46, 3, 86, 2, 16, 7, 49, 8, 32, 4, 47, 
    6, 56, 5, 48, 4, 63, 2, 28, 7, 57, 8, 61, 0, 46, 3, 38, 1, 58, 
    0, 54, 8, 23, 5, 30, 2, 46, 7, 51, 3, 45, 1, 68, 6, 23, 4, 55
  };
  const int q4853[] = {
    9, 9, // Number of jobs and machines
    6, 57, 8, 90, 3, 26, 1, 67, 0, 43, 5, 34, 7, 29, 4, 90, 2, 55, 
    8, 44, 7, 74, 4, 59, 0, 76, 3, 68, 1, 95, 5, 96, 2, 62, 6, 52, 
    8, 71, 5, 97, 6, 91, 1, 56, 0, 37, 2, 52, 3, 22, 7, 26, 4, 59, 
    4, 37, 6, 18, 8, 72, 2, 35, 0,  8, 5, 97, 7, 14, 1, 62, 3, 87, 
    3, 75, 8, 48, 0, 47, 4, 18, 1, 65, 7, 71, 6, 56, 2, 24, 5, 79, 
    8, 44, 6, 58, 7, 40, 3, 35, 1, 73, 4, 55, 2, 94, 5, 34, 0, 23, 
    5, 53, 3, 56, 0, 81, 6, 43, 8,  4, 2, 66, 7, 47, 4, 93, 1, 65, 
    4, 94, 3, 57, 8, 21, 6, 14, 7, 45, 1,  2, 5,  8, 2, 13, 0,  4, 
    2, 22, 4, 91, 6, 44, 5, 83, 1, 19, 8, 93, 0, 62, 3, 92, 7, 76
  };
  const int q4854[] = {
    9, 9, // Number of jobs and machines
    5, 34, 6, 56, 8, 36, 0, 89, 2, 60, 7, 72, 1, 68, 4,  1, 3, 84, 
    7, 38, 2, 63, 8, 94, 5, 25, 1, 72, 4, 48, 6, 46, 3, 97, 0, 50, 
    4, 52, 8, 77, 0, 53, 7,  3, 5, 94, 6, 78, 1, 30, 2, 81, 3, 17, 
    4, 62, 6, 58, 5, 47, 8, 95, 0, 64, 2, 96, 1, 52, 7, 75, 3, 60, 
    6, 21, 5, 86, 1, 42, 4, 47, 7, 17, 8, 47, 3, 28, 0, 58, 2, 25, 
    5, 95, 7, 34, 4, 73, 8, 19, 3, 77, 6,  3, 0, 15, 2,  4, 1, 78, 
    8, 19, 1, 82, 7, 47, 5, 21, 3, 40, 6, 30, 0, 27, 2, 59, 4, 92, 
    7, 84, 4, 97, 2, 93, 6, 75, 1, 72, 3,  8, 8, 84, 5, 69, 0, 75, 
    5, 65, 3, 61, 1, 82, 2, 97, 8, 79, 4, 35, 0, 41, 7, 62, 6, 38
  };
  const int q4855[] = {
    9, 9, // Number of jobs and machines
    5, 21, 0, 13, 4, 21, 3, 75, 1, 54, 2, 18, 8, 36, 7, 23, 6, 94, 
    6, 40, 3, 29, 0,  4, 1, 81, 4, 34, 5, 59, 8, 24, 2, 92, 7, 71, 
    8, 42, 5, 54, 4, 84, 2, 45, 0, 22, 6, 79, 1, 43, 7, 37, 3,  9, 
    6, 24, 5, 51, 7, 88, 1, 82, 3, 89, 0, 37, 2,  3, 8, 41, 4, 26, 
    7, 56, 8, 85, 0, 14, 2, 85, 4, 28, 5, 19, 6, 54, 3, 18, 1, 14, 
    0, 34, 1, 51, 6, 39, 4, 86, 8, 85, 2, 95, 3,  4, 7, 90, 5, 75, 
    2, 37, 7, 29, 6, 13, 4, 77, 0, 51, 3, 39, 1, 48, 5, 79, 8, 48, 
    1, 79, 0, 57, 4, 19, 8, 63, 6,  7, 5, 11, 7,  3, 2, 32, 3, 51, 
    5, 73, 4, 52, 7, 49, 8, 12, 3, 54, 0, 46, 6, 34, 1, 14, 2, 78
  };
  const int q4856[] = {
    9, 9, // Number of jobs and machines
    8, 10, 2,  2, 7, 81, 0,  3, 3, 35, 6, 19, 1,  4, 4,  8, 5, 47, 
    3, 43, 5, 72, 0,  3, 4, 23, 8, 73, 7, 96, 2, 12, 6, 73, 1, 50, 
    7, 61, 2, 86, 5, 98, 6, 91, 4, 88, 0, 40, 1, 66, 3, 68, 8, 87, 
    1, 87, 2, 69, 8, 44, 5, 53, 7, 22, 4, 29, 6, 33, 0, 80, 3, 62, 
    6, 99, 3, 46, 2, 49, 7, 99, 4, 93, 8, 38, 0, 98, 5, 57, 1, 97, 
    4,  5, 2, 81, 5, 55, 0, 73, 7, 23, 3, 43, 8, 42, 6, 23, 1, 13, 
    0, 17, 5, 10, 6, 28, 4, 21, 2, 57, 8, 97, 7, 97, 1, 41, 3, 21, 
    4, 56, 5, 95, 0, 65, 8, 46, 2, 17, 6,  8, 7, 44, 3, 32, 1, 55, 
    7, 93, 2, 10, 8, 36, 6, 62, 5, 55, 4, 84, 1, 33, 3, 57, 0, 30
  };
  const int q4857[] = {
    9, 9, // Number of jobs and machines
    8, 87, 0, 37, 5, 67, 7, 46, 3, 29, 6, 39, 1, 91, 2, 91, 4, 54, 
    2, 93, 4, 47, 7, 84, 5, 61, 3, 42, 0, 50, 1, 89, 8, 10, 6, 98, 
    3, 17, 7, 87, 2, 56, 1, 33, 0, 56, 4, 67, 5, 20, 8, 42, 6, 15, 
    4, 51, 7, 99, 2, 50, 5, 48, 3, 28, 0, 19, 6, 40, 8, 60, 1, 43, 
    0, 55, 1, 17, 3,  2, 8, 58, 2, 11, 6, 69, 7, 67, 4, 35, 5, 87, 
    8, 84, 7, 41, 3, 59, 2, 52, 0, 71, 1, 68, 6, 35, 5, 32, 4, 46, 
    1, 78, 2, 24, 0, 98, 7, 12, 6, 64, 4,  1, 8, 14, 3, 41, 5, 92, 
    7, 83, 0, 18, 1, 51, 3, 44, 4, 45, 5, 77, 6, 25, 2, 63, 8, 45, 
    3, 38, 6,  3, 5, 35, 4, 60, 8, 60, 0, 86, 1, 65, 2, 50, 7, 40
  };
  const int q4858[] = {
    9, 9, // Number of jobs and machines
    6, 83, 7, 48, 8, 72, 4,  2, 5, 69, 2, 60, 3,  5, 1, 35, 0, 28, 
    3, 25, 6, 59, 5, 34, 0, 97, 8, 49, 4, 28, 2, 95, 7, 60, 1, 66, 
    0, 22, 3, 85, 4, 24, 6, 97, 1, 95, 7, 82, 5, 17, 8, 20, 2, 53, 
    2, 56, 1, 63, 8, 22, 6, 88, 0,  5, 7, 88, 5, 84, 3, 76, 4, 85, 
    8, 17, 7, 97, 3, 93, 4, 74, 5, 76, 2, 83, 6, 74, 1, 40, 0, 73, 
    0, 40, 3, 80, 4, 32, 5, 84, 7, 48, 2, 71, 1, 99, 8, 72, 6,  4, 
    2, 54, 6, 99, 1, 41, 8, 53, 0, 16, 4, 43, 5, 26, 3, 44, 7, 45, 
    1, 88, 2, 24, 6, 68, 0, 69, 8, 11, 3, 81, 7, 15, 4, 52, 5, 44, 
    7, 93, 8, 42, 5,  7, 3, 93, 4, 85, 2, 90, 1, 62, 6, 88, 0, 17
  };
  const int q4859[] = {
    9, 9, // Number of jobs and machines
    8, 69, 3, 24, 2, 35, 7, 22, 0, 76, 4, 70, 5, 68, 6, 70, 1, 11, 
    2, 19, 7, 56, 6, 25, 4, 44, 8, 59, 0, 53, 5, 17, 1, 76, 3, 25, 
    1, 32, 3, 50, 2, 10, 7, 36, 8, 23, 5,  5, 0, 97, 6, 94, 4, 70, 
    2, 16, 1, 69, 0, 77, 7, 52, 5, 96, 8, 55, 4, 43, 3, 94, 6, 45, 
    2, 26, 6, 57, 5, 96, 3,  2, 0, 66, 4, 40, 8, 65, 7, 20, 1, 23, 
    4, 97, 1, 70, 8, 37, 0, 26, 2,  1, 6, 97, 7, 11, 5, 64, 3, 51, 
    0, 92, 3, 89, 8,  9, 1, 25, 7, 21, 6,  2, 4, 90, 5, 77, 2, 27, 
    0,  9, 8,  2, 1, 42, 3, 60, 4, 48, 5,  2, 2, 59, 6, 83, 7, 43, 
    1, 59, 7, 76, 5, 71, 2, 15, 3,  3, 6, 82, 8, 59, 0, 12, 4, 73
  };
  const int q4860[] = {
    9, 9, // Number of jobs and machines
    6, 58, 7, 61, 4, 28, 3, 18, 5, 41, 0, 63, 1, 94, 2, 12, 8, 66, 
    2,  3, 6, 88, 8,  4, 1, 64, 3, 76, 5,  7, 7, 22, 0, 95, 4, 30, 
    4, 31, 3, 99, 0, 75, 8, 70, 2, 70, 5, 67, 6, 11, 1, 19, 7, 15, 
    4, 32, 7, 33, 5, 13, 3, 50, 0, 38, 8, 61, 2, 92, 6, 27, 1, 27, 
    2, 97, 3, 71, 4, 62, 6, 29, 7, 47, 5, 49, 1, 20, 8, 39, 0, 25, 
    4,  3, 1, 56, 7, 53, 0, 70, 5, 78, 2, 29, 8, 88, 3, 63, 6, 45, 
    5, 98, 7, 53, 4, 56, 2, 74, 0, 32, 8,  7, 1, 52, 6, 35, 3, 71, 
    8,  2, 6, 26, 2, 64, 7, 20, 4, 85, 3, 43, 1, 35, 5, 24, 0, 83, 
    7, 37, 2, 63, 3, 46, 6, 26, 1, 29, 0, 46, 8, 68, 5,  1, 4, 65
  };
  const int q4861[] = {
    9, 9, // Number of jobs and machines
    3, 93, 1, 15, 5, 32, 4, 43, 0, 29, 7, 74, 8,  4, 2, 74, 6, 24, 
    4, 39, 2, 59, 8, 30, 6, 77, 7,  3, 5,  9, 1, 59, 3, 71, 0, 36, 
    8, 32, 5, 11, 6, 57, 7, 73, 4, 99, 1, 59, 2, 28, 3, 41, 0, 73, 
    6, 83, 0, 87, 4, 80, 7, 33, 5,  2, 1, 20, 3, 43, 2, 29, 8, 35, 
    4, 85, 1, 47, 0, 98, 8, 62, 7, 63, 6, 29, 3, 79, 5,  4, 2, 36, 
    6, 49, 0, 66, 8, 64, 7,  5, 1, 32, 4, 99, 5, 54, 3, 95, 2, 35, 
    7, 24, 0, 54, 1, 33, 3, 15, 2, 20, 5, 29, 4, 90, 8, 33, 6, 87, 
    3, 34, 6, 67, 4, 93, 8, 98, 5, 77, 7, 51, 1, 98, 2, 64, 0, 81, 
    7,  9, 3, 65, 0, 25, 8, 64, 6, 35, 5, 13, 2, 18, 4, 89, 1, 31
  };
  const int q4862[] = {
    9, 9, // Number of jobs and machines
    4, 47, 1, 17, 6, 28, 5, 20, 0, 47, 8, 34, 2, 14, 3, 82, 7, 55, 
    5, 80, 7, 41, 6, 26, 3, 21, 4, 96, 8, 38, 2, 45, 1, 13, 0, 39, 
    2, 19, 3, 97, 0, 20, 4, 46, 8, 14, 5, 91, 7, 10, 1, 60, 6, 77, 
    4, 28, 2, 15, 1, 73, 7, 17, 3, 49, 0, 50, 8, 95, 5, 76, 6, 42, 
    8, 40, 7, 62, 5, 17, 1, 99, 6, 80, 4, 18, 2, 24, 3, 75, 0, 45, 
    3, 32, 8, 68, 4, 94, 5, 72, 1, 85, 0, 47, 7, 89, 6, 35, 2,  7, 
    4, 74, 2, 10, 3, 92, 7, 48, 5, 43, 0, 47, 8, 34, 6, 96, 1, 32, 
    0, 61, 3, 28, 7,  4, 5,  3, 2, 44, 1, 10, 8, 46, 6, 57, 4, 57, 
    5,  1, 4, 92, 0, 41, 1, 76, 3, 64, 7, 35, 6, 68, 8, 64, 2, 62
  };
  const int q4863[] = {
    9, 9, // Number of jobs and machines
    4, 49, 6, 72, 5, 26, 1, 82, 0, 42, 7, 99, 3, 69, 8, 42, 2, 30, 
    8, 51, 5, 90, 4, 53, 2, 86, 3, 88, 6, 90, 7,  2, 1, 29, 0, 72, 
    2, 34, 1, 54, 4, 30, 8, 51, 7, 28, 6, 35, 0, 30, 3, 61, 5, 25, 
    7, 37, 2, 26, 8, 24, 4,  8, 0, 79, 1, 19, 5, 56, 6, 73, 3, 26, 
    3, 34, 7, 95, 2, 91, 0, 65, 6, 60, 5, 30, 8, 33, 4,  5, 1, 59, 
    0, 40, 6, 99, 1, 47, 8, 66, 5, 11, 7, 92, 4, 39, 2, 66, 3, 46, 
    1, 17, 2, 23, 8, 92, 3, 57, 0, 19, 5,  7, 7, 53, 4, 36, 6, 98, 
    2, 83, 7, 36, 8, 31, 6,  9, 4, 48, 1, 82, 3, 11, 0,  5, 5, 70, 
    3, 65, 4, 89, 1, 57, 0, 35, 8, 25, 2, 51, 5, 41, 6, 52, 7, 45
  };
  const int q4864[] = {
    9, 9, // Number of jobs and machines
    4, 69, 2, 48, 8, 46, 0, 75, 1, 69, 7, 88, 6, 91, 3, 42, 5, 89, 
    3,  3, 8, 25, 4, 36, 7,  7, 2, 30, 0,  1, 5, 78, 6, 16, 1, 10, 
    8, 33, 6, 81, 2, 22, 5, 66, 7, 40, 3, 44, 1,  1, 4, 34, 0, 97, 
    0, 60, 2, 40, 8, 53, 3,  8, 7, 53, 1, 53, 6, 90, 5, 69, 4, 17, 
    6, 64, 3,  5, 8, 93, 4, 24, 2, 90, 0, 69, 1, 77, 7, 17, 5, 39, 
    4, 51, 5, 75, 8, 80, 3, 49, 6, 10, 2, 26, 1, 57, 7, 68, 0, 26, 
    5, 70, 2, 10, 6, 45, 8, 19, 7, 22, 3, 37, 4, 75, 0, 19, 1, 66, 
    5, 80, 2, 53, 4, 39, 8, 25, 0, 24, 6, 93, 7, 53, 3, 88, 1, 94, 
    3, 97, 1, 78, 2, 15, 6, 85, 5, 41, 4, 69, 7, 75, 0, 43, 8,  1
  };
  const int q4865[] = {
    9, 9, // Number of jobs and machines
    4, 41, 0, 89, 7, 48, 6,  6, 3, 75, 5, 74, 1,  1, 8, 19, 2, 28, 
    7, 59, 2, 20, 3, 38, 1, 63, 8, 93, 0, 43, 6, 84, 5, 75, 4, 61, 
    8,  8, 1, 26, 0, 30, 4, 56, 2, 89, 6, 77, 5, 97, 3, 72, 7, 63, 
    4, 72, 7, 15, 3, 46, 1, 41, 8, 75, 5, 70, 2, 66, 6,  7, 0, 80, 
    7, 77, 2,  7, 0, 38, 5, 89, 8, 17, 3, 84, 6, 96, 4,  2, 1, 30, 
    5, 88, 6, 76, 1, 53, 4, 86, 0, 85, 7, 89, 3, 78, 2, 73, 8, 62, 
    4, 97, 3, 92, 1, 51, 7, 42, 2, 21, 6, 18, 8, 50, 5, 59, 0,  4, 
    4, 43, 1, 82, 7,  6, 3,  5, 8, 94, 2, 91, 5, 52, 6, 95, 0, 52, 
    2, 18, 3, 61, 5,  5, 1, 76, 8, 67, 0, 85, 4, 34, 7, 77, 6, 10
  };
  const int q4866[] = {
    9, 9, // Number of jobs and machines
    3, 80, 8, 59, 5, 84, 7, 52, 4,  8, 1, 29, 2, 56, 0, 45, 6, 62, 
    6,  1, 2, 54, 8, 71, 4, 36, 3, 53, 0, 74, 1, 26, 5, 19, 7, 92, 
    0, 94, 5, 27, 1, 24, 3, 77, 4, 29, 6, 43, 2, 98, 7, 74, 8, 95, 
    2, 50, 3, 70, 0, 51, 8, 23, 4, 35, 1, 17, 6, 59, 7, 30, 5, 96, 
    1, 85, 6, 66, 7,  3, 5, 31, 0, 33, 4, 64, 2, 16, 8, 37, 3, 95, 
    6, 12, 4, 93, 1, 46, 0, 91, 7, 36, 8, 44, 5, 68, 2, 75, 3, 72, 
    3, 95, 1, 47, 0, 35, 6, 18, 2, 18, 7, 84, 5, 67, 8, 98, 4, 38, 
    2, 47, 5, 47, 7, 99, 3, 87, 8, 93, 4, 97, 6, 28, 1, 13, 0, 73, 
    1,  5, 4, 24, 7, 91, 3, 36, 0, 44, 2,  6, 5, 18, 6, 46, 8, 82
  };
  const int q4867[] = {
    9, 9, // Number of jobs and machines
    5,  7, 2, 35, 6, 23, 8, 27, 1, 71, 7, 25, 0, 80, 4, 90, 3, 46, 
    8, 59, 6, 94, 0, 11, 5,  7, 2, 37, 7, 56, 4, 59, 3, 36, 1, 58, 
    5, 42, 2, 58, 0,  3, 1, 26, 4, 25, 3, 75, 7, 82, 8, 95, 6, 88, 
    8, 56, 3, 71, 4, 19, 5, 53, 6, 73, 2, 57, 7, 87, 1, 30, 0, 56, 
    5, 79, 3, 72, 4, 83, 7, 39, 0, 48, 2, 55, 1, 76, 8,  4, 6, 24, 
    7, 43, 4, 55, 0, 77, 8, 66, 5,  6, 1, 33, 3, 17, 6,  5, 2, 90, 
    1, 17, 2, 62, 0,  9, 5, 76, 7, 46, 6, 33, 8,  5, 4, 66, 3, 36, 
    2, 62, 5, 39, 1,  4, 7, 96, 6, 89, 4, 89, 0, 35, 3, 40, 8,  1, 
    0, 68, 1, 77, 7, 67, 4, 61, 3, 63, 8, 20, 5,  8, 6, 57, 2, 33
  };
  const int q4868[] = {
    9, 9, // Number of jobs and machines
    4, 82, 8,  6, 7, 86, 6, 22, 0, 28, 1, 73, 2, 87, 3, 96, 5, 47, 
    1, 39, 0, 16, 5, 47, 4, 39, 8,  2, 3, 91, 6, 20, 2, 98, 7, 28, 
    8, 52, 4, 93, 5, 85, 0, 67, 1, 40, 6, 26, 3, 76, 7, 78, 2, 64, 
    3, 84, 6, 96, 4, 57, 0, 29, 1, 10, 8, 99, 7, 21, 5, 47, 2, 38, 
    7, 47, 1, 46, 4, 20, 8, 68, 3, 36, 6, 40, 2, 57, 0, 67, 5, 70, 
    5, 32, 6, 70, 7, 81, 1,  6, 4, 83, 3, 23, 0, 43, 2, 84, 8, 96, 
    4, 24, 2, 90, 6, 55, 1, 57, 5, 15, 7, 62, 3, 34, 8,  5, 0, 61, 
    2, 90, 6, 62, 7, 44, 4, 47, 0, 45, 5, 30, 8, 81, 3, 62, 1, 73, 
    5, 19, 4, 57, 6, 79, 8, 97, 7, 97, 1, 97, 2, 91, 3, 21, 0, 99
  };
  const int q4869[] = {
    9, 9, // Number of jobs and machines
    6, 58, 2, 20, 8,  5, 0, 54, 5, 30, 3, 32, 1, 24, 7, 41, 4, 87, 
    5, 28, 4, 85, 8, 90, 1, 95, 7, 33, 0, 37, 3, 69, 2, 70, 6, 86, 
    6, 23, 0, 26, 2, 30, 5, 19, 3,  8, 4, 49, 7, 45, 1, 95, 8, 66, 
    4, 50, 8, 12, 3, 21, 5, 16, 2, 43, 6, 64, 0, 11, 7, 77, 1, 25, 
    7, 51, 0,  6, 6, 39, 5, 88, 4, 64, 2, 83, 1, 85, 3, 99, 8, 36, 
    2, 71, 1, 97, 8, 15, 3, 23, 7, 13, 0, 18, 4, 91, 6, 28, 5, 71, 
    0, 84, 1, 69, 6, 66, 7, 42, 8, 87, 2, 79, 4, 11, 3, 40, 5, 75, 
    6, 20, 2,  7, 7, 56, 3, 70, 8, 52, 4, 49, 1, 21, 0, 50, 5, 29, 
    2,  3, 7, 48, 4, 82, 1, 99, 5, 40, 8, 18, 3, 10, 6, 53, 0, 52
  };
  const int q4870[] = {
    9, 9, // Number of jobs and machines
    6, 15, 2, 57, 3, 70, 8, 93, 1,  1, 5, 63, 0, 85, 4, 43, 7, 68, 
    0, 71, 4, 42, 2, 13, 8, 18, 5,  7, 1, 79, 7, 90, 3, 15, 6, 87, 
    5, 20, 8, 72, 6, 37, 1, 68, 0, 19, 2,  2, 4, 96, 3, 96, 7, 59, 
    3, 58, 1, 75, 7, 47, 8, 61, 6,  1, 4, 87, 5, 31, 2, 64, 0, 42, 
    2, 80, 5, 55, 1, 25, 3, 47, 7, 83, 4, 29, 0, 21, 8, 87, 6, 23, 
    2, 45, 0, 43, 8, 22, 1, 16, 6, 29, 5, 20, 7, 64, 3,  1, 4, 30, 
    5, 88, 0, 80, 4, 19, 6, 22, 3, 31, 8, 58, 2, 42, 7, 65, 1, 92, 
    0, 38, 6, 76, 8, 80, 1, 95, 4, 66, 7, 68, 5, 64, 2, 98, 3, 67, 
    2, 87, 5, 12, 1, 71, 3, 31, 4, 60, 6, 50, 0,  1, 7, 15, 8, 84
  };
  const int q4871[] = {
    9, 9, // Number of jobs and machines
    1, 64, 5, 51, 4, 53, 8, 88, 3, 66, 6, 84, 7, 32, 0, 33, 2, 66, 
    3, 88, 2, 27, 4, 84, 1, 58, 0, 36, 5, 82, 6, 55, 8, 95, 7, 91, 
    4, 92, 1, 33, 7, 54, 0, 96, 8, 23, 2,  8, 6, 94, 3, 92, 5, 54, 
    8, 42, 5, 16, 3, 52, 2, 46, 4, 70, 1, 52, 6,  3, 7, 12, 0, 75, 
    0, 33, 2, 63, 5, 77, 6, 53, 1,  6, 3, 56, 8, 95, 7, 38, 4, 81, 
    7, 16, 8, 90, 3,  3, 1, 66, 4, 63, 5, 25, 0, 27, 6,  9, 2, 17, 
    8, 12, 1, 26, 2, 72, 0, 31, 3, 12, 7, 54, 4, 54, 6, 33, 5, 14, 
    7, 85, 4, 65, 3, 42, 6, 81, 5, 73, 0, 43, 1,  3, 8, 40, 2, 43, 
    8, 67, 0, 69, 5, 56, 2, 26, 3, 64, 7, 36, 6, 93, 1, 31, 4, 47
  };
  const int q4872[] = {
    9, 9, // Number of jobs and machines
    5, 19, 7, 40, 4, 48, 0, 62, 8, 83, 6, 73, 1, 82, 2, 53, 3, 22, 
    5, 58, 4, 25, 6,  2, 2, 80, 3, 39, 7, 79, 0, 54, 8, 54, 1, 98, 
    0, 73, 8, 60, 4, 54, 1, 70, 5,  4, 2, 96, 3, 15, 6, 42, 7, 21, 
    1, 81, 8, 55, 7,  6, 6, 70, 3, 43, 2, 33, 5, 44, 4, 96, 0, 56, 
    0, 89, 5,  9, 2, 88, 4, 71, 3, 99, 7, 42, 8, 95, 6, 66, 1, 35, 
    1, 47, 6,  8, 7, 15, 5, 48, 3, 18, 8, 69, 0, 83, 4, 69, 2, 46, 
    8,  3, 2,  9, 0, 92, 3, 36, 6, 89, 1, 29, 5, 68, 4,  3, 7, 93, 
    3, 64, 5, 71, 1, 33, 0,  7, 2, 21, 7, 83, 6, 41, 4, 72, 8,  8, 
    4, 86, 7, 39, 6, 24, 2, 13, 0, 65, 3, 83, 1, 56, 8, 80, 5, 57
  };
  const int q4873[] = {
    9, 9, // Number of jobs and machines
    1, 19, 7, 26, 3, 66, 2, 88, 6, 55, 5, 58, 0, 93, 4, 49, 8, 97, 
    4, 21, 2, 72, 8, 46, 7, 92, 1, 37, 6, 56, 0, 50, 3, 64, 5, 62, 
    2, 85, 6, 55, 5, 79, 7, 88, 1, 68, 8, 97, 0, 87, 3, 36, 4, 21, 
    6, 24, 3, 63, 7, 33, 1, 80, 5, 10, 2, 45, 8, 49, 0, 58, 4, 52, 
    0, 52, 5, 57, 7, 78, 6, 31, 3, 34, 1, 45, 2, 50, 8, 43, 4, 78, 
    8, 93, 0, 18, 2, 68, 6, 26, 5, 75, 1, 30, 4, 49, 7, 24, 3, 23, 
    1,  1, 6, 22, 0, 34, 8,  8, 4,  9, 7,  1, 2, 55, 5, 39, 3, 13, 
    0, 46, 7, 76, 4, 59, 5, 16, 1, 81, 3, 32, 2, 55, 6, 13, 8, 49, 
    7, 24, 0, 75, 3, 30, 5, 35, 8, 67, 4, 15, 1, 69, 2, 89, 6, 73
  };
  const int q4874[] = {
    9, 9, // Number of jobs and machines
    6, 27, 0, 89, 7, 33, 2, 35, 3, 86, 5, 14, 1, 29, 8, 97, 4, 20, 
    4, 79, 6, 57, 3, 33, 7,  5, 2, 96, 8, 27, 1, 83, 0, 94, 5, 86, 
    5, 79, 2, 41, 8, 65, 3, 47, 1, 11, 6,  6, 0, 97, 7, 78, 4, 99, 
    4, 26, 8, 50, 0, 35, 6, 99, 3, 37, 5, 21, 2, 59, 1, 84, 7, 52, 
    5, 35, 7, 86, 4, 94, 0, 55, 8, 16, 6, 87, 2, 47, 3, 29, 1, 26, 
    4, 29, 7, 52, 2, 11, 1, 56, 3,  7, 8, 72, 0, 71, 6, 88, 5, 59, 
    7, 30, 3, 86, 1, 91, 2, 81, 4, 37, 0, 33, 8, 73, 5, 36, 6, 56, 
    3, 69, 4, 57, 7, 16, 8, 91, 0, 26, 5, 99, 6, 10, 2, 10, 1, 54, 
    0, 87, 3,  3, 8, 36, 4,  5, 5, 34, 2, 34, 6, 24, 1,  5, 7, 12
  };
  const int q4875[] = {
    9, 9, // Number of jobs and machines
    3, 53, 6, 40, 0, 78, 4, 39, 7, 46, 5, 10, 1, 70, 8, 77, 2, 23, 
    5, 89, 0, 18, 7, 48, 6, 91, 8, 25, 2, 73, 3, 77, 1, 16, 4, 50, 
    8, 88, 1, 91, 5, 18, 6, 66, 2, 13, 4, 46, 3, 22, 0, 70, 7, 83, 
    0, 26, 7, 15, 3, 75, 1, 98, 4, 92, 2, 12, 5, 44, 8, 16, 6, 92, 
    2, 12, 5, 80, 7, 58, 1, 29, 4, 10, 3, 76, 0, 89, 6, 14, 8, 78, 
    7, 38, 0, 18, 1, 63, 6, 56, 2, 10, 3, 86, 8, 74, 5, 81, 4, 34, 
    7, 66, 8,  3, 5, 57, 1, 39, 3, 16, 4, 28, 0, 36, 2,  7, 6, 60, 
    3, 89, 2, 86, 0, 79, 7, 47, 6, 33, 4, 17, 1, 50, 8,  9, 5,  7, 
    5, 36, 3, 92, 7, 62, 8, 14, 4, 89, 0, 45, 6, 35, 2, 18, 1, 57
  };
  const int q4876[] = {
    9, 9, // Number of jobs and machines
    0, 37, 6, 24, 5, 18, 2, 98, 8, 21, 3, 11, 7,  7, 4,  4, 1, 97, 
    5, 98, 1, 28, 8, 86, 0, 38, 2, 78, 4, 85, 3, 30, 7, 50, 6, 75, 
    4, 62, 8, 86, 7, 70, 1,  3, 3,  5, 0, 37, 2, 33, 5, 88, 6, 98, 
    4, 58, 1, 87, 3, 43, 8, 55, 5, 66, 2, 86, 6, 21, 0, 73, 7,  5, 
    1,  7, 0, 60, 6,  1, 4, 62, 2, 42, 7,  3, 8,  4, 3, 18, 5, 19, 
    2, 98, 4, 89, 3,  7, 1, 21, 5, 17, 6, 39, 8, 24, 7, 21, 0, 62, 
    6, 99, 5, 65, 1, 78, 4, 77, 3, 64, 2, 80, 8, 96, 0, 38, 7, 38, 
    6,  3, 4, 61, 2, 59, 7, 26, 0, 75, 5, 76, 8,  3, 3, 36, 1, 50, 
    1, 98, 7, 38, 3, 98, 6, 41, 4, 57, 8, 16, 2, 78, 5, 48, 0, 31
  };
  const int q4877[] = {
    9, 9, // Number of jobs and machines
    3, 35, 0, 74, 1, 34, 5,  8, 6, 67, 4, 14, 7, 64, 2, 38, 8, 34, 
    6, 91, 7, 32, 1, 73, 0, 74, 5, 94, 3, 11, 4, 52, 2, 43, 8, 22, 
    6, 10, 1, 23, 5, 61, 7,  9, 0, 45, 3, 93, 2, 12, 4, 11, 8, 54, 
    3, 47, 0, 95, 4, 91, 8, 95, 1, 58, 7, 86, 6, 48, 2, 72, 5, 19, 
    1,  1, 4,  8, 5, 70, 0, 75, 6, 98, 3, 21, 8, 81, 7, 31, 2, 87, 
    8, 48, 7, 37, 1, 52, 5, 68, 6, 97, 0,  5, 2, 44, 4, 73, 3, 40, 
    1, 37, 5, 47, 0, 79, 6, 70, 3, 83, 8, 69, 2, 97, 7, 36, 4, 24, 
    4, 89, 0, 56, 6, 49, 7,  4, 3, 24, 8, 90, 5, 50, 2, 45, 1, 94, 
    0, 63, 5, 74, 7, 23, 2, 33, 1,  9, 6, 83, 4, 36, 8, 80, 3, 34
  };
  const int q4878[] = {
    9, 9, // Number of jobs and machines
    5, 19, 2, 88, 3, 72, 6, 46, 0, 73, 4, 29, 7,  3, 8, 68, 1, 70, 
    2,  3, 7, 58, 4, 21, 1, 42, 5, 69, 0, 62, 3, 69, 8, 84, 6, 63, 
    0, 74, 3, 90, 4, 42, 1, 65, 7, 84, 8, 39, 6,  4, 5, 63, 2, 88, 
    1, 48, 0, 38, 2, 84, 6, 61, 7, 80, 8, 52, 5, 37, 4, 89, 3, 35, 
    2, 85, 4, 56, 3, 71, 6, 34, 8, 71, 5, 89, 7, 68, 1, 98, 0, 84, 
    6,  2, 7, 83, 5, 44, 3,  1, 8, 46, 1, 60, 2, 86, 0, 58, 4, 19, 
    8, 51, 5, 51, 3, 72, 4, 80, 2, 70, 1, 25, 6, 43, 0, 46, 7, 45, 
    2, 22, 7, 14, 0, 78, 1, 13, 4, 24, 6, 73, 8, 49, 3, 51, 5, 60, 
    2,  7, 6, 61, 3, 57, 1, 23, 5, 36, 0, 84, 4, 19, 8, 60, 7, 34
  };
  const int q4879[] = {
    9, 9, // Number of jobs and machines
    0, 94, 7, 32, 3, 68, 8, 94, 2, 53, 5, 58, 6, 90, 1, 66, 4,  4, 
    6, 84, 5, 50, 4, 70, 2, 94, 3,  9, 0, 63, 7, 40, 1, 19, 8, 34, 
    2,  1, 0, 38, 8, 52, 7,  4, 6, 70, 4, 74, 5,  6, 1, 69, 3, 73, 
    2, 43, 5, 10, 8, 26, 7,  1, 6, 28, 0, 82, 3, 49, 1, 71, 4, 68, 
    6, 85, 3, 48, 1, 73, 5, 55, 7, 64, 8, 43, 4, 53, 2, 36, 0,  7, 
    7, 43, 1, 91, 4, 95, 3,  7, 8, 50, 0, 98, 2, 53, 6, 36, 5,  7, 
    3, 49, 2, 19, 5, 73, 8, 35, 4, 73, 7, 25, 0, 97, 1, 74, 6, 40, 
    1, 67, 6,  4, 4, 51, 0, 80, 3, 42, 2, 48, 7, 66, 5, 70, 8,  2, 
    0, 52, 8, 17, 3, 37, 1, 89, 7,  7, 4,  3, 2, 12, 6, 90, 5, 75
  };
  const int q4880[] = {
    9, 9, // Number of jobs and machines
    1, 38, 2, 55, 7, 81, 0,  6, 6, 13, 8, 74, 5, 68, 4, 28, 3, 16, 
    0,  9, 2, 69, 1, 14, 6, 94, 4, 82, 8, 38, 7, 25, 5, 92, 3, 14, 
    1, 42, 0, 66, 2, 28, 6, 55, 5, 77, 8, 62, 3, 41, 4, 86, 7, 54, 
    2,  3, 5, 98, 1, 73, 6, 56, 3, 30, 7, 96, 0, 86, 4, 31, 8, 28, 
    3, 21, 1, 43, 5, 58, 2, 86, 8, 17, 0, 47, 6, 60, 7, 72, 4, 34, 
    2, 63, 4, 27, 3, 38, 7, 76, 1, 90, 5, 30, 6, 68, 8, 88, 0, 73, 
    5, 84, 0, 61, 7, 52, 8, 60, 2, 13, 4, 84, 3, 77, 6, 41, 1, 26, 
    8, 88, 2, 31, 5, 52, 7, 99, 6,  3, 0, 56, 3, 14, 4, 81, 1, 67, 
    5, 98, 6, 28, 7, 22, 2, 58, 0, 18, 1, 36, 3, 43, 4, 16, 8,  9
  };
  const int q4881[] = {
    9, 9, // Number of jobs and machines
    3, 29, 7, 88, 2, 85, 4, 12, 5,  2, 0,  1, 6, 22, 8, 61, 1, 53, 
    5, 55, 2, 58, 7, 76, 8, 87, 1, 73, 3, 92, 4, 61, 0, 19, 6, 62, 
    5, 39, 8, 72, 6, 31, 2, 61, 4, 71, 3, 98, 0, 96, 1, 42, 7, 33, 
    6, 44, 0, 19, 1, 70, 8, 70, 2, 56, 3, 17, 4, 77, 7, 82, 5, 57, 
    7, 60, 1, 77, 2, 40, 8,  9, 6, 23, 0, 47, 3, 20, 5, 27, 4, 62, 
    4, 56, 2, 92, 0, 25, 1, 69, 5, 98, 6, 85, 3, 72, 7, 82, 8, 73, 
    3,  9, 7, 71, 6, 48, 2, 78, 8, 79, 5, 70, 4, 64, 0,  6, 1, 27, 
    2, 24, 8, 72, 3, 88, 0, 22, 1, 18, 4, 35, 7, 58, 6, 39, 5, 13, 
    1, 93, 0, 64, 2, 54, 8, 92, 7, 45, 3, 32, 6, 77, 5, 36, 4, 12
  };
  const int q4882[] = {
    9, 9, // Number of jobs and machines
    3, 72, 2, 44, 5, 84, 7, 35, 0, 60, 4, 74, 8, 86, 6, 99, 1,  3, 
    1,  8, 5, 93, 7, 44, 2,  9, 4, 69, 0, 99, 8, 56, 3, 27, 6, 29, 
    8, 41, 3, 81, 2, 98, 5, 11, 4, 44, 0, 16, 6, 30, 7, 91, 1, 52, 
    4, 75, 5, 91, 8,  4, 2, 46, 3, 66, 6, 25, 1, 35, 7, 70, 0, 34, 
    2, 26, 8, 57, 0, 36, 3, 62, 7, 55, 4, 33, 6, 26, 5, 86, 1, 83, 
    5, 66, 7,  2, 2, 47, 4, 59, 0, 34, 1, 90, 6, 96, 8, 16, 3, 69, 
    6, 92, 4, 61, 1, 91, 5, 38, 2, 33, 3, 13, 8, 47, 7, 60, 0, 14, 
    1, 64, 7, 94, 3, 72, 0, 57, 4,  4, 8, 15, 6, 72, 5, 32, 2, 14, 
    1, 83, 7, 60, 0, 37, 6, 32, 2, 94, 3, 68, 5, 25, 8, 12, 4,  5
  };
  const int q4883[] = {
    9, 9, // Number of jobs and machines
    2, 66, 7, 71, 3, 81, 1, 48, 0, 71, 6, 24, 4, 95, 8,  4, 5, 69, 
    3, 47, 4, 52, 8, 34, 7, 64, 2, 92, 6, 80, 5, 35, 0, 34, 1, 47, 
    3, 70, 2, 60, 8, 27, 1, 74, 5, 88, 0, 95, 4, 99, 6, 91, 7, 90, 
    3, 91, 8, 69, 2, 84, 0, 68, 5, 51, 6, 68, 1, 53, 4, 83, 7, 42, 
    3, 94, 7, 27, 2, 71, 8, 68, 4, 11, 1,  4, 0, 57, 5, 26, 6, 28, 
    2, 85, 8, 62, 3, 81, 6, 45, 0, 61, 7,  3, 4, 65, 5, 72, 1, 18, 
    7, 50, 2, 31, 6, 42, 5, 50, 3, 87, 1, 17, 0, 67, 8, 46, 4, 98, 
    5, 47, 7, 86, 6, 27, 0, 47, 3, 23, 4, 12, 8, 86, 2, 22, 1, 37, 
    7, 55, 0, 34, 4, 21, 3, 76, 6, 11, 5, 49, 1, 61, 8, 79, 2, 91
  };
  const int q4884[] = {
    9, 9, // Number of jobs and machines
    1, 48, 0,  3, 3, 46, 7, 83, 4, 47, 5, 65, 2, 46, 6, 29, 8, 78, 
    3, 37, 0, 64, 6, 53, 8, 25, 2, 53, 7, 71, 1, 37, 4, 61, 5, 24, 
    6, 98, 2, 66, 4, 27, 5, 73, 1,  8, 3, 37, 8, 81, 0, 99, 7, 40, 
    6,  2, 8, 44, 5, 57, 1, 45, 2, 39, 7, 65, 3, 98, 4, 98, 0, 44, 
    8, 81, 1, 53, 0, 16, 2, 88, 4, 81, 6, 83, 5, 69, 3, 63, 7, 84, 
    0, 78, 8, 17, 6, 88, 4, 75, 5, 60, 7, 13, 1, 51, 2, 37, 3, 77, 
    4, 90, 0, 71, 7, 61, 2, 79, 6, 78, 3, 33, 5, 90, 8, 10, 1, 37, 
    6, 48, 3, 28, 0, 84, 4, 49, 7, 76, 8, 46, 2, 21, 5, 16, 1, 95, 
    4, 78, 5, 92, 2, 17, 1, 57, 3, 67, 6, 38, 0, 77, 7, 92, 8, 23
  };
  const int q4885[] = {
    9, 9, // Number of jobs and machines
    6, 41, 4, 61, 5, 90, 1, 14, 2, 34, 8, 17, 3, 89, 7, 95, 0, 57, 
    7, 55, 2, 60, 1, 11, 3,  6, 4, 99, 0, 77, 6, 45, 5, 34, 8, 99, 
    5, 22, 4, 28, 7, 70, 6,  8, 1, 72, 8, 41, 0,  3, 2, 92, 3, 67, 
    0, 70, 2, 52, 3, 49, 4,  2, 6, 55, 7, 77, 8, 72, 5, 98, 1, 43, 
    5,  5, 4,  3, 6, 33, 1, 75, 3, 68, 2, 92, 8, 81, 7, 55, 0, 23, 
    5, 99, 7, 14, 1, 41, 8, 78, 3,  7, 2, 82, 6, 25, 0, 47, 4, 67, 
    7, 36, 8, 26, 2, 29, 0, 67, 5, 99, 1, 37, 4, 24, 3,  8, 6, 29, 
    1, 32, 4, 10, 7, 74, 2, 58, 5, 14, 3, 47, 0,  6, 6, 82, 8, 50, 
    2, 63, 6, 17, 4, 27, 7, 40, 5, 62, 0, 79, 3, 79, 1, 94, 8,  9
  };
  const int q4886[] = {
    9, 9, // Number of jobs and machines
    3, 27, 1, 78, 2,  9, 8, 65, 6, 99, 0, 11, 7, 34, 4, 21, 5, 14, 
    1, 26, 8, 43, 4, 47, 0, 14, 3, 12, 7, 20, 2, 92, 5,  3, 6, 79, 
    7, 31, 4, 69, 6, 49, 3, 82, 8, 32, 1, 61, 0, 67, 5,  6, 2, 13, 
    1,  8, 2, 76, 4, 42, 5, 34, 8, 19, 3, 15, 7, 52, 6, 50, 0, 43, 
    5, 66, 3, 63, 0,  5, 8, 64, 2, 62, 6, 86, 1, 75, 7,  6, 4, 72, 
    5,  1, 8, 37, 6, 98, 2, 68, 3,  2, 7, 21, 0, 22, 1, 56, 4, 86, 
    5, 54, 3, 35, 1, 90, 8,  2, 2, 42, 6, 82, 0, 40, 4, 16, 7, 17, 
    6, 48, 4, 77, 1, 28, 2, 16, 3, 60, 7, 44, 5, 16, 0, 98, 8, 87, 
    5, 38, 0, 72, 1, 20, 8, 81, 3, 34, 4, 42, 2, 72, 7, 20, 6, 14
  };
  const int q4887[] = {
    9, 9, // Number of jobs and machines
    1, 17, 3,  2, 2, 91, 0, 16, 5, 40, 4, 79, 7, 97, 8, 71, 6, 52, 
    7, 53, 0, 12, 2, 96, 4, 17, 1, 35, 6, 46, 3, 85, 8, 30, 5, 43, 
    4, 40, 2, 23, 6, 31, 1, 80, 7, 77, 5, 50, 0, 10, 3, 51, 8, 42, 
    7, 19, 3,  7, 0, 93, 5, 69, 6, 56, 1, 82, 4, 82, 2, 98, 8, 91, 
    4, 97, 2, 79, 1, 10, 8, 75, 5, 84, 6, 69, 7,  7, 0, 63, 3,  6, 
    1, 83, 2, 97, 4, 90, 7, 37, 8, 43, 5, 73, 0, 31, 6, 19, 3,  5, 
    0,  9, 1, 80, 6, 10, 7,  7, 8, 66, 4, 17, 5, 50, 3, 81, 2, 13, 
    1, 84, 7, 71, 0, 35, 4, 11, 8, 95, 5, 59, 3, 80, 6, 30, 2, 93, 
    3, 58, 2, 18, 5, 28, 4, 70, 8, 22, 6, 86, 1, 67, 7, 54, 0, 89
  };
  const int q4888[] = {
    9, 9, // Number of jobs and machines
    2, 52, 7, 41, 6, 63, 1, 44, 0, 25, 8, 82, 3, 61, 5, 51, 4, 44, 
    0, 45, 8, 67, 2, 88, 7, 15, 3,  5, 5, 48, 4, 28, 1, 71, 6, 14, 
    6, 46, 3, 12, 8, 12, 4, 87, 7, 81, 5,  8, 0, 17, 2,  8, 1, 41, 
    0,  9, 2, 21, 6, 31, 4, 68, 8, 30, 5, 53, 3, 54, 7, 37, 1, 15, 
    2, 22, 5, 85, 6, 70, 8, 19, 0, 66, 1, 96, 3, 59, 4, 77, 7, 96, 
    1, 94, 3, 63, 0, 13, 6,  2, 5, 86, 2, 15, 8, 41, 4, 89, 7, 91, 
    4, 22, 5, 12, 3, 53, 7, 18, 0, 25, 6, 33, 8, 69, 2, 25, 1, 90, 
    2,  4, 8, 19, 7, 28, 3, 98, 0, 66, 5, 98, 1, 30, 6, 75, 4,  2, 
    4, 32, 6, 66, 3, 84, 7, 34, 1, 80, 5, 49, 0,  9, 2, 41, 8,  4
  };
  const int q4889[] = {
    9, 9, // Number of jobs and machines
    0, 48, 5, 14, 8, 90, 2, 30, 1, 13, 6, 66, 4, 87, 7, 72, 3, 89, 
    7, 50, 6, 23, 5, 64, 8, 55, 1, 63, 0,  7, 4, 33, 2, 87, 3, 47, 
    2,  8, 0, 54, 5, 13, 3, 47, 1, 96, 8, 95, 7, 32, 6, 64, 4, 67, 
    0,  6, 6, 68, 4, 61, 3, 47, 8, 15, 7, 60, 1, 46, 2, 18, 5,  9, 
    4, 69, 8, 66, 1, 89, 6, 93, 5, 57, 3, 46, 0, 60, 2,  5, 7, 72, 
    0,  6, 7, 30, 3, 51, 5, 81, 1, 37, 4, 49, 2, 79, 6, 96, 8, 28, 
    8,  6, 4, 76, 0, 42, 2, 58, 1, 37, 6, 17, 7,  1, 5, 45, 3, 76, 
    4, 89, 5, 59, 3, 75, 7, 28, 0,  9, 1, 70, 8, 21, 6, 14, 2, 63, 
    3,  4, 2, 58, 5, 32, 1, 33, 0, 45, 4,  6, 6,  6, 7, 80, 8, 40
  };
  const int q4890[] = {
    9, 9, // Number of jobs and machines
    5, 62, 2, 39, 8,  6, 4, 48, 0, 75, 7, 36, 6, 37, 1, 61, 3, 42, 
    5, 88, 7, 56, 3, 23, 0, 66, 2, 94, 1, 66, 8, 74, 6, 55, 4, 18, 
    2, 57, 7, 97, 1, 28, 4, 99, 8, 53, 0,  2, 5, 14, 3, 95, 6,  9, 
    5, 24, 8, 99, 1,  6, 6, 95, 7, 58, 3, 46, 2, 25, 0, 44, 4,  5, 
    2, 90, 6, 22, 4, 54, 0, 94, 1, 55, 8, 14, 5, 55, 7, 19, 3, 42, 
    8, 95, 4, 36, 7,  9, 0, 81, 3, 34, 1,  9, 2, 52, 6,  5, 5, 23, 
    1,  1, 2, 42, 8, 73, 6,  6, 3, 85, 7,  1, 0, 12, 5, 29, 4, 23, 
    6, 96, 4, 94, 3, 64, 0, 41, 1, 53, 8, 98, 2, 48, 5, 21, 7, 94, 
    5, 79, 0, 85, 2, 47, 6, 39, 1, 28, 3, 67, 8, 42, 7, 41, 4, 54
  };
  const int q4891[] = {
    9, 9, // Number of jobs and machines
    4, 39, 6, 30, 7,  6, 8, 17, 5, 36, 2, 41, 1, 12, 0,  4, 3, 11, 
    6, 72, 2, 41, 3, 90, 0, 90, 1, 35, 7, 21, 8, 30, 5, 70, 4, 74, 
    7, 13, 3, 47, 5, 96, 0,  5, 6, 56, 2, 21, 4, 96, 8, 72, 1, 48, 
    7, 99, 6, 96, 0, 33, 4, 14, 3, 22, 8, 68, 5, 92, 1, 99, 2, 66, 
    0, 89, 7, 59, 2, 16, 6, 15, 1, 93, 3, 17, 4, 63, 5, 50, 8, 53, 
    2, 26, 6, 61, 3,  4, 8, 98, 4, 97, 5, 71, 7, 14, 0, 11, 1, 89, 
    6, 36, 3, 83, 8, 28, 2, 38, 4, 13, 0, 20, 7, 63, 1, 30, 5,  9, 
    0, 61, 3, 58, 6,  5, 4, 81, 5, 24, 2, 86, 1, 88, 7, 12, 8,  6, 
    3, 46, 6, 46, 2, 70, 4, 69, 1, 39, 5, 75, 7,  4, 8, 58, 0, 68
  };
  const int q4892[] = {
    9, 9, // Number of jobs and machines
    1, 61, 6, 79, 7, 53, 8, 77, 2,  2, 3, 66, 0, 95, 4, 53, 5, 19, 
    0, 58, 2, 38, 6, 38, 7, 71, 5, 39, 8, 26, 3, 42, 1, 22, 4, 12, 
    0, 96, 8, 30, 3, 99, 1, 53, 2, 83, 5, 22, 7,  3, 4, 11, 6, 30, 
    0, 86, 2, 19, 5, 54, 1, 47, 4, 87, 7, 39, 6, 95, 3, 58, 8,  9, 
    5, 88, 2, 70, 6, 57, 4, 87, 1,  3, 7, 34, 3, 11, 0, 88, 8,  3, 
    0, 17, 5, 62, 1, 79, 8, 60, 7, 18, 3, 61, 6, 75, 2, 26, 4, 72, 
    4, 26, 1, 28, 5, 40, 6, 46, 2, 16, 0, 46, 7, 14, 8, 33, 3, 20, 
    0, 51, 1, 66, 2, 80, 4, 70, 8, 40, 6, 28, 5, 70, 3,  6, 7, 37, 
    3, 83, 0, 46, 7, 33, 5, 74, 1, 34, 6, 65, 2, 84, 4, 16, 8, 79
  };
  const int q4893[] = {
    9, 9, // Number of jobs and machines
    4, 48, 1, 95, 5, 51, 8,  4, 0, 15, 3, 96, 7, 66, 2, 54, 6, 52, 
    4, 72, 2, 54, 0, 23, 6,  6, 1, 23, 3, 31, 7, 88, 8, 29, 5, 86, 
    5, 70, 6, 81, 4, 28, 8, 68, 1, 89, 2, 35, 7, 62, 3, 84, 0, 42, 
    8,  4, 0, 81, 3, 99, 5, 39, 4, 96, 2, 94, 6, 90, 1, 34, 7, 20, 
    1, 51, 2, 91, 6, 62, 0, 42, 8, 27, 5, 12, 3, 47, 4,  9, 7, 17, 
    8, 10, 5, 82, 2, 34, 0,  9, 6, 40, 3, 56, 4, 51, 7, 48, 1, 97, 
    2, 52, 8, 43, 3, 40, 6, 21, 4, 90, 0, 20, 1, 19, 7, 42, 5, 37, 
    1, 34, 6, 80, 2, 99, 5, 74, 0, 76, 4, 84, 7,  2, 3, 64, 8, 13, 
    2, 21, 5, 39, 7, 93, 6, 89, 1, 74, 4, 99, 8, 19, 0, 90, 3, 17
  };
  const int q4894[] = {
    9, 9, // Number of jobs and machines
    8, 21, 6, 52, 0, 73, 7, 19, 1, 80, 3, 91, 4, 78, 2, 20, 5, 22, 
    3, 95, 6, 55, 0,  7, 1, 91, 4, 93, 8, 14, 2, 30, 7, 46, 5, 39, 
    5, 29, 0,  6, 1, 92, 7, 28, 3, 54, 8, 20, 4, 50, 2, 73, 6, 67, 
    1, 35, 2, 80, 7, 41, 3, 14, 8, 21, 6, 13, 5, 36, 0,  9, 4, 39, 
    6, 76, 0, 40, 3, 10, 7, 82, 5, 35, 2, 12, 1, 65, 4, 70, 8,  1, 
    5, 43, 2,  5, 7, 80, 8, 72, 6,  8, 4, 41, 1, 55, 0, 98, 3, 84, 
    3, 62, 1, 78, 4, 85, 7, 50, 5, 67, 8, 29, 6, 43, 0, 70, 2, 89, 
    1, 43, 6, 75, 8, 53, 7, 78, 4, 99, 5, 18, 3, 89, 0, 86, 2, 46, 
    6, 12, 1,  2, 2, 25, 8, 46, 7, 47, 3, 88, 5, 56, 4, 16, 0, 50
  };
  const int q4895[] = {
    9, 9, // Number of jobs and machines
    3,  6, 2, 80, 7, 84, 0, 31, 1, 41, 6, 62, 8, 61, 4, 97, 5, 86, 
    4, 50, 5, 76, 8, 79, 0, 23, 1, 51, 3, 59, 2, 44, 6, 67, 7,  9, 
    1,  9, 0, 23, 7, 24, 8, 23, 3, 68, 6, 15, 4, 12, 5,  2, 2, 10, 
    6, 95, 5, 17, 0, 94, 2, 17, 7, 81, 3, 54, 4, 49, 1, 18, 8, 89, 
    7, 96, 4, 68, 2,  9, 8, 67, 6, 78, 1, 92, 5, 99, 0, 35, 3, 95, 
    8, 26, 0,  8, 4, 54, 5, 61, 1, 51, 7, 57, 2, 44, 6, 42, 3, 46, 
    7, 51, 3, 84, 4, 66, 1, 78, 2, 41, 6, 27, 8, 73, 0, 71, 5, 62, 
    8, 52, 5, 25, 4, 72, 7, 68, 6, 17, 1, 79, 0, 87, 2, 28, 3, 79, 
    4, 28, 5, 58, 6,  3, 3, 57, 0, 33, 1, 78, 2, 11, 8, 71, 7, 21
  };
  const int q4896[] = {
    9, 9, // Number of jobs and machines
    3, 14, 8, 50, 0,  4, 6, 52, 2, 64, 7, 78, 5, 54, 1, 22, 4, 67, 
    0, 14, 4, 15, 3, 28, 6, 46, 8, 41, 7, 54, 5, 74, 2, 13, 1, 89, 
    6, 35, 3, 64, 7, 43, 4, 77, 0, 35, 5, 49, 1, 78, 8, 61, 2, 95, 
    3, 96, 6, 93, 4, 86, 8, 16, 7,  3, 5, 40, 0, 29, 2, 77, 1, 48, 
    3, 81, 7, 44, 0, 76, 1, 57, 4, 37, 8, 61, 2, 67, 5, 55, 6, 53, 
    6, 90, 8, 95, 3, 18, 0, 19, 5, 51, 1, 95, 2, 87, 7, 34, 4, 98, 
    8, 81, 4, 25, 6,  7, 7, 81, 5, 21, 2, 34, 1, 29, 0, 67, 3, 78, 
    0, 66, 3, 92, 6, 55, 4,  5, 5, 78, 2, 50, 1, 16, 7, 12, 8, 67, 
    4, 93, 8, 18, 3, 95, 0, 70, 5, 82, 2, 92, 6, 27, 1, 70, 7, 36
  };
  const int q4897[] = {
    9, 9, // Number of jobs and machines
    4,  2, 8,  2, 6, 38, 1, 34, 5, 38, 2, 74, 3, 97, 7,  6, 0, 95, 
    8, 18, 0, 30, 4, 34, 6,  9, 3,  2, 7, 35, 1, 81, 2, 77, 5, 56, 
    4, 25, 8, 14, 1, 21, 2, 71, 7, 40, 3, 87, 0, 23, 5, 95, 6, 72, 
    2, 64, 5, 61, 7, 18, 1, 57, 3, 89, 8, 52, 6,  6, 4, 28, 0, 22, 
    7, 87, 1, 65, 0, 25, 8, 27, 4, 66, 2, 59, 6, 99, 5, 31, 3, 17, 
    7, 46, 5, 92, 2, 92, 8, 89, 4, 55, 6, 96, 0, 92, 3, 17, 1, 58, 
    5, 11, 4, 82, 3, 99, 7,  8, 8, 39, 2, 67, 1, 62, 0,  6, 6, 58, 
    1, 46, 8, 27, 3, 33, 4, 70, 5, 31, 7, 14, 0, 13, 6, 94, 2, 31, 
    6, 44, 1, 43, 4, 12, 0, 69, 2, 57, 8, 18, 7, 51, 5,  6, 3, 82
  };
  const int q4898[] = {
    9, 9, // Number of jobs and machines
    7, 69, 0, 72, 4, 46, 3, 46, 2, 46, 5, 41, 6, 21, 1,  1, 8, 33, 
    6, 97, 8, 94, 3, 95, 7, 69, 1,  7, 4, 10, 5, 90, 0,  1, 2, 63, 
    5, 27, 7, 83, 0, 30, 3, 88, 6, 47, 4, 34, 2, 44, 8, 84, 1, 13, 
    1, 35, 2, 25, 3, 28, 4, 37, 8,  2, 7, 32, 0, 48, 6, 25, 5,  9, 
    4, 21, 3, 95, 8, 52, 0, 37, 7, 40, 2, 43, 6, 97, 5, 94, 1, 50, 
    4,  6, 1, 92, 6, 83, 8, 13, 2, 33, 0, 50, 5, 61, 7, 63, 3, 98, 
    2, 78, 1, 66, 6, 88, 3, 82, 0,  4, 5, 48, 4, 38, 7, 11, 8, 31, 
    6, 49, 8, 10, 4, 40, 2, 42, 3, 30, 7, 34, 5, 70, 0, 65, 1, 32, 
    1, 73, 6, 93, 4, 85, 5, 80, 7, 67, 0,  9, 8, 39, 3, 74, 2, 90
  };
  const int q4899[] = {
    9, 9, // Number of jobs and machines
    2,  8, 3, 84, 7, 61, 4,  2, 1, 82, 5,  1, 6, 32, 8,  7, 0, 86, 
    5, 18, 3, 65, 2, 70, 8, 66, 6,  6, 4, 79, 0, 84, 7,  3, 1, 36, 
    8, 93, 6,  2, 1, 10, 4, 40, 2, 75, 0, 55, 3, 57, 5, 53, 7,  8, 
    5, 90, 4, 43, 2, 22, 8,  9, 6, 17, 3, 89, 0,  3, 7, 94, 1, 87, 
    8, 31, 4, 41, 2, 95, 0,  5, 6, 32, 7, 54, 5, 50, 3, 34, 1, 65, 
    6, 51, 5, 46, 4, 32, 1, 91, 8,  4, 2, 52, 0, 49, 3, 94, 7, 12, 
    2, 97, 5, 58, 3, 26, 7, 69, 4, 80, 0, 97, 1, 83, 6, 15, 8, 70, 
    7, 13, 3, 55, 8, 60, 2,  6, 0, 64, 1, 86, 4, 29, 5, 62, 6, 62, 
    2, 33, 7, 55, 1, 10, 3, 24, 4, 97, 0, 96, 5, 40, 8, 46, 6, 85
  };
  const int q4900[] = {
    9, 9, // Number of jobs and machines
    4, 78, 2, 72, 5, 42, 7,  7, 1, 23, 0, 79, 3, 20, 6, 63, 8, 14, 
    2, 72, 6, 82, 0, 37, 5, 50, 7, 11, 1, 17, 8, 99, 3,  2, 4, 89, 
    7, 75, 3, 24, 4, 98, 2, 80, 6, 99, 1, 11, 5, 13, 8, 23, 0, 14, 
    1, 94, 0, 11, 3, 50, 2, 38, 8,  1, 5, 65, 4, 15, 7, 91, 6, 88, 
    4, 99, 3, 96, 7, 33, 8, 59, 6, 19, 5, 16, 1, 27, 2, 88, 0, 60, 
    1, 43, 5, 99, 7, 13, 4, 49, 6, 41, 0, 84, 3, 74, 2, 17, 8, 55, 
    7, 27, 8, 16, 5, 32, 6, 76, 0, 15, 1, 87, 2, 73, 3, 73, 4, 69, 
    0, 31, 6, 67, 2, 82, 8, 68, 5, 90, 4, 77, 1, 71, 7, 49, 3, 43, 
    7, 10, 4, 96, 6, 55, 2, 40, 8, 26, 1, 50, 3, 59, 0, 19, 5,  8
  };
  const int q4901[] = {
    9, 9, // Number of jobs and machines
    6,  6, 5, 60, 8, 36, 7, 99, 3, 47, 1,  6, 4,  2, 2, 38, 0, 64, 
    5, 34, 6, 89, 7, 95, 1, 81, 0, 33, 3, 50, 8, 49, 4, 87, 2, 76, 
    4, 71, 1, 33, 5,  1, 6, 42, 2, 24, 0, 80, 3, 44, 7, 96, 8, 24, 
    7, 82, 2, 55, 3, 21, 1, 64, 4, 14, 6, 87, 5, 51, 8, 28, 0, 52, 
    1,  6, 6, 27, 7, 11, 4, 83, 5, 45, 3, 54, 8, 44, 2, 81, 0, 53, 
    5, 53, 4, 84, 8, 16, 7, 60, 3, 93, 6, 37, 1, 51, 2, 28, 0, 46, 
    1, 11, 7, 89, 4, 26, 8, 71, 5, 21, 2, 35, 6, 68, 3, 63, 0,  2, 
    0, 16, 1, 16, 6, 19, 2, 59, 4, 24, 3, 26, 7, 44, 8, 49, 5, 77, 
    6, 18, 4, 36, 8,  7, 5,  1, 2, 52, 1, 26, 0, 25, 3, 75, 7, 88
  };
  const int q4902[] = {
    9, 9, // Number of jobs and machines
    6, 13, 2, 15, 8, 75, 3, 57, 4, 49, 0, 66, 7, 83, 5, 18, 1, 93, 
    6, 36, 8, 42, 1, 76, 2, 33, 0, 82, 5, 83, 7,  9, 3, 28, 4, 37, 
    7, 85, 2, 77, 1, 95, 0, 23, 4, 29, 6, 53, 5, 81, 8,  2, 3, 61, 
    5, 44, 4,  3, 1, 78, 8, 25, 6, 10, 7, 88, 3, 63, 2, 96, 0, 99, 
    6, 35, 0, 22, 8, 95, 4, 74, 1,  5, 3, 84, 7, 34, 2, 22, 5, 36, 
    2, 56, 4, 98, 0, 85, 7, 95, 6, 35, 3,  5, 5, 61, 1, 71, 8, 23, 
    0, 31, 6, 40, 8, 50, 7, 11, 2, 76, 4, 44, 1, 68, 3, 86, 5, 81, 
    8,  5, 6, 97, 4, 76, 2, 25, 1,  7, 5, 29, 3, 48, 7, 14, 0, 93, 
    8,  6, 1, 35, 6, 95, 0, 77, 4,  7, 7, 48, 5, 18, 2, 63, 3, 16
  };
  const int q4903[] = {
    9, 9, // Number of jobs and machines
    4, 49, 3, 20, 7, 69, 8, 42, 6, 73, 0, 98, 2, 77, 1, 89, 5,  3, 
    8, 89, 7, 89, 6, 64, 5,  7, 4, 94, 3, 52, 2,  9, 0, 29, 1, 50, 
    0, 29, 6, 27, 8, 72, 7, 39, 2, 78, 1, 34, 3, 94, 4, 16, 5, 60, 
    3, 94, 1, 43, 2, 22, 5, 99, 0, 55, 8, 60, 7, 65, 4, 30, 6, 48, 
    2, 42, 7,  2, 3, 78, 4, 17, 6,  6, 5, 37, 0,  5, 1, 64, 8, 36, 
    6,  6, 1, 92, 8, 17, 3, 77, 7, 73, 5, 35, 0,  6, 2, 51, 4, 72, 
    6, 29, 8, 83, 0, 85, 2, 67, 5, 32, 3, 37, 4, 84, 7, 79, 1, 77, 
    0, 53, 1, 65, 4, 44, 7, 99, 3, 50, 2, 90, 8, 19, 5, 81, 6, 66, 
    6, 38, 5, 20, 2, 41, 4, 37, 1, 57, 3,  7, 7, 56, 0, 87, 8, 23
  };
  const int q4904[] = {
    9, 9, // Number of jobs and machines
    7, 41, 0, 91, 5, 43, 6, 49, 2, 85, 8, 88, 3, 22, 4, 32, 1, 95, 
    6, 81, 4, 18, 8, 77, 1, 96, 2, 70, 0, 99, 5,  4, 3, 32, 7,  2, 
    4, 88, 6, 77, 1, 53, 0, 13, 5, 51, 8,  1, 2, 92, 3, 81, 7, 97, 
    0, 48, 4, 17, 5, 76, 1, 42, 7, 21, 8, 25, 2, 55, 3, 30, 6, 30, 
    0, 32, 6, 90, 2, 25, 5, 93, 3, 92, 4, 49, 7, 36, 8, 19, 1, 44, 
    0, 23, 8, 25, 6, 59, 5, 49, 1, 66, 2,  7, 3, 54, 7, 10, 4, 30, 
    3, 10, 1, 39, 7, 91, 4, 78, 0, 64, 8, 29, 5, 47, 2, 55, 6,  2, 
    1, 89, 0, 48, 2, 67, 5, 86, 4, 59, 8, 14, 7, 83, 3, 61, 6, 13, 
    0, 77, 5, 78, 8, 19, 2, 63, 1, 79, 6, 40, 7,  3, 3, 57, 4, 98
  };
  const int q4905[] = {
    9, 9, // Number of jobs and machines
    4, 42, 3, 87, 0, 28, 2, 52, 5, 28, 8, 17, 7, 98, 1, 24, 6,  5, 
    3, 66, 1, 30, 7, 63, 0, 26, 2, 77, 8, 63, 6, 79, 4, 82, 5, 37, 
    4, 81, 2, 58, 6, 47, 1, 12, 3, 39, 5, 44, 0, 75, 8, 11, 7, 79, 
    5, 73, 3, 77, 7, 68, 4, 84, 0, 93, 1, 77, 8, 48, 6,  3, 2,  7, 
    4,  6, 7,  7, 1, 80, 0, 10, 2, 99, 5, 26, 6, 47, 8, 70, 3, 45, 
    4, 65, 3, 42, 6, 67, 5, 46, 7, 33, 2, 77, 1, 21, 8, 45, 0, 60, 
    7, 87, 6, 83, 1, 25, 0, 13, 4, 30, 3, 91, 8, 61, 2, 38, 5, 10, 
    1, 80, 0,  2, 6, 35, 4, 71, 2, 24, 5, 18, 8, 27, 3, 80, 7, 29, 
    7, 47, 3, 61, 8, 31, 6, 24, 4, 89, 0, 32, 2, 19, 5, 97, 1, 73
  };
  const int q4906[] = {
    9, 9, // Number of jobs and machines
    4, 86, 1, 84, 3, 81, 5, 15, 2, 52, 6, 12, 7, 48, 0, 92, 8, 30, 
    1, 89, 0, 13, 7, 92, 4, 11, 8, 69, 5, 66, 3, 71, 6, 39, 2, 61, 
    4,  3, 5,  2, 2, 14, 6, 35, 3, 46, 0, 14, 7, 20, 8, 24, 1, 93, 
    1, 48, 3,  7, 6, 92, 2, 20, 7, 61, 5, 81, 4, 60, 0, 45, 8, 38, 
    8, 10, 6, 37, 4, 57, 3, 82, 1, 35, 5, 35, 7, 46, 2, 62, 0, 39, 
    8, 95, 4,  7, 7, 26, 6,  6, 3, 59, 2, 42, 1, 60, 5, 70, 0, 19, 
    3, 57, 4, 70, 8, 74, 0, 87, 2, 70, 7, 19, 5, 19, 6, 46, 1, 29, 
    0, 83, 4, 56, 3, 78, 1, 63, 2, 54, 7, 25, 5, 33, 6, 23, 8, 71, 
    7, 82, 1, 25, 3, 34, 6, 63, 2, 18, 4, 19, 5, 72, 8, 98, 0, 32
  };
  const int q4907[] = {
    9, 9, // Number of jobs and machines
    3, 78, 7, 43, 5, 75, 4, 96, 0, 85, 1, 90, 2, 64, 8, 42, 6, 47, 
    1, 62, 0, 80, 4, 83, 8, 56, 5, 69, 2, 18, 3, 57, 6, 55, 7, 26, 
    1, 71, 8, 27, 5,  4, 6, 24, 0, 13, 4, 50, 3, 60, 2, 31, 7, 88, 
    6, 47, 2, 40, 4, 84, 1, 90, 0, 21, 5, 41, 3, 15, 8, 21, 7, 55, 
    7, 83, 3, 48, 0, 68, 5, 50, 8, 43, 2, 44, 6, 58, 4, 99, 1, 12, 
    8, 25, 7, 95, 5, 92, 4, 84, 3, 55, 6, 60, 0, 36, 1, 73, 2, 66, 
    6, 68, 7, 30, 5, 27, 0,  8, 8, 34, 1, 51, 3, 23, 2, 79, 4, 77, 
    1, 77, 6, 70, 0, 40, 2, 70, 7, 56, 5, 70, 3, 30, 4, 22, 8, 15, 
    0, 15, 5,  1, 4, 77, 1, 38, 3, 70, 8, 29, 7, 13, 6, 71, 2, 72
  };
  const int q4908[] = {
    9, 9, // Number of jobs and machines
    2, 76, 6, 21, 5, 29, 7, 67, 1, 33, 0,  9, 4, 32, 8, 88, 3, 88, 
    0, 69, 3, 41, 4, 39, 8, 18, 6, 84, 1,  9, 5, 66, 2, 25, 7, 85, 
    4, 58, 0, 40, 7, 87, 3, 15, 5, 40, 2, 34, 8, 86, 1, 54, 6, 75, 
    5, 44, 1, 75, 4, 10, 2, 40, 3, 31, 7, 83, 8, 65, 0,  6, 6, 14, 
    3, 37, 6, 77, 4, 84, 0, 69, 1, 63, 7, 53, 2, 94, 8, 99, 5, 67, 
    6, 39, 8, 88, 7, 95, 0, 57, 4, 11, 5, 32, 2, 91, 3, 58, 1, 40, 
    6,  9, 0, 62, 3, 45, 7, 41, 2, 99, 1, 87, 4, 17, 8, 93, 5, 63, 
    3,  3, 0, 88, 7, 42, 2, 84, 5,  6, 8, 65, 4, 68, 1, 65, 6, 85, 
    0, 73, 8, 55, 3, 99, 6, 95, 5, 35, 4, 34, 1, 20, 2, 58, 7, 57
  };
  const int q4909[] = {
    9, 9, // Number of jobs and machines
    3, 52, 0, 39, 2, 92, 4, 47, 7, 91, 5, 70, 6, 93, 1, 98, 8, 33, 
    2,  6, 7, 22, 8,  6, 0, 37, 4, 75, 1, 27, 3, 28, 5, 84, 6, 75, 
    6, 85, 3, 67, 2, 99, 7, 49, 0, 68, 5, 42, 4, 71, 8, 70, 1, 87, 
    5, 62, 1, 17, 3, 68, 0, 62, 8, 98, 7, 27, 6, 62, 4, 32, 2, 97, 
    5, 90, 2, 78, 8, 79, 7, 10, 6, 70, 3, 64, 1, 67, 4, 72, 0, 70, 
    5, 33, 3, 13, 4, 10, 6, 40, 2, 19, 1, 23, 0, 85, 8, 44, 7, 10, 
    2, 39, 3, 56, 7, 51, 6, 65, 1, 11, 8, 64, 0, 57, 4, 20, 5, 80, 
    2, 74, 0, 36, 4, 94, 5, 45, 8, 84, 3, 71, 7, 79, 6, 35, 1, 74, 
    1, 58, 2, 95, 6, 34, 7, 98, 3, 14, 4, 33, 8, 89, 0, 57, 5, 53
  };
  const int q4910[] = {
    9, 9, // Number of jobs and machines
    3,  8, 1,  4, 2, 31, 0, 58, 8, 64, 7, 94, 5, 93, 4, 25, 6, 43, 
    7, 56, 6, 51, 0, 99, 2, 59, 3, 57, 1, 40, 5, 54, 8, 32, 4, 22, 
    6, 89, 4, 73, 8, 68, 2, 69, 7, 87, 1, 59, 3, 82, 5, 94, 0, 42, 
    5, 36, 3, 65, 1, 41, 0,  3, 7, 29, 6, 84, 2, 80, 8, 74, 4, 10, 
    7, 49, 3, 97, 0, 45, 6, 10, 1, 56, 4,  2, 5,  9, 8,  7, 2, 91, 
    3,  1, 2, 20, 4, 36, 5, 26, 7, 98, 8,  8, 0, 94, 6, 30, 1,  2, 
    7, 65, 2, 46, 1, 73, 5, 75, 3, 28, 6, 23, 8, 69, 4, 34, 0, 56, 
    7, 13, 3, 34, 0, 45, 2, 94, 5,  9, 4, 62, 8, 89, 6, 18, 1, 35, 
    3, 41, 5, 51, 2, 33, 6, 63, 4, 83, 0, 13, 1, 31, 8, 73, 7, 88
  };
  const int q4911[] = {
    9, 9, // Number of jobs and machines
    4, 35, 7, 36, 5, 98, 6,  9, 8, 71, 1, 95, 0, 60, 3,  1, 2, 20, 
    5, 47, 4, 39, 8, 34, 2, 74, 3,  7, 6, 17, 1, 28, 0, 39, 7, 12, 
    2, 38, 5, 91, 0, 38, 8, 44, 4, 67, 3, 63, 6, 21, 7, 69, 1,  3, 
    0, 80, 6, 65, 1, 32, 5, 47, 4, 56, 2, 76, 8, 45, 7, 77, 3, 75, 
    5, 52, 7, 77, 0, 10, 8, 85, 2, 36, 3, 78, 6, 33, 1, 65, 4, 25, 
    0, 65, 5, 88, 4, 22, 2, 71, 8,  8, 6, 56, 1, 65, 7, 15, 3, 31, 
    6, 35, 0, 44, 4, 92, 7, 48, 8, 19, 2, 95, 5, 94, 3, 86, 1, 78, 
    7, 82, 6, 49, 3, 84, 5, 58, 8, 41, 4, 88, 1, 75, 0, 97, 2,  6, 
    1, 54, 3, 39, 6, 98, 5, 42, 8, 38, 4, 58, 0, 96, 7, 19, 2, 69
  };
  const int q4912[] = {
    9, 9, // Number of jobs and machines
    1, 98, 4, 25, 5, 88, 8, 79, 7, 99, 3, 40, 0, 62, 6, 55, 2, 67, 
    3, 13, 8, 28, 2, 78, 7, 44, 5, 52, 1, 36, 0, 85, 6, 93, 4, 43, 
    8, 36, 4, 53, 6,  3, 1, 63, 7, 88, 3, 44, 2, 59, 5, 22, 0, 49, 
    3, 89, 2, 32, 0, 28, 5, 20, 1, 23, 7, 75, 8, 91, 6, 89, 4, 42, 
    8, 84, 0, 13, 7,  9, 1, 11, 2, 74, 6, 77, 4, 83, 3, 27, 5, 40, 
    3, 27, 0, 75, 8, 91, 7, 71, 4, 27, 1, 81, 5, 98, 2, 32, 6, 62, 
    4, 57, 3, 80, 8, 20, 2, 39, 7, 18, 5, 35, 6,  2, 0, 82, 1, 66, 
    1, 76, 5, 48, 7, 37, 6, 45, 8, 28, 2, 53, 4,  3, 0, 25, 3, 30, 
    1, 41, 2, 51, 8, 46, 5, 74, 0, 77, 7, 64, 4,  4, 6, 66, 3, 91
  };
  const int q4913[] = {
    9, 9, // Number of jobs and machines
    0, 85, 6, 92, 8,  4, 7,  4, 4, 53, 3, 80, 2, 98, 5, 11, 1,  6, 
    3, 78, 2, 52, 5, 24, 6, 40, 0, 19, 1, 93, 8, 10, 4, 83, 7, 95, 
    8, 84, 0, 29, 5, 50, 2, 57, 7, 46, 6, 65, 3, 40, 4, 25, 1,  8, 
    6, 86, 2,  1, 8, 66, 4, 63, 1, 76, 3, 87, 5, 52, 0, 35, 7, 71, 
    3, 89, 1, 84, 6, 46, 7, 20, 5, 47, 4,  3, 8, 71, 0, 94, 2, 18, 
    7, 61, 2, 94, 0, 99, 1, 61, 3, 39, 6, 38, 8, 97, 5,  8, 4, 33, 
    2, 39, 4, 67, 5, 49, 6, 65, 7, 90, 0, 15, 3, 95, 8, 68, 1, 94, 
    4, 10, 5, 96, 6,  8, 0, 89, 2, 33, 1, 27, 3, 77, 7, 70, 8, 32, 
    8, 80, 0, 13, 2, 14, 3,  7, 5, 72, 7, 22, 4, 15, 6, 92, 1, 54
  };
  const int q4914[] = {
    9, 9, // Number of jobs and machines
    4, 80, 6,  7, 7,  5, 2, 67, 0, 64, 8, 24, 1,  8, 5, 32, 3, 23, 
    4, 69, 2, 46, 6, 75, 5, 92, 3, 20, 8, 12, 1,  9, 7, 69, 0, 78, 
    6, 26, 0, 72, 7, 85, 4, 46, 3, 21, 2, 49, 1, 16, 8, 62, 5, 76, 
    3, 53, 5, 82, 6, 60, 7,  2, 2, 70, 1, 45, 4, 59, 8, 83, 0, 34, 
    5, 75, 1, 78, 2, 90, 7, 34, 3, 88, 8, 58, 0, 76, 6, 61, 4, 70, 
    1, 63, 6, 65, 7, 94, 3, 41, 4, 52, 8, 82, 5, 98, 2, 93, 0, 61, 
    0, 87, 1, 92, 7, 15, 6, 53, 8, 88, 2, 65, 3,  4, 4, 77, 5, 15, 
    0, 84, 6,  8, 2, 84, 1, 43, 3, 59, 4, 25, 7, 31, 8,  4, 5,  7, 
    1, 37, 2, 93, 8, 49, 5, 46, 7, 51, 6, 85, 0, 23, 3,  7, 4, 87
  };
  const int q4915[] = {
    9, 9, // Number of jobs and machines
    4, 50, 3, 17, 0, 30, 1,  9, 7, 26, 8, 94, 6, 34, 5, 91, 2, 41, 
    3, 64, 2,  5, 6, 85, 0, 84, 8, 19, 5, 16, 4, 17, 7, 12, 1, 71, 
    4, 32, 1, 76, 3, 44, 7, 58, 5, 12, 2, 80, 0, 12, 8, 71, 6, 90, 
    1, 85, 3, 11, 5, 39, 7,  1, 0, 36, 4, 91, 6, 29, 8,  6, 2, 36, 
    8, 43, 2, 82, 6, 13, 1, 73, 4, 12, 3, 22, 7, 77, 0, 13, 5, 61, 
    3, 31, 1, 76, 2, 41, 5, 43, 6, 32, 4, 94, 8, 28, 7, 25, 0, 75, 
    2, 73, 5, 74, 4, 65, 1, 37, 0, 93, 6, 68, 3, 71, 7, 73, 8, 54, 
    8, 97, 5,  8, 7, 36, 6, 28, 4, 81, 3, 60, 1, 25, 2, 48, 0, 86, 
    1, 90, 0, 23, 6, 63, 7, 77, 8, 96, 3, 74, 2, 49, 5, 93, 4, 99
  };
  const int q4916[] = {
    9, 9, // Number of jobs and machines
    0, 17, 2, 30, 1, 28, 4, 51, 3,  5, 8, 59, 5, 73, 6, 59, 7, 56, 
    8, 14, 6, 75, 7, 47, 1, 92, 4, 76, 3, 51, 2, 84, 5, 89, 0, 69, 
    6, 38, 1, 42, 2, 23, 4, 15, 8, 41, 5, 10, 0, 27, 7, 33, 3, 38, 
    6, 93, 0, 62, 4, 12, 2, 77, 5, 90, 3, 17, 7, 49, 8, 84, 1, 11, 
    6, 54, 8, 15, 0,  5, 1, 25, 7,  7, 3, 35, 2, 43, 5, 31, 4, 63, 
    1, 99, 2, 22, 7, 90, 6, 91, 4, 63, 3, 14, 0, 77, 8, 53, 5, 15, 
    1, 13, 5, 87, 0, 41, 6, 12, 2, 96, 4, 68, 8, 22, 3, 30, 7,  8, 
    6, 75, 5, 71, 8, 75, 3, 54, 0, 55, 4, 86, 2, 41, 7, 96, 1,  3, 
    5,  3, 4, 97, 7, 15, 8, 27, 0, 73, 1, 47, 2, 30, 6, 65, 3, 19
  };
  const int q4917[] = {
    9, 9, // Number of jobs and machines
    0, 41, 1, 48, 3, 39, 5, 44, 6, 60, 4, 97, 2, 25, 7, 44, 8, 50, 
    6, 75, 0,  8, 2, 63, 3, 96, 7, 10, 4, 72, 1, 54, 5, 28, 8, 27, 
    6, 83, 2, 59, 7, 51, 5, 23, 3, 71, 1, 20, 0,  3, 8, 62, 4,  4, 
    0, 83, 2, 92, 4, 43, 3, 23, 6, 31, 5, 67, 7, 92, 1, 31, 8, 80, 
    4, 32, 7, 67, 0, 19, 3, 47, 8, 27, 1,  6, 5,  1, 6, 45, 2, 96, 
    4, 59, 2, 72, 7, 72, 6, 19, 1, 19, 0, 42, 8, 22, 5, 83, 3, 26, 
    8, 25, 3, 29, 6, 68, 1, 96, 2, 14, 0, 33, 5, 72, 4,  6, 7,  3, 
    2, 15, 8, 76, 6, 88, 5, 52, 1, 56, 7,  8, 0, 41, 3, 55, 4, 99, 
    3, 79, 6, 19, 8, 71, 1, 59, 7, 23, 2, 40, 5, 93, 0, 18, 4, 14
  };
  const int q4918[] = {
    9, 9, // Number of jobs and machines
    7, 44, 5, 28, 4, 13, 1, 84, 0, 27, 8, 19, 6, 96, 2, 84, 3,  3, 
    1, 24, 8, 17, 2, 58, 0, 11, 7, 14, 6,  6, 4,  6, 5, 79, 3, 83, 
    2, 57, 8, 26, 6, 17, 3, 38, 1, 12, 7,  7, 0, 10, 5, 43, 4, 42, 
    1, 37, 4, 30, 6, 56, 2, 47, 3, 18, 8, 87, 7, 79, 5, 70, 0, 20, 
    8, 21, 0, 14, 7, 48, 5, 15, 6, 67, 1, 57, 4, 36, 2, 59, 3, 80, 
    6, 93, 2, 95, 3, 92, 8, 51, 7, 17, 1, 57, 5, 56, 0, 50, 4, 24, 
    8, 56, 7, 86, 6, 82, 3, 47, 4, 29, 0, 65, 1, 96, 5, 21, 2, 89, 
    6, 62, 7, 41, 1, 58, 8,  8, 3, 74, 0, 90, 4,  8, 2, 47, 5, 89, 
    7, 74, 5, 45, 8, 28, 6, 22, 3, 33, 1, 59, 0, 20, 2,  6, 4, 61
  };
  const int q4919[] = {
    9, 9, // Number of jobs and machines
    1, 82, 5, 60, 4, 12, 8, 26, 0, 73, 3, 41, 2, 60, 6, 38, 7, 38, 
    5,  6, 2, 84, 0, 66, 1, 18, 3, 51, 6, 60, 7,  3, 4,  5, 8, 70, 
    2,  5, 3, 35, 7, 36, 8,  4, 1, 31, 5, 33, 0, 36, 6, 52, 4, 63, 
    5, 61, 6, 92, 2,  2, 8, 67, 7, 84, 1, 83, 4, 15, 3, 86, 0,  5, 
    1, 92, 3, 92, 0, 49, 8,  6, 4,  5, 7, 48, 5, 65, 6, 56, 2, 71, 
    7, 99, 3,  1, 1, 97, 2, 20, 8, 20, 4, 89, 6, 25, 0, 38, 5, 69, 
    4, 97, 6, 96, 7, 35, 3, 45, 5, 14, 8, 72, 1, 82, 0, 93, 2, 69, 
    5, 83, 6, 80, 3, 74, 0, 66, 8, 93, 1, 83, 2, 88, 4, 47, 7, 89, 
    2,  3, 6, 12, 3, 32, 8, 17, 4, 98, 0, 13, 1, 10, 7, 48, 5, 78
  };
  const int q4920[] = {
    9, 9, // Number of jobs and machines
    2, 68, 6, 96, 0, 50, 1,  4, 5, 80, 3, 53, 8, 58, 4, 90, 7, 12, 
    6, 42, 4, 61, 2, 59, 5, 51, 3,  3, 7, 32, 0, 99, 8, 65, 1, 97, 
    5,  2, 8,  4, 0, 85, 3, 64, 4, 84, 1, 71, 7, 80, 6, 35, 2, 79, 
    0, 62, 7, 11, 2, 98, 1, 21, 3, 79, 6, 88, 8, 98, 5, 91, 4, 43, 
    0, 44, 5, 23, 2, 24, 1,  5, 8, 71, 7, 21, 3, 66, 6, 10, 4, 68, 
    1, 42, 2, 24, 3, 81, 6, 82, 5, 77, 8, 97, 7, 16, 4, 34, 0, 41, 
    3, 67, 7, 46, 5, 20, 0, 40, 2, 80, 1, 41, 4, 69, 8, 96, 6, 49, 
    4, 37, 6, 54, 5, 69, 3, 77, 1,  9, 8, 80, 7, 61, 2, 60, 0, 37, 
    8, 77, 4, 75, 7, 48, 3, 46, 0, 79, 1, 42, 6, 26, 5, 65, 2, 71
  };
  const int q4921[] = {
    9, 9, // Number of jobs and machines
    2, 13, 0,  3, 8, 56, 5, 71, 6, 66, 4, 89, 7, 70, 3, 35, 1, 21, 
    0, 14, 8, 36, 6, 48, 4,  4, 7, 48, 1, 53, 2, 67, 5, 94, 3, 16, 
    1, 98, 6, 64, 0, 90, 3, 84, 8, 42, 5, 10, 2, 50, 7, 10, 4, 72, 
    4, 84, 0, 34, 2,  2, 3, 90, 6, 18, 5, 15, 8, 74, 1, 72, 7,  6, 
    7, 65, 4, 96, 2,  4, 6, 74, 8,  4, 5, 77, 0,  3, 1, 97, 3, 68, 
    4, 47, 2, 29, 1, 46, 3, 65, 5, 99, 8, 42, 6, 40, 7, 69, 0, 43, 
    6, 20, 0, 78, 3, 68, 8, 95, 4, 64, 1, 26, 7, 74, 2, 75, 5, 35, 
    6,  1, 3, 65, 0, 80, 2, 57, 5, 13, 7, 44, 1, 70, 4, 46, 8, 66, 
    0, 60, 3, 35, 4, 22, 2,  6, 1, 85, 8, 66, 7, 80, 6, 36, 5, 84
  };
  const int q4922[] = {
    9, 9, // Number of jobs and machines
    4, 81, 8, 77, 5, 15, 7, 81, 3, 39, 1, 62, 0, 94, 2, 58, 6, 59, 
    1, 19, 5,  8, 2, 88, 4, 45, 8, 31, 3,  3, 7,  6, 0, 85, 6, 53, 
    4, 72, 7, 47, 5, 99, 8, 63, 1, 49, 6, 84, 3, 41, 0, 35, 2, 67, 
    2, 93, 8,  3, 6, 88, 0, 47, 5, 76, 3, 29, 1, 41, 4, 23, 7, 31, 
    3, 41, 7, 66, 5, 30, 1, 59, 6,  4, 0, 57, 8, 80, 4, 92, 2, 67, 
    6, 43, 1, 77, 4, 10, 3, 66, 5, 46, 2, 38, 7, 36, 0, 85, 8, 20, 
    2, 49, 1, 29, 0, 47, 3, 15, 6, 83, 5, 74, 8, 44, 4, 11, 7,  6, 
    3, 63, 0, 84, 2, 96, 1, 68, 7, 42, 8, 52, 4, 44, 5, 10, 6, 14, 
    2, 49, 3, 76, 0,  4, 7, 89, 5, 61, 6, 98, 8, 67, 4,  9, 1, 80
  };
  const int q4923[] = {
    9, 9, // Number of jobs and machines
    5, 83, 4, 18, 0, 24, 6, 90, 7,  6, 3, 29, 8, 58, 2, 10, 1, 55, 
    6, 71, 4, 78, 3, 11, 8, 81, 0,  1, 5, 44, 2, 11, 1, 37, 7, 74, 
    7, 43, 1, 94, 4, 55, 8, 60, 2, 71, 6,  3, 5, 81, 3, 83, 0, 27, 
    0,  7, 3, 84, 5, 59, 6, 32, 2, 42, 1, 54, 4, 13, 7, 59, 8, 46, 
    6, 33, 1, 94, 2, 34, 8, 68, 7, 78, 0, 62, 4,  1, 5, 46, 3, 52, 
    6,  8, 4, 16, 7, 90, 2, 50, 8, 34, 0,  8, 1, 30, 3, 93, 5, 15, 
    4,  1, 3, 13, 2, 90, 5,  9, 8, 25, 1, 71, 7, 99, 6, 24, 0, 27, 
    6, 17, 4, 43, 5, 42, 7, 23, 1,  6, 3, 14, 8, 17, 0, 37, 2, 70, 
    8, 83, 3, 45, 1, 76, 4, 29, 5, 83, 6, 83, 7,  7, 0, 68, 2, 13
  };
  const int q4924[] = {
    9, 9, // Number of jobs and machines
    0, 92, 4, 50, 8, 65, 1,  9, 2, 19, 5, 65, 6, 57, 3, 79, 7, 43, 
    8, 72, 2, 36, 0, 71, 5, 60, 7, 29, 6, 18, 1, 36, 3, 19, 4, 41, 
    7, 39, 4, 60, 6, 61, 2, 25, 5, 85, 8, 29, 0, 24, 3, 61, 1, 27, 
    4, 87, 0, 89, 3, 27, 7, 17, 5, 31, 8, 14, 1, 67, 2, 88, 6, 10, 
    1, 66, 4,  8, 2, 48, 5, 91, 6, 26, 7, 94, 3, 53, 8,  6, 0,  8, 
    8, 54, 7, 88, 6, 15, 4, 93, 3, 99, 0, 82, 5, 80, 2, 97, 1, 35, 
    2, 16, 7, 84, 5,  3, 0, 25, 3, 80, 4, 12, 6, 94, 8, 80, 1, 80, 
    2, 93, 3, 99, 1, 39, 7, 86, 0, 11, 6,  4, 4,  3, 8, 51, 5,  1, 
    8, 41, 6, 35, 3, 58, 7, 28, 5, 23, 4, 76, 1,  7, 2, 71, 0, 24
  };
  const int q4925[] = {
    9, 9, // Number of jobs and machines
    0, 84, 8, 98, 7, 10, 2, 29, 1, 77, 5, 47, 3, 54, 4, 39, 6,  2, 
    0, 29, 4, 60, 7, 75, 8, 85, 6, 82, 3, 63, 5, 68, 1, 57, 2,  5, 
    8, 39, 4, 23, 1, 64, 6, 49, 7,  8, 2,  4, 5, 40, 0,  1, 3, 56, 
    2, 73, 8, 65, 0, 29, 3, 77, 6, 23, 7, 55, 1, 95, 5, 99, 4, 97, 
    1, 71, 2, 53, 6, 91, 4, 82, 7, 53, 0, 11, 3, 48, 8, 97, 5, 99, 
    3, 84, 5, 16, 2, 14, 1, 79, 4, 90, 6, 76, 0,  3, 8, 64, 7, 53, 
    2, 19, 0, 43, 1, 97, 5,  8, 8, 48, 3, 59, 7, 64, 6, 90, 4, 50, 
    3, 80, 7, 80, 0, 19, 1, 17, 8, 20, 5, 11, 4, 10, 2,  6, 6, 71, 
    1, 89, 2, 59, 7, 86, 4,  6, 3, 66, 0, 71, 5, 73, 6, 16, 8, 59
  };
  const int q4926[] = {
    9, 9, // Number of jobs and machines
    0, 37, 3, 49, 7, 27, 8, 26, 4, 76, 5, 74, 1, 24, 6, 85, 2, 80, 
    7, 39, 6, 23, 4,  5, 2, 42, 8, 56, 1, 81, 5, 13, 0, 24, 3, 42, 
    8, 15, 3, 95, 6, 98, 2, 72, 5, 45, 7, 93, 1, 99, 0, 50, 4, 34, 
    0, 21, 1, 20, 7, 87, 2,  4, 3, 41, 4, 79, 6, 87, 5, 80, 8, 51, 
    6, 95, 1, 55, 5, 86, 4, 85, 2, 71, 0,  4, 3, 60, 7, 19, 8, 10, 
    1, 83, 8, 48, 2, 34, 4, 13, 0, 52, 3, 53, 7, 73, 5, 45, 6, 84, 
    2, 76, 0, 50, 4, 18, 7, 27, 3, 49, 1, 72, 6, 54, 5, 14, 8, 95, 
    1, 11, 2, 73, 0, 78, 8, 12, 6, 50, 7, 39, 4, 99, 3, 54, 5, 84, 
    1, 15, 3, 79, 4, 32, 7, 50, 0, 85, 8, 97, 6,  6, 5, 78, 2, 60
  };
  const int q4927[] = {
    9, 9, // Number of jobs and machines
    6, 21, 2, 99, 8,  4, 1, 60, 5, 89, 7, 41, 0, 74, 4, 25, 3, 25, 
    7, 75, 5,  7, 4, 55, 3, 93, 6,  5, 1, 13, 2, 70, 0, 96, 8, 13, 
    5, 12, 1, 17, 0, 35, 2, 25, 6,  4, 7,  6, 3, 27, 4, 61, 8, 96, 
    5,  5, 0, 24, 1, 80, 7, 63, 2, 65, 4, 34, 8, 66, 6, 60, 3, 84, 
    6, 87, 0, 51, 5, 16, 1, 22, 3, 65, 2, 14, 7,  5, 4, 36, 8, 11, 
    6, 76, 5, 95, 4, 98, 2, 39, 0, 50, 3, 66, 8, 26, 7, 97, 1, 43, 
    2, 55, 4, 49, 0, 70, 8, 87, 1, 60, 7, 88, 5,  1, 3, 52, 6, 76, 
    8, 86, 1, 46, 5, 86, 0, 57, 3, 12, 6, 15, 2, 59, 7, 52, 4, 52, 
    7, 28, 2, 92, 1, 70, 8, 62, 3, 57, 0, 98, 5, 56, 4, 21, 6, 33
  };
  const int q4928[] = {
    9, 9, // Number of jobs and machines
    1, 52, 8, 19, 3, 89, 6,  9, 4, 90, 2, 18, 0, 62, 5, 16, 7, 64, 
    1, 21, 7, 62, 6, 46, 5, 55, 2,  7, 0, 30, 4, 97, 8, 73, 3, 57, 
    2, 92, 6, 27, 4, 94, 8, 19, 5, 98, 3,  4, 1, 38, 0, 50, 7,  4, 
    8, 57, 5, 53, 0, 97, 3, 90, 7, 67, 6, 53, 4, 41, 2, 33, 1, 81, 
    6, 80, 2, 42, 3,  2, 8, 58, 5, 91, 7, 19, 0, 48, 4, 78, 1, 15, 
    8, 71, 3, 64, 4, 84, 6, 86, 7, 59, 2, 57, 5, 39, 1, 85, 0, 66, 
    4,  3, 7,  4, 3, 19, 6, 27, 8, 23, 0, 76, 1, 88, 5, 24, 2, 31, 
    6, 23, 1, 94, 3, 80, 5, 75, 2, 84, 4, 45, 0, 97, 8, 41, 7, 63, 
    0, 95, 2, 20, 4, 33, 3, 40, 8, 85, 5,  2, 7, 73, 6, 26, 1, 77
  };
  const int q4929[] = {
    9, 9, // Number of jobs and machines
    8, 15, 5,  6, 3, 43, 4, 10, 2, 30, 7, 44, 6,  4, 0, 80, 1, 19, 
    6, 35, 1, 74, 4, 37, 3, 39, 5, 29, 7, 71, 8, 17, 2, 54, 0, 20, 
    7, 99, 3, 24, 6, 82, 5, 26, 8, 66, 4, 36, 1, 82, 0, 83, 2, 98, 
    6, 98, 4,  2, 7, 34, 8, 75, 0, 35, 5, 79, 2, 53, 3, 87, 1, 49, 
    1, 53, 0,  2, 8, 75, 7, 93, 4, 51, 6, 95, 2, 37, 5,  7, 3, 26, 
    6, 73, 5, 93, 3, 50, 0, 74, 4, 94, 2, 25, 8, 51, 1, 82, 7, 38, 
    7, 99, 4, 52, 3, 43, 6, 42, 0, 48, 5, 47, 2, 46, 1, 31, 8, 10, 
    4, 98, 7, 87, 5, 29, 1, 76, 3, 69, 8, 28, 0, 93, 6, 50, 2, 97, 
    6, 10, 8, 73, 5, 36, 7, 63, 0, 13, 4, 30, 1, 46, 3, 34, 2, 91
  };
  const int q4930[] = {
    9, 9, // Number of jobs and machines
    7, 88, 8, 37, 3, 50, 6, 55, 0, 43, 2, 42, 4,  2, 1, 64, 5, 86, 
    8, 87, 1,  3, 5, 33, 0, 77, 3,  8, 2, 97, 6, 69, 7, 84, 4, 19, 
    5, 55, 8, 17, 6, 91, 2, 84, 0, 50, 4, 16, 7, 23, 3, 11, 1, 51, 
    6, 23, 2, 34, 0, 40, 3, 93, 4, 75, 7, 93, 8, 46, 1, 34, 5, 99, 
    6, 97, 5,  1, 0, 47, 8, 46, 3, 38, 2, 77, 1, 35, 4, 22, 7, 75, 
    1, 59, 3, 62, 7, 64, 4, 27, 6, 78, 0, 95, 8, 33, 2, 25, 5, 15, 
    0, 60, 1,  7, 6, 24, 4, 25, 3, 95, 7, 76, 5, 31, 2,  1, 8, 94, 
    3,  9, 1, 10, 8, 89, 2, 24, 5, 16, 4, 63, 6, 74, 0, 34, 7, 49, 
    3,  6, 0, 91, 5, 70, 6, 31, 1, 67, 2, 71, 8, 65, 7, 39, 4, 80
  };
  const int q4931[] = {
    9, 9, // Number of jobs and machines
    5, 87, 4, 61, 1, 42, 7, 61, 6, 32, 3, 28, 8, 94, 2, 76, 0, 45, 
    8, 31, 4, 23, 5,  7, 2, 12, 6, 66, 1,  6, 3, 48, 7, 17, 0, 93, 
    7, 92, 6,  1, 1, 30, 8, 20, 5,  5, 3, 30, 2, 23, 0, 11, 4, 14, 
    6, 12, 7, 53, 8, 23, 2, 96, 4, 80, 1, 95, 3, 15, 0, 64, 5, 80, 
    1, 38, 0, 42, 5, 20, 7, 21, 6, 17, 4, 14, 3, 28, 2, 28, 8, 25, 
    8, 26, 6, 45, 0, 22, 5, 79, 1, 16, 7,  4, 2,  9, 3, 88, 4, 72, 
    1, 84, 0, 40, 7, 57, 2, 82, 8, 70, 4, 93, 6,  2, 3, 24, 5, 37, 
    8, 25, 1, 33, 4, 59, 2, 40, 0, 47, 7, 78, 6, 75, 5, 41, 3, 55, 
    8, 88, 2, 43, 1, 37, 6, 33, 0, 91, 3, 18, 5, 50, 4, 94, 7, 56
  };
  const int q4932[] = {
    9, 9, // Number of jobs and machines
    2, 88, 6, 14, 1, 84, 7, 84, 8, 28, 3, 39, 0, 12, 4, 37, 5, 97, 
    6,  3, 7, 99, 2, 64, 3, 68, 4, 97, 8, 17, 0, 83, 5, 24, 1, 88, 
    7, 18, 0, 69, 2, 84, 1, 42, 4, 17, 8, 33, 5, 43, 3,  6, 6, 54, 
    5, 61, 4, 83, 3,  5, 8, 72, 0, 61, 6, 42, 1,  3, 2, 70, 7, 54, 
    6, 31, 2, 86, 3, 19, 4, 39, 7, 67, 0, 94, 5,  4, 8, 10, 1, 81, 
    1, 21, 8,  5, 2, 74, 7, 79, 6,  6, 5, 68, 3, 56, 4, 54, 0, 54, 
    1, 10, 4, 22, 5, 25, 3, 49, 2, 80, 0, 37, 8, 68, 7, 66, 6, 85, 
    8, 81, 1, 13, 5, 11, 6, 76, 7, 36, 3, 23, 2, 33, 4,  9, 0, 67, 
    7, 41, 8, 14, 0, 72, 4, 50, 1, 85, 5, 70, 3, 96, 2, 47, 6, 13
  };
  const int q4933[] = {
    9, 9, // Number of jobs and machines
    4, 23, 6, 40, 3, 38, 0, 34, 2, 38, 7, 54, 1, 96, 8,  8, 5, 49, 
    8, 97, 6, 51, 4,  8, 7, 33, 0, 32, 2,  3, 1, 72, 3, 62, 5, 17, 
    4, 54, 5, 61, 2, 14, 3, 58, 6, 17, 0, 31, 8, 66, 1, 74, 7, 61, 
    2, 97, 0, 38, 8, 53, 5, 43, 4, 41, 6,  8, 1, 29, 7,  7, 3, 50, 
    4, 40, 3, 87, 6,  9, 5, 34, 7, 84, 0,  4, 2, 46, 1, 86, 8, 66, 
    6, 59, 5, 60, 0, 46, 2,  6, 4, 72, 8,  7, 7, 14, 1, 14, 3, 33, 
    2, 85, 3, 78, 7, 32, 6, 92, 5, 34, 4, 49, 8, 79, 0, 72, 1, 34, 
    3,  9, 1,  1, 2, 90, 5, 20, 7, 92, 8, 87, 4, 20, 6,  9, 0, 66, 
    1, 28, 5, 43, 3, 31, 0, 83, 2, 95, 7, 74, 4, 90, 6, 83, 8, 56
  };
  const int q4934[] = {
    9, 9, // Number of jobs and machines
    5, 56, 4, 90, 1, 69, 6, 78, 8, 97, 3, 20, 7, 61, 2, 44, 0, 77, 
    3, 23, 4, 41, 1, 43, 0, 16, 5, 21, 8, 49, 2, 33, 7, 57, 6, 68, 
    8, 78, 4, 64, 3, 78, 1, 70, 7,  6, 6, 37, 2, 64, 0, 16, 5, 59, 
    6, 57, 7, 55, 1, 77, 2, 83, 0, 75, 8, 36, 5, 17, 4, 72, 3, 93, 
    0, 73, 2,  5, 1, 54, 4, 58, 6, 98, 3, 33, 8, 57, 7,  8, 5, 97, 
    5,  2, 3, 35, 4, 50, 1, 91, 2, 23, 0, 41, 7, 18, 6, 97, 8, 52, 
    8, 78, 1, 52, 6,  2, 3, 87, 7, 70, 5, 37, 2,  7, 4, 92, 0, 36, 
    8, 78, 7, 27, 4, 13, 1,  3, 0, 31, 2,  1, 6,  4, 5, 81, 3, 48, 
    3, 73, 1,  7, 6, 42, 8, 61, 7, 53, 2, 90, 4, 35, 5,  1, 0, 26
  };
  const int q4935[] = {
    9, 9, // Number of jobs and machines
    1, 54, 6, 64, 0, 86, 2, 24, 5, 18, 7, 40, 4, 49, 3, 57, 8, 15, 
    6, 23, 3, 71, 2, 66, 1, 18, 4,  5, 0, 37, 5,  2, 7, 88, 8, 24, 
    1, 38, 7, 90, 5, 20, 2, 98, 0, 91, 4,  6, 6, 11, 3, 30, 8, 73, 
    6,  1, 2, 58, 1, 99, 3, 25, 0, 36, 5, 90, 7, 98, 8, 40, 4, 63, 
    7, 43, 3, 60, 2, 29, 6, 28, 0, 75, 8, 18, 4, 80, 1, 47, 5, 59, 
    4,  2, 0, 83, 7, 41, 3, 37, 6, 66, 8,  8, 1, 81, 5, 95, 2,  4, 
    3, 53, 0, 37, 2, 98, 8,  8, 7, 22, 4, 66, 6, 41, 5, 69, 1, 79, 
    3, 37, 5, 64, 0, 35, 4, 93, 7, 83, 1, 65, 2, 32, 6,  3, 8, 13, 
    2, 66, 3, 25, 8, 96, 5, 74, 1, 15, 0, 57, 7, 26, 4, 84, 6, 12
  };
  const int q4936[] = {
    9, 9, // Number of jobs and machines
    4, 53, 1, 59, 2, 57, 7, 85, 3, 85, 5, 30, 6, 95, 8, 19, 0, 48, 
    3, 90, 5, 41, 2, 79, 4, 66, 7, 33, 1, 93, 0, 94, 6, 64, 8, 58, 
    8, 14, 0, 54, 1, 50, 2,  9, 5, 18, 7, 60, 3, 67, 4, 55, 6, 96, 
    6, 46, 3, 22, 4, 36, 5, 78, 1, 57, 8, 47, 7, 16, 2, 59, 0, 24, 
    5, 82, 6, 95, 1, 51, 4, 52, 2, 98, 8, 92, 7, 72, 0,  4, 3, 50, 
    7, 25, 0, 37, 3,  9, 6, 49, 2, 63, 8, 62, 1, 79, 4, 82, 5, 53, 
    5, 90, 8, 50, 3, 18, 6, 53, 0, 94, 1, 51, 7, 17, 4, 35, 2, 33, 
    5,  4, 2, 71, 8, 43, 6, 62, 0, 33, 1, 44, 3, 23, 7, 20, 4, 72, 
    6, 82, 5, 16, 3, 52, 4, 10, 1, 73, 0,  6, 8, 87, 7, 88, 2, 49
  };
  const int q4937[] = {
    9, 9, // Number of jobs and machines
    0, 42, 8, 13, 1, 58, 4,  9, 3, 59, 7, 82, 6,  8, 2, 84, 5, 98, 
    7, 59, 5, 26, 4,  9, 2,  3, 1, 69, 3, 92, 0, 81, 6, 61, 8, 82, 
    0, 78, 4, 75, 1, 58, 6, 47, 7, 76, 8, 39, 3,  4, 5, 47, 2, 99, 
    7, 14, 3, 43, 6, 73, 1, 20, 8, 81, 2, 54, 4,  6, 0, 74, 5, 72, 
    7, 77, 5, 84, 4, 13, 6, 12, 2, 89, 8, 45, 1, 43, 0, 51, 3, 87, 
    2, 95, 6, 78, 1, 84, 5, 21, 3, 99, 7, 11, 0, 80, 8, 54, 4, 37, 
    1, 11, 8, 14, 5, 34, 4, 61, 3, 96, 7, 29, 6, 34, 2, 96, 0,  1, 
    8, 42, 4, 99, 1, 86, 7, 33, 2,  1, 5,  7, 6, 94, 0, 32, 3, 29, 
    6, 55, 3, 89, 1, 98, 4, 58, 7, 19, 5, 40, 0, 41, 8, 10, 2, 44
  };
  const int q4938[] = {
    9, 9, // Number of jobs and machines
    3, 27, 6, 24, 4,  6, 8, 25, 2, 34, 7, 97, 0, 36, 1, 98, 5, 58, 
    3, 88, 1, 95, 2, 42, 4, 77, 5, 89, 6, 14, 0, 73, 8, 24, 7, 22, 
    4, 55, 8, 83, 5, 79, 1, 53, 2, 34, 3, 73, 0, 42, 7, 13, 6, 29, 
    4, 65, 8, 86, 1, 61, 0, 94, 5, 43, 3, 59, 7, 88, 6, 15, 2, 35, 
    2, 15, 4, 39, 5, 49, 7,  5, 1, 71, 3, 69, 0, 19, 6,  2, 8,  6, 
    4, 79, 3, 65, 8, 36, 6, 77, 2, 74, 5, 64, 0, 24, 1, 47, 7, 28, 
    7, 60, 8, 66, 0, 37, 3, 26, 2, 44, 6,  9, 4, 84, 1, 84, 5, 84, 
    4, 60, 8, 10, 2, 91, 7, 22, 1, 51, 0, 48, 3, 88, 5, 50, 6, 50, 
    7, 44, 1, 92, 2, 66, 5, 53, 3, 23, 8, 20, 4, 21, 6, 46, 0, 54
  };
  const int q4939[] = {
    9, 9, // Number of jobs and machines
    0, 66, 5, 38, 8, 54, 7, 12, 1, 81, 3,  2, 2, 19, 4, 16, 6, 39, 
    3, 23, 6, 82, 8, 53, 4, 15, 7, 69, 2, 74, 1, 76, 0, 74, 5, 25, 
    8, 78, 3, 84, 2,  7, 5, 36, 1, 58, 0, 72, 4,  7, 6, 72, 7,  9, 
    1, 34, 3, 27, 0, 54, 7, 44, 4, 81, 5, 48, 8, 58, 6, 75, 2, 26, 
    6, 49, 0, 43, 1, 89, 7, 38, 4, 34, 2,  2, 5, 99, 3, 52, 8, 80, 
    0, 95, 4, 93, 3, 62, 8, 88, 2, 95, 7, 77, 5, 38, 1, 14, 6, 93, 
    2, 24, 3, 50, 6, 62, 4, 42, 0, 84, 5, 47, 8, 27, 7, 95, 1, 60, 
    2, 85, 3, 94, 6, 36, 5, 99, 7, 18, 4, 27, 1, 55, 0, 83, 8,  3, 
    4, 54, 0, 35, 6,  5, 5, 21, 8, 57, 2, 78, 3, 38, 1, 69, 7, 81
  };
  const int q4940[] = {
    9, 9, // Number of jobs and machines
    1, 23, 2, 41, 8, 46, 4, 60, 0, 63, 3, 93, 6, 81, 7, 85, 5, 74, 
    2, 50, 1, 81, 4, 11, 0, 68, 8, 34, 5, 52, 7, 44, 6, 36, 3, 13, 
    2, 42, 8, 42, 7, 78, 4, 61, 3, 86, 5, 96, 6, 83, 0, 14, 1, 19, 
    0, 50, 3, 28, 6, 35, 1, 56, 5, 58, 2, 24, 4, 12, 7, 95, 8, 60, 
    5, 67, 4, 48, 0, 70, 3, 38, 6, 76, 7, 55, 8,  8, 2, 80, 1, 87, 
    6, 37, 8, 83, 0, 23, 1, 45, 3, 15, 4, 27, 2, 60, 7, 90, 5, 32, 
    1, 91, 8,  4, 6,  9, 3, 53, 0, 23, 4, 57, 2, 84, 5, 59, 7, 87, 
    7,  6, 4, 84, 5, 86, 6, 78, 3, 33, 1, 84, 0, 25, 2, 66, 8, 58, 
    5,  7, 4, 14, 7, 32, 3, 21, 6, 74, 1, 59, 2, 20, 0,  6, 8, 93
  };
  const int q4941[] = {
    9, 9, // Number of jobs and machines
    8, 21, 0, 93, 3, 36, 4, 51, 1, 42, 6, 64, 7,  1, 2, 18, 5, 63, 
    8, 27, 4,  7, 1, 92, 6, 50, 0, 61, 5, 14, 7, 91, 2, 30, 3, 69, 
    3, 95, 8, 78, 7, 41, 0, 64, 1, 21, 5, 89, 4,  8, 2, 82, 6, 89, 
    3, 45, 2, 86, 5, 75, 8, 48, 1, 29, 7, 67, 4, 74, 0, 75, 6, 25, 
    2, 99, 7, 79, 1, 53, 6, 35, 3, 48, 4, 61, 5, 90, 0, 99, 8, 58, 
    8, 30, 3, 49, 2, 75, 1, 63, 4, 21, 7, 34, 5, 52, 0, 73, 6, 66, 
    3, 92, 7, 72, 2, 98, 6, 10, 4, 24, 5, 17, 8, 76, 1, 26, 0, 38, 
    7, 40, 2, 78, 3,  7, 4,  6, 5, 28, 1, 75, 6, 46, 0, 48, 8, 79, 
    0, 36, 5, 83, 8, 93, 3, 52, 4, 21, 1, 81, 2, 67, 6, 79, 7, 50
  };
  const int q4942[] = {
    9, 9, // Number of jobs and machines
    6, 57, 7, 84, 0, 89, 2, 21, 8,  3, 5, 26, 1, 41, 4, 39, 3, 75, 
    5, 68, 4, 77, 7, 95, 3, 74, 6, 11, 0, 12, 2, 63, 8, 23, 1, 60, 
    5, 54, 0, 70, 2, 78, 4, 20, 8, 84, 1, 59, 6, 49, 3, 25, 7, 71, 
    2,  8, 8, 64, 4, 91, 6, 62, 3, 19, 5, 86, 7, 85, 0, 58, 1, 64, 
    8, 40, 0, 22, 2, 21, 4, 78, 5, 50, 6, 53, 3, 75, 7, 71, 1, 33, 
    0, 51, 3, 57, 8, 85, 6, 53, 5, 81, 7, 70, 2, 89, 4, 34, 1, 88, 
    8, 22, 3, 55, 2, 22, 7,  9, 6, 85, 5, 50, 4, 43, 1, 72, 0, 89, 
    1, 54, 6, 31, 3, 46, 7, 98, 2, 80, 0, 73, 5, 14, 4, 69, 8, 18, 
    3, 80, 8, 38, 0, 55, 2,  3, 6, 19, 4, 49, 5, 38, 7, 38, 1, 27
  };
  const int q4943[] = {
    9, 9, // Number of jobs and machines
    1, 33, 4, 37, 2, 43, 8, 31, 7, 53, 6, 10, 0, 96, 5,  8, 3, 11, 
    3, 67, 8, 47, 2, 62, 1, 57, 5, 52, 7, 46, 4, 14, 6, 65, 0,  3, 
    8, 15, 1, 82, 0, 43, 7, 55, 2, 34, 3,  8, 5, 28, 6, 42, 4, 27, 
    7, 67, 3, 29, 4, 59, 6, 52, 2, 25, 5, 54, 8, 61, 1, 77, 0, 61, 
    4, 20, 0, 58, 6, 31, 1, 89, 3, 35, 2, 64, 5, 95, 8, 90, 7, 21, 
    4, 38, 7, 42, 5, 96, 2,  6, 0, 89, 6, 84, 1, 78, 8, 72, 3, 24, 
    7, 89, 4, 42, 8, 61, 1, 76, 6, 23, 3, 63, 5, 92, 0,  4, 2, 75, 
    2, 27, 5, 23, 8, 71, 3, 65, 0,  8, 7, 29, 1, 33, 6, 62, 4, 82, 
    3, 23, 6, 99, 5, 36, 0, 82, 8, 95, 7, 37, 2, 21, 4, 48, 1, 88
  };
  const int q4944[] = {
    9, 9, // Number of jobs and machines
    6, 81, 5, 16, 3, 32, 8, 99, 7, 40, 0, 18, 1, 23, 4, 33, 2, 63, 
    2,  7, 6, 16, 1, 67, 8, 12, 7, 15, 4, 41, 5, 62, 3, 78, 0, 23, 
    4,  8, 6, 23, 3, 66, 5, 88, 0,  2, 7, 87, 2,  1, 1, 67, 8, 57, 
    0, 31, 4, 22, 7, 83, 6, 59, 8, 86, 5, 55, 1,  1, 3, 14, 2, 92, 
    5,  7, 1, 39, 7, 67, 8, 67, 3, 41, 2, 76, 6, 33, 0, 43, 4, 73, 
    4, 21, 0, 42, 6,  7, 8,  4, 2, 60, 3, 66, 5, 26, 7, 43, 1, 51, 
    4, 11, 6, 30, 1, 96, 7, 76, 5, 34, 3, 16, 0, 17, 2, 80, 8, 42, 
    2, 43, 5, 96, 1, 32, 3, 85, 6,  1, 4, 42, 8, 76, 0, 51, 7, 19, 
    5, 70, 0, 18, 6,  6, 7,  5, 2, 33, 4, 83, 1, 13, 3, 83, 8, 79
  };
  const int q4945[] = {
    9, 9, // Number of jobs and machines
    4, 80, 6, 87, 5, 80, 2, 17, 3,  1, 1, 44, 8, 21, 0, 54, 7, 28, 
    4, 89, 1, 65, 7,  1, 6, 37, 3, 46, 0, 49, 8, 33, 5,  2, 2, 66, 
    8, 46, 2, 19, 5, 19, 0, 24, 3, 70, 1, 83, 4, 24, 6, 81, 7, 76, 
    1, 86, 3, 65, 0, 93, 6, 24, 4, 20, 7, 26, 8, 67, 5, 98, 2, 93, 
    0, 40, 1, 79, 4, 45, 6,  9, 3, 41, 5, 70, 7, 98, 8, 69, 2, 40, 
    6, 32, 1, 64, 3, 57, 2,  9, 0, 62, 4, 27, 5, 19, 7, 69, 8, 53, 
    1,  3, 2, 16, 8, 54, 5,  4, 4, 47, 0, 16, 6, 71, 3, 14, 7,  6, 
    4, 64, 3, 94, 6,  2, 2, 96, 5, 20, 0, 13, 7, 48, 8, 59, 1, 94, 
    6, 30, 2, 41, 1, 20, 4, 98, 0,  2, 8, 32, 5, 35, 3, 26, 7, 89
  };
  const int q4946[] = {
    9, 9, // Number of jobs and machines
    4, 92, 1, 72, 2, 94, 8, 22, 3, 15, 0, 21, 7, 41, 6, 81, 5, 18, 
    4,  4, 2, 10, 1, 24, 0, 35, 3, 71, 5, 83, 6, 45, 8, 92, 7, 68, 
    0, 10, 3, 84, 5,  4, 1, 55, 6, 18, 2, 63, 7, 13, 8, 39, 4, 64, 
    4, 50, 3,  7, 7, 80, 5, 35, 6,  5, 0, 35, 2, 87, 8, 91, 1, 38, 
    0, 96, 1, 60, 5,  2, 6, 93, 8, 95, 4, 73, 7, 18, 2, 85, 3, 90, 
    7, 31, 8, 93, 5, 39, 3, 80, 0,  9, 4, 44, 2, 99, 6, 79, 1,  7, 
    7, 54, 8, 30, 0, 65, 1, 22, 4, 97, 5, 18, 3, 96, 6, 94, 2, 97, 
    3, 70, 2, 68, 7, 62, 0, 51, 4, 47, 6, 56, 5, 27, 1, 61, 8, 22, 
    7, 53, 0, 91, 8, 72, 6, 57, 1, 40, 2, 81, 3, 27, 4, 24, 5, 92
  };
  const int q4947[] = {
    9, 9, // Number of jobs and machines
    6, 74, 3, 35, 7, 82, 2, 40, 1, 92, 8, 66, 0, 14, 4,  6, 5, 68, 
    2, 51, 8, 74, 3, 74, 1, 39, 0, 58, 4, 26, 6, 72, 5, 13, 7,  7, 
    1, 47, 0,  4, 5, 71, 7, 87, 3, 60, 6, 95, 8, 66, 2,  2, 4, 42, 
    4, 24, 0, 71, 1, 28, 5, 94, 2, 71, 6, 29, 7,  4, 8, 53, 3, 14, 
    7, 44, 1, 41, 6, 43, 5, 70, 3, 59, 0, 99, 8, 67, 2, 91, 4, 64, 
    1, 19, 3, 55, 2, 78, 6, 89, 5,  6, 4, 30, 0, 77, 7, 40, 8, 79, 
    5, 60, 8, 24, 3, 17, 7, 75, 6, 11, 2, 29, 0,  1, 4, 66, 1, 26, 
    1, 99, 2, 69, 8,  5, 3, 38, 7, 81, 0, 33, 4, 25, 6, 49, 5, 98, 
    5, 25, 8,  4, 7, 48, 6, 58, 0, 16, 3, 88, 2, 87, 4, 63, 1, 28
  };
  const int q4948[] = {
    9, 9, // Number of jobs and machines
    8, 58, 7, 16, 6, 47, 5, 31, 2, 84, 0, 34, 4, 53, 3, 72, 1, 31, 
    5, 95, 0, 96, 7, 78, 6, 10, 2, 10, 3,  6, 1, 45, 8, 63, 4, 14, 
    3, 49, 0, 76, 6,  8, 4,  4, 1, 23, 5, 36, 2, 69, 7, 75, 8, 18, 
    7, 61, 0, 81, 5, 90, 1, 26, 8, 98, 6, 79, 3, 22, 2, 97, 4,  5, 
    4, 36, 2, 53, 8,  9, 3, 75, 0, 46, 5, 56, 7, 57, 1,  8, 6, 28, 
    5, 19, 0, 84, 8,  8, 7, 57, 1, 59, 2, 28, 6, 67, 4, 62, 3, 59, 
    1, 42, 4, 55, 3,  2, 8, 67, 5, 88, 7, 55, 6, 54, 2, 37, 0, 50, 
    8, 47, 5, 62, 0, 96, 3, 81, 4, 12, 6,  6, 7, 51, 1, 75, 2, 70, 
    7, 54, 2, 77, 1, 39, 0, 51, 4,  9, 3,  9, 6, 12, 8, 45, 5, 85
  };
  const int q4949[] = {
    9, 9, // Number of jobs and machines
    5, 10, 8, 94, 1, 31, 4, 51, 0, 33, 3, 24, 6, 35, 7, 49, 2, 96, 
    3, 16, 1,  4, 0, 95, 6, 76, 2, 53, 7, 91, 5,  6, 4, 39, 8, 73, 
    1, 33, 5, 16, 0, 98, 2, 48, 3,  7, 7, 58, 6, 64, 4, 53, 8, 64, 
    0, 15, 8,  2, 7, 87, 4, 81, 6, 51, 5, 86, 2, 78, 1, 69, 3, 80, 
    0, 43, 1, 18, 6, 36, 7, 80, 4, 91, 3, 35, 2, 67, 8, 47, 5, 97, 
    5, 48, 2, 85, 1, 98, 6, 61, 0, 18, 4,  5, 3,  6, 7, 73, 8, 74, 
    2, 37, 7, 24, 3, 34, 1, 64, 5, 52, 6, 41, 4, 50, 0, 35, 8, 37, 
    6, 24, 3, 29, 0, 27, 8, 80, 7, 19, 5, 49, 2, 38, 1, 15, 4, 95, 
    0, 95, 4, 18, 6, 47, 1, 50, 7, 54, 2, 84, 3, 25, 5,  4, 8, 76
  };
  const int q4950[] = {
    9, 9, // Number of jobs and machines
    3, 53, 4, 94, 7, 40, 2, 53, 1, 44, 8, 33, 5, 52, 6, 67, 0, 71, 
    6, 68, 2, 48, 3, 68, 0, 40, 5, 86, 1, 35, 8,  4, 4, 56, 7, 19, 
    4, 37, 6, 48, 1, 58, 7, 82, 5,  5, 8, 75, 2, 28, 0, 49, 3, 24, 
    3, 70, 4, 27, 8, 39, 2, 52, 0, 83, 7, 18, 6, 53, 5, 55, 1, 63, 
    7, 55, 8, 72, 4, 40, 5, 95, 2, 64, 0, 94, 1, 58, 6, 72, 3, 65, 
    6, 15, 8, 16, 5, 31, 1, 96, 4, 47, 3, 56, 7, 53, 2, 66, 0, 62, 
    2, 83, 1, 84, 6, 60, 5, 55, 3, 62, 8, 86, 0, 97, 7, 14, 4, 45, 
    8, 13, 7,  4, 0, 77, 1, 35, 3, 42, 2, 63, 6, 82, 5, 75, 4, 69, 
    6,  5, 5, 51, 2,  6, 1, 46, 4, 46, 3, 20, 8, 29, 7, 48, 0, 66
  };
  const int q4951[] = {
    9, 9, // Number of jobs and machines
    2, 44, 4, 97, 1, 13, 3, 92, 7, 96, 6, 58, 8, 56, 0,  6, 5, 56, 
    3, 18, 5, 35, 4, 82, 1, 84, 6, 67, 7, 30, 8, 43, 2, 16, 0, 91, 
    6, 86, 3, 82, 0,  8, 1, 86, 2, 72, 4, 31, 5, 68, 7, 21, 8, 57, 
    5, 70, 8, 42, 6, 31, 3, 84, 4, 12, 2, 41, 7, 54, 0, 51, 1, 29, 
    1, 50, 4, 68, 7,  2, 0,  5, 5, 97, 2, 61, 8, 66, 3, 26, 6, 78, 
    5, 63, 4, 83, 2, 25, 0, 93, 7, 13, 8, 65, 1, 76, 6, 92, 3, 46, 
    5, 26, 2, 31, 8, 46, 0, 40, 4,  4, 1, 67, 3, 96, 6, 13, 7, 22, 
    3, 71, 6, 46, 2, 15, 7, 76, 1, 70, 0, 17, 5, 15, 4, 85, 8, 51, 
    8, 26, 7, 14, 6, 22, 0, 92, 3, 50, 5, 39, 1, 25, 2, 21, 4,  3
  };
  const int q4952[] = {
    9, 9, // Number of jobs and machines
    8, 73, 3, 38, 4, 52, 0, 40, 7, 16, 6, 51, 5, 69, 2, 50, 1, 54, 
    3, 25, 7, 56, 6, 49, 4, 21, 5, 66, 2, 84, 1, 46, 0, 94, 8, 10, 
    0, 10, 4, 72, 5, 97, 6, 52, 8,  5, 7, 62, 1, 67, 3, 95, 2, 77, 
    4, 19, 3, 37, 7, 58, 2, 30, 8,  5, 6,  8, 5,  9, 1, 97, 0, 60, 
    4, 32, 7, 88, 3, 81, 5, 52, 8,  6, 2, 11, 1, 67, 6, 54, 0, 75, 
    0, 89, 3, 96, 2, 31, 1, 26, 8, 37, 6, 83, 4, 87, 5, 22, 7, 50, 
    0, 30, 4, 74, 6, 43, 3, 58, 1, 80, 5, 96, 7, 52, 2, 15, 8, 96, 
    4, 82, 3, 69, 8, 51, 1, 99, 2, 79, 0, 56, 7, 40, 5, 52, 6, 91, 
    2, 18, 4, 23, 6, 94, 3, 37, 1, 29, 8, 57, 0, 46, 5, 90, 7, 57
  };
  const int q4953[] = {
    9, 9, // Number of jobs and machines
    2, 32, 3, 14, 4, 40, 5, 39, 1, 90, 6, 34, 8, 36, 7, 46, 0, 19, 
    8, 89, 3,  6, 1, 91, 6, 67, 5, 39, 2, 58, 0,  4, 7, 92, 4, 55, 
    3, 71, 6, 68, 8, 13, 5, 91, 2, 90, 7, 41, 0, 18, 4, 77, 1, 74, 
    0, 33, 4, 42, 8, 74, 7, 87, 3, 48, 2, 80, 1,  3, 6, 22, 5, 71, 
    3, 29, 1, 91, 6, 10, 2, 60, 7, 98, 5,  5, 4, 10, 0, 27, 8, 46, 
    8, 82, 6, 41, 5,  3, 1, 13, 2,  3, 3, 41, 7, 16, 0, 82, 4, 52, 
    8, 33, 1, 42, 4, 93, 0, 94, 2, 98, 6, 49, 7,  1, 3, 90, 5, 51, 
    2, 89, 1, 12, 4, 40, 7, 40, 3, 13, 6, 39, 0, 52, 5, 10, 8, 58, 
    4, 61, 8, 47, 1, 29, 0, 37, 2, 34, 3, 59, 6, 24, 5, 59, 7, 93
  };
  const int q4954[] = {
    9, 9, // Number of jobs and machines
    4, 46, 2, 45, 8, 75, 3, 52, 5, 40, 6, 29, 1, 23, 0, 52, 7, 64, 
    8, 58, 6, 56, 5, 28, 4, 74, 3, 38, 0, 96, 7, 89, 1, 32, 2, 64, 
    3, 40, 7, 45, 2, 96, 8, 66, 6,  6, 1, 13, 4, 84, 0, 26, 5, 44, 
    6, 90, 2, 30, 8,  7, 1, 67, 7, 48, 4, 95, 5, 37, 3, 38, 0, 50, 
    5, 34, 7, 65, 6, 41, 2, 50, 0, 93, 8, 87, 3, 41, 4, 91, 1, 55, 
    6, 96, 2, 69, 4, 55, 8,  2, 3,  3, 1, 21, 7, 26, 0, 31, 5, 26, 
    8, 62, 1, 77, 2, 74, 4, 13, 0, 15, 6, 50, 5, 66, 3, 28, 7, 82, 
    3, 80, 2, 56, 4, 16, 7, 58, 1, 96, 0, 48, 5, 91, 8, 22, 6,  7, 
    5, 20, 1, 82, 6, 10, 8, 91, 4, 23, 3, 56, 2, 99, 7, 58, 0, 65
  };
  const int q4955[] = {
    9, 9, // Number of jobs and machines
    6, 48, 2, 12, 7, 52, 5, 55, 8, 11, 3, 86, 1, 71, 0, 83, 4, 46, 
    8, 14, 0, 29, 4, 58, 6,  8, 3, 51, 7, 19, 2, 61, 5, 93, 1, 57, 
    5, 46, 7, 31, 1, 30, 6, 12, 2, 36, 8, 85, 4, 51, 3, 12, 0, 62, 
    6, 26, 7, 90, 2, 24, 0, 74, 3, 66, 8, 11, 5, 14, 1, 15, 4, 37, 
    5, 77, 7, 21, 8, 16, 0, 55, 6, 22, 1, 81, 2, 58, 4, 29, 3,  4, 
    6, 69, 7, 94, 4, 53, 8, 23, 1, 62, 0, 26, 2, 69, 5, 14, 3, 84, 
    1, 77, 4, 45, 5, 25, 6,  1, 8,  9, 7, 92, 0, 24, 2, 46, 3, 87, 
    3, 52, 0, 40, 7, 38, 2, 33, 8, 90, 4, 34, 1, 95, 6, 49, 5, 91, 
    7, 52, 0, 61, 2, 62, 8,  7, 1, 59, 3, 61, 4, 45, 6, 62, 5,  4
  };
  const int q4956[] = {
    9, 9, // Number of jobs and machines
    4, 98, 0, 67, 5, 13, 3, 52, 1,  1, 8, 51, 6, 69, 7, 26, 2, 31, 
    3, 10, 2,  5, 1, 87, 6, 36, 7, 71, 5, 13, 0, 42, 4, 48, 8, 46, 
    4, 36, 0,  4, 8, 47, 5, 30, 7, 93, 6, 97, 1, 70, 2, 13, 3,  8, 
    0, 33, 1,  6, 5, 34, 3, 98, 8, 93, 6, 75, 2, 16, 7, 45, 4, 69, 
    1, 67, 3, 52, 8, 46, 5, 52, 7, 89, 4, 90, 0, 88, 6, 90, 2, 29, 
    1, 12, 6, 73, 5, 85, 0, 12, 3, 33, 7, 38, 2, 14, 8, 54, 4, 90, 
    7, 49, 0, 64, 4, 18, 6, 26, 5, 56, 1, 74, 8, 71, 2, 15, 3,  2, 
    1, 37, 8, 38, 4, 92, 7, 23, 3, 91, 0, 23, 6, 69, 5, 42, 2, 71, 
    5, 56, 0, 98, 8, 90, 6, 58, 4, 90, 3,  8, 2, 73, 1, 29, 7, 87
  };
  const int q4957[] = {
    9, 9, // Number of jobs and machines
    3, 91, 8, 54, 0, 94, 7, 44, 5, 94, 4, 13, 2, 28, 6, 97, 1, 11, 
    2, 62, 5, 60, 4,  5, 0, 23, 1, 91, 8, 36, 7, 46, 6, 46, 3, 34, 
    7, 53, 8, 91, 2, 83, 3, 68, 4, 62, 0, 76, 6, 19, 1, 74, 5, 53, 
    5, 30, 3, 60, 1, 28, 0, 39, 8, 62, 6,  7, 2, 85, 7, 52, 4, 47, 
    5, 35, 4, 44, 2, 86, 6, 41, 1, 60, 3, 24, 0, 30, 8, 19, 7, 29, 
    5, 68, 3, 65, 7, 47, 2,  2, 6, 88, 8,  6, 1, 80, 0, 61, 4, 96, 
    6, 35, 3, 46, 4, 96, 5, 40, 7, 34, 0, 44, 1, 26, 2, 87, 8, 29, 
    0, 46, 5, 95, 6, 49, 3,  3, 7, 83, 4,  6, 1, 92, 8, 71, 2, 93, 
    3, 20, 6,  9, 4, 34, 2, 34, 0, 22, 1, 10, 7, 63, 8, 59, 5, 29
  };
  const int q4958[] = {
    9, 9, // Number of jobs and machines
    1, 33, 4, 25, 8,  8, 0, 91, 6,  3, 7, 41, 2, 20, 3, 32, 5,  3, 
    2, 51, 3, 33, 4, 83, 7, 42, 8, 26, 5, 25, 1, 32, 6, 20, 0, 23, 
    8, 66, 1, 52, 4, 47, 2, 63, 3, 83, 7, 87, 0,  9, 5, 20, 6, 44, 
    0, 61, 4, 32, 3, 70, 1, 22, 2, 78, 7, 69, 5,  6, 8, 46, 6, 64, 
    4, 11, 6, 41, 1, 32, 3, 50, 8, 90, 0, 25, 5, 61, 7, 37, 2, 65, 
    2, 12, 4, 46, 7, 31, 5, 46, 3, 86, 8, 34, 0, 44, 6, 80, 1,  9, 
    1, 65, 2, 78, 6, 62, 7, 82, 3, 13, 0, 57, 4, 55, 8, 65, 5, 96, 
    0, 35, 6, 41, 1, 17, 3, 71, 2, 88, 5, 94, 7, 68, 4, 15, 8, 38, 
    6,  1, 0, 36, 2, 34, 1, 99, 8, 39, 4, 41, 7, 41, 5,  9, 3, 64
  };
  const int q4959[] = {
    9, 9, // Number of jobs and machines
    2, 84, 8, 47, 7, 32, 6, 28, 3,  4, 5, 54, 0, 71, 1,  9, 4, 79, 
    0, 23, 5, 12, 6, 72, 2,  8, 7, 48, 3, 18, 4, 82, 8, 43, 1, 80, 
    8, 91, 2, 16, 7, 14, 4, 86, 0, 64, 3, 46, 5,  1, 1, 77, 6, 96, 
    3,  1, 8,  5, 7, 17, 4, 43, 0, 39, 6, 15, 1, 97, 5, 45, 2, 95, 
    3, 56, 6, 25, 4, 29, 0, 52, 8, 36, 2, 70, 1, 91, 5, 10, 7, 69, 
    8, 10, 5, 98, 6, 77, 3, 72, 0, 89, 1, 31, 7, 40, 2, 32, 4, 83, 
    1,  3, 6, 22, 7, 86, 4, 38, 5, 68, 8, 41, 2, 93, 3,  7, 0, 46, 
    5, 61, 1, 20, 8,  2, 3, 35, 6, 52, 7, 30, 4, 83, 2, 84, 0, 79, 
    1, 58, 6, 14, 5, 65, 3, 60, 4, 24, 0, 36, 7, 72, 2, 41, 8, 94
  };
  const int q4960[] = {
    9, 9, // Number of jobs and machines
    8, 85, 7, 68, 2,  7, 1, 11, 6, 66, 5, 22, 3, 28, 0, 92, 4, 87, 
    4, 47, 3, 81, 7, 64, 2, 94, 1, 45, 0, 97, 6, 27, 8, 29, 5, 26, 
    8, 37, 4, 81, 5, 24, 7, 66, 1, 44, 3, 67, 6,  3, 2, 37, 0, 26, 
    4, 45, 8, 69, 3, 28, 2, 54, 1,  2, 7, 78, 5, 19, 6, 83, 0, 60, 
    1, 95, 6, 70, 8, 71, 0, 60, 2, 63, 3, 15, 7, 44, 5, 63, 4, 46, 
    2, 25, 6, 19, 4, 77, 1, 18, 5, 38, 7, 29, 0, 29, 8, 48, 3, 71, 
    6, 16, 5, 18, 0, 71, 4, 23, 2, 32, 7, 99, 1, 19, 3,  3, 8, 83, 
    7, 58, 4, 97, 1, 47, 3, 11, 8, 43, 6,  7, 0, 66, 2, 17, 5, 43, 
    5, 96, 3, 67, 8, 23, 1, 12, 4, 69, 0, 22, 6, 52, 2, 49, 7, 10
  };
  const int q4961[] = {
    9, 9, // Number of jobs and machines
    6, 54, 1, 23, 3, 28, 4, 40, 2, 65, 8, 49, 7, 55, 0, 87, 5, 56, 
    2, 60, 0, 42, 4, 23, 1, 10, 8, 22, 7, 98, 5, 24, 6, 29, 3, 31, 
    6, 59, 2, 70, 0, 62, 4,  7, 1, 49, 3, 31, 8, 26, 7, 90, 5, 80, 
    3, 41, 6, 81, 7, 33, 4, 32, 5, 21, 1, 93, 0, 32, 8, 70, 2, 48, 
    3, 97, 1, 14, 7,  7, 2, 31, 8, 70, 0, 45, 5, 92, 4, 62, 6, 14, 
    1,  8, 7, 12, 5, 75, 8, 88, 4, 37, 0, 70, 2, 89, 6, 90, 3, 64, 
    3, 64, 0, 66, 6, 95, 2, 96, 7, 91, 1, 98, 4, 97, 5, 78, 8, 45, 
    4, 39, 1, 22, 2, 13, 8, 80, 7, 23, 5, 30, 6, 69, 0, 75, 3, 60, 
    1,  5, 6,  7, 7, 67, 4, 69, 8, 98, 3, 66, 5, 95, 0, 93, 2, 25
  };
  const int q4962[] = {
    9, 9, // Number of jobs and machines
    6, 91, 8, 74, 3,  1, 2, 39, 1, 59, 5, 57, 7,  6, 0, 63, 4, 56, 
    4,  3, 7, 89, 0, 84, 8, 15, 6, 14, 5, 73, 1, 14, 3, 69, 2, 22, 
    6, 93, 3, 20, 5, 20, 7, 25, 0, 30, 1, 25, 4, 69, 2, 97, 8, 32, 
    6, 26, 0, 52, 3, 30, 4,  9, 1, 46, 7, 84, 5, 43, 8, 85, 2, 37, 
    2, 96, 7, 46, 8, 40, 1, 98, 5, 38, 6,  5, 3, 61, 4, 75, 0, 64, 
    5, 37, 8, 42, 0, 69, 7, 60, 4, 11, 2, 48, 6, 36, 3, 94, 1, 62, 
    7, 74, 3, 87, 8, 34, 5, 56, 2,  9, 6, 41, 4, 91, 1, 11, 0, 45, 
    5, 62, 2, 48, 8, 31, 3, 16, 4, 67, 7, 32, 1, 54, 0, 99, 6, 95, 
    1, 81, 6, 20, 3, 99, 5, 21, 4, 78, 7, 97, 8, 49, 0,  8, 2, 17
  };
  const int q4963[] = {
    9, 9, // Number of jobs and machines
    7, 97, 8, 13, 0, 36, 5, 87, 6, 10, 4, 47, 2, 26, 1, 95, 3, 24, 
    2, 73, 6, 30, 1, 53, 0,  8, 3, 67, 7, 42, 4, 71, 8, 41, 5, 34, 
    2, 41, 3, 31, 1,  3, 6, 13, 5, 84, 8,  5, 0, 99, 4, 76, 7, 56, 
    0, 72, 3, 14, 2, 77, 1, 44, 7, 33, 4, 92, 6, 87, 5, 36, 8, 22, 
    4, 54, 1, 29, 5, 48, 0, 90, 6,  6, 2, 13, 3, 11, 7, 61, 8, 94, 
    3, 19, 1, 57, 7, 69, 8, 18, 5, 83, 4, 46, 0, 18, 6, 67, 2, 98, 
    0, 31, 4, 35, 1, 86, 6, 78, 8, 11, 3, 11, 5, 46, 2, 98, 7, 89, 
    1, 89, 3, 25, 7, 32, 8, 23, 6, 60, 0, 13, 4, 95, 5, 36, 2, 24, 
    4, 50, 6, 71, 0, 76, 5, 66, 3, 25, 1, 58, 7, 56, 2, 53, 8, 82
  };
  const int q4964[] = {
    9, 9, // Number of jobs and machines
    4, 69, 0, 82, 6, 91, 1, 63, 2, 70, 5, 70, 7,  4, 3, 37, 8, 38, 
    4, 64, 3, 36, 5, 19, 6, 70, 2,  5, 7, 59, 0, 24, 8, 53, 1, 31, 
    5,  6, 6, 72, 1, 57, 2, 82, 8, 12, 4, 37, 7, 29, 3, 45, 0, 98, 
    1, 55, 3, 80, 0, 57, 8, 62, 5, 45, 2, 73, 7, 15, 4, 94, 6, 13, 
    1, 77, 4, 69, 0, 20, 6, 76, 5, 48, 2, 11, 8, 20, 3, 29, 7, 67, 
    3, 92, 2, 72, 0, 97, 4, 56, 5, 46, 7, 36, 8, 30, 1, 39, 6, 18, 
    6, 98, 2, 93, 8, 10, 4, 49, 3, 18, 5, 34, 0, 80, 7,  5, 1, 52, 
    6, 52, 0, 99, 7, 80, 3, 84, 4, 67, 5, 53, 1, 37, 2, 78, 8, 41, 
    4, 62, 2, 67, 8, 58, 5, 70, 0, 19, 1, 94, 6,  8, 7, 79, 3, 73
  };
  const int q4965[] = {
    9, 9, // Number of jobs and machines
    7,  5, 2, 64, 3, 68, 6, 17, 0, 89, 1, 71, 4, 26, 5, 78, 8, 65, 
    3, 65, 2, 93, 6, 50, 5, 12, 1,  5, 4, 53, 8, 48, 0, 96, 7, 32, 
    6, 45, 7, 49, 8, 32, 2, 18, 4, 35, 1, 31, 5, 93, 0, 21, 3, 40, 
    1, 89, 7,  9, 8, 59, 4, 61, 6, 30, 3, 63, 2, 63, 5, 27, 0,  5, 
    1, 89, 8,  5, 5, 30, 2, 53, 3, 62, 0, 78, 7, 29, 4, 26, 6, 44, 
    1, 15, 4, 11, 3, 11, 6,  4, 7, 95, 2, 85, 8, 89, 0, 68, 5, 82, 
    8, 50, 2, 19, 6,  3, 7, 77, 3, 14, 4, 79, 1, 87, 5, 68, 0, 67, 
    6, 82, 4, 91, 7, 62, 2, 88, 5, 96, 0, 47, 3, 18, 8, 31, 1, 52, 
    3, 69, 1, 36, 8, 85, 5, 64, 6, 77, 7, 56, 2, 74, 4, 89, 0, 17
  };
  const int q4966[] = {
    9, 9, // Number of jobs and machines
    2, 68, 6, 52, 0, 27, 5, 31, 4, 42, 7, 72, 8, 96, 3, 46, 1, 93, 
    4, 63, 3, 72, 7, 47, 6, 11, 0, 57, 2, 59, 1, 68, 5, 54, 8, 78, 
    4, 16, 6, 97, 8, 28, 1, 62, 0, 26, 7, 59, 5, 77, 3, 38, 2, 52, 
    3, 75, 5, 33, 1, 52, 8, 69, 0, 17, 7, 80, 2, 37, 6, 25, 4, 36, 
    5, 72, 1, 76, 3,  6, 7, 44, 2, 28, 6, 95, 0, 68, 4, 99, 8, 62, 
    3, 95, 5,  3, 2, 77, 7,  5, 1, 46, 4, 55, 6, 62, 8, 41, 0, 60, 
    7, 67, 8, 45, 6, 35, 4, 67, 0, 25, 1, 12, 3, 65, 2, 13, 5, 59, 
    4,  4, 3, 61, 0, 40, 1, 84, 6, 23, 2, 29, 7,  1, 5, 29, 8, 69, 
    1, 26, 2, 37, 5, 71, 3, 76, 0, 61, 7, 87, 8, 83, 6, 64, 4, 35
  };
  const int q4967[] = {
    9, 9, // Number of jobs and machines
    0, 79, 2, 78, 7, 33, 3,  3, 8, 82, 1, 17, 6, 60, 4, 39, 5, 72, 
    0, 14, 2, 87, 6, 78, 4, 99, 7,  1, 3, 53, 1, 23, 8, 17, 5, 12, 
    6, 46, 8, 46, 0, 40, 1, 33, 2, 85, 3, 21, 5, 37, 7, 71, 4, 21, 
    6, 40, 2, 89, 4, 74, 1, 22, 5,  3, 7, 38, 3, 35, 0, 18, 8, 72, 
    5, 40, 6, 40, 1, 38, 3, 78, 2, 30, 4, 85, 0, 88, 7, 24, 8, 28, 
    3, 50, 6, 62, 0,  1, 4, 89, 5, 14, 2, 22, 8, 65, 7, 51, 1, 28, 
    2, 97, 4, 55, 6, 97, 7, 74, 0, 90, 5, 94, 8, 61, 1, 55, 3, 41, 
    7, 29, 6, 73, 4, 55, 1, 69, 0, 81, 2, 94, 5, 99, 3, 52, 8, 81, 
    5, 88, 6, 16, 0, 55, 2, 23, 4, 95, 1, 94, 8, 72, 3, 29, 7, 33
  };
  const int q4968[] = {
    9, 9, // Number of jobs and machines
    8, 61, 3, 65, 6, 21, 7, 33, 2, 75, 0, 30, 4, 67, 5, 83, 1, 46, 
    1, 38, 6, 66, 4, 96, 7, 67, 0, 80, 3, 98, 5, 10, 2, 37, 8, 89, 
    5, 54, 3, 77, 4, 72, 8, 79, 0, 58, 2,  4, 6, 17, 7, 32, 1, 61, 
    1, 21, 2, 80, 3, 59, 4, 99, 5, 91, 8, 37, 0,  3, 6, 43, 7, 66, 
    6, 46, 4, 49, 7, 45, 2, 96, 8, 67, 0, 89, 3, 95, 1, 93, 5, 90, 
    0, 67, 7, 52, 1, 85, 6, 87, 8, 32, 2, 99, 4,  5, 3, 46, 5, 52, 
    5,  1, 4,  7, 6, 97, 0, 43, 1, 26, 8, 63, 3, 59, 2, 18, 7, 60, 
    3, 21, 2,  7, 7, 94, 1, 85, 5, 77, 6, 18, 4, 45, 0, 94, 8, 43, 
    6, 89, 2, 17, 8, 73, 7, 85, 4, 95, 3, 63, 0, 10, 5, 54, 1, 42
  };
  const int q4969[] = {
    9, 9, // Number of jobs and machines
    6, 78, 2, 26, 8, 98, 5, 45, 1, 81, 0, 56, 7, 60, 3, 46, 4, 94, 
    5, 43, 0, 13, 2, 31, 8,  5, 3, 60, 1, 25, 6, 47, 4, 82, 7, 73, 
    5, 75, 8, 91, 4, 70, 2,  9, 6, 91, 3, 43, 0,  1, 1, 91, 7, 50, 
    1, 54, 2, 71, 0,  8, 4, 12, 5, 62, 6, 89, 3, 72, 8,  6, 7, 35, 
    3, 19, 4, 77, 6, 35, 2, 35, 0, 19, 1, 49, 8, 93, 7,  7, 5, 95, 
    3, 47, 2, 11, 1,  3, 8, 39, 6, 23, 0, 72, 5, 39, 4, 21, 7, 15, 
    2, 70, 3, 17, 6, 21, 4, 30, 5, 85, 1, 84, 0, 78, 8, 66, 7, 99, 
    4, 22, 3, 67, 6, 43, 0, 59, 2, 69, 8, 67, 7, 40, 1, 79, 5, 74, 
    7, 52, 0, 69, 4, 89, 5, 36, 3, 95, 2, 67, 1, 78, 6, 88, 8, 51
  };
  const int q4970[] = {
    9, 9, // Number of jobs and machines
    6, 21, 4, 65, 8,  2, 5, 66, 1, 65, 2, 26, 0, 96, 7, 43, 3, 41, 
    3, 97, 2, 39, 0, 97, 4, 38, 7, 82, 5, 85, 6, 90, 8, 35, 1, 62, 
    7, 66, 5, 83, 3,  2, 6, 21, 0, 81, 4, 70, 1, 45, 8, 42, 2, 12, 
    2, 98, 7, 38, 5, 61, 6, 70, 3, 66, 4, 26, 1, 86, 8, 30, 0, 48, 
    0, 85, 7, 83, 4, 95, 2, 98, 1, 90, 5,  4, 6, 35, 8, 56, 3, 84, 
    7, 11, 6, 69, 0, 84, 3, 20, 8, 32, 1, 33, 2, 43, 5, 61, 4, 66, 
    0, 77, 4, 83, 2,  7, 8, 61, 3, 33, 5, 10, 7, 67, 1, 77, 6, 46, 
    0, 29, 5,  4, 1, 60, 3, 30, 2, 57, 4, 40, 8, 95, 7,  7, 6, 86, 
    4,  4, 6, 94, 1, 66, 2, 39, 0, 41, 8, 37, 3, 67, 7, 63, 5, 92
  };
  const int q4971[] = {
    9, 9, // Number of jobs and machines
    4, 10, 3, 75, 7, 98, 1, 17, 5, 53, 6, 91, 8, 42, 0, 88, 2, 35, 
    6, 66, 8, 27, 4, 86, 2, 93, 3, 23, 7, 94, 5, 61, 0, 58, 1, 52, 
    5, 97, 1, 45, 4, 88, 8, 16, 3, 99, 0, 78, 7, 74, 2, 75, 6, 21, 
    2, 23, 5,  2, 0, 13, 1, 57, 6, 61, 3, 66, 8, 69, 4, 48, 7, 66, 
    6, 22, 0, 79, 4, 37, 5, 38, 1, 96, 8, 81, 3, 70, 7, 25, 2, 61, 
    7, 93, 6, 53, 8, 73, 4,  2, 3, 36, 5, 17, 0, 98, 2, 88, 1, 36, 
    1, 67, 4, 45, 8, 79, 2, 82, 0, 99, 6,  2, 5, 94, 3, 77, 7, 53, 
    8, 17, 7, 50, 3, 34, 6, 71, 4, 68, 5, 73, 1, 59, 2, 77, 0, 99, 
    7, 34, 4,  8, 5, 73, 3, 48, 1, 99, 6, 55, 8, 45, 2, 60, 0, 46
  };
  const int q4972[] = {
    9, 9, // Number of jobs and machines
    6, 88, 0, 32, 4, 49, 1, 99, 5,  6, 3, 19, 7, 51, 2, 67, 8, 42, 
    2, 98, 8, 57, 5, 18, 4, 84, 0, 62, 6, 43, 1, 18, 7, 26, 3, 55, 
    1, 76, 7, 94, 5, 67, 4,  5, 8, 29, 0, 52, 2,  7, 3, 84, 6, 28, 
    3, 17, 6, 87, 4, 85, 8, 31, 7, 87, 1, 22, 5, 62, 2, 84, 0,  1, 
    3, 38, 8, 89, 4, 44, 6,  1, 2, 63, 5, 41, 0, 98, 7, 38, 1, 36, 
    8, 80, 0, 66, 2, 19, 4,  1, 1, 68, 6, 41, 5, 67, 3, 28, 7, 71, 
    7, 88, 2,  6, 3,  6, 1, 70, 0, 92, 8, 97, 4,  5, 6, 95, 5, 35, 
    0, 73, 8, 85, 4,  8, 7, 12, 3, 54, 2, 39, 6,  5, 5, 40, 1,  7, 
    0, 91, 1, 10, 2,  7, 3, 35, 6, 77, 4,  9, 8, 75, 7, 83, 5, 23
  };
  const int q4973[] = {
    9, 9, // Number of jobs and machines
    1, 84, 3, 91, 2, 39, 6, 94, 8, 30, 5, 11, 7, 80, 4, 13, 0, 68, 
    6,  7, 0, 56, 1, 37, 7, 24, 5, 39, 4,  7, 8,  8, 2, 46, 3, 76, 
    1, 33, 2, 28, 6, 18, 4, 82, 5, 98, 3, 41, 7, 47, 8, 16, 0,  2, 
    4,  5, 3, 81, 1, 73, 0, 60, 5, 47, 8, 76, 2, 90, 7, 30, 6, 66, 
    8, 60, 0,  2, 5, 90, 3, 44, 1, 72, 6, 81, 4, 21, 7,  4, 2, 95, 
    2, 82, 6, 44, 1, 82, 5, 27, 4, 18, 7, 39, 0, 75, 3, 42, 8, 63, 
    1, 51, 0, 28, 4, 43, 6, 22, 3, 86, 8,  9, 7, 33, 5, 35, 2, 27, 
    5, 56, 7, 46, 0, 51, 1, 40, 6, 46, 4, 42, 2, 71, 8, 22, 3,  3, 
    6, 29, 4, 92, 7, 49, 0, 23, 1, 89, 2, 37, 8, 75, 5, 27, 3, 88
  };
  const int q4974[] = {
    9, 9, // Number of jobs and machines
    0, 48, 6, 86, 3, 81, 4, 57, 5, 23, 7, 12, 2, 12, 1, 18, 8, 68, 
    7, 71, 0, 55, 8, 54, 1, 68, 5,  8, 6, 83, 2, 45, 4, 81, 3, 32, 
    3, 66, 7, 74, 6, 88, 1, 67, 4, 42, 0, 13, 5,  6, 2,  8, 8, 77, 
    0, 15, 4, 43, 2, 87, 6, 84, 7, 54, 3, 19, 8, 51, 5, 17, 1, 54, 
    3,  5, 2, 35, 1, 91, 4, 37, 8, 62, 6, 51, 5, 72, 7, 31, 0, 76, 
    5, 68, 7, 94, 2, 63, 1, 98, 6, 63, 0, 68, 3, 91, 4, 61, 8,  3, 
    5, 71, 0, 94, 6, 84, 7, 56, 1, 59, 4, 96, 3, 34, 8,  9, 2, 72, 
    2, 21, 7, 11, 6, 14, 5,  7, 0, 89, 1, 84, 3, 66, 8, 26, 4, 69, 
    1, 42, 0, 22, 7, 47, 4, 52, 6, 34, 2, 55, 5, 34, 3, 42, 8, 88
  };
  const int q4975[] = {
    9, 9, // Number of jobs and machines
    0,  4, 6, 18, 5, 21, 8, 31, 4, 86, 7, 52, 2, 28, 3,  7, 1, 44, 
    5, 80, 1, 42, 4, 89, 2, 78, 3, 27, 6, 25, 8, 85, 7, 72, 0, 37, 
    4, 29, 0, 39, 1, 69, 6, 21, 5, 84, 3, 74, 2, 77, 8, 74, 7, 45, 
    4, 82, 8, 62, 2, 14, 6, 45, 5, 73, 0, 68, 7, 64, 3, 44, 1, 94, 
    3, 77, 0, 91, 6, 11, 5, 19, 7, 65, 2, 29, 8, 42, 1, 77, 4, 43, 
    6, 54, 1, 86, 4, 14, 8, 99, 2, 47, 7, 39, 5, 66, 0, 57, 3, 33, 
    7, 15, 6, 93, 4, 50, 3, 52, 0, 62, 8, 32, 1, 91, 2, 44, 5, 33, 
    7, 49, 8,  8, 1, 10, 2, 33, 6, 50, 0, 63, 3, 34, 5, 82, 4, 24, 
    4,  5, 7, 23, 8, 44, 0, 15, 3, 58, 2, 17, 6, 99, 1, 92, 5, 57
  };
  const int q4976[] = {
    9, 9, // Number of jobs and machines
    5, 49, 0, 84, 7, 85, 1, 28, 2, 60, 4, 93, 6, 12, 8, 37, 3,  3, 
    4, 33, 5, 22, 1, 99, 8, 74, 6, 45, 7, 93, 2, 54, 0, 97, 3, 77, 
    8, 87, 2, 43, 0,  1, 7, 16, 5, 63, 4, 33, 6, 65, 3, 83, 1, 20, 
    0, 44, 8, 11, 5, 46, 2, 11, 6, 88, 7, 32, 4, 47, 3, 25, 1, 69, 
    0, 10, 4, 16, 8, 57, 1, 27, 6, 28, 5, 26, 3, 55, 2, 94, 7, 62, 
    0, 20, 4, 19, 8, 34, 1, 94, 3, 45, 6, 71, 7, 62, 5, 66, 2, 86, 
    6, 73, 1, 66, 5, 27, 3, 66, 0, 80, 4, 28, 2, 49, 8, 11, 7,  5, 
    4, 47, 1, 52, 2, 80, 0, 36, 6, 18, 5, 61, 7, 67, 8, 48, 3, 93, 
    4, 69, 1, 89, 2, 32, 7, 93, 6, 95, 3, 94, 5,  7, 8, 59, 0, 40
  };
  const int q4977[] = {
    9, 9, // Number of jobs and machines
    3,  3, 1,  1, 6, 97, 8, 88, 4, 32, 5, 80, 0, 40, 7, 59, 2, 31, 
    5, 96, 1, 27, 4, 10, 2, 83, 0, 38, 7, 93, 8, 33, 3, 89, 6, 92, 
    3, 55, 0, 46, 1, 40, 7, 89, 2, 57, 8, 88, 4, 87, 6, 56, 5, 77, 
    8,  6, 3, 88, 7, 46, 0, 68, 4, 62, 5, 68, 1, 79, 6, 34, 2, 53, 
    7, 71, 3, 73, 5, 55, 8,  5, 0, 49, 6, 10, 2, 93, 4, 54, 1, 43, 
    4, 35, 1,  5, 7, 60, 6, 86, 5, 24, 3, 71, 0, 41, 8, 96, 2, 51, 
    2, 13, 7,  7, 1, 40, 6, 76, 4, 62, 3,  2, 8, 32, 0, 12, 5, 28, 
    8, 11, 7, 79, 4, 65, 3,  3, 5, 75, 1, 90, 0, 26, 6, 85, 2, 98, 
    1, 90, 8, 44, 7, 54, 3, 24, 2, 78, 5, 52, 4,  6, 6, 66, 0, 70
  };
  const int q4978[] = {
    9, 9, // Number of jobs and machines
    5, 80, 8, 39, 7, 31, 3, 69, 4, 92, 2, 42, 6, 94, 1, 71, 0, 19, 
    7, 62, 8, 98, 6, 15, 0, 33, 5, 31, 1, 30, 2, 39, 3, 74, 4, 75, 
    3,  7, 4, 11, 8,  8, 5,  3, 7, 69, 0,  9, 2, 38, 1, 21, 6, 72, 
    2, 95, 0, 39, 5, 27, 4, 96, 6, 45, 1, 66, 8, 52, 3, 83, 7, 70, 
    7, 30, 4, 63, 5, 36, 1, 70, 8, 12, 0, 59, 3, 57, 2, 11, 6, 64, 
    5, 17, 3, 67, 7, 40, 6, 67, 4, 96, 2, 49, 1,  3, 0, 95, 8, 28, 
    5, 56, 4, 51, 1, 62, 7, 90, 2, 25, 0, 94, 8, 16, 6,  3, 3, 35, 
    0, 72, 2, 88, 5, 73, 4,  8, 6,  6, 8, 80, 1, 37, 7, 39, 3,  6, 
    5, 13, 4,  9, 0, 11, 2, 86, 6, 79, 1, 79, 7, 62, 8, 57, 3, 77
  };
  const int q4979[] = {
    9, 9, // Number of jobs and machines
    3, 59, 5, 78, 6, 16, 1, 55, 0,  7, 7, 38, 8, 13, 4, 32, 2, 10, 
    2, 54, 3, 95, 4, 93, 0, 27, 6,  7, 8, 94, 1, 88, 7, 14, 5, 45, 
    0, 74, 2, 66, 1, 61, 3, 47, 6, 11, 4, 45, 7, 68, 5, 71, 8, 29, 
    4,  1, 8,  4, 0, 90, 3, 25, 7, 25, 5, 22, 6, 44, 1, 38, 2, 43, 
    2, 88, 1, 29, 5, 64, 4, 52, 0, 86, 3, 17, 8, 89, 7, 70, 6, 93, 
    4,  4, 8, 58, 2, 27, 5, 24, 7, 10, 0, 79, 6, 69, 1, 96, 3, 29, 
    1, 75, 6,  4, 7, 10, 5, 55, 2, 29, 0, 91, 8, 20, 3, 87, 4, 92, 
    1, 31, 4, 67, 0,  3, 6, 43, 5, 64, 3, 81, 8, 97, 7, 99, 2, 45, 
    8, 23, 3, 87, 6, 68, 7, 43, 0, 28, 1, 66, 4, 65, 2, 99, 5, 56
  };
  const int q4980[] = {
    9, 9, // Number of jobs and machines
    1, 51, 5, 87, 4, 19, 6, 14, 3, 26, 8, 24, 7, 90, 2, 75, 0, 89, 
    3, 48, 5, 75, 0, 73, 1, 76, 7, 53, 8, 58, 4, 95, 2, 39, 6, 89, 
    6, 75, 2, 29, 0, 39, 4, 24, 7, 29, 5,  3, 3,  2, 1, 44, 8, 54, 
    8,  8, 4, 47, 7, 38, 0, 56, 1,  2, 3, 34, 6, 17, 5, 76, 2, 68, 
    8, 11, 0, 41, 3, 55, 1, 56, 5, 50, 4,  1, 6, 64, 7, 39, 2, 51, 
    8, 93, 1, 74, 0, 30, 4, 81, 5,  2, 3, 96, 7, 63, 6, 91, 2,  5, 
    1, 58, 7, 76, 6, 59, 0, 51, 8, 19, 4, 49, 2, 46, 5, 54, 3, 94, 
    2, 18, 8, 99, 0, 19, 5, 70, 1, 62, 6,  5, 7, 47, 4, 92, 3, 75, 
    8,  1, 5, 52, 0, 27, 4, 64, 2, 29, 6, 15, 7, 72, 3, 68, 1, 96
  };
  const int q4981[] = {
    9, 9, // Number of jobs and machines
    7, 21, 2, 41, 4, 93, 6, 97, 1, 49, 0, 87, 3, 52, 8, 12, 5, 83, 
    4, 89, 8, 94, 6, 62, 1, 16, 0,  4, 2, 34, 7, 28, 5, 83, 3, 75, 
    8, 14, 7, 65, 3, 88, 0, 30, 1, 82, 6, 61, 5, 21, 4,  7, 2, 22, 
    5, 65, 1, 16, 6, 12, 8, 84, 3, 71, 7, 33, 4, 14, 2, 82, 0, 98, 
    0, 31, 6, 16, 1, 18, 3, 73, 7, 61, 5, 87, 4,  5, 2, 55, 8, 16, 
    0, 69, 5, 55, 8, 77, 2, 18, 3, 28, 7, 46, 4, 22, 1, 14, 6, 74, 
    8, 84, 7, 28, 4, 58, 0, 94, 6, 44, 2, 69, 5, 97, 1,  6, 3, 89, 
    0, 95, 3, 77, 6, 68, 1, 36, 8, 27, 5, 72, 7, 91, 4, 39, 2, 39, 
    5, 35, 4, 92, 6,  5, 1, 16, 0, 86, 3, 63, 7, 80, 2, 76, 8, 28
  };
  const int q4982[] = {
    9, 9, // Number of jobs and machines
    3, 60, 7, 44, 8, 26, 6, 56, 2, 88, 4, 62, 1,  3, 5, 61, 0, 77, 
    5, 54, 0, 43, 7, 12, 2, 74, 1, 56, 3, 34, 4, 24, 6, 11, 8, 98, 
    8, 83, 3, 12, 7, 83, 6, 72, 1, 52, 5, 14, 2, 96, 4, 18, 0, 48, 
    6, 31, 8, 31, 4, 61, 0, 27, 5, 49, 1, 16, 2, 86, 7, 99, 3, 34, 
    1,  2, 4, 19, 5, 75, 8, 20, 3, 47, 0, 25, 6, 99, 2, 88, 7, 11, 
    5, 75, 1, 26, 4, 57, 3, 79, 6, 96, 7, 82, 8, 83, 0, 20, 2, 32, 
    0, 28, 2, 46, 1, 42, 6, 98, 7, 46, 3, 75, 8, 94, 4, 81, 5, 61, 
    0, 52, 8, 30, 4, 35, 2, 25, 1, 81, 3, 53, 6, 88, 5, 53, 7, 23, 
    8, 58, 3, 32, 4, 45, 6, 28, 0, 63, 5, 24, 7, 39, 1, 41, 2, 78
  };
  const int q4983[] = {
    9, 9, // Number of jobs and machines
    0, 58, 3, 30, 7, 84, 1, 95, 2, 39, 5, 88, 8, 32, 6, 30, 4, 82, 
    3, 63, 5, 98, 7, 67, 8, 37, 0, 16, 4, 35, 1, 44, 2, 64, 6,  3, 
    7, 66, 3, 96, 5, 76, 0, 77, 6, 94, 1, 15, 8, 82, 2, 52, 4, 11, 
    0, 98, 8, 98, 4, 82, 3, 98, 7, 37, 2, 30, 6, 97, 5, 53, 1, 81, 
    8, 62, 2, 14, 0, 23, 7,  9, 1, 48, 6,  2, 4, 46, 3, 82, 5, 93, 
    7, 29, 4,  1, 1, 37, 2, 89, 8, 73, 0, 47, 3, 22, 5,  3, 6,  1, 
    0, 87, 5, 29, 4, 46, 1, 43, 8, 34, 2, 15, 3, 91, 7, 75, 6, 51, 
    3, 39, 5, 33, 8, 85, 4, 65, 1, 11, 6, 63, 2, 49, 0, 97, 7, 44, 
    5, 63, 6, 59, 0,  7, 8, 92, 4, 26, 7, 81, 3, 52, 1,  8, 2,  4
  };
  const int q4984[] = {
    9, 9, // Number of jobs and machines
    2, 91, 8,  3, 6, 17, 1, 38, 5, 89, 3,  5, 7, 52, 4, 39, 0, 88, 
    7, 31, 0,  5, 4, 28, 8, 17, 6, 91, 5, 57, 3, 33, 2, 87, 1, 36, 
    2, 91, 7, 78, 5, 20, 1, 46, 4, 85, 6, 95, 8, 33, 0, 46, 3, 18, 
    1, 11, 6, 90, 0, 90, 5, 80, 3, 57, 4, 96, 7, 86, 2, 59, 8,  5, 
    2, 33, 4, 82, 7, 29, 0, 75, 3, 66, 5, 43, 6, 21, 8, 24, 1, 45, 
    7, 76, 6, 26, 4, 56, 0, 22, 3, 89, 2, 73, 1, 77, 5, 88, 8, 79, 
    5, 25, 1, 92, 7, 28, 2, 19, 6, 69, 0, 91, 4, 20, 3, 51, 8, 14, 
    6, 55, 1, 81, 2, 88, 8,  1, 3, 41, 0, 24, 5, 30, 7, 22, 4, 17, 
    7, 37, 6, 65, 3, 92, 1, 33, 5, 90, 0, 29, 4, 79, 2, 89, 8, 40
  };
  const int q4985[] = {
    9, 9, // Number of jobs and machines
    0, 88, 4, 91, 3, 14, 8, 47, 2, 97, 7,  6, 1, 93, 5, 87, 6, 22, 
    3, 16, 2, 30, 0, 86, 1, 57, 6, 25, 4, 60, 5, 19, 7, 36, 8, 78, 
    5, 18, 2, 69, 3, 59, 4, 64, 0, 74, 6, 62, 7, 44, 1, 66, 8, 10, 
    6,  2, 1, 81, 7, 81, 0, 13, 2, 82, 8, 86, 3, 53, 5, 30, 4, 65, 
    8, 20, 4, 18, 0, 57, 6, 46, 2, 12, 7, 88, 5, 62, 3, 90, 1, 53, 
    8, 50, 7, 24, 6, 64, 0,  5, 5, 93, 1,  5, 3, 13, 2, 36, 4, 60, 
    5, 40, 4, 30, 8, 93, 7, 93, 2,  7, 0, 88, 3, 98, 1, 55, 6, 29, 
    0, 67, 1, 67, 7, 86, 6, 21, 4, 41, 2, 13, 3, 73, 5, 32, 8, 75, 
    7, 93, 4, 45, 2, 10, 5, 52, 0, 75, 8,  6, 6,  6, 3, 27, 1,  5
  };
  const int q4986[] = {
    9, 9, // Number of jobs and machines
    5, 38, 4,  4, 0, 50, 3,  3, 2, 13, 6, 95, 8, 98, 1, 85, 7, 20, 
    6, 80, 7, 11, 8, 67, 1, 32, 5, 55, 4, 39, 0,  1, 3, 68, 2, 18, 
    5, 50, 0, 70, 2, 97, 1, 68, 8, 92, 4,  4, 7, 37, 6, 27, 3, 36, 
    8,  9, 1, 48, 4, 38, 3, 29, 7, 91, 0, 89, 2, 19, 5,  9, 6, 65, 
    1, 74, 6, 90, 2, 17, 4, 89, 0, 18, 3, 28, 5, 58, 8, 53, 7, 73, 
    3, 54, 4, 22, 2, 47, 0,  2, 5, 94, 8, 69, 6, 58, 1, 37, 7, 54, 
    2, 93, 0, 64, 4, 14, 8, 33, 1, 40, 5, 87, 6, 94, 3, 24, 7, 44, 
    8, 74, 2, 86, 6, 68, 3, 57, 0, 42, 5, 27, 1, 93, 4, 50, 7,  6, 
    2, 29, 0, 63, 4, 63, 6, 60, 5, 13, 8, 72, 3, 76, 1, 42, 7, 29
  };
  const int q4987[] = {
    9, 9, // Number of jobs and machines
    1,  6, 5, 30, 6, 96, 7, 84, 3, 31, 2, 44, 4, 46, 8, 25, 0, 78, 
    8,  8, 1, 32, 4,  6, 7, 26, 6,  2, 0, 23, 5, 75, 2, 65, 3,  3, 
    3, 19, 6, 20, 5, 29, 1, 42, 2, 90, 7, 52, 0, 24, 8, 41, 4, 43, 
    0, 82, 3, 20, 1, 92, 7, 50, 6, 14, 2, 52, 4, 28, 8, 57, 5, 36, 
    4, 45, 3, 73, 2, 30, 6, 52, 5, 86, 1, 57, 7, 24, 0, 94, 8, 99, 
    6, 38, 7, 40, 2,  2, 4, 13, 3, 88, 0, 44, 5, 59, 1, 13, 8, 75, 
    3, 28, 4, 51, 5, 23, 8, 41, 0, 59, 2, 13, 1, 31, 7,  5, 6, 29, 
    3, 61, 0, 70, 4, 81, 5, 85, 2, 67, 8, 95, 7, 14, 6, 39, 1, 51, 
    3, 81, 2, 22, 8, 85, 0, 25, 6, 75, 1, 59, 7, 57, 4, 95, 5, 93
  };
  const int q4988[] = {
    9, 9, // Number of jobs and machines
    8, 31, 5,  2, 1, 88, 3, 84, 7, 59, 0, 18, 4, 13, 2, 45, 6, 56, 
    6, 24, 1, 69, 4, 68, 2, 84, 8, 73, 5, 78, 0, 41, 7,  5, 3, 83, 
    1, 72, 5, 68, 2, 16, 8, 80, 7, 49, 0, 14, 4, 76, 3, 99, 6, 22, 
    3, 43, 7,  7, 5, 59, 4, 23, 6, 74, 1, 51, 8, 44, 0, 44, 2, 99, 
    7, 34, 1, 72, 5, 55, 0, 34, 2, 93, 6, 78, 4, 91, 3, 43, 8, 50, 
    3, 40, 8, 87, 4, 30, 6, 63, 5, 29, 2, 74, 7, 61, 1, 20, 0, 75, 
    4, 36, 5, 51, 0, 52, 3, 61, 1, 46, 2,  5, 6, 56, 8,  1, 7, 87, 
    3, 12, 5, 27, 1, 63, 6,  3, 7, 65, 0, 84, 8, 68, 2, 50, 4, 64, 
    5, 84, 7, 93, 4, 54, 3, 91, 2, 36, 8, 21, 6, 83, 1, 55, 0, 90
  };
  const int q4989[] = {
    9, 9, // Number of jobs and machines
    1, 56, 6, 84, 3, 12, 7, 61, 8, 25, 5, 93, 0, 37, 2, 94, 4, 99, 
    2, 53, 4, 51, 0, 70, 1, 37, 8, 56, 7, 15, 6, 57, 5, 70, 3, 25, 
    8, 56, 4, 53, 0, 21, 6, 40, 3, 43, 7, 74, 2, 57, 1, 29, 5, 45, 
    4, 85, 6, 79, 5, 81, 2, 35, 1, 16, 3, 15, 7, 43, 8, 25, 0, 62, 
    0, 16, 2, 15, 5, 14, 4, 44, 8, 99, 6, 40, 7, 27, 3, 46, 1, 85, 
    4, 67, 6, 93, 1, 45, 3, 38, 7, 37, 5, 35, 2, 94, 0, 84, 8, 23, 
    4, 93, 2, 56, 3, 13, 6, 99, 5, 69, 1, 99, 8, 85, 0, 56, 7, 43, 
    0, 76, 4, 57, 3, 92, 5, 83, 6, 16, 2, 74, 1,  3, 7, 42, 8, 19, 
    4, 61, 3, 20, 5,  9, 6, 50, 1, 48, 8, 48, 2,  1, 7, 95, 0, 73
  };
  const int q4990[] = {
    9, 9, // Number of jobs and machines
    7, 80, 1, 63, 3, 50, 0, 98, 6, 73, 4, 51, 2, 64, 5, 49, 8, 76, 
    2, 36, 6, 48, 7, 44, 4, 94, 3, 15, 1, 14, 5,  1, 0,  7, 8, 76, 
    6, 63, 1,  9, 2, 85, 5, 14, 7, 74, 8, 14, 4, 58, 0, 57, 3, 48, 
    4, 11, 0, 30, 8, 59, 5, 67, 1, 49, 6,  3, 2, 83, 7, 41, 3, 44, 
    2, 61, 4, 57, 6, 47, 7, 68, 3, 87, 0, 89, 5, 85, 8, 88, 1, 96, 
    5, 77, 8, 82, 2, 75, 0,  5, 3, 28, 4, 36, 1, 91, 7, 53, 6, 32, 
    8, 33, 3, 65, 6,  8, 5, 92, 4, 98, 0, 42, 1, 43, 7,  9, 2, 87, 
    0, 60, 8, 38, 3, 72, 6, 79, 7, 48, 5, 54, 2, 85, 1,  1, 4, 78, 
    8, 88, 1, 81, 0, 84, 3, 85, 7, 89, 6, 88, 5, 93, 2, 57, 4, 59
  };
  const int q4991[] = {
    9, 9, // Number of jobs and machines
    8, 44, 6, 75, 3, 99, 1, 94, 7, 68, 5, 81, 0, 74, 2, 52, 4, 73, 
    6, 67, 8, 62, 1, 19, 7, 90, 5, 92, 2, 67, 3, 35, 0, 53, 4, 64, 
    2, 67, 5, 97, 6, 21, 3, 67, 0, 41, 7, 27, 1, 43, 8, 70, 4, 70, 
    4, 97, 5, 99, 6, 66, 1, 96, 8,  1, 3, 76, 0, 33, 2, 73, 7, 23, 
    7, 96, 2, 23, 1, 71, 4,  8, 5, 17, 6,  7, 0, 42, 8, 93, 3, 58, 
    5, 65, 6, 32, 1, 48, 7, 41, 4,  4, 2, 71, 8, 62, 3, 23, 0, 39, 
    0, 92, 6, 76, 1, 96, 4, 17, 5, 52, 3, 88, 7, 98, 8, 45, 2, 62, 
    1, 95, 3, 50, 5, 30, 2, 43, 0, 95, 7, 68, 8, 59, 6, 49, 4, 11, 
    6, 65, 5, 63, 0, 45, 8,  7, 7, 55, 2, 87, 3, 36, 1, 18, 4, 97
  };
  const int q4992[] = {
    9, 9, // Number of jobs and machines
    7, 48, 6, 32, 0, 61, 4, 41, 1, 93, 5, 79, 8, 31, 2, 83, 3,  3, 
    1, 84, 3, 26, 4, 60, 2, 95, 8, 47, 5,  6, 0, 26, 6, 60, 7, 33, 
    4, 52, 3, 64, 8,  4, 5, 67, 1, 91, 2, 75, 6, 77, 7, 74, 0, 70, 
    3, 89, 8, 79, 2, 39, 1, 77, 4, 56, 6, 65, 0, 27, 5, 82, 7, 33, 
    7, 14, 8, 56, 2, 79, 3,  7, 1, 68, 4, 32, 5, 15, 0, 37, 6, 82, 
    7,  4, 4, 32, 1, 32, 5,  9, 3, 97, 0, 56, 2, 59, 8, 73, 6, 67, 
    1, 40, 8, 69, 7, 45, 3, 56, 6, 51, 0, 32, 2, 95, 4, 99, 5, 34, 
    8, 94, 2, 60, 1, 54, 5, 74, 3, 14, 4, 67, 7, 69, 6, 88, 0, 71, 
    0, 51, 7, 86, 5, 60, 3, 26, 6, 95, 2, 18, 4, 14, 1, 66, 8,  2
  };
  const int q4993[] = {
    9, 9, // Number of jobs and machines
    8, 44, 7, 88, 1, 81, 6, 18, 3, 12, 2, 32, 0, 25, 5, 47, 4, 99, 
    4, 65, 0,  7, 1, 34, 8, 39, 6, 47, 3, 14, 7, 62, 5, 69, 2, 60, 
    2, 55, 5, 95, 0, 91, 7, 16, 3, 76, 8, 96, 1, 97, 6, 40, 4, 53, 
    8, 69, 1, 74, 4, 67, 3, 83, 7, 24, 0, 29, 5, 22, 2, 26, 6, 99, 
    4, 65, 0, 29, 2, 99, 3, 38, 5, 97, 6, 39, 8, 40, 1, 87, 7, 55, 
    6, 45, 5, 63, 3, 96, 8, 89, 7, 18, 1, 55, 0, 98, 4, 43, 2, 56, 
    3, 19, 8, 34, 2,  3, 5, 36, 4, 95, 1, 10, 7, 36, 6, 23, 0, 88, 
    2, 15, 3, 76, 5, 48, 7, 55, 6, 64, 8, 30, 1, 70, 0, 38, 4, 86, 
    5, 91, 7, 89, 0, 43, 6, 47, 4, 60, 2, 31, 1,  5, 8, 83, 3, 31
  };
  const int q4994[] = {
    9, 9, // Number of jobs and machines
    2, 64, 7, 92, 1, 61, 8, 68, 6, 16, 5, 32, 3, 89, 0, 86, 4, 90, 
    0, 62, 4, 42, 6, 64, 7, 49, 2, 18, 3, 23, 8,  8, 1, 31, 5, 93, 
    7, 81, 4, 18, 0, 17, 6, 60, 3, 66, 1, 94, 2, 90, 8, 13, 5, 20, 
    4, 57, 5, 20, 8, 76, 6, 27, 0,  7, 7, 33, 2,  6, 3, 70, 1, 77, 
    3, 35, 6, 75, 7,  4, 0, 68, 5, 14, 8, 80, 1, 44, 4,  2, 2, 17, 
    2, 96, 3, 84, 5, 78, 7, 68, 4, 77, 1, 19, 6, 11, 8, 51, 0, 41, 
    5, 56, 8, 11, 6, 86, 2, 23, 7, 54, 1, 97, 4, 32, 0, 59, 3,  8, 
    6,  7, 1, 96, 4, 33, 5, 61, 8, 66, 7, 96, 3, 96, 0, 61, 2, 82, 
    0, 46, 6, 93, 8, 12, 2, 23, 1, 85, 3, 67, 4, 22, 5, 49, 7,  6
  };
  const int q4995[] = {
    9, 9, // Number of jobs and machines
    1, 68, 8, 37, 4, 49, 3, 97, 6, 44, 5, 43, 7,  8, 0, 23, 2, 26, 
    3, 53, 8, 90, 4, 72, 7, 18, 2, 19, 6, 96, 1, 40, 5, 39, 0, 33, 
    3, 72, 1, 39, 0, 98, 6, 28, 2, 64, 8, 72, 4, 61, 7, 84, 5,  8, 
    1,  1, 2, 37, 5, 94, 4, 24, 3, 50, 0, 33, 6, 96, 7, 30, 8,  5, 
    2, 75, 0, 10, 4, 73, 7, 46, 8, 25, 6, 49, 3, 91, 1, 49, 5, 75, 
    1, 47, 8, 91, 0, 97, 3, 89, 5,  7, 2, 96, 4, 35, 7, 11, 6, 57, 
    6, 68, 0,  1, 5, 35, 4, 75, 8, 10, 2, 44, 1, 29, 3, 53, 7, 87, 
    7, 84, 2, 30, 5, 66, 3, 84, 6, 77, 0, 81, 8, 12, 4, 46, 1, 51, 
    5, 50, 3, 55, 6, 34, 0, 81, 4, 53, 7, 80, 8, 53, 2, 64, 1, 23
  };
  const int q4996[] = {
    9, 9, // Number of jobs and machines
    0,  2, 6, 94, 3, 68, 5, 64, 1, 45, 7, 54, 4, 70, 8, 70, 2,  2, 
    6, 35, 4, 80, 8,  4, 1, 81, 0, 13, 7, 15, 3, 46, 5, 33, 2, 34, 
    2, 31, 5,  2, 1, 40, 4, 94, 3, 75, 7, 16, 8, 95, 0, 58, 6, 84, 
    5, 37, 2,  4, 8, 60, 0, 71, 1, 45, 6, 98, 7, 17, 4, 13, 3, 27, 
    4, 40, 7, 40, 2, 48, 5, 34, 1, 70, 0, 65, 3, 39, 6, 44, 8, 65, 
    6, 97, 7, 59, 0, 68, 4, 18, 5, 70, 2, 50, 8, 37, 1, 45, 3, 93, 
    3, 31, 5, 39, 8, 99, 4, 35, 6, 65, 0, 48, 2, 22, 7, 18, 1,  9, 
    1, 87, 2, 61, 5,  8, 4, 73, 3, 68, 7,  1, 8, 23, 6, 32, 0, 63, 
    7, 39, 5, 41, 0, 62, 8, 41, 3, 91, 6, 66, 2, 39, 1, 79, 4, 56
  };
  const int q4997[] = {
    9, 9, // Number of jobs and machines
    1, 50, 3, 25, 5, 17, 4, 77, 0, 74, 2, 18, 7, 17, 8, 60, 6, 91, 
    4, 92, 3, 89, 5, 76, 7,  3, 1, 19, 8, 47, 0, 90, 6, 96, 2, 26, 
    3, 16, 8, 31, 2, 34, 4, 31, 1, 52, 5, 97, 6, 71, 7, 76, 0,  6, 
    6, 70, 4, 66, 8, 89, 7, 63, 5, 71, 3, 48, 1, 22, 0, 96, 2, 61, 
    5, 24, 6, 48, 1, 17, 4, 43, 2, 14, 8, 35, 3, 36, 0, 11, 7,  4, 
    1, 32, 5, 80, 0, 71, 4, 61, 7, 54, 6, 93, 2, 95, 8, 32, 3, 26, 
    1, 46, 5, 90, 3, 85, 6,  6, 4, 15, 7, 43, 2, 64, 0, 30, 8,  6, 
    5,  7, 7, 27, 2, 21, 3, 35, 4,  7, 8, 34, 1, 75, 6, 96, 0, 36, 
    6, 69, 8, 31, 1, 24, 2, 32, 3, 11, 7, 60, 5, 90, 4, 56, 0, 97
  };
  const int q4998[] = {
    9, 9, // Number of jobs and machines
    0, 52, 3, 59, 7, 39, 2, 48, 5, 71, 1, 27, 8, 55, 4, 28, 6, 36, 
    4, 65, 2, 36, 6, 84, 3, 92, 7, 91, 0,  8, 8, 27, 1, 26, 5, 64, 
    0,  9, 2,  6, 8, 63, 4, 22, 7, 71, 5, 84, 3, 44, 6, 95, 1, 83, 
    8, 19, 1, 89, 5, 95, 3, 50, 4, 11, 7, 93, 2, 38, 0, 16, 6, 25, 
    1, 18, 6, 11, 4, 45, 8,  3, 0, 37, 7, 27, 2,  5, 3, 32, 5, 19, 
    4, 48, 5, 31, 1, 91, 2, 47, 3, 92, 8, 31, 7, 32, 0,  8, 6, 63, 
    2, 85, 6, 88, 4, 30, 5, 65, 3, 16, 7, 39, 8, 67, 1, 57, 0, 67, 
    6, 33, 8, 85, 4, 95, 1, 81, 7, 63, 3, 40, 2, 96, 0, 37, 5, 63, 
    2, 47, 6, 86, 7,  9, 4, 24, 0, 45, 1, 61, 3,  6, 5, 37, 8, 50
  };
  const int q4999[] = {
    9, 9, // Number of jobs and machines
    4, 56, 1, 95, 3, 10, 2, 34, 5, 10, 6, 19, 0, 79, 7, 21, 8, 20, 
    8, 65, 6, 48, 3, 43, 4, 44, 7, 25, 5, 57, 0,  1, 1, 67, 2, 16, 
    0, 15, 4, 43, 5, 12, 1, 59, 3, 74, 8, 21, 2, 89, 6,  2, 7, 90, 
    8, 75, 0, 50, 1, 43, 2, 36, 4, 90, 3, 88, 7, 42, 6,  9, 5, 12, 
    7, 13, 2, 83, 8, 19, 6, 51, 4, 67, 3, 65, 1, 61, 5, 86, 0, 60, 
    0, 54, 1, 75, 4, 92, 2, 33, 3, 44, 8, 46, 6,  4, 7, 18, 5, 16, 
    0, 38, 7,  5, 6, 15, 3, 47, 2, 28, 8, 95, 4, 47, 5, 99, 1, 56, 
    2, 96, 5, 94, 7, 74, 3, 76, 4, 31, 8, 76, 0,  5, 1, 75, 6, 73, 
    8, 93, 7, 21, 5, 66, 1, 60, 2, 47, 4,  6, 0, 77, 3, 45, 6, 95
  };
  const int q5000[] = {
    9, 9, // Number of jobs and machines
    6, 54, 0, 43, 8, 55, 1, 62, 7, 81, 5, 40, 3, 20, 4, 70, 2, 58, 
    2, 93, 6, 37, 1, 47, 3, 93, 8, 76, 0, 26, 4, 90, 7, 54, 5, 98, 
    4, 46, 5, 19, 3, 86, 0, 60, 2, 39, 1, 63, 7, 71, 8, 76, 6, 37, 
    1, 81, 0, 78, 5, 47, 3, 58, 7, 22, 8, 23, 4, 40, 2, 45, 6, 21, 
    7, 18, 6, 56, 0, 27, 1, 67, 4, 51, 5, 94, 8, 69, 2, 93, 3, 57, 
    6, 98, 4, 53, 7, 44, 2, 29, 0, 66, 3, 80, 8, 80, 1, 57, 5,  2, 
    0, 17, 8, 59, 6, 48, 3, 50, 5, 72, 7, 62, 1, 55, 2, 82, 4,  5, 
    1, 43, 0, 66, 5, 75, 4, 32, 8,  1, 3, 54, 2,  5, 6, 23, 7, 21, 
    2, 60, 1, 52, 0, 89, 8, 52, 6, 25, 7, 32, 5, 71, 4, 31, 3, 74
  };
  const int q5001[] = {
    9, 9, // Number of jobs and machines
    4, 39, 0, 98, 1, 57, 6, 46, 7, 29, 2, 57, 5, 56, 3, 44, 8, 25, 
    4, 70, 6, 26, 2, 96, 1, 75, 7, 66, 8, 47, 5, 32, 0, 86, 3, 14, 
    2, 58, 0,  7, 4, 99, 3, 12, 5, 52, 6, 55, 7, 26, 1, 95, 8,  3, 
    6, 19, 1, 67, 8, 95, 0, 76, 7, 54, 5, 79, 3, 35, 4, 29, 2, 13, 
    3, 98, 7, 56, 6, 48, 5,  3, 0, 17, 2, 23, 4, 12, 1, 37, 8, 99, 
    0, 55, 3, 15, 5, 96, 6, 19, 2, 66, 4, 63, 7, 73, 1,  5, 8, 37, 
    5, 31, 3, 45, 4, 97, 6, 75, 1, 49, 8,  5, 7, 41, 2, 67, 0,  9, 
    2, 18, 8, 27, 6, 30, 5, 64, 3, 34, 1, 92, 4, 83, 0, 62, 7, 48, 
    5, 34, 1, 47, 0, 27, 8, 21, 6, 76, 4, 39, 2, 81, 7, 84, 3, 97
  };
  const int q5002[] = {
    9, 9, // Number of jobs and machines
    5, 90, 1, 78, 2, 87, 4, 35, 3, 17, 7, 61, 6, 70, 8,  3, 0, 69, 
    1, 96, 8,  2, 4, 69, 2, 43, 5, 98, 0, 80, 6, 34, 7, 14, 3, 90, 
    2, 50, 1, 77, 8,  4, 6, 48, 0, 43, 3, 82, 4, 68, 7, 36, 5, 47, 
    0, 43, 7, 36, 4, 83, 3, 77, 5, 99, 1, 19, 8, 93, 2, 77, 6, 12, 
    4, 94, 0, 76, 7, 86, 1, 14, 3, 13, 2, 78, 6, 11, 5, 89, 8, 48, 
    1, 54, 2, 86, 3, 23, 7, 73, 5, 96, 4, 71, 8, 77, 0,  7, 6, 29, 
    6, 70, 7, 35, 8, 75, 2, 98, 4, 41, 5, 79, 3, 58, 1, 58, 0, 69, 
    4, 72, 1, 18, 5, 18, 3, 80, 7, 70, 0, 69, 6, 84, 2, 54, 8, 80, 
    7, 91, 1, 76, 4, 75, 8, 15, 0, 41, 5, 24, 3, 46, 6, 81, 2, 78
  };
  const int q5003[] = {
    9, 9, // Number of jobs and machines
    6, 91, 4, 10, 8, 58, 5, 97, 2,  9, 0, 15, 3, 58, 7, 83, 1,  6, 
    4,  5, 8, 46, 1,  1, 6, 85, 0, 20, 5, 32, 7, 88, 3, 54, 2, 14, 
    4, 56, 7, 90, 5, 25, 3, 30, 1, 48, 0, 94, 8, 67, 6, 70, 2, 26, 
    4, 49, 7, 13, 1,  1, 2,  8, 8,  9, 3, 17, 0, 48, 5, 67, 6, 95, 
    7, 14, 6, 36, 4, 23, 0,  7, 5, 83, 3, 29, 1, 71, 2, 83, 8, 27, 
    7, 63, 6, 10, 8, 38, 2, 38, 4, 23, 0, 25, 1, 37, 3, 19, 5, 93, 
    5, 75, 0, 45, 4, 96, 3, 86, 7, 94, 2, 34, 1, 14, 6, 41, 8,  9, 
    3, 30, 4, 65, 8, 95, 7, 46, 1, 51, 6, 40, 0, 26, 5, 52, 2, 84, 
    7, 18, 3, 59, 2, 68, 8, 70, 6, 84, 4, 84, 1, 51, 5,  5, 0, 52
  };
  const int q5004[] = {
    9, 9, // Number of jobs and machines
    7, 58, 8, 74, 2, 68, 4, 69, 6, 15, 3, 39, 1, 69, 5, 77, 0, 87, 
    6, 63, 4, 72, 3, 36, 7, 83, 5, 30, 1, 59, 2, 95, 0, 81, 8, 39, 
    0, 23, 1,  3, 8, 72, 7, 91, 5, 86, 4, 16, 6, 25, 3, 51, 2, 68, 
    5, 74, 8, 43, 1, 59, 6, 29, 4, 55, 0, 16, 7, 81, 2,  4, 3, 14, 
    5, 56, 1, 94, 3, 81, 7, 89, 0, 55, 8, 36, 2, 64, 6, 45, 4, 58, 
    6, 47, 4, 67, 0, 47, 5, 44, 2, 93, 3, 57, 1, 76, 8, 54, 7, 27, 
    6, 29, 1, 41, 2, 90, 0, 24, 8, 73, 3,  1, 4, 63, 5, 10, 7, 51, 
    8, 87, 1, 96, 3, 26, 2, 25, 0, 63, 6, 60, 7, 62, 5, 11, 4, 73, 
    5, 76, 3,  8, 1, 60, 4, 36, 0,  5, 7, 32, 2, 98, 8, 53, 6, 19
  };
  const int q5005[] = {
    9, 9, // Number of jobs and machines
    5, 59, 1,  2, 0, 36, 7, 45, 2, 56, 4, 74, 8, 93, 6, 64, 3, 70, 
    2, 55, 3, 48, 4, 54, 1, 55, 0, 74, 6, 74, 5, 89, 7, 97, 8, 84, 
    1, 75, 5, 55, 3, 35, 7,  6, 0,  1, 4,  8, 2, 44, 6, 86, 8, 94, 
    4, 43, 0, 31, 7, 14, 8, 51, 3, 87, 6, 68, 2, 18, 5, 87, 1, 74, 
    2, 48, 5, 67, 6, 13, 7, 84, 3, 23, 1, 71, 8,  7, 0, 54, 4, 22, 
    0, 55, 4, 83, 8, 85, 6, 77, 3,  8, 5, 58, 2, 37, 1, 11, 7, 66, 
    4, 59, 2, 95, 5, 80, 7, 58, 0, 98, 1, 99, 3, 81, 8, 77, 6, 97, 
    1, 43, 0, 93, 4, 78, 8,  4, 2, 80, 6, 69, 7, 11, 3, 12, 5, 41, 
    4, 17, 0, 83, 6, 99, 1,  8, 5, 84, 8, 12, 3,  7, 7,  3, 2, 94
  };
  const int q5006[] = {
    9, 9, // Number of jobs and machines
    8,  5, 3, 44, 1, 49, 7, 79, 5, 15, 4, 13, 6, 67, 0,  2, 2, 47, 
    3, 75, 7,  4, 1, 82, 2, 20, 8, 37, 0, 36, 4, 95, 6, 99, 5, 58, 
    7, 27, 8, 72, 0, 60, 6, 14, 3, 48, 2, 94, 5, 73, 4, 78, 1, 85, 
    8, 32, 4, 32, 0, 70, 2, 13, 3, 38, 7, 44, 1, 94, 6, 91, 5, 32, 
    1, 69, 0, 56, 4, 79, 6,  8, 8, 44, 7, 70, 3, 24, 2, 94, 5, 11, 
    6, 91, 0, 50, 4, 67, 3, 81, 5, 75, 8, 19, 2, 21, 7, 17, 1, 59, 
    4, 65, 2,  4, 1, 48, 8, 87, 7, 78, 3, 17, 0, 73, 5, 31, 6, 32, 
    3, 89, 8, 70, 0, 78, 4, 91, 1, 61, 7, 26, 6, 52, 5, 30, 2, 56, 
    1, 93, 7, 79, 5, 26, 2, 30, 0, 86, 8, 92, 4, 69, 6, 31, 3, 14
  };
  const int q5007[] = {
    9, 9, // Number of jobs and machines
    8,  7, 2, 71, 3, 45, 4, 65, 7, 92, 0, 11, 5, 94, 1, 45, 6, 49, 
    2,  7, 6, 48, 7, 88, 8, 45, 5, 54, 0, 37, 4, 11, 3, 11, 1, 14, 
    4, 13, 6, 70, 2, 71, 1,  4, 7, 28, 0, 66, 3, 78, 8, 97, 5, 11, 
    0, 69, 6, 44, 8, 87, 2, 85, 4, 13, 3, 42, 7, 89, 5, 22, 1, 74, 
    6, 26, 4, 67, 1, 65, 3,  2, 8, 31, 0, 17, 5, 11, 2, 15, 7,  2, 
    7, 62, 2,  7, 8, 83, 0, 98, 3, 73, 4, 71, 6, 86, 1, 86, 5, 68, 
    4, 79, 2, 55, 6, 35, 3, 40, 7, 28, 5, 27, 8, 59, 1, 72, 0, 65, 
    0, 53, 1, 50, 5, 73, 8, 86, 4, 84, 6, 20, 2, 47, 3, 30, 7, 26, 
    5,  2, 0, 22, 3,  8, 4, 34, 8, 25, 1, 43, 2, 42, 6, 81, 7, 28
  };
  const int q5008[] = {
    9, 9, // Number of jobs and machines
    4, 89, 6, 15, 8, 43, 0, 99, 1, 10, 3, 19, 5, 32, 2, 26, 7, 41, 
    8,  3, 7, 52, 6, 28, 1, 10, 5, 53, 2,  3, 0, 36, 3,  4, 4, 21, 
    3, 22, 6, 27, 7, 96, 5, 40, 0, 60, 2, 96, 4, 58, 8, 22, 1, 41, 
    8, 35, 2, 62, 6, 38, 5, 10, 4, 28, 7, 25, 1, 65, 3, 88, 0, 51, 
    8, 33, 1, 79, 7, 28, 2, 33, 3, 82, 6, 47, 5, 86, 0, 11, 4, 16, 
    3, 96, 5, 47, 8, 30, 4, 84, 7, 92, 1,  2, 2, 88, 0, 23, 6, 52, 
    3, 37, 6, 53, 8, 76, 4, 95, 5, 38, 1, 19, 7, 18, 2,  6, 0, 39, 
    7, 93, 2, 95, 0, 55, 6, 35, 3, 56, 5, 47, 1, 99, 8, 37, 4, 30, 
    2, 75, 5, 25, 1, 97, 0, 38, 7, 21, 3, 22, 6, 75, 8, 22, 4, 12
  };
  const int q5009[] = {
    9, 9, // Number of jobs and machines
    0, 25, 6, 23, 1,  6, 5, 47, 2, 14, 3, 72, 4, 71, 7, 89, 8, 87, 
    4, 32, 1, 79, 8,  7, 3, 84, 2, 61, 6, 93, 0, 97, 7, 92, 5,  5, 
    5, 41, 0, 85, 2, 56, 3, 65, 8, 81, 7, 73, 6, 37, 4, 45, 1, 76, 
    2, 14, 1, 87, 7, 39, 4, 38, 5, 96, 8, 89, 3, 43, 6, 18, 0, 21, 
    1, 58, 6,  6, 2, 46, 4,  3, 0, 21, 5, 92, 3,  2, 7, 63, 8, 41, 
    5, 94, 8, 31, 2, 23, 6, 90, 1, 14, 3,  9, 4, 11, 7, 70, 0, 87, 
    5, 97, 4, 19, 8, 83, 3,  5, 7, 28, 2, 34, 0, 80, 6, 71, 1, 14, 
    6,  4, 7, 13, 3, 17, 2, 45, 0, 36, 4, 32, 8, 81, 1, 53, 5, 18, 
    3, 27, 6, 36, 1,  3, 7, 70, 8, 57, 0, 23, 5, 81, 2, 59, 4, 70
  };
  const int q5010[] = {
    9, 9, // Number of jobs and machines
    4, 14, 7, 29, 1, 54, 0, 85, 6, 85, 5, 77, 2, 75, 3, 76, 8,  9, 
    3, 12, 8, 92, 2, 16, 4, 23, 6, 10, 1, 18, 0, 22, 5, 60, 7, 87, 
    7, 94, 1, 27, 0, 61, 8, 48, 5, 76, 6, 62, 3, 69, 2,  7, 4, 96, 
    3, 49, 6, 36, 1, 40, 8, 31, 7, 26, 2,  9, 5,  2, 0, 68, 4, 30, 
    0, 71, 8, 59, 5, 81, 4, 46, 7, 33, 2, 82, 6, 75, 1, 76, 3, 36, 
    0, 44, 6, 71, 3, 86, 4, 14, 5,  1, 7, 83, 2, 45, 1, 71, 8, 29, 
    5, 55, 6, 23, 3, 59, 4, 36, 1, 97, 7, 91, 0, 46, 8, 51, 2, 66, 
    1, 39, 3,  8, 7, 62, 4, 52, 6, 49, 2, 88, 8, 22, 0,  3, 5, 29, 
    3, 77, 7, 81, 0, 78, 1, 10, 4, 36, 2, 10, 8, 97, 6, 82, 5, 55
  };
  const int q5011[] = {
    9, 9, // Number of jobs and machines
    1, 12, 5,  2, 0, 32, 2, 74, 6, 40, 8, 18, 7,  9, 3, 11, 4, 97, 
    0, 86, 6, 43, 7, 44, 5, 64, 4, 79, 3, 23, 8, 91, 2, 85, 1, 24, 
    8, 27, 2, 82, 1, 93, 5, 98, 3, 80, 0, 26, 6, 98, 7, 87, 4, 96, 
    3, 80, 7, 89, 2, 89, 0,  2, 4, 91, 1, 28, 6, 72, 8, 75, 5, 79, 
    6, 67, 2, 72, 7, 61, 4, 21, 1, 90, 5, 69, 8, 29, 3,  1, 0, 57, 
    2, 28, 4, 27, 6, 86, 3, 96, 5, 86, 7, 16, 0, 82, 8, 31, 1, 63, 
    7, 25, 2, 94, 1, 99, 5, 37, 8, 40, 4, 63, 6, 53, 0, 25, 3, 91, 
    6, 68, 2, 56, 8, 10, 1, 91, 0, 67, 3, 14, 5, 77, 4, 70, 7, 53, 
    1, 24, 7, 75, 3, 78, 6, 32, 5, 58, 4,  4, 0, 78, 2, 72, 8, 30
  };
  const int q5012[] = {
    9, 9, // Number of jobs and machines
    0, 12, 4, 58, 5, 99, 1,  1, 8, 96, 3,  2, 2, 79, 7, 18, 6, 12, 
    4, 46, 2, 30, 8, 99, 7, 31, 5, 19, 0, 37, 1,  6, 3, 75, 6, 11, 
    8, 46, 2, 38, 1,  5, 7, 49, 6,  7, 3, 30, 4, 70, 5, 86, 0, 88, 
    7,  6, 0, 85, 2, 66, 8,  9, 3, 41, 4, 94, 5, 90, 1,  1, 6, 13, 
    2, 75, 5, 35, 8, 64, 4, 29, 1, 31, 6, 76, 7, 75, 3, 55, 0, 91, 
    1, 64, 5, 19, 4,  5, 0, 90, 7, 78, 2, 81, 8, 16, 3, 25, 6, 88, 
    6, 53, 8, 52, 0, 62, 4, 93, 5, 64, 1, 21, 3, 58, 7, 62, 2, 49, 
    0, 82, 4, 73, 2,  4, 1, 21, 8, 13, 3, 47, 6, 94, 5, 83, 7, 59, 
    1, 36, 2,  2, 7, 18, 0, 55, 6, 81, 8, 31, 4, 20, 3, 20, 5, 85
  };
  const int q5013[] = {
    9, 9, // Number of jobs and machines
    1, 68, 7, 45, 5, 94, 4, 39, 8, 70, 2, 24, 3, 54, 6, 99, 0, 53, 
    7, 31, 4, 65, 3, 70, 0, 31, 1, 82, 8, 55, 5, 15, 6, 77, 2, 70, 
    1, 96, 6, 29, 2, 49, 5, 37, 8, 12, 4, 54, 0, 58, 7, 36, 3, 13, 
    6, 68, 7, 91, 0,  3, 3, 37, 5, 18, 2,  7, 1, 31, 8, 71, 4, 64, 
    3, 12, 1, 28, 7, 16, 2,  2, 0, 95, 8, 42, 6, 22, 5, 81, 4,  7, 
    0, 97, 2, 36, 7, 64, 6, 33, 4, 10, 5, 90, 3, 14, 1, 73, 8, 58, 
    3, 56, 0, 11, 4, 71, 8, 94, 7, 59, 6, 64, 1, 11, 5, 81, 2, 35, 
    7, 10, 3, 11, 2, 65, 5, 90, 8, 68, 1,  2, 0, 11, 6, 63, 4, 28, 
    3, 11, 8,  1, 6, 39, 1, 44, 7, 97, 5, 19, 0, 54, 4, 46, 2, 85
  };
  const int q5014[] = {
    9, 9, // Number of jobs and machines
    8, 76, 0, 58, 1, 25, 6, 73, 4, 66, 2, 44, 3, 93, 5, 75, 7,  2, 
    7, 97, 8, 51, 1,  1, 6, 40, 0,  6, 3, 35, 4, 70, 2, 42, 5, 69, 
    3,  1, 2, 60, 8, 83, 0, 15, 6, 62, 5, 82, 4, 88, 7, 97, 1, 46, 
    3, 47, 8, 47, 1, 73, 4, 67, 5, 87, 7, 17, 6, 24, 0, 91, 2, 35, 
    0, 68, 8, 53, 6, 61, 2, 72, 1, 40, 5, 64, 4, 67, 3, 80, 7, 43, 
    4, 29, 1,  8, 3,  2, 8, 50, 2, 30, 6, 10, 0, 92, 5, 91, 7, 79, 
    0,  6, 6, 66, 8, 95, 5,  9, 3, 33, 2, 89, 1, 80, 7, 98, 4, 44, 
    6, 31, 2, 85, 5,  6, 0, 54, 4, 50, 3,  6, 1, 74, 8, 90, 7, 94, 
    8, 40, 0, 40, 6,  8, 1, 96, 2, 57, 7, 75, 4, 23, 3, 49, 5, 36
  };
  const int q5015[] = {
    9, 9, // Number of jobs and machines
    3, 39, 5, 91, 6, 83, 0, 64, 7, 28, 2, 68, 8, 97, 1, 82, 4, 31, 
    2, 92, 4, 39, 7, 91, 5, 84, 6, 65, 8, 53, 3,  7, 1, 72, 0, 65, 
    1, 87, 7, 65, 5, 26, 6, 84, 3, 20, 8, 64, 4, 69, 2, 10, 0, 52, 
    5, 52, 8, 26, 7, 43, 4, 26, 0, 75, 3, 46, 2, 96, 6, 97, 1, 50, 
    3, 42, 0, 86, 6, 79, 8, 76, 4, 62, 1, 33, 5, 97, 2, 29, 7, 83, 
    5, 18, 1, 15, 2, 75, 7, 95, 0, 54, 8, 26, 4, 84, 6, 58, 3, 59, 
    8, 93, 6, 16, 0, 71, 2, 26, 5, 11, 1, 35, 4, 59, 3, 20, 7, 57, 
    0, 67, 6, 41, 7, 56, 8, 25, 4, 76, 2, 92, 1, 35, 3, 68, 5,  5, 
    2, 28, 7, 51, 5, 57, 0, 75, 4, 38, 6, 59, 1, 43, 8, 16, 3, 91
  };
  const int q5016[] = {
    9, 9, // Number of jobs and machines
    8, 78, 2, 84, 0, 34, 6, 69, 4, 64, 3, 40, 7, 28, 5,  8, 1, 52, 
    1, 14, 4, 50, 8, 57, 2, 73, 0, 92, 3, 99, 7, 71, 5, 20, 6, 74, 
    7, 99, 2,  5, 6, 46, 1, 41, 8, 62, 4, 69, 0, 39, 5, 65, 3, 77, 
    7, 85, 1, 24, 6, 99, 0, 25, 2, 32, 3, 28, 5, 96, 4,  8, 8, 40, 
    0,  5, 6, 87, 8, 32, 1, 97, 5, 87, 3, 36, 2, 64, 4,  9, 7, 89, 
    3, 52, 0, 26, 8, 71, 7, 31, 2, 25, 5, 18, 6,  4, 4,  1, 1, 74, 
    5,  1, 4, 57, 8, 25, 6, 94, 7, 31, 1, 50, 0, 87, 2, 51, 3, 62, 
    2, 78, 7, 18, 4,  9, 3,  2, 0, 89, 6, 99, 5, 96, 8, 98, 1, 51, 
    7, 43, 6, 99, 8, 60, 5, 29, 1, 96, 4, 85, 3, 95, 0, 52, 2, 81
  };
  const int q5017[] = {
    9, 9, // Number of jobs and machines
    6, 18, 2, 14, 5,  7, 7, 82, 0, 52, 1, 14, 4, 75, 3, 49, 8, 96, 
    6, 19, 5, 89, 7, 28, 2, 31, 3, 73, 1, 96, 4, 45, 8, 94, 0, 27, 
    7, 78, 0, 33, 5, 79, 6, 34, 8, 46, 4, 72, 3, 28, 1, 98, 2, 35, 
    3, 79, 2, 58, 7, 48, 4, 23, 8, 68, 6, 84, 1, 59, 5, 39, 0, 70, 
    8, 10, 6, 94, 2, 72, 1, 96, 0, 80, 7, 20, 4, 39, 5, 75, 3,  5, 
    6, 25, 2, 76, 7, 15, 8, 10, 5, 23, 1, 13, 3, 10, 0, 80, 4, 68, 
    2, 78, 7, 19, 0, 18, 5, 71, 6, 66, 8, 14, 4, 68, 3, 82, 1, 47, 
    2, 70, 3, 24, 6, 65, 4,  6, 0, 53, 1, 75, 5, 21, 8, 70, 7, 32, 
    8, 14, 4,  8, 1, 75, 0, 48, 6, 68, 2, 52, 3, 78, 5,  1, 7, 85
  };
  const int q5018[] = {
    9, 9, // Number of jobs and machines
    3, 36, 8, 11, 4, 64, 2, 19, 1, 70, 7, 17, 0,  4, 6, 98, 5, 56, 
    6, 33, 7, 65, 0, 17, 8, 79, 5, 22, 1, 96, 3, 57, 2, 96, 4, 31, 
    1, 11, 0, 19, 2, 54, 4, 28, 6, 44, 8, 38, 3, 70, 7, 80, 5, 13, 
    8, 86, 6, 38, 7, 21, 0, 14, 1, 36, 4, 35, 3, 66, 5, 48, 2, 99, 
    5, 42, 3, 20, 7,  2, 1, 77, 6, 18, 2, 60, 0, 61, 8, 96, 4, 34, 
    5, 96, 0, 67, 6, 41, 7, 46, 3, 42, 8, 80, 1, 76, 2, 79, 4, 27, 
    8, 97, 2, 31, 1, 27, 6, 58, 5,  1, 0, 45, 7,  2, 4, 75, 3, 98, 
    2,  6, 7, 97, 4,  4, 1, 31, 3, 73, 6, 10, 5, 70, 8, 34, 0, 18, 
    0, 66, 1, 66, 3, 82, 7, 54, 6, 16, 2, 55, 4, 89, 5, 85, 8, 46
  };
  const int q5019[] = {
    9, 9, // Number of jobs and machines
    3, 46, 5, 38, 1, 75, 4,  5, 2, 15, 6, 13, 7, 61, 0, 40, 8, 35, 
    5, 40, 7, 46, 4, 35, 2, 20, 6, 84, 8, 14, 0, 73, 3, 50, 1, 66, 
    3, 80, 4, 43, 7, 99, 8, 73, 5, 19, 6, 35, 0, 21, 1, 85, 2, 66, 
    1, 75, 0, 23, 4, 11, 6, 38, 7, 15, 3,  4, 8, 40, 2, 67, 5, 53, 
    7, 90, 3, 77, 4, 59, 5,  1, 8, 22, 2, 20, 0, 42, 1, 48, 6, 77, 
    5, 12, 3, 26, 6, 12, 0, 14, 1, 89, 2, 86, 8, 95, 7, 18, 4,  1, 
    2, 65, 1,  6, 6, 75, 3, 26, 8,  2, 7, 48, 4, 92, 5, 22, 0, 91, 
    1,  1, 3, 29, 0, 46, 5, 63, 7, 75, 2, 91, 6, 96, 8, 47, 4, 36, 
    7,  3, 1, 41, 2, 98, 6, 50, 4, 57, 8, 88, 3, 31, 5, 86, 0, 68
  };
  const int q5020[] = {
    9, 9, // Number of jobs and machines
    7, 89, 3, 37, 1, 61, 4, 25, 2, 27, 6, 24, 0, 71, 5, 41, 8, 40, 
    2, 63, 4, 75, 0, 61, 8, 64, 3, 85, 7, 50, 5, 76, 1, 40, 6, 22, 
    0, 63, 6, 60, 1, 93, 2, 85, 8, 36, 5, 15, 3, 83, 7, 94, 4, 74, 
    5, 63, 8, 16, 7, 74, 2, 12, 6, 63, 1, 17, 0, 98, 3, 42, 4, 10, 
    0, 92, 6, 31, 4, 63, 7, 37, 3, 10, 1, 19, 8, 93, 5, 52, 2, 31, 
    1, 42, 5, 55, 6, 28, 2, 11, 0,  6, 8, 77, 3, 41, 4, 22, 7, 97, 
    8, 45, 2, 48, 7, 78, 1, 92, 3,  6, 5, 97, 4, 49, 0, 66, 6, 77, 
    6, 74, 7, 43, 5, 19, 2, 87, 1, 15, 8, 14, 0, 81, 4, 38, 3, 78, 
    7, 85, 3, 63, 0,  5, 6, 34, 1, 28, 4, 79, 5, 62, 8, 16, 2, 39
  };
  const int q5021[] = {
    9, 9, // Number of jobs and machines
    3, 78, 4, 37, 8, 91, 6, 93, 0, 90, 1, 79, 5, 15, 2, 30, 7, 48, 
    0, 40, 6, 88, 1, 48, 3, 53, 2, 31, 5, 42, 7, 31, 4, 31, 8, 19, 
    2, 11, 6, 70, 0, 91, 5, 22, 7, 99, 8, 67, 1, 95, 3, 80, 4, 40, 
    1, 64, 8, 89, 0, 87, 4, 22, 7, 53, 6, 93, 5, 48, 2, 32, 3,  5, 
    8, 81, 3, 74, 0, 99, 4, 98, 7, 86, 5, 64, 1, 59, 2, 69, 6, 94, 
    8, 67, 7, 33, 6, 95, 4,  6, 0, 82, 1, 43, 5, 40, 3, 62, 2, 69, 
    5, 31, 6, 93, 2, 79, 8, 28, 3, 69, 7, 10, 0, 56, 4, 54, 1, 33, 
    0, 63, 6, 39, 7, 43, 5, 49, 4, 23, 3, 52, 2, 34, 8, 89, 1, 20, 
    1, 14, 7, 78, 6, 81, 5, 81, 0, 57, 2, 32, 8, 10, 4, 61, 3,  3
  };
  const int q5022[] = {
    9, 9, // Number of jobs and machines
    2, 13, 7, 87, 3, 95, 4, 40, 6, 46, 8, 97, 1, 98, 5, 69, 0,  7, 
    3,  8, 0, 12, 8, 94, 6, 35, 4, 17, 5, 44, 1, 48, 7, 41, 2, 42, 
    0, 31, 2, 90, 3, 37, 8, 40, 6, 26, 4, 34, 1, 61, 7, 18, 5, 19, 
    8, 87, 0, 67, 4, 45, 1, 75, 5, 51, 7, 85, 2, 20, 3, 32, 6, 10, 
    5, 60, 3, 18, 0,  2, 4, 23, 1, 38, 2, 85, 8, 45, 7, 60, 6, 50, 
    4, 15, 7,  6, 3, 28, 8, 28, 5, 35, 6, 62, 0, 73, 2, 88, 1, 88, 
    8, 50, 1, 23, 7, 50, 0, 10, 3, 71, 2, 82, 5, 86, 4, 88, 6, 24, 
    6, 57, 0,  4, 7, 55, 2, 50, 1, 41, 8, 35, 3, 29, 4, 64, 5, 27, 
    4,  3, 1, 49, 6, 94, 3, 16, 0, 15, 7, 27, 2, 94, 8, 46, 5, 97
  };
  const int q5023[] = {
    9, 9, // Number of jobs and machines
    2, 90, 3, 78, 0, 46, 8, 82, 5, 25, 7, 45, 6, 51, 4, 10, 1, 79, 
    2, 38, 4, 20, 6, 44, 8, 93, 7, 59, 3, 93, 1, 78, 0, 67, 5, 68, 
    7, 38, 8, 33, 4, 19, 3, 91, 2, 32, 1, 16, 0, 46, 5, 34, 6, 37, 
    5, 13, 8, 58, 3, 39, 2, 33, 0, 76, 6, 90, 4, 56, 1, 54, 7, 44, 
    6, 80, 0, 74, 3, 33, 1, 11, 8, 26, 4, 88, 7, 65, 5, 82, 2, 17, 
    8, 38, 7, 91, 2, 61, 1, 99, 4, 38, 5, 11, 0, 10, 3, 75, 6,  5, 
    1, 25, 3, 52, 8,  7, 4, 32, 5, 74, 6, 90, 2, 24, 0, 53, 7, 43, 
    5, 61, 1, 29, 3, 72, 0, 67, 6, 72, 2, 93, 8, 16, 4, 45, 7, 17, 
    3, 56, 6, 49, 2, 35, 8, 94, 0, 19, 1, 11, 4, 39, 5, 84, 7, 91
  };
  const int q5024[] = {
    9, 9, // Number of jobs and machines
    4,  1, 5, 15, 1, 83, 0, 11, 3, 22, 2, 45, 7, 14, 8, 56, 6,  4, 
    1, 15, 5, 29, 0, 32, 3, 91, 2,  3, 6, 14, 4, 56, 8, 53, 7, 32, 
    7, 56, 1, 58, 5, 30, 6, 78, 8, 71, 3, 29, 4, 84, 0, 31, 2, 54, 
    0, 37, 2, 87, 6, 17, 1, 76, 3, 38, 7, 34, 4, 20, 5, 56, 8,  3, 
    6,  4, 0, 55, 8, 62, 2, 63, 4, 60, 3,  7, 1, 87, 7, 84, 5, 73, 
    0, 92, 6, 70, 5, 51, 1, 29, 7, 81, 8,  8, 4, 83, 2, 67, 3, 71, 
    5, 54, 3, 11, 6, 67, 8, 95, 4, 89, 2,  9, 7, 29, 1, 66, 0, 64, 
    2, 99, 7, 13, 6, 70, 0,  2, 3, 65, 5, 55, 8, 55, 1, 69, 4,  8, 
    1, 90, 2, 62, 8, 72, 4, 45, 0, 54, 6, 63, 3, 36, 5, 53, 7, 88
  };
  const int q5025[] = {
    9, 9, // Number of jobs and machines
    7, 13, 6, 44, 5, 51, 3, 29, 0, 55, 8, 87, 2, 10, 4, 32, 1, 42, 
    2,  3, 1, 71, 0, 35, 6, 73, 8, 59, 3, 40, 7,  8, 4, 73, 5, 98, 
    3, 72, 6, 51, 2, 91, 5, 77, 4, 29, 0, 36, 1, 15, 7, 61, 8, 45, 
    1, 90, 2, 53, 0,  8, 8, 13, 5, 24, 3, 55, 4, 59, 7, 36, 6, 29, 
    1, 61, 3, 71, 7, 29, 5,  1, 8, 46, 6, 92, 2, 61, 4, 15, 0, 97, 
    2, 18, 0, 61, 6, 57, 8, 14, 1, 57, 7, 99, 3, 78, 4, 67, 5, 24, 
    4, 30, 1,  6, 3, 42, 0, 49, 2, 74, 5, 92, 8, 41, 7, 74, 6, 81, 
    5, 35, 4, 14, 8, 16, 3, 22, 0, 68, 1,  4, 7, 73, 2, 55, 6, 81, 
    7, 41, 3, 57, 0, 78, 4, 94, 2,  7, 5, 33, 6, 97, 8, 80, 1, 58
  };
  const int q5026[] = {
    9, 9, // Number of jobs and machines
    8, 20, 6, 54, 2,  9, 3, 45, 5, 24, 1, 63, 0, 10, 7, 75, 4, 19, 
    0,  5, 1, 36, 2, 74, 4, 15, 3,  6, 6, 37, 5, 10, 7, 54, 8, 43, 
    5, 83, 0, 24, 8, 23, 3, 87, 4, 87, 2, 28, 7, 24, 6, 46, 1, 58, 
    5, 68, 6, 77, 0, 81, 8,  1, 2, 64, 3, 71, 7,  9, 4, 31, 1, 15, 
    7, 50, 3, 84, 0, 33, 4, 59, 5,  5, 6, 99, 1, 54, 2, 24, 8, 25, 
    5,  2, 4,  9, 1, 52, 6, 81, 7, 68, 8, 78, 2, 98, 0, 28, 3, 86, 
    7, 93, 4,  8, 3, 21, 1, 28, 2, 22, 8, 79, 0, 65, 5, 15, 6, 37, 
    4,  3, 7, 16, 6,  8, 1, 73, 8, 68, 2, 33, 5, 85, 3, 48, 0, 37, 
    3, 61, 5, 86, 6, 60, 1, 11, 2, 25, 0, 14, 7, 45, 8, 81, 4, 85
  };
  const int q5027[] = {
    9, 9, // Number of jobs and machines
    0, 80, 3, 71, 5, 67, 4, 76, 8, 22, 7, 38, 6, 37, 1, 66, 2, 91, 
    3, 26, 5, 43, 2,  7, 7, 53, 1, 40, 8, 78, 0, 29, 6, 23, 4, 47, 
    8, 11, 4, 12, 6, 51, 7,  6, 2, 47, 0, 26, 5, 44, 1, 79, 3, 26, 
    0, 57, 6, 90, 3, 14, 8, 59, 4, 85, 7, 71, 5,  3, 2, 90, 1, 30, 
    7, 30, 3, 65, 8, 14, 6, 76, 1, 14, 0, 42, 4, 30, 5, 48, 2, 24, 
    4, 56, 5, 60, 2, 89, 1,  6, 8, 58, 0, 82, 7,  2, 3,  7, 6, 16, 
    4, 81, 2, 93, 7, 64, 6, 58, 3,  3, 0, 88, 8, 48, 1, 36, 5, 25, 
    4, 87, 0, 22, 8, 89, 1, 96, 2, 71, 5, 75, 6,  5, 7,  6, 3, 74, 
    8, 98, 7, 69, 6, 84, 3, 70, 1,  8, 2, 79, 0, 70, 5, 41, 4, 85
  };
  const int q5028[] = {
    9, 9, // Number of jobs and machines
    7,  4, 1, 57, 0, 47, 3, 87, 8, 59, 5, 48, 6, 64, 4, 10, 2, 42, 
    8, 45, 1, 36, 5, 48, 4, 57, 2, 71, 6, 73, 3, 37, 7, 32, 0, 24, 
    8, 66, 5, 41, 1, 55, 2, 21, 4, 80, 6,  9, 0, 15, 7, 31, 3, 21, 
    7, 19, 2, 10, 1, 37, 3, 74, 5, 45, 6, 76, 4, 70, 0, 13, 8, 98, 
    4, 48, 8,  6, 7, 49, 2,  7, 1, 24, 5, 33, 6, 38, 0, 96, 3, 26, 
    7, 37, 4, 66, 2, 80, 8, 17, 0, 94, 6, 70, 1, 24, 5, 14, 3, 60, 
    8, 61, 0,  8, 6, 61, 5, 78, 2, 73, 7, 78, 4, 99, 1,  7, 3, 19, 
    8, 18, 2,  5, 5, 89, 6, 52, 1, 46, 4, 36, 0, 85, 7, 77, 3,  3, 
    1, 45, 4, 23, 3, 24, 6, 20, 7, 51, 8,  8, 0, 77, 5,  6, 2, 58
  };
  const int q5029[] = {
    9, 9, // Number of jobs and machines
    5, 91, 8, 61, 4, 61, 7, 27, 0, 23, 3, 90, 1, 92, 2, 36, 6, 32, 
    8, 20, 5, 32, 0, 57, 6, 59, 7, 50, 4, 84, 3, 78, 1, 13, 2, 60, 
    0, 86, 2, 41, 4, 10, 1, 56, 3, 71, 6,  2, 5, 44, 8, 51, 7, 53, 
    2, 10, 4, 78, 1, 75, 6, 11, 3, 57, 7, 46, 0, 76, 5, 99, 8, 25, 
    0, 15, 3, 39, 8, 85, 5, 25, 4, 58, 1, 49, 2, 49, 7, 49, 6, 61, 
    8, 90, 7, 24, 5, 39, 6, 58, 1, 88, 4, 87, 2, 83, 0, 61, 3,  3, 
    3, 50, 8, 45, 1, 93, 2,  4, 6, 92, 4, 68, 0, 87, 7, 63, 5, 13, 
    7, 64, 8, 45, 3, 57, 2, 29, 0, 17, 1, 30, 6, 79, 4, 63, 5, 38, 
    4,  6, 2, 56, 6, 29, 1, 64, 3, 14, 5, 57, 7, 77, 8, 22, 0, 17
  };
  const int q5030[] = {
    9, 9, // Number of jobs and machines
    1, 85, 4, 47, 6, 31, 2, 70, 7, 59, 5, 34, 0, 52, 8, 30, 3, 95, 
    1, 36, 6, 63, 3, 94, 2, 80, 5, 42, 4,  9, 8, 38, 7,  5, 0,  9, 
    3, 21, 7, 58, 4, 46, 5, 73, 2, 47, 0, 55, 8,  2, 1, 77, 6, 84, 
    0, 39, 3, 87, 6, 69, 1, 71, 4, 28, 2, 46, 7, 14, 8, 41, 5, 27, 
    3, 32, 5, 34, 8, 61, 4, 44, 2, 66, 0, 11, 1, 37, 6, 14, 7, 46, 
    2,  9, 4, 25, 8, 11, 3, 62, 6, 98, 0, 43, 5, 29, 7, 70, 1, 16, 
    4, 33, 1, 59, 2, 22, 8, 64, 6, 70, 7, 84, 3, 49, 0, 60, 5,  6, 
    6, 80, 0, 18, 2, 80, 4,  8, 1, 26, 5,  2, 3, 40, 8, 25, 7, 97, 
    1, 83, 0, 40, 5, 95, 7, 17, 4, 66, 6, 74, 3, 29, 8, 92, 2, 29
  };
  const int q5031[] = {
    9, 9, // Number of jobs and machines
    7, 90, 8, 76, 1, 94, 4, 53, 5, 27, 6,  6, 0, 76, 2, 10, 3, 80, 
    5, 99, 7, 64, 2, 94, 0, 75, 4, 80, 8, 99, 1, 16, 6, 89, 3, 24, 
    0, 55, 6, 15, 2,  9, 8, 88, 5, 95, 1,  2, 4, 88, 3, 34, 7, 55, 
    2, 65, 7, 54, 5, 25, 1, 81, 4,  5, 8, 97, 0, 34, 3, 18, 6, 41, 
    3, 67, 8, 35, 6, 98, 4, 58, 2, 31, 7, 22, 5, 76, 1, 49, 0,  9, 
    0, 75, 3, 45, 4, 58, 6, 78, 8, 36, 2, 79, 1, 43, 5, 96, 7, 77, 
    3, 76, 8, 50, 1, 75, 5, 27, 2, 84, 4, 41, 7, 21, 6, 55, 0, 63, 
    3, 71, 8, 39, 5, 37, 4, 82, 2, 53, 1, 23, 6, 66, 0, 27, 7, 71, 
    4, 87, 8, 59, 7, 74, 1,  5, 3, 40, 2, 75, 6, 63, 5, 39, 0, 54
  };
  const int q5032[] = {
    9, 9, // Number of jobs and machines
    0, 11, 4, 34, 8, 43, 6, 42, 2, 59, 7, 53, 1, 26, 5, 81, 3, 92, 
    8, 49, 7, 80, 1, 19, 5, 29, 4, 55, 6, 27, 3,  3, 2, 42, 0, 54, 
    1, 29, 5, 12, 0, 74, 2, 36, 6, 34, 3, 42, 8,  2, 4, 58, 7, 24, 
    1, 57, 4, 13, 7, 88, 6, 37, 0, 70, 8, 52, 5, 56, 3, 74, 2, 89, 
    6, 51, 3, 52, 4, 93, 2, 61, 5, 75, 0, 22, 1, 28, 7, 73, 8, 33, 
    8, 98, 5,  2, 2, 24, 6, 58, 3, 93, 4, 83, 0, 88, 7, 59, 1, 36, 
    1,  2, 6, 96, 5, 59, 3, 13, 2,  8, 0, 99, 7, 42, 4, 43, 8, 54, 
    4, 51, 5, 10, 1, 86, 7, 76, 2,  7, 8, 59, 0,  9, 6,  9, 3, 38, 
    4, 10, 1, 74, 6, 73, 8, 73, 2, 67, 5, 81, 7, 42, 0, 39, 3, 46
  };
  const int q5033[] = {
    9, 9, // Number of jobs and machines
    5, 37, 4,  8, 0, 15, 2, 51, 1, 47, 6, 16, 7, 72, 8, 18, 3,  9, 
    2, 75, 7,  2, 1,  9, 0, 16, 3, 54, 8, 23, 6, 18, 4, 69, 5,  8, 
    2, 86, 7, 92, 5, 66, 4, 69, 0, 90, 8, 40, 3, 86, 1, 89, 6, 29, 
    6, 25, 7, 62, 1, 85, 3, 10, 8, 36, 4, 61, 2, 21, 0, 92, 5, 78, 
    0,  1, 1, 81, 3, 16, 2, 25, 4, 97, 6, 59, 8, 38, 5,  2, 7,  4, 
    7, 52, 3, 41, 8, 84, 1, 11, 4, 15, 5, 17, 0, 52, 2, 90, 6, 65, 
    1, 58, 2,  2, 7, 22, 0, 79, 6, 73, 8,  5, 4, 46, 3, 30, 5, 26, 
    5, 59, 6, 76, 0, 37, 3, 17, 7, 13, 1, 78, 8, 74, 4, 33, 2, 42, 
    8, 81, 5, 30, 4, 17, 2, 31, 1, 45, 3, 24, 6, 30, 7, 13, 0, 79
  };
  const int q5034[] = {
    9, 9, // Number of jobs and machines
    5, 45, 3, 17, 1, 65, 4, 19, 2, 64, 8,  2, 7, 49, 0,  1, 6, 62, 
    7, 33, 6, 85, 4, 59, 3, 36, 2, 33, 8, 21, 0, 67, 5, 65, 1, 36, 
    6, 65, 7, 48, 4, 56, 1, 76, 5, 48, 3, 20, 2, 39, 8, 60, 0, 24, 
    4, 22, 1, 13, 3, 21, 8, 92, 7, 21, 6, 17, 0, 17, 2, 72, 5, 56, 
    2, 68, 6, 43, 7, 66, 8, 98, 5, 23, 4, 97, 1,  9, 3, 10, 0, 98, 
    2, 42, 3,  5, 0,  8, 6, 36, 4, 87, 7, 79, 5, 58, 1, 23, 8, 98, 
    3, 15, 5, 95, 6, 97, 4, 43, 0, 70, 2, 13, 7, 79, 1, 22, 8, 95, 
    8, 47, 1, 70, 5, 68, 4, 75, 0,  7, 6, 99, 3, 86, 2, 33, 7, 43, 
    1, 82, 5, 24, 0, 85, 8, 33, 6, 67, 4, 40, 7, 48, 3, 86, 2, 50
  };
  const int q5035[] = {
    9, 9, // Number of jobs and machines
    7, 73, 4, 46, 2, 47, 0, 73, 1, 40, 3, 97, 8, 72, 5, 97, 6, 12, 
    5, 30, 1, 29, 0, 62, 3, 10, 4, 75, 2, 39, 8, 24, 6, 35, 7, 69, 
    8, 61, 6, 17, 7, 74, 0, 97, 4, 20, 5, 23, 2, 43, 1, 78, 3, 88, 
    2, 24, 4, 30, 6, 47, 1, 87, 7, 93, 0, 37, 3, 13, 8, 82, 5, 42, 
    1, 83, 5, 46, 0, 10, 2, 81, 6, 94, 4, 15, 8, 32, 7, 87, 3, 29, 
    8, 48, 1, 79, 3, 70, 4, 99, 0,  5, 6, 29, 2, 80, 5,  2, 7, 20, 
    6, 83, 4, 62, 0,  5, 3, 34, 2, 30, 7, 75, 8, 84, 5, 59, 1, 78, 
    6, 75, 1, 29, 7, 79, 5, 80, 2, 57, 0, 78, 4, 93, 8,  1, 3, 24, 
    0,  7, 4, 34, 3, 81, 7, 57, 8, 12, 1, 53, 6, 97, 5, 95, 2,  3
  };
  const int q5036[] = {
    9, 9, // Number of jobs and machines
    7, 45, 8, 27, 2, 80, 3, 88, 4, 13, 1, 20, 0, 80, 5, 26, 6,  3, 
    7, 99, 5, 83, 1,  1, 8, 24, 4, 18, 6, 77, 3,  3, 0, 88, 2, 68, 
    5, 54, 1, 78, 4, 14, 2, 72, 3, 78, 8, 48, 7, 50, 0, 57, 6, 30, 
    1, 41, 6, 70, 3, 51, 4, 96, 7, 17, 5, 86, 2, 34, 0, 66, 8, 78, 
    5,  2, 0, 88, 2, 26, 7, 45, 8, 11, 6,  4, 4, 89, 1, 34, 3,  3, 
    1, 37, 6,  8, 5, 51, 2, 27, 4, 64, 7, 85, 3,  4, 0, 31, 8, 71, 
    6, 84, 0, 70, 1, 65, 7, 45, 5, 68, 3, 58, 2, 75, 8, 66, 4, 87, 
    2,  8, 1, 79, 3, 30, 6, 51, 8, 82, 0, 68, 5, 88, 7, 59, 4, 36, 
    1, 70, 7, 50, 4,  6, 2, 86, 5, 25, 3, 59, 6, 62, 8, 44, 0, 18
  };
  const int q5037[] = {
    9, 9, // Number of jobs and machines
    1,  2, 3, 33, 7, 63, 6, 71, 2,  3, 8, 20, 4, 27, 5, 43, 0, 98, 
    7, 26, 1, 20, 5, 55, 4, 21, 3, 83, 0, 93, 2, 97, 6, 65, 8,  4, 
    3, 25, 1, 59, 0, 56, 4, 82, 8, 96, 7, 88, 5, 91, 6, 73, 2, 11, 
    1, 69, 2, 85, 8, 28, 0, 99, 5, 89, 6, 63, 3, 22, 7, 81, 4, 33, 
    8, 61, 5, 72, 3, 73, 7, 40, 0, 51, 2, 32, 1,  1, 6, 41, 4, 90, 
    3, 53, 6, 10, 8, 47, 1, 36, 2, 50, 0, 76, 7, 24, 4, 46, 5, 36, 
    7, 29, 4,  9, 3, 27, 2,  1, 0, 58, 1, 69, 6, 72, 8, 71, 5, 17, 
    2, 48, 1, 51, 0, 93, 3, 94, 5, 27, 6, 29, 8, 98, 7, 43, 4, 67, 
    5, 55, 8, 93, 4, 82, 3, 24, 0, 41, 7, 83, 2, 85, 1,  5, 6, 32
  };
  const int q5038[] = {
    9, 9, // Number of jobs and machines
    1, 39, 8,  2, 2, 48, 4, 32, 5, 12, 7, 97, 6, 91, 0, 95, 3, 40, 
    4,  2, 6, 34, 7, 50, 5,  4, 1, 68, 3, 33, 2, 10, 8, 17, 0, 89, 
    7, 54, 3, 80, 6, 23, 8, 95, 2, 97, 1, 61, 0, 95, 4, 34, 5, 77, 
    3, 11, 2, 25, 8, 60, 7, 85, 6, 20, 4, 88, 1, 59, 5, 51, 0, 72, 
    2, 73, 6,  7, 3, 27, 5, 96, 1, 57, 4, 26, 7, 61, 0, 15, 8, 26, 
    2, 96, 0, 29, 7, 14, 3, 52, 4, 96, 1,  9, 8, 99, 5, 79, 6, 46, 
    7, 68, 2, 36, 0, 52, 4, 84, 1, 94, 6, 36, 5, 63, 3, 49, 8, 17, 
    5, 90, 2, 72, 1, 87, 7, 48, 3, 21, 4, 89, 6, 16, 0, 66, 8, 54, 
    0, 21, 3,  3, 2, 89, 1, 96, 5, 60, 4, 52, 7, 98, 8, 25, 6, 93
  };
  const int q5039[] = {
    9, 9, // Number of jobs and machines
    5, 17, 7, 48, 8, 29, 3, 59, 6, 96, 2, 20, 4, 43, 0, 74, 1, 87, 
    6, 11, 2, 31, 8, 54, 5, 45, 7, 49, 4, 15, 1, 22, 0,  7, 3, 14, 
    8, 74, 1, 23, 5, 21, 4, 75, 7, 25, 6, 60, 3, 53, 2,  5, 0, 30, 
    0, 81, 3, 72, 4, 69, 7, 35, 1, 47, 2, 76, 8, 57, 6, 81, 5, 44, 
    8, 31, 6,  9, 5, 66, 7,  1, 4, 24, 0, 75, 1, 82, 2, 66, 3, 58, 
    0, 10, 2,  7, 5, 22, 6, 95, 4,  9, 7, 28, 3, 23, 1, 54, 8, 14, 
    4, 41, 8, 96, 2,  6, 6, 17, 5,  9, 3, 74, 1, 56, 0, 17, 7, 48, 
    0, 86, 1, 47, 5, 90, 7, 10, 2, 83, 8, 68, 6,  2, 4,  7, 3, 93, 
    5, 15, 1, 55, 8, 18, 3, 90, 4, 29, 0, 24, 2, 29, 6,  2, 7, 92
  };
  const int q5040[] = {
    9, 9, // Number of jobs and machines
    1, 99, 8,  5, 2, 57, 0, 51, 5, 71, 3, 50, 6, 15, 7, 63, 4, 79, 
    3, 40, 2,  6, 0, 71, 7, 22, 5, 96, 6, 18, 1, 22, 4, 64, 8, 30, 
    3, 83, 8, 36, 7, 31, 4, 44, 2, 31, 1, 64, 5, 65, 0, 63, 6, 59, 
    6, 93, 4, 78, 2, 44, 3, 61, 5, 50, 7, 18, 1, 60, 0, 33, 8, 70, 
    3, 79, 7, 17, 1,  1, 6, 10, 0, 36, 5, 89, 4, 11, 8, 33, 2, 99, 
    1, 14, 0, 59, 4, 64, 2, 85, 6, 73, 8, 30, 7, 75, 3, 50, 5, 16, 
    5, 68, 6, 61, 0, 47, 4, 85, 7, 33, 2, 31, 3, 83, 1, 10, 8, 56, 
    5, 91, 7, 58, 1, 43, 2, 24, 8,  6, 6, 95, 3, 90, 4, 72, 0, 47, 
    0, 19, 1, 32, 5, 38, 3, 96, 6, 33, 4, 21, 2, 92, 8,  4, 7, 35
  };
  const int q5041[] = {
    9, 9, // Number of jobs and machines
    0, 30, 6, 15, 4, 73, 3, 79, 8, 87, 5, 71, 2, 49, 7, 69, 1, 92, 
    6, 31, 4, 45, 0, 16, 3, 74, 8, 69, 7, 66, 2,  3, 1, 92, 5, 40, 
    8, 20, 6, 11, 4,  2, 0, 34, 2, 99, 1, 83, 5, 32, 7, 44, 3, 21, 
    1, 48, 5, 26, 2, 36, 8, 32, 7, 26, 3, 16, 4, 24, 6, 22, 0, 36, 
    7, 95, 3, 80, 0, 69, 6, 79, 2, 28, 4, 13, 5, 64, 1, 31, 8, 92, 
    7, 82, 5, 75, 3, 83, 2, 40, 4, 39, 1, 80, 0, 33, 8,  6, 6, 20, 
    7, 79, 1, 71, 3, 74, 6, 57, 2, 80, 0, 15, 8, 23, 4, 44, 5, 74, 
    8, 25, 7, 18, 4, 89, 3, 88, 5, 91, 2, 26, 0, 47, 6, 66, 1, 19, 
    5, 94, 0, 61, 1, 91, 2, 32, 8, 69, 3, 44, 4, 91, 6, 35, 7, 89
  };
  const int q5042[] = {
    9, 9, // Number of jobs and machines
    5,  3, 0, 85, 4, 84, 6, 74, 8, 51, 1, 99, 7, 83, 3, 81, 2, 63, 
    1, 60, 5, 13, 7, 25, 4, 45, 2, 12, 0, 88, 6, 95, 3, 84, 8, 93, 
    6, 30, 3, 62, 7, 18, 5, 73, 0,  6, 8, 80, 1, 50, 2, 36, 4, 71, 
    0, 37, 4, 36, 3,  4, 5, 40, 6, 96, 1, 47, 2, 38, 8, 37, 7, 57, 
    4, 53, 3, 36, 2, 99, 1, 38, 5, 55, 8,  1, 7, 76, 6, 97, 0, 98, 
    7, 78, 2, 18, 1, 47, 5, 32, 6, 92, 4, 75, 0, 43, 8, 47, 3, 89, 
    8, 16, 4, 45, 1, 16, 0, 18, 3, 93, 2, 34, 6, 85, 5, 34, 7, 42, 
    0, 37, 3, 62, 2, 39, 5, 19, 6, 12, 4, 42, 1, 31, 8, 41, 7, 18, 
    4, 70, 2, 46, 0, 69, 8, 58, 5, 28, 3, 79, 1, 71, 6,  8, 7, 57
  };
  const int q5043[] = {
    9, 9, // Number of jobs and machines
    8, 12, 4, 24, 6,  2, 3, 15, 7, 37, 1, 77, 2,  1, 5, 11, 0, 50, 
    7, 63, 4, 69, 3, 57, 5,  3, 2, 30, 0, 74, 1,  4, 6,  8, 8, 82, 
    4, 67, 7, 83, 1, 97, 3, 35, 5, 34, 8, 34, 2, 67, 0, 24, 6, 25, 
    2, 68, 7, 66, 1, 72, 6, 34, 8, 22, 4, 81, 0, 59, 5, 99, 3, 27, 
    4, 23, 0, 66, 3, 41, 1, 48, 6, 15, 7, 49, 5, 92, 8, 40, 2, 28, 
    2, 25, 7, 49, 0, 27, 5,  4, 6, 11, 3, 69, 1, 54, 4,  3, 8, 92, 
    3,  2, 2, 94, 6, 45, 7, 51, 1, 90, 0, 31, 8, 23, 5, 83, 4, 95, 
    6, 84, 7, 83, 4, 64, 3, 28, 5, 99, 0, 80, 1, 25, 2, 38, 8, 45, 
    2, 75, 5, 73, 0, 73, 7, 73, 1,  8, 3, 66, 6, 97, 4, 49, 8,  6
  };
  const int q5044[] = {
    9, 9, // Number of jobs and machines
    6, 43, 1, 30, 7, 27, 8, 66, 3, 53, 5, 50, 0, 15, 4, 63, 2, 24, 
    0, 99, 5, 59, 6, 70, 3, 70, 7, 66, 1, 89, 4, 60, 8, 37, 2,  9, 
    1, 71, 0, 62, 7, 70, 5, 77, 3, 45, 2, 81, 6, 99, 8, 33, 4, 46, 
    5,  2, 0, 35, 7, 78, 3, 46, 8, 34, 2, 10, 1, 53, 4, 50, 6, 74, 
    5,  7, 8, 65, 4, 69, 3, 75, 1,  3, 7, 51, 0, 43, 2, 77, 6, 41, 
    1, 65, 0, 91, 3, 58, 7, 65, 5,  4, 8, 84, 2, 21, 4, 64, 6, 20, 
    0, 64, 1,  5, 4, 14, 6, 30, 2, 87, 7, 85, 3, 12, 8, 21, 5, 75, 
    0,  9, 7, 60, 8, 94, 1, 20, 6, 28, 2, 43, 5, 23, 3, 69, 4, 97, 
    0, 18, 6, 29, 1, 29, 3, 69, 2, 78, 8, 19, 4, 30, 5, 37, 7, 79
  };
  const int q5045[] = {
    9, 9, // Number of jobs and machines
    2,  5, 4,  5, 5, 45, 7, 38, 8, 26, 6, 90, 3, 63, 1, 65, 0, 24, 
    7, 43, 8,  5, 4, 19, 6, 39, 0, 21, 1, 36, 2, 99, 3, 62, 5, 19, 
    7, 52, 2, 87, 4, 85, 8, 82, 0, 99, 1, 38, 6, 31, 5, 65, 3, 82, 
    5, 36, 3, 14, 6, 17, 2, 58, 0, 97, 7, 39, 4, 41, 1, 10, 8, 61, 
    7, 78, 1,  3, 6,  4, 0, 53, 8, 90, 4, 17, 3, 65, 2,  5, 5, 41, 
    5,  8, 0, 62, 2,  2, 1, 91, 4, 87, 3, 49, 6, 15, 7, 57, 8, 83, 
    3, 34, 6, 81, 1, 67, 5, 90, 4, 58, 8,  6, 2, 65, 7, 31, 0, 40, 
    0, 84, 8, 64, 3, 71, 4,  4, 7, 24, 1, 95, 2, 63, 5, 73, 6, 27, 
    5, 23, 3, 27, 8, 10, 1, 22, 6, 53, 7, 13, 4, 21, 0, 82, 2, 73
  };
  const int q5046[] = {
    9, 9, // Number of jobs and machines
    7, 66, 5, 57, 0, 32, 4, 43, 1, 63, 8, 55, 3, 75, 2, 63, 6, 99, 
    8, 56, 2, 71, 6, 43, 4, 46, 0, 32, 7,  5, 5, 91, 1, 69, 3, 33, 
    6, 88, 3, 19, 1, 54, 0, 11, 5, 13, 8, 81, 2, 24, 4, 38, 7, 23, 
    0, 84, 2, 99, 8, 22, 3, 49, 6, 22, 5, 20, 1, 80, 7, 51, 4, 11, 
    5, 64, 2, 77, 1, 78, 7, 19, 6, 50, 8, 81, 3, 95, 0, 79, 4, 31, 
    1, 74, 8,  2, 2, 88, 3,  1, 4, 32, 5, 80, 6, 32, 7, 65, 0, 29, 
    1, 83, 8, 48, 3, 35, 5, 32, 6, 65, 7, 18, 2, 79, 0, 15, 4, 33, 
    5, 91, 8, 46, 0, 57, 1, 20, 7, 15, 2, 49, 4, 93, 6, 96, 3,  7, 
    6, 24, 2, 22, 8, 70, 4, 58, 7, 76, 3, 68, 0, 39, 1, 78, 5, 46
  };
  const int q5047[] = {
    9, 9, // Number of jobs and machines
    2, 45, 7, 40, 0, 14, 5, 59, 8, 29, 4, 94, 6, 26, 1, 41, 3, 75, 
    8, 29, 4, 18, 7, 41, 1, 35, 0, 89, 3, 95, 5, 77, 2, 82, 6, 13, 
    3, 93, 5, 50, 0, 75, 7, 78, 8, 98, 4, 40, 1, 91, 6,  5, 2, 58, 
    4, 58, 0, 31, 1, 66, 6, 72, 3, 14, 7, 62, 8, 22, 2, 90, 5, 11, 
    5, 30, 2, 45, 4, 28, 1, 69, 0, 19, 3, 73, 6, 57, 8, 63, 7, 32, 
    6, 81, 5, 25, 0, 99, 8, 94, 1, 37, 3, 32, 7,  3, 4, 26, 2, 78, 
    3, 60, 4, 79, 1, 62, 8, 46, 2, 51, 0, 66, 6, 99, 5,  8, 7, 40, 
    3, 72, 1, 97, 5, 68, 7, 21, 8, 61, 2, 12, 6, 95, 4, 95, 0, 96, 
    5, 91, 8, 17, 7, 14, 4, 37, 0, 62, 6,  6, 3, 61, 1, 23, 2, 47
  };
  const int q5048[] = {
    9, 9, // Number of jobs and machines
    7, 62, 4, 70, 2, 70, 8, 98, 5, 74, 6, 45, 0,  8, 1, 77, 3, 46, 
    7, 62, 2, 57, 5, 14, 6, 53, 4, 48, 1, 27, 3, 46, 8, 15, 0, 89, 
    7, 73, 8, 52, 1, 10, 6, 28, 5, 64, 0, 46, 3, 48, 2, 32, 4, 36, 
    6, 37, 7, 70, 1, 95, 4, 88, 8, 93, 2, 27, 0, 74, 3, 51, 5, 87, 
    0, 19, 6, 90, 7, 83, 3, 91, 1, 16, 8, 19, 4, 36, 2, 53, 5, 18, 
    2,  9, 0, 78, 6, 31, 3,  8, 5, 48, 8, 20, 1,  9, 7,  9, 4, 51, 
    3, 77, 6,  6, 5, 49, 7, 36, 1, 31, 2, 95, 4, 29, 8, 35, 0, 95, 
    7,  1, 1, 23, 4, 28, 2, 15, 5, 34, 0, 63, 6, 75, 3, 50, 8, 62, 
    7, 99, 5, 43, 2, 16, 4, 95, 6, 99, 8, 84, 3, 93, 1, 71, 0, 79
  };
  const int q5049[] = {
    9, 9, // Number of jobs and machines
    4, 53, 7, 12, 2, 69, 5, 69, 0, 98, 8, 43, 6, 11, 3, 15, 1, 80, 
    6,  2, 0, 68, 7, 88, 8, 92, 1, 27, 4, 37, 5, 60, 2, 60, 3, 61, 
    0, 19, 1, 64, 7, 47, 8, 35, 2, 44, 3, 90, 4, 86, 6, 59, 5, 56, 
    4, 45, 7, 60, 3, 10, 0, 32, 1, 71, 5, 56, 6, 40, 2, 89, 8, 23, 
    7, 10, 3, 28, 2, 63, 5, 14, 0, 18, 4, 27, 8, 36, 1, 27, 6, 52, 
    5, 13, 1, 34, 7, 51, 6, 38, 8, 63, 3, 62, 4, 31, 2, 63, 0, 22, 
    4, 99, 2, 97, 0, 36, 5, 63, 1, 19, 7, 29, 3, 57, 6, 58, 8, 58, 
    2, 23, 6, 43, 1, 67, 8, 24, 7, 89, 4, 67, 0, 28, 3, 49, 5, 34, 
    7, 96, 1, 69, 5, 15, 2, 64, 8, 31, 0, 45, 6, 96, 4, 19, 3, 97
  };
  const int q5050[] = {
    9, 9, // Number of jobs and machines
    1, 95, 0, 57, 6, 55, 3,  6, 2, 92, 5, 70, 4, 56, 8, 99, 7, 79, 
    8, 80, 6, 62, 2, 53, 3, 33, 5, 13, 7, 79, 0, 67, 1, 88, 4, 47, 
    0, 96, 6, 47, 1, 70, 4,  7, 3, 46, 8, 59, 5, 39, 7, 71, 2, 95, 
    3, 16, 7, 29, 8, 70, 6, 14, 4, 72, 1, 58, 2, 19, 5, 71, 0, 80, 
    0, 99, 5, 93, 4, 51, 3, 86, 1, 91, 6, 10, 8,  1, 2, 67, 7, 94, 
    7, 13, 4, 88, 2, 63, 5, 34, 8,  5, 0, 74, 3, 37, 6, 35, 1, 85, 
    8, 55, 1, 46, 0,  8, 7, 62, 3, 62, 6, 32, 2, 70, 5, 25, 4, 53, 
    6, 74, 8, 80, 2, 52, 3, 78, 4, 34, 1, 44, 5, 94, 7, 55, 0, 96, 
    0, 97, 2, 33, 1,  7, 3, 96, 4, 81, 6, 99, 7, 41, 8, 30, 5, 50
  };
  const int q5051[] = {
    9, 9, // Number of jobs and machines
    2, 54, 8, 79, 0, 31, 7, 15, 1, 88, 6, 37, 4, 83, 3, 26, 5,  3, 
    0, 83, 5, 41, 4, 39, 3, 92, 8, 16, 6, 55, 1, 93, 7, 56, 2, 54, 
    0, 95, 8, 18, 3, 83, 7, 94, 5, 49, 4, 44, 6, 76, 2, 36, 1,  7, 
    8,  3, 7, 79, 0, 96, 2, 82, 5, 17, 3, 60, 1, 77, 4,  7, 6, 23, 
    2, 47, 4, 54, 0, 10, 6, 89, 7, 77, 3, 51, 5, 45, 1, 57, 8, 82, 
    0, 43, 7, 38, 4, 42, 3, 20, 1, 35, 2, 39, 5, 97, 6, 44, 8, 26, 
    3, 90, 7, 43, 2, 91, 6, 83, 4, 30, 0, 55, 1, 64, 8, 82, 5, 76, 
    8, 95, 2, 45, 0, 33, 1, 18, 3,  7, 7,  7, 4, 14, 5, 84, 6, 45, 
    2,  4, 3, 94, 1, 90, 6, 57, 7, 55, 5, 11, 0, 28, 4, 99, 8, 94
  };
  const int q5052[] = {
    9, 9, // Number of jobs and machines
    6,  4, 5, 21, 2, 59, 0, 19, 3, 19, 4, 39, 7, 76, 1,  5, 8,  9, 
    3, 96, 4,  2, 0, 92, 1, 53, 6, 92, 8, 37, 2, 66, 5, 23, 7,  2, 
    5, 68, 4, 48, 0,  1, 8, 48, 2, 34, 3, 61, 1, 91, 7, 49, 6, 27, 
    1, 37, 8,  1, 4, 20, 2, 48, 5, 45, 7, 43, 0,  7, 3, 18, 6, 76, 
    4, 15, 6, 31, 0, 13, 5, 92, 8, 54, 3, 69, 2, 12, 1, 96, 7, 65, 
    2, 66, 4, 91, 5, 65, 6, 36, 3, 90, 8, 83, 0, 73, 1, 57, 7, 56, 
    5, 33, 6, 12, 3,  7, 4, 16, 7, 39, 1, 97, 0, 69, 2, 73, 8, 23, 
    0, 94, 7, 93, 3, 56, 5, 59, 4, 86, 1, 22, 8, 83, 6, 39, 2, 50, 
    5, 67, 3, 42, 4, 39, 8, 47, 6, 60, 2, 47, 7, 76, 0, 51, 1, 58
  };
  const int q5053[] = {
    9, 9, // Number of jobs and machines
    5, 30, 4, 42, 2, 32, 1, 57, 8, 77, 3, 96, 6, 49, 0, 41, 7, 22, 
    3, 29, 1, 85, 2, 62, 4,  5, 0, 29, 6, 82, 5, 85, 7, 25, 8, 55, 
    6, 24, 2, 80, 8, 50, 0, 77, 5, 32, 3, 93, 7, 17, 1, 40, 4, 58, 
    3, 92, 2, 86, 6, 40, 1, 77, 5, 53, 8, 66, 7, 96, 4, 94, 0, 11, 
    7, 69, 2, 82, 8, 79, 5, 16, 1, 41, 4, 57, 0, 47, 6, 12, 3, 24, 
    8, 55, 6,  5, 7, 92, 2, 21, 3, 64, 1, 84, 4, 39, 0, 62, 5, 45, 
    8, 41, 3, 85, 5, 45, 4, 93, 2, 65, 0, 90, 7, 21, 6, 84, 1, 50, 
    4, 22, 1, 90, 7, 25, 5, 16, 0, 15, 3,  1, 6, 41, 2, 78, 8,  9, 
    3, 12, 2, 27, 5, 20, 1, 38, 8, 82, 4, 85, 6, 42, 0, 28, 7, 15
  };
  const int q5054[] = {
    9, 9, // Number of jobs and machines
    3, 20, 1, 37, 0, 66, 5, 98, 8, 53, 6, 81, 4, 36, 7, 96, 2, 74, 
    1, 77, 3, 38, 6, 65, 2, 49, 5, 51, 0, 72, 7, 59, 8, 60, 4, 75, 
    3, 96, 5, 59, 8, 59, 2, 87, 4, 67, 1, 33, 0, 83, 6, 55, 7, 39, 
    6, 98, 0, 86, 8, 72, 7, 26, 2, 74, 4, 58, 3, 30, 5, 72, 1, 68, 
    3, 66, 1, 23, 0, 67, 7, 99, 2, 56, 5, 13, 6, 84, 4, 81, 8, 92, 
    6, 81, 0, 35, 3, 77, 2, 50, 8, 10, 5, 16, 4, 67, 7, 10, 1, 31, 
    2, 80, 8, 95, 4, 66, 0, 70, 7,  2, 1, 43, 5, 52, 6, 36, 3, 10, 
    8, 46, 1, 10, 4, 27, 7, 95, 6, 88, 3, 58, 5, 62, 2, 64, 0, 11, 
    1, 51, 7, 56, 2, 56, 4, 21, 8, 11, 3, 84, 0, 49, 5, 20, 6,  3
  };
  const int q5055[] = {
    9, 9, // Number of jobs and machines
    2, 83, 0, 82, 1, 66, 3, 32, 6, 55, 4, 96, 8, 89, 7, 43, 5, 53, 
    0, 72, 6, 37, 8, 46, 5, 36, 7, 73, 4, 86, 1, 75, 3, 70, 2, 80, 
    8, 37, 2, 81, 6, 77, 4,  9, 7, 96, 0, 65, 1, 46, 5, 53, 3, 41, 
    6, 84, 8, 22, 5, 54, 7, 12, 1, 74, 4, 42, 3, 95, 0, 87, 2, 26, 
    6, 14, 2, 59, 4, 50, 7, 68, 5,  9, 0, 75, 8, 61, 1, 78, 3,  2, 
    0, 37, 7, 21, 4, 38, 8, 76, 2, 40, 1, 20, 6, 55, 5, 31, 3, 73, 
    3, 17, 6,  2, 7, 75, 5, 99, 2, 77, 1, 94, 4, 98, 0, 42, 8, 69, 
    2,  9, 6, 27, 8, 70, 7, 19, 0, 15, 3, 34, 1, 17, 4, 53, 5, 40, 
    3, 69, 0, 28, 7, 54, 5, 24, 1, 41, 4,  4, 2,  4, 8, 25, 6, 18
  };
  const int q5056[] = {
    9, 9, // Number of jobs and machines
    5, 89, 6, 26, 3,  5, 7, 38, 0, 92, 8, 17, 1, 88, 2, 83, 4, 66, 
    7, 36, 5,  3, 6,  8, 1, 46, 3, 67, 4, 81, 8, 75, 0, 14, 2, 47, 
    0, 49, 7, 18, 4, 44, 5, 89, 8, 69, 2, 82, 6,  7, 3, 86, 1, 12, 
    2, 61, 6, 88, 4, 54, 7, 73, 5, 35, 8, 13, 0, 13, 3, 75, 1, 71, 
    3, 22, 5, 58, 7,  3, 1, 97, 6, 83, 4, 14, 2, 86, 8, 85, 0, 69, 
    7, 29, 1, 97, 8,  1, 0, 95, 4, 71, 6, 42, 2, 48, 3,  5, 5, 13, 
    0, 77, 2, 99, 6, 79, 1, 95, 3, 94, 4,  5, 5,  8, 7, 90, 8, 36, 
    8, 44, 3, 32, 0,  3, 1,  8, 7, 74, 2, 44, 6, 13, 4, 82, 5, 58, 
    5,  4, 3,  2, 6, 53, 1, 59, 7, 85, 2, 27, 0,  9, 4, 94, 8, 14
  };
  const int q5057[] = {
    9, 9, // Number of jobs and machines
    4, 58, 5, 42, 3, 34, 2,  9, 7, 52, 0, 12, 6, 35, 1, 65, 8, 75, 
    8, 42, 2, 49, 1, 65, 7, 28, 4, 78, 0, 69, 6, 21, 3, 95, 5, 53, 
    4, 46, 3, 16, 6, 28, 8, 36, 7, 72, 1, 36, 0, 60, 2, 78, 5, 13, 
    3, 49, 4, 11, 6, 81, 1, 27, 7,  4, 0, 21, 2, 66, 5, 17, 8, 84, 
    5, 37, 1, 21, 2, 92, 7, 86, 4, 50, 0, 15, 8, 33, 3,  3, 6, 55, 
    1,  6, 2, 15, 0, 97, 4, 10, 7, 14, 6, 11, 8, 22, 3, 12, 5, 36, 
    5, 86, 8, 57, 7, 65, 1, 73, 0, 33, 6, 22, 2, 27, 4, 40, 3, 92, 
    5, 95, 0, 30, 4, 28, 8, 15, 2, 21, 7, 93, 3, 16, 1, 27, 6, 56, 
    6, 58, 2,  7, 8, 48, 7, 16, 3, 34, 5, 18, 0, 79, 4,  4, 1,  1
  };
  const int q5058[] = {
    9, 9, // Number of jobs and machines
    3, 85, 1, 13, 2, 25, 5,  8, 8, 95, 7, 70, 4, 30, 0, 69, 6, 33, 
    5, 33, 1,  3, 8, 42, 7, 67, 0, 78, 6, 56, 3, 55, 2, 54, 4, 87, 
    7, 54, 6, 56, 1, 98, 3, 25, 5, 85, 8, 49, 4, 26, 0, 92, 2, 51, 
    3, 26, 1, 62, 0, 92, 4, 38, 8, 76, 5, 84, 6, 46, 2, 71, 7, 32, 
    5, 13, 0, 40, 7, 46, 6, 21, 8, 22, 4, 58, 2, 86, 3, 95, 1,  2, 
    8, 63, 1, 77, 2, 79, 6, 94, 3, 18, 0, 96, 4, 37, 5, 20, 7, 14, 
    7, 43, 1, 65, 6, 19, 2, 72, 8, 22, 0, 48, 5, 58, 3, 52, 4, 89, 
    6, 16, 0,  3, 7, 50, 8, 23, 1, 48, 5, 62, 3, 54, 4, 20, 2,  7, 
    3, 65, 4, 88, 0,  7, 2, 54, 7, 38, 1, 33, 5, 14, 6, 70, 8, 54
  };
  const int q5059[] = {
    9, 9, // Number of jobs and machines
    8, 45, 4, 51, 5, 82, 2, 88, 7,  8, 1, 12, 3, 37, 6, 88, 0, 19, 
    2, 35, 4,  9, 6, 34, 3, 35, 7, 22, 0, 16, 5,  8, 8, 79, 1, 38, 
    2,  5, 7, 73, 5, 26, 4, 16, 6, 99, 8, 76, 1, 27, 0, 81, 3, 61, 
    2, 22, 7, 71, 8, 66, 4, 90, 0, 64, 6, 45, 1, 42, 3, 82, 5, 88, 
    1, 94, 0, 24, 4, 79, 6, 65, 8, 16, 3, 72, 2, 36, 7, 44, 5, 73, 
    4, 51, 1, 96, 3, 96, 8, 51, 7, 67, 5, 13, 2, 64, 6, 82, 0,  4, 
    0, 41, 4, 39, 7, 78, 3, 16, 1, 70, 6, 12, 5, 10, 8, 77, 2, 22, 
    0, 33, 5, 27, 7, 80, 4,  6, 2, 44, 8, 76, 1, 90, 6, 27, 3, 49, 
    5, 16, 3, 30, 8, 39, 1, 87, 0,  7, 7, 64, 4, 54, 2, 89, 6, 90
  };
  const int q5060[] = {
    9, 9, // Number of jobs and machines
    4, 46, 5, 59, 8, 60, 6, 19, 0,  4, 2, 81, 1, 82, 3, 40, 7, 34, 
    1, 80, 5, 35, 8, 50, 0, 40, 3, 95, 6, 74, 2, 63, 4, 88, 7, 41, 
    4, 34, 7, 75, 1, 86, 8, 69, 3, 27, 2, 10, 5, 37, 6, 63, 0, 65, 
    1, 94, 8, 93, 2, 13, 5, 26, 7, 16, 3, 79, 4, 19, 0, 68, 6, 98, 
    6, 43, 3, 43, 8, 14, 5, 67, 0, 83, 1, 64, 2,  9, 4, 61, 7, 33, 
    1, 36, 4, 31, 7, 67, 2, 55, 6, 10, 5, 21, 8, 34, 0, 17, 3, 67, 
    3, 15, 8, 84, 2, 86, 1, 74, 0, 10, 4, 19, 6,  3, 5, 79, 7, 69, 
    6, 61, 0, 24, 1, 73, 7, 40, 2,  8, 8, 20, 3, 81, 4, 46, 5, 27, 
    4, 41, 7, 61, 5,  5, 3, 47, 0, 48, 6, 70, 8, 62, 1, 96, 2, 75
  };
  const int q5061[] = {
    9, 9, // Number of jobs and machines
    8, 98, 7, 29, 4, 95, 2, 58, 5, 94, 6, 47, 0, 50, 1, 63, 3, 47, 
    5,  3, 7, 53, 8, 79, 1, 62, 2, 48, 0, 79, 3, 36, 4, 97, 6, 21, 
    1, 33, 7, 81, 0, 41, 5, 62, 8, 83, 4, 91, 2, 38, 6, 50, 3, 72, 
    8, 68, 2, 77, 0, 47, 4, 65, 1,  7, 5, 20, 3, 57, 7, 22, 6,  4, 
    8, 13, 0, 76, 6,  5, 1,  3, 7, 24, 5, 37, 4, 90, 2, 81, 3, 78, 
    8, 93, 6, 93, 4, 25, 5, 20, 1, 91, 3, 37, 7, 38, 0, 86, 2, 49, 
    4, 99, 7, 21, 2, 98, 3,  6, 5, 13, 1, 84, 6, 71, 0, 44, 8, 86, 
    4, 20, 5, 49, 3, 48, 6, 15, 7, 58, 0, 56, 1, 97, 8, 87, 2, 40, 
    4, 95, 7, 99, 3, 12, 5, 42, 6, 62, 2,  1, 1, 94, 8, 12, 0, 45
  };
  const int q5062[] = {
    9, 9, // Number of jobs and machines
    8, 98, 2, 71, 1, 45, 5, 26, 3, 35, 0, 83, 4, 85, 7, 88, 6,  6, 
    4, 27, 6, 33, 8, 66, 5, 50, 2, 83, 0, 82, 3, 63, 1,  4, 7, 58, 
    0, 21, 6, 37, 1, 20, 5, 50, 4, 58, 8, 61, 7, 61, 3, 71, 2, 61, 
    5, 31, 0, 72, 3, 92, 7, 20, 4, 41, 1, 82, 2,  6, 8, 53, 6, 12, 
    1, 58, 2,  8, 6, 47, 5, 61, 8, 59, 7, 51, 3, 90, 0, 91, 4,  4, 
    2, 91, 8,  8, 1, 16, 4, 23, 0,  1, 6, 19, 5, 38, 3, 79, 7, 47, 
    8,  6, 4, 16, 5, 79, 6, 79, 7, 34, 1, 98, 3, 34, 2, 39, 0, 55, 
    7, 66, 3, 58, 0, 84, 1, 79, 6, 31, 8, 95, 4, 46, 2, 95, 5, 44, 
    7, 63, 2, 58, 1, 66, 3, 95, 0, 29, 6,  1, 8, 19, 4, 24, 5, 69
  };
  const int q5063[] = {
    9, 9, // Number of jobs and machines
    6, 58, 4, 74, 1, 65, 0, 80, 7, 54, 5, 45, 8, 97, 3, 92, 2, 38, 
    3, 19, 8, 92, 5, 16, 0, 34, 2, 26, 6, 71, 1, 20, 7, 56, 4,  9, 
    0,  3, 4, 37, 6, 10, 8, 89, 1, 87, 7, 16, 5, 52, 2, 28, 3, 10, 
    7, 69, 0, 39, 2, 66, 6, 56, 4, 17, 5,  8, 3, 32, 1, 71, 8, 20, 
    0, 72, 4, 46, 1, 72, 5,  5, 8, 95, 6, 37, 2, 86, 3, 60, 7, 86, 
    1, 75, 2, 48, 6, 93, 3, 79, 5, 10, 0, 89, 7, 31, 4, 62, 8, 31, 
    0,  6, 7, 36, 5, 38, 2, 48, 6, 41, 1, 94, 8, 34, 4, 82, 3, 25, 
    6, 16, 0, 78, 1,  5, 5, 65, 2, 69, 8, 59, 4, 88, 7, 51, 3, 59, 
    3, 38, 7, 85, 8,  5, 6, 48, 0, 96, 1, 16, 2, 19, 5, 98, 4, 55
  };
  const int q5064[] = {
    9, 9, // Number of jobs and machines
    0, 85, 8,  9, 7, 74, 3, 47, 4, 80, 2, 89, 5, 57, 1,  2, 6, 55, 
    1, 77, 8, 96, 7, 40, 6,  2, 5, 68, 2, 65, 4, 26, 3, 50, 0, 71, 
    7, 44, 4, 65, 8, 46, 3, 48, 5, 28, 1, 97, 2, 53, 0, 70, 6, 77, 
    0, 38, 1, 46, 5, 18, 3, 99, 8, 69, 4, 14, 7, 24, 2,  1, 6, 50, 
    4, 57, 3, 66, 1, 47, 5, 78, 0, 25, 7, 90, 6, 71, 2, 30, 8, 77, 
    8, 40, 2,  8, 0, 75, 5, 31, 4, 11, 3, 51, 1, 36, 6, 78, 7, 93, 
    0, 50, 8, 49, 5,  2, 4, 60, 3, 70, 6,  3, 7, 58, 2, 84, 1, 22, 
    4, 33, 7, 56, 3, 37, 8, 38, 1, 56, 0, 15, 6, 47, 5, 57, 2, 40, 
    7, 42, 1, 97, 2, 74, 6, 42, 0, 91, 3, 50, 5, 65, 8, 98, 4, 88
  };
  const int q5065[] = {
    9, 9, // Number of jobs and machines
    6, 10, 0, 78, 4, 23, 3, 77, 7, 47, 5, 88, 8, 27, 2,  2, 1,  1, 
    3, 52, 8, 20, 4, 36, 1, 45, 2, 59, 0, 57, 7, 26, 6, 21, 5, 27, 
    3, 33, 6,  1, 1, 34, 5, 85, 2, 18, 0, 44, 4, 11, 7, 33, 8,  3, 
    6, 87, 7, 17, 8, 49, 1, 81, 0, 84, 5, 79, 3, 51, 2, 89, 4, 37, 
    3, 98, 5, 88, 0, 28, 2, 16, 7, 95, 6, 54, 1, 16, 4, 39, 8, 66, 
    1, 37, 5, 85, 8, 35, 2, 64, 7, 12, 0,  4, 6, 61, 4, 42, 3, 21, 
    7, 50, 8, 28, 0, 81, 1, 20, 4, 55, 6, 34, 5, 57, 3, 20, 2, 86, 
    6,  8, 4, 65, 8,  8, 5, 88, 2, 14, 1, 95, 0, 22, 3, 17, 7, 21, 
    6, 83, 1, 38, 7, 94, 0, 53, 8, 99, 5, 78, 4, 33, 2, 30, 3, 82
  };
  const int q5066[] = {
    9, 9, // Number of jobs and machines
    5, 40, 0, 75, 7,  8, 8, 40, 4, 32, 3, 54, 6, 58, 2, 34, 1, 90, 
    5, 46, 1, 91, 0, 88, 6, 30, 2, 98, 3, 35, 8, 23, 7, 12, 4, 71, 
    0, 62, 7, 25, 6, 13, 1, 98, 4,  2, 3, 31, 2, 76, 8, 82, 5, 64, 
    1, 28, 2, 10, 7, 39, 6, 37, 8, 55, 3, 53, 0, 43, 4, 97, 5, 70, 
    2, 53, 8,  1, 5, 88, 0, 27, 6, 39, 7, 50, 3, 37, 1, 54, 4, 73, 
    6, 65, 2, 83, 0, 34, 5, 42, 7, 54, 3, 67, 4,  9, 8, 33, 1, 54, 
    7, 89, 6, 35, 3, 83, 4, 86, 0, 72, 1, 13, 5, 13, 2, 28, 8,  8, 
    1, 10, 5, 73, 4, 27, 8, 66, 3, 29, 0, 14, 6, 25, 2, 93, 7, 88, 
    1, 75, 6, 44, 7, 56, 3, 10, 5, 16, 8, 90, 0, 76, 2, 52, 4, 13
  };
  const int q5067[] = {
    9, 9, // Number of jobs and machines
    5, 56, 7, 66, 2, 11, 0, 74, 4, 76, 8, 75, 6, 49, 1, 72, 3,  4, 
    2, 95, 0, 63, 3, 91, 1, 98, 8, 56, 6, 93, 4, 10, 5, 52, 7,  8, 
    6, 16, 3, 62, 8, 83, 0, 70, 4, 49, 2,  8, 1,  6, 5, 58, 7, 78, 
    4, 12, 1, 90, 0, 41, 8, 61, 2, 81, 7, 69, 3, 44, 5, 67, 6, 65, 
    4, 13, 0,  1, 1,  9, 5, 78, 6, 38, 3, 78, 2, 35, 8,  3, 7, 47, 
    0, 44, 6, 73, 3, 85, 4, 27, 2, 67, 8, 96, 5, 83, 7, 52, 1, 63, 
    2,  4, 5, 39, 8, 65, 4, 15, 7, 84, 0, 24, 1, 93, 6, 68, 3, 25, 
    5, 61, 1, 73, 2, 22, 0, 48, 3,  9, 4, 10, 8, 81, 7, 92, 6, 27, 
    6, 45, 1, 50, 2, 55, 3, 95, 7, 39, 5, 15, 0, 52, 8, 29, 4, 37
  };
  const int q5068[] = {
    9, 9, // Number of jobs and machines
    5, 39, 7, 44, 0, 56, 2, 24, 8, 60, 1, 89, 3, 64, 4, 53, 6, 87, 
    8, 13, 3, 67, 0, 31, 4, 44, 1, 82, 5, 77, 6, 90, 2, 21, 7, 59, 
    0, 67, 5, 51, 7, 59, 2, 74, 1, 33, 4, 33, 3, 42, 6, 35, 8,  3, 
    1, 86, 2, 69, 0, 98, 8, 39, 7, 45, 5, 16, 3, 98, 6, 42, 4, 67, 
    8, 47, 3, 78, 7, 38, 1, 97, 0, 72, 2, 56, 4, 56, 5, 77, 6, 28, 
    3, 37, 0, 87, 2, 76, 7, 15, 8, 16, 6, 95, 1, 81, 5, 89, 4,  1, 
    5, 15, 4, 70, 6, 38, 7, 18, 8, 98, 0, 95, 3, 75, 2,  9, 1, 24, 
    6, 43, 4, 70, 0, 17, 3, 30, 2, 50, 8, 82, 5, 96, 1, 49, 7, 39, 
    7, 95, 1, 39, 4, 57, 6, 42, 5, 82, 8, 14, 2, 46, 0, 26, 3, 38
  };
  const int q5069[] = {
    9, 9, // Number of jobs and machines
    1, 12, 3, 30, 5, 70, 4, 20, 6, 15, 2, 89, 0, 38, 7, 28, 8,  4, 
    7, 27, 1, 62, 2, 25, 3, 38, 0, 53, 4, 10, 8, 40, 6, 10, 5, 17, 
    2, 35, 8, 77, 5, 22, 0, 43, 6, 27, 3, 39, 4, 91, 7, 48, 1, 84, 
    3, 83, 4, 28, 2, 65, 8, 43, 6, 79, 7,  4, 5, 98, 0, 94, 1, 41, 
    1,  4, 3, 35, 0,  3, 5,  7, 7, 39, 8, 30, 4, 58, 6, 25, 2, 58, 
    7, 99, 8, 60, 5, 63, 6, 44, 4, 78, 2, 25, 0, 63, 3, 21, 1,  8, 
    2, 68, 3, 20, 5, 42, 8, 93, 0, 82, 6, 45, 7, 63, 1, 79, 4, 75, 
    3, 19, 1, 23, 2, 97, 6, 81, 8,  3, 7, 69, 4, 50, 0, 27, 5, 72, 
    0, 61, 1, 25, 5, 59, 3, 21, 7,  9, 8, 93, 2, 87, 6,  3, 4, 16
  };
  const int q5070[] = {
    9, 9, // Number of jobs and machines
    8,  2, 6, 60, 1, 98, 5, 97, 3, 21, 0, 72, 2, 13, 4, 56, 7, 93, 
    5, 68, 3, 87, 2,  5, 8, 62, 6, 99, 1,  7, 4, 31, 7, 55, 0, 73, 
    3, 32, 7, 35, 6, 67, 1, 85, 5, 58, 8, 67, 4, 55, 2, 87, 0, 13, 
    4, 61, 0, 62, 6, 92, 7, 13, 5, 86, 2, 19, 8, 84, 3, 91, 1, 11, 
    7, 94, 0, 89, 6, 23, 8,  4, 3, 23, 2, 65, 4, 41, 5, 36, 1, 42, 
    5, 64, 7, 78, 1, 32, 4, 16, 3, 27, 6,  3, 2, 87, 0, 38, 8, 20, 
    7, 28, 4, 78, 6, 13, 1, 86, 0, 42, 5, 83, 8, 25, 2, 45, 3, 95, 
    8,  7, 6, 28, 7, 20, 1, 59, 4, 32, 2, 20, 0, 29, 5, 89, 3, 94, 
    3, 55, 6, 68, 1, 87, 5, 18, 8, 14, 4, 60, 2, 47, 7, 80, 0, 20
  };
  const int q5071[] = {
    9, 9, // Number of jobs and machines
    6, 21, 2, 24, 1, 68, 0, 83, 8, 99, 7, 95, 3, 84, 5, 68, 4,  6, 
    4, 94, 8, 21, 1, 38, 7, 12, 6, 35, 5, 86, 0,  7, 2, 55, 3, 24, 
    4, 95, 7, 45, 5, 43, 2, 98, 0, 80, 1, 80, 8, 24, 3, 64, 6, 12, 
    1, 87, 5,  4, 7,  3, 4, 86, 6, 69, 3, 22, 2, 62, 8, 49, 0,  9, 
    4, 79, 8, 77, 0, 19, 7, 25, 1,  5, 5,  4, 6, 31, 2,  6, 3, 82, 
    1,  4, 3,  4, 4, 84, 5, 96, 8, 27, 6,  4, 2, 73, 7, 44, 0, 15, 
    6, 49, 8, 96, 5, 30, 2,  3, 7, 19, 3, 62, 0, 70, 1, 67, 4, 16, 
    5, 30, 2, 52, 3, 48, 8, 26, 1, 95, 6, 90, 7, 45, 0, 81, 4, 34, 
    7, 32, 1, 22, 0, 77, 6, 96, 8, 21, 5, 76, 3, 16, 4, 98, 2, 90
  };
  const int q5072[] = {
    9, 9, // Number of jobs and machines
    5, 45, 8, 58, 7, 65, 4, 22, 6,  1, 3, 52, 1, 14, 0, 11, 2, 78, 
    1, 93, 7, 44, 4, 46, 5,  2, 6,  8, 3, 59, 8, 67, 0, 16, 2,  8, 
    1, 68, 4,  9, 6, 80, 7, 41, 5,  7, 3,  4, 8, 13, 0, 54, 2, 33, 
    7, 30, 6, 39, 3, 17, 1, 97, 8, 12, 4, 20, 2, 21, 5, 13, 0, 44, 
    5, 32, 8, 27, 1, 42, 6, 52, 3, 55, 4,  6, 0, 12, 7, 41, 2, 36, 
    8, 43, 7,  7, 2, 36, 6, 41, 5, 43, 3, 17, 1, 47, 4, 77, 0, 75, 
    8,  8, 0, 35, 6, 67, 5, 55, 7, 81, 1, 70, 2, 17, 4, 20, 3, 45, 
    6, 63, 8,  1, 7, 95, 0, 41, 1, 49, 3, 62, 4, 92, 2, 54, 5, 43, 
    6, 17, 2, 16, 1, 61, 3, 22, 5, 61, 4, 51, 7, 17, 8, 74, 0, 35
  };
  const int q5073[] = {
    9, 9, // Number of jobs and machines
    8, 61, 1, 16, 7, 34, 2, 15, 3, 26, 0, 17, 6, 21, 4, 46, 5,  9, 
    5, 38, 2, 17, 3, 82, 8, 66, 0, 34, 7,  3, 6, 95, 4, 76, 1, 66, 
    6, 88, 8, 98, 7, 35, 1, 76, 5, 92, 4, 62, 0, 28, 3, 87, 2, 97, 
    2, 60, 1, 72, 5, 23, 8, 31, 4, 63, 0, 94, 7, 59, 3, 40, 6, 95, 
    0, 87, 6, 27, 7,  2, 3, 13, 4, 99, 8, 70, 1, 81, 5, 89, 2, 17, 
    0, 44, 8, 89, 3, 42, 7, 20, 6, 32, 2, 49, 4, 20, 5, 56, 1, 81, 
    5, 82, 6, 54, 7, 72, 0,  3, 4, 96, 2, 46, 3, 23, 1,  5, 8,  9, 
    7, 73, 4, 95, 0, 37, 2, 17, 3, 88, 5, 52, 6,  8, 1, 38, 8, 90, 
    8, 67, 0, 15, 1, 27, 2, 65, 4, 55, 3, 23, 7, 78, 6, 19, 5, 15
  };
  const int q5074[] = {
    9, 9, // Number of jobs and machines
    6, 57, 0, 49, 3, 97, 1, 10, 5, 46, 8, 26, 7, 82, 2, 30, 4, 65, 
    2, 45, 5, 46, 6, 93, 4, 54, 0, 21, 8, 80, 3, 77, 1,  9, 7, 81, 
    1, 11, 7, 19, 3, 12, 4, 33, 0, 11, 2, 12, 6, 65, 8, 79, 5, 30, 
    3,  7, 4, 66, 6, 98, 5, 34, 8, 92, 1, 24, 2, 60, 7, 63, 0, 19, 
    4, 90, 6, 34, 7,  5, 3, 22, 5, 46, 0, 87, 2, 70, 1, 25, 8, 72, 
    4, 30, 8, 20, 7, 68, 6, 41, 5, 77, 2, 87, 1, 13, 0, 43, 3, 94, 
    7, 90, 1, 82, 3, 44, 8, 62, 5, 95, 0, 75, 4, 35, 6, 85, 2, 75, 
    3, 58, 7, 23, 2, 49, 6, 16, 1, 85, 4, 93, 5, 42, 0, 93, 8, 33, 
    6,  2, 4, 72, 3, 64, 8, 33, 1, 88, 7, 28, 2, 16, 5, 21, 0, 39
  };
  const int q5075[] = {
    9, 9, // Number of jobs and machines
    5, 19, 6, 82, 3, 13, 7, 45, 1, 62, 4, 90, 0, 79, 8, 64, 2, 16, 
    2, 51, 1, 88, 8, 28, 3, 34, 5, 14, 7, 41, 0, 26, 6, 44, 4,  5, 
    0, 59, 1, 82, 7, 32, 5, 52, 6, 49, 3, 10, 4, 78, 2, 61, 8, 47, 
    6, 48, 2,  2, 1, 61, 8, 74, 3, 17, 7, 63, 0, 54, 5, 71, 4, 76, 
    1, 54, 6, 19, 5,  5, 8, 44, 0, 92, 7, 33, 2, 56, 3, 29, 4, 88, 
    4,  8, 2, 80, 3, 37, 6, 40, 0,  5, 7, 15, 1, 52, 8, 31, 5, 71, 
    2, 31, 8, 84, 3, 36, 5, 56, 1, 21, 7, 82, 0, 84, 6, 23, 4, 73, 
    4, 32, 7, 73, 2, 91, 5, 46, 1, 92, 6, 21, 3, 92, 8, 36, 0, 61, 
    5, 17, 6, 73, 2, 85, 0, 57, 1, 75, 4, 74, 8, 10, 7, 45, 3, 73
  };
  const int q5076[] = {
    9, 9, // Number of jobs and machines
    6,  4, 5, 49, 8, 10, 7, 72, 2, 14, 4, 59, 0,  1, 3, 37, 1, 39, 
    3, 60, 8, 74, 4,  9, 5,  8, 0, 12, 2, 99, 1, 30, 7, 58, 6, 79, 
    3, 14, 6, 55, 5, 13, 1,  8, 4, 93, 7, 15, 8, 24, 2, 79, 0, 24, 
    8, 57, 2,  2, 4, 30, 5, 49, 0, 72, 7, 64, 1, 21, 6, 49, 3, 62, 
    4, 68, 7, 92, 6, 86, 1, 90, 5, 87, 2, 51, 0, 71, 3, 30, 8, 69, 
    4, 31, 3,  1, 0, 35, 8, 19, 2, 40, 5, 48, 7, 27, 6, 98, 1, 73, 
    3, 39, 1, 80, 6, 69, 4, 12, 2, 88, 8, 68, 0, 90, 7, 10, 5, 84, 
    2, 41, 6, 53, 0, 89, 7,  2, 8,  4, 5, 89, 3, 75, 4, 13, 1, 88, 
    5, 68, 0,  7, 6, 73, 8, 88, 7, 14, 1, 13, 2, 47, 3, 56, 4, 78
  };
  const int q5077[] = {
    9, 9, // Number of jobs and machines
    5, 90, 0, 93, 7, 58, 8, 57, 4, 30, 6, 70, 2, 20, 3, 10, 1, 96, 
    4, 62, 8, 67, 0, 30, 7, 70, 5, 72, 1, 20, 6, 45, 2, 41, 3, 41, 
    4, 34, 1,  5, 0,  4, 2, 24, 8, 91, 3,  6, 7, 83, 6, 61, 5, 41, 
    2, 14, 0, 53, 3, 66, 7, 87, 1, 49, 5, 36, 8, 12, 6, 33, 4, 26, 
    2, 63, 8, 68, 5,  9, 0, 97, 3, 15, 7,  2, 6,  5, 1, 41, 4, 26, 
    2, 32, 8, 10, 4, 68, 1, 34, 7, 33, 3, 98, 6, 67, 5, 56, 0,  7, 
    7, 87, 6, 11, 3, 14, 5, 28, 2, 38, 0, 25, 1,  7, 8, 97, 4, 70, 
    0, 87, 8, 13, 7, 90, 5, 17, 6, 60, 1, 10, 4, 27, 2, 92, 3, 67, 
    8, 45, 5, 30, 1, 13, 4, 94, 7, 34, 2, 20, 6,  3, 0, 47, 3, 28
  };
  const int q5078[] = {
    9, 9, // Number of jobs and machines
    8,  2, 7, 39, 3, 58, 4, 30, 2, 36, 5, 71, 1, 42, 6, 18, 0, 64, 
    4, 14, 0, 19, 1, 66, 8, 81, 5, 68, 2, 40, 7, 36, 6, 95, 3, 58, 
    5, 85, 6, 23, 4, 61, 7, 11, 2, 67, 8, 98, 1, 42, 3, 11, 0, 97, 
    0, 90, 1, 80, 8, 22, 3, 52, 6, 70, 7, 93, 4, 86, 5, 13, 2, 11, 
    2, 61, 8, 75, 7, 27, 3, 48, 4, 30, 1, 91, 6, 71, 5, 33, 0, 79, 
    8,  6, 1, 26, 3, 47, 2, 32, 7, 65, 5, 82, 6, 17, 0,  4, 4, 46, 
    6, 25, 0, 34, 5, 83, 2,  5, 3,  8, 1, 17, 8, 18, 4, 91, 7, 30, 
    4, 51, 3, 58, 7, 90, 6, 55, 5, 91, 8, 36, 0, 80, 1, 43, 2, 58, 
    0,  6, 1, 71, 4, 78, 3, 66, 8, 25, 5, 12, 6, 17, 7, 36, 2, 27
  };
  const int q5079[] = {
    9, 9, // Number of jobs and machines
    7, 68, 8, 74, 6,  8, 1,  9, 5, 50, 3, 42, 2, 59, 4, 91, 0,  2, 
    2, 60, 7, 71, 8, 40, 5, 68, 0, 55, 4, 43, 3, 87, 1, 51, 6, 97, 
    3, 40, 7, 59, 6, 83, 4, 47, 2, 56, 8, 33, 5, 21, 1, 40, 0, 72, 
    3,  1, 7, 74, 6, 25, 4, 94, 0, 97, 2, 82, 8, 79, 5, 43, 1,  8, 
    5, 54, 7,  7, 3, 99, 8, 12, 4, 65, 6, 23, 2, 50, 0, 94, 1, 30, 
    8, 32, 3, 69, 2,  8, 5, 53, 0, 88, 1, 16, 6, 15, 4, 49, 7, 26, 
    3, 26, 8, 87, 0, 99, 7, 50, 2, 95, 4, 84, 1, 55, 5, 41, 6,  3, 
    4, 78, 2, 58, 0, 21, 7, 44, 3, 27, 8, 77, 6, 44, 1, 63, 5, 56, 
    3, 31, 1, 29, 8,  4, 2, 80, 5, 99, 0, 92, 7, 91, 4, 39, 6, 91
  };
  const int q5080[] = {
    9, 9, // Number of jobs and machines
    2, 17, 6,  6, 4, 14, 7, 95, 1, 61, 8, 90, 0, 11, 5, 30, 3, 40, 
    6, 26, 8, 18, 1, 70, 5, 23, 7, 55, 2, 67, 3, 73, 4, 54, 0, 10, 
    6, 80, 1,  6, 8, 96, 4, 23, 2, 70, 5, 12, 0, 69, 3, 14, 7, 44, 
    1,  5, 3, 22, 7, 33, 0, 35, 8, 26, 4, 61, 6,  6, 2, 12, 5, 63, 
    3, 96, 5, 95, 6, 63, 8, 50, 0, 16, 4,  9, 1, 46, 2, 59, 7, 89, 
    1, 25, 3, 35, 4, 26, 6, 65, 8, 94, 5, 71, 2, 99, 0, 87, 7, 95, 
    4, 88, 1,  4, 3,  3, 0, 77, 2, 42, 8, 98, 6, 89, 5, 11, 7, 15, 
    4, 33, 2, 61, 3, 27, 7, 46, 8, 98, 6, 16, 0, 83, 5,  6, 1, 64, 
    6, 95, 7, 70, 3, 26, 1, 81, 0, 65, 8, 37, 2, 85, 4, 13, 5, 32
  };
  const int q5081[] = {
    9, 9, // Number of jobs and machines
    2, 92, 8, 49, 6, 68, 4, 77, 5, 25, 7, 79, 1, 55, 0, 62, 3, 53, 
    2, 37, 3, 72, 5, 41, 1, 41, 6, 18, 7,  9, 4, 42, 0, 37, 8,  2, 
    2, 22, 7, 15, 3, 47, 6, 40, 4, 19, 0, 60, 8, 93, 1, 79, 5,  7, 
    1, 94, 6, 71, 7, 97, 4, 76, 5, 53, 2, 16, 3, 81, 8, 96, 0, 40, 
    8, 26, 7, 26, 5, 35, 3, 23, 6, 51, 2, 67, 4, 43, 0, 13, 1, 92, 
    1,  1, 8, 89, 4, 58, 2, 15, 6, 64, 7, 54, 3, 86, 5, 22, 0, 45, 
    7, 10, 5, 86, 6, 88, 3, 50, 2, 87, 1, 89, 4, 29, 8, 89, 0, 36, 
    8, 23, 4, 24, 1, 28, 0,  5, 2, 21, 7, 67, 3,  9, 6, 52, 5, 48, 
    1, 86, 0, 75, 2, 58, 3, 32, 8, 99, 5, 36, 7, 42, 4, 97, 6, 94
  };
  const int q5082[] = {
    9, 9, // Number of jobs and machines
    4,  8, 8, 78, 3, 27, 5, 62, 0, 38, 2,  8, 6, 61, 1, 12, 7, 67, 
    7, 53, 4,  5, 8, 69, 0, 29, 1, 74, 6, 33, 5, 62, 2, 39, 3, 52, 
    4, 58, 3, 47, 1, 56, 0, 23, 5, 54, 8, 66, 2, 93, 6, 72, 7, 42, 
    3, 13, 6,  3, 2, 92, 1,  7, 8, 50, 5, 15, 7, 57, 0, 15, 4, 95, 
    0, 30, 2,  6, 3, 51, 8, 21, 6,  6, 4, 89, 1, 49, 7, 99, 5, 81, 
    0, 95, 8,  1, 1, 50, 3, 50, 6, 13, 2, 49, 4, 37, 7, 43, 5, 40, 
    6, 41, 0, 90, 2, 79, 1, 43, 3, 74, 4, 43, 5, 20, 7, 65, 8, 87, 
    3,  9, 8, 33, 7, 54, 2, 49, 0, 29, 4, 17, 1,  9, 5, 92, 6, 84, 
    7, 59, 4, 92, 8, 88, 3, 96, 1,  9, 6, 75, 0, 21, 5, 21, 2, 99
  };
  const int q5083[] = {
    9, 9, // Number of jobs and machines
    0, 70, 5, 41, 2, 59, 7, 71, 1, 35, 6, 82, 3, 58, 4, 51, 8, 42, 
    3, 84, 5, 31, 4, 27, 6,  2, 2, 76, 0, 56, 8, 26, 1, 45, 7, 94, 
    4, 51, 5, 36, 3, 31, 2, 81, 6, 48, 8, 40, 1, 32, 0, 48, 7, 10, 
    3, 50, 7,  9, 2, 81, 6, 84, 8,  3, 4, 15, 1,  1, 0, 69, 5,  9, 
    0, 44, 4,  7, 1, 58, 8, 48, 5, 42, 7, 42, 2, 39, 3, 67, 6, 13, 
    6, 78, 3, 76, 1, 41, 0, 34, 8, 82, 5, 93, 4, 45, 2, 60, 7, 82, 
    1, 82, 8,  1, 7, 75, 6, 20, 0, 85, 3, 55, 4, 71, 2, 77, 5, 57, 
    3,  9, 6, 94, 5, 61, 2,  8, 8, 51, 4, 25, 1, 21, 7, 98, 0, 60, 
    1, 35, 2,  3, 3, 55, 5,  5, 4, 44, 8, 70, 0, 45, 7, 61, 6, 77
  };
  const int q5084[] = {
    9, 9, // Number of jobs and machines
    4,  8, 6, 53, 0, 32, 1, 11, 8, 20, 2, 23, 7, 54, 3, 56, 5, 71, 
    6, 35, 0, 21, 2, 28, 4, 42, 3, 66, 7, 25, 1, 77, 8, 25, 5, 66, 
    4, 67, 6, 61, 8, 82, 5, 91, 0, 73, 3, 99, 1, 28, 2,  7, 7,  5, 
    2, 25, 8, 22, 5, 52, 3, 82, 1, 25, 6, 24, 0, 10, 4, 41, 7, 63, 
    2, 33, 4, 77, 0, 69, 1, 89, 3, 42, 8, 71, 6, 86, 7, 90, 5, 86, 
    5, 49, 4, 68, 1, 93, 0, 60, 8, 75, 7, 66, 3, 84, 6, 33, 2, 95, 
    0, 19, 6,  6, 3, 76, 8,  8, 5,  8, 1, 45, 7, 13, 4, 41, 2, 83, 
    0, 13, 7,  7, 3,  7, 5, 20, 8, 37, 4, 64, 2, 40, 6, 14, 1, 30, 
    5, 21, 0, 77, 3, 31, 6, 85, 2,  5, 7, 85, 8, 40, 4, 59, 1, 68
  };
  const int q5085[] = {
    9, 9, // Number of jobs and machines
    7, 86, 4, 31, 3, 17, 5, 49, 8, 84, 2, 99, 6, 16, 1, 43, 0, 61, 
    8, 72, 7,  3, 1, 27, 0, 90, 2, 30, 3, 55, 4, 16, 5, 37, 6, 21, 
    2, 61, 7, 68, 3, 98, 1, 39, 5, 26, 8, 45, 6, 76, 4, 59, 0, 19, 
    2, 20, 3, 40, 6, 43, 1, 12, 0, 79, 8,  6, 5, 91, 4, 13, 7, 20, 
    1, 87, 4, 67, 7, 44, 5, 28, 6, 79, 0, 93, 8, 54, 3, 71, 2, 80, 
    7,  6, 2, 53, 1, 64, 0, 66, 6, 57, 4, 32, 5,  2, 3, 73, 8, 84, 
    0,  8, 4, 57, 1, 67, 6, 39, 2, 83, 5,  9, 8, 61, 7, 33, 3, 65, 
    8, 42, 3, 26, 5, 24, 7, 96, 1, 70, 4,  6, 6,  8, 2, 65, 0, 13, 
    8, 52, 6, 28, 7, 50, 3, 93, 0,  2, 4, 79, 5, 55, 2, 14, 1, 33
  };
  const int q5086[] = {
    9, 9, // Number of jobs and machines
    8, 72, 5,  3, 6, 50, 0, 10, 1, 39, 3, 81, 2, 86, 7, 71, 4, 84, 
    2, 77, 1, 15, 8, 75, 5, 85, 4,  9, 6, 44, 0, 91, 7, 65, 3,  4, 
    3, 48, 5, 43, 0, 27, 4, 47, 8, 15, 7, 51, 1, 91, 2, 73, 6, 23, 
    8, 51, 1, 54, 2, 65, 4, 72, 5, 14, 3, 62, 7, 71, 0, 34, 6, 66, 
    2,  1, 6, 66, 3, 43, 4,  6, 7, 49, 1, 54, 0,  5, 5, 45, 8, 29, 
    7, 34, 5, 88, 4, 99, 6, 24, 0, 82, 8, 59, 2,  2, 1, 84, 3, 23, 
    7,  4, 6, 97, 3, 48, 2, 41, 1, 30, 0, 65, 8, 13, 4, 24, 5, 47, 
    3, 29, 0,  2, 2, 95, 4, 90, 7, 16, 8, 51, 1, 90, 5, 31, 6, 79, 
    1, 63, 2, 91, 7, 11, 8, 25, 0, 19, 3, 28, 6, 95, 5,  1, 4, 65
  };
  const int q5087[] = {
    9, 9, // Number of jobs and machines
    2, 97, 0, 66, 7,  3, 5,  9, 4,  1, 6, 85, 3, 67, 8, 16, 1,  9, 
    2, 36, 1,  2, 7, 37, 5, 44, 6, 95, 8, 42, 0, 55, 4, 33, 3, 41, 
    4, 57, 0, 97, 7, 95, 8, 86, 3,  4, 2, 26, 6, 68, 1, 10, 5,  3, 
    4, 67, 8,  3, 6, 93, 2, 65, 3, 41, 0, 83, 7, 26, 1, 58, 5, 10, 
    5,  6, 6, 67, 0, 93, 1, 58, 8, 38, 3, 38, 4, 14, 2, 32, 7, 20, 
    5, 23, 4, 42, 6, 64, 7, 47, 0, 83, 3, 46, 1, 51, 8, 82, 2, 29, 
    7, 17, 6, 98, 1, 66, 5, 19, 8, 14, 3, 29, 2, 90, 4, 20, 0, 38, 
    2, 40, 3, 83, 4, 97, 1, 15, 5,  5, 6,  2, 0, 49, 8, 97, 7, 16, 
    1, 54, 7, 26, 8, 21, 6, 16, 0, 87, 4, 70, 2, 34, 3, 48, 5, 52
  };
  const int q5088[] = {
    9, 9, // Number of jobs and machines
    5, 90, 0, 65, 4,  1, 7, 93, 8, 52, 6, 77, 2, 92, 1, 89, 3, 62, 
    8, 62, 2, 43, 5, 23, 3, 80, 1, 50, 4, 47, 6, 65, 0, 37, 7, 25, 
    6, 39, 3,  7, 0, 94, 4, 38, 5, 95, 8, 47, 1, 16, 7, 16, 2, 16, 
    2, 21, 1, 46, 4, 35, 8, 95, 0, 35, 6, 74, 7, 35, 3, 36, 5,  6, 
    4, 25, 2, 41, 3, 83, 1, 91, 0, 41, 5, 80, 6, 33, 8, 29, 7, 68, 
    3, 75, 6, 79, 1, 11, 7, 72, 0, 49, 2, 19, 5, 10, 4, 77, 8, 42, 
    7, 54, 5, 77, 2, 52, 1, 55, 3, 92, 0, 27, 6, 43, 8,  1, 4, 52, 
    5, 34, 1, 26, 4, 91, 8, 53, 0, 82, 7, 14, 3, 17, 6, 99, 2, 66, 
    4, 73, 6, 11, 2, 62, 1, 37, 5, 15, 0, 48, 3, 59, 8, 77, 7, 78
  };
  const int q5089[] = {
    9, 9, // Number of jobs and machines
    2, 13, 3, 48, 4, 97, 6, 83, 0, 41, 7, 62, 5, 60, 8, 13, 1, 24, 
    2,  1, 1, 70, 7, 19, 0, 25, 8, 94, 6, 63, 5, 17, 3, 88, 4, 22, 
    1, 80, 5, 55, 6, 67, 0, 31, 7, 32, 3, 14, 8, 80, 4, 67, 2, 34, 
    6, 86, 0, 52, 4, 78, 3, 39, 2, 70, 1, 50, 5, 79, 8, 72, 7, 33, 
    8, 43, 2, 25, 1, 56, 3, 12, 5, 45, 7, 34, 4, 43, 0, 65, 6, 85, 
    8, 56, 5, 12, 3, 47, 4, 16, 6, 65, 0, 78, 7, 52, 1, 64, 2, 84, 
    4,  4, 8, 60, 7, 62, 5, 12, 3, 86, 6, 18, 2, 70, 0, 70, 1,  9, 
    2, 37, 0,  7, 5, 38, 7, 70, 4,  1, 8,  7, 3, 68, 1, 20, 6,  1, 
    8, 45, 3, 84, 1, 37, 5, 66, 6, 70, 2, 29, 7, 24, 4, 84, 0, 95
  };
  const int q5090[] = {
    9, 9, // Number of jobs and machines
    8, 12, 6,  3, 3, 43, 7, 98, 4, 75, 2, 30, 5, 29, 1, 32, 0, 50, 
    8,  9, 3,  4, 4, 73, 0, 93, 5, 63, 6, 47, 1, 84, 7, 57, 2, 44, 
    4,  5, 5, 14, 7, 96, 8, 89, 1, 16, 6, 23, 2, 24, 0, 23, 3,  6, 
    4, 87, 2, 23, 8, 89, 5, 55, 0, 11, 6, 65, 3, 87, 1, 23, 7, 50, 
    7, 71, 0, 93, 3, 69, 4, 51, 8, 65, 6, 60, 1, 79, 5, 20, 2, 24, 
    3, 97, 1, 42, 4, 44, 8, 56, 0, 58, 2, 93, 7, 87, 5, 30, 6, 77, 
    6, 21, 4, 78, 7, 96, 0, 71, 2, 45, 5, 34, 3, 36, 1, 10, 8,  6, 
    8, 64, 2, 77, 1, 50, 3, 22, 0, 65, 4, 84, 6, 93, 7, 57, 5, 85, 
    6,  9, 1, 35, 8, 50, 4, 90, 0, 17, 3, 10, 5, 28, 7, 23, 2, 35
  };
  const int q5091[] = {
    9, 9, // Number of jobs and machines
    3,  1, 0, 33, 2, 25, 7, 65, 6, 27, 4, 67, 8, 20, 1, 17, 5, 38, 
    5, 68, 6, 89, 0, 49, 4, 90, 7, 37, 8, 38, 3, 83, 1, 43, 2,  8, 
    5, 37, 7,  5, 4, 82, 8, 63, 0, 17, 2, 80, 6, 47, 3, 43, 1, 77, 
    7, 33, 8, 39, 2, 28, 6, 50, 4, 68, 0, 34, 5,  2, 3, 93, 1, 29, 
    8, 50, 1, 56, 4, 31, 5, 27, 2, 95, 6, 85, 0, 23, 3,  5, 7, 59, 
    3, 86, 2,  9, 1, 29, 8, 34, 7,  2, 0, 66, 5, 52, 6, 20, 4, 91, 
    4, 63, 6, 92, 5, 20, 2,  9, 8, 59, 7, 24, 0, 18, 1, 38, 3, 45, 
    6,  3, 0, 57, 1, 44, 5, 38, 2, 29, 4, 14, 8, 90, 7, 72, 3, 56, 
    0, 21, 3, 68, 2, 75, 7, 61, 4, 20, 5,  3, 8, 61, 1, 49, 6, 39
  };
  const int q5092[] = {
    9, 9, // Number of jobs and machines
    4, 19, 0, 96, 2, 72, 3, 10, 6, 39, 1, 77, 7, 66, 8,  9, 5, 29, 
    5, 67, 7, 84, 0, 52, 6, 65, 2, 23, 4, 47, 8, 93, 1, 87, 3,  2, 
    4, 86, 8, 16, 7,  7, 3, 67, 1, 43, 5, 44, 6, 99, 2, 69, 0, 49, 
    4, 20, 5, 30, 6, 91, 0, 60, 3, 46, 8, 63, 2, 77, 1, 10, 7, 59, 
    1,  6, 2, 66, 5, 92, 7, 77, 4, 44, 3, 34, 8, 59, 0, 67, 6, 81, 
    6, 59, 8, 28, 5, 84, 4, 88, 2, 33, 0, 54, 1, 43, 7,  9, 3, 77, 
    2, 67, 6, 26, 8, 13, 7, 26, 1, 86, 5, 17, 4, 88, 3, 91, 0, 10, 
    8,  8, 2, 74, 6,  9, 3, 61, 1, 27, 7, 29, 4, 92, 5, 76, 0, 20, 
    7, 44, 5, 61, 2, 96, 8, 97, 6, 23, 1,  1, 4, 23, 3, 83, 0, 35
  };
  const int q5093[] = {
    9, 9, // Number of jobs and machines
    4, 23, 8, 83, 5,  3, 1, 56, 3, 81, 0, 60, 7, 64, 6, 26, 2, 12, 
    6, 41, 4,  9, 5,  1, 0, 69, 8, 63, 3, 84, 7,  8, 1, 35, 2, 78, 
    6, 61, 5, 11, 4, 93, 8, 19, 0, 42, 3,  5, 2, 56, 7, 20, 1, 90, 
    4, 26, 5, 57, 0, 60, 6, 55, 3, 68, 8, 55, 2,  7, 7, 30, 1, 12, 
    8,  2, 3, 78, 5, 66, 6, 12, 1,  1, 2, 77, 7, 10, 0, 30, 4, 32, 
    2, 33, 4,  2, 7, 22, 1, 63, 8, 38, 3, 14, 0, 55, 6, 27, 5,  1, 
    5, 23, 2, 62, 3, 25, 7,  5, 1, 34, 8,  6, 0, 18, 6, 78, 4, 46, 
    6, 93, 8, 31, 5, 75, 3, 10, 7, 71, 1, 39, 4, 26, 0, 86, 2, 58, 
    4,  7, 8, 11, 6,  4, 7, 58, 5, 25, 2, 79, 3, 18, 1, 88, 0,  7
  };
  const int q5094[] = {
    9, 9, // Number of jobs and machines
    3, 52, 0, 19, 4, 81, 6, 16, 1, 51, 5, 26, 7, 18, 2,  4, 8, 52, 
    4, 83, 8, 11, 7, 48, 0, 14, 1, 33, 2, 11, 5, 68, 6, 46, 3, 84, 
    0, 54, 8, 99, 6, 72, 7, 76, 1, 47, 2, 32, 5, 36, 3, 93, 4, 59, 
    7, 10, 0, 83, 3, 26, 8, 85, 1, 62, 6,  9, 2, 61, 5,  8, 4,  7, 
    8, 94, 1, 12, 6, 52, 4, 67, 3, 44, 5, 91, 0, 56, 2, 41, 7, 61, 
    2, 11, 8, 57, 3, 23, 5, 28, 0, 59, 6, 12, 4, 75, 7,  7, 1, 97, 
    1, 26, 7, 33, 3,  1, 6,  9, 8, 20, 4, 79, 0, 25, 5, 81, 2, 37, 
    7, 52, 4, 71, 3, 94, 0, 17, 6, 78, 8, 92, 1, 28, 5, 48, 2, 27, 
    0, 41, 6, 64, 5, 14, 2, 16, 4, 45, 7, 10, 8, 77, 1, 58, 3, 81
  };
  const int q5095[] = {
    9, 9, // Number of jobs and machines
    3, 76, 0, 95, 2, 31, 7, 52, 5, 24, 1, 48, 8, 60, 4, 51, 6,  1, 
    6, 35, 7, 36, 2, 69, 8, 44, 1, 50, 5, 56, 4, 17, 3, 48, 0, 73, 
    5, 79, 6, 65, 2, 46, 4, 85, 1, 67, 0, 63, 7, 58, 3, 30, 8, 32, 
    1, 11, 2, 33, 3, 96, 6, 86, 0, 69, 8, 42, 5, 69, 4,  1, 7, 35, 
    5, 94, 2, 28, 7, 89, 1, 98, 6, 52, 4, 30, 3,  5, 0,  4, 8, 25, 
    1, 10, 2, 19, 0, 35, 3,  6, 7, 89, 8, 45, 5,  5, 6, 64, 4, 24, 
    7, 71, 4, 65, 5, 46, 3, 23, 0, 42, 1, 49, 6, 73, 8, 31, 2, 85, 
    4, 93, 1, 35, 3,  9, 0, 84, 8, 38, 5,  4, 7, 79, 2, 65, 6, 65, 
    1, 34, 0, 35, 7, 65, 6, 68, 5, 58, 4, 45, 3, 91, 2, 89, 8, 37
  };
  const int q5096[] = {
    9, 9, // Number of jobs and machines
    4, 62, 8, 13, 6, 99, 2,  7, 5, 83, 1,  9, 3, 99, 7, 26, 0, 49, 
    0, 31, 4, 36, 3, 77, 7, 79, 5, 32, 8, 65, 6, 26, 2, 94, 1, 66, 
    1, 54, 2, 22, 3,  3, 0, 11, 7, 24, 5, 81, 4, 86, 6, 85, 8, 43, 
    8, 72, 3, 55, 1, 53, 2,  2, 6, 26, 0, 56, 5, 84, 7, 23, 4, 75, 
    8, 57, 1,  4, 5, 22, 6, 27, 7, 17, 0, 32, 3, 51, 4, 30, 2, 30, 
    2, 65, 3,  1, 4, 98, 7, 18, 1, 59, 6, 81, 8, 26, 5, 99, 0,  8, 
    1, 29, 7,  2, 0, 46, 4,  6, 2, 65, 6, 47, 5, 34, 8, 14, 3, 44, 
    7,  2, 2, 36, 3,  5, 6, 18, 8, 15, 4, 90, 0, 27, 1, 59, 5, 59, 
    2, 44, 4, 94, 5, 56, 7, 28, 8, 21, 0, 12, 1, 95, 3, 58, 6, 19
  };
  const int q5097[] = {
    9, 9, // Number of jobs and machines
    4, 71, 6, 73, 5, 13, 8, 51, 3, 74, 7, 52, 0,  7, 2, 28, 1, 93, 
    2, 37, 4, 81, 6, 93, 0, 93, 5, 71, 1, 49, 7, 36, 3, 71, 8, 25, 
    0, 30, 2,  2, 7, 75, 4, 22, 5, 14, 8, 72, 6, 68, 3,  4, 1, 81, 
    1, 16, 8, 66, 4, 95, 5,  3, 3, 98, 0, 76, 2, 95, 6, 26, 7, 80, 
    5, 20, 1, 67, 6, 55, 0, 19, 8, 14, 2, 54, 3, 94, 4, 25, 7, 52, 
    1,  3, 2,  6, 4, 28, 8, 11, 7, 37, 5, 89, 0, 48, 3,  3, 6, 83, 
    5, 68, 2, 27, 0,  6, 7, 80, 6, 68, 3, 67, 4, 93, 1, 71, 8, 93, 
    1, 64, 0, 44, 2, 37, 8, 85, 5, 60, 6, 81, 7, 26, 4, 37, 3, 29, 
    4, 43, 0, 18, 2,  3, 7, 70, 1, 88, 3, 89, 6, 57, 8, 47, 5, 28
  };
  const int q5098[] = {
    9, 9, // Number of jobs and machines
    1, 73, 0, 20, 3, 52, 8,  3, 6, 83, 7, 35, 2,  9, 5, 29, 4,  4, 
    4, 20, 2,  4, 3, 17, 7, 80, 8, 82, 1, 18, 6, 26, 5, 72, 0, 44, 
    4, 78, 2, 48, 1, 14, 7, 93, 3,  1, 5,  5, 8, 13, 6, 40, 0, 97, 
    0, 66, 8, 68, 1, 87, 2, 16, 7, 93, 5, 93, 4, 66, 6, 35, 3, 46, 
    8, 84, 2, 30, 6, 39, 0, 45, 5, 66, 7, 42, 4, 60, 3, 81, 1, 66, 
    1, 88, 3, 72, 4, 47, 7,  2, 0, 88, 6, 65, 8, 26, 5, 94, 2, 50, 
    7, 70, 2,  7, 1, 54, 8, 63, 5, 66, 4, 27, 6, 26, 0, 64, 3, 37, 
    7, 26, 6, 60, 2, 26, 8, 47, 3, 66, 5, 82, 4, 56, 0, 79, 1, 24, 
    6, 64, 4, 55, 0, 40, 1, 47, 3, 91, 7, 14, 8, 27, 2, 97, 5, 83
  };
  const int q5099[] = {
    9, 9, // Number of jobs and machines
    4,  4, 6, 52, 8, 50, 5, 96, 3, 95, 1, 70, 0, 52, 2, 58, 7, 39, 
    3, 74, 1, 40, 0, 76, 5, 74, 6, 63, 4,  3, 8, 39, 7, 50, 2, 74, 
    7,  4, 2, 70, 0, 43, 1, 39, 8, 31, 6, 35, 4, 18, 5, 50, 3, 95, 
    1, 96, 3, 82, 6, 37, 7, 73, 8, 66, 0, 70, 4, 36, 5, 21, 2,  5, 
    7, 24, 0, 99, 2, 98, 8,  7, 3, 26, 6, 71, 5, 74, 1, 27, 4, 33, 
    8, 52, 7, 55, 4, 94, 0, 98, 2, 37, 6, 74, 5, 83, 1, 65, 3, 93, 
    5, 95, 7, 16, 2,  6, 6, 97, 0, 22, 8, 92, 1, 94, 3, 43, 4, 58, 
    7, 46, 5, 49, 1, 60, 4, 13, 3, 85, 6, 67, 2, 35, 8, 86, 0, 14, 
    5, 63, 6, 81, 7, 28, 3, 65, 1, 59, 2, 34, 0, 33, 8, 34, 4, 82
  };
  const int q5100[] = {
    9, 9, // Number of jobs and machines
    5, 34, 1, 71, 0, 30, 2, 10, 8, 67, 3, 85, 7, 50, 4, 10, 6, 55, 
    5, 11, 7, 26, 4, 15, 2,  8, 0, 45, 1, 31, 3, 77, 6, 94, 8, 74, 
    3, 12, 5, 49, 4, 78, 7, 33, 8, 73, 0,  5, 2, 90, 1, 75, 6, 81, 
    0, 63, 4, 67, 7, 54, 1, 83, 3, 53, 5, 95, 8, 63, 2, 91, 6,  1, 
    8, 34, 1,  1, 2, 36, 4, 80, 6, 39, 5, 33, 7, 51, 3, 27, 0, 16, 
    8, 14, 3, 88, 2, 18, 1,  4, 5,  8, 4, 38, 7,  1, 6, 94, 0, 44, 
    4, 51, 7, 62, 8, 54, 5, 92, 6, 80, 0, 95, 2, 89, 3, 72, 1, 56, 
    2, 98, 4, 56, 6, 22, 0, 72, 5, 56, 3, 65, 8, 55, 1, 39, 7, 20, 
    4,  2, 2, 75, 6, 25, 5, 13, 7, 23, 8, 36, 3, 19, 0, 84, 1, 61
  };
  const int q5101[] = {
    9, 9, // Number of jobs and machines
    2, 91, 0, 53, 1, 74, 4, 23, 6, 90, 3, 76, 8,  1, 5, 59, 7, 40, 
    7, 95, 4, 72, 2,  6, 1, 62, 3, 81, 0, 55, 5, 88, 8, 36, 6, 27, 
    4, 39, 3, 66, 8, 23, 7, 68, 2, 50, 1, 34, 6,  5, 0, 63, 5, 77, 
    1, 55, 8, 55, 4, 90, 0, 85, 6, 62, 3, 68, 7, 69, 2, 89, 5, 82, 
    6, 98, 0, 97, 5, 14, 3, 27, 2, 12, 8, 67, 7, 54, 4,  8, 1, 25, 
    6, 93, 1,  5, 7, 27, 3, 96, 5, 54, 4, 17, 2, 44, 8,  3, 0, 13, 
    4, 29, 8,  2, 0, 53, 6,  2, 2, 30, 5, 49, 7, 47, 1, 13, 3, 60, 
    2, 67, 8, 58, 1, 33, 6, 48, 3, 42, 7, 85, 0, 87, 5, 98, 4, 47, 
    8, 36, 6,  8, 4, 41, 2, 57, 5, 36, 7, 50, 0, 18, 3, 80, 1, 69
  };
  const int q5102[] = {
    9, 9, // Number of jobs and machines
    7, 51, 8, 98, 0, 39, 5, 68, 1, 82, 6, 37, 4, 95, 2, 62, 3, 15, 
    5, 11, 6, 12, 2, 92, 1, 47, 0, 31, 4, 42, 3, 15, 8, 71, 7, 63, 
    7, 97, 5, 80, 1, 47, 0, 68, 8, 44, 6, 15, 3, 58, 4, 78, 2, 68, 
    1, 85, 7, 21, 0,  5, 8, 24, 3, 32, 5, 47, 2, 64, 4, 64, 6, 53, 
    0, 46, 6, 43, 8, 89, 2, 90, 3, 45, 7, 87, 4, 52, 1, 75, 5,  8, 
    5, 78, 4, 90, 7, 62, 3, 27, 1, 48, 2, 63, 0, 57, 6, 19, 8, 51, 
    6, 71, 8, 81, 2, 48, 0, 97, 3, 95, 7, 93, 1, 63, 4, 77, 5, 29, 
    3, 23, 0, 37, 1, 29, 2, 34, 4, 40, 8, 92, 7, 96, 5, 62, 6, 31, 
    3, 21, 2, 75, 8, 99, 7, 39, 4, 90, 0, 24, 1, 43, 5, 84, 6, 52
  };
  const int q5103[] = {
    9, 9, // Number of jobs and machines
    5, 56, 1,  6, 0, 38, 4,  1, 6, 52, 7, 70, 3,  5, 2, 42, 8, 77, 
    2, 58, 7,  9, 3, 33, 5, 64, 6, 17, 4, 27, 8, 35, 1, 72, 0, 18, 
    5, 27, 7,  1, 0, 12, 1, 32, 3, 29, 8, 52, 6, 12, 2,  3, 4, 11, 
    5, 21, 7, 36, 2, 57, 0, 17, 4, 63, 8, 13, 3, 83, 1, 55, 6, 44, 
    8, 93, 3, 59, 1, 51, 6, 78, 2, 68, 0, 52, 7, 97, 5, 28, 4, 67, 
    1, 62, 7, 72, 6, 34, 5, 21, 0, 78, 2, 86, 4, 17, 8, 85, 3, 14, 
    7, 21, 3, 86, 5, 65, 1, 20, 4, 19, 8, 20, 2, 42, 6, 69, 0, 38, 
    1, 80, 3, 29, 0, 45, 5, 96, 7, 40, 2, 68, 4, 28, 8, 43, 6, 77, 
    3, 37, 2, 46, 7, 94, 1, 67, 4, 79, 5, 55, 6, 96, 0, 53, 8, 98
  };
  const int q5104[] = {
    9, 9, // Number of jobs and machines
    4, 13, 7, 94, 1, 16, 2, 57, 8, 47, 6, 88, 5, 62, 3, 21, 0, 18, 
    1, 19, 8, 96, 2, 53, 3, 42, 5,  2, 7, 66, 0, 69, 4, 90, 6, 10, 
    5, 41, 3,  6, 6, 30, 8, 71, 4,  2, 0, 32, 2, 60, 1, 71, 7, 85, 
    3, 67, 8, 35, 2, 91, 4, 63, 5, 70, 7, 50, 6, 98, 1, 28, 0, 80, 
    3, 36, 8, 56, 5, 64, 2, 39, 6, 76, 1, 88, 0, 69, 4, 83, 7,  1, 
    5, 68, 6, 90, 2, 39, 8,  4, 7, 31, 3, 23, 1, 92, 4,  4, 0, 16, 
    3, 11, 7, 26, 0, 12, 6,  4, 2, 21, 8, 39, 4, 40, 1, 61, 5, 97, 
    7, 86, 1, 40, 3, 39, 5, 25, 2, 55, 4,  9, 6, 93, 8, 62, 0, 15, 
    6, 26, 0, 30, 7, 35, 3, 51, 1, 85, 2, 62, 8, 24, 4, 78, 5, 76
  };
  const int q5105[] = {
    9, 9, // Number of jobs and machines
    2, 14, 0,  5, 7, 36, 3,  1, 1, 61, 8, 71, 4, 63, 5, 13, 6, 84, 
    1, 35, 8,  9, 6,  1, 0, 46, 2, 32, 4,  8, 3, 61, 7, 71, 5, 49, 
    4, 70, 8, 42, 5, 38, 3, 63, 6, 12, 7, 82, 2, 44, 1, 33, 0, 33, 
    2, 39, 5, 61, 6, 42, 3, 17, 0, 47, 1, 74, 8, 26, 4, 59, 7, 99, 
    8, 12, 0, 68, 3, 55, 6, 31, 2, 63, 5, 24, 4, 29, 7, 16, 1, 96, 
    2, 21, 8, 72, 7, 76, 6, 79, 1, 67, 3, 59, 4, 56, 0, 84, 5, 90, 
    0, 42, 5, 15, 4, 36, 8, 32, 1, 79, 3, 58, 7, 95, 6, 12, 2, 56, 
    6, 92, 4, 94, 0, 31, 8, 39, 3, 47, 7, 21, 2, 22, 5, 16, 1, 15, 
    3,  1, 5, 21, 4,  5, 1, 90, 2, 58, 8, 94, 7, 75, 0, 22, 6,  8
  };
  const int q5106[] = {
    9, 9, // Number of jobs and machines
    4, 33, 8, 95, 6, 69, 7, 83, 1, 37, 0, 25, 3, 40, 2, 48, 5, 27, 
    3, 13, 8, 41, 0, 97, 1, 36, 6, 62, 5, 84, 4, 13, 2, 28, 7, 44, 
    3, 58, 1, 74, 5, 80, 7, 62, 0, 23, 2, 67, 6, 84, 4, 68, 8, 56, 
    4, 30, 3, 68, 5,  4, 8, 77, 1, 14, 6, 23, 2, 50, 0, 48, 7,  6, 
    0, 30, 8, 85, 1, 78, 6, 64, 5, 35, 7, 26, 4, 36, 3, 99, 2, 59, 
    2, 49, 6, 39, 7, 73, 4, 81, 1, 10, 3,  7, 0, 99, 8, 24, 5, 34, 
    6, 31, 8, 55, 3, 75, 2, 73, 7, 75, 4, 92, 1, 32, 5, 58, 0, 55, 
    3, 26, 4, 60, 2, 51, 1, 43, 5, 44, 8, 15, 0, 63, 6, 82, 7, 58, 
    2, 78, 0, 41, 3, 18, 6, 10, 1, 35, 8, 14, 4, 48, 5, 95, 7, 59
  };
  const int q5107[] = {
    9, 9, // Number of jobs and machines
    2, 94, 6, 59, 5, 44, 0,  9, 8, 14, 1, 81, 3, 77, 4, 25, 7, 87, 
    4, 12, 7, 60, 1, 81, 8, 15, 2,  6, 0, 51, 3, 97, 6, 15, 5, 83, 
    3, 39, 5, 38, 2, 32, 1,  7, 8, 18, 6, 25, 4, 13, 7, 54, 0, 83, 
    6, 88, 2, 37, 1, 51, 0, 90, 8, 50, 7, 61, 4, 44, 3, 48, 5,  3, 
    1, 38, 6, 87, 4, 58, 0, 74, 8,  5, 3, 88, 7, 11, 2, 78, 5, 34, 
    4,  8, 3, 45, 6, 56, 8, 64, 0, 86, 2, 83, 7, 43, 5, 45, 1, 93, 
    7, 18, 4, 94, 5, 30, 8, 33, 0, 48, 2,  1, 1, 58, 6, 26, 3, 75, 
    7, 35, 1, 51, 0, 39, 6, 43, 2, 96, 5, 26, 3, 14, 8,  8, 4, 31, 
    2, 11, 0, 94, 3, 54, 6, 17, 4, 46, 1, 56, 8, 95, 7, 92, 5, 53
  };
  const int q5108[] = {
    9, 9, // Number of jobs and machines
    5, 35, 7,  4, 8, 89, 2,  9, 1,  2, 3, 19, 4, 33, 0, 16, 6, 21, 
    1,  8, 8, 95, 3, 83, 5, 21, 2, 38, 4, 15, 7, 34, 0, 22, 6, 19, 
    7, 34, 2,  7, 6, 33, 1, 95, 4, 79, 5, 35, 0, 22, 3, 12, 8, 51, 
    2, 29, 1,  3, 3, 15, 5, 48, 4, 26, 6,  9, 0, 67, 8,  4, 7, 69, 
    4, 79, 7,  7, 2, 19, 0,  8, 5,  1, 3, 19, 1,  4, 8, 65, 6, 13, 
    1, 18, 4, 29, 7, 75, 5, 27, 2,  8, 0,  1, 8, 10, 6, 82, 3,  5, 
    8, 69, 1, 14, 7,  7, 3,  6, 6, 93, 2, 48, 0,  7, 4, 55, 5, 95, 
    5, 32, 0, 41, 4, 42, 2,  1, 1,  4, 8, 43, 7, 61, 6, 71, 3,  1, 
    4, 28, 2, 60, 1, 16, 6, 69, 0, 78, 5, 52, 3, 94, 8, 72, 7,  1
  };
  const int q5109[] = {
    9, 9, // Number of jobs and machines
    0, 29, 5, 28, 2, 17, 3, 76, 1, 69, 4,  1, 6, 40, 8, 39, 7, 30, 
    2, 46, 4, 15, 3, 55, 7, 89, 5, 84, 0, 55, 6, 48, 1,  2, 8, 33, 
    1, 50, 2, 89, 5, 32, 4, 24, 6, 71, 8, 44, 7, 51, 3, 27, 0, 80, 
    5,  6, 8, 15, 4,  5, 6, 13, 2, 63, 0, 87, 1, 55, 7, 91, 3,  8, 
    2, 90, 0,  4, 8, 48, 6, 32, 7, 48, 3, 17, 4, 53, 1, 84, 5, 52, 
    0,  2, 3,  9, 2,  1, 7, 90, 8, 46, 6, 28, 5, 72, 1, 46, 4, 27, 
    3, 80, 4, 15, 5, 57, 0, 31, 1, 41, 7, 39, 2, 48, 6,  5, 8, 96, 
    8, 75, 2, 96, 7, 22, 1, 99, 5, 52, 4, 73, 3,  1, 0,  4, 6, 79, 
    7,  2, 8, 49, 4, 59, 2, 82, 3,  2, 5, 70, 6, 52, 1, 22, 0, 29
  };
  const int q5110[] = {
    9, 9, // Number of jobs and machines
    3, 17, 7, 69, 6, 50, 0,  7, 2, 26, 4, 40, 1, 99, 8, 67, 5, 77, 
    7, 60, 6, 48, 8, 16, 5, 45, 3, 46, 0, 98, 4, 71, 2,  8, 1, 91, 
    2, 72, 5, 41, 0, 20, 4, 78, 1, 83, 8, 90, 3, 99, 6, 31, 7, 11, 
    1, 15, 8, 36, 6, 13, 2, 42, 7, 79, 0, 56, 3, 19, 4, 78, 5, 13, 
    8, 64, 7,  9, 1, 70, 5, 34, 0, 96, 6, 96, 2, 39, 4,  6, 3, 32, 
    1, 76, 8, 17, 7, 60, 3, 99, 2,  2, 0, 66, 6,  5, 4, 34, 5, 90, 
    0, 58, 7, 73, 1, 15, 8, 19, 4, 46, 2, 34, 3, 57, 6,  5, 5, 47, 
    5, 29, 2, 32, 1, 36, 4, 79, 8, 22, 6, 86, 0, 44, 3, 65, 7, 23, 
    5, 41, 0, 64, 3, 50, 2,  5, 7, 16, 4, 15, 6, 12, 1, 54, 8, 26
  };
  const int q5111[] = {
    9, 9, // Number of jobs and machines
    6, 33, 8, 25, 3, 28, 5, 67, 7, 82, 4,  1, 2, 29, 0, 75, 1, 60, 
    4,  7, 7, 38, 0, 92, 2, 95, 3, 35, 1, 45, 8, 78, 6, 23, 5, 63, 
    6, 62, 2, 28, 4, 69, 8, 57, 0, 37, 1, 62, 3, 56, 5, 37, 7, 46, 
    4, 69, 7, 78, 0, 20, 3, 59, 6, 75, 2, 21, 1, 59, 5,  1, 8, 62, 
    3, 29, 7, 59, 2, 49, 0, 46, 1, 29, 6, 48, 8, 30, 4, 81, 5, 56, 
    4, 52, 5,  3, 8, 35, 7, 12, 0, 36, 1, 75, 6, 54, 3, 46, 2, 60, 
    3, 36, 6, 78, 4, 58, 7, 80, 8, 34, 5, 42, 2, 43, 0, 91, 1, 42, 
    3, 47, 2, 53, 5, 65, 1, 85, 4, 60, 8, 74, 0, 94, 7,  9, 6, 19, 
    2, 51, 8,  4, 4, 79, 1, 53, 7, 36, 0, 30, 6, 95, 3, 36, 5, 25
  };
  const int q5112[] = {
    9, 9, // Number of jobs and machines
    3, 68, 8, 78, 1, 91, 0, 37, 5, 71, 7, 31, 4, 37, 6, 65, 2, 14, 
    6, 60, 0, 99, 4, 21, 1, 60, 5, 42, 2,  2, 8, 77, 7, 53, 3, 95, 
    4, 94, 7, 60, 3, 29, 1, 92, 8, 15, 0, 98, 5, 45, 2, 70, 6, 81, 
    8, 10, 2, 88, 0, 28, 7, 82, 3, 47, 4, 30, 6,  5, 1, 40, 5, 82, 
    8, 79, 5, 26, 0, 98, 4, 47, 1, 11, 6, 92, 3, 98, 2, 39, 7, 64, 
    2, 67, 0, 42, 7, 47, 5, 38, 4, 14, 1, 49, 6, 67, 3, 15, 8, 94, 
    2,  8, 0, 60, 4, 56, 1, 61, 8, 46, 7, 76, 5, 98, 3, 55, 6, 82, 
    7, 71, 4, 41, 5, 37, 3, 25, 8, 38, 6, 31, 2, 53, 0,  5, 1, 14, 
    2, 43, 1, 68, 4, 43, 7, 38, 3, 41, 8, 36, 5, 95, 6, 28, 0, 35
  };
  const int q5113[] = {
    9, 9, // Number of jobs and machines
    2, 33, 1, 76, 5, 57, 7, 30, 8, 47, 6, 84, 3, 54, 4, 61, 0, 45, 
    7, 28, 1, 33, 3, 76, 5, 39, 8, 87, 2, 46, 4, 93, 0,  3, 6, 26, 
    1, 62, 5, 32, 4,  5, 8, 25, 3, 31, 6, 68, 0, 61, 2, 31, 7, 96, 
    6, 34, 1, 82, 8,  7, 7,  6, 5, 13, 3, 82, 4, 62, 2, 66, 0, 24, 
    2, 87, 0, 23, 5, 35, 4, 26, 8, 76, 1, 20, 6, 69, 7, 37, 3, 41, 
    1, 98, 3,  5, 2, 91, 8,  2, 5, 26, 7, 41, 0, 72, 6, 24, 4, 62, 
    3, 82, 5, 49, 8, 71, 6, 95, 1, 33, 2,  3, 7, 77, 0, 58, 4, 53, 
    4, 31, 3, 97, 6, 68, 5, 11, 0, 13, 1, 26, 7, 41, 2, 56, 8, 82, 
    5, 18, 4, 18, 7, 98, 2, 73, 3, 11, 8, 54, 1,  6, 0, 81, 6, 50
  };
  const int q5114[] = {
    9, 9, // Number of jobs and machines
    7, 15, 5, 40, 8,  9, 0, 41, 3, 45, 2, 73, 1, 62, 4, 14, 6, 20, 
    5, 21, 7,  6, 2, 22, 0, 61, 8, 42, 1, 53, 6, 27, 3, 49, 4,  2, 
    0, 22, 1, 97, 2, 79, 4, 29, 7, 99, 8, 34, 5, 71, 3, 13, 6, 52, 
    5, 74, 2, 27, 6, 30, 8, 90, 0, 84, 1, 61, 3, 35, 4, 18, 7,  4, 
    5, 29, 0, 93, 4, 61, 2, 51, 1,  5, 7,  3, 6, 10, 3, 30, 8, 15, 
    6, 18, 7,  9, 8, 91, 0, 54, 3, 40, 4, 11, 2, 15, 1, 58, 5, 81, 
    4, 70, 8, 70, 5,  7, 2, 76, 1,  4, 6, 31, 7, 63, 0, 76, 3, 11, 
    6, 32, 0, 59, 2, 68, 4, 97, 3, 37, 7, 87, 5, 35, 1, 31, 8, 48, 
    1, 51, 4, 35, 0, 17, 6, 33, 3, 41, 2, 85, 8, 80, 7, 11, 5, 88
  };
  const int q5115[] = {
    9, 9, // Number of jobs and machines
    2,  6, 8, 98, 6, 34, 3, 96, 0,  9, 5, 10, 4, 29, 1, 82, 7, 37, 
    2,  7, 6, 54, 5, 38, 8, 76, 4, 62, 1, 85, 0, 80, 7, 39, 3, 21, 
    5, 84, 6, 64, 1, 41, 0, 26, 8, 77, 4, 61, 3, 17, 2, 23, 7, 22, 
    5, 46, 4,  1, 6, 60, 3, 23, 8, 71, 0, 16, 1, 98, 2, 48, 7, 62, 
    1, 97, 4, 32, 8, 64, 5, 96, 6, 51, 3, 86, 2, 12, 0, 68, 7, 14, 
    7, 69, 1, 83, 6, 61, 3, 82, 2, 92, 0, 22, 8, 72, 5, 11, 4, 88, 
    3,  5, 7, 92, 2, 35, 5,  4, 1, 11, 0, 87, 8, 64, 4, 32, 6, 93, 
    6, 65, 5, 50, 3, 43, 4, 51, 8, 41, 7, 76, 0, 55, 2, 74, 1, 21, 
    0, 29, 8, 52, 3, 55, 4, 51, 6, 51, 5, 68, 2, 53, 1, 69, 7, 90
  };
  const int q5116[] = {
    9, 9, // Number of jobs and machines
    2, 92, 3, 36, 4, 89, 7, 16, 1, 60, 6, 10, 0, 94, 8,  7, 5, 19, 
    3, 98, 2, 93, 6, 14, 8, 50, 4, 62, 7, 28, 5, 36, 1, 43, 0, 38, 
    6, 18, 4, 78, 7, 47, 0, 93, 1, 70, 5, 94, 2, 30, 3,  1, 8,  7, 
    8, 45, 1, 15, 2, 69, 3, 24, 6, 32, 7, 60, 0, 68, 5, 48, 4, 85, 
    4, 31, 2, 36, 0,  3, 5, 50, 8, 75, 6, 93, 1, 25, 7, 55, 3, 15, 
    2, 45, 7, 74, 6, 74, 4, 76, 0, 63, 5, 73, 3,  4, 8, 22, 1, 69, 
    6, 59, 3, 29, 2, 30, 5, 78, 4, 51, 1, 83, 0, 51, 7, 80, 8, 67, 
    7, 35, 0, 39, 3, 26, 1, 21, 4, 69, 6, 18, 2, 24, 8, 83, 5,  8, 
    8, 87, 6, 45, 4, 12, 3, 20, 0, 85, 7, 25, 2, 34, 5,  4, 1, 57
  };
  const int q5117[] = {
    9, 9, // Number of jobs and machines
    3, 45, 2, 59, 5, 10, 4,  8, 8, 41, 7, 45, 0, 98, 1, 29, 6, 29, 
    3, 46, 2, 92, 4, 43, 1, 82, 6, 96, 8, 40, 0, 62, 5, 19, 7, 89, 
    4, 80, 7, 17, 8, 92, 6, 89, 1, 44, 5, 66, 2, 79, 0,  7, 3, 80, 
    2, 39, 3, 79, 1, 58, 5, 95, 8,  4, 4, 56, 6, 29, 7, 76, 0, 37, 
    4, 59, 5, 79, 7, 87, 6, 32, 8, 10, 2, 94, 0, 10, 3, 49, 1, 95, 
    6,  4, 5, 42, 2, 81, 3, 77, 7, 53, 1, 73, 0, 34, 4, 17, 8, 60, 
    7, 28, 5, 35, 3, 45, 8, 79, 6, 95, 4, 79, 0, 98, 1, 14, 2, 90, 
    1, 60, 3, 10, 7, 46, 0, 64, 8, 63, 6, 66, 5, 28, 2, 72, 4, 98, 
    1, 37, 2, 61, 7,  4, 5, 44, 8, 92, 4, 41, 3, 51, 0, 65, 6, 30
  };
  const int q5118[] = {
    9, 9, // Number of jobs and machines
    3, 93, 6, 62, 2, 86, 8, 22, 4,  5, 0, 77, 1, 63, 7, 63, 5, 30, 
    7, 19, 8, 45, 3, 85, 1, 83, 2, 60, 0, 77, 6, 96, 5, 76, 4, 93, 
    8, 50, 2, 97, 0, 21, 4, 97, 7, 46, 5, 15, 1, 69, 6, 82, 3, 24, 
    4, 52, 5, 32, 0, 38, 3, 92, 2,  2, 8, 72, 7, 86, 1, 44, 6, 81, 
    3, 30, 6, 26, 1, 98, 0, 52, 5, 19, 2, 73, 4, 86, 7, 20, 8, 83, 
    7, 70, 2, 53, 3,  7, 1, 86, 4, 90, 8, 36, 6, 41, 5, 93, 0, 44, 
    5, 55, 6, 26, 0, 28, 8, 91, 2,  1, 3, 96, 1, 91, 4, 51, 7, 36, 
    6, 57, 4, 36, 7, 38, 3, 86, 5, 34, 0, 43, 1, 97, 8, 83, 2, 12, 
    3, 96, 6,  5, 2, 70, 5, 29, 4, 40, 8, 10, 7, 52, 0, 66, 1, 93
  };
  const int q5119[] = {
    9, 9, // Number of jobs and machines
    8, 61, 0, 96, 6, 72, 1, 38, 7, 23, 2, 94, 5, 82, 4, 31, 3, 30, 
    7, 57, 8, 75, 5, 87, 4,  3, 1, 81, 6, 41, 3, 37, 2, 80, 0, 76, 
    0, 32, 5, 81, 2, 87, 6, 98, 4, 50, 1, 89, 8, 56, 7, 28, 3, 28, 
    3, 31, 1, 94, 6, 46, 5, 36, 2, 73, 4, 30, 7, 21, 8, 82, 0, 51, 
    3, 27, 5, 29, 8, 85, 1, 99, 7, 82, 0, 29, 4, 37, 2, 29, 6, 81, 
    3, 41, 2, 33, 8, 31, 1, 80, 0,  5, 7,  6, 6, 95, 5, 47, 4, 90, 
    4, 96, 6, 75, 8, 44, 1, 39, 2, 79, 3, 59, 5, 12, 7, 13, 0, 85, 
    4, 66, 8, 28, 6,  9, 7, 52, 0,  5, 3, 29, 2, 92, 5, 48, 1, 34, 
    5, 20, 0, 60, 8, 28, 7, 75, 4, 63, 3, 84, 2, 53, 1, 41, 6, 72
  };
  const int q5120[] = {
    9, 9, // Number of jobs and machines
    8,  7, 3, 49, 1, 58, 0, 64, 6, 38, 5, 26, 2,  2, 4, 13, 7, 19, 
    8, 57, 2, 80, 0, 21, 1, 45, 5,  9, 7, 16, 3, 10, 4,  1, 6, 13, 
    2, 13, 7, 54, 6, 30, 5, 18, 3, 11, 0, 48, 1, 33, 8, 49, 4, 23, 
    0, 89, 1,  2, 3, 46, 5, 41, 2, 88, 8, 86, 7, 17, 6, 51, 4, 93, 
    5, 63, 3, 36, 8,  1, 7, 75, 1, 68, 0, 57, 4, 39, 6, 57, 2, 80, 
    6, 38, 5, 70, 7, 33, 8, 58, 1, 42, 0, 62, 2,  7, 4, 22, 3, 17, 
    7, 63, 4, 44, 6, 14, 0, 82, 1, 33, 5,  6, 8, 82, 2,  9, 3, 28, 
    2, 68, 8, 49, 7, 75, 0, 75, 6, 58, 5, 30, 1, 81, 3, 29, 4, 99, 
    1, 11, 4, 47, 2, 71, 7,  8, 0, 83, 3, 15, 6, 53, 8, 33, 5, 37
  };
  const int q5121[] = {
    9, 9, // Number of jobs and machines
    7, 97, 6, 63, 0, 24, 5, 11, 3, 11, 4, 25, 8, 76, 1, 98, 2, 48, 
    7, 29, 4, 21, 3, 44, 1,  5, 2, 72, 6, 16, 8,  8, 0, 70, 5, 77, 
    1, 55, 3, 52, 7, 30, 0, 99, 5, 32, 6, 94, 8, 61, 2, 24, 4, 12, 
    2, 86, 5, 19, 1, 94, 3, 18, 0, 74, 7,  6, 8, 64, 4, 26, 6, 16, 
    2, 54, 5, 67, 4, 72, 7, 86, 3, 10, 0, 34, 1, 49, 8, 58, 6, 56, 
    3, 49, 0, 11, 4, 18, 6, 12, 5, 71, 8, 67, 1, 54, 7, 30, 2, 24, 
    6, 76, 3, 70, 4, 11, 0, 30, 2, 46, 5,  6, 1, 98, 8,  7, 7, 81, 
    1, 42, 2, 90, 5, 56, 8, 52, 3, 46, 7, 98, 6, 81, 0, 71, 4, 37, 
    2, 93, 6, 75, 7, 25, 0,  7, 8, 24, 5, 31, 3, 14, 1, 75, 4, 60
  };
  const int q5122[] = {
    9, 9, // Number of jobs and machines
    5, 38, 8, 35, 2, 19, 4, 66, 1, 76, 0, 65, 7,  5, 6, 98, 3, 71, 
    3, 77, 2, 34, 5, 79, 8, 45, 7, 44, 6, 33, 0, 31, 1, 74, 4, 66, 
    7, 67, 4, 47, 2, 11, 5, 64, 6, 52, 8, 20, 1, 52, 0, 19, 3, 97, 
    2, 53, 7, 57, 3, 59, 6, 24, 4,  4, 0, 10, 1, 69, 5, 31, 8, 34, 
    8, 98, 1, 32, 6, 81, 5,  5, 2, 88, 3, 56, 4, 90, 0, 55, 7, 74, 
    3, 10, 2, 59, 8, 40, 0, 14, 6, 18, 5, 38, 1, 29, 7, 46, 4, 84, 
    2, 23, 6, 55, 1, 16, 7, 54, 0, 40, 8,  2, 3, 94, 4, 91, 5, 16, 
    7, 61, 8, 84, 0, 76, 3, 97, 5, 44, 4, 38, 2, 98, 6,  1, 1, 50, 
    7, 87, 8, 70, 4, 44, 6, 21, 5, 96, 3,  9, 2, 58, 1, 92, 0, 68
  };
  const int q5123[] = {
    9, 9, // Number of jobs and machines
    7,  5, 3, 38, 0, 10, 8, 24, 4, 69, 1, 37, 6, 55, 5, 77, 2,  9, 
    7, 68, 4, 65, 5, 67, 3, 69, 8, 42, 6, 19, 1, 17, 0, 92, 2, 75, 
    4, 73, 7, 32, 5,  7, 2,  2, 0, 82, 8, 79, 1, 42, 3, 37, 6, 13, 
    2, 12, 1, 84, 7, 19, 6, 37, 8, 80, 5, 16, 0, 45, 3, 76, 4, 53, 
    8, 39, 0, 59, 7, 28, 6, 60, 1, 20, 4, 37, 5, 91, 3, 95, 2, 49, 
    4, 57, 7,  3, 6,  6, 3, 19, 5, 92, 1, 28, 8,  4, 2, 65, 0, 40, 
    0, 40, 2, 54, 8, 23, 3, 94, 5, 51, 7, 53, 4, 19, 6, 33, 1,  8, 
    5, 45, 4,  8, 7,  2, 0, 24, 1, 10, 2, 60, 3, 95, 6, 78, 8, 85, 
    8, 45, 0,  1, 6,  2, 7, 29, 3, 95, 5, 50, 4, 97, 1, 28, 2, 70
  };
  const int q5124[] = {
    9, 9, // Number of jobs and machines
    3, 56, 6, 60, 1, 26, 5,  2, 7, 11, 8, 98, 4, 71, 0,  9, 2, 44, 
    2, 63, 0, 97, 6, 85, 1, 77, 4, 81, 3, 56, 5, 52, 7, 43, 8,  2, 
    8, 76, 3, 46, 4, 27, 2, 59, 1, 58, 7, 29, 6, 28, 5, 17, 0, 90, 
    4, 14, 1, 94, 7, 45, 0, 49, 2, 23, 5, 52, 3, 81, 6,  1, 8, 63, 
    6,  8, 3, 10, 0, 20, 2, 59, 1, 75, 5, 19, 8, 28, 7, 21, 4, 35, 
    7, 31, 2, 35, 4, 98, 1, 94, 0,  2, 3,  7, 5, 45, 8, 15, 6, 61, 
    7, 52, 3, 49, 1,  2, 0, 77, 4,  8, 8, 45, 6, 49, 5, 22, 2, 27, 
    3, 51, 4, 53, 1, 32, 0, 56, 2, 39, 7, 73, 6, 19, 5, 25, 8, 72, 
    4, 88, 0, 84, 6, 58, 7, 36, 5, 33, 8, 19, 3, 67, 1, 13, 2,  8
  };
  const int q5125[] = {
    9, 9, // Number of jobs and machines
    1, 91, 2, 11, 0, 93, 4, 86, 6, 30, 8, 26, 3, 93, 7, 78, 5, 68, 
    8,  1, 1,  4, 3, 87, 4, 19, 0, 16, 5, 79, 6, 49, 2,  1, 7, 57, 
    4, 85, 7, 94, 8,  2, 5, 20, 3,  6, 0, 40, 6, 85, 1, 86, 2, 55, 
    8, 72, 0, 48, 6, 19, 2, 42, 1, 88, 5, 91, 4, 41, 7, 35, 3, 57, 
    2, 38, 1, 36, 3, 34, 5, 31, 0, 84, 7, 20, 6, 62, 8, 42, 4, 57, 
    0, 48, 7, 17, 8, 88, 5, 31, 3,  2, 1, 97, 4, 71, 6, 47, 2, 41, 
    7, 32, 8, 43, 1, 62, 6, 27, 0, 26, 5, 85, 4, 64, 2,  5, 3, 19, 
    0, 49, 2, 83, 5,  2, 4, 54, 1, 49, 3, 74, 6, 22, 8, 78, 7, 94, 
    4, 76, 7, 96, 3, 66, 5, 53, 1, 16, 0, 87, 2, 50, 6, 70, 8, 36
  };
  const int q5126[] = {
    9, 9, // Number of jobs and machines
    5, 24, 4, 51, 6, 67, 3, 29, 8, 25, 0, 28, 2, 88, 1, 15, 7, 64, 
    2, 92, 4,  4, 5, 54, 3, 25, 1,  3, 8, 55, 0, 61, 7, 48, 6, 13, 
    0, 16, 6, 57, 5, 88, 8, 31, 1,  5, 3, 41, 4,  9, 7, 31, 2,  9, 
    3, 92, 0, 32, 5, 48, 6, 16, 7, 96, 1, 43, 2, 93, 8, 26, 4, 85, 
    8, 62, 6, 46, 0, 96, 5, 21, 2, 17, 7, 21, 3, 75, 4, 48, 1, 56, 
    2, 26, 7,  8, 8, 91, 3, 15, 1, 16, 4, 28, 0, 21, 5, 69, 6, 39, 
    0, 30, 8, 27, 1, 41, 3, 94, 2, 15, 5, 97, 4, 73, 6, 92, 7,  8, 
    0, 96, 4, 18, 2, 11, 3, 92, 8, 98, 6, 68, 5, 71, 7, 59, 1, 26, 
    1, 56, 5, 52, 6, 63, 8, 23, 4, 45, 3, 51, 2, 39, 0, 46, 7, 56
  };
  const int q5127[] = {
    9, 9, // Number of jobs and machines
    0, 14, 4, 78, 6, 58, 2, 46, 3, 17, 5, 19, 7, 64, 8, 94, 1,  5, 
    4, 87, 8, 10, 7, 67, 6, 63, 5, 54, 2, 65, 1, 94, 3, 98, 0, 11, 
    4, 46, 5, 47, 6, 54, 2, 18, 8, 38, 3, 55, 0, 58, 7, 84, 1,  7, 
    6, 51, 8, 11, 4,  3, 3, 84, 2, 35, 0, 86, 7, 80, 1, 60, 5, 68, 
    1,  6, 2,  3, 3, 41, 0, 14, 7, 71, 8, 82, 6, 38, 4,  6, 5, 21, 
    1,  7, 2, 40, 4, 14, 6, 45, 7, 90, 0, 62, 3, 70, 5, 29, 8, 96, 
    8, 21, 7, 19, 2, 16, 0, 40, 5, 64, 3, 34, 4, 76, 1, 62, 6, 92, 
    8, 60, 0, 57, 7, 33, 4, 47, 5, 44, 1, 25, 3, 97, 2, 72, 6, 19, 
    6, 30, 5, 98, 0, 19, 7, 29, 3, 11, 4, 76, 2, 67, 1, 65, 8, 36
  };
  const int q5128[] = {
    9, 9, // Number of jobs and machines
    4, 61, 7, 17, 8, 76, 5, 38, 2, 65, 3,  3, 6, 48, 0, 83, 1,  7, 
    3,  2, 1, 72, 5, 85, 0, 23, 2,  8, 4, 63, 6, 97, 7, 85, 8, 86, 
    0, 89, 3, 10, 1, 49, 2, 66, 8, 79, 4,  9, 7, 47, 5,  5, 6, 61, 
    3, 26, 7, 53, 6, 90, 2, 28, 4, 53, 0, 41, 8, 83, 5, 35, 1, 37, 
    1, 23, 5, 22, 2, 16, 0, 83, 3, 82, 7, 86, 8, 79, 4, 38, 6, 92, 
    0, 73, 1, 65, 7, 60, 6,  4, 3,  7, 5, 77, 2, 57, 8, 66, 4, 85, 
    8,  1, 5, 21, 6, 90, 2, 71, 7, 51, 3, 90, 1, 48, 4, 18, 0, 16, 
    4, 20, 3, 96, 1, 59, 6,  5, 8, 37, 2,  2, 0, 73, 7, 19, 5, 32, 
    6, 51, 7, 22, 8, 77, 1, 32, 4, 19, 5, 27, 2,  8, 0, 15, 3, 69
  };
  const int q5129[] = {
    9, 9, // Number of jobs and machines
    8,  3, 3, 90, 6, 57, 0, 31, 2, 61, 4, 11, 1, 39, 5, 10, 7, 62, 
    8, 91, 3, 87, 1, 42, 6, 78, 2, 23, 0, 82, 7,  6, 5, 72, 4, 17, 
    7, 70, 8, 83, 4, 16, 5, 96, 3, 26, 6, 97, 2, 31, 1, 58, 0, 51, 
    6, 46, 0, 26, 7, 39, 3, 47, 2, 95, 5, 23, 4, 48, 1, 54, 8, 63, 
    0, 23, 3, 78, 5, 24, 2, 96, 7, 70, 4, 49, 8, 84, 6, 11, 1, 27, 
    1, 66, 5, 45, 0, 10, 2, 54, 3, 30, 8, 42, 7, 34, 4, 70, 6, 60, 
    6, 95, 1, 71, 4, 75, 0, 70, 5, 66, 3, 16, 7, 41, 8, 48, 2, 29, 
    6, 91, 0, 63, 5, 34, 7, 51, 3, 54, 8, 43, 1, 75, 4, 57, 2,  6, 
    6, 16, 4, 40, 7, 10, 8, 92, 1, 55, 5, 59, 2, 98, 0, 56, 3,  3
  };
  const int q5130[] = {
    9, 9, // Number of jobs and machines
    1, 28, 6, 46, 8, 75, 3, 92, 0, 73, 5,  6, 4, 96, 7, 45, 2, 88, 
    6, 51, 0, 78, 1, 49, 2, 79, 4, 95, 3, 96, 5, 51, 7, 74, 8, 18, 
    4, 21, 5, 76, 6, 78, 0,  7, 2, 45, 7, 81, 3, 65, 1, 80, 8, 63, 
    0, 70, 8, 55, 6, 97, 5, 13, 1, 86, 3, 50, 4, 11, 2,  5, 7, 25, 
    7, 68, 2,  7, 5, 73, 0, 93, 8, 60, 1, 55, 3, 33, 6, 17, 4, 33, 
    0, 29, 5, 43, 2, 29, 4, 43, 7, 94, 6, 87, 1, 93, 8, 31, 3, 78, 
    0,  1, 4, 96, 6, 82, 2,  9, 5, 58, 8, 76, 7, 89, 3, 89, 1, 42, 
    5, 26, 3, 12, 8, 68, 4, 26, 6, 69, 7, 80, 1, 31, 0, 57, 2, 74, 
    1,  5, 3, 24, 5, 76, 7, 20, 4, 71, 2,  3, 6, 95, 8,  1, 0, 31
  };
  const int q5131[] = {
    9, 9, // Number of jobs and machines
    7, 34, 6, 86, 5, 43, 2, 89, 0, 95, 8, 80, 3, 73, 4, 56, 1, 21, 
    2, 90, 8, 65, 4,  3, 0, 58, 5, 51, 3, 41, 7, 76, 1, 50, 6, 77, 
    1, 16, 0, 14, 3, 38, 2, 63, 4, 17, 8, 11, 6, 96, 5, 48, 7, 69, 
    5, 22, 0, 81, 4, 82, 1, 90, 6, 52, 8, 26, 7, 86, 3, 82, 2, 84, 
    3, 56, 8, 25, 6, 15, 2, 51, 0, 81, 4, 71, 1, 16, 7, 47, 5, 80, 
    1, 95, 7, 67, 3, 40, 6, 58, 5, 36, 0, 46, 4, 43, 8, 51, 2, 79, 
    1, 35, 3, 37, 4, 51, 2, 24, 0, 74, 6, 76, 7, 80, 8, 11, 5, 27, 
    3, 79, 5, 30, 2, 90, 6,  4, 7, 80, 8, 75, 0, 30, 4, 25, 1, 52, 
    3, 62, 7, 82, 5, 54, 0, 93, 4, 23, 6, 67, 2, 81, 8, 81, 1, 46
  };
  const int q5132[] = {
    9, 9, // Number of jobs and machines
    0, 62, 7, 57, 2, 36, 8, 13, 5, 47, 3, 46, 6, 12, 1, 37, 4, 40, 
    8, 24, 5, 13, 3, 40, 0, 94, 4, 58, 1, 31, 2, 24, 6, 62, 7, 79, 
    4, 81, 3,  5, 2, 17, 6,  3, 1, 54, 7,  6, 5, 64, 8, 35, 0, 12, 
    4,  1, 8, 71, 7, 85, 1, 59, 5, 34, 3,  7, 0, 24, 2, 12, 6,  5, 
    6, 25, 4, 28, 2, 37, 8, 84, 3, 75, 0, 24, 1, 18, 7, 94, 5, 21, 
    8, 34, 6, 87, 2, 37, 7, 10, 4, 61, 0,  5, 1, 92, 5, 44, 3,  8, 
    0,  1, 8, 46, 7, 89, 2, 20, 3, 66, 4, 78, 1, 35, 5, 59, 6, 55, 
    3, 61, 5, 39, 1, 89, 8, 38, 0, 49, 7, 40, 4, 44, 6, 98, 2, 17, 
    2, 62, 3, 65, 5,  9, 4, 38, 6, 41, 0, 46, 1, 54, 7, 88, 8, 75
  };
  const int q5133[] = {
    9, 9, // Number of jobs and machines
    0, 86, 4, 98, 5,  9, 6, 10, 3, 15, 2, 49, 7, 15, 8, 38, 1, 36, 
    0, 58, 6, 49, 4, 22, 2, 63, 5, 22, 8,  1, 3, 80, 7, 55, 1, 18, 
    8, 37, 1, 42, 6, 63, 7, 87, 5, 25, 4, 44, 3, 74, 0, 62, 2, 77, 
    7, 28, 6, 82, 0, 51, 5, 43, 2, 33, 3, 10, 8, 37, 1, 14, 4, 49, 
    2, 54, 7, 54, 3, 67, 5, 26, 8, 47, 4, 74, 0, 30, 1, 30, 6, 83, 
    0,  3, 5, 55, 1, 54, 8, 49, 6, 24, 2, 91, 7, 28, 3, 69, 4, 48, 
    8, 81, 4,  2, 3, 68, 1, 92, 2, 99, 0, 93, 7, 49, 5, 99, 6, 83, 
    4, 89, 3, 24, 0, 57, 1, 21, 8, 24, 6, 87, 5, 66, 2,  4, 7, 62, 
    2, 15, 4, 89, 8, 84, 7, 31, 6, 57, 1, 24, 3, 32, 0, 12, 5, 18
  };
  const int q5134[] = {
    9, 9, // Number of jobs and machines
    6, 26, 5, 70, 2, 43, 3, 81, 4, 81, 1, 83, 7, 94, 8, 66, 0, 63, 
    5, 38, 7, 95, 8,  6, 3, 44, 4, 63, 2, 31, 1, 52, 0, 97, 6, 36, 
    0, 50, 4, 58, 5, 76, 6, 52, 7, 32, 2, 93, 1,  7, 3, 21, 8, 14, 
    8, 31, 5,  8, 1, 22, 0, 91, 4, 48, 7, 24, 2, 32, 3, 99, 6, 84, 
    7, 84, 0, 85, 5, 25, 3, 20, 4, 23, 6, 71, 1, 48, 8, 22, 2, 99, 
    8, 79, 2, 61, 6, 10, 0, 87, 1, 91, 5, 44, 4, 48, 3, 75, 7, 47, 
    7, 46, 6, 81, 4, 84, 3,  3, 8, 40, 5, 58, 2, 94, 1, 61, 0, 76, 
    3, 20, 0, 75, 7, 16, 5, 68, 6, 61, 1, 15, 2,  8, 4, 43, 8, 41, 
    4, 90, 7, 49, 2,  6, 0, 59, 6, 55, 1, 42, 5, 91, 8, 42, 3, 38
  };
  const int q5135[] = {
    9, 9, // Number of jobs and machines
    5,  1, 1, 59, 3, 32, 7, 50, 2, 10, 0,  2, 6, 14, 8, 70, 4, 57, 
    5, 31, 2, 79, 3, 21, 7,  9, 6, 22, 1, 69, 4, 16, 0, 95, 8, 40, 
    1, 28, 8, 98, 4, 15, 7, 74, 0,  4, 5,  2, 2, 49, 6, 53, 3,  8, 
    7, 94, 4, 53, 1, 45, 8, 13, 0,  2, 3, 56, 5, 22, 6, 79, 2, 18, 
    6, 54, 2,  6, 8, 50, 0, 18, 1, 62, 4, 24, 5, 81, 3, 34, 7, 12, 
    6, 46, 8, 75, 1,  5, 0, 75, 7, 39, 4, 35, 3, 29, 5, 46, 2, 75, 
    3, 92, 0, 78, 2, 59, 1, 90, 8, 83, 4, 72, 7, 34, 6, 29, 5, 58, 
    2, 30, 4, 13, 3, 50, 0, 42, 5, 34, 7,  6, 1, 65, 8, 66, 6, 66, 
    5,  5, 3, 46, 4, 18, 7,  2, 6, 90, 1,  8, 0, 91, 8, 94, 2,  4
  };
  const int q5136[] = {
    9, 9, // Number of jobs and machines
    5, 16, 8, 28, 3, 54, 6, 33, 4, 55, 2, 74, 7, 98, 0, 11, 1,  2, 
    5, 42, 6, 79, 3, 94, 7,  7, 8, 45, 1, 43, 4, 67, 0, 40, 2, 99, 
    4, 16, 5, 70, 3, 62, 8, 26, 6, 34, 1, 67, 2, 97, 0, 39, 7, 55, 
    3, 13, 1, 68, 8, 31, 7,  6, 4, 80, 5, 69, 2, 50, 0,  9, 6, 84, 
    1,  3, 8, 88, 5, 49, 2, 48, 0, 93, 4, 65, 7, 15, 6, 82, 3, 76, 
    4, 17, 0,  6, 8,  4, 7, 80, 6, 17, 2, 91, 5, 59, 1, 33, 3, 87, 
    5, 18, 8, 42, 6, 18, 3, 45, 4, 95, 0, 84, 1, 38, 2, 20, 7, 59, 
    7, 84, 0, 91, 5, 93, 4, 97, 6, 20, 3, 26, 1, 23, 8, 27, 2, 74, 
    7,  3, 3, 42, 4, 72, 1, 74, 8, 55, 5, 65, 0, 31, 6, 10, 2, 89
  };
  const int q5137[] = {
    9, 9, // Number of jobs and machines
    8, 96, 2, 56, 4, 78, 6, 81, 1, 21, 5, 92, 7, 11, 3, 75, 0, 99, 
    0, 80, 2,  2, 8, 80, 1, 23, 4, 76, 3,  6, 5, 39, 7, 43, 6,  3, 
    4, 92, 1, 30, 0, 40, 5,  9, 7, 26, 8, 61, 3, 12, 6, 48, 2, 16, 
    5, 55, 0, 64, 6, 19, 4, 78, 8, 49, 2, 28, 3, 61, 7, 55, 1, 22, 
    2, 52, 1, 78, 6, 69, 0, 97, 8, 90, 3, 39, 5,  8, 4,  7, 7, 10, 
    5, 12, 4, 33, 7, 48, 6, 17, 1, 61, 8, 14, 0, 52, 2, 55, 3, 80, 
    3,  5, 8, 68, 2, 67, 0,  7, 6, 28, 4, 52, 1, 86, 5, 91, 7, 36, 
    4, 59, 2, 80, 3, 93, 7, 72, 5, 16, 1, 62, 8, 43, 6, 48, 0, 27, 
    8, 36, 4, 44, 1, 23, 0, 49, 5, 76, 6, 74, 2, 17, 3, 58, 7,  5
  };
  const int q5138[] = {
    9, 9, // Number of jobs and machines
    2, 39, 6, 32, 0, 45, 4,  6, 5, 45, 3, 65, 1,  8, 7, 88, 8,  7, 
    7, 72, 6, 10, 8, 56, 2, 65, 3, 93, 4, 42, 5, 47, 1, 89, 0, 27, 
    7, 54, 4, 86, 6, 95, 1, 21, 5, 45, 8, 51, 2, 81, 0, 28, 3, 26, 
    8, 85, 2, 44, 7, 54, 3, 83, 5, 79, 6, 20, 0, 11, 4, 77, 1, 33, 
    1, 30, 0, 26, 4, 38, 6, 55, 3, 10, 2, 69, 7, 52, 5, 20, 8, 96, 
    0,  3, 1, 28, 8, 49, 3, 61, 7, 76, 5, 73, 6, 64, 4, 35, 2, 28, 
    6, 44, 2, 82, 1, 93, 7, 49, 5, 25, 8, 82, 4, 25, 0, 78, 3, 70, 
    5, 23, 8, 89, 4, 19, 0, 30, 7, 88, 1, 91, 3, 75, 6, 73, 2, 56, 
    7, 13, 2,  7, 4, 16, 1, 61, 8, 83, 0, 22, 3, 93, 6, 99, 5,  4
  };
  const int q5139[] = {
    9, 9, // Number of jobs and machines
    7, 45, 5, 84, 4, 42, 1, 54, 0, 45, 8, 96, 2,  6, 3, 54, 6,  4, 
    1, 66, 2, 56, 0, 95, 4,  3, 7, 14, 6, 48, 5, 96, 8, 57, 3, 75, 
    4,  2, 3, 32, 7, 78, 5, 40, 6, 22, 0, 34, 8, 66, 1, 25, 2, 22, 
    8, 31, 5, 14, 3, 97, 4,  1, 1,  9, 2,  5, 6,  9, 0, 61, 7, 78, 
    7, 93, 5, 40, 2, 84, 6, 62, 4, 80, 1, 74, 8, 34, 3, 93, 0, 88, 
    7, 52, 8, 66, 2, 29, 3, 45, 6, 69, 5, 98, 4, 69, 0, 46, 1, 14, 
    8, 84, 7, 94, 1, 88, 4, 65, 6, 73, 5, 42, 0, 77, 2, 32, 3,  9, 
    5, 12, 7, 64, 1, 57, 0, 11, 6, 76, 2, 19, 3, 41, 8, 69, 4, 29, 
    1, 67, 8, 43, 0, 21, 4, 29, 6, 17, 3, 66, 2, 64, 7, 80, 5, 39
  };
  const int q5140[] = {
    9, 9, // Number of jobs and machines
    5, 37, 0, 99, 2, 33, 3, 75, 7, 43, 1, 18, 6, 85, 8, 70, 4, 48, 
    0, 10, 6, 54, 4, 26, 5, 77, 1, 45, 2, 19, 3, 96, 7, 96, 8, 33, 
    8, 71, 6, 29, 5, 66, 3, 15, 2, 37, 4, 77, 0, 34, 1, 18, 7, 77, 
    5, 25, 4, 71, 0, 54, 6, 12, 2, 76, 1, 86, 3, 16, 8, 57, 7, 50, 
    0, 41, 1, 34, 7, 63, 6, 87, 3, 92, 4, 48, 8, 15, 5, 61, 2, 22, 
    7,  4, 8, 55, 4,  1, 1, 40, 3,  8, 6, 49, 5, 29, 0, 74, 2, 78, 
    2,  9, 7, 66, 0, 85, 6, 70, 5, 64, 8, 79, 4, 63, 1, 88, 3, 58, 
    1, 38, 8, 95, 6,  6, 7, 23, 2, 75, 5, 53, 0, 41, 4, 14, 3,  7, 
    3, 32, 5, 59, 4, 57, 0, 45, 6, 81, 8, 31, 7, 17, 2, 24, 1, 25
  };
  const int q5141[] = {
    9, 9, // Number of jobs and machines
    3, 13, 8,  3, 2, 35, 4,  1, 0, 85, 6, 61, 5, 82, 7, 40, 1, 48, 
    8, 50, 7, 95, 4, 24, 2, 55, 1,  9, 5, 63, 6, 78, 3,  9, 0, 38, 
    1, 28, 5, 28, 0, 59, 8, 43, 3, 34, 7, 70, 6, 71, 2, 77, 4, 91, 
    8, 80, 1, 41, 3, 76, 4, 28, 0, 84, 2, 46, 6, 83, 7, 77, 5, 71, 
    8, 30, 2, 84, 1, 46, 6, 36, 7, 48, 4, 76, 5, 62, 0, 38, 3, 36, 
    8,  4, 3, 35, 2, 18, 7, 64, 5, 93, 6, 99, 1, 53, 4, 79, 0, 67, 
    4, 18, 2, 12, 3,  2, 5, 27, 0, 35, 7, 61, 1, 26, 8, 24, 6, 67, 
    2, 67, 8, 61, 6, 21, 1, 17, 7, 83, 3, 36, 5, 83, 0, 51, 4, 72, 
    6, 95, 3, 19, 0, 34, 8, 88, 5, 88, 4, 56, 7, 78, 2, 49, 1, 75
  };
  const int q5142[] = {
    9, 9, // Number of jobs and machines
    8, 52, 1, 25, 4, 76, 5, 55, 0, 29, 7, 41, 2, 51, 6, 67, 3, 72, 
    8, 46, 2, 37, 6, 96, 0, 49, 4, 24, 5, 73, 7, 40, 1, 48, 3, 39, 
    0,  4, 1,  1, 3, 14, 2, 45, 5, 88, 7, 38, 4, 42, 8, 85, 6, 19, 
    2, 11, 4, 31, 0, 20, 5, 94, 8,  9, 7, 40, 1,  3, 3, 95, 6, 33, 
    1, 10, 5, 42, 7, 23, 3, 89, 6, 58, 4, 26, 0, 33, 2, 75, 8, 59, 
    1, 90, 4,  3, 3, 35, 8, 29, 0, 93, 2, 92, 6, 44, 5, 66, 7, 74, 
    8, 40, 5, 79, 1, 92, 3, 24, 2, 84, 4, 51, 6, 37, 0, 29, 7, 68, 
    3, 66, 7, 73, 8, 50, 4, 18, 5, 73, 1, 89, 0, 58, 2, 37, 6, 37, 
    5, 80, 2,  6, 4, 47, 6, 91, 1, 28, 3, 24, 8, 16, 0, 67, 7, 33
  };
  const int q5143[] = {
    9, 9, // Number of jobs and machines
    8, 18, 5, 15, 4, 40, 2,  3, 3, 98, 0, 39, 1, 89, 7, 94, 6,  2, 
    3, 50, 7, 36, 2, 52, 5, 91, 6, 23, 0, 82, 8, 73, 4,  1, 1, 27, 
    0, 46, 5, 67, 1, 77, 6, 56, 8, 15, 4, 53, 3, 83, 2, 99, 7, 65, 
    7, 70, 2, 88, 4, 67, 3, 99, 8,  1, 5, 55, 6, 21, 0, 96, 1, 99, 
    1, 90, 5,  9, 3,  5, 6, 83, 8, 21, 2, 30, 7, 57, 0, 49, 4, 89, 
    3, 46, 0, 26, 6, 16, 5, 83, 8, 55, 2, 18, 4, 39, 1, 22, 7, 64, 
    7, 25, 4, 51, 6, 44, 1, 70, 2, 62, 0, 56, 5, 12, 3, 95, 8, 20, 
    1, 98, 7, 66, 0, 13, 5, 92, 4, 33, 8, 29, 3, 13, 2, 70, 6, 88, 
    0, 93, 6,  5, 2, 49, 4, 40, 3, 14, 5, 45, 1,  1, 7, 91, 8, 23
  };
  const int q5144[] = {
    9, 9, // Number of jobs and machines
    3, 98, 6, 94, 1, 94, 5, 28, 2, 42, 4, 25, 8, 69, 0, 30, 7, 33, 
    2, 56, 1, 18, 4, 17, 6, 79, 5, 81, 7, 96, 0, 78, 3, 86, 8, 44, 
    1, 11, 7, 19, 6, 77, 0,  6, 3,  7, 5, 78, 8, 54, 2, 29, 4, 54, 
    8, 85, 6, 81, 0, 80, 2, 63, 7, 83, 1, 41, 3, 42, 4, 90, 5, 81, 
    7, 30, 3, 57, 5, 29, 0, 93, 1, 11, 2, 33, 6, 29, 8, 73, 4, 84, 
    6, 51, 4,  9, 3, 18, 1, 99, 2, 34, 8, 45, 0, 37, 5,  9, 7, 49, 
    5, 21, 8, 59, 2, 30, 6, 77, 4, 83, 1, 12, 3, 51, 0, 78, 7, 12, 
    2,  1, 0,  6, 3, 63, 1, 53, 5, 63, 8, 61, 6, 50, 4, 71, 7, 20, 
    3, 30, 5, 80, 1, 27, 6, 40, 4, 32, 2, 46, 7, 64, 0, 17, 8, 98
  };
  const int q5145[] = {
    9, 9, // Number of jobs and machines
    5, 69, 0, 56, 8, 54, 2, 33, 7, 66, 4, 81, 3, 35, 1, 65, 6, 73, 
    0, 61, 2, 17, 1, 84, 5, 17, 4, 22, 6, 22, 8, 32, 7, 52, 3, 78, 
    3, 27, 6, 31, 4, 66, 5, 81, 0, 53, 7, 15, 8, 62, 2, 10, 1, 67, 
    0, 46, 3, 39, 4, 99, 7, 53, 5, 78, 1, 40, 8, 88, 6, 76, 2, 53, 
    8, 81, 1, 14, 4, 10, 5,  5, 3,  2, 6, 49, 2, 78, 0, 51, 7, 73, 
    0, 27, 5, 30, 4, 71, 7, 30, 2, 94, 6, 93, 8, 16, 1, 82, 3,  1, 
    1, 61, 8, 79, 6, 62, 3, 16, 4,  4, 7, 98, 2, 53, 0, 86, 5, 33, 
    1, 40, 6,  1, 5, 38, 8,  8, 0,  1, 3, 63, 2, 55, 4, 14, 7,  7, 
    2, 48, 8, 91, 3, 63, 0, 46, 7, 91, 5, 79, 1, 88, 4, 97, 6, 88
  };
  const int q5146[] = {
    9, 9, // Number of jobs and machines
    0, 47, 8, 50, 3, 39, 6, 28, 2, 85, 4,  6, 7, 82, 5, 76, 1, 48, 
    4,  7, 5, 45, 1, 80, 2, 52, 3, 16, 6, 25, 8, 28, 7, 12, 0, 53, 
    8, 88, 3, 30, 4, 47, 2, 96, 0, 48, 7, 86, 5, 55, 6, 60, 1, 97, 
    0, 95, 2, 23, 3, 94, 7, 47, 8, 66, 6, 55, 4, 78, 1, 52, 5, 42, 
    5, 53, 6, 12, 1, 70, 3, 43, 2, 33, 4, 76, 8, 69, 0, 16, 7, 68, 
    7, 25, 8, 68, 6, 98, 2, 56, 5, 76, 1, 72, 3, 15, 4, 24, 0, 46, 
    3, 51, 0, 30, 7, 19, 1, 27, 5, 84, 4, 31, 6, 24, 8, 48, 2, 24, 
    5, 96, 0, 52, 7, 86, 3, 38, 8, 65, 1, 46, 6, 35, 4, 56, 2, 56, 
    8, 89, 0, 17, 7, 41, 2, 90, 1, 20, 6, 68, 3, 15, 5, 72, 4, 42
  };
  const int q5147[] = {
    9, 9, // Number of jobs and machines
    8, 82, 7, 69, 4, 69, 3, 52, 2, 28, 0, 54, 1, 37, 6, 34, 5, 49, 
    6, 28, 0, 69, 8, 47, 5, 51, 2, 85, 7, 98, 1, 28, 3,  1, 4, 26, 
    2, 26, 3, 91, 4, 76, 8,  2, 5, 27, 7, 98, 1,  3, 6, 63, 0, 93, 
    5, 66, 6,  4, 4, 78, 2, 21, 7, 72, 3, 28, 8, 34, 1, 29, 0, 99, 
    4, 84, 1, 56, 3, 68, 7, 73, 8, 46, 6, 76, 5, 82, 2, 70, 0,  9, 
    7, 92, 5, 94, 2,  8, 3, 62, 8, 75, 0,  2, 6, 36, 4, 58, 1, 54, 
    6, 36, 1, 25, 5, 64, 2, 62, 4, 93, 0, 88, 7, 41, 8, 93, 3, 10, 
    4, 72, 6, 37, 7, 52, 1, 90, 3, 45, 2, 32, 0, 95, 5, 71, 8, 79, 
    8, 48, 0, 87, 2, 52, 7, 93, 3, 87, 5, 77, 1, 80, 4, 70, 6, 36
  };
  const int q5148[] = {
    9, 9, // Number of jobs and machines
    0, 32, 5, 45, 3, 90, 4, 58, 2, 22, 8, 62, 6, 78, 1,  7, 7, 10, 
    6, 13, 4, 33, 5,  8, 8, 36, 3, 49, 1, 46, 0,  1, 2, 34, 7, 30, 
    7, 66, 8,  7, 5, 82, 6, 42, 0, 31, 2, 35, 1, 46, 3, 90, 4, 92, 
    0, 35, 1, 53, 3, 51, 6, 75, 2, 87, 5, 95, 7, 59, 4, 72, 8, 55, 
    0, 87, 4, 45, 7, 54, 2, 99, 6, 90, 5,  7, 3, 94, 8, 58, 1, 31, 
    6, 54, 3, 98, 7, 74, 1, 50, 0, 49, 4, 34, 2, 50, 8,  8, 5, 41, 
    1, 38, 4, 93, 2, 16, 3, 23, 8, 33, 7,  1, 5, 76, 6, 50, 0, 39, 
    6, 47, 4, 82, 5, 44, 7, 30, 3,  9, 1, 62, 0, 47, 2, 49, 8, 44, 
    5, 75, 6, 53, 2, 79, 0, 10, 4, 37, 3, 19, 7, 54, 1, 35, 8, 45
  };
  const int q5149[] = {
    9, 9, // Number of jobs and machines
    0, 46, 4, 95, 5, 59, 3, 27, 1, 39, 2, 51, 8, 73, 6, 85, 7, 31, 
    0, 66, 7, 57, 8, 99, 1, 79, 6, 33, 5, 21, 2, 86, 4, 36, 3, 84, 
    0, 28, 7, 51, 3, 38, 1, 79, 8, 37, 6, 66, 4, 34, 2, 26, 5, 59, 
    5, 58, 3, 15, 8, 20, 6, 89, 2, 82, 7,  4, 0, 94, 1, 82, 4, 91, 
    1, 19, 0, 50, 2, 65, 8,  7, 6, 56, 7,  1, 4, 35, 5, 82, 3, 16, 
    3, 11, 4, 63, 2, 11, 6, 89, 7, 88, 8, 12, 0, 48, 5, 73, 1, 33, 
    1, 12, 5, 10, 2, 78, 8, 48, 6, 57, 7, 45, 3, 21, 4, 24, 0, 62, 
    4, 75, 0, 26, 1, 75, 6, 57, 3, 40, 2, 15, 8, 22, 7, 14, 5, 64, 
    2, 69, 8, 57, 5, 14, 6, 85, 0, 38, 7, 83, 1, 65, 3, 12, 4, 65
  };
  const int q5150[] = {
    9, 9, // Number of jobs and machines
    5,  5, 0, 70, 8, 90, 2,  9, 3, 40, 4, 77, 6, 98, 7, 51, 1, 71, 
    7, 50, 1, 30, 0, 93, 5, 92, 4, 20, 8, 40, 3, 91, 6, 65, 2, 63, 
    5, 29, 0, 40, 2,  5, 1,  2, 4, 11, 3, 30, 6, 35, 8, 31, 7, 10, 
    3, 80, 7, 16, 5, 14, 4, 20, 6, 70, 0, 33, 1, 84, 8, 37, 2, 33, 
    3,  9, 5, 75, 8, 65, 6, 27, 2, 44, 0, 93, 7,  7, 4, 59, 1, 24, 
    6, 55, 5,  1, 2, 72, 1, 10, 3, 69, 0, 67, 4, 33, 8, 93, 7, 90, 
    7, 39, 2, 12, 8, 95, 4, 93, 3, 75, 6,  3, 5,  9, 1, 19, 0, 97, 
    4, 78, 7, 15, 8, 72, 6, 30, 2, 88, 3, 80, 5, 91, 1, 17, 0, 71, 
    1, 59, 4, 60, 8, 78, 2, 92, 3, 33, 5, 41, 6, 94, 0, 41, 7, 31
  };
  const int q5151[] = {
    9, 9, // Number of jobs and machines
    3, 11, 6, 35, 7, 90, 4, 35, 0, 94, 2, 76, 8, 73, 1, 76, 5, 97, 
    1, 12, 3, 66, 2, 56, 6, 12, 8, 11, 0, 85, 5, 67, 7, 41, 4, 77, 
    4, 80, 8,  9, 7, 87, 2, 82, 1, 73, 6, 53, 0, 28, 3, 96, 5, 89, 
    4, 59, 2, 26, 3, 84, 5, 18, 0,  2, 6, 97, 1, 24, 7, 51, 8, 38, 
    7,  8, 8, 68, 5,  6, 6,  9, 0, 54, 4, 23, 1,  5, 3, 55, 2, 46, 
    7, 35, 4, 78, 3, 39, 8, 51, 0, 41, 1, 74, 6, 65, 5, 78, 2, 58, 
    0, 99, 7, 20, 6, 17, 4, 30, 1, 47, 3, 94, 2, 85, 5, 47, 8, 94, 
    6, 69, 0, 23, 3, 75, 4, 72, 5, 76, 8, 38, 1, 62, 7, 95, 2, 67, 
    1, 78, 4, 12, 0, 78, 3, 74, 2, 64, 7,  9, 8, 57, 5, 94, 6, 15
  };
  const int q5152[] = {
    9, 9, // Number of jobs and machines
    0, 57, 5,  4, 1, 77, 8, 39, 3, 43, 7, 35, 6, 56, 4, 88, 2, 88, 
    3, 47, 2, 90, 0, 19, 1, 38, 4, 41, 7, 31, 6, 19, 8, 74, 5, 65, 
    0, 17, 4, 59, 6, 41, 5,  4, 1, 19, 2, 28, 3, 15, 8, 44, 7, 39, 
    1, 76, 3, 10, 8, 75, 5, 81, 7, 16, 6, 69, 0, 68, 2, 74, 4, 60, 
    5, 89, 4, 14, 8, 18, 7, 81, 6, 95, 2, 26, 3, 78, 0, 19, 1, 88, 
    7, 35, 3, 56, 8, 64, 4, 10, 0, 41, 2, 71, 1, 84, 5, 29, 6,  4, 
    0, 88, 5, 44, 1, 43, 8, 77, 3, 91, 4, 75, 6, 32, 7, 41, 2, 90, 
    4, 85, 5, 43, 1, 40, 0,  8, 3, 70, 8, 52, 7, 68, 6, 84, 2,  4, 
    7, 42, 4, 85, 0, 83, 6, 63, 3, 53, 2, 78, 5, 40, 1, 60, 8, 44
  };
  const int q5153[] = {
    9, 9, // Number of jobs and machines
    5, 70, 4, 62, 1, 62, 7, 54, 0, 76, 6, 81, 2, 32, 8, 93, 3, 46, 
    8, 77, 0, 20, 2, 71, 6, 84, 5, 54, 4, 45, 7, 67, 1, 22, 3,  5, 
    7, 98, 1,  6, 8, 22, 3, 70, 5, 86, 6, 34, 0, 26, 2, 11, 4, 52, 
    2, 73, 1, 22, 6, 99, 3, 74, 8, 38, 5, 58, 0, 82, 4, 64, 7, 68, 
    7, 47, 4, 66, 1, 73, 8, 53, 5, 69, 2, 97, 0, 46, 6, 39, 3, 66, 
    1, 40, 2, 79, 4, 63, 6, 58, 3, 50, 7, 41, 0, 85, 5, 52, 8, 76, 
    4, 83, 7, 47, 3, 28, 0, 81, 2, 70, 5, 40, 8, 69, 6, 10, 1, 95, 
    1, 82, 7, 97, 4, 37, 5, 86, 8, 15, 2,  6, 6, 58, 3, 39, 0, 99, 
    2, 93, 8, 35, 4, 23, 6, 15, 5, 24, 3, 64, 7, 68, 0, 31, 1, 50
  };
  const int q5154[] = {
    9, 9, // Number of jobs and machines
    5, 79, 7,  1, 1,  8, 6, 27, 0, 94, 8, 60, 4, 96, 3, 47, 2, 31, 
    3, 48, 2, 59, 5, 55, 1,  7, 4, 21, 7, 79, 8, 50, 0,  1, 6, 46, 
    3,  6, 2, 35, 4, 18, 1, 75, 6, 51, 7, 33, 5, 85, 8, 51, 0, 77, 
    3, 29, 8, 29, 2, 81, 0, 63, 4, 42, 5, 87, 1, 37, 7, 67, 6, 93, 
    1, 15, 3, 34, 0, 77, 2, 85, 5, 49, 7, 57, 8, 25, 4, 85, 6, 69, 
    6, 58, 8, 21, 5, 29, 4, 46, 3, 12, 1, 62, 0, 59, 2, 35, 7, 12, 
    7, 36, 6, 83, 0, 40, 8, 97, 1, 61, 3,  4, 2, 68, 4, 60, 5,  4, 
    7, 44, 3, 21, 0, 40, 1, 23, 6, 77, 5, 25, 2, 41, 8, 87, 4, 41, 
    2, 78, 6, 35, 0, 43, 1, 90, 4, 25, 7, 22, 5, 10, 8, 14, 3,  3
  };
  const int q5155[] = {
    9, 9, // Number of jobs and machines
    3, 33, 7, 40, 6, 94, 0, 91, 2, 60, 5, 82, 4,  6, 1, 61, 8, 42, 
    1, 10, 4, 58, 3, 44, 6,  4, 2, 25, 8, 66, 0, 36, 5, 53, 7,  2, 
    2, 22, 1, 34, 0, 97, 7, 87, 3, 96, 4, 80, 6, 54, 8, 80, 5, 75, 
    3, 20, 8, 43, 2, 30, 6, 72, 1,  2, 4, 58, 7, 13, 5, 87, 0, 93, 
    1, 13, 4, 67, 7, 88, 8, 45, 5, 77, 6,  4, 2, 84, 3, 36, 0, 79, 
    0, 77, 7, 94, 2, 67, 3, 59, 1, 79, 8, 58, 6, 60, 5, 29, 4, 15, 
    0, 70, 4, 82, 6, 61, 7, 52, 2, 65, 3, 82, 5, 12, 8, 53, 1, 33, 
    5, 10, 0, 36, 7, 60, 2, 40, 1, 62, 8, 68, 4, 88, 6, 54, 3, 92, 
    6, 98, 0, 47, 3,  6, 2,  9, 7, 53, 1, 83, 8, 64, 5, 19, 4, 76
  };
  const int q5156[] = {
    9, 9, // Number of jobs and machines
    7, 20, 8, 79, 1, 82, 0, 94, 6, 14, 4, 39, 5, 91, 2, 89, 3, 17, 
    2,  3, 3,  9, 8, 70, 0, 89, 6, 11, 7, 52, 1, 19, 5, 45, 4, 18, 
    5, 98, 7, 77, 3, 40, 2, 27, 0, 18, 8, 53, 1, 84, 4,  8, 6, 36, 
    4,  2, 7, 83, 3,  2, 1,  7, 0, 62, 6, 51, 8, 53, 2, 17, 5, 16, 
    0, 84, 7, 53, 2, 25, 5,  7, 4, 78, 3, 51, 8,  9, 6, 30, 1, 85, 
    6, 64, 3, 33, 1, 24, 2, 50, 5, 51, 7, 64, 8, 93, 0, 59, 4, 68, 
    5, 25, 0, 43, 4, 19, 2, 15, 8, 21, 1, 82, 6,  8, 3,  8, 7, 17, 
    6,  5, 2, 71, 3, 43, 8, 70, 7, 95, 0,  5, 4, 40, 1, 10, 5, 94, 
    1, 67, 4, 77, 7, 95, 5, 37, 6, 99, 8, 16, 3, 46, 2, 71, 0, 89
  };
  const int q5157[] = {
    9, 9, // Number of jobs and machines
    6, 16, 2, 29, 0, 30, 4,  6, 8, 63, 7, 63, 5, 93, 1, 95, 3, 88, 
    8, 77, 5, 30, 6, 88, 3, 32, 1, 58, 7, 94, 4, 63, 2, 59, 0, 54, 
    1, 46, 8,  9, 3, 34, 4, 99, 5, 59, 2, 57, 7, 20, 0, 50, 6, 72, 
    0, 36, 1, 98, 2, 68, 6, 63, 8, 37, 7, 41, 3,  6, 4,  6, 5, 41, 
    2, 64, 5, 85, 0, 78, 6, 54, 8,  8, 3, 74, 7, 96, 4, 35, 1, 20, 
    3, 68, 8,  2, 2, 15, 4, 69, 7, 46, 5, 26, 1, 78, 6, 40, 0, 92, 
    7, 47, 3, 11, 6, 44, 8, 88, 2, 80, 4, 31, 0, 99, 5, 90, 1, 80, 
    8, 28, 0, 90, 6, 43, 3, 53, 7, 72, 1, 88, 4, 59, 5, 39, 2, 99, 
    3, 57, 6, 73, 4, 97, 7, 43, 5, 54, 1, 63, 0, 64, 2, 89, 8, 80
  };
  const int q5158[] = {
    9, 9, // Number of jobs and machines
    7, 47, 1, 49, 3,  4, 6, 54, 4, 25, 2,  2, 8, 45, 0, 50, 5, 82, 
    0, 86, 4, 74, 7, 21, 1, 37, 6, 56, 8, 91, 5, 47, 2, 27, 3, 73, 
    7, 83, 4, 66, 5, 58, 1, 84, 2, 36, 6, 95, 0, 51, 3, 73, 8, 73, 
    0, 58, 7, 56, 1, 55, 2, 30, 6, 34, 8, 67, 5, 62, 4, 29, 3, 62, 
    3, 55, 6, 16, 5, 41, 1, 18, 7, 50, 0, 50, 8, 69, 4, 52, 2, 64, 
    1, 19, 0, 10, 4, 47, 8, 31, 5, 90, 2, 98, 7, 44, 3, 29, 6, 59, 
    6, 54, 1,  7, 0, 56, 2, 61, 3, 44, 8, 29, 5, 63, 7, 60, 4, 40, 
    8, 88, 7, 32, 4, 44, 5, 80, 6, 50, 3, 58, 2, 65, 1,  5, 0,  2, 
    2, 28, 1, 28, 0, 53, 4, 87, 7, 10, 6, 61, 8, 45, 3, 99, 5, 20
  };
  const int q5159[] = {
    9, 9, // Number of jobs and machines
    4, 69, 3, 59, 8, 35, 6, 38, 0, 12, 7, 79, 5, 33, 2, 75, 1, 41, 
    0, 66, 6, 41, 7, 80, 8, 19, 3, 33, 1, 92, 4, 57, 5,  3, 2, 49, 
    3, 90, 7, 89, 6, 95, 5, 83, 8, 69, 0, 42, 4,  2, 1, 85, 2, 71, 
    4, 96, 5, 68, 2, 33, 8, 66, 3, 31, 6, 24, 7, 67, 1, 88, 0, 66, 
    1, 37, 3,  5, 0, 20, 6, 72, 4, 38, 7,  6, 8,  2, 5, 79, 2, 86, 
    4, 93, 0, 95, 1, 52, 5, 54, 6, 51, 7, 31, 3, 26, 2, 46, 8, 44, 
    8, 80, 4, 22, 0, 25, 3, 73, 7, 52, 6, 20, 2, 28, 1, 39, 5, 49, 
    7,  4, 2, 45, 0, 14, 3, 49, 1, 13, 4, 73, 8, 16, 6,  3, 5, 98, 
    8, 16, 4, 33, 2, 23, 1, 98, 7, 60, 6, 63, 3, 99, 0, 67, 5, 83
  };
  const int q5160[] = {
    9, 9, // Number of jobs and machines
    4, 51, 2, 84, 5, 85, 7, 90, 3, 59, 0, 96, 6, 70, 8, 77, 1, 65, 
    2, 72, 1, 30, 7, 24, 6, 88, 5, 71, 4, 87, 8, 59, 3, 86, 0, 95, 
    6, 22, 0, 23, 7, 50, 1, 68, 4, 61, 3, 86, 2,  7, 8, 83, 5, 51, 
    0, 61, 7,  2, 6, 14, 2, 18, 3, 35, 8, 55, 5, 76, 1, 67, 4,  4, 
    2, 94, 3,  9, 5, 41, 1, 33, 6, 28, 0, 13, 4,  1, 7, 65, 8, 16, 
    6,  4, 1, 78, 7, 63, 0, 46, 8,  7, 5, 88, 4, 62, 3, 46, 2,  5, 
    3, 27, 2, 72, 6,  6, 4, 89, 8,  5, 5, 18, 1, 68, 7,  9, 0, 96, 
    0, 93, 1, 74, 5, 32, 3, 75, 7, 68, 4, 63, 8, 18, 2, 55, 6, 10, 
    0, 53, 3, 22, 8, 59, 4, 11, 7, 85, 2, 83, 6, 68, 1, 94, 5, 47
  };
  const int q5161[] = {
    9, 9, // Number of jobs and machines
    1, 40, 4,  6, 5,  1, 6, 11, 0, 82, 7, 79, 2, 16, 8, 12, 3,  3, 
    4,  3, 5, 60, 6, 29, 1, 17, 8, 46, 2, 49, 7, 76, 3, 47, 0, 24, 
    3,  6, 4,  6, 8, 84, 0, 28, 6,  4, 1, 48, 7, 84, 5, 23, 2,  8, 
    3, 74, 5,  7, 7, 56, 2, 94, 8, 25, 0,  8, 6, 40, 1, 85, 4, 93, 
    8, 78, 5, 91, 7, 73, 2, 52, 0, 79, 6, 88, 1, 34, 4, 15, 3, 49, 
    0, 13, 1, 37, 8, 84, 2,  4, 7, 53, 4, 29, 5, 75, 6, 21, 3, 19, 
    1, 60, 6,  5, 8, 42, 4, 16, 5, 23, 0,  3, 3, 32, 7, 50, 2, 97, 
    8, 47, 5, 75, 7, 53, 0, 74, 4, 50, 6, 79, 3, 56, 2, 37, 1, 48, 
    4, 21, 1, 37, 0, 65, 7, 18, 2,  9, 8, 36, 5, 88, 6,  4, 3, 90
  };
  const int q5162[] = {
    9, 9, // Number of jobs and machines
    2, 50, 1, 49, 8, 59, 0, 24, 4, 49, 3, 80, 6, 75, 5, 36, 7, 30, 
    7, 95, 2, 84, 3, 12, 4, 19, 5, 80, 6, 53, 1, 21, 8,  4, 0, 19, 
    5, 50, 0,  9, 1, 70, 7, 13, 3, 58, 2, 67, 6, 53, 8, 84, 4, 16, 
    3, 81, 0, 72, 2,  2, 8, 46, 4, 68, 1, 81, 5, 24, 6, 49, 7, 38, 
    4, 24, 0,  5, 2, 54, 3, 27, 6, 41, 8, 15, 7, 33, 1, 47, 5, 86, 
    5, 21, 8, 41, 4, 76, 6, 76, 0, 45, 2, 71, 7, 45, 1, 18, 3, 44, 
    2, 44, 1, 41, 3, 25, 6,  2, 7, 50, 4, 54, 8,  2, 5, 70, 0, 98, 
    2, 43, 3, 90, 7, 55, 4, 43, 1, 52, 0, 43, 5,  4, 8, 79, 6, 22, 
    8,  8, 4, 80, 1, 90, 5, 47, 0, 78, 2, 48, 7, 52, 6, 81, 3, 20
  };
  const int q5163[] = {
    9, 9, // Number of jobs and machines
    3, 53, 1, 22, 6, 71, 7, 47, 0, 96, 8, 67, 4, 11, 5, 27, 2, 80, 
    1, 87, 0, 25, 8, 89, 4, 49, 7, 87, 2, 86, 5,  3, 6, 54, 3, 31, 
    5, 64, 8, 57, 4,  4, 6, 50, 2, 94, 3, 65, 7, 72, 0, 35, 1, 45, 
    8, 32, 0, 40, 5, 52, 6, 61, 4, 91, 1, 91, 7, 10, 3, 37, 2, 17, 
    5, 99, 7, 50, 0, 80, 6, 18, 3, 50, 4, 72, 8, 25, 2, 51, 1, 49, 
    0, 62, 6, 69, 1, 75, 3,  7, 5, 97, 2, 24, 7, 65, 4, 17, 8, 64, 
    5, 22, 1, 87, 8, 69, 7, 59, 0, 92, 2, 74, 4, 96, 3, 16, 6, 16, 
    3,  5, 4, 51, 1, 16, 2, 80, 0, 20, 7, 97, 5, 14, 6, 44, 8, 89, 
    7, 22, 2, 43, 6, 28, 8, 64, 3, 18, 4, 45, 0, 10, 1, 24, 5, 21
  };
  const int q5164[] = {
    9, 9, // Number of jobs and machines
    4, 13, 8, 90, 2, 63, 5, 56, 3, 47, 1, 94, 6, 71, 0, 47, 7, 97, 
    2, 75, 6, 49, 3, 77, 1, 40, 0, 42, 7, 85, 5, 62, 4, 10, 8, 58, 
    5, 37, 7, 12, 0, 75, 6, 87, 2, 35, 8,  8, 3, 84, 4, 55, 1, 93, 
    8, 65, 2, 70, 4, 30, 0, 54, 6, 40, 5, 29, 1, 61, 3, 66, 7, 99, 
    0,  5, 2, 64, 4, 34, 1, 98, 6, 91, 5, 10, 7, 28, 3, 81, 8, 54, 
    5, 29, 6, 19, 4, 25, 8, 18, 1, 93, 2, 36, 7, 17, 0, 92, 3, 34, 
    2, 59, 4, 43, 3, 32, 5, 64, 0, 33, 1, 40, 8, 91, 7, 30, 6, 52, 
    5, 74, 7, 49, 6, 70, 1, 57, 8, 72, 4, 51, 3, 96, 0,  1, 2, 61, 
    4, 35, 3, 50, 8, 78, 7, 66, 1, 57, 6, 47, 2, 79, 0, 43, 5, 10
  };
  const int q5165[] = {
    9, 9, // Number of jobs and machines
    5, 66, 7, 75, 4, 11, 1, 59, 8, 94, 0, 60, 6, 40, 2, 93, 3, 94, 
    3, 41, 8, 51, 2, 79, 4, 13, 6, 63, 0, 47, 7, 72, 5, 96, 1, 82, 
    7, 52, 5, 11, 4, 26, 3, 86, 6, 65, 0, 48, 2, 86, 1, 35, 8, 79, 
    6, 92, 3,  9, 1, 56, 4, 62, 5, 44, 7,  5, 2, 73, 0, 21, 8, 34, 
    7, 25, 0,  1, 6, 33, 4, 88, 3, 68, 5, 17, 2, 25, 1, 88, 8, 43, 
    6, 29, 7, 42, 5, 35, 8, 71, 4, 88, 3, 14, 1, 24, 0, 51, 2, 38, 
    8, 14, 3, 43, 6, 71, 1, 43, 4, 12, 5, 15, 0, 52, 7, 16, 2, 70, 
    0, 25, 1, 38, 2, 39, 4, 51, 8, 65, 5,  9, 7, 60, 3, 73, 6, 12, 
    7, 49, 5, 70, 4,  4, 6, 94, 0, 28, 8, 70, 1, 98, 2, 41, 3, 55
  };
  const int q5166[] = {
    9, 9, // Number of jobs and machines
    8, 89, 0, 41, 2, 92, 4, 59, 7, 85, 3, 95, 1, 45, 5, 12, 6, 92, 
    7, 50, 3, 15, 6, 53, 1, 35, 5, 60, 4,  2, 2, 95, 8,  9, 0, 13, 
    1, 75, 5, 81, 3, 44, 2,  6, 6, 68, 7, 82, 0, 17, 4, 20, 8, 22, 
    7, 76, 2, 58, 3,  3, 6, 85, 1, 88, 0, 68, 8, 14, 4, 24, 5, 98, 
    8, 48, 1, 21, 0,  2, 5, 89, 3, 42, 2, 10, 6, 40, 4, 63, 7, 48, 
    6, 84, 5, 67, 1, 64, 2, 50, 7, 77, 4, 44, 3, 37, 8, 87, 0, 24, 
    6, 23, 2, 78, 3, 38, 1,  1, 0, 77, 8, 53, 7, 91, 5, 59, 4, 69, 
    4, 36, 1, 80, 6, 41, 2, 51, 5, 20, 7, 38, 3,  6, 8, 89, 0, 18, 
    0, 59, 1, 64, 7, 93, 4, 14, 6, 27, 2, 74, 8, 48, 3, 55, 5,  7
  };
  const int q5167[] = {
    9, 9, // Number of jobs and machines
    8, 22, 1, 82, 3, 74, 2, 97, 0, 92, 7, 37, 6, 35, 5, 12, 4, 30, 
    3, 47, 8, 37, 2, 56, 5, 32, 0, 56, 6, 71, 1, 28, 7, 57, 4, 91, 
    7, 35, 3, 94, 8, 51, 6,  1, 1, 35, 0, 72, 5, 88, 4, 26, 2, 77, 
    7, 91, 4,  5, 3, 17, 2, 31, 6, 49, 5, 14, 1,  8, 0, 84, 8, 59, 
    2, 31, 7, 76, 5, 20, 1, 86, 4, 85, 8, 28, 0, 31, 6, 56, 3, 66, 
    8, 41, 1,  5, 7, 40, 4, 13, 0, 82, 5, 19, 3, 76, 6, 81, 2, 95, 
    5, 83, 1, 58, 2, 54, 7, 40, 3, 28, 0, 83, 4, 45, 8, 89, 6, 44, 
    4, 29, 0, 24, 3, 72, 1,  2, 6, 77, 5, 32, 7, 73, 2, 40, 8, 84, 
    2, 29, 3, 54, 7, 14, 6, 30, 5, 57, 0, 46, 8, 76, 4,  9, 1, 74
  };
  const int q5168[] = {
    9, 9, // Number of jobs and machines
    5,  7, 7,  8, 1, 13, 6,  8, 0, 24, 4, 18, 8, 57, 3, 49, 2, 77, 
    3, 50, 8, 64, 1, 64, 7, 29, 2, 68, 0, 44, 5, 93, 4, 31, 6, 41, 
    8, 18, 5, 23, 7, 37, 4, 63, 6, 15, 3, 36, 2, 56, 1, 16, 0, 51, 
    4, 81, 6, 96, 2, 46, 7, 33, 5, 51, 8,  9, 0, 14, 1, 98, 3, 36, 
    4, 53, 8,  7, 1, 17, 2, 14, 3, 56, 6, 68, 5, 68, 7, 22, 0, 66, 
    1,  8, 2, 83, 7, 83, 8, 99, 0, 36, 5, 89, 3,  3, 6, 91, 4, 87, 
    7, 19, 1, 23, 8, 92, 5, 28, 6, 50, 2, 77, 3, 89, 4, 84, 0,  8, 
    2, 95, 3, 39, 7, 52, 4,  1, 0, 21, 5, 82, 6, 87, 8, 73, 1, 82, 
    6, 49, 2, 64, 0,  3, 7, 17, 4, 76, 3, 61, 1, 90, 5, 95, 8,  7
  };
  const int q5169[] = {
    9, 9, // Number of jobs and machines
    1, 33, 6, 99, 3,  3, 0, 39, 2, 44, 5, 70, 7,  3, 8, 24, 4, 35, 
    5, 56, 2, 94, 1, 41, 4, 72, 7, 76, 0, 45, 8, 10, 3, 30, 6, 35, 
    6, 80, 5, 39, 3, 68, 2, 91, 8, 30, 4, 67, 0, 59, 1, 50, 7, 48, 
    4, 74, 0, 71, 7, 74, 5, 35, 6, 73, 3, 32, 2, 48, 1, 68, 8, 79, 
    5, 56, 0, 21, 8, 60, 7,  4, 1, 79, 2, 62, 3, 63, 4, 68, 6, 45, 
    0, 23, 2, 75, 5, 63, 4, 17, 1, 61, 7, 61, 8, 75, 6, 49, 3,  6, 
    3, 68, 7, 46, 1, 42, 6, 35, 8, 45, 0, 27, 5, 30, 2, 58, 4, 37, 
    7, 52, 8, 40, 6, 21, 1, 16, 5, 77, 2, 82, 0, 39, 4, 43, 3, 35, 
    7, 75, 1, 60, 8, 70, 2, 86, 0, 86, 6,  2, 3, 23, 4, 22, 5, 75
  };
  const int q5170[] = {
    9, 9, // Number of jobs and machines
    0, 51, 3, 64, 4, 51, 2, 75, 8, 86, 6, 82, 5, 15, 1, 30, 7, 24, 
    5, 12, 2, 52, 3, 61, 4, 61, 7, 93, 0, 21, 8, 42, 6, 21, 1, 19, 
    1, 94, 0, 24, 3, 91, 6, 67, 4, 48, 7, 37, 2, 64, 8, 68, 5, 38, 
    7, 20, 6, 16, 5, 77, 4, 90, 1,  1, 2, 74, 3, 75, 0, 19, 8, 32, 
    2, 31, 0, 75, 3, 27, 5,  3, 1, 81, 7, 46, 8, 48, 6, 68, 4, 61, 
    4, 63, 6, 91, 5, 53, 1, 53, 3,  8, 2, 99, 0, 73, 7,  9, 8, 44, 
    1, 54, 0, 93, 3, 20, 6, 17, 5, 22, 2, 63, 7, 13, 4, 18, 8, 63, 
    5, 42, 1,  9, 3,  9, 7,  2, 8, 82, 6, 45, 0, 30, 2, 34, 4, 76, 
    4, 39, 6, 74, 3, 96, 8, 42, 2, 67, 1, 18, 7, 34, 0, 76, 5, 88
  };
  const int q5171[] = {
    9, 9, // Number of jobs and machines
    2, 93, 1, 39, 8, 39, 3, 85, 5, 39, 6, 35, 7,  9, 4, 61, 0, 91, 
    7, 74, 3, 74, 4, 33, 0, 41, 2, 17, 5, 87, 1, 33, 8, 58, 6, 35, 
    7, 23, 3, 84, 4,  5, 1, 29, 0, 27, 8, 15, 6, 60, 2, 55, 5, 51, 
    5, 36, 2, 52, 1, 68, 3, 34, 6, 68, 0, 88, 4, 18, 8, 37, 7, 84, 
    3, 80, 2, 78, 8, 17, 4, 80, 1, 75, 6, 86, 0, 12, 5, 97, 7, 21, 
    5,  4, 6, 87, 1, 63, 7, 93, 2, 85, 3, 73, 4, 38, 0, 23, 8, 60, 
    1, 80, 8,  9, 6, 41, 2,  2, 0, 33, 3, 43, 5, 27, 7, 36, 4, 87, 
    6, 44, 1, 46, 0, 68, 5, 80, 8, 90, 2, 70, 4, 86, 3, 38, 7,  9, 
    0, 75, 1, 58, 2, 13, 4, 47, 6, 89, 7, 63, 5, 74, 3, 54, 8, 99
  };
  const int q5172[] = {
    9, 9, // Number of jobs and machines
    3, 58, 8, 97, 7,  7, 6,  6, 4, 92, 5, 91, 1, 25, 2, 30, 0, 96, 
    7, 44, 6, 86, 3, 91, 4, 45, 1, 37, 5, 66, 2, 73, 0, 60, 8, 51, 
    6,  9, 3, 16, 4, 77, 7, 20, 0, 44, 5,  6, 1, 80, 8, 51, 2, 60, 
    4, 31, 5, 79, 2, 39, 3, 16, 0, 80, 6, 83, 1, 10, 8, 16, 7, 88, 
    5, 48, 2, 50, 8, 68, 3, 42, 4,  8, 1, 72, 7,  1, 6, 69, 0, 45, 
    0,  8, 1, 76, 4, 83, 5, 45, 7, 16, 2, 26, 6, 57, 3, 36, 8, 18, 
    4, 30, 3, 37, 8, 81, 0, 21, 6, 93, 7, 42, 2, 49, 1, 64, 5,  9, 
    7, 50, 8, 80, 1, 50, 3, 45, 5, 19, 0,  2, 4,  6, 6, 61, 2, 75, 
    3, 43, 1, 83, 5, 24, 4, 34, 8, 92, 7, 81, 0, 55, 6, 94, 2, 76
  };
  const int q5173[] = {
    9, 9, // Number of jobs and machines
    5,  5, 2, 24, 1, 59, 7, 12, 3, 86, 0, 81, 4, 92, 8, 99, 6, 92, 
    7, 36, 1, 71, 5, 37, 2, 19, 3, 48, 4, 46, 6, 34, 8,  7, 0, 49, 
    7,  7, 1, 17, 5, 76, 2, 65, 3, 57, 4,  8, 8, 74, 6, 82, 0, 76, 
    0, 66, 2, 79, 4, 75, 7, 38, 8, 60, 6, 81, 5, 23, 3, 71, 1, 96, 
    2, 95, 6, 89, 5, 37, 8, 81, 1,  3, 3, 86, 7,  5, 4, 35, 0, 77, 
    8, 15, 5, 67, 3, 34, 0, 74, 7, 78, 2, 39, 4, 31, 6, 23, 1, 23, 
    3, 18, 8, 33, 2, 90, 6, 98, 7, 75, 1, 22, 5, 13, 0, 13, 4, 57, 
    1, 28, 6, 96, 4, 74, 7, 72, 2, 29, 0, 21, 8, 98, 5, 39, 3, 94, 
    3, 11, 7, 14, 5, 82, 6, 13, 4, 64, 2, 38, 8, 60, 1, 84, 0,  1
  };
  const int q5174[] = {
    9, 9, // Number of jobs and machines
    2, 43, 6, 68, 5, 90, 0, 15, 3, 53, 7, 53, 4, 96, 8, 78, 1, 34, 
    0, 96, 4, 56, 2, 82, 1,  3, 3, 20, 8, 43, 6, 63, 5, 92, 7,  6, 
    8, 41, 5, 14, 0, 36, 7, 68, 3, 31, 2, 34, 4, 79, 1, 33, 6, 89, 
    3, 93, 1, 12, 2, 64, 4, 48, 8, 43, 0, 60, 5, 20, 6, 69, 7, 44, 
    7, 90, 8, 69, 3, 35, 6, 30, 0, 29, 5, 82, 1, 52, 4, 48, 2,  2, 
    6, 98, 3, 64, 4,  3, 5, 49, 8, 29, 0, 47, 1, 20, 7, 63, 2, 99, 
    2, 16, 3, 42, 6, 82, 0, 20, 5, 68, 8, 74, 7, 60, 4, 22, 1,  5, 
    4, 18, 0, 80, 6, 68, 5, 90, 7,  8, 2, 20, 1, 37, 3, 22, 8, 53, 
    6, 80, 7, 18, 4, 52, 3, 12, 5, 17, 1,  1, 2, 28, 0,  3, 8, 49
  };
  const int q5175[] = {
    9, 9, // Number of jobs and machines
    0, 97, 3, 98, 8, 80, 7, 43, 6, 50, 1, 77, 2, 69, 5, 95, 4, 90, 
    1, 32, 8, 93, 3,  2, 7, 82, 2, 80, 5, 13, 4, 71, 6,  5, 0,  4, 
    5, 58, 4,  8, 7,  7, 8, 20, 0, 90, 3,  5, 2, 64, 6, 86, 1, 60, 
    7, 45, 2, 36, 0, 40, 4, 40, 8, 51, 6, 10, 1, 29, 5, 61, 3, 97, 
    3, 40, 1, 58, 4, 99, 8, 56, 2, 67, 7, 62, 5,  8, 6, 75, 0, 63, 
    4, 16, 5, 19, 0, 39, 7, 12, 2,  7, 1, 75, 3, 52, 8, 71, 6, 65, 
    3,  5, 5, 92, 0, 12, 2, 52, 7, 72, 6, 52, 8, 47, 4, 34, 1,  4, 
    0, 44, 6, 73, 4, 66, 3, 28, 8, 92, 5, 14, 7, 92, 2,  7, 1, 37, 
    7, 41, 4, 82, 6, 34, 8, 97, 2, 97, 5, 78, 3,  8, 1,  2, 0, 79
  };
  const int q5176[] = {
    9, 9, // Number of jobs and machines
    3, 81, 0,  7, 8, 10, 1,  9, 2, 46, 4,  8, 5, 94, 7, 95, 6, 10, 
    7, 60, 3, 38, 8,  3, 2, 82, 6, 37, 5, 86, 0, 17, 1, 67, 4, 54, 
    4, 94, 3, 70, 7, 19, 2, 46, 5, 30, 6, 14, 8, 17, 0, 41, 1, 30, 
    3, 77, 4, 69, 6, 22, 0, 87, 1, 60, 5, 15, 7, 39, 8, 46, 2, 65, 
    1, 98, 4, 81, 3, 67, 6, 41, 2, 41, 5, 75, 8, 82, 7, 83, 0, 38, 
    0, 63, 4, 62, 8, 19, 5, 11, 3, 92, 6, 44, 7, 92, 1, 37, 2, 43, 
    4, 97, 7, 92, 3, 75, 1,  5, 2, 89, 5, 86, 0, 62, 8, 78, 6, 70, 
    5, 84, 8, 82, 0, 86, 6, 13, 7, 18, 4, 34, 1, 49, 3, 23, 2, 85, 
    1, 19, 0, 14, 8,  2, 3, 58, 5, 41, 4, 69, 7, 81, 2, 93, 6, 75
  };
  const int q5177[] = {
    9, 9, // Number of jobs and machines
    2, 65, 3,  1, 1, 12, 6, 25, 8,  5, 0, 56, 4, 53, 7, 72, 5, 14, 
    2, 60, 3, 92, 5, 82, 0,  2, 6, 90, 7, 83, 1, 26, 8, 80, 4, 24, 
    8, 61, 3, 10, 2, 90, 6, 63, 0, 82, 7,  9, 1, 12, 5, 60, 4, 42, 
    3, 78, 6, 98, 8, 17, 0, 89, 5, 53, 7, 77, 2, 16, 1,  8, 4, 71, 
    8, 98, 6, 71, 4, 89, 7, 22, 5, 58, 0, 23, 2, 33, 3, 71, 1, 86, 
    2, 35, 0, 23, 8, 25, 6, 12, 4, 85, 5, 55, 3, 23, 1, 81, 7, 59, 
    1, 12, 4, 31, 7, 72, 0, 56, 5, 76, 8, 33, 3, 73, 2, 64, 6, 13, 
    1, 35, 7, 59, 4, 41, 8, 94, 6, 87, 2, 45, 5, 25, 3, 13, 0, 76, 
    3, 60, 5, 69, 4, 83, 0, 72, 6, 97, 1, 90, 7, 82, 8, 70, 2, 36
  };
  const int q5178[] = {
    9, 9, // Number of jobs and machines
    4, 48, 5, 10, 0, 31, 8, 14, 7, 86, 3,  9, 1, 99, 6, 47, 2, 73, 
    4, 33, 1,  6, 8, 15, 0, 93, 2, 35, 5, 38, 7, 88, 3, 20, 6, 66, 
    8, 73, 6, 55, 4, 14, 2, 78, 0, 13, 7, 68, 5, 33, 3, 19, 1,  6, 
    3, 32, 5, 62, 4, 65, 8,  5, 0, 31, 7, 70, 2, 24, 1, 38, 6, 73, 
    0, 92, 6, 22, 7, 42, 5, 28, 4, 99, 2, 65, 1, 22, 3, 62, 8, 50, 
    1, 87, 3, 32, 5, 42, 8, 42, 0, 91, 6, 87, 2, 38, 7, 51, 4, 99, 
    7, 90, 4, 10, 5, 74, 2, 97, 8, 84, 6, 42, 3, 18, 1, 24, 0, 14, 
    8, 21, 7, 50, 6, 94, 3, 68, 5, 44, 2, 46, 4, 87, 1, 82, 0, 88, 
    8, 98, 0, 87, 7, 56, 4, 29, 1, 27, 3, 90, 5, 31, 6, 83, 2, 21
  };
  const int q5179[] = {
    9, 9, // Number of jobs and machines
    6, 62, 4, 12, 5, 76, 1, 27, 0, 55, 8, 32, 2, 25, 7, 39, 3, 44, 
    0,  6, 3, 76, 7, 95, 2, 23, 1, 63, 6, 35, 8, 88, 4, 52, 5, 56, 
    5, 50, 1, 63, 0, 29, 7, 59, 6, 22, 8, 85, 2, 64, 4, 38, 3, 49, 
    3, 49, 1, 87, 6, 95, 7, 33, 0, 75, 5, 98, 4, 67, 2,  2, 8, 79, 
    6,  5, 0, 35, 1, 82, 3, 49, 4, 49, 7, 29, 2, 99, 8, 37, 5, 86, 
    0,  9, 5,  9, 2, 31, 4, 61, 8, 95, 7, 87, 6, 51, 3, 90, 1, 80, 
    2, 56, 6, 66, 4, 61, 8, 20, 0, 24, 7, 60, 3, 42, 5, 82, 1, 83, 
    5, 99, 2, 23, 1, 51, 0, 93, 8,  7, 7, 99, 4, 94, 3, 17, 6, 30, 
    7, 17, 8, 58, 5, 22, 4, 99, 6, 91, 0,  3, 1, 30, 3, 16, 2, 65
  };
  const int q5180[] = {
    9, 9, // Number of jobs and machines
    5, 63, 3, 13, 7, 55, 1, 36, 2, 22, 8, 18, 6,  8, 4, 11, 0, 62, 
    1, 13, 6, 49, 0, 60, 5, 72, 8, 13, 4, 96, 3, 24, 7,  5, 2, 39, 
    5, 72, 7, 82, 4, 63, 2, 80, 1, 12, 8, 91, 0, 15, 3, 72, 6, 78, 
    8, 73, 5, 27, 3, 66, 1, 99, 2, 81, 4, 70, 7, 82, 6,  6, 0, 81, 
    4, 71, 6, 49, 3, 96, 5, 74, 8, 86, 2, 35, 0, 62, 7, 35, 1, 79, 
    3, 42, 4, 33, 5, 63, 7, 92, 0, 76, 6, 97, 8, 38, 2,  5, 1,  1, 
    2, 32, 3,  7, 5, 25, 6, 40, 4, 37, 8, 96, 0, 33, 7, 76, 1, 98, 
    5, 91, 1, 95, 4, 38, 6, 28, 7, 45, 3, 67, 0, 86, 8,  7, 2,  6, 
    4, 80, 2,  9, 6, 17, 3, 92, 8, 23, 7, 25, 0, 61, 1, 66, 5, 52
  };
  const int q5181[] = {
    9, 9, // Number of jobs and machines
    7, 68, 4, 67, 5,  5, 8, 43, 0, 73, 6, 47, 2, 29, 1, 46, 3, 30, 
    6, 10, 7,  5, 0, 11, 3,  5, 8, 66, 5,  9, 4, 12, 1, 65, 2, 36, 
    3, 14, 4, 60, 5, 81, 1, 32, 2, 34, 0, 49, 8,  7, 7, 52, 6, 35, 
    0, 48, 1, 68, 5, 99, 3, 33, 4,  6, 7, 41, 6, 96, 2,  1, 8, 92, 
    0, 11, 7, 94, 3, 82, 5,  8, 2, 20, 1, 64, 8, 75, 6, 78, 4, 41, 
    4, 49, 6, 31, 2, 14, 8, 20, 7, 73, 0,  4, 3, 39, 5, 12, 1,  2, 
    2, 97, 1,  8, 5, 15, 4, 59, 7, 96, 6, 34, 0, 27, 8, 60, 3, 36, 
    5, 32, 0, 68, 8, 80, 4, 77, 2, 36, 6, 11, 7, 85, 3, 66, 1,  3, 
    7, 12, 8, 66, 5, 58, 3, 73, 4, 12, 1, 20, 2, 86, 0, 65, 6, 42
  };
  const int q5182[] = {
    9, 9, // Number of jobs and machines
    6, 31, 4, 87, 0, 97, 8, 10, 2, 50, 3, 53, 1, 29, 7, 41, 5, 11, 
    5, 20, 2, 62, 3, 76, 7, 82, 1, 31, 6, 92, 4, 69, 8, 72, 0, 45, 
    0, 26, 1, 62, 3, 25, 5, 37, 6, 91, 8, 48, 7, 40, 4, 85, 2, 89, 
    6, 63, 3, 29, 7, 87, 8, 56, 1, 72, 0, 73, 5, 17, 2, 49, 4, 76, 
    8, 63, 6, 94, 1, 89, 3,  7, 0, 90, 7, 31, 2, 47, 5, 34, 4, 72, 
    5, 81, 4, 40, 1, 63, 8, 26, 0, 38, 6, 91, 7, 10, 3, 20, 2, 36, 
    7, 66, 5, 12, 1, 48, 4, 68, 2, 14, 6, 46, 0, 90, 3, 62, 8, 28, 
    3, 24, 2, 30, 7, 71, 5, 53, 1,  5, 8, 13, 0, 67, 6, 68, 4, 14, 
    1, 28, 6, 16, 2, 56, 3,  6, 7, 45, 4, 73, 5, 25, 8, 96, 0, 74
  };
  const int q5183[] = {
    9, 9, // Number of jobs and machines
    7, 37, 3,  6, 5, 70, 2, 86, 1, 43, 0, 84, 8, 11, 4, 93, 6, 19, 
    1, 57, 6, 53, 4, 85, 0, 55, 7, 75, 3, 64, 8, 68, 2, 53, 5,  2, 
    1, 37, 5, 16, 4,  8, 3, 73, 7, 69, 0, 78, 8, 46, 2, 50, 6, 44, 
    1, 51, 4, 89, 3, 76, 7, 18, 8, 95, 2, 45, 6, 63, 0, 57, 5, 58, 
    5, 62, 8, 72, 2,  6, 6, 56, 7, 76, 4, 95, 3, 15, 0, 46, 1, 21, 
    1, 55, 3, 78, 0, 37, 8, 23, 7, 81, 6,  2, 4, 13, 5, 96, 2, 44, 
    0, 73, 7, 53, 4, 28, 5, 23, 1, 89, 2,  5, 3, 49, 8, 52, 6,  2, 
    8, 50, 3, 10, 6, 72, 4, 75, 7, 61, 1,  3, 5, 58, 2, 42, 0,  4, 
    3, 57, 7,  9, 4, 90, 0, 26, 5, 21, 1, 77, 6, 86, 2, 61, 8, 84
  };
  const int q5184[] = {
    9, 9, // Number of jobs and machines
    7, 70, 5, 34, 0, 81, 3, 91, 2, 60, 6, 98, 4, 68, 1, 38, 8,  7, 
    5, 49, 8, 75, 7, 37, 6, 54, 3, 34, 0, 47, 1,  7, 2, 82, 4, 37, 
    7, 80, 6, 76, 8,  1, 3, 83, 0, 74, 5, 96, 2, 67, 1, 96, 4, 41, 
    7, 15, 4, 94, 8, 81, 1, 64, 5,  1, 0, 10, 2, 43, 3, 68, 6, 13, 
    0, 75, 3,  1, 8,  5, 7, 93, 6, 46, 5, 49, 1, 89, 4, 47, 2, 22, 
    3, 89, 5, 81, 0, 41, 7, 55, 1, 43, 6, 12, 4, 28, 2, 78, 8, 30, 
    0, 51, 1, 60, 2, 69, 3, 35, 7, 35, 4, 98, 8, 13, 5, 46, 6, 43, 
    4, 80, 0, 32, 5, 52, 3, 40, 8, 32, 1, 81, 2, 48, 7, 25, 6, 30, 
    1, 11, 8,  8, 0, 45, 7, 99, 3, 99, 2, 94, 6, 34, 5, 74, 4, 49
  };
  const int q5185[] = {
    9, 9, // Number of jobs and machines
    5, 94, 2, 98, 6, 20, 8, 81, 0, 61, 3,  8, 4, 43, 1, 62, 7, 63, 
    3, 30, 8, 31, 5, 81, 7, 89, 6, 22, 1, 51, 0, 36, 2, 99, 4, 52, 
    7, 72, 3, 49, 6, 27, 4, 81, 1, 54, 0, 55, 5, 74, 8, 77, 2, 38, 
    3, 19, 8, 19, 5, 74, 1, 67, 2,  7, 7, 20, 4, 81, 6, 18, 0, 43, 
    3, 25, 2, 44, 4, 55, 1, 34, 8, 71, 5, 67, 6, 19, 0, 67, 7, 55, 
    6, 52, 2, 64, 3, 60, 5, 26, 8, 59, 1, 80, 0, 38, 4, 10, 7,  8, 
    3, 42, 2, 56, 6, 78, 7, 26, 8, 33, 1, 74, 4, 58, 5, 33, 0,  6, 
    6, 20, 4, 14, 5, 32, 7, 94, 1, 83, 2,  1, 8, 69, 0, 92, 3, 61, 
    1, 49, 6, 83, 8, 24, 2, 57, 4, 42, 3, 48, 5, 86, 0, 77, 7, 27
  };
  const int q5186[] = {
    9, 9, // Number of jobs and machines
    1,  5, 6, 86, 7, 45, 0, 65, 5, 91, 4, 58, 2, 91, 3, 12, 8, 29, 
    2, 72, 0, 21, 6, 98, 8, 27, 1, 45, 3, 76, 7, 85, 5, 62, 4, 69, 
    6, 86, 3, 92, 1, 66, 0,  2, 8,  8, 5, 56, 7, 45, 2, 13, 4, 33, 
    2, 48, 4, 28, 8, 17, 1, 52, 5, 79, 0, 36, 6, 53, 7, 94, 3, 33, 
    1, 81, 8, 36, 3, 70, 5, 40, 0, 17, 4, 94, 7, 99, 2, 79, 6, 37, 
    3, 47, 2, 85, 1,  3, 4, 31, 8, 53, 6,  2, 0, 74, 7, 78, 5, 60, 
    5, 64, 3, 89, 4,  9, 7,  6, 8,  5, 1, 38, 0, 15, 6, 80, 2, 22, 
    6, 24, 2, 82, 0, 72, 5, 21, 1, 15, 4, 82, 3, 58, 8, 95, 7, 75, 
    3, 19, 5, 63, 6, 32, 4, 21, 2, 47, 7, 49, 8, 90, 0, 97, 1, 42
  };
  const int q5187[] = {
    9, 9, // Number of jobs and machines
    6, 78, 4, 74, 2, 81, 3, 57, 1,  1, 0, 55, 8, 29, 5, 61, 7, 25, 
    5, 17, 7, 93, 2, 23, 6, 59, 8, 10, 0, 47, 3, 86, 4, 92, 1, 47, 
    1, 89, 4, 45, 2, 37, 3, 56, 5, 38, 0, 20, 8, 63, 6, 16, 7, 67, 
    2, 13, 4, 88, 3, 24, 1, 13, 7, 28, 0, 74, 6, 88, 5, 42, 8, 81, 
    6, 72, 2, 82, 1, 11, 3, 50, 7, 24, 8, 60, 4, 53, 5, 58, 0, 89, 
    2,  7, 0, 61, 5, 97, 7, 64, 1, 27, 4, 86, 8,  1, 6, 81, 3, 32, 
    8, 87, 4, 23, 6, 88, 0, 97, 3, 25, 5, 21, 7, 71, 1, 56, 2, 53, 
    8, 38, 2, 90, 1, 80, 3, 27, 7, 91, 0, 49, 4,  2, 5, 79, 6, 94, 
    5, 85, 0,  1, 8, 68, 4, 49, 7, 14, 3, 59, 1,  4, 6, 53, 2, 73
  };
  const int q5188[] = {
    9, 9, // Number of jobs and machines
    4, 50, 7, 64, 0, 33, 5, 25, 1, 78, 8, 95, 3, 14, 2, 54, 6, 49, 
    5, 83, 0, 95, 7, 29, 1, 30, 2, 31, 4, 50, 6, 96, 8, 17, 3, 42, 
    2, 29, 3, 19, 1, 82, 7, 26, 6, 85, 4, 40, 0, 31, 8, 36, 5, 67, 
    1, 85, 2, 47, 0, 96, 7, 49, 6, 10, 5, 36, 3, 58, 8, 80, 4, 76, 
    3, 96, 7, 81, 0, 76, 8, 87, 5, 65, 1, 79, 4,  9, 6, 61, 2, 89, 
    5, 62, 2, 60, 7, 44, 6, 57, 0, 33, 4, 44, 8, 20, 3, 10, 1, 24, 
    7, 57, 0, 70, 3, 22, 5, 38, 6, 40, 1, 61, 4, 31, 8, 84, 2, 50, 
    4, 78, 1, 93, 7, 29, 8, 22, 2, 77, 5, 95, 6, 24, 3,  8, 0, 94, 
    2, 34, 4, 20, 1, 97, 5, 23, 0, 90, 7,  8, 8, 44, 3, 47, 6, 43
  };
  const int q5189[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 31, 0, 22, 3, 82, 8, 45, 7, 94, 6, 84, 5,  1, 1, 29, 
    6, 24, 5, 22, 4, 48, 0, 97, 7, 91, 3, 22, 1, 68, 2, 71, 8, 72, 
    6, 10, 0, 95, 2, 33, 3, 54, 1, 65, 8, 22, 4, 23, 5, 86, 7, 12, 
    2, 10, 4, 20, 3, 23, 8, 79, 1, 26, 7, 58, 5, 63, 0, 23, 6, 74, 
    6, 31, 3, 95, 4, 77, 8, 80, 2, 18, 7, 62, 1, 86, 5, 89, 0, 60, 
    2, 41, 3, 59, 8,  8, 5, 13, 6, 15, 0, 63, 1, 19, 4, 24, 7, 56, 
    1, 86, 5, 45, 7, 49, 2, 79, 8, 54, 6, 62, 3, 54, 0, 34, 4, 39, 
    4, 63, 8, 56, 6, 68, 2, 14, 0, 34, 7, 54, 3, 44, 1, 78, 5, 76, 
    4, 29, 8, 24, 2, 60, 6, 75, 5, 94, 3, 70, 0, 87, 1, 57, 7, 77
  };
  const int q5190[] = {
    9, 9, // Number of jobs and machines
    0, 56, 1, 17, 3, 67, 2, 76, 5, 30, 7, 92, 8, 81, 6, 14, 4, 64, 
    7, 46, 1, 95, 5, 89, 4, 85, 3, 72, 0, 23, 6, 19, 8, 80, 2, 62, 
    4, 79, 3, 31, 7, 42, 2, 19, 0, 65, 6, 19, 8, 83, 1, 84, 5, 29, 
    4, 91, 8, 45, 3, 17, 1,  7, 7, 62, 0, 71, 5, 30, 2, 96, 6, 60, 
    6, 11, 2, 61, 8, 57, 5, 34, 3, 75, 4, 32, 1,  5, 7, 75, 0, 13, 
    7,  7, 4,  8, 3, 17, 8, 85, 5, 46, 1,  8, 2, 54, 6, 82, 0,  5, 
    5, 86, 8, 90, 2, 45, 4, 83, 3, 37, 1, 76, 6, 63, 0, 18, 7, 97, 
    3, 29, 5, 70, 2, 93, 1, 26, 8, 97, 0, 15, 4, 59, 7, 34, 6, 19, 
    0,  1, 1, 73, 7, 25, 5, 46, 4, 69, 6, 75, 8, 33, 3, 74, 2, 90
  };
  const int q5191[] = {
    9, 9, // Number of jobs and machines
    3, 79, 2, 12, 0, 12, 7, 62, 6, 40, 5, 83, 1, 91, 4, 11, 8, 16, 
    8, 30, 5, 46, 4, 15, 7, 60, 2, 41, 6, 47, 3, 23, 1, 74, 0,  5, 
    6, 80, 3, 12, 1, 94, 5, 78, 8, 77, 4, 71, 2, 12, 0, 56, 7, 22, 
    8, 49, 2, 63, 7, 31, 5, 44, 4, 39, 1, 30, 6, 97, 3, 40, 0, 54, 
    3, 99, 2, 74, 7, 99, 8, 39, 1, 58, 4, 70, 5, 87, 6, 25, 0, 27, 
    2, 48, 1, 64, 5, 58, 6, 91, 4, 31, 0,  5, 8, 35, 7, 73, 3, 23, 
    4, 89, 2, 93, 1, 36, 3, 89, 0,  7, 5, 93, 7, 55, 8, 30, 6, 81, 
    5, 96, 2, 95, 6,  1, 0, 18, 1, 22, 4, 99, 7, 97, 3,  9, 8, 87, 
    1, 80, 3,  3, 4, 58, 5, 40, 6, 79, 0, 42, 7, 93, 8, 20, 2, 55
  };
  const int q5192[] = {
    9, 9, // Number of jobs and machines
    5, 81, 8, 16, 0, 16, 7, 88, 2, 90, 6, 64, 1, 30, 4, 53, 3, 55, 
    8, 52, 7, 33, 3, 52, 2, 70, 6, 62, 5, 76, 1, 17, 4, 34, 0, 22, 
    4, 32, 8, 57, 0, 46, 7, 21, 6, 33, 1, 28, 3, 95, 5,  1, 2, 50, 
    3, 25, 5, 26, 1, 29, 4,  3, 8, 63, 7, 84, 0, 75, 6, 50, 2,  6, 
    8, 32, 5, 66, 2, 88, 6,  4, 4, 10, 7, 27, 1, 59, 3, 73, 0, 47, 
    0, 58, 4,  1, 8, 97, 5, 13, 7, 15, 6, 54, 1, 47, 3, 12, 2, 98, 
    4, 45, 6, 41, 8, 68, 0, 71, 5, 53, 3, 30, 1, 55, 7, 68, 2, 54, 
    4, 43, 3, 30, 0, 86, 2, 85, 8, 12, 7, 83, 1, 95, 6, 10, 5, 23, 
    6, 69, 1, 74, 5,  3, 7, 16, 3, 65, 2, 49, 8, 63, 4, 40, 0, 74
  };
  const int q5193[] = {
    9, 9, // Number of jobs and machines
    2, 42, 6, 27, 5, 27, 0, 59, 7, 54, 8,  6, 4, 42, 1, 42, 3, 70, 
    2,  3, 8, 51, 5, 65, 4, 52, 0,  2, 3,  4, 1, 60, 6, 63, 7, 12, 
    6,  7, 2, 84, 0, 56, 4, 61, 8, 36, 1, 52, 3, 90, 7, 25, 5,  2, 
    0, 99, 3, 42, 6, 77, 2, 76, 5, 52, 8,  4, 1, 37, 4, 72, 7, 24, 
    3, 33, 5, 30, 7, 20, 8, 46, 4, 68, 2, 52, 6,  7, 0, 45, 1, 72, 
    5, 80, 8, 22, 0, 85, 4, 32, 2, 98, 6, 67, 7, 77, 3, 32, 1, 80, 
    4, 56, 1, 96, 6, 39, 5, 11, 0, 98, 8, 73, 7, 59, 2, 54, 3, 82, 
    1, 94, 4, 49, 6, 94, 2, 96, 5, 19, 8, 52, 7, 82, 3, 12, 0, 72, 
    6,  7, 0, 89, 8, 69, 5, 85, 3, 39, 1, 71, 7, 86, 2, 18, 4, 78
  };
  const int q5194[] = {
    9, 9, // Number of jobs and machines
    1, 56, 4, 12, 7, 34, 3, 12, 2, 95, 0, 63, 6, 76, 8, 12, 5, 68, 
    2, 15, 4, 46, 7, 83, 0, 44, 5,  2, 8, 95, 3, 60, 6, 20, 1, 88, 
    1, 92, 0, 78, 3, 85, 2, 58, 5, 42, 6, 82, 8, 67, 4, 25, 7, 39, 
    1, 59, 0, 70, 2, 29, 6, 89, 7, 16, 4, 16, 3, 11, 8, 18, 5, 75, 
    7, 27, 3, 16, 6, 94, 2, 97, 1, 44, 5, 99, 4, 33, 0,  4, 8, 83, 
    2,  2, 4, 27, 3, 14, 0, 96, 5, 33, 8, 86, 6, 86, 7, 74, 1, 97, 
    0, 60, 6, 29, 4, 13, 1,  8, 7, 96, 8, 83, 2, 49, 3, 98, 5, 98, 
    3, 11, 5,  5, 2, 88, 6, 52, 4, 37, 8, 85, 7, 26, 0, 32, 1, 12, 
    3, 73, 4, 90, 7, 87, 2, 68, 6, 85, 0, 10, 5, 82, 8, 49, 1, 35
  };
  const int q5195[] = {
    9, 9, // Number of jobs and machines
    6,  2, 2, 77, 4, 64, 1, 15, 5, 22, 8, 83, 3,  6, 7, 26, 0, 72, 
    3, 48, 8, 44, 5,  1, 4, 78, 2, 91, 7, 33, 1, 65, 0,  6, 6, 73, 
    4, 76, 8,  7, 7, 90, 1, 57, 0, 99, 6, 23, 5, 84, 2, 42, 3, 89, 
    6, 45, 7, 16, 5, 94, 0, 40, 2, 33, 4, 28, 8, 20, 3, 67, 1, 25, 
    5, 28, 7, 47, 4, 23, 1,  5, 8,  2, 0, 50, 6, 23, 3, 14, 2, 78, 
    6, 89, 4, 98, 5,  4, 3, 80, 8, 41, 1, 43, 7, 61, 0, 22, 2, 73, 
    7, 12, 0, 87, 6, 36, 2, 55, 1, 36, 4, 24, 5, 73, 8, 96, 3,  9, 
    3, 27, 4, 85, 5, 31, 0, 31, 1, 37, 7,  7, 6, 71, 2, 79, 8, 11, 
    5, 89, 2, 11, 4,  4, 7, 42, 1,  5, 6, 19, 0, 92, 3, 32, 8,  1
  };
  const int q5196[] = {
    9, 9, // Number of jobs and machines
    4, 17, 8, 76, 7, 82, 5, 91, 3, 49, 6, 88, 2, 23, 0, 24, 1, 19, 
    8, 33, 7, 10, 4, 17, 5, 97, 1, 98, 6, 45, 2, 88, 0, 76, 3, 20, 
    4,  2, 1, 63, 3, 53, 5, 22, 7, 19, 8, 19, 0,  9, 2, 45, 6, 11, 
    0, 74, 8, 94, 1, 32, 3, 24, 6, 68, 4, 53, 7, 94, 2, 60, 5, 41, 
    5, 58, 3, 13, 7, 41, 0, 74, 1,  1, 2, 18, 4, 28, 8,  1, 6, 74, 
    3, 50, 8, 11, 2,  6, 6, 76, 7, 35, 4, 89, 5, 64, 0, 44, 1, 94, 
    1, 13, 0, 91, 7, 23, 3, 67, 4, 85, 6, 36, 2, 19, 8, 15, 5, 35, 
    3, 28, 0,  3, 7, 72, 4,  1, 1, 26, 8, 55, 2, 22, 5, 53, 6, 10, 
    4, 75, 7, 29, 2, 49, 6, 86, 8, 70, 3,  4, 5, 58, 1, 45, 0, 10
  };
  const int q5197[] = {
    9, 9, // Number of jobs and machines
    7, 73, 3, 69, 0, 28, 4, 69, 6, 29, 8, 65, 5, 98, 1, 30, 2, 24, 
    0, 45, 2, 94, 8, 11, 1, 42, 4, 55, 7, 38, 6, 93, 3, 41, 5, 88, 
    6, 28, 8, 17, 4, 39, 1, 17, 5, 45, 3, 44, 7, 22, 0, 53, 2, 17, 
    5, 31, 7, 27, 8, 19, 2, 90, 3, 44, 4, 85, 6, 45, 1, 27, 0, 65, 
    0, 18, 3, 32, 5, 79, 6, 24, 4, 85, 7,  6, 1, 50, 2, 98, 8, 69, 
    0,  7, 7, 63, 2, 72, 1, 76, 8, 67, 6, 33, 3, 39, 4, 87, 5, 68, 
    8, 41, 7,  4, 1, 87, 3, 90, 5, 67, 4, 47, 6, 12, 0, 27, 2,  5, 
    8, 17, 0, 45, 7, 40, 1, 46, 6, 93, 4,  7, 2,  2, 3, 32, 5, 33, 
    8, 30, 4, 91, 3, 25, 2, 45, 7, 20, 1, 59, 6, 56, 5, 87, 0, 72
  };
  const int q5198[] = {
    9, 9, // Number of jobs and machines
    7, 31, 5, 16, 3, 29, 2, 56, 4, 68, 8, 93, 1, 21, 6, 99, 0, 21, 
    0, 53, 3, 52, 7, 60, 5, 52, 8, 20, 1, 75, 6, 90, 4, 54, 2, 63, 
    1, 31, 8, 85, 3, 52, 4, 59, 0, 81, 6,  9, 5, 58, 2, 37, 7, 80, 
    7, 69, 1, 16, 4, 38, 3, 46, 5, 56, 2, 49, 0, 64, 8, 77, 6, 42, 
    5, 50, 1, 98, 4, 87, 2, 51, 7, 76, 6, 23, 8, 75, 3, 68, 0, 79, 
    8, 38, 3, 57, 1, 36, 0, 46, 2, 94, 6, 17, 5, 35, 4, 42, 7, 63, 
    6, 76, 2, 59, 5, 21, 0, 95, 4, 17, 7, 50, 3, 35, 1, 20, 8, 73, 
    7, 25, 2, 65, 8, 69, 0, 93, 4, 63, 3, 37, 5, 34, 6, 49, 1, 77, 
    3, 29, 0, 89, 7, 88, 1, 13, 8, 55, 6, 97, 2, 37, 4, 87, 5, 40
  };
  const int q5199[] = {
    9, 9, // Number of jobs and machines
    0, 36, 4, 27, 8, 53, 1,  3, 6, 51, 2, 79, 7, 27, 3,  7, 5, 32, 
    7, 84, 1, 92, 3, 52, 4,  2, 2, 62, 6, 41, 5,  5, 0, 46, 8,  6, 
    7, 23, 8, 12, 5, 79, 6, 55, 3, 28, 0, 91, 2, 68, 4, 71, 1,  5, 
    6, 84, 7,  3, 3, 83, 5, 78, 0, 97, 2, 64, 4, 67, 8, 10, 1,  6, 
    8, 45, 4, 14, 3, 87, 7, 29, 1, 81, 6, 50, 0, 86, 2, 68, 5, 10, 
    3, 78, 8, 72, 0, 81, 2, 77, 4, 21, 5, 24, 1,  4, 7, 45, 6, 28, 
    8, 53, 6, 20, 3,  3, 1, 61, 5, 91, 2, 33, 7, 87, 0, 69, 4,  9, 
    3, 34, 1, 15, 6, 15, 8, 67, 4, 43, 5, 39, 2, 48, 0, 60, 7, 26, 
    7, 24, 0,  6, 1, 81, 4, 34, 8, 50, 5, 89, 6,  5, 3, 62, 2, 80
  };
  const int q5200[] = {
    9, 9, // Number of jobs and machines
    4, 32, 7, 37, 5,  3, 2, 28, 8, 64, 0, 36, 1, 21, 3, 61, 6, 34, 
    4, 36, 2, 88, 1, 80, 3, 81, 5, 69, 0, 64, 6, 41, 7, 15, 8, 10, 
    4, 84, 1, 65, 3, 58, 0,  2, 5, 91, 8,  9, 7,  6, 6, 42, 2, 81, 
    4, 40, 6, 23, 5, 18, 1, 91, 0,  9, 3, 89, 7, 80, 2, 83, 8, 15, 
    8, 47, 0,  6, 2, 94, 7, 39, 4, 25, 5, 89, 3, 41, 6, 23, 1, 82, 
    1, 31, 0, 30, 4, 81, 5, 92, 2, 17, 6, 16, 7, 63, 8, 25, 3, 25, 
    4, 15, 0, 40, 3, 80, 5, 12, 2, 42, 1, 97, 6, 90, 8, 44, 7, 42, 
    4, 63, 6,  8, 5, 21, 7, 41, 3, 65, 2, 69, 8, 15, 1, 43, 0,  2, 
    3,  2, 5, 61, 7, 10, 4, 19, 6, 49, 2, 77, 8, 91, 1, 10, 0, 41
  };
  const int q5201[] = {
    9, 9, // Number of jobs and machines
    8, 79, 2, 98, 6, 15, 5, 93, 4, 10, 7, 71, 1, 34, 3, 98, 0, 39, 
    5, 44, 8, 29, 4, 35, 2, 37, 1, 75, 3, 91, 0, 40, 6, 82, 7, 50, 
    5, 67, 1, 57, 0, 57, 6, 39, 4, 20, 8, 96, 3, 20, 7, 29, 2, 46, 
    1, 84, 4, 62, 0, 63, 2, 30, 5,  6, 3, 31, 8, 36, 7, 94, 6, 36, 
    6, 88, 7,  9, 3,  4, 1,  2, 4, 87, 0, 62, 5, 67, 2, 95, 8, 27, 
    3, 90, 7, 11, 1, 31, 5, 61, 8, 12, 6, 43, 4, 72, 2,  1, 0, 36, 
    0, 12, 5, 63, 4, 45, 8, 17, 1, 17, 2, 94, 6, 94, 3, 72, 7, 16, 
    2, 30, 8, 68, 5, 48, 6, 46, 1, 39, 0, 66, 4, 76, 7, 79, 3, 59, 
    0, 53, 1, 78, 3, 31, 8, 19, 2,  1, 7, 39, 4, 20, 5, 97, 6, 18
  };
  const int q5202[] = {
    9, 9, // Number of jobs and machines
    6, 72, 3, 64, 0, 60, 7, 94, 4, 34, 8, 71, 5, 25, 1, 58, 2, 15, 
    2, 33, 4, 40, 3,  9, 5, 19, 6, 61, 8, 23, 0, 38, 1, 30, 7, 12, 
    6, 94, 8, 88, 1, 65, 0, 47, 5,  4, 2, 41, 3, 19, 7, 24, 4, 96, 
    5, 73, 7, 32, 2, 46, 6, 60, 3, 50, 4,  1, 0, 39, 8, 31, 1, 99, 
    7, 79, 4, 95, 0, 15, 2, 78, 3, 39, 1, 87, 8, 78, 6,  4, 5,  8, 
    4,  6, 6, 75, 0, 39, 8, 77, 3, 16, 7, 94, 5, 75, 1, 24, 2,  7, 
    5, 60, 3, 27, 8, 81, 7, 29, 2,  2, 0, 74, 1, 74, 6, 54, 4, 38, 
    7, 90, 2, 27, 5, 28, 8, 30, 6, 52, 1, 90, 4, 28, 3, 12, 0, 19, 
    2, 15, 4, 24, 5, 27, 6, 60, 8,  6, 7, 83, 1, 45, 0, 30, 3, 30
  };
  const int q5203[] = {
    9, 9, // Number of jobs and machines
    6, 20, 1, 75, 2, 57, 4, 85, 8,  2, 7, 74, 0, 76, 5, 22, 3,  4, 
    1, 54, 0, 74, 7, 28, 2, 59, 5, 70, 3, 79, 6, 50, 8, 71, 4,  9, 
    4, 56, 1, 70, 6,  5, 8,  4, 0, 50, 7, 74, 2, 11, 3, 15, 5, 33, 
    3, 59, 0, 88, 1, 82, 4, 93, 8, 92, 7,  1, 5, 99, 2,  6, 6, 79, 
    7, 32, 1, 77, 4,  4, 5, 25, 8,  9, 0, 70, 6, 15, 2,  6, 3, 61, 
    5, 76, 0, 30, 8, 70, 2, 36, 4, 33, 3, 41, 6,  1, 1, 77, 7, 69, 
    7, 69, 6, 73, 1, 83, 5, 76, 4, 28, 2, 92, 3, 23, 8, 89, 0, 41, 
    6, 17, 5, 35, 1, 73, 2, 94, 0,  4, 4, 57, 3, 25, 8, 31, 7, 63, 
    4, 60, 8, 93, 0, 69, 2, 82, 3, 45, 7, 89, 1, 56, 6, 27, 5, 57
  };
  const int q5204[] = {
    9, 9, // Number of jobs and machines
    0, 92, 3, 37, 4, 45, 6, 94, 5, 21, 7, 98, 2, 40, 1, 36, 8, 49, 
    1, 72, 2, 31, 5, 93, 7, 64, 8, 92, 4, 75, 3, 17, 6, 24, 0, 64, 
    5, 37, 6, 62, 8, 97, 3, 91, 4, 74, 7, 33, 2, 46, 1,  6, 0, 27, 
    5, 62, 4, 31, 1, 26, 7, 24, 0, 95, 6, 85, 2, 86, 8, 35, 3, 61, 
    8, 90, 5, 26, 1, 80, 4, 74, 7,  3, 0, 48, 3, 26, 6, 39, 2, 18, 
    7, 13, 0, 35, 6, 49, 2, 33, 5, 96, 4, 81, 3, 20, 8,  1, 1, 47, 
    4, 70, 0, 73, 8, 35, 7, 59, 5,  2, 6, 20, 3, 65, 1, 21, 2, 54, 
    0, 96, 5, 32, 8, 16, 1, 24, 2,  9, 4, 80, 3, 32, 7, 42, 6, 67, 
    1, 43, 4, 50, 3, 69, 0, 49, 5, 34, 7,  7, 6, 84, 2, 27, 8, 13
  };
  const int q5205[] = {
    9, 9, // Number of jobs and machines
    3, 11, 2, 89, 4, 49, 8, 44, 6,  8, 7, 53, 0, 95, 1, 76, 5, 54, 
    6, 76, 0, 53, 1, 89, 2, 22, 4, 38, 7, 52, 8, 87, 3, 61, 5, 49, 
    7, 17, 8, 34, 2,  8, 6,  7, 1, 21, 3, 27, 4, 67, 5, 85, 0, 22, 
    3, 48, 0, 69, 2,  2, 8, 36, 4, 64, 5, 21, 6, 81, 1, 88, 7, 76, 
    4, 86, 5, 71, 0, 77, 1, 59, 8, 70, 3, 79, 2, 53, 7, 43, 6, 44, 
    3, 61, 2, 83, 8, 86, 1, 48, 7, 60, 4, 76, 5, 22, 0, 53, 6, 83, 
    6, 10, 5, 82, 2, 41, 7, 44, 4, 42, 1, 94, 8, 72, 0, 43, 3, 13, 
    5, 48, 6,  1, 7, 79, 2, 59, 4, 35, 3, 57, 8, 67, 1,  2, 0, 61, 
    0, 84, 6, 69, 2, 65, 1, 95, 8, 61, 7, 29, 3, 41, 5, 87, 4, 21
  };
  const int q5206[] = {
    9, 9, // Number of jobs and machines
    8, 10, 4, 58, 6, 75, 1, 31, 0, 53, 3, 24, 2, 13, 7, 36, 5, 98, 
    8, 65, 7, 28, 3, 70, 5, 81, 2, 40, 0, 22, 1, 81, 4, 64, 6, 26, 
    1, 46, 7,  6, 0, 68, 2, 76, 5, 32, 6, 96, 3, 78, 4, 17, 8, 53, 
    7, 67, 4,  9, 8, 89, 3, 70, 1, 77, 6, 15, 5, 69, 2, 62, 0, 25, 
    6,  1, 3, 16, 7, 58, 1, 41, 4, 58, 0, 34, 2, 52, 8, 41, 5, 86, 
    3, 95, 1, 44, 5, 87, 8, 75, 2, 15, 7, 33, 0, 94, 4, 97, 6, 69, 
    4, 14, 1,  1, 8,  6, 0, 84, 3, 60, 7, 35, 5, 44, 2, 89, 6, 93, 
    1,  2, 3, 16, 7, 47, 4, 54, 0, 41, 2, 69, 6, 69, 5, 17, 8, 53, 
    4, 46, 3, 78, 0, 69, 5, 40, 2, 68, 8,  7, 6, 95, 1, 44, 7, 58
  };
  const int q5207[] = {
    9, 9, // Number of jobs and machines
    8, 88, 5, 34, 1, 68, 3, 78, 4, 41, 6, 65, 0, 76, 7, 37, 2, 96, 
    8, 97, 2, 93, 1, 12, 4, 64, 7, 17, 5, 97, 0, 41, 6, 53, 3, 82, 
    0, 70, 6, 86, 2, 55, 4, 68, 3, 89, 1, 88, 7, 24, 5,  8, 8, 23, 
    6, 80, 5, 48, 0, 70, 8, 94, 7, 12, 4, 75, 3, 51, 1,  1, 2, 39, 
    5, 63, 4, 74, 1, 41, 3, 46, 6,  6, 7, 32, 2, 27, 8, 46, 0, 58, 
    0, 33, 3, 87, 6, 40, 1, 65, 2, 85, 5, 13, 4, 15, 7,  8, 8, 33, 
    1, 29, 6, 94, 8, 46, 2, 65, 5, 70, 4, 61, 0, 23, 3,  3, 7, 81, 
    5, 89, 6, 88, 8,  2, 0, 64, 1, 12, 2, 26, 7, 91, 4, 47, 3, 76, 
    5, 80, 4, 51, 8, 38, 6, 12, 1,  8, 7, 29, 3,  1, 0, 63, 2, 37
  };
  const int q5208[] = {
    9, 9, // Number of jobs and machines
    6, 44, 7, 14, 4, 46, 1, 77, 0, 53, 2, 24, 3, 50, 8,  7, 5, 65, 
    8, 11, 5, 11, 0, 44, 3, 55, 6, 35, 7, 59, 2, 14, 4, 28, 1, 80, 
    6, 39, 5, 91, 7, 46, 4, 56, 1, 85, 8, 78, 3, 63, 2,  7, 0, 48, 
    7, 74, 2, 42, 8, 15, 0, 78, 5, 45, 4, 37, 1, 63, 6, 53, 3, 96, 
    4, 61, 1, 31, 2, 25, 5,  7, 6, 27, 7, 28, 8, 30, 0, 88, 3, 63, 
    8,  1, 7, 74, 3, 99, 6, 62, 2, 87, 4, 10, 0, 64, 1, 97, 5, 64, 
    2, 40, 0, 66, 3,  4, 6, 78, 1, 46, 7,  2, 4, 24, 8, 70, 5,  4, 
    5, 57, 2, 97, 3, 82, 8,  7, 7,  5, 4, 17, 0,  8, 6, 53, 1, 99, 
    3, 59, 7, 72, 5, 28, 1, 74, 6,  4, 0, 69, 4, 90, 8, 69, 2, 27
  };
  const int q5209[] = {
    9, 9, // Number of jobs and machines
    3, 16, 5, 46, 4, 68, 8, 37, 6,  7, 0, 90, 1, 45, 2, 14, 7, 48, 
    7, 32, 8, 17, 4, 71, 0, 36, 5, 45, 1, 34, 6, 95, 2, 71, 3, 48, 
    2, 43, 6,  9, 1, 50, 5, 38, 4, 99, 8, 53, 0, 73, 3, 26, 7, 47, 
    5, 62, 8, 50, 2, 63, 6, 48, 3, 29, 0,  4, 1, 22, 4, 68, 7, 10, 
    4, 87, 1, 96, 0, 57, 5, 26, 8, 67, 2, 86, 7, 10, 3, 79, 6,  3, 
    4, 11, 3,  8, 0, 98, 7, 37, 2, 19, 6, 12, 5, 15, 1, 34, 8, 75, 
    6, 38, 7, 91, 3, 15, 8, 80, 4, 38, 0, 83, 5,  4, 1, 86, 2,  3, 
    6, 68, 3, 81, 0, 85, 1,  3, 8, 10, 2, 38, 4, 50, 5, 47, 7, 50, 
    3, 53, 7, 90, 2, 28, 6, 14, 0, 75, 1, 24, 4, 94, 8, 30, 5, 62
  };
  const int q5210[] = {
    9, 9, // Number of jobs and machines
    5,  5, 3, 59, 6, 38, 2, 65, 1, 87, 4, 39, 8, 12, 0, 68, 7, 75, 
    1, 13, 3, 48, 0, 91, 2, 52, 7, 76, 4, 25, 6, 12, 8, 67, 5, 87, 
    6, 32, 1, 90, 2, 25, 4, 21, 3, 64, 8, 25, 7, 21, 0, 16, 5, 12, 
    7, 70, 3, 13, 6, 79, 2, 21, 5, 69, 8, 62, 0, 17, 1, 68, 4, 64, 
    1, 54, 3, 87, 2, 10, 8,  5, 6, 91, 4, 49, 5, 60, 7, 93, 0, 79, 
    7, 63, 8, 75, 4, 36, 0, 91, 6, 84, 1, 86, 3, 41, 2, 73, 5, 58, 
    6,  1, 2, 16, 4,  1, 5, 72, 3,  6, 8, 30, 7, 71, 1, 31, 0, 29, 
    3,  2, 6,  7, 7, 54, 4, 34, 0, 31, 2, 77, 8, 25, 5,  3, 1,  1, 
    7, 66, 3,  2, 8, 34, 6, 95, 4, 31, 5, 60, 1, 67, 0, 73, 2, 65
  };
  const int q5211[] = {
    9, 9, // Number of jobs and machines
    7, 36, 6, 13, 3, 18, 2, 70, 0, 88, 5, 81, 8, 39, 1, 60, 4, 22, 
    0, 71, 4, 18, 1, 99, 3, 49, 7, 98, 2,  2, 8, 48, 6, 71, 5, 72, 
    1, 67, 7, 74, 3, 68, 6, 15, 0, 21, 4, 76, 8, 34, 2, 30, 5, 81, 
    8, 77, 5, 77, 0, 96, 4, 76, 2, 65, 3, 92, 7, 58, 1, 77, 6, 32, 
    5, 27, 0, 30, 8, 55, 3, 15, 7, 93, 1, 48, 6, 69, 2, 27, 4, 71, 
    7, 84, 8, 70, 3, 97, 5, 16, 2,  1, 0, 40, 4, 18, 1,  3, 6, 48, 
    3, 45, 2, 20, 5, 87, 6, 31, 0, 32, 8, 73, 1, 10, 4,  2, 7, 84, 
    3, 81, 7, 20, 8,  5, 6, 35, 1, 34, 0, 62, 2, 16, 5, 44, 4, 74, 
    8, 12, 5, 11, 2, 33, 1, 94, 4, 62, 0, 56, 3, 29, 7, 62, 6, 39
  };
  const int q5212[] = {
    9, 9, // Number of jobs and machines
    8, 87, 5, 77, 6, 99, 0, 43, 4, 44, 2, 32, 7, 97, 1, 84, 3, 38, 
    6, 29, 1, 52, 3, 44, 7, 51, 0, 94, 4, 85, 5, 46, 8, 34, 2, 14, 
    3, 87, 0, 49, 6, 19, 4, 44, 5, 85, 1, 27, 2, 36, 7, 87, 8, 50, 
    3, 71, 5, 61, 0, 55, 7, 88, 2, 90, 1,  8, 4, 58, 8, 33, 6, 41, 
    1, 15, 4, 53, 2, 48, 5, 82, 6, 25, 7, 43, 8, 93, 0, 25, 3, 25, 
    8, 39, 4, 72, 1, 21, 7, 11, 2, 51, 6,  4, 5, 66, 3, 42, 0, 56, 
    2, 22, 4, 63, 5, 53, 8, 64, 7, 25, 0, 81, 6,  6, 1, 34, 3, 58, 
    0, 62, 8,  8, 1, 72, 3, 18, 2, 15, 5, 36, 4, 88, 7, 49, 6, 72, 
    2, 47, 6, 45, 3, 68, 0, 92, 1, 11, 5, 50, 8, 37, 4, 74, 7, 68
  };
  const int q5213[] = {
    9, 9, // Number of jobs and machines
    5, 57, 4, 59, 0, 81, 7, 60, 3, 39, 6, 68, 1, 81, 2, 44, 8, 25, 
    2, 86, 1, 81, 5, 37, 0,  5, 6, 40, 4, 54, 7, 82, 8, 80, 3, 95, 
    8,  4, 6, 62, 3, 99, 7, 98, 4, 99, 2, 51, 0, 66, 1, 67, 5, 49, 
    8, 98, 3, 18, 6,  9, 4, 30, 2, 77, 5, 58, 0, 97, 7, 51, 1, 86, 
    2, 91, 3, 35, 7,  6, 5, 80, 8, 31, 1, 14, 0, 60, 6,  5, 4, 29, 
    2, 23, 0, 31, 5, 91, 8, 31, 1, 38, 4, 59, 6,  5, 7, 65, 3, 31, 
    6, 95, 7, 28, 5,  2, 2, 97, 8, 68, 1, 24, 3, 16, 0, 63, 4,  5, 
    6, 18, 1, 47, 4, 35, 5, 12, 2, 65, 3, 70, 7, 58, 8, 88, 0, 19, 
    1, 21, 3, 43, 4, 16, 5, 51, 6, 24, 0, 28, 8, 21, 2, 41, 7, 86
  };
  const int q5214[] = {
    9, 9, // Number of jobs and machines
    4, 28, 8, 88, 7, 78, 5, 26, 0, 40, 1, 49, 6, 65, 3, 31, 2, 22, 
    4, 83, 2, 31, 0, 92, 1, 28, 8, 22, 5, 20, 6, 71, 3, 73, 7, 49, 
    6, 78, 4, 28, 7,  7, 3, 15, 0, 34, 2, 55, 5, 86, 1, 39, 8,  3, 
    6, 24, 5, 80, 1, 38, 8, 27, 4, 11, 7, 77, 3, 90, 0, 17, 2,  8, 
    2, 19, 3, 33, 7, 92, 8, 54, 0, 63, 5, 49, 4, 78, 1, 99, 6, 97, 
    8, 88, 4, 89, 1, 57, 3, 86, 2, 88, 6, 68, 7, 91, 5, 47, 0, 47, 
    6, 94, 2, 30, 8, 25, 7, 68, 4, 40, 0,  1, 3, 82, 1, 62, 5,  8, 
    2, 14, 4, 20, 6, 22, 1,  7, 5, 53, 0,  5, 8, 99, 3, 19, 7,  7, 
    0, 82, 6, 53, 7, 71, 5, 62, 4, 10, 8, 54, 1, 82, 3, 15, 2, 80
  };
  const int q5215[] = {
    9, 9, // Number of jobs and machines
    4, 49, 2, 75, 8, 97, 3, 48, 7, 72, 5, 45, 6,  5, 1, 93, 0, 34, 
    7, 46, 0, 97, 8, 97, 1, 72, 4, 46, 6, 18, 5, 39, 2, 51, 3, 86, 
    1,  2, 2, 80, 7, 16, 5, 84, 6, 77, 3, 34, 0, 73, 8, 48, 4, 98, 
    3, 20, 5, 38, 0, 24, 8, 61, 6, 19, 1, 94, 2, 67, 7, 92, 4, 20, 
    3, 74, 4, 94, 8, 66, 5,  4, 7, 86, 2, 26, 0, 45, 1, 11, 6, 23, 
    7, 32, 2, 70, 1, 54, 5, 43, 0, 76, 4, 82, 3, 23, 6, 11, 8, 47, 
    7, 82, 8, 18, 4,  5, 1, 58, 3, 26, 2, 81, 5, 77, 6, 69, 0, 39, 
    8, 29, 2, 43, 3, 58, 6, 55, 4, 85, 5, 18, 1, 75, 0, 35, 7, 52, 
    2, 71, 3, 34, 7,  4, 4, 92, 1, 22, 0, 60, 5, 25, 8, 24, 6, 95
  };
  const int q5216[] = {
    9, 9, // Number of jobs and machines
    0, 39, 7, 45, 1,  7, 3, 24, 2, 62, 4, 99, 5, 80, 6, 82, 8, 82, 
    8, 11, 7, 96, 0, 24, 5, 27, 3, 80, 1, 78, 6, 50, 4, 89, 2,  5, 
    3, 85, 1,  1, 5, 51, 7, 29, 8, 83, 0, 77, 2, 36, 6, 36, 4, 92, 
    4, 69, 0, 80, 8, 98, 2, 50, 6,  4, 1, 48, 5, 42, 7,  4, 3, 47, 
    4, 50, 1, 49, 7, 59, 5, 30, 6, 49, 2,  4, 0,  6, 3, 71, 8, 53, 
    2, 31, 7, 72, 3, 19, 8,  8, 5, 63, 6, 36, 1,  3, 4, 15, 0, 74, 
    7, 59, 8, 25, 1, 52, 6, 17, 0, 32, 4, 35, 5, 42, 2,  4, 3, 11, 
    3, 74, 5, 93, 1, 26, 0, 92, 7, 37, 2, 40, 8, 27, 4,  9, 6, 12, 
    5, 87, 2,  2, 7, 97, 6, 99, 0, 20, 8,  7, 3, 52, 4, 55, 1,  5
  };
  const int q5217[] = {
    9, 9, // Number of jobs and machines
    7, 98, 8, 59, 2, 92, 3, 68, 1,  9, 0, 55, 5, 53, 6, 83, 4, 67, 
    2, 63, 5, 59, 4, 37, 8, 29, 3, 18, 7, 25, 1, 19, 6, 10, 0, 48, 
    2, 76, 5, 92, 8, 14, 7, 73, 1, 32, 0, 16, 6, 22, 3, 61, 4, 46, 
    8, 90, 5, 95, 2, 40, 3, 95, 7, 77, 6, 55, 0, 97, 1,  9, 4, 26, 
    1,  9, 5, 63, 7,  5, 6, 68, 3, 99, 4, 31, 8, 26, 2, 28, 0, 48, 
    3, 24, 2, 56, 5, 14, 4, 20, 6, 82, 0, 78, 1, 81, 7, 67, 8, 11, 
    6, 34, 8, 41, 3, 66, 7, 27, 0, 38, 2, 72, 5, 10, 1, 42, 4, 11, 
    1, 46, 2, 17, 3,  6, 0, 27, 6, 35, 7, 38, 5, 50, 4, 76, 8, 83, 
    0, 53, 3, 31, 8, 32, 1, 44, 5, 78, 4, 85, 2, 80, 7, 97, 6, 14
  };
  const int q5218[] = {
    9, 9, // Number of jobs and machines
    3, 43, 2, 85, 6, 76, 7, 79, 5, 87, 0, 24, 1,  9, 8, 93, 4, 50, 
    3, 23, 0, 21, 2, 64, 7, 36, 6, 32, 5, 47, 4, 99, 1, 56, 8, 94, 
    7, 90, 6, 70, 5, 47, 1,  5, 4,  2, 3,  4, 8, 62, 0, 24, 2, 61, 
    7, 53, 6, 39, 0, 42, 1, 80, 3, 45, 4, 42, 2,  6, 8, 37, 5, 43, 
    5, 45, 1, 17, 8, 28, 6, 86, 7, 32, 2, 65, 4, 30, 3, 37, 0, 60, 
    4, 80, 7, 27, 5, 50, 8, 21, 0, 12, 1, 99, 6, 25, 3, 73, 2, 47, 
    8, 21, 4,  5, 5, 92, 2, 70, 0, 99, 3, 41, 1, 30, 6,  6, 7, 86, 
    2, 86, 8, 88, 5,  3, 0, 18, 1, 18, 6, 28, 4, 90, 7, 82, 3,  7, 
    8, 21, 3, 35, 1, 64, 2, 68, 6, 68, 7, 59, 4, 17, 0, 88, 5, 73
  };
  const int q5219[] = {
    9, 9, // Number of jobs and machines
    6,  9, 3, 60, 0, 56, 7, 65, 4, 19, 2, 57, 8,  5, 5, 23, 1, 80, 
    8, 29, 6, 81, 4, 42, 1, 84, 0, 81, 5, 86, 2,  2, 7, 39, 3, 77, 
    2, 62, 8, 70, 1, 80, 7, 74, 5, 41, 0, 10, 6, 56, 3, 24, 4, 53, 
    8, 83, 5, 90, 3,  4, 0, 62, 2, 28, 4, 79, 6, 54, 7, 47, 1, 35, 
    4, 77, 6, 40, 2, 76, 0, 81, 1, 61, 5, 99, 7, 64, 8, 28, 3, 94, 
    0, 58, 4,  8, 6, 80, 1, 95, 5, 64, 8, 40, 2, 35, 3, 24, 7, 11, 
    0, 38, 3, 74, 7, 48, 2, 10, 1, 84, 5, 99, 4, 66, 8, 51, 6, 98, 
    1, 73, 7, 23, 3, 30, 5, 81, 4, 35, 0,  6, 2, 82, 8, 92, 6,  2, 
    2, 76, 0, 45, 7, 69, 4, 85, 5, 12, 6, 64, 3, 83, 1, 66, 8, 31
  };
  const int q5220[] = {
    9, 9, // Number of jobs and machines
    8, 48, 3, 27, 1, 91, 2, 30, 7, 56, 5, 59, 6, 28, 0, 47, 4,  5, 
    7,  6, 3, 39, 5, 66, 1,  2, 4, 55, 8, 49, 6, 62, 0, 33, 2,  2, 
    4, 96, 3, 56, 1, 34, 2,  8, 5, 65, 0, 56, 8,  8, 6, 71, 7, 60, 
    7, 44, 5, 64, 6, 37, 8, 35, 2, 76, 4, 26, 3,  8, 1, 80, 0, 47, 
    0, 63, 8, 54, 7, 74, 2, 71, 3, 23, 5, 67, 4,  4, 6,  9, 1, 43, 
    7, 84, 5, 14, 2, 19, 3,  8, 1, 89, 0, 94, 6, 36, 8, 73, 4, 83, 
    6, 89, 7, 56, 8, 43, 2,  7, 4, 14, 1, 33, 3, 24, 0, 77, 5, 13, 
    3,  8, 5, 26, 7, 55, 1, 21, 8, 13, 0, 63, 6, 71, 4, 62, 2, 67, 
    1, 11, 8, 88, 0, 94, 5, 23, 2, 16, 7, 79, 3, 30, 4, 37, 6, 82
  };
  const int q5221[] = {
    9, 9, // Number of jobs and machines
    7, 59, 3, 23, 8, 31, 0, 60, 6, 47, 2, 77, 4, 68, 5, 43, 1, 31, 
    5, 37, 7, 60, 4, 32, 1, 27, 6, 90, 8, 47, 3, 89, 0, 20, 2, 20, 
    2, 60, 0, 19, 8, 94, 6, 54, 7, 50, 3, 68, 1, 90, 4, 35, 5, 85, 
    3, 46, 0, 76, 5, 62, 1,  6, 2, 50, 8, 58, 7,  6, 6, 25, 4,  3, 
    4, 14, 6, 42, 7, 80, 2, 96, 8, 83, 5, 98, 0, 54, 3, 62, 1, 87, 
    5, 64, 8,  6, 4, 91, 2, 99, 6, 53, 0, 88, 1,  2, 7, 97, 3, 18, 
    0, 72, 8, 51, 3, 17, 7, 78, 5, 76, 2, 40, 6, 68, 1, 44, 4, 56, 
    6, 87, 4, 42, 8,  5, 3, 41, 2, 71, 0, 39, 7, 18, 1, 52, 5, 70, 
    1, 70, 5, 50, 7,  6, 6, 64, 0, 33, 2, 59, 8, 19, 3, 83, 4, 71
  };
  const int q5222[] = {
    9, 9, // Number of jobs and machines
    3, 11, 6, 64, 0, 57, 1,  5, 7, 24, 4, 14, 2, 43, 8, 26, 5, 97, 
    4,  2, 1,  3, 2, 68, 0, 69, 7, 13, 8, 19, 5, 14, 6, 23, 3, 13, 
    1, 79, 0, 55, 6, 62, 5, 40, 4, 41, 7, 81, 8, 90, 3, 34, 2, 88, 
    3, 50, 1, 56, 5, 62, 0, 32, 7, 85, 2, 33, 6, 96, 8, 15, 4, 78, 
    5, 46, 3, 71, 4, 63, 8, 28, 7,  8, 6, 97, 0, 24, 1, 21, 2, 47, 
    1, 95, 2,  8, 0, 50, 4, 91, 6,  2, 8, 31, 5, 62, 7, 17, 3, 30, 
    0, 86, 8, 32, 7, 40, 3, 20, 4, 65, 2, 80, 5, 50, 6, 15, 1, 82, 
    4, 31, 8, 95, 6, 82, 7, 86, 5, 66, 3, 30, 2, 50, 0, 66, 1, 49, 
    3, 24, 5, 42, 8, 58, 6, 52, 7, 12, 1, 54, 4, 23, 2, 46, 0, 33
  };
  const int q5223[] = {
    9, 9, // Number of jobs and machines
    5, 47, 3, 44, 2, 32, 8, 49, 1, 95, 4, 34, 6, 67, 7,  2, 0, 53, 
    7, 46, 2, 84, 8, 94, 5, 25, 4, 77, 3, 33, 0, 99, 6, 70, 1,  3, 
    7, 24, 4, 23, 1, 86, 8, 95, 6, 19, 2, 76, 0, 89, 3, 78, 5, 74, 
    7,  2, 1, 21, 5,  6, 8, 29, 0, 59, 4, 21, 3, 43, 6, 98, 2,  9, 
    6, 26, 5, 67, 7, 80, 8, 81, 2, 32, 1, 11, 4, 38, 0, 32, 3, 38, 
    7, 65, 3, 57, 2, 75, 8,  6, 4,  8, 0, 53, 6, 51, 1, 36, 5, 34, 
    7, 14, 0, 21, 2, 42, 5,  5, 6, 31, 3, 37, 4,  1, 8, 30, 1, 77, 
    4, 34, 0,  9, 8, 41, 7, 82, 1, 30, 3, 69, 2, 51, 5, 88, 6, 76, 
    7,  5, 0, 46, 2, 77, 4, 59, 3, 45, 1, 13, 8, 68, 5, 74, 6, 82
  };
  const int q5224[] = {
    9, 9, // Number of jobs and machines
    1,  7, 6, 37, 3, 13, 8, 64, 0, 97, 4, 34, 5, 41, 2,  2, 7, 64, 
    0,  5, 4, 18, 1, 20, 7, 99, 6, 71, 5, 92, 8, 66, 3, 70, 2, 57, 
    2, 92, 1,  9, 0, 83, 5, 68, 6, 27, 4, 33, 8, 83, 3, 83, 7, 97, 
    3, 34, 1, 33, 2, 24, 4, 13, 6, 64, 8, 51, 5,  5, 0, 19, 7, 23, 
    6, 82, 4, 47, 3, 81, 7, 85, 2, 81, 0, 33, 5, 41, 8, 92, 1,  9, 
    5, 60, 7, 36, 0,  5, 3, 89, 4, 79, 6,  2, 2, 37, 1, 99, 8, 90, 
    4, 83, 3, 45, 5, 96, 1, 99, 0, 22, 2, 65, 7, 36, 6, 64, 8,  5, 
    4, 59, 2, 33, 0, 57, 7, 45, 8, 49, 3, 69, 6, 73, 5,  3, 1, 20, 
    4, 42, 8, 45, 0, 72, 1, 52, 2, 30, 6, 35, 7, 94, 3, 99, 5, 40
  };
  const int q5225[] = {
    9, 9, // Number of jobs and machines
    7, 75, 0, 33, 2, 50, 8,  3, 1, 66, 4, 31, 6, 35, 3, 98, 5, 55, 
    7, 36, 0, 39, 4, 40, 3, 33, 2,  1, 8, 25, 6, 18, 5, 69, 1,  7, 
    1, 96, 0, 73, 6, 26, 3, 25, 2, 83, 7,  9, 4, 79, 8, 11, 5, 16, 
    0, 63, 2, 86, 1, 30, 8, 47, 4, 68, 6, 32, 5, 59, 3, 75, 7,  4, 
    1, 10, 2, 44, 8, 42, 0, 22, 5, 46, 3, 25, 6, 87, 7, 72, 4, 60, 
    0, 41, 2, 53, 4, 20, 3, 65, 1, 80, 8, 45, 7, 24, 6, 82, 5, 49, 
    7, 96, 5, 88, 2, 54, 8,  6, 3, 21, 0, 27, 1, 43, 4,  4, 6, 52, 
    5, 95, 2, 12, 8, 68, 3, 64, 0, 13, 7, 95, 4, 75, 6, 60, 1, 80, 
    2, 17, 0, 52, 5, 81, 7, 20, 6, 52, 3, 37, 4, 11, 1, 57, 8, 27
  };
  const int q5226[] = {
    9, 9, // Number of jobs and machines
    5, 65, 0, 68, 3, 35, 4, 87, 7, 74, 6, 93, 8, 67, 1, 51, 2, 76, 
    8, 22, 7, 29, 3, 89, 0, 38, 4, 48, 2, 93, 6, 10, 1, 21, 5, 66, 
    8, 24, 1, 92, 2, 23, 7, 61, 0, 99, 5, 79, 6, 60, 4,  2, 3, 38, 
    8, 44, 4, 42, 7, 10, 1,  8, 0, 74, 3, 55, 5, 27, 6, 52, 2, 99, 
    0,  5, 3, 19, 4, 90, 2, 33, 6, 47, 7, 22, 8, 76, 5, 59, 1, 12, 
    4, 26, 1, 54, 5, 55, 6, 50, 3, 49, 0, 96, 8, 58, 2, 65, 7, 59, 
    8, 61, 1, 91, 7, 52, 2, 93, 0, 20, 4, 97, 3, 32, 5, 31, 6, 47, 
    7, 24, 4, 55, 2, 12, 6, 79, 5, 89, 3, 77, 1, 16, 0, 15, 8,  3, 
    5, 57, 7, 16, 2, 59, 6, 33, 1, 75, 0, 41, 3, 89, 4, 16, 8, 63
  };
  const int q5227[] = {
    9, 9, // Number of jobs and machines
    5, 34, 0, 27, 6, 13, 1, 41, 7,  4, 8,  5, 4, 99, 3, 29, 2, 79, 
    8, 77, 2, 71, 5, 23, 3, 18, 1, 43, 7, 31, 4, 76, 6, 26, 0, 36, 
    2, 22, 1, 63, 8,  3, 6, 44, 3, 11, 7, 13, 0, 40, 4, 10, 5, 71, 
    1, 42, 2, 41, 6, 97, 4,  9, 7,  2, 8, 37, 3, 74, 5, 67, 0, 27, 
    6, 97, 7, 20, 1, 42, 3, 97, 8, 51, 4, 86, 2, 12, 5,  9, 0, 54, 
    5, 37, 3, 20, 6, 65, 0,  6, 2, 21, 7, 78, 4, 16, 1, 45, 8, 27, 
    2, 50, 0, 88, 8, 68, 6, 22, 3, 74, 1, 10, 7, 39, 5, 77, 4, 32, 
    6, 65, 7, 63, 3, 97, 2, 98, 0, 70, 8, 91, 1, 61, 4, 67, 5, 34, 
    2, 49, 8, 56, 0, 86, 6,  7, 1, 57, 4, 64, 7, 73, 5, 84, 3, 49
  };
  const int q5228[] = {
    9, 9, // Number of jobs and machines
    3, 19, 8, 58, 0, 73, 6, 58, 4, 51, 7, 45, 1, 24, 5, 91, 2, 97, 
    0, 38, 4, 96, 3, 41, 2, 21, 8, 33, 7, 16, 5, 37, 1, 91, 6, 62, 
    4, 10, 0, 35, 2, 84, 1, 62, 5, 68, 3,  4, 7, 38, 6, 44, 8, 30, 
    7, 56, 1, 18, 3, 69, 8, 15, 0, 41, 2, 11, 5, 96, 6,  6, 4, 52, 
    8,  1, 1, 47, 0,  6, 5, 45, 7, 33, 4, 77, 2, 53, 3, 26, 6, 11, 
    1, 47, 5, 91, 6, 41, 8, 40, 2, 64, 0, 64, 7, 90, 4, 27, 3, 89, 
    8, 68, 4, 56, 2, 85, 6,  8, 7, 84, 3, 43, 1, 35, 5,  2, 0, 51, 
    2,  9, 7, 66, 8, 58, 1, 73, 3, 92, 6, 10, 4, 81, 0, 17, 5, 79, 
    5, 56, 2, 21, 6, 11, 1, 28, 7, 78, 8, 39, 0, 76, 4, 54, 3,  1
  };
  const int q5229[] = {
    9, 9, // Number of jobs and machines
    0, 95, 1,  6, 6, 92, 3, 35, 2, 57, 7, 60, 4, 56, 5,  4, 8,  7, 
    4, 38, 6, 30, 3, 24, 0, 83, 5, 27, 2, 58, 1,  4, 8, 75, 7, 73, 
    4, 54, 3, 82, 7, 68, 6, 47, 2, 65, 0, 34, 1, 17, 5, 64, 8, 51, 
    5, 89, 7, 46, 8, 56, 4, 97, 2, 56, 3, 81, 6, 76, 0, 10, 1, 35, 
    8, 86, 3, 93, 7, 86, 1, 98, 4, 27, 2,  5, 0, 77, 5, 45, 6, 22, 
    7, 46, 5, 19, 4, 11, 1, 89, 3, 97, 6, 47, 0, 35, 8, 18, 2, 41, 
    3, 55, 6, 20, 1,  2, 5, 63, 0, 29, 8, 33, 4, 49, 7, 78, 2,  7, 
    5, 37, 6, 46, 3, 34, 7,  8, 4, 98, 8, 21, 2, 23, 0, 21, 1, 28, 
    4, 75, 1,  3, 6, 32, 5, 86, 2, 58, 3, 41, 7, 22, 8, 91, 0, 42
  };
  const int q5230[] = {
    9, 9, // Number of jobs and machines
    5,  1, 2, 10, 6, 85, 0, 25, 3, 28, 1, 29, 7, 62, 4, 87, 8, 45, 
    8, 92, 1, 33, 4,  4, 5, 69, 7, 62, 2, 30, 6, 52, 0, 20, 3, 77, 
    3, 21, 5,  2, 6, 47, 2, 17, 4, 38, 7, 95, 1, 82, 0, 80, 8, 36, 
    0, 41, 2, 51, 6, 88, 5, 80, 1, 46, 4, 67, 3, 88, 7, 95, 8, 75, 
    1, 25, 0, 49, 2, 23, 6, 15, 3, 72, 4, 31, 8, 35, 7, 56, 5, 22, 
    0, 39, 5, 51, 8, 29, 1, 70, 2, 68, 7, 26, 3, 35, 6, 78, 4, 52, 
    5, 83, 3, 89, 8, 91, 1, 75, 0,  4, 4,  1, 2, 78, 6, 79, 7, 28, 
    1, 36, 6, 73, 5, 14, 3, 44, 2, 19, 7, 21, 4, 76, 0, 58, 8, 92, 
    8, 91, 4, 47, 0, 79, 1, 18, 5, 13, 3, 25, 7, 96, 6, 17, 2, 35
  };
  const int q5231[] = {
    9, 9, // Number of jobs and machines
    4, 71, 0, 80, 2, 27, 3, 60, 8,  8, 5, 86, 1, 19, 6, 83, 7, 94, 
    6, 37, 0, 45, 5, 90, 1, 65, 3, 21, 2, 28, 7, 12, 4, 57, 8, 55, 
    8, 11, 6, 67, 2, 48, 3, 95, 7, 32, 1, 61, 5, 23, 4, 85, 0, 14, 
    4, 58, 7, 56, 0, 82, 6, 77, 1, 68, 8, 64, 2, 20, 5, 67, 3, 51, 
    6, 28, 2, 19, 3, 47, 8,  2, 7, 51, 0, 90, 5, 84, 4, 39, 1,  7, 
    3, 49, 8, 12, 6, 35, 4, 46, 5, 16, 0, 55, 7, 74, 2, 68, 1,  5, 
    7, 60, 8, 56, 3, 35, 5, 61, 1, 93, 2, 91, 6, 79, 0, 38, 4, 18, 
    5, 69, 6, 18, 7, 98, 2, 89, 0, 82, 3, 54, 8, 72, 4, 20, 1, 23, 
    3, 22, 6, 66, 4, 11, 7, 35, 1, 71, 8, 87, 0, 54, 5, 83, 2, 80
  };
  const int q5232[] = {
    9, 9, // Number of jobs and machines
    4, 12, 7, 36, 8, 46, 5, 41, 6,  4, 3, 11, 1, 26, 0, 25, 2, 72, 
    6, 76, 2, 60, 0, 52, 1, 94, 4, 38, 7, 49, 8, 68, 5, 42, 3, 77, 
    4, 36, 5,  4, 1, 68, 2, 43, 8,  5, 7, 19, 0, 88, 6,  9, 3, 69, 
    0, 84, 4, 65, 8, 53, 5, 58, 3, 41, 6, 35, 7,  3, 1, 60, 2, 70, 
    5,  3, 7,  8, 2, 86, 4, 14, 0, 65, 8, 41, 6, 45, 3, 37, 1, 77, 
    7, 76, 6, 35, 1, 72, 0, 84, 2, 81, 5, 51, 8, 93, 4, 50, 3, 39, 
    4, 18, 6, 91, 7, 58, 2, 24, 3, 94, 0, 94, 5, 11, 1, 54, 8, 19, 
    4, 32, 6, 65, 7, 50, 0, 70, 8, 52, 3, 51, 2, 25, 1, 23, 5, 16, 
    4, 61, 3, 63, 6, 14, 0, 88, 8, 16, 1, 64, 5, 10, 7, 35, 2, 60
  };
  const int q5233[] = {
    9, 9, // Number of jobs and machines
    0, 61, 8, 55, 1, 92, 6, 24, 5, 33, 2, 79, 7, 98, 3, 80, 4, 51, 
    8, 29, 1, 34, 4, 60, 7, 69, 2, 91, 0, 73, 3, 29, 6,  5, 5, 79, 
    5, 17, 8, 54, 1,  3, 2, 61, 6, 29, 0,  7, 3, 48, 4, 10, 7, 91, 
    7, 54, 3, 87, 8, 25, 1, 80, 4, 45, 6, 14, 0, 37, 5, 67, 2, 86, 
    4, 22, 7, 87, 3, 25, 1, 69, 5, 82, 6, 62, 0, 24, 8, 75, 2, 23, 
    4, 70, 8, 61, 3,  9, 0, 48, 1, 74, 7,  5, 6,  6, 5, 56, 2, 32, 
    0, 62, 1,  8, 6, 80, 4, 23, 5, 75, 8, 67, 7, 16, 2, 15, 3, 51, 
    1, 26, 8, 34, 0, 31, 6, 41, 3, 50, 4, 15, 5, 20, 7, 13, 2, 38, 
    4, 64, 3, 93, 2, 67, 7, 59, 6, 34, 5, 68, 0, 41, 1, 14, 8, 30
  };
  const int q5234[] = {
    9, 9, // Number of jobs and machines
    0, 70, 3, 22, 6, 95, 2, 97, 1, 88, 7, 47, 4, 73, 8,  9, 5, 93, 
    6, 35, 1, 65, 8,  2, 7, 52, 0, 73, 2, 95, 3, 30, 4, 30, 5, 65, 
    0, 96, 1, 60, 3, 11, 5, 81, 7, 87, 6, 57, 2, 73, 4, 53, 8, 24, 
    2, 53, 0, 55, 4, 14, 7, 24, 8, 31, 1, 60, 6, 35, 3, 48, 5, 92, 
    2, 41, 6, 82, 1, 39, 3, 93, 8, 62, 0, 42, 5, 29, 4, 23, 7,  5, 
    7, 48, 8, 47, 4, 54, 6, 64, 3, 46, 5, 25, 2, 42, 1, 42, 0, 91, 
    2, 68, 5, 43, 1, 53, 4, 60, 8, 63, 6, 16, 0, 60, 7, 39, 3, 94, 
    6, 37, 7, 42, 2, 89, 3, 79, 5, 15, 4, 69, 8, 31, 1, 98, 0, 61, 
    6, 52, 2, 75, 5, 65, 8, 31, 1, 11, 4, 22, 0, 31, 7, 87, 3, 44
  };
  const int q5235[] = {
    9, 9, // Number of jobs and machines
    7,  2, 6, 80, 5, 66, 4, 39, 3, 32, 0, 97, 1, 70, 8, 32, 2, 48, 
    0, 41, 1, 60, 8, 67, 6, 66, 5, 89, 7, 68, 3, 23, 2,  5, 4, 24, 
    3, 51, 2, 54, 4, 66, 5, 45, 8, 22, 0,  9, 1, 75, 7,  5, 6,  9, 
    6, 31, 2, 18, 3, 74, 4, 49, 0, 88, 8,  1, 7, 30, 5, 36, 1, 55, 
    2, 53, 6, 20, 5, 40, 0, 24, 8, 39, 7, 25, 3, 54, 1, 15, 4, 19, 
    8, 65, 5, 43, 1, 28, 3, 45, 0, 84, 6, 14, 4, 97, 2, 54, 7, 35, 
    4, 33, 3, 67, 1, 89, 0, 96, 7, 88, 2,  8, 5, 11, 6, 88, 8, 62, 
    6, 42, 4, 16, 2, 26, 5, 80, 0, 57, 7,  4, 3, 37, 1, 53, 8, 45, 
    4, 23, 7, 39, 8, 85, 2, 61, 0, 57, 5,  4, 1, 85, 6, 18, 3, 83
  };
  const int q5236[] = {
    9, 9, // Number of jobs and machines
    1, 35, 7, 30, 3, 85, 0, 85, 5, 88, 2, 41, 6, 36, 8, 38, 4, 24, 
    7, 71, 6, 43, 0,  6, 2,  7, 5, 75, 8,  2, 1, 55, 4, 31, 3, 68, 
    2,  8, 5, 86, 7, 71, 0, 14, 4, 24, 3, 67, 1, 53, 6, 86, 8, 13, 
    1, 80, 8, 80, 6,  3, 2,  4, 3,  1, 4, 74, 5, 46, 7, 77, 0, 41, 
    7, 18, 4, 92, 5, 47, 0, 50, 2,  2, 8, 60, 3, 83, 6, 30, 1, 40, 
    5, 31, 6, 73, 3, 99, 0, 37, 4, 25, 8, 31, 7, 71, 1, 93, 2, 38, 
    7, 72, 4, 39, 5, 95, 1, 55, 2, 44, 6, 91, 0, 28, 8, 66, 3, 17, 
    8, 59, 3, 84, 2, 78, 5, 47, 7, 90, 1,  8, 4, 46, 0, 15, 6, 43, 
    3, 20, 0, 99, 5, 87, 8,  9, 4, 76, 6, 88, 1, 23, 7, 73, 2, 15
  };
  const int q5237[] = {
    9, 9, // Number of jobs and machines
    1,  8, 6, 60, 5, 50, 3,  4, 7, 13, 4, 20, 8, 13, 2, 61, 0, 88, 
    7, 39, 3, 74, 6, 74, 4, 75, 8, 61, 2,  6, 1, 97, 0, 42, 5, 97, 
    1, 15, 7, 75, 8, 23, 0,  2, 4, 51, 5, 51, 2, 52, 6,  2, 3, 26, 
    3, 78, 1, 30, 6, 50, 0, 51, 7, 81, 8, 97, 5,  7, 4, 38, 2, 61, 
    6, 15, 8, 12, 1, 19, 2,  5, 7, 48, 4, 21, 0, 72, 3, 81, 5, 42, 
    6, 55, 5, 14, 0, 27, 1, 55, 8,  8, 7, 74, 3, 15, 4,  5, 2, 69, 
    1, 23, 8,  6, 2,  6, 5, 62, 0, 12, 7, 76, 6, 99, 3, 22, 4, 71, 
    4, 46, 6, 73, 5, 58, 8,  5, 3,  1, 0, 47, 1, 26, 2,  9, 7, 23, 
    8, 36, 6, 49, 7,  3, 2, 79, 1, 53, 4, 14, 5, 34, 0, 16, 3, 44
  };
  const int q5238[] = {
    9, 9, // Number of jobs and machines
    0, 72, 3,  4, 4, 89, 6, 66, 8, 58, 1, 71, 5, 52, 7, 44, 2, 29, 
    4,  3, 1, 72, 8, 41, 7, 47, 5,  7, 6, 94, 2, 70, 3, 96, 0, 90, 
    4, 82, 8, 94, 3, 27, 1, 78, 7, 95, 5, 27, 6, 14, 0, 81, 2, 60, 
    1, 45, 5, 13, 8, 92, 2, 37, 4, 21, 7, 42, 3, 16, 0, 96, 6, 53, 
    1, 33, 6, 53, 7, 40, 2, 89, 3, 34, 4, 39, 0, 49, 8, 92, 5, 29, 
    7, 10, 3, 38, 1, 54, 8, 31, 2, 52, 5,  4, 6,  1, 4, 71, 0, 68, 
    8, 97, 2, 14, 4, 20, 7, 44, 0, 18, 3,  9, 1, 25, 5,  9, 6, 76, 
    5, 56, 1, 57, 6, 89, 8, 35, 2, 68, 0, 97, 3, 38, 4, 62, 7, 81, 
    7, 81, 8, 81, 1, 48, 4, 87, 5, 76, 6, 60, 2, 20, 0,  8, 3, 50
  };
  const int q5239[] = {
    9, 9, // Number of jobs and machines
    2, 57, 6, 29, 3, 16, 7, 79, 4, 73, 1, 81, 5, 39, 8, 31, 0,  1, 
    6, 69, 2, 38, 4, 51, 3, 28, 0, 36, 8, 86, 7, 26, 1, 76, 5, 32, 
    0, 65, 6, 15, 7, 67, 2, 31, 4, 47, 1, 52, 8, 82, 3, 61, 5, 30, 
    2, 29, 6, 77, 4, 34, 8, 19, 3, 58, 1, 78, 0, 98, 5, 91, 7, 40, 
    3, 60, 6, 71, 1, 50, 2, 81, 8, 81, 0, 94, 4, 80, 7,  2, 5,  7, 
    2, 79, 7, 35, 5,  9, 1, 82, 0, 58, 4, 77, 8, 74, 3, 85, 6, 93, 
    8, 45, 0, 19, 5, 48, 2,  7, 4, 29, 7,  2, 3, 90, 6, 35, 1, 12, 
    7, 89, 3, 98, 5, 18, 0, 30, 4, 27, 8, 54, 2, 29, 6, 37, 1, 17, 
    3, 72, 2, 53, 5, 75, 1, 16, 7, 88, 4, 12, 8, 15, 0, 34, 6, 27
  };
  const int q5240[] = {
    9, 9, // Number of jobs and machines
    7, 98, 2, 35, 6, 83, 8, 51, 3, 78, 0, 62, 5, 74, 4, 45, 1, 91, 
    5, 91, 4, 94, 0, 59, 6, 26, 7, 27, 3, 80, 1, 66, 8, 27, 2, 76, 
    0, 10, 5, 35, 7, 78, 4, 40, 6,  4, 8, 34, 2, 97, 1, 13, 3,  1, 
    5, 55, 4, 55, 8, 78, 1, 36, 7, 59, 3, 83, 6, 25, 0, 41, 2, 44, 
    8, 42, 0, 62, 5, 63, 7, 55, 6, 93, 1, 97, 2, 25, 4, 31, 3, 17, 
    6,  1, 7, 67, 1, 19, 2, 87, 4, 51, 0, 51, 5, 79, 8, 88, 3, 40, 
    5, 76, 6, 69, 3, 97, 2, 56, 7, 19, 0, 74, 4, 31, 8, 63, 1, 11, 
    4, 61, 6, 35, 2, 65, 1, 40, 5, 21, 3, 82, 8, 46, 0, 47, 7,  2, 
    2, 25, 6, 84, 3, 52, 1, 37, 7, 25, 4, 29, 5, 29, 8, 68, 0, 38
  };
  const int q5241[] = {
    9, 9, // Number of jobs and machines
    0, 39, 8,  2, 3, 76, 6, 93, 5, 76, 4, 66, 7, 52, 1, 33, 2, 13, 
    7, 52, 3, 29, 5, 20, 8, 48, 4, 37, 6, 39, 2, 93, 1, 63, 0, 93, 
    2, 57, 4, 31, 5, 46, 6, 23, 3, 81, 7, 92, 1, 51, 8, 96, 0, 54, 
    1, 35, 0, 16, 2, 64, 6, 35, 4, 54, 7, 69, 3, 25, 8, 55, 5, 29, 
    6, 54, 1, 18, 3, 71, 7, 65, 8, 38, 4, 69, 5, 26, 2, 82, 0, 58, 
    6, 34, 7, 19, 3, 38, 1, 33, 2, 74, 5, 74, 8, 13, 0, 62, 4, 30, 
    2, 49, 3, 68, 1, 71, 6, 20, 4, 61, 5, 89, 7, 84, 0, 31, 8, 29, 
    7,  5, 1, 42, 6, 99, 3, 49, 2, 56, 8, 68, 5, 17, 0, 41, 4, 45, 
    4, 68, 8, 59, 5, 57, 6, 26, 1, 37, 7, 41, 2, 46, 0, 72, 3, 64
  };
  const int q5242[] = {
    9, 9, // Number of jobs and machines
    8, 82, 4, 16, 2, 53, 5, 73, 6, 44, 7, 88, 0, 24, 3,  1, 1, 10, 
    8, 31, 7, 39, 0,  9, 5, 36, 3, 56, 2, 41, 6, 89, 4, 90, 1, 35, 
    6, 31, 7, 99, 0, 74, 8, 72, 4, 70, 3, 30, 5, 78, 2, 30, 1,  6, 
    0, 10, 7, 89, 4, 93, 1, 59, 6, 53, 8, 67, 3, 51, 5, 97, 2, 82, 
    3, 70, 8, 27, 7, 36, 6, 82, 2, 50, 5,  8, 0, 46, 1, 27, 4, 91, 
    6, 85, 8, 54, 0, 64, 5, 90, 7, 64, 2, 44, 1, 74, 3, 27, 4, 72, 
    8, 75, 0, 47, 6, 43, 3, 66, 2, 90, 1, 93, 5, 54, 4, 94, 7, 26, 
    8, 35, 4, 40, 2, 51, 3, 69, 5, 54, 6, 80, 7,  1, 1, 50, 0,  9, 
    7, 42, 4, 52, 5, 99, 0, 26, 3, 18, 2,  5, 1, 90, 6, 98, 8,  8
  };
  const int q5243[] = {
    9, 9, // Number of jobs and machines
    0, 77, 7, 74, 1, 33, 6, 19, 3, 57, 8, 85, 4, 72, 2, 92, 5, 78, 
    2, 87, 3, 53, 5, 49, 6, 87, 7, 70, 1, 29, 0, 72, 8,  1, 4, 63, 
    4,  8, 0, 32, 1, 73, 6, 97, 3, 60, 5, 28, 8, 33, 2, 57, 7,  2, 
    4,  7, 6, 17, 3, 64, 5, 70, 7, 40, 0, 41, 2, 50, 1, 74, 8, 40, 
    7, 37, 4, 16, 1, 25, 0, 62, 5, 14, 6,  6, 3, 38, 2, 39, 8, 42, 
    3, 75, 8, 46, 4, 29, 5, 28, 0, 56, 7, 53, 1,  7, 6, 39, 2, 71, 
    5, 41, 8, 82, 0, 16, 1, 39, 2, 13, 6, 67, 4, 91, 7, 87, 3, 73, 
    1, 80, 7, 15, 5, 78, 0, 87, 3, 16, 6, 20, 8, 18, 2, 43, 4, 63, 
    7, 93, 1, 42, 4, 24, 5, 13, 2, 79, 0, 43, 8, 62, 6,  5, 3, 32
  };
  const int q5244[] = {
    9, 9, // Number of jobs and machines
    7,  6, 4, 70, 5, 66, 3, 34, 1, 62, 6, 53, 0, 73, 2, 51, 8, 69, 
    2, 21, 3,  2, 1, 29, 6, 22, 0, 98, 7,  8, 8, 26, 5, 45, 4,  8, 
    4,  9, 7, 77, 6, 60, 2, 53, 8, 45, 5, 55, 1, 30, 3, 31, 0, 23, 
    5, 28, 1, 94, 2, 17, 6, 69, 7,  4, 8, 33, 3, 44, 0,  4, 4, 17, 
    5, 74, 8, 54, 0,  9, 4, 55, 3, 79, 6, 53, 1, 34, 2, 78, 7, 95, 
    3, 59, 4, 55, 5, 13, 0, 65, 8, 60, 7, 11, 6, 30, 2, 80, 1, 44, 
    0, 49, 7, 18, 1, 16, 2, 10, 3, 91, 4, 98, 6, 92, 8, 92, 5,  3, 
    1, 98, 3, 91, 7, 40, 2, 41, 8, 58, 5, 99, 6, 26, 4, 75, 0, 19, 
    0, 30, 8, 36, 6, 57, 5, 18, 3, 76, 1, 67, 2, 85, 7, 78, 4, 23
  };
  const int q5245[] = {
    9, 9, // Number of jobs and machines
    0, 17, 2, 99, 1, 96, 6, 52, 5, 65, 8, 31, 4, 55, 3, 91, 7,  8, 
    8, 98, 1,  4, 0, 34, 5, 69, 2, 74, 4, 86, 7, 19, 3, 70, 6, 85, 
    7, 37, 0, 60, 1,  2, 6, 31, 4, 26, 5, 18, 2, 28, 3, 79, 8, 22, 
    1, 64, 4, 18, 3, 58, 8, 39, 2, 95, 5, 33, 6, 64, 0,  4, 7, 59, 
    0, 15, 7, 90, 4,  7, 5, 26, 3, 61, 8,  4, 6, 72, 1, 38, 2, 13, 
    2, 16, 0, 65, 7, 90, 6, 39, 8, 16, 1, 59, 5, 40, 4, 12, 3, 11, 
    2, 57, 4, 69, 0, 91, 7,  5, 6, 45, 5, 11, 3, 52, 8, 10, 1, 48, 
    3, 29, 1, 61, 5,  2, 6, 20, 4, 62, 0, 91, 8, 95, 7, 24, 2, 52, 
    3, 96, 0, 47, 2, 22, 4, 49, 8,  1, 6, 49, 7, 32, 5, 79, 1, 11
  };
  const int q5246[] = {
    9, 9, // Number of jobs and machines
    7, 27, 2, 74, 6,  9, 1, 50, 0, 27, 5,  9, 8, 13, 3, 93, 4, 68, 
    2, 90, 0, 17, 6, 56, 1,  2, 7, 27, 5, 90, 4, 40, 3, 78, 8, 53, 
    8,  7, 1, 75, 7, 49, 4, 93, 6, 80, 3, 45, 0, 96, 5, 68, 2, 25, 
    2, 48, 8, 25, 7, 38, 1, 75, 6,  1, 4, 31, 5, 30, 3, 38, 0, 39, 
    3, 97, 8, 80, 2,  5, 6, 77, 0, 68, 1, 92, 4, 16, 7, 26, 5, 53, 
    4, 29, 0, 81, 6, 51, 2, 88, 1, 79, 8, 75, 3, 30, 7, 73, 5,  1, 
    0, 88, 5, 18, 6, 82, 3,  7, 1, 25, 7,  6, 8,  7, 2, 25, 4, 99, 
    4, 86, 7, 93, 8, 81, 2, 81, 6, 63, 1, 86, 0,  1, 3, 38, 5, 61, 
    1, 30, 7, 71, 2, 17, 0, 27, 5, 60, 3, 88, 4, 54, 6, 99, 8, 60
  };
  const int q5247[] = {
    9, 9, // Number of jobs and machines
    1, 98, 0, 41, 8, 71, 4, 22, 2, 84, 6,  4, 3, 79, 7, 57, 5, 68, 
    7, 72, 1, 33, 5, 45, 8, 38, 4, 80, 3, 44, 2, 71, 0, 74, 6, 12, 
    0, 38, 2,  2, 1, 21, 6, 18, 4, 86, 8, 89, 3, 30, 7, 43, 5, 44, 
    6, 43, 7, 27, 3, 31, 4, 39, 0, 57, 5, 10, 8, 56, 1, 91, 2, 64, 
    2, 90, 7, 55, 3, 40, 1, 86, 0, 24, 4, 26, 8, 11, 5,  6, 6, 79, 
    4, 72, 3, 50, 1, 30, 6, 55, 2,  2, 0, 78, 8, 50, 5,  8, 7, 80, 
    4, 74, 0, 85, 6, 99, 1, 26, 7, 50, 5, 56, 8, 40, 3, 81, 2, 24, 
    4, 64, 2, 11, 5, 94, 8, 44, 0, 70, 7, 50, 1,  4, 3, 11, 6, 13, 
    8, 78, 1, 73, 3, 40, 6, 92, 5, 68, 0, 95, 4, 57, 7, 33, 2,  9
  };
  const int q5248[] = {
    9, 9, // Number of jobs and machines
    0, 67, 3,  1, 6, 99, 8, 97, 7, 12, 4, 11, 2, 17, 1, 49, 5, 42, 
    0, 70, 5, 13, 2,  6, 6, 22, 7, 33, 3, 88, 8, 92, 1, 41, 4, 40, 
    6, 83, 0, 38, 5, 21, 2, 77, 7, 71, 3, 97, 8, 65, 1, 39, 4, 31, 
    5, 50, 7, 68, 8, 91, 4, 87, 1, 99, 2, 20, 0, 73, 6, 17, 3, 28, 
    0,  4, 1, 25, 7,  7, 2, 10, 3, 59, 5, 67, 8, 69, 4,  4, 6, 55, 
    6, 16, 5,  9, 4, 61, 2, 99, 7, 89, 3, 42, 1, 74, 8, 81, 0,  6, 
    8, 37, 5, 54, 6, 80, 0,  7, 2, 15, 7, 14, 3, 77, 1, 41, 4, 93, 
    3, 69, 4, 18, 0, 94, 5,  6, 1, 83, 6,  2, 2, 37, 7,  3, 8,  2, 
    5, 67, 4, 48, 0, 46, 6, 24, 2, 46, 7, 58, 3, 47, 1, 72, 8,  9
  };
  const int q5249[] = {
    9, 9, // Number of jobs and machines
    5, 74, 7, 63, 4, 68, 2, 55, 8, 98, 3, 73, 0, 36, 1, 10, 6, 92, 
    4, 22, 3, 30, 5, 91, 8,  3, 2,  5, 0, 84, 1, 42, 7, 33, 6, 23, 
    8, 53, 6, 29, 0, 64, 1, 80, 4, 27, 3, 98, 2, 45, 7,  1, 5, 26, 
    7, 26, 8, 94, 5, 82, 3, 74, 1, 57, 2, 61, 0, 39, 4, 83, 6, 13, 
    1, 63, 5, 52, 7, 55, 3,  8, 8, 41, 4, 88, 0,  8, 2,  9, 6, 17, 
    0, 92, 7, 58, 6, 87, 4, 52, 2, 27, 5,  2, 8,  4, 1, 76, 3, 10, 
    0,  2, 7, 66, 1, 13, 6,  4, 4,  9, 3, 76, 2, 92, 8,  9, 5, 42, 
    2, 25, 3, 73, 1, 37, 6, 76, 0,  2, 7, 60, 4, 76, 5, 60, 8, 11, 
    0, 12, 6, 20, 1, 31, 2, 86, 5, 38, 8, 28, 7, 43, 3, 52, 4, 41
  };
  const int q5250[] = {
    9, 9, // Number of jobs and machines
    0, 48, 5, 80, 3, 25, 6, 34, 7, 86, 2, 62, 4, 50, 8, 28, 1,  5, 
    2, 64, 7, 40, 5, 68, 4, 40, 6, 25, 0, 43, 1, 98, 8, 39, 3, 25, 
    2, 51, 1, 37, 6, 77, 8, 77, 4, 91, 7, 95, 3, 24, 5, 92, 0, 55, 
    1, 83, 8, 46, 0, 63, 5, 97, 7,  2, 3, 10, 6, 37, 4, 85, 2, 91, 
    3, 96, 8, 53, 2, 42, 0, 38, 4, 60, 7, 97, 5, 15, 1, 64, 6, 84, 
    5, 23, 3, 73, 8, 77, 6, 39, 4, 32, 2, 66, 1, 77, 7,  5, 0, 64, 
    7, 43, 6, 55, 1, 24, 4, 40, 3, 66, 5, 53, 0, 79, 8,  4, 2, 37, 
    6, 64, 2,  8, 4, 32, 7, 69, 5, 72, 8, 36, 1, 80, 3,  2, 0, 19, 
    7, 41, 5, 37, 1, 47, 6, 99, 4, 95, 3, 21, 2, 62, 0, 36, 8, 98
  };
  const int q5251[] = {
    9, 9, // Number of jobs and machines
    1, 36, 6, 50, 0, 96, 8, 30, 7, 25, 4, 88, 5, 24, 2, 74, 3, 83, 
    2, 29, 4, 72, 1, 32, 7, 27, 3, 56, 0, 29, 5, 55, 8, 88, 6, 91, 
    7, 67, 4, 74, 6, 91, 1,  7, 5, 90, 2, 48, 3, 96, 0, 88, 8, 35, 
    8, 98, 1,  2, 4, 50, 7, 49, 6, 17, 0, 91, 2, 77, 3, 71, 5, 72, 
    2, 54, 4, 70, 1,  1, 5, 75, 8, 59, 7, 91, 6, 71, 0, 40, 3, 24, 
    6, 58, 7, 20, 4, 32, 1, 90, 3, 98, 2, 82, 5, 14, 0, 19, 8, 36, 
    7, 88, 1, 97, 6, 24, 5, 82, 3, 76, 2, 12, 4, 18, 0, 48, 8, 43, 
    0, 14, 3, 19, 1, 39, 6, 46, 4, 58, 5, 57, 8, 99, 7, 85, 2, 10, 
    3, 24, 8, 21, 0, 93, 7, 82, 6, 14, 5, 79, 1, 31, 2, 89, 4, 67
  };
  const int q5252[] = {
    9, 9, // Number of jobs and machines
    6, 44, 0, 99, 3, 89, 1, 16, 2, 84, 4, 29, 5, 53, 7, 73, 8,  5, 
    7, 74, 5, 46, 6, 79, 3, 81, 2, 63, 1, 79, 8, 16, 0, 14, 4, 64, 
    5,  1, 3, 69, 7, 48, 4, 38, 0, 91, 1, 92, 2, 68, 8, 10, 6, 90, 
    8, 76, 1,  5, 0, 44, 2, 30, 6, 73, 5, 45, 3, 99, 7, 72, 4, 81, 
    0,  5, 4, 95, 7, 44, 3, 87, 6,  8, 5, 94, 8,  9, 2, 10, 1, 22, 
    6, 69, 3, 60, 5,  2, 4, 69, 2, 89, 7, 65, 1, 63, 0, 27, 8, 12, 
    5, 34, 0, 45, 2, 12, 1, 83, 4, 15, 3, 67, 7, 90, 8, 68, 6, 85, 
    2, 14, 7, 16, 8, 58, 0, 22, 4,  7, 6, 34, 3, 32, 1, 22, 5, 27, 
    7, 29, 3, 85, 4, 60, 8,  9, 6, 32, 5, 16, 0,  4, 2, 90, 1, 45
  };
  const int q5253[] = {
    9, 9, // Number of jobs and machines
    2, 45, 5, 37, 3, 63, 4, 65, 6, 99, 7, 62, 0, 18, 8,  5, 1, 68, 
    3, 84, 2, 55, 7, 99, 0, 97, 4, 50, 8, 66, 1, 46, 5,  4, 6, 80, 
    5, 31, 7, 28, 4, 49, 8,  2, 2, 83, 3, 98, 0, 36, 1, 61, 6,  9, 
    4,  3, 7, 71, 3, 55, 1, 61, 8, 95, 0, 80, 5, 38, 2, 64, 6, 36, 
    8,  4, 6, 32, 0, 18, 2, 16, 5, 67, 7, 88, 4, 46, 1, 97, 3, 31, 
    1, 61, 7, 82, 5, 87, 6, 56, 0, 71, 4,  4, 8,  6, 3, 25, 2, 91, 
    3, 37, 7, 85, 1, 84, 2, 74, 5, 84, 0, 96, 6, 94, 4, 84, 8, 77, 
    4, 72, 3, 86, 7, 93, 0, 51, 8, 51, 6, 82, 1, 74, 5, 49, 2, 66, 
    3, 67, 1, 97, 7, 35, 6, 64, 0, 89, 8, 12, 5, 94, 4, 67, 2, 14
  };
  const int q5254[] = {
    9, 9, // Number of jobs and machines
    4,  6, 1, 68, 3, 79, 0, 87, 8, 77, 5, 58, 6, 83, 2, 32, 7, 79, 
    1, 64, 8, 31, 5, 20, 6, 25, 0, 29, 4, 23, 3, 49, 2, 77, 7, 88, 
    8, 72, 6, 44, 5, 76, 4, 56, 2, 60, 7, 38, 1, 26, 3, 18, 0, 47, 
    8, 80, 1, 35, 0, 80, 3, 34, 2, 20, 5, 17, 7, 31, 4, 74, 6, 79, 
    7, 55, 6, 74, 2, 35, 3, 72, 5, 83, 8,  9, 0, 20, 4, 21, 1, 72, 
    1, 48, 6, 65, 7, 51, 3, 11, 5, 36, 0, 25, 8, 94, 4, 26, 2, 19, 
    5, 71, 6, 52, 4, 64, 2, 50, 3, 80, 8, 22, 1, 18, 7, 38, 0, 40, 
    4, 30, 7, 49, 6, 83, 8, 94, 5, 79, 0, 65, 2, 84, 1, 49, 3, 78, 
    7, 89, 6, 73, 0,  9, 8, 99, 5, 31, 2, 39, 1, 27, 4, 74, 3,  1
  };
  const int q5255[] = {
    9, 9, // Number of jobs and machines
    0, 45, 5, 67, 8, 20, 6, 17, 3, 99, 1, 58, 2, 87, 4, 85, 7, 13, 
    3, 52, 1,  4, 5, 44, 4, 87, 0, 38, 2, 73, 7, 49, 8, 61, 6, 59, 
    1, 21, 2, 61, 5, 17, 7, 15, 3, 76, 0, 47, 6, 75, 8, 43, 4, 83, 
    4, 93, 2,  4, 1, 55, 5, 67, 3, 89, 6, 22, 7, 54, 8, 88, 0, 66, 
    7, 22, 2, 84, 0, 56, 8, 39, 1, 42, 4,  5, 3, 52, 5, 83, 6, 68, 
    5, 71, 0, 43, 2, 47, 6, 59, 7, 23, 4, 59, 3, 49, 8, 87, 1,  3, 
    5, 89, 6, 18, 7, 62, 8, 95, 3, 78, 4, 10, 2, 75, 1, 50, 0, 44, 
    7, 34, 5,  3, 1, 19, 6,  1, 3, 49, 8, 31, 0, 23, 4, 33, 2, 37, 
    5, 28, 7, 26, 1, 39, 8, 71, 2, 60, 0, 94, 3, 56, 4, 70, 6, 17
  };
  const int q5256[] = {
    9, 9, // Number of jobs and machines
    5, 79, 1, 71, 0, 22, 3, 32, 8, 46, 7,  9, 2, 91, 6, 31, 4, 33, 
    8, 37, 7, 34, 2, 27, 5, 33, 6, 45, 1, 74, 0, 96, 3,  3, 4, 61, 
    8, 96, 0, 25, 7, 53, 6, 18, 4, 29, 2, 48, 5, 42, 3, 43, 1, 32, 
    5, 25, 6, 52, 2, 91, 4, 82, 0, 34, 7, 91, 8, 75, 3, 17, 1, 71, 
    7, 28, 4, 58, 5, 38, 0, 22, 8,  6, 1, 49, 3, 48, 6, 86, 2,  1, 
    4, 87, 3,  7, 8, 18, 5, 14, 1, 85, 2, 74, 6, 65, 0, 48, 7, 69, 
    3,  7, 2, 47, 1,  7, 7, 66, 0, 95, 8, 78, 5, 72, 6, 94, 4,  7, 
    1, 11, 5, 23, 6, 75, 7, 16, 3, 90, 4, 91, 0, 81, 2, 37, 8, 46, 
    5, 19, 0, 95, 3, 36, 1, 11, 6, 61, 2, 63, 8, 99, 7, 95, 4, 59
  };
  const int q5257[] = {
    9, 9, // Number of jobs and machines
    1, 94, 7, 74, 4, 59, 3, 81, 2, 67, 8, 91, 6, 96, 5, 20, 0, 62, 
    4, 86, 0, 97, 7,  6, 2,  3, 5, 51, 1, 43, 6, 25, 3, 21, 8, 79, 
    4,  7, 7, 80, 1, 27, 6, 82, 0, 48, 8, 29, 2, 75, 3, 53, 5, 81, 
    8, 83, 7,  3, 3, 22, 0, 87, 6, 99, 5, 55, 4, 82, 2, 70, 1, 38, 
    4, 94, 0, 76, 3, 44, 2, 54, 8, 28, 6, 20, 7, 59, 5, 11, 1,  4, 
    1, 91, 0,  9, 6, 29, 7, 87, 5, 67, 2, 37, 8, 81, 4, 52, 3, 41, 
    0, 50, 1, 88, 6, 65, 7, 41, 5, 52, 3, 53, 2, 67, 4,  5, 8, 45, 
    4, 76, 1, 56, 3, 75, 0, 98, 5, 39, 8, 30, 7, 16, 2,  4, 6, 80, 
    6, 78, 1, 62, 3, 26, 2, 73, 8, 72, 0, 11, 4, 24, 5, 80, 7, 14
  };
  const int q5258[] = {
    9, 9, // Number of jobs and machines
    3, 97, 1, 38, 8, 23, 7, 58, 4, 58, 5,  2, 6, 30, 0, 56, 2, 54, 
    6, 34, 8, 54, 7, 99, 3, 69, 0, 78, 1, 27, 2, 47, 4, 35, 5, 61, 
    1, 11, 2, 46, 8, 31, 6, 79, 4, 81, 7, 92, 5, 32, 0, 28, 3, 64, 
    8, 46, 5, 51, 0,  6, 4, 45, 1, 76, 7, 54, 2, 59, 3, 45, 6, 69, 
    5, 21, 0, 17, 2, 11, 4, 69, 6, 27, 8,  9, 3, 93, 1, 21, 7, 92, 
    3,  6, 1, 75, 7, 40, 4, 93, 0,  1, 6, 63, 5, 48, 2, 47, 8,  1, 
    7, 74, 4, 87, 5, 27, 2, 27, 0, 18, 8, 39, 6, 10, 3, 63, 1, 76, 
    7,  1, 0, 61, 8, 57, 4,  8, 2, 46, 5, 39, 3,  8, 1, 39, 6, 98, 
    3, 22, 0, 46, 5, 85, 1,  6, 8, 41, 2, 43, 6, 94, 4, 39, 7, 58
  };
  const int q5259[] = {
    9, 9, // Number of jobs and machines
    2,  8, 3, 94, 4, 67, 8, 85, 6, 54, 5, 24, 7, 78, 0, 72, 1, 51, 
    3, 39, 0, 54, 1, 35, 2,  3, 5, 34, 8, 66, 6, 15, 7,  6, 4, 97, 
    0, 49, 8, 69, 2, 24, 6,  2, 4, 75, 1, 76, 7, 78, 3, 64, 5, 25, 
    7, 69, 8, 73, 4, 40, 0, 60, 3, 37, 6, 29, 1, 34, 5, 31, 2, 80, 
    8, 64, 2, 68, 3,  3, 4, 97, 6, 58, 0, 52, 5, 14, 1, 90, 7, 27, 
    5, 24, 3, 98, 6, 26, 8, 44, 7, 28, 2, 67, 1, 12, 0, 28, 4, 26, 
    5, 94, 0, 35, 3, 62, 2, 14, 6, 35, 8, 51, 1, 12, 4, 12, 7, 83, 
    7, 12, 5, 30, 3, 82, 2, 88, 6, 40, 8, 22, 4, 83, 1, 21, 0, 34, 
    4, 18, 6, 59, 0, 69, 3, 65, 5, 26, 1, 90, 2, 36, 7, 24, 8, 19
  };
  const int q5260[] = {
    9, 9, // Number of jobs and machines
    8, 22, 5, 79, 4, 79, 0, 14, 7, 10, 2, 95, 3, 78, 6, 56, 1, 38, 
    5, 35, 7, 77, 2, 32, 3,  3, 1, 41, 4, 89, 0, 43, 6, 81, 8, 24, 
    8,  7, 0, 77, 5, 49, 3, 82, 7, 92, 4,  4, 1, 21, 2, 13, 6, 47, 
    0, 20, 8, 47, 6,  2, 5, 82, 3, 31, 4, 41, 2, 72, 7, 62, 1, 19, 
    1, 22, 8,  5, 2,  3, 7, 74, 4, 26, 6, 79, 5,  8, 0,  6, 3,  9, 
    4, 19, 8, 54, 3, 68, 7, 73, 1,  4, 5, 14, 2, 34, 0,  8, 6, 41, 
    2, 81, 1, 44, 4, 19, 5, 25, 6, 88, 0, 90, 7, 30, 8, 75, 3, 38, 
    8, 73, 0, 35, 5, 10, 1, 24, 7, 72, 2, 43, 3, 21, 6, 54, 4, 58, 
    1, 32, 0, 69, 5, 11, 2, 96, 7, 20, 3, 77, 4, 55, 6, 91, 8, 81
  };
  const int q5261[] = {
    9, 9, // Number of jobs and machines
    7, 84, 3, 54, 8, 74, 5, 48, 2, 30, 0, 43, 1, 82, 6, 64, 4, 53, 
    0, 68, 4, 48, 1, 55, 5, 52, 3, 33, 6, 41, 2, 24, 8, 64, 7, 78, 
    0, 37, 4, 12, 2, 54, 6, 16, 7, 79, 8, 50, 5, 65, 3, 62, 1,  1, 
    7, 70, 6, 21, 0,  9, 3, 73, 1, 95, 8, 35, 5, 58, 4, 31, 2, 87, 
    7, 94, 1, 12, 3, 56, 0, 60, 5, 16, 8, 85, 2, 45, 6, 83, 4, 62, 
    7, 23, 6, 62, 8, 63, 2, 53, 3, 99, 5,  9, 1, 98, 4, 63, 0, 78, 
    7, 50, 3, 96, 5, 47, 0, 59, 2, 21, 4, 23, 1,  4, 8, 22, 6,  6, 
    6,  6, 7,  3, 1,  3, 3, 75, 4, 16, 5, 43, 2, 49, 0, 43, 8, 80, 
    6, 73, 0, 57, 5,  5, 3,  8, 8,  2, 1, 69, 2,  4, 4, 86, 7,  1
  };
  const int q5262[] = {
    9, 9, // Number of jobs and machines
    6, 26, 5, 59, 0, 52, 8, 71, 2, 32, 1, 99, 4, 69, 7, 74, 3, 75, 
    0, 79, 3, 86, 1, 73, 5, 77, 6, 92, 7, 70, 4, 49, 8, 98, 2, 75, 
    1, 93, 4, 25, 0, 71, 8, 49, 3, 91, 2, 72, 6, 79, 7, 91, 5, 92, 
    4, 50, 2, 75, 7, 22, 1, 22, 5, 15, 6, 25, 8, 29, 0, 28, 3, 87, 
    4, 94, 1, 91, 2, 41, 7, 16, 0,  3, 3, 37, 8, 14, 5, 70, 6, 99, 
    8, 98, 3,  2, 0, 43, 5, 97, 6, 99, 2, 11, 1, 36, 4, 47, 7, 57, 
    6, 51, 4, 53, 7, 81, 0, 88, 1, 26, 8, 77, 3, 19, 2, 22, 5,  5, 
    2, 11, 6, 43, 8, 90, 3, 20, 7, 33, 5, 84, 4,  9, 0, 75, 1, 71, 
    4, 27, 2, 51, 5, 66, 8, 75, 3, 98, 1, 15, 6, 57, 7, 15, 0, 31
  };
  const int q5263[] = {
    9, 9, // Number of jobs and machines
    3, 98, 6, 19, 7, 91, 4, 50, 0, 92, 2, 38, 8, 47, 1, 61, 5, 57, 
    0, 74, 5,  5, 7, 40, 6, 39, 4, 11, 3, 26, 2, 61, 1, 66, 8, 59, 
    6, 24, 1, 27, 8,  1, 2,  6, 4, 36, 5, 16, 7, 70, 0, 31, 3, 10, 
    2, 75, 4, 75, 8, 67, 1, 90, 5, 28, 0, 44, 3, 24, 6, 98, 7, 86, 
    5, 29, 8, 81, 0, 68, 7, 92, 2, 16, 3, 99, 1, 83, 6, 73, 4, 34, 
    8, 69, 1, 87, 7,  1, 5, 81, 3, 79, 2, 18, 4, 78, 6, 21, 0, 81, 
    6,  2, 5, 13, 4, 15, 2, 91, 8, 20, 1, 31, 7, 85, 3, 17, 0, 37, 
    1,  7, 2, 57, 6,  1, 0, 91, 7, 23, 4, 92, 8, 53, 3, 69, 5, 85, 
    4, 68, 5, 57, 7, 83, 2, 56, 6, 66, 8, 55, 3, 49, 1, 86, 0, 79
  };
  const int q5264[] = {
    9, 9, // Number of jobs and machines
    5, 99, 8, 33, 2, 63, 1, 95, 7, 56, 3, 21, 6, 80, 0, 93, 4, 17, 
    8, 39, 4,  1, 7,  1, 1, 46, 2, 32, 5, 10, 3, 22, 6, 75, 0, 86, 
    3, 73, 1, 43, 7, 91, 2, 45, 8, 73, 0, 28, 4, 83, 5, 48, 6, 31, 
    8, 93, 7, 57, 0, 14, 1,  2, 4, 75, 6,  5, 2, 86, 3, 19, 5, 14, 
    7, 69, 2, 97, 0,  3, 1, 47, 6, 98, 4, 30, 8,  6, 3, 83, 5, 73, 
    3, 92, 5,  2, 4, 32, 1,  5, 2, 73, 0, 12, 8,  9, 7, 90, 6, 51, 
    3, 92, 4,  2, 6, 88, 2, 55, 0, 92, 7, 35, 1, 98, 8, 47, 5, 19, 
    8, 65, 7, 39, 3, 13, 6, 88, 5, 48, 1, 92, 2, 67, 0, 60, 4, 48, 
    4, 57, 7, 32, 2, 64, 0, 44, 6, 98, 8, 73, 3, 69, 5, 26, 1, 92
  };
  const int q5265[] = {
    9, 9, // Number of jobs and machines
    3, 93, 6, 81, 4, 37, 1, 93, 5, 37, 7, 82, 0, 59, 2, 69, 8, 68, 
    6, 61, 7, 10, 8, 83, 4, 85, 2, 48, 0, 49, 5, 38, 3, 61, 1, 80, 
    5, 62, 1, 60, 0, 51, 8,  2, 3,  1, 6, 74, 4, 23, 7, 46, 2, 91, 
    5, 98, 2, 81, 1, 31, 4, 77, 8, 12, 6, 12, 0, 94, 7, 73, 3, 38, 
    3, 83, 7, 51, 1, 71, 2,  8, 5, 25, 8, 74, 0, 94, 4, 34, 6, 31, 
    3, 32, 1, 20, 7, 29, 0, 59, 6, 37, 8, 60, 5, 81, 2, 74, 4, 13, 
    3, 20, 6, 69, 0, 98, 4, 29, 5, 34, 8, 54, 2, 42, 7, 22, 1, 23, 
    7, 88, 4,  7, 6, 43, 1, 80, 8, 61, 2, 15, 3, 59, 5, 68, 0, 72, 
    2,  2, 6, 18, 0, 73, 3, 91, 7, 19, 1,  7, 8, 67, 5, 50, 4, 59
  };
  const int q5266[] = {
    9, 9, // Number of jobs and machines
    2, 56, 5, 19, 8, 99, 1, 21, 6, 50, 7, 75, 4, 14, 3, 60, 0, 24, 
    1, 61, 5, 14, 7, 23, 0, 69, 2, 17, 6, 34, 3, 59, 4, 80, 8, 59, 
    0, 38, 7, 28, 4, 85, 3, 91, 8,  1, 1, 28, 6, 79, 2, 41, 5, 29, 
    4, 95, 6, 13, 2, 57, 3, 53, 0, 29, 5, 91, 7, 56, 1, 49, 8, 79, 
    5, 36, 6, 67, 7, 68, 2, 81, 4, 78, 3, 63, 8, 53, 1, 93, 0, 15, 
    0, 28, 2, 18, 1, 19, 8,  7, 6, 16, 4, 38, 7, 78, 5,  2, 3, 84, 
    0, 95, 8, 38, 5, 21, 7, 29, 3, 50, 1, 79, 2, 42, 6,  5, 4, 94, 
    3,  1, 4, 42, 1, 83, 7, 84, 0, 69, 2, 88, 6, 83, 5, 36, 8, 17, 
    3, 43, 2, 68, 7, 59, 4, 81, 1, 26, 5, 79, 8, 13, 0, 10, 6, 65
  };
  const int q5267[] = {
    9, 9, // Number of jobs and machines
    2, 91, 6, 40, 3, 94, 0, 51, 5, 68, 8, 16, 7, 64, 4, 42, 1, 88, 
    4, 46, 3, 78, 5, 36, 0, 94, 8, 52, 1,  6, 2, 99, 7, 38, 6, 96, 
    1, 78, 7, 78, 5, 92, 2, 34, 3, 26, 6, 93, 4, 21, 0,  3, 8,  7, 
    1, 93, 4, 86, 2, 61, 8, 44, 5, 25, 7, 62, 3, 38, 6, 18, 0, 65, 
    3, 26, 2, 25, 0, 85, 1, 35, 6, 20, 5, 23, 4,  8, 8,  9, 7, 41, 
    1, 55, 6, 63, 4, 71, 0, 69, 3, 23, 2, 20, 5, 24, 8, 43, 7, 17, 
    0, 51, 3, 71, 7, 59, 5, 36, 8, 14, 2, 49, 1, 49, 6, 37, 4, 38, 
    7, 33, 2, 96, 0, 18, 3, 43, 8, 73, 6, 82, 5, 87, 1, 99, 4, 40, 
    4, 26, 1, 24, 7, 34, 0, 83, 3, 58, 5, 66, 2, 77, 6, 60, 8, 84
  };
  const int q5268[] = {
    9, 9, // Number of jobs and machines
    4, 51, 1, 60, 2, 13, 3,  3, 5, 73, 8, 46, 6, 25, 7, 98, 0, 91, 
    6, 89, 8, 69, 1, 12, 5, 51, 2, 86, 3, 36, 7, 73, 0, 67, 4, 16, 
    1, 41, 6, 11, 4, 78, 5, 86, 3, 28, 7, 51, 0, 82, 8, 40, 2, 49, 
    1, 31, 5, 99, 8, 39, 3, 32, 6, 10, 7, 51, 4, 52, 0, 54, 2, 89, 
    1, 97, 2, 34, 6, 65, 8, 69, 3, 15, 7, 63, 4, 53, 5, 15, 0, 76, 
    4, 24, 6, 47, 7, 92, 8, 40, 5, 67, 2, 55, 1, 35, 0, 92, 3, 76, 
    2, 76, 1, 84, 7, 45, 3, 34, 6, 70, 0, 20, 8, 17, 4, 81, 5, 99, 
    3, 83, 2, 40, 6, 99, 7, 27, 4, 68, 0, 74, 5, 55, 8, 71, 1, 42, 
    8, 51, 3, 67, 6, 65, 5,  1, 4, 72, 1, 18, 2, 50, 0, 31, 7, 53
  };
  const int q5269[] = {
    9, 9, // Number of jobs and machines
    7, 65, 1, 17, 6, 69, 0, 68, 4, 54, 5, 10, 3, 18, 2, 71, 8, 71, 
    5, 23, 0, 39, 8, 15, 6, 38, 4, 83, 2, 57, 1, 26, 7, 54, 3,  9, 
    6, 52, 1, 27, 0, 43, 3, 44, 7, 31, 2, 84, 8, 37, 4, 92, 5, 82, 
    7, 29, 6, 15, 0, 67, 5, 15, 2, 68, 3, 89, 8, 19, 4, 44, 1, 39, 
    7, 51, 6, 31, 3, 71, 5, 32, 4, 11, 8, 32, 2,  4, 0, 31, 1,  6, 
    7, 94, 5, 83, 0, 95, 6, 44, 4, 90, 2, 77, 1, 45, 8, 52, 3, 41, 
    4, 95, 5, 67, 6, 69, 1, 44, 8, 66, 0, 52, 3,  7, 2, 35, 7,  7, 
    3, 97, 6, 30, 0, 10, 7, 31, 4, 36, 2, 17, 1, 20, 5, 99, 8,  5, 
    2, 12, 0, 88, 7, 56, 4, 14, 8, 17, 5, 91, 6, 70, 3, 73, 1, 98
  };
  const int q5270[] = {
    9, 9, // Number of jobs and machines
    6, 38, 2, 34, 8, 47, 3, 92, 7, 76, 1, 42, 5, 60, 4, 23, 0, 10, 
    6, 12, 0, 36, 7, 92, 2, 30, 4, 14, 3, 17, 8, 38, 1, 83, 5, 11, 
    2, 20, 1, 15, 8, 38, 5, 26, 6, 22, 3, 57, 4, 31, 0, 21, 7, 24, 
    8, 16, 4,  2, 1, 78, 2, 41, 3, 73, 0, 81, 6, 45, 5,  3, 7, 39, 
    4, 63, 5, 60, 2, 29, 6, 86, 8, 95, 7, 68, 3, 57, 0, 31, 1, 48, 
    2, 72, 7, 41, 8, 17, 3, 43, 5, 60, 0, 58, 6, 59, 1, 76, 4,  8, 
    2, 65, 7, 60, 4, 98, 5, 29, 3, 29, 6, 82, 1, 29, 0, 49, 8, 60, 
    0,  8, 8, 90, 2, 79, 4,  8, 3,  1, 6, 70, 5, 14, 7, 75, 1,  7, 
    8, 13, 0, 96, 7, 67, 4, 57, 1,  2, 5, 26, 6, 93, 2, 91, 3, 37
  };
  const int q5271[] = {
    9, 9, // Number of jobs and machines
    5,  2, 6,  3, 7, 86, 3, 97, 0, 33, 1, 49, 8, 38, 4, 27, 2, 45, 
    7, 64, 6, 42, 1, 92, 3, 69, 0, 46, 4,  8, 2, 93, 5, 74, 8, 43, 
    7, 27, 4, 72, 3, 20, 5, 14, 0, 65, 1, 31, 2, 95, 8, 30, 6, 50, 
    0, 73, 1, 14, 5, 11, 6, 61, 2, 74, 3, 48, 4, 53, 8, 25, 7, 59, 
    0, 41, 1, 31, 7, 74, 3,  3, 5, 74, 2, 18, 4, 75, 6, 13, 8, 57, 
    4, 17, 1, 21, 6, 86, 2, 73, 3, 32, 8, 75, 0, 36, 5, 11, 7, 74, 
    8, 17, 6, 96, 4, 73, 5, 66, 0, 80, 1, 78, 3, 79, 7, 69, 2, 14, 
    5, 29, 0, 37, 8, 72, 3, 64, 2, 29, 6, 83, 1, 17, 4, 77, 7, 86, 
    8, 40, 6, 68, 2, 12, 5,  1, 0, 99, 4, 34, 3, 52, 7, 36, 1, 69
  };
  const int q5272[] = {
    9, 9, // Number of jobs and machines
    1, 87, 8, 40, 6, 52, 0, 58, 4, 45, 5, 45, 2, 55, 7,  1, 3, 63, 
    8, 72, 5, 73, 6, 70, 2, 64, 0, 90, 4, 43, 1, 52, 7, 18, 3, 27, 
    1,  5, 8,  4, 5, 69, 4, 56, 2, 95, 3, 88, 0, 46, 6,  6, 7, 53, 
    0, 70, 3, 24, 5,  5, 1,  7, 8, 37, 2, 70, 6, 41, 7, 70, 4, 81, 
    2, 97, 5, 97, 8, 73, 1, 99, 6, 78, 0, 20, 4, 61, 7, 96, 3, 50, 
    6, 67, 3, 56, 0, 64, 8, 67, 1, 16, 2, 63, 4, 61, 7, 40, 5, 28, 
    0, 37, 1, 86, 4, 27, 2, 80, 6, 40, 3, 48, 8, 99, 7, 10, 5, 50, 
    4, 33, 0,  1, 3, 88, 8, 40, 2, 22, 7, 64, 5, 63, 1, 99, 6, 86, 
    0, 38, 8, 82, 4, 82, 6, 19, 2, 17, 5,  2, 7, 22, 1, 39, 3, 79
  };
  const int q5273[] = {
    9, 9, // Number of jobs and machines
    8, 20, 7, 47, 2, 13, 5, 82, 1, 10, 6, 45, 3,  3, 4, 84, 0, 18, 
    3, 19, 2, 87, 4, 83, 1, 99, 6, 56, 5, 83, 0, 23, 8, 65, 7,  3, 
    6, 24, 1, 44, 2, 72, 4, 72, 7, 83, 5, 11, 0,  7, 8, 38, 3, 58, 
    5, 40, 3,  8, 8, 49, 1, 14, 4, 89, 7, 89, 6, 61, 0, 61, 2, 37, 
    6, 73, 0, 23, 3, 84, 1,  4, 5, 93, 7, 63, 4, 77, 2, 27, 8, 15, 
    1, 54, 0, 81, 3, 31, 2, 51, 4, 37, 6, 60, 7, 20, 8, 32, 5, 63, 
    6,  1, 1,  5, 0, 62, 8,  2, 2, 84, 3, 41, 4, 15, 7, 17, 5, 83, 
    4, 34, 6, 47, 5, 67, 1, 86, 2, 20, 0, 92, 8, 95, 7, 13, 3, 35, 
    7, 97, 5, 87, 0, 67, 3,  4, 4, 64, 8, 42, 2,  8, 6, 75, 1,  1
  };
  const int q5274[] = {
    9, 9, // Number of jobs and machines
    8,  2, 1, 34, 0, 69, 2, 58, 3, 29, 5, 96, 6, 87, 7, 56, 4, 55, 
    5, 56, 0, 36, 6, 68, 2, 66, 4, 20, 7, 70, 1, 65, 3, 97, 8, 92, 
    4,  7, 8,  5, 5, 16, 7, 86, 2, 60, 6, 54, 0, 44, 1, 24, 3, 78, 
    2,  9, 0, 98, 7,  4, 5, 83, 1, 57, 6, 84, 3, 15, 4, 33, 8, 72, 
    1,  1, 5, 98, 8, 36, 3, 36, 6, 43, 7, 92, 0, 26, 4, 90, 2, 81, 
    4, 71, 3, 26, 7, 57, 6, 21, 0, 79, 2, 80, 8, 30, 5,  2, 1, 28, 
    3, 67, 7, 14, 5,  8, 6, 78, 1, 93, 0, 56, 8, 37, 2, 89, 4, 75, 
    6, 17, 5, 37, 3, 97, 8, 56, 4, 75, 0, 91, 1, 21, 7,  5, 2, 59, 
    2, 44, 3, 66, 1, 14, 8, 23, 6, 75, 4, 91, 7, 49, 0, 52, 5, 22
  };
  const int q5275[] = {
    9, 9, // Number of jobs and machines
    6, 66, 0, 50, 1, 94, 3, 48, 4, 49, 5, 92, 8, 69, 7, 94, 2, 60, 
    7, 97, 1, 18, 8, 61, 0, 29, 6, 41, 5, 22, 2, 20, 4, 51, 3, 43, 
    2, 49, 8, 67, 3, 22, 6, 50, 1, 29, 4, 59, 5, 42, 7, 79, 0, 72, 
    3, 19, 8, 27, 1, 98, 7, 32, 5, 81, 0, 80, 4, 73, 6,  5, 2, 31, 
    4, 74, 0, 21, 6, 14, 8, 23, 7, 80, 3, 12, 5, 13, 2, 56, 1, 60, 
    4,  8, 6, 44, 5, 17, 7, 22, 0, 19, 3, 43, 1, 78, 2, 50, 8, 77, 
    5, 46, 4,  9, 7, 10, 1, 43, 3, 30, 6, 14, 0, 21, 8, 60, 2, 82, 
    6, 85, 8, 80, 0, 58, 3, 99, 7, 70, 1, 39, 5, 15, 2,  4, 4, 82, 
    0, 46, 8, 40, 5, 74, 4, 66, 1, 14, 7, 74, 2, 22, 3, 18, 6, 87
  };
  const int q5276[] = {
    9, 9, // Number of jobs and machines
    6, 68, 3, 27, 4, 47, 2, 71, 5, 40, 1, 44, 7, 34, 8, 51, 0, 60, 
    5, 96, 2, 15, 1, 15, 3, 47, 8,  6, 7, 19, 4, 73, 0, 20, 6, 28, 
    0, 24, 1, 44, 7, 88, 3, 30, 6, 47, 8, 62, 5, 88, 2, 84, 4, 54, 
    2, 41, 5, 80, 7, 30, 8, 95, 1, 27, 6, 65, 3,  4, 0,  2, 4, 87, 
    7, 20, 5, 61, 6, 40, 0, 20, 1,  9, 8, 57, 2, 79, 3,  4, 4, 59, 
    3, 58, 2, 19, 7, 85, 0, 90, 5, 19, 4, 89, 8, 46, 6, 27, 1, 53, 
    4, 20, 5, 74, 7,  5, 3, 74, 2, 35, 6, 95, 1, 28, 8, 21, 0, 86, 
    0, 23, 3, 52, 1, 66, 4, 86, 2, 77, 7, 72, 5, 31, 8,  6, 6, 28, 
    4, 95, 5, 17, 8, 75, 7, 19, 2, 97, 6,  7, 0, 82, 3, 46, 1, 36
  };
  const int q5277[] = {
    9, 9, // Number of jobs and machines
    4, 27, 5, 60, 3, 37, 8, 32, 6, 88, 7, 54, 1, 69, 2, 99, 0, 97, 
    3, 11, 6, 23, 8, 33, 0, 65, 7, 99, 2, 14, 4, 74, 1, 35, 5, 27, 
    6, 21, 3, 47, 4, 57, 7, 25, 8, 19, 0, 59, 5, 12, 2, 94, 1, 49, 
    2,  4, 1, 45, 0, 23, 6, 32, 8, 25, 7, 64, 4, 74, 3, 48, 5, 93, 
    5, 78, 1, 77, 4, 12, 0, 82, 6, 62, 7, 54, 3, 36, 8, 25, 2, 58, 
    3, 43, 7, 36, 5, 89, 4, 77, 8, 72, 0, 79, 6, 75, 2, 61, 1, 35, 
    0, 62, 5, 81, 3, 22, 7, 44, 6, 62, 1, 68, 8, 61, 4,  3, 2,  8, 
    3, 70, 0, 16, 2, 86, 4, 50, 1, 80, 8, 77, 5,  3, 7, 70, 6, 46, 
    3, 33, 8, 70, 0, 66, 5, 61, 2,  9, 7, 46, 4, 91, 6, 54, 1, 62
  };
  const int q5278[] = {
    9, 9, // Number of jobs and machines
    2, 89, 5, 38, 1, 60, 4, 11, 0, 18, 3, 89, 8, 55, 6, 66, 7, 34, 
    2, 83, 3, 72, 0, 76, 8, 22, 4, 73, 5, 25, 1, 61, 7, 58, 6, 78, 
    1, 38, 7, 15, 3, 91, 0, 57, 4, 11, 8,  4, 2, 47, 5, 99, 6, 92, 
    7, 18, 6, 39, 3, 78, 4, 94, 8, 26, 0, 36, 1, 34, 2,  8, 5, 74, 
    8, 80, 4, 46, 2, 16, 0, 11, 7, 27, 5, 78, 6, 79, 3, 37, 1, 60, 
    3, 32, 6, 67, 4, 36, 1, 27, 8, 25, 7, 48, 5, 98, 2, 99, 0, 27, 
    7, 35, 4, 57, 1, 90, 6, 85, 2, 22, 3, 41, 0, 42, 5, 23, 8, 83, 
    5, 33, 4, 69, 7, 98, 0, 29, 3, 25, 8, 60, 6, 20, 2, 35, 1, 18, 
    8, 89, 2, 12, 3, 58, 5, 47, 1, 85, 6, 45, 4, 99, 7, 18, 0, 91
  };
  const int q5279[] = {
    9, 9, // Number of jobs and machines
    7, 57, 8, 91, 6,  7, 3, 42, 1, 30, 2, 68, 5, 18, 4, 93, 0, 69, 
    7, 79, 3, 21, 1, 50, 4, 13, 5, 10, 2, 36, 8, 62, 6, 91, 0, 95, 
    8, 18, 1, 67, 6, 62, 5, 13, 7, 54, 3, 27, 4, 79, 0, 29, 2, 15, 
    1, 97, 0, 71, 4, 42, 5, 43, 3, 20, 6, 30, 7, 55, 2, 66, 8, 87, 
    3, 12, 0, 81, 8, 25, 1, 15, 6, 68, 7, 36, 4, 59, 2, 96, 5, 89, 
    3, 17, 0, 75, 7,  2, 4,  8, 6, 81, 1, 60, 2, 10, 8, 25, 5, 49, 
    4, 13, 3,  2, 1, 75, 0, 42, 2, 32, 8, 24, 6, 60, 5, 47, 7, 81, 
    5, 49, 1, 68, 3, 95, 0, 21, 8, 86, 2, 93, 4, 36, 7, 56, 6, 76, 
    8, 95, 4, 22, 5,  3, 1, 85, 2, 53, 0, 15, 7, 55, 3, 38, 6, 58
  };
  const int q5280[] = {
    9, 9, // Number of jobs and machines
    0, 68, 5, 97, 1, 62, 8, 10, 7,  8, 3, 43, 6, 49, 2, 85, 4, 73, 
    2, 30, 4,  9, 5, 39, 3, 49, 0, 44, 8, 28, 1, 95, 6, 91, 7, 14, 
    0, 25, 5, 66, 7,  9, 8, 92, 1, 62, 4, 74, 6, 14, 2, 97, 3, 45, 
    4, 23, 6,  7, 2, 22, 7, 27, 0, 41, 5,  1, 3, 71, 1, 68, 8, 54, 
    2, 69, 1, 92, 5,  8, 3,  9, 4, 78, 8, 22, 0, 18, 6, 86, 7, 80, 
    4, 38, 6, 27, 8, 66, 1, 64, 2, 27, 3, 29, 0, 91, 7, 57, 5, 41, 
    7, 55, 0, 90, 3, 15, 8, 42, 1, 79, 4, 62, 6, 34, 2, 23, 5, 53, 
    6, 42, 5, 39, 4, 19, 0, 44, 8, 83, 7, 60, 1, 49, 3, 96, 2, 31, 
    4, 93, 5, 25, 8, 32, 2, 96, 6, 47, 3, 15, 0, 42, 1, 35, 7, 52
  };
  const int q5281[] = {
    9, 9, // Number of jobs and machines
    5, 70, 6, 25, 0, 90, 4, 87, 8, 84, 7, 71, 3, 86, 2,  2, 1, 96, 
    6, 30, 3, 61, 5, 94, 0,  2, 2, 44, 7, 79, 8, 39, 1,  3, 4, 16, 
    4, 16, 6, 50, 2,  6, 8, 94, 1, 77, 5, 63, 7, 98, 3, 25, 0,  4, 
    2, 97, 3, 69, 8, 16, 7, 69, 5, 72, 0, 83, 4, 93, 1, 97, 6, 45, 
    0, 23, 2, 33, 7, 83, 3, 68, 4, 50, 8, 53, 5, 26, 1,  4, 6, 41, 
    7, 84, 4, 81, 5, 22, 1, 90, 6, 53, 0, 80, 3,  4, 8, 42, 2, 25, 
    7, 22, 1, 46, 5, 47, 4, 43, 3, 95, 8, 31, 6, 99, 2, 92, 0, 60, 
    1, 76, 2, 92, 5, 43, 0, 30, 6, 41, 8, 94, 3, 29, 7, 22, 4, 61, 
    1, 37, 5, 83, 6, 81, 4, 90, 0, 18, 8, 50, 7, 71, 2, 50, 3, 61
  };
  const int q5282[] = {
    9, 9, // Number of jobs and machines
    4, 35, 1, 71, 5,  8, 7, 43, 3, 48, 0, 67, 8, 99, 6, 21, 2, 36, 
    2, 35, 8, 23, 7, 19, 4, 88, 3, 60, 6, 30, 5, 90, 0, 98, 1, 25, 
    5, 57, 8, 69, 7,  5, 2, 56, 6, 49, 4, 83, 1, 33, 0, 53, 3, 76, 
    8, 57, 1, 93, 5, 12, 4, 98, 0, 97, 3, 11, 6, 62, 7, 18, 2, 27, 
    8, 81, 0, 40, 4, 47, 7, 48, 1, 34, 6, 30, 5, 62, 2, 19, 3, 49, 
    5, 89, 8, 10, 4, 59, 6, 52, 1, 54, 2, 57, 7, 55, 0, 52, 3, 70, 
    8, 18, 3,  5, 0, 70, 2,  6, 4, 73, 1, 45, 6, 75, 5, 39, 7, 16, 
    7, 70, 5, 75, 8,  1, 4, 64, 6, 55, 0, 55, 2, 35, 3, 89, 1, 73, 
    2, 22, 5, 52, 8, 68, 1, 49, 7, 46, 3, 89, 6, 95, 0, 56, 4, 31
  };
  const int q5283[] = {
    9, 9, // Number of jobs and machines
    7, 21, 8, 61, 1,  9, 4, 22, 3,  2, 0, 60, 2,  2, 6, 23, 5, 91, 
    5, 63, 2, 90, 4, 52, 6, 47, 8, 78, 0, 70, 7, 75, 1,  4, 3, 45, 
    6,  9, 5, 77, 2, 99, 0, 23, 3, 53, 1, 13, 7, 57, 4, 94, 8, 34, 
    6, 55, 4,  4, 2, 75, 7, 47, 3,  2, 0, 85, 5, 17, 1, 81, 8, 80, 
    2, 22, 8, 36, 3, 81, 6, 45, 0, 42, 4, 57, 1, 32, 5, 72, 7, 84, 
    3, 34, 0, 39, 7, 77, 6, 53, 1,  9, 2, 47, 5, 77, 4, 83, 8,  4, 
    3,  7, 4,  6, 1, 37, 6, 36, 0,  6, 7, 18, 5, 42, 8, 54, 2, 34, 
    3, 12, 1, 42, 8, 94, 5, 28, 0, 39, 7, 86, 2, 83, 4, 31, 6, 82, 
    6, 32, 8, 26, 7, 49, 0, 37, 1, 27, 3, 31, 5, 60, 2, 57, 4, 99
  };
  const int q5284[] = {
    9, 9, // Number of jobs and machines
    2,  3, 7, 85, 0, 81, 5, 99, 8, 14, 3, 42, 1, 63, 4,  1, 6, 33, 
    6, 11, 0, 96, 5,  3, 2, 23, 4, 96, 3, 36, 7, 33, 1, 23, 8, 13, 
    8, 51, 2, 16, 4, 54, 5, 79, 0, 93, 6,  3, 1,  5, 7, 90, 3, 79, 
    2,  8, 3, 20, 1, 98, 0, 10, 8, 88, 5, 55, 6, 48, 4,  1, 7, 60, 
    7, 13, 3, 15, 5, 68, 2, 90, 0, 43, 4, 19, 8, 30, 6, 58, 1, 33, 
    7, 70, 2, 35, 0, 46, 3, 48, 6, 39, 5, 63, 4, 96, 8, 70, 1, 56, 
    3, 21, 8, 87, 1, 63, 2, 32, 7, 21, 0, 92, 4, 74, 5, 15, 6, 21, 
    5, 44, 3, 51, 1, 37, 2, 20, 0, 68, 4, 51, 6, 33, 7, 40, 8, 83, 
    0, 82, 6, 81, 4, 20, 2,  5, 3, 15, 5, 21, 7,  9, 1, 22, 8, 69
  };
  const int q5285[] = {
    9, 9, // Number of jobs and machines
    6, 64, 8, 48, 4, 35, 1, 24, 3, 74, 7, 84, 0, 30, 2, 69, 5, 57, 
    3, 22, 8, 43, 2, 67, 0, 22, 5, 95, 7, 22, 4, 98, 6, 45, 1, 12, 
    5, 76, 1, 57, 0, 40, 2, 60, 3,  2, 7, 27, 4, 14, 6, 91, 8, 17, 
    2, 36, 3, 12, 4, 86, 6, 37, 0,  4, 8, 25, 1, 75, 5, 75, 7, 10, 
    0, 91, 4, 29, 3, 30, 1, 18, 2, 87, 8, 67, 5, 76, 6, 71, 7, 61, 
    8,  8, 4, 27, 2, 21, 5, 72, 1, 14, 3, 17, 6, 82, 7, 49, 0, 22, 
    7, 90, 8, 23, 2, 57, 6, 83, 5, 82, 4,  3, 3, 18, 1, 80, 0, 99, 
    4, 73, 6, 92, 1, 72, 7, 33, 2, 85, 8, 94, 3, 60, 0, 59, 5, 12, 
    0, 94, 5, 22, 1, 16, 8, 82, 4, 33, 2, 30, 7, 34, 6, 27, 3,  3
  };
  const int q5286[] = {
    9, 9, // Number of jobs and machines
    4, 16, 3, 30, 7, 62, 0, 36, 6, 35, 8, 74, 2, 10, 1, 32, 5, 74, 
    6, 67, 5, 92, 1, 35, 3, 24, 0, 93, 4, 88, 2, 28, 7, 79, 8, 33, 
    6,  6, 1, 97, 4, 99, 0,  9, 8, 74, 3, 64, 2,  2, 7, 13, 5, 88, 
    6, 91, 8, 78, 0, 58, 2, 73, 4, 75, 7, 45, 1, 78, 5, 96, 3, 41, 
    3, 71, 1, 31, 8, 88, 5,  5, 2, 26, 6,  7, 0, 63, 4, 31, 7, 15, 
    2,  5, 1,  1, 0, 61, 4,  3, 8, 69, 5, 12, 7, 97, 3, 85, 6, 67, 
    7, 96, 1, 72, 4, 35, 2, 34, 6, 59, 5, 46, 3, 45, 8, 61, 0, 25, 
    4, 23, 2,  2, 6, 32, 8, 87, 0, 76, 5, 64, 7, 33, 3, 21, 1,  8, 
    6, 58, 5, 15, 4, 49, 3, 66, 7, 65, 0, 13, 8, 54, 1, 17, 2, 98
  };
  const int q5287[] = {
    9, 9, // Number of jobs and machines
    0, 99, 2, 70, 3, 76, 1, 56, 6, 34, 5, 32, 4, 73, 8, 89, 7, 39, 
    8, 58, 3, 55, 6, 91, 7, 81, 2, 80, 4, 64, 0, 63, 1, 90, 5, 12, 
    4, 21, 0, 80, 5, 99, 7, 99, 2, 78, 1,  5, 8, 53, 6, 90, 3, 46, 
    0, 20, 1, 53, 6,  7, 8, 72, 3, 26, 5, 68, 2, 80, 4, 57, 7, 20, 
    3,  4, 6, 80, 5, 24, 1, 93, 2, 68, 4, 45, 0, 82, 8, 50, 7, 86, 
    8, 34, 6, 28, 7, 13, 2, 40, 4, 30, 0, 49, 3, 30, 1, 51, 5, 48, 
    2, 90, 8, 18, 6, 69, 5,  5, 7, 56, 0, 13, 3, 98, 1, 74, 4,  4, 
    5, 83, 0, 26, 1,  8, 3, 12, 6, 10, 2, 57, 7, 71, 8, 60, 4, 95, 
    1, 34, 3,  7, 7, 30, 5, 23, 2, 16, 0, 97, 4, 46, 6, 87, 8, 29
  };
  const int q5288[] = {
    9, 9, // Number of jobs and machines
    5, 76, 6,  3, 3, 61, 8, 28, 2, 26, 1, 23, 4, 31, 7, 74, 0, 78, 
    1, 12, 8, 73, 5, 26, 4, 40, 2, 31, 6, 56, 7, 88, 0, 14, 3, 38, 
    1, 61, 4, 72, 5, 48, 8, 70, 0, 53, 3, 96, 2, 42, 6, 51, 7, 88, 
    5,  1, 0, 93, 1, 59, 2, 95, 8, 11, 3,  4, 7,  2, 6, 79, 4, 23, 
    0, 84, 7, 93, 8,  3, 3, 91, 2, 45, 6, 25, 5,  8, 4, 99, 1, 79, 
    6, 84, 8, 44, 1, 63, 0, 60, 4, 58, 5, 22, 3, 90, 7, 66, 2, 96, 
    1, 37, 3, 52, 8, 86, 2, 39, 5, 65, 0, 19, 4, 56, 6, 30, 7, 86, 
    7, 55, 6,  1, 4, 35, 3, 64, 8, 88, 2, 52, 5, 41, 0,  4, 1, 41, 
    1, 93, 8, 87, 2, 91, 6, 58, 4, 90, 3, 30, 7, 77, 5, 77, 0, 23
  };
  const int q5289[] = {
    9, 9, // Number of jobs and machines
    3, 87, 2, 77, 4, 28, 1, 89, 6,  5, 8, 16, 0,  5, 5, 33, 7,  7, 
    8, 34, 4, 93, 6, 71, 5, 52, 0, 20, 1, 84, 7, 29, 3, 91, 2, 69, 
    1, 32, 5, 28, 4, 37, 2, 34, 0,  4, 6, 53, 3, 63, 7, 83, 8, 36, 
    1, 92, 0, 11, 5, 87, 3, 99, 4, 17, 6, 61, 2, 50, 7, 83, 8, 80, 
    8,  1, 0, 91, 4, 22, 7, 69, 3, 84, 6, 34, 2, 84, 1, 96, 5, 31, 
    5, 44, 8, 93, 1, 49, 7, 93, 6,  5, 0, 27, 3, 42, 2, 94, 4, 21, 
    1, 97, 8, 33, 0, 53, 4, 82, 6, 75, 2, 99, 5, 26, 7, 39, 3, 40, 
    4, 70, 8, 62, 6, 15, 5, 53, 1, 60, 3, 14, 2, 51, 0, 91, 7, 48, 
    4, 77, 7, 60, 5,  8, 3, 77, 1, 11, 6, 45, 0, 84, 2, 97, 8, 46
  };
  const int q5290[] = {
    9, 9, // Number of jobs and machines
    0, 41, 8, 87, 4, 74, 7, 49, 2, 64, 3, 44, 6, 28, 1, 26, 5, 51, 
    6, 42, 7, 29, 4, 19, 1,  5, 5, 79, 3, 98, 8, 30, 0,  7, 2, 58, 
    6, 94, 7, 99, 1, 75, 5, 21, 8,  2, 0, 80, 2, 55, 4, 71, 3, 58, 
    1, 99, 5, 74, 6, 15, 3, 88, 2, 11, 7, 28, 8, 89, 0, 61, 4, 57, 
    4, 19, 1, 52, 2, 80, 3, 92, 6, 91, 7, 89, 0, 71, 8, 96, 5,  4, 
    4, 94, 0,  5, 2, 61, 6, 80, 3, 31, 8, 12, 5, 86, 1, 30, 7, 20, 
    6, 70, 0, 80, 7, 26, 4, 69, 3, 95, 2, 75, 1, 88, 8, 68, 5, 17, 
    2,  6, 3, 25, 4, 42, 7, 10, 6, 36, 1, 59, 8, 83, 0, 53, 5, 18, 
    4, 34, 1,  7, 8, 51, 0, 50, 2,  8, 6, 21, 5, 43, 3, 64, 7, 92
  };
  const int q5291[] = {
    9, 9, // Number of jobs and machines
    3, 29, 4, 92, 2, 99, 7, 85, 0, 87, 6, 84, 1, 73, 8, 34, 5,  2, 
    3, 65, 0, 70, 4, 47, 6, 52, 5, 43, 7, 38, 2, 19, 1, 52, 8, 61, 
    8, 81, 6, 65, 0, 15, 2, 74, 5, 40, 3, 56, 4, 38, 7, 19, 1, 61, 
    4,  8, 0, 87, 2, 11, 1, 60, 6, 27, 3, 40, 7, 36, 5,  7, 8,  7, 
    7, 69, 5, 78, 8, 27, 4, 17, 0, 97, 1, 26, 2, 29, 3,  1, 6, 58, 
    7,  9, 6, 28, 0, 27, 8, 13, 1, 52, 4, 90, 5, 80, 3, 75, 2, 78, 
    4, 46, 6, 81, 2, 14, 3, 35, 0, 71, 7, 34, 1, 41, 8, 17, 5, 13, 
    5, 19, 4, 39, 3, 18, 7, 32, 1, 56, 2, 38, 8, 18, 0, 14, 6, 52, 
    8,  9, 3,  8, 1, 66, 2, 25, 6, 88, 7, 35, 5, 22, 4, 37, 0, 15
  };
  const int q5292[] = {
    9, 9, // Number of jobs and machines
    8, 37, 4, 38, 2, 55, 6, 71, 0, 80, 7, 29, 3, 43, 1, 16, 5, 50, 
    5, 71, 1, 15, 0, 77, 3, 40, 2, 29, 8, 58, 4, 19, 6, 37, 7, 60, 
    0,  7, 8, 55, 3,  3, 1, 89, 6, 62, 7, 67, 4, 65, 2, 45, 5, 50, 
    2, 62, 6, 13, 1, 59, 8, 21, 5, 57, 7,  7, 3, 57, 4, 36, 0, 55, 
    2, 15, 8, 80, 7,  5, 6, 72, 1, 68, 3, 26, 5, 81, 4, 95, 0, 88, 
    3, 20, 5, 94, 4, 10, 0, 69, 6, 48, 1, 71, 8, 26, 2, 93, 7, 73, 
    8, 73, 7, 88, 1, 66, 2,  5, 5, 31, 4, 89, 0, 92, 6, 37, 3, 53, 
    1, 24, 2, 38, 6, 21, 4, 29, 0, 79, 7, 14, 3,  5, 8, 33, 5, 79, 
    1, 84, 4, 97, 5, 86, 6, 35, 7, 43, 3, 22, 0, 51, 2, 48, 8, 15
  };
  const int q5293[] = {
    9, 9, // Number of jobs and machines
    7, 52, 1, 58, 2, 49, 5, 12, 3, 87, 6, 37, 0, 25, 8, 75, 4, 48, 
    1, 97, 2, 28, 8, 92, 6, 10, 5, 98, 7, 33, 0, 60, 4, 38, 3, 30, 
    7, 84, 5, 61, 6, 36, 2, 29, 1, 35, 4, 51, 0, 68, 3, 57, 8, 30, 
    7, 78, 4, 86, 1, 47, 5, 62, 2, 45, 3, 67, 8, 64, 6, 72, 0, 15, 
    2, 96, 8, 85, 5, 24, 7, 41, 6, 16, 1, 31, 0, 94, 4, 22, 3, 26, 
    2, 71, 5, 72, 4, 35, 3, 86, 1, 38, 0, 53, 8, 29, 6, 67, 7,  9, 
    7, 89, 2, 13, 8, 76, 6, 67, 0, 21, 5, 48, 3, 63, 1, 22, 4, 26, 
    6, 40, 1, 78, 0, 82, 7, 52, 3, 96, 2, 96, 8, 63, 4, 97, 5, 10, 
    2, 24, 5, 51, 6, 46, 7, 31, 4, 28, 1, 17, 3, 48, 8,  2, 0, 75
  };
  const int q5294[] = {
    9, 9, // Number of jobs and machines
    4, 38, 0, 74, 3, 83, 5, 66, 6, 93, 1, 38, 7, 17, 8, 55, 2, 20, 
    0, 43, 5, 95, 2, 50, 4, 36, 6, 24, 3, 39, 1, 13, 7, 34, 8, 33, 
    2, 94, 0, 75, 1, 35, 4, 15, 8, 55, 7, 73, 3, 27, 6, 76, 5, 87, 
    1, 27, 7, 78, 0, 53, 8, 42, 6, 56, 3, 39, 5, 75, 4, 27, 2, 58, 
    7, 32, 1, 94, 0,  8, 4, 52, 8, 26, 2, 43, 3, 42, 5, 62, 6, 56, 
    6, 35, 7, 99, 8, 81, 4, 21, 2, 15, 3, 60, 1, 53, 5, 76, 0, 65, 
    1, 57, 2,  2, 4, 38, 7, 11, 6, 57, 5, 83, 3, 75, 8, 99, 0, 82, 
    3, 57, 2, 49, 5, 69, 7, 13, 4,  3, 0, 57, 1, 18, 6,  3, 8, 86, 
    7,  9, 4, 45, 2, 88, 0, 75, 8, 63, 3, 63, 1, 79, 6, 21, 5, 69
  };
  const int q5295[] = {
    9, 9, // Number of jobs and machines
    6, 76, 8, 80, 3, 14, 2, 93, 7, 61, 4, 15, 5, 65, 1, 90, 0, 46, 
    8, 89, 6, 72, 2, 78, 3, 63, 1, 88, 4,  5, 5, 60, 7, 17, 0, 19, 
    6, 42, 8, 62, 1, 65, 4, 36, 2, 43, 3, 24, 5, 36, 0, 33, 7,  4, 
    1, 63, 3, 16, 5, 76, 7, 86, 8, 14, 6, 79, 0, 65, 4, 81, 2, 72, 
    1, 63, 7, 86, 4, 21, 6, 82, 0, 92, 3, 80, 8, 15, 2, 12, 5, 80, 
    4, 35, 6, 19, 7, 73, 3,  7, 0, 21, 8, 21, 1, 14, 5, 53, 2, 62, 
    2, 86, 3, 25, 7, 14, 5, 42, 8, 53, 1, 61, 4, 50, 0, 34, 6, 63, 
    6, 41, 7, 75, 2, 78, 5, 40, 1, 20, 3,  6, 4,  7, 8, 71, 0, 20, 
    0, 78, 4, 20, 1, 48, 6, 47, 7, 48, 2, 29, 5, 14, 8, 80, 3, 32
  };
  const int q5296[] = {
    9, 9, // Number of jobs and machines
    6, 20, 0, 39, 1, 54, 2, 91, 4, 81, 5, 39, 3, 95, 8, 89, 7, 47, 
    0, 82, 8, 90, 1, 55, 4, 54, 3, 85, 6, 38, 7, 45, 5, 26, 2, 84, 
    4, 96, 7, 59, 0, 70, 3, 71, 8, 21, 2, 57, 1, 84, 5, 67, 6, 29, 
    5, 13, 6, 97, 2, 28, 8, 43, 1,  4, 4, 34, 7, 86, 3, 58, 0, 75, 
    8, 32, 1, 84, 0, 90, 4, 39, 7, 91, 3, 69, 2, 67, 6, 55, 5, 61, 
    2, 20, 8, 67, 7,  5, 6, 33, 0, 59, 5, 85, 3, 51, 1, 17, 4, 88, 
    1, 34, 0, 28, 2, 31, 3, 65, 6, 20, 8, 43, 5, 19, 7, 66, 4, 56, 
    7, 50, 0, 62, 3, 27, 4, 33, 6, 62, 1, 99, 5, 74, 2, 13, 8, 13, 
    1, 96, 6, 25, 8, 22, 0, 51, 3, 27, 7, 42, 5, 70, 4, 54, 2, 43
  };
  const int q5297[] = {
    9, 9, // Number of jobs and machines
    0, 67, 8, 28, 4, 95, 5, 61, 1, 83, 3, 63, 2, 77, 7, 89, 6, 24, 
    8,  9, 2, 48, 1, 48, 7, 23, 0,  2, 6, 15, 3, 24, 5,  7, 4, 42, 
    8, 15, 5, 24, 2, 38, 6,  1, 3, 20, 0, 39, 4, 96, 7,  4, 1, 44, 
    7, 75, 8, 51, 0,  3, 5, 82, 1, 84, 4, 25, 2, 90, 3, 33, 6, 64, 
    5, 40, 8,  6, 7, 60, 3, 12, 1, 73, 4, 54, 0, 90, 2, 58, 6, 84, 
    6, 14, 2, 33, 0, 42, 1, 75, 7, 89, 3, 89, 5, 50, 8,  2, 4, 22, 
    1, 42, 3, 35, 6, 13, 2, 65, 0, 86, 5,  5, 7, 87, 4, 21, 8, 59, 
    2, 65, 1, 52, 0, 75, 6, 46, 4, 73, 3, 23, 7,  7, 8, 56, 5,  1, 
    1, 99, 0, 83, 8, 86, 6, 25, 5, 61, 4, 88, 2, 85, 3, 41, 7, 63
  };
  const int q5298[] = {
    9, 9, // Number of jobs and machines
    3, 58, 5, 26, 6, 36, 0, 67, 2, 16, 7, 62, 4, 31, 1, 80, 8, 35, 
    0, 73, 1, 52, 5, 51, 8, 74, 3, 94, 2, 10, 4, 41, 7, 47, 6, 32, 
    3, 36, 8, 56, 7, 42, 1, 88, 6, 48, 4,  1, 0, 11, 2, 70, 5, 93, 
    7, 47, 5, 88, 1, 87, 3, 79, 4, 80, 8, 14, 2, 85, 0, 74, 6, 19, 
    4, 25, 7, 58, 2, 51, 0, 28, 8, 73, 5,  8, 3, 70, 1, 72, 6, 38, 
    7, 33, 1, 56, 2, 89, 6, 16, 4, 54, 3, 98, 0, 97, 8, 68, 5, 45, 
    7, 53, 8, 11, 1, 41, 6,  5, 4, 58, 0, 51, 2, 80, 5, 15, 3, 20, 
    0, 59, 6, 71, 2, 87, 8, 18, 5, 93, 7, 27, 1, 67, 4, 97, 3, 96, 
    7, 75, 3, 52, 0, 18, 5, 90, 4, 71, 2, 14, 6, 37, 8, 19, 1, 74
  };
  const int q5299[] = {
    9, 9, // Number of jobs and machines
    7, 64, 2, 93, 4, 65, 3, 54, 5, 45, 6, 69, 1, 47, 8, 42, 0, 38, 
    6, 23, 5, 54, 2, 56, 3,  6, 7, 46, 1, 48, 4, 38, 0, 88, 8, 11, 
    7, 17, 1, 85, 6,  1, 8, 13, 3, 88, 5, 25, 2, 78, 0, 26, 4, 73, 
    0, 93, 4, 75, 7, 29, 5, 85, 3, 34, 6, 74, 1, 62, 2, 97, 8, 90, 
    6, 92, 8, 43, 7, 45, 4, 63, 1, 52, 5, 28, 2, 28, 0,  4, 3, 99, 
    4, 68, 2,  2, 3, 40, 7, 39, 5, 13, 0, 77, 8, 24, 6, 53, 1, 33, 
    6, 63, 0, 62, 8, 26, 4, 71, 7, 34, 3, 36, 2, 77, 5, 73, 1, 23, 
    2, 56, 4, 43, 3, 90, 7,  4, 5, 83, 8, 44, 6, 10, 1, 24, 0, 58, 
    8, 80, 7, 64, 4, 75, 3, 53, 6, 14, 5, 75, 0,  5, 1, 34, 2, 62
  };
  const int q5300[] = {
    9, 9, // Number of jobs and machines
    2, 82, 6, 36, 7, 37, 0, 20, 4, 26, 1, 64, 5, 77, 8, 95, 3, 72, 
    7, 85, 3,  9, 5, 35, 2, 27, 4, 99, 6, 85, 1, 99, 8, 89, 0, 90, 
    0, 74, 2, 60, 6, 62, 3, 83, 8, 15, 4, 52, 7, 85, 1, 50, 5, 20, 
    3, 84, 8, 78, 7, 43, 2, 73, 5, 56, 6, 58, 1, 18, 4, 34, 0, 88, 
    1, 39, 2, 36, 8, 91, 7, 56, 5, 29, 3, 86, 6, 21, 0, 22, 4, 77, 
    4, 56, 7, 53, 5, 62, 2,  9, 0, 18, 8, 85, 3, 47, 1, 48, 6,  6, 
    3, 20, 8, 26, 2, 24, 6, 81, 0,  1, 4, 98, 7, 66, 5, 99, 1, 39, 
    4, 83, 7, 80, 3, 83, 1, 48, 6, 98, 2, 92, 0, 71, 8, 49, 5, 15, 
    2, 77, 8, 77, 5, 85, 1, 26, 4, 32, 3, 19, 0, 49, 6, 42, 7, 60
  };
  const int q5301[] = {
    9, 9, // Number of jobs and machines
    6, 98, 1, 28, 7, 59, 3, 92, 8, 42, 2, 42, 5, 42, 4,  2, 0, 36, 
    8, 26, 2, 94, 6, 73, 0, 69, 1, 44, 4, 81, 5, 93, 3, 88, 7,  5, 
    8, 89, 1, 92, 3, 79, 7, 32, 0, 60, 2, 24, 6, 33, 4, 64, 5, 42, 
    1, 74, 7, 84, 6, 82, 5, 29, 3, 27, 4, 67, 2, 47, 0, 55, 8, 55, 
    0, 29, 2,  7, 7, 35, 3, 97, 5, 63, 8, 69, 1, 13, 6, 76, 4, 86, 
    8, 45, 3, 71, 6, 46, 4, 96, 7, 88, 2, 37, 0, 55, 1, 88, 5,  1, 
    4, 97, 3, 63, 6, 80, 5,  4, 8, 11, 1, 95, 2, 51, 7, 80, 0,  6, 
    6, 32, 5, 14, 1, 19, 4, 84, 7, 81, 0, 51, 8, 55, 3, 58, 2, 35, 
    7, 87, 2, 68, 8, 55, 6, 99, 3,  5, 4, 86, 5, 52, 0, 30, 1, 13
  };
  const int q5302[] = {
    9, 9, // Number of jobs and machines
    3, 76, 1, 80, 4, 37, 6, 27, 0, 63, 5,  2, 7,  4, 2,  3, 8, 50, 
    8, 20, 6,  7, 3, 91, 7, 49, 1, 11, 2, 32, 5, 65, 0, 57, 4, 59, 
    1, 73, 6, 11, 2, 41, 7, 55, 5, 10, 4, 67, 3, 83, 8, 60, 0, 99, 
    4, 82, 0, 65, 3, 12, 6, 83, 5, 31, 8, 84, 7, 80, 1,  2, 2, 19, 
    5, 47, 4, 29, 3, 28, 0,  8, 6, 44, 2, 11, 8, 26, 7, 97, 1,  8, 
    2, 53, 7, 10, 4, 61, 0, 18, 5, 24, 1, 84, 3, 26, 8, 90, 6, 76, 
    8, 80, 6, 55, 5, 64, 1, 27, 3, 58, 7,  5, 0, 66, 4, 24, 2, 72, 
    6, 77, 3,  7, 8, 28, 4, 90, 2, 62, 1, 34, 0, 96, 5, 55, 7, 36, 
    5, 88, 2, 24, 4, 18, 3, 25, 6, 20, 1, 35, 8, 13, 7, 63, 0, 15
  };
  const int q5303[] = {
    9, 9, // Number of jobs and machines
    5, 84, 3, 12, 7, 77, 4, 30, 0, 88, 2, 81, 6, 46, 1, 84, 8, 54, 
    4, 25, 7, 82, 5, 96, 8, 90, 0,  8, 1, 93, 6, 10, 3, 99, 2, 26, 
    5,  8, 1, 38, 8, 11, 2, 11, 3, 31, 4, 46, 7,  6, 6, 47, 0, 45, 
    1, 56, 0, 70, 4, 75, 5, 18, 2,  8, 7,  1, 6,  2, 3, 97, 8, 24, 
    2, 28, 5, 32, 3, 77, 8, 15, 6, 63, 4, 68, 1, 49, 0, 55, 7, 65, 
    2, 49, 7, 36, 5, 73, 6, 78, 4,  3, 1, 45, 8, 16, 0, 97, 3, 40, 
    4, 93, 0, 15, 1, 67, 6, 25, 7, 35, 5, 93, 8, 46, 3,  1, 2, 16, 
    3, 36, 2, 76, 4, 58, 1, 17, 8, 72, 7,  3, 6, 34, 5, 66, 0, 43, 
    6, 77, 0, 54, 4, 19, 7, 86, 3, 20, 5, 29, 2, 35, 1, 85, 8, 66
  };
  const int q5304[] = {
    9, 9, // Number of jobs and machines
    2, 36, 3, 88, 0, 82, 8, 25, 7, 68, 5, 19, 6, 40, 4, 91, 1,  3, 
    6, 17, 7, 34, 0, 46, 8, 24, 4, 70, 2, 33, 1,  4, 3,  5, 5, 95, 
    1, 50, 0, 12, 2, 96, 3,  3, 8, 48, 5, 56, 7, 60, 6, 34, 4, 67, 
    0, 59, 3, 59, 8, 31, 7, 92, 4, 14, 1, 76, 5, 13, 6, 13, 2, 69, 
    8, 54, 0, 50, 3, 45, 7, 22, 5, 67, 2, 52, 4, 29, 6, 60, 1, 62, 
    0, 29, 4, 32, 7, 20, 6, 96, 5, 38, 2, 18, 1, 37, 3, 86, 8, 97, 
    8,  5, 5, 35, 1, 25, 4, 97, 0, 98, 3, 43, 6, 12, 7, 48, 2, 44, 
    1, 97, 5, 79, 0, 60, 2, 60, 7, 79, 4, 54, 6, 81, 3, 91, 8, 93, 
    7, 59, 2,  3, 3, 88, 1, 68, 6, 95, 8, 84, 0, 51, 5, 85, 4,  8
  };
  const int q5305[] = {
    9, 9, // Number of jobs and machines
    1,  9, 8,  3, 7, 37, 6, 27, 3, 49, 2,  1, 4,  5, 5, 22, 0, 87, 
    6, 97, 4, 36, 5, 28, 3, 90, 8, 89, 0, 10, 2, 25, 7, 63, 1, 81, 
    4, 11, 7, 36, 8, 86, 3, 66, 0,  5, 1, 98, 5,  9, 6, 41, 2, 52, 
    3, 63, 1, 87, 2, 79, 8, 52, 7, 23, 5, 84, 6, 80, 4, 82, 0, 56, 
    6, 72, 7, 90, 1, 22, 3, 22, 0, 83, 5, 10, 4, 19, 8, 66, 2,  2, 
    1,  3, 2,  8, 6, 98, 0, 73, 5, 56, 3, 54, 7, 83, 4, 53, 8, 14, 
    5, 23, 0, 67, 7, 49, 4, 41, 6, 91, 2, 94, 8, 75, 1, 73, 3, 56, 
    6, 44, 7,  6, 5,  1, 0, 45, 8, 74, 3, 14, 2, 64, 4, 34, 1, 20, 
    8, 67, 7, 98, 3,  7, 0, 78, 4, 29, 1, 66, 6, 90, 5, 79, 2, 21
  };
  const int q5306[] = {
    9, 9, // Number of jobs and machines
    8, 88, 7, 92, 4, 71, 2, 66, 3, 47, 5, 29, 1,  6, 0, 68, 6, 18, 
    2, 13, 0, 49, 4, 85, 6, 81, 8, 11, 5, 53, 1, 85, 7, 32, 3, 65, 
    8, 32, 3, 43, 4, 86, 2, 39, 1, 22, 6, 74, 7, 95, 0, 60, 5, 73, 
    6, 88, 7, 84, 4, 66, 0, 78, 5, 79, 2, 75, 1, 21, 8, 98, 3, 86, 
    8, 28, 3, 65, 0, 68, 5, 37, 6, 40, 1, 54, 7, 75, 4, 13, 2,  7, 
    4, 36, 2, 25, 3,  5, 7, 53, 5, 94, 6, 22, 0, 13, 8, 89, 1, 23, 
    0, 54, 4, 96, 3, 92, 6, 82, 8, 29, 7, 13, 5, 15, 1, 99, 2,  3, 
    3, 50, 4, 14, 6, 72, 5,  7, 1, 71, 7, 21, 8,  3, 2, 57, 0, 54, 
    3, 48, 0, 89, 6, 42, 8, 12, 5, 10, 7, 83, 1, 52, 4, 82, 2,  2
  };
  const int q5307[] = {
    9, 9, // Number of jobs and machines
    1, 82, 3, 56, 2, 12, 4, 84, 7, 39, 8, 58, 6, 79, 5, 29, 0, 41, 
    1, 99, 3, 22, 2,  1, 8, 54, 5, 54, 0, 20, 7, 50, 6,  6, 4, 75, 
    7, 23, 2, 54, 6, 44, 4, 82, 3, 99, 5, 41, 1, 34, 8, 27, 0, 55, 
    2, 28, 5, 64, 3, 15, 1, 17, 4, 42, 8, 90, 6, 91, 0, 32, 7, 76, 
    7, 76, 1, 21, 6, 12, 2, 77, 5, 46, 3, 28, 8, 54, 0, 33, 4,  9, 
    2, 89, 6, 93, 0, 77, 4, 72, 1, 14, 8, 10, 3, 16, 7, 11, 5, 50, 
    8, 37, 5, 35, 2,  8, 3, 77, 1,  3, 7, 58, 6, 90, 4, 10, 0, 34, 
    4, 58, 1, 16, 0, 61, 7, 42, 2, 19, 8, 19, 6, 96, 5, 13, 3, 52, 
    2, 75, 6, 12, 3, 41, 0,  3, 5, 31, 7, 15, 1, 22, 8, 82, 4,  8
  };
  const int q5308[] = {
    9, 9, // Number of jobs and machines
    3, 67, 7, 82, 5, 82, 6, 75, 4, 46, 0, 24, 8, 80, 2, 47, 1, 17, 
    0, 57, 3, 59, 6, 47, 5, 54, 7,  3, 2, 67, 4, 45, 8, 34, 1, 34, 
    5, 52, 3, 85, 2, 43, 0, 96, 7, 82, 8, 11, 1, 10, 6, 32, 4, 25, 
    3, 53, 6,  5, 4,  3, 1, 18, 2, 43, 0, 41, 5,  8, 7, 91, 8, 72, 
    2, 44, 5, 73, 3, 25, 4, 29, 7, 28, 8, 90, 0, 20, 1,  4, 6, 84, 
    2,  4, 7, 39, 1, 40, 3, 63, 4, 49, 5, 64, 8, 22, 6, 23, 0, 38, 
    4, 78, 2, 93, 6, 53, 1,  8, 5, 86, 7, 41, 8, 85, 0,  1, 3, 88, 
    6, 93, 0, 81, 7, 15, 2, 35, 5, 48, 1, 88, 8, 56, 4,  5, 3, 65, 
    8, 49, 0, 53, 2, 78, 4, 51, 3, 67, 5, 17, 7, 77, 1,  6, 6, 72
  };
  const int q5309[] = {
    9, 9, // Number of jobs and machines
    1, 53, 0, 66, 4, 83, 3, 34, 6, 39, 2, 50, 5, 48, 7, 24, 8,  7, 
    1,  7, 2, 98, 4, 42, 0, 19, 5, 54, 6, 89, 7, 21, 3, 23, 8, 70, 
    6,  5, 5, 61, 4,  7, 0, 35, 2,  6, 8, 46, 3, 64, 7, 88, 1, 15, 
    1, 33, 5, 11, 6, 77, 7, 53, 0, 20, 2, 44, 8, 29, 4, 15, 3, 18, 
    4, 77, 7, 63, 5, 41, 1, 81, 8, 55, 2, 23, 3, 92, 6, 57, 0, 35, 
    3, 77, 1, 87, 7, 68, 0, 67, 5, 61, 4, 57, 2, 83, 6, 92, 8, 71, 
    5, 74, 8, 25, 2, 93, 3, 50, 0, 94, 6, 72, 7, 59, 4, 67, 1, 69, 
    3, 94, 8, 34, 6, 83, 2, 84, 1, 11, 0, 96, 4, 73, 7, 67, 5, 25, 
    5, 44, 8, 80, 4, 93, 3, 37, 0, 29, 7,  9, 1, 40, 6, 25, 2, 11
  };
  const int q5310[] = {
    9, 9, // Number of jobs and machines
    2, 69, 1, 73, 3, 86, 8, 39, 0, 20, 5, 36, 7, 25, 6,  5, 4, 15, 
    3, 86, 2, 93, 8, 81, 4, 70, 7, 61, 0, 13, 5, 42, 1, 98, 6, 17, 
    2,  5, 3,  8, 6, 60, 7, 94, 0, 15, 1, 56, 4, 23, 8, 89, 5, 57, 
    6, 43, 2, 93, 7, 96, 1,  3, 4, 66, 8,  4, 3, 35, 5, 64, 0, 62, 
    0, 19, 1, 64, 8, 81, 6, 79, 7, 80, 3, 86, 4, 68, 2, 59, 5, 62, 
    0, 40, 6, 26, 7, 71, 3, 36, 2, 53, 1, 13, 5, 81, 8, 31, 4, 56, 
    0, 86, 6, 18, 4, 27, 2, 72, 8, 55, 1, 48, 5, 34, 3, 90, 7, 28, 
    2, 48, 6,  8, 0, 72, 3, 63, 5, 92, 7, 61, 8, 11, 1, 38, 4, 50, 
    5, 95, 4, 98, 8, 21, 7, 23, 1, 84, 0, 67, 3, 43, 6, 26, 2, 97
  };
  const int q5311[] = {
    9, 9, // Number of jobs and machines
    4, 19, 8, 55, 5, 61, 6, 28, 2, 35, 0, 93, 7, 88, 3, 91, 1, 42, 
    5, 90, 8, 18, 3, 59, 6, 68, 2, 20, 4, 86, 1,  6, 0, 75, 7, 96, 
    7, 42, 0, 20, 1, 13, 6, 44, 3,  8, 4, 95, 8, 19, 5, 53, 2, 28, 
    5, 64, 1, 40, 4, 27, 0, 26, 7, 36, 3, 98, 2,  1, 8, 25, 6, 24, 
    1, 46, 6, 85, 5, 35, 4, 43, 2, 61, 3, 72, 7, 95, 0, 31, 8, 68, 
    8, 13, 2, 31, 0, 86, 5, 18, 4, 87, 3, 14, 7, 79, 6, 60, 1, 28, 
    3, 41, 4, 86, 0, 39, 7, 97, 2,  9, 8, 53, 5, 97, 6, 85, 1, 40, 
    2,  6, 6,  8, 7, 20, 4, 85, 3, 83, 5, 57, 8, 22, 0, 55, 1, 54, 
    7, 66, 2, 48, 4, 79, 3, 59, 1, 68, 5, 39, 6,  7, 8, 60, 0, 20
  };
  const int q5312[] = {
    9, 9, // Number of jobs and machines
    3, 41, 7, 31, 6, 88, 8, 71, 2, 66, 5, 68, 4, 47, 1, 38, 0, 74, 
    4, 40, 8, 36, 6, 49, 2,  6, 1, 61, 5, 36, 7, 61, 3, 83, 0, 79, 
    0,  4, 3, 54, 7, 47, 6, 57, 2, 21, 1, 25, 8, 79, 4, 53, 5, 17, 
    0, 16, 5, 71, 4,  4, 1, 65, 6, 83, 8, 63, 2, 29, 7, 79, 3, 45, 
    5, 33, 4, 59, 7, 60, 6, 49, 8, 10, 0, 99, 2, 31, 3, 93, 1, 65, 
    4,  3, 8, 10, 1,  6, 3, 45, 0, 68, 2, 46, 7,  1, 5, 39, 6,  8, 
    1, 18, 2, 70, 0, 60, 6, 60, 3, 31, 4, 19, 7, 31, 5, 45, 8, 71, 
    4, 35, 3, 29, 7, 35, 6, 29, 5, 57, 8,  1, 1, 47, 2, 85, 0, 21, 
    6,  4, 8, 82, 0, 90, 2, 42, 5, 89, 1, 81, 3, 85, 4, 83, 7, 33
  };
  const int q5313[] = {
    9, 9, // Number of jobs and machines
    0, 26, 3, 69, 8, 30, 6, 76, 2,  5, 5,  8, 7, 68, 1, 98, 4, 32, 
    7, 95, 4,  8, 3, 76, 6, 12, 5, 17, 0, 80, 1, 40, 8,  9, 2, 80, 
    2, 45, 7, 59, 3, 83, 4, 75, 8, 56, 1, 94, 0, 26, 6, 51, 5, 40, 
    4, 92, 8, 20, 7, 52, 2, 13, 0, 77, 6, 24, 1, 55, 3, 22, 5, 17, 
    2, 60, 6, 86, 0, 22, 8, 20, 7,  8, 1, 54, 5,  6, 4, 50, 3, 63, 
    5, 74, 3, 74, 4, 60, 0, 97, 8, 45, 6, 98, 2, 15, 7, 19, 1, 12, 
    0, 23, 5, 35, 4, 87, 8, 94, 2, 65, 6, 94, 3, 28, 1, 50, 7,  1, 
    1, 89, 5, 69, 0, 36, 2, 80, 8, 82, 7, 67, 4, 45, 6, 68, 3, 43, 
    3, 68, 5, 33, 1, 12, 0, 36, 8, 64, 2, 18, 6, 68, 4, 63, 7, 67
  };
  const int q5314[] = {
    9, 9, // Number of jobs and machines
    6, 55, 8, 99, 0, 24, 3, 94, 1, 77, 5, 58, 7, 69, 4, 93, 2, 25, 
    0, 63, 8, 31, 1, 59, 2, 82, 4, 84, 3, 40, 5,  8, 6, 37, 7, 80, 
    3,  5, 4, 35, 2, 23, 0, 31, 8, 18, 5, 94, 7, 51, 1, 26, 6, 69, 
    3, 84, 5, 43, 7,  5, 0, 89, 2, 13, 6, 74, 8, 19, 1, 16, 4, 21, 
    7, 99, 5, 56, 6, 54, 0, 26, 8, 54, 1, 99, 2, 76, 3, 46, 4,  2, 
    0,  4, 4, 77, 8, 53, 1, 61, 7, 70, 3, 25, 2, 16, 5,  5, 6, 82, 
    0, 57, 8, 88, 7,  4, 1, 94, 5, 89, 3, 45, 6, 91, 4,  9, 2, 56, 
    3, 70, 6, 40, 1, 19, 5, 60, 4, 85, 0, 80, 7, 27, 2, 55, 8, 87, 
    8, 31, 2, 87, 4, 37, 6, 83, 1, 19, 0, 91, 5, 38, 3,  8, 7, 84
  };
  const int q5315[] = {
    9, 9, // Number of jobs and machines
    3, 83, 4, 57, 1, 35, 6, 29, 8, 29, 0,  5, 7, 38, 5,  4, 2, 25, 
    1, 35, 8, 81, 5, 28, 6,  7, 7,  9, 3, 52, 2, 70, 4, 76, 0, 57, 
    2, 80, 0, 51, 4, 11, 3, 23, 8, 70, 5, 49, 6, 54, 1, 64, 7, 26, 
    5, 78, 4, 37, 2, 25, 0, 84, 6, 74, 1, 94, 7, 82, 3, 80, 8, 11, 
    5, 29, 3, 16, 8, 51, 1, 59, 4, 27, 6,  7, 7, 39, 2, 58, 0, 38, 
    4, 51, 1, 80, 5, 68, 3, 45, 2, 49, 0,  8, 6, 63, 8, 28, 7, 12, 
    8, 15, 5, 59, 0, 44, 3, 86, 2,  3, 1, 23, 7, 92, 4, 46, 6, 74, 
    3, 58, 8, 87, 1, 85, 6, 19, 5, 78, 7, 81, 4,  7, 0, 29, 2, 10, 
    2, 11, 3, 52, 1, 27, 7, 49, 5, 82, 8, 85, 4, 74, 6,  7, 0, 34
  };
  const int q5316[] = {
    9, 9, // Number of jobs and machines
    6, 77, 1, 28, 7, 96, 0, 75, 4, 53, 2, 82, 3, 19, 8, 77, 5, 72, 
    1, 18, 7, 31, 6,  4, 5, 97, 4, 51, 8, 27, 2, 73, 3, 14, 0, 48, 
    3, 29, 5, 90, 8, 32, 4, 24, 2, 68, 0, 66, 1, 76, 6, 45, 7, 57, 
    1, 94, 8, 42, 7, 19, 5, 76, 6, 69, 2, 38, 0, 46, 4, 63, 3, 21, 
    2, 55, 3, 84, 0, 42, 8, 44, 5, 52, 7, 15, 6,  3, 1, 98, 4, 40, 
    3, 42, 6,  9, 4, 45, 2,  2, 8, 56, 1, 49, 7, 78, 5, 41, 0, 58, 
    8, 55, 6, 77, 2, 48, 5, 34, 7, 17, 3, 13, 1, 99, 0, 57, 4,  8, 
    5, 39, 8, 84, 0, 89, 3, 98, 2, 24, 6, 37, 7, 92, 1, 46, 4, 47, 
    3, 93, 1, 91, 2, 32, 6, 44, 0, 11, 4, 95, 5, 17, 8,  8, 7, 96
  };
  const int q5317[] = {
    9, 9, // Number of jobs and machines
    7, 85, 5, 33, 6, 38, 3, 60, 4, 56, 1, 60, 0, 60, 8,  2, 2, 84, 
    4, 12, 0, 89, 1, 89, 8, 67, 5, 34, 6,  4, 2, 28, 7, 19, 3, 74, 
    2, 90, 5, 23, 0, 76, 7, 92, 1, 44, 3, 96, 6, 12, 8, 91, 4, 71, 
    0, 69, 1, 89, 8, 70, 7, 20, 2, 26, 5,  2, 3, 12, 4, 78, 6, 63, 
    4, 56, 5, 64, 3, 31, 1, 25, 7, 10, 2, 39, 6, 23, 0, 19, 8, 37, 
    2, 89, 4, 33, 3, 52, 1, 13, 0, 80, 7, 27, 5, 61, 6, 82, 8, 72, 
    7, 87, 8, 96, 2, 33, 0, 56, 3, 95, 1, 89, 5, 10, 6, 41, 4, 53, 
    8, 10, 6, 13, 0,  1, 1, 13, 4, 49, 3, 81, 5,  1, 2, 87, 7, 64, 
    0, 85, 3, 75, 1, 69, 4, 86, 8, 29, 6, 84, 7, 31, 2, 37, 5, 57
  };
  const int q5318[] = {
    9, 9, // Number of jobs and machines
    0, 23, 1, 63, 7, 82, 3, 74, 4, 98, 5, 84, 6, 44, 2, 20, 8,  3, 
    7, 35, 6,  7, 2, 90, 8, 32, 0,  7, 5,  8, 4, 68, 3, 65, 1,  2, 
    8, 67, 2, 60, 7, 84, 0,  4, 4, 49, 6, 12, 5, 78, 3, 22, 1, 73, 
    3, 49, 4, 76, 8, 90, 0, 46, 7, 10, 1, 98, 5, 47, 2, 99, 6, 77, 
    2, 19, 7, 73, 0, 73, 4, 15, 3, 46, 5,  2, 1, 41, 6, 90, 8,  8, 
    4, 54, 6, 33, 2, 18, 0, 11, 7,  4, 1, 80, 5, 67, 3, 35, 8, 43, 
    6, 65, 3, 82, 8, 59, 0, 75, 1, 74, 7,  8, 5, 53, 2, 79, 4, 43, 
    1, 35, 7, 26, 2, 15, 3, 15, 5, 93, 8, 56, 0,  2, 6, 29, 4, 19, 
    7,  5, 2, 42, 8, 18, 4, 73, 6, 10, 5, 16, 0, 35, 3, 21, 1,  9
  };
  const int q5319[] = {
    9, 9, // Number of jobs and machines
    0, 53, 1, 91, 5, 70, 7, 50, 2,  9, 6, 92, 4, 94, 3, 14, 8, 23, 
    3,  7, 2, 50, 4, 69, 5, 30, 8, 17, 1,  1, 7, 58, 6, 94, 0, 89, 
    7, 58, 1, 56, 6,  2, 2, 17, 0, 53, 5, 43, 4, 48, 3, 22, 8, 18, 
    7, 35, 5, 26, 3, 27, 8, 90, 0, 87, 1, 34, 6,  5, 4, 61, 2, 44, 
    7, 80, 6, 69, 1, 77, 0, 99, 2, 74, 4, 41, 5, 97, 8, 62, 3, 73, 
    3, 12, 1, 97, 8,  8, 7, 37, 0, 47, 6, 20, 5, 85, 4, 20, 2,  8, 
    5, 87, 0, 82, 7, 17, 3, 53, 6, 38, 2, 55, 4, 83, 1, 29, 8, 84, 
    3, 93, 2, 93, 8, 55, 6, 18, 7, 51, 1, 56, 4, 25, 0, 15, 5,  5, 
    6, 33, 8, 48, 0, 28, 1, 56, 2, 40, 3, 28, 7, 65, 5, 35, 4, 56
  };
  const int q5320[] = {
    9, 9, // Number of jobs and machines
    5, 53, 0, 39, 6, 45, 2, 59, 8, 47, 7, 73, 4, 86, 1, 34, 3,  2, 
    3, 18, 6, 88, 1, 23, 8, 76, 0, 16, 7, 80, 5, 96, 2, 88, 4,  8, 
    8, 74, 3, 10, 6, 22, 5, 66, 4, 84, 7, 62, 1, 45, 2, 53, 0, 45, 
    2, 99, 3, 13, 6, 33, 8, 49, 4, 25, 7,  5, 1, 67, 0, 15, 5, 91, 
    5, 80, 2, 98, 6,  8, 7, 69, 3, 55, 0, 19, 1, 68, 4, 28, 8, 75, 
    7, 80, 4, 92, 1,  3, 2, 69, 0, 62, 8, 98, 3, 62, 5, 43, 6,  9, 
    7, 86, 0, 59, 2, 33, 3, 95, 4, 41, 6, 12, 1, 21, 8, 20, 5, 87, 
    4, 15, 6, 24, 1, 55, 8, 60, 5, 44, 3, 97, 0, 39, 7, 54, 2, 28, 
    8, 21, 0, 87, 4, 73, 5, 40, 1, 21, 2, 55, 3, 76, 6, 51, 7, 10
  };
  const int q5321[] = {
    9, 9, // Number of jobs and machines
    2, 98, 6,  5, 4, 28, 0, 38, 7, 53, 1, 65, 8, 75, 5, 80, 3, 36, 
    1, 87, 0, 79, 5, 62, 4, 53, 3, 49, 2, 23, 8, 70, 6, 68, 7, 85, 
    5, 50, 2, 64, 0, 76, 3, 19, 6, 55, 7, 60, 1, 66, 4, 24, 8, 68, 
    0, 89, 1, 45, 8, 90, 2, 34, 4, 64, 6, 64, 7, 55, 5, 45, 3, 57, 
    5, 89, 8, 48, 4, 18, 7, 37, 3,  8, 1, 63, 6, 55, 0, 40, 2, 99, 
    8, 13, 3, 69, 6, 96, 7, 28, 4, 53, 5, 51, 0,  3, 1, 11, 2, 37, 
    2,  8, 5, 52, 8,  9, 3, 19, 0, 30, 1, 66, 4,  2, 7, 52, 6, 25, 
    4, 66, 2,  1, 7, 26, 5, 94, 3, 68, 6, 68, 8, 19, 0, 81, 1, 10, 
    0, 51, 6, 44, 1, 86, 3, 20, 8, 19, 4, 76, 7, 60, 5, 21, 2, 67
  };
  const int q5322[] = {
    9, 9, // Number of jobs and machines
    7, 21, 2,  4, 0, 52, 3, 77, 6, 67, 8, 17, 1, 82, 5, 19, 4, 51, 
    2, 43, 3,  5, 6, 61, 8, 58, 0, 72, 4, 80, 7, 48, 5, 14, 1, 52, 
    3, 86, 2, 23, 6, 11, 5, 61, 7, 70, 0, 68, 1, 22, 8, 38, 4, 22, 
    1, 47, 5, 77, 6, 36, 2, 46, 4, 84, 8, 14, 7, 89, 3, 72, 0, 85, 
    7, 13, 3, 78, 5, 51, 4, 48, 1, 65, 8, 72, 2, 41, 0, 98, 6, 27, 
    8, 84, 5, 88, 4,  4, 0, 45, 3, 92, 2, 88, 6, 87, 7, 42, 1, 14, 
    1, 74, 0, 92, 3, 23, 2, 94, 5, 24, 6, 84, 4, 33, 7, 91, 8, 32, 
    7,  2, 1, 71, 8, 27, 5, 97, 3, 13, 0,  6, 2, 69, 6, 62, 4, 87, 
    8, 29, 4, 96, 0, 36, 6, 85, 7, 28, 3, 37, 5, 91, 1, 53, 2, 11
  };
  const int q5323[] = {
    9, 9, // Number of jobs and machines
    1, 62, 4, 55, 3, 74, 0, 34, 2, 80, 8, 67, 5, 75, 6, 53, 7, 57, 
    1, 50, 5, 48, 6, 73, 8, 69, 4, 10, 3, 23, 2, 33, 0, 15, 7, 96, 
    8, 37, 5, 63, 2, 26, 1, 40, 7, 16, 0, 96, 4,  1, 3,  3, 6, 52, 
    6, 85, 8, 98, 0, 24, 2, 75, 4, 30, 1, 99, 3,  5, 7, 69, 5, 34, 
    4, 54, 5, 76, 7, 10, 1, 82, 2, 90, 0, 70, 3, 59, 6, 73, 8, 98, 
    1, 50, 8,  8, 2, 87, 3, 50, 4, 85, 5, 44, 6, 49, 0, 98, 7, 77, 
    3, 58, 0, 30, 4, 29, 8, 72, 2, 30, 1, 25, 5, 11, 6, 19, 7, 91, 
    6, 81, 5, 44, 7,  3, 8, 82, 1, 21, 0, 92, 3, 29, 4, 17, 2, 48, 
    2, 83, 6,  2, 4, 48, 8, 63, 1, 31, 7, 21, 0, 29, 5, 91, 3,  8
  };
  const int q5324[] = {
    9, 9, // Number of jobs and machines
    7, 20, 6, 77, 2, 18, 8, 41, 3, 40, 0, 84, 1, 51, 4, 57, 5, 98, 
    5, 82, 8, 84, 2, 16, 1, 50, 4, 33, 6, 45, 0,  8, 3, 61, 7, 84, 
    7, 39, 0, 13, 1, 19, 8, 41, 4,  6, 2, 60, 3, 76, 6, 87, 5, 74, 
    0,  3, 3, 85, 6, 98, 8, 37, 5, 25, 7, 87, 2, 30, 4, 26, 1, 35, 
    2, 84, 1, 34, 3, 84, 6, 83, 8, 89, 5, 83, 0, 17, 4,  6, 7,  1, 
    4, 49, 0, 82, 2, 45, 7, 81, 6, 55, 8, 48, 3, 17, 1, 67, 5, 90, 
    8, 79, 0, 40, 3, 73, 1, 26, 6, 51, 5, 68, 4, 76, 7, 56, 2, 61, 
    3, 36, 4, 10, 5, 35, 8, 62, 6, 38, 0, 91, 7, 76, 2,  9, 1, 51, 
    5, 20, 6, 19, 0, 64, 4, 34, 8, 82, 3, 18, 2, 95, 7, 29, 1, 91
  };
  const int q5325[] = {
    9, 9, // Number of jobs and machines
    1, 94, 3, 81, 7, 88, 5, 70, 8, 81, 0,  4, 4, 67, 2, 13, 6, 92, 
    5, 84, 6, 82, 0,  1, 4, 92, 3, 91, 2, 46, 7, 36, 8,  6, 1, 54, 
    0, 61, 8, 63, 4, 58, 5, 60, 6, 69, 3, 12, 2, 88, 1, 59, 7, 77, 
    6, 81, 8, 86, 1, 68, 2, 56, 7, 19, 4, 21, 3, 54, 5, 94, 0,  9, 
    3, 66, 0, 45, 8, 87, 6, 37, 1,  8, 4, 82, 5, 90, 2, 99, 7, 28, 
    0, 45, 3, 33, 6, 15, 8, 86, 5, 47, 1, 33, 2, 77, 4,  5, 7, 51, 
    5, 68, 3, 35, 7, 67, 0, 64, 8, 86, 2,  1, 1, 30, 6, 29, 4, 74, 
    0, 86, 6, 74, 8, 98, 7, 84, 5, 12, 2, 43, 1, 20, 3, 99, 4, 48, 
    4, 73, 5, 83, 1, 80, 2, 52, 8, 83, 0, 37, 6, 92, 7,  9, 3, 72
  };
  const int q5326[] = {
    9, 9, // Number of jobs and machines
    6, 90, 1, 48, 4, 24, 7, 85, 2, 37, 5, 28, 8, 16, 0, 42, 3, 37, 
    0, 70, 3, 34, 5,  1, 6, 54, 4, 86, 7, 24, 2, 11, 1, 91, 8, 37, 
    1, 78, 0, 70, 2, 93, 3, 53, 7,  3, 8, 26, 6, 41, 4, 31, 5, 78, 
    2,  9, 0, 15, 3, 63, 7, 31, 8, 36, 4, 21, 6, 93, 5, 86, 1,  3, 
    5, 85, 2, 85, 6, 25, 1, 74, 8, 59, 3,  3, 0, 35, 7, 30, 4, 10, 
    8, 36, 5, 92, 0, 25, 1,  7, 7, 85, 3, 12, 6, 93, 4, 56, 2, 92, 
    7, 23, 5, 87, 0, 92, 3, 93, 1,  2, 2, 92, 4, 47, 6, 27, 8, 43, 
    1, 86, 8, 11, 4, 98, 6,  2, 7, 23, 2, 97, 3, 59, 0, 63, 5, 32, 
    6, 71, 4, 93, 7, 20, 8, 43, 2, 28, 5, 56, 3, 94, 1,  9, 0, 69
  };
  const int q5327[] = {
    9, 9, // Number of jobs and machines
    1, 42, 6,  6, 4, 69, 5, 42, 3, 39, 7, 37, 8, 56, 2, 63, 0, 72, 
    2,  1, 3, 14, 6, 16, 1, 11, 4, 78, 8, 16, 0, 93, 7, 34, 5, 55, 
    2, 37, 5, 21, 1, 80, 3, 90, 7, 84, 4, 13, 8, 15, 0, 11, 6, 39, 
    7, 80, 0, 44, 5, 83, 1,  5, 3, 17, 2, 15, 8, 55, 6, 55, 4, 25, 
    7, 88, 1, 90, 3, 44, 2, 58, 0, 69, 8, 97, 4, 58, 5, 53, 6,  9, 
    2, 17, 6, 46, 8, 49, 5, 88, 3, 35, 4, 44, 1,  9, 7,  8, 0,  3, 
    7, 56, 3, 39, 0, 19, 8,  7, 1, 74, 5, 11, 4, 49, 2, 35, 6, 26, 
    3,  5, 2, 85, 8, 77, 6, 83, 1, 39, 7, 38, 0, 48, 5, 37, 4, 59, 
    5,  7, 4, 46, 0, 45, 7, 89, 8,  6, 6, 82, 3,  3, 2, 55, 1, 65
  };
  const int q5328[] = {
    9, 9, // Number of jobs and machines
    0, 45, 6, 50, 5, 71, 4, 68, 7, 21, 3,  4, 2, 30, 8, 59, 1, 92, 
    6, 20, 8, 36, 1, 19, 2, 80, 4, 82, 0, 16, 5, 54, 7, 37, 3, 26, 
    1, 12, 7, 31, 8, 50, 6, 58, 0, 94, 5, 11, 3, 23, 4, 89, 2, 26, 
    8, 75, 3, 17, 7, 46, 4, 88, 6, 85, 2, 41, 0,  4, 5, 82, 1, 26, 
    7, 13, 3, 29, 2, 20, 1, 90, 6, 85, 8,  3, 0, 66, 5, 80, 4, 78, 
    6, 57, 1, 49, 2, 73, 7, 62, 4,  2, 8, 59, 3, 75, 5, 50, 0, 33, 
    5, 70, 1, 38, 6,  4, 0, 43, 3, 91, 8,  2, 4, 92, 7, 51, 2, 95, 
    3, 93, 0, 12, 2, 35, 8, 27, 5, 19, 7,  6, 4, 34, 1, 67, 6, 13, 
    5, 40, 3, 69, 4, 70, 0, 96, 8, 27, 1, 91, 7, 80, 6, 53, 2, 86
  };
  const int q5329[] = {
    9, 9, // Number of jobs and machines
    4, 98, 3, 65, 1, 72, 7, 49, 2, 70, 8, 75, 6, 64, 0, 45, 5, 94, 
    2, 32, 7, 20, 3, 38, 8, 59, 5, 86, 1,  2, 0, 43, 6, 95, 4, 65, 
    8, 42, 7, 57, 5, 48, 1, 38, 2, 69, 4, 90, 0, 47, 3, 33, 6, 72, 
    3, 26, 8, 66, 5, 54, 0,  3, 1, 61, 2, 56, 7, 19, 4, 97, 6, 12, 
    2, 21, 1, 37, 8, 49, 3, 57, 4, 25, 7, 72, 6, 49, 0, 33, 5, 27, 
    7, 71, 6, 66, 1, 81, 5, 65, 2, 25, 8, 44, 0, 22, 3, 15, 4, 71, 
    3, 85, 4, 17, 7, 79, 6, 24, 1, 51, 8, 71, 0, 39, 2, 84, 5, 20, 
    3, 28, 1, 99, 0, 98, 2, 85, 4, 89, 7, 45, 5, 19, 8, 51, 6, 25, 
    3, 85, 5, 37, 7, 32, 6, 86, 0, 54, 8, 19, 4, 80, 2,  4, 1, 48
  };
  const int q5330[] = {
    9, 9, // Number of jobs and machines
    2, 63, 6, 98, 1, 61, 5, 35, 8, 51, 3,  7, 0, 27, 7,  2, 4, 23, 
    6, 98, 5, 27, 1, 32, 4, 31, 7,  9, 3, 94, 2, 80, 8,  5, 0, 33, 
    2, 51, 4, 91, 3, 26, 5, 51, 1, 99, 7, 20, 6, 17, 8, 64, 0, 91, 
    3, 91, 8, 39, 2, 11, 5,  3, 6, 38, 7, 52, 1, 97, 4, 22, 0, 12, 
    3, 29, 1, 10, 7, 52, 5, 81, 0, 57, 4, 10, 2,  8, 6, 37, 8,  3, 
    3,  2, 7,  9, 0, 14, 6, 35, 8, 66, 4, 79, 5, 46, 1, 68, 2, 92, 
    7, 96, 2, 62, 1, 16, 4, 54, 8, 57, 6, 61, 5, 24, 3, 56, 0, 69, 
    8, 15, 2, 53, 5, 78, 4, 54, 0, 56, 3, 81, 6, 27, 7, 62, 1, 70, 
    4, 53, 2, 38, 1, 20, 5, 17, 8, 92, 6, 86, 7, 90, 3, 40, 0, 66
  };
  const int q5331[] = {
    9, 9, // Number of jobs and machines
    8, 26, 5, 11, 2, 20, 0, 85, 1,  3, 6, 94, 3, 19, 7, 41, 4, 75, 
    4, 21, 5, 40, 3, 92, 6, 96, 2, 97, 7,  7, 8, 34, 0, 63, 1, 55, 
    6,  4, 4, 41, 3, 40, 7, 73, 1, 71, 8, 10, 5,  4, 0, 28, 2, 38, 
    3, 49, 2, 62, 8, 44, 0, 37, 4, 73, 6, 84, 7, 36, 5, 28, 1, 59, 
    4,  1, 2, 52, 5, 59, 3, 32, 7, 69, 0, 33, 6, 64, 1, 54, 8, 69, 
    7, 75, 6, 29, 0, 13, 4, 20, 5, 73, 2, 81, 1, 86, 8, 20, 3,  3, 
    7, 29, 5, 53, 8, 69, 0, 71, 2, 62, 1, 65, 6, 61, 4, 37, 3, 94, 
    5,  2, 3, 82, 8,  6, 6, 30, 0,  5, 7, 42, 4, 33, 1,  9, 2, 92, 
    8, 92, 1, 31, 3, 35, 5, 77, 6, 16, 4,  9, 7, 38, 0, 10, 2, 65
  };
  const int q5332[] = {
    9, 9, // Number of jobs and machines
    4, 35, 5, 85, 2, 21, 8, 59, 7, 76, 1, 51, 6, 26, 3, 78, 0, 33, 
    6, 56, 7,  8, 3, 54, 5, 54, 4, 51, 8,  1, 0, 55, 2, 57, 1, 95, 
    1, 62, 7, 88, 3, 55, 0, 97, 4, 94, 8, 42, 6, 98, 5, 52, 2, 72, 
    5, 66, 0, 79, 2,  9, 3, 97, 6, 10, 1, 84, 8, 77, 4, 76, 7, 99, 
    7, 29, 4, 84, 1, 67, 0, 77, 5, 64, 2, 57, 3, 10, 6, 81, 8,  2, 
    8, 75, 4, 10, 0,  5, 6, 79, 7, 33, 2, 22, 3, 80, 1, 24, 5, 96, 
    4, 62, 3,  3, 7,  6, 1, 39, 6, 24, 2, 72, 5, 88, 8, 12, 0,  8, 
    4, 47, 0, 12, 3, 87, 2, 90, 8,  2, 5, 14, 7, 65, 1, 36, 6, 20, 
    4, 93, 8, 66, 6, 65, 3, 55, 7, 92, 2, 68, 5, 56, 0, 43, 1, 64
  };
  const int q5333[] = {
    9, 9, // Number of jobs and machines
    1, 65, 6, 11, 2, 97, 4, 26, 0, 63, 3,  8, 5, 46, 8,  8, 7, 77, 
    7, 41, 3, 19, 1, 89, 2, 63, 8,  9, 4, 85, 6, 47, 0, 53, 5, 19, 
    3, 67, 6, 79, 4, 96, 1, 87, 8,  5, 7, 80, 2, 13, 5, 31, 0, 22, 
    8,  7, 3, 14, 5, 92, 2, 27, 1, 65, 0, 46, 4, 27, 6, 73, 7,  3, 
    0, 21, 2, 81, 7, 16, 1, 20, 4,  9, 5, 28, 8, 63, 3, 73, 6, 40, 
    3, 70, 7, 10, 8, 53, 2, 39, 6, 95, 4, 69, 5, 38, 1, 94, 0, 84, 
    0, 91, 3, 31, 4, 80, 2, 25, 6, 97, 1, 30, 7, 23, 8, 40, 5,  6, 
    6, 15, 7, 46, 3, 58, 1, 58, 5, 71, 4, 14, 0, 33, 2, 51, 8, 44, 
    3, 27, 4, 66, 8, 72, 7, 89, 6, 54, 2, 23, 5, 70, 1, 37, 0, 46
  };
  const int q5334[] = {
    9, 9, // Number of jobs and machines
    8, 76, 3, 94, 0, 86, 4, 88, 5, 89, 2, 64, 6, 30, 1, 85, 7, 42, 
    1, 25, 4, 85, 6, 35, 3, 94, 2,  5, 0, 51, 7, 61, 8, 25, 5, 60, 
    6, 78, 3, 57, 5, 70, 0, 67, 2, 32, 7, 36, 8, 84, 4, 92, 1, 49, 
    4, 18, 2, 43, 6, 13, 1, 49, 8,  1, 3, 53, 7,  8, 0, 49, 5, 27, 
    2, 99, 4, 44, 0, 27, 3, 28, 1, 47, 6, 91, 7, 61, 5, 52, 8, 29, 
    1, 86, 4, 25, 5, 54, 7, 18, 6, 78, 3, 70, 0, 42, 2, 83, 8, 55, 
    3, 76, 8, 34, 6, 15, 5, 59, 7, 93, 1, 62, 2, 54, 0, 48, 4, 21, 
    7, 33, 3, 90, 5, 49, 0, 43, 4, 93, 6, 17, 1, 59, 2, 68, 8, 91, 
    0, 65, 5, 69, 1, 39, 3,  3, 6, 43, 2,  8, 8, 93, 7, 60, 4, 11
  };
  const int q5335[] = {
    9, 9, // Number of jobs and machines
    3, 11, 2, 69, 1, 97, 8, 94, 5, 87, 7, 83, 4, 81, 0, 81, 6, 77, 
    5, 74, 8, 14, 0, 22, 1, 87, 6, 65, 2, 16, 3, 82, 4, 34, 7, 57, 
    3, 25, 4, 94, 5, 17, 6,  1, 7, 16, 2, 35, 1, 61, 0, 51, 8, 99, 
    1, 60, 3, 19, 8, 19, 7, 23, 0, 95, 4, 15, 6, 30, 5, 34, 2, 62, 
    5, 91, 6, 28, 8, 37, 2, 61, 4, 16, 1, 64, 7, 91, 0, 93, 3, 93, 
    5,  9, 8, 78, 0, 19, 2, 83, 7, 26, 4, 77, 6,  9, 3, 26, 1,  3, 
    5, 47, 2, 47, 8, 24, 4, 23, 0, 75, 6, 84, 7, 56, 3, 13, 1, 91, 
    6, 18, 3, 89, 2, 16, 5, 17, 1, 99, 7, 10, 4, 53, 0, 47, 8, 34, 
    5, 17, 1, 40, 7, 61, 6, 48, 0, 31, 4, 38, 3,  2, 8, 30, 2, 51
  };
  const int q5336[] = {
    9, 9, // Number of jobs and machines
    5, 74, 8, 24, 7, 49, 4,  5, 2, 32, 3, 31, 1, 95, 6, 65, 0, 40, 
    7, 69, 2, 18, 1, 89, 0, 89, 8, 82, 6, 85, 5, 85, 4, 99, 3, 46, 
    1, 69, 3, 32, 4, 25, 7, 85, 0, 47, 5, 65, 2, 95, 8, 77, 6, 95, 
    7, 44, 4, 16, 2, 69, 3, 75, 5, 25, 0, 56, 6,  8, 1, 56, 8, 41, 
    2, 66, 7, 74, 8, 33, 4, 49, 5, 66, 6, 45, 0, 41, 1, 87, 3, 71, 
    2, 95, 1, 87, 3, 40, 8, 12, 5, 25, 0, 85, 7, 53, 4, 78, 6, 38, 
    7, 46, 2, 85, 5, 88, 6, 10, 4,  8, 8, 84, 1, 30, 0, 40, 3, 46, 
    8, 40, 2, 81, 0, 24, 4, 74, 6, 85, 7, 24, 3, 57, 5,  2, 1, 96, 
    8, 65, 7, 68, 4, 92, 3, 51, 5, 30, 2, 80, 6, 64, 1, 42, 0, 21
  };
  const int q5337[] = {
    9, 9, // Number of jobs and machines
    1, 55, 6, 34, 2, 91, 7, 41, 4,  5, 0, 61, 5, 41, 8, 24, 3, 42, 
    7, 49, 6, 79, 3, 21, 1, 87, 0, 85, 5, 30, 8,  7, 2, 12, 4, 89, 
    8, 23, 1, 53, 7, 57, 5, 68, 6, 14, 2, 93, 3,  2, 0, 29, 4, 81, 
    6, 69, 8, 20, 0, 79, 1, 16, 5, 11, 4,  6, 3, 26, 2, 53, 7, 61, 
    2,  7, 7, 10, 3, 56, 5, 65, 1, 39, 8, 63, 4, 16, 6, 45, 0, 52, 
    6, 52, 0,  2, 8, 11, 1, 99, 7, 11, 2, 96, 5, 62, 3, 78, 4, 25, 
    8, 28, 2, 18, 5, 23, 6, 39, 0, 30, 4, 36, 3, 72, 7, 49, 1, 38, 
    7, 89, 2,  6, 4, 63, 6, 29, 0, 81, 5, 78, 8, 75, 3, 44, 1, 85, 
    4,  2, 6, 63, 1, 81, 8, 88, 5, 50, 3,  7, 2, 37, 0, 58, 7, 58
  };
  const int q5338[] = {
    9, 9, // Number of jobs and machines
    8, 95, 2, 57, 0, 36, 3, 14, 4,  9, 7, 59, 1, 28, 6, 19, 5, 21, 
    0, 24, 6, 46, 7, 64, 5, 71, 2, 62, 8, 55, 3,  8, 1, 90, 4, 63, 
    2, 55, 3,  7, 6, 35, 5, 35, 0, 15, 1, 21, 8, 75, 7, 98, 4,  4, 
    4, 58, 7, 91, 6, 91, 0, 82, 2, 17, 5, 36, 1, 34, 3, 42, 8, 59, 
    0, 50, 1, 47, 2, 11, 6, 90, 7, 92, 4, 83, 5, 14, 3, 75, 8, 32, 
    0, 23, 2, 32, 4, 65, 5, 51, 6, 34, 1, 27, 8, 94, 7, 55, 3, 21, 
    2, 61, 8, 91, 0,  7, 5, 44, 1, 80, 6, 95, 7, 80, 3, 89, 4, 78, 
    5, 46, 4, 76, 3, 59, 1, 96, 2, 11, 7, 40, 0, 87, 6,  4, 8, 44, 
    6,  6, 0, 20, 7, 51, 8, 72, 4, 16, 2,  1, 3, 94, 1, 90, 5,  6
  };
  const int q5339[] = {
    9, 9, // Number of jobs and machines
    1, 84, 0, 23, 3,  5, 6, 28, 4, 72, 7, 54, 2, 70, 5, 84, 8, 16, 
    7, 56, 8, 41, 6, 27, 2, 22, 5,  4, 3, 74, 1, 35, 0, 39, 4, 97, 
    5, 98, 8,  6, 6, 51, 0, 92, 4, 44, 3, 55, 1, 45, 2, 31, 7, 34, 
    7, 42, 4, 56, 2, 94, 5, 37, 3, 39, 8, 97, 1, 82, 0, 16, 6, 61, 
    5, 88, 2, 79, 4, 61, 6, 34, 0, 71, 3, 30, 1, 33, 8, 28, 7, 98, 
    8, 42, 4, 27, 1, 57, 2, 82, 7, 49, 6, 31, 0, 88, 5, 20, 3, 97, 
    6, 25, 1, 43, 7, 42, 0,  6, 3, 30, 2, 96, 4, 24, 5, 47, 8, 43, 
    8, 80, 5, 44, 4, 51, 2, 11, 0, 38, 3, 92, 7, 67, 6, 56, 1, 73, 
    5, 87, 2, 95, 4,  4, 0, 80, 7, 11, 8, 17, 3, 40, 1, 22, 6, 60
  };
  const int q5340[] = {
    9, 9, // Number of jobs and machines
    5, 93, 1, 90, 7, 28, 8, 38, 3, 25, 4, 97, 6, 61, 2, 62, 0, 87, 
    4, 12, 7, 13, 1, 15, 6, 28, 8, 82, 3, 45, 2, 27, 5,  9, 0, 28, 
    6, 80, 5, 77, 2, 67, 7, 86, 1, 74, 4, 59, 0, 86, 3, 72, 8, 61, 
    1, 18, 7, 37, 0, 85, 3, 72, 8, 39, 2, 98, 6,  3, 5, 72, 4, 97, 
    8, 86, 7, 29, 6, 56, 1, 78, 3, 77, 0, 12, 4, 83, 5, 76, 2, 72, 
    8, 15, 7, 86, 2, 42, 4, 42, 0, 88, 6, 50, 1, 37, 3, 64, 5, 85, 
    4, 39, 3, 67, 0, 91, 8, 11, 1, 62, 6, 53, 5, 96, 7, 99, 2, 39, 
    2, 80, 5, 30, 7, 24, 1, 93, 3, 17, 6, 33, 4, 10, 0, 70, 8, 75, 
    4, 74, 8, 75, 2, 78, 7, 35, 5, 72, 3, 50, 0, 96, 6, 33, 1, 92
  };
  const int q5341[] = {
    9, 9, // Number of jobs and machines
    1, 41, 2,  7, 6, 69, 7, 78, 0, 78, 8, 27, 4, 57, 3, 79, 5, 72, 
    5, 40, 3, 31, 2, 15, 4, 39, 7, 38, 1, 30, 6, 31, 8, 75, 0, 93, 
    1, 31, 0, 19, 6, 49, 3, 89, 2,  8, 5, 37, 7, 66, 4,  6, 8, 47, 
    0, 70, 3, 38, 7,  7, 6, 70, 8, 25, 4,  3, 2, 82, 5, 55, 1, 41, 
    4, 84, 2,  5, 5, 58, 0, 80, 6,  2, 1, 80, 3, 54, 7, 95, 8, 78, 
    2, 63, 5, 33, 8, 24, 4, 76, 0, 41, 7, 36, 6, 43, 1, 34, 3, 13, 
    4, 49, 5, 85, 6, 82, 0, 63, 8, 36, 1, 44, 7, 85, 2,  2, 3,  7, 
    8, 25, 4,  3, 0,  1, 5, 95, 7, 96, 6, 77, 1, 46, 2,  4, 3, 53, 
    7, 86, 5, 17, 2, 60, 4, 27, 3, 53, 1, 51, 0, 66, 8, 41, 6, 48
  };
  const int q5342[] = {
    9, 9, // Number of jobs and machines
    8, 20, 6, 12, 1, 46, 2, 53, 4, 76, 7, 93, 5, 11, 3, 82, 0, 94, 
    3, 71, 8,  8, 2, 36, 5, 88, 1, 77, 0, 29, 7, 80, 6, 79, 4, 15, 
    7, 77, 2, 27, 0, 44, 8,  4, 1, 78, 3, 44, 5,  3, 4, 79, 6, 12, 
    7, 97, 2, 36, 3, 11, 4, 73, 1, 39, 6, 45, 8, 92, 0, 38, 5,  1, 
    3, 29, 4, 91, 7, 50, 5, 92, 6, 80, 1, 79, 2, 70, 8, 22, 0, 77, 
    5, 39, 6,  5, 8, 49, 1,  1, 2, 12, 7, 57, 4, 45, 0, 95, 3, 91, 
    5, 32, 0, 66, 1,  7, 6, 78, 8, 55, 4, 85, 2, 75, 7, 83, 3, 14, 
    1, 53, 5, 77, 3, 73, 7, 14, 6, 56, 0, 22, 4, 81, 8, 28, 2, 42, 
    6, 28, 0, 44, 4, 71, 7, 66, 8, 32, 3, 56, 5, 59, 2, 86, 1, 82
  };
  const int q5343[] = {
    9, 9, // Number of jobs and machines
    8, 98, 0, 52, 7, 72, 5, 99, 3, 17, 6, 15, 2, 98, 1, 80, 4, 30, 
    2, 55, 5,  2, 6, 13, 8, 46, 1, 11, 7, 58, 0, 60, 4, 46, 3, 88, 
    3, 51, 5, 68, 2, 85, 7, 47, 1, 81, 6, 39, 4, 76, 0, 16, 8, 89, 
    5, 60, 0,  1, 3,  3, 8,  2, 1, 24, 6, 46, 4, 62, 2, 99, 7, 26, 
    7, 73, 0, 78, 6, 69, 1, 34, 3, 48, 8, 13, 5, 45, 4, 10, 2, 36, 
    3, 92, 6, 24, 8, 20, 5, 68, 0, 50, 4, 85, 1, 74, 2, 22, 7, 45, 
    6, 75, 3,  1, 0, 59, 7, 40, 2, 74, 1, 19, 4, 64, 8, 21, 5,  9, 
    2, 40, 6, 25, 0, 39, 3, 20, 8, 29, 5, 42, 4, 62, 7, 27, 1, 85, 
    3, 93, 6, 72, 0, 45, 1, 82, 7, 95, 4, 11, 8, 31, 2, 97, 5, 39
  };
  const int q5344[] = {
    9, 9, // Number of jobs and machines
    0, 45, 5, 95, 8, 63, 4, 31, 7, 89, 1, 83, 3, 87, 6, 73, 2, 61, 
    4, 87, 5, 28, 0, 87, 2, 86, 3, 39, 1, 43, 8, 23, 6, 34, 7, 36, 
    8, 55, 3, 82, 5, 76, 2,  7, 4, 16, 1, 79, 7, 51, 0, 52, 6, 40, 
    7, 84, 0, 32, 2, 45, 4, 60, 8, 53, 6, 22, 1, 41, 3, 55, 5, 39, 
    1, 70, 3, 25, 6, 99, 4, 26, 7, 55, 0, 36, 8, 56, 5, 15, 2, 87, 
    5, 10, 4, 30, 0, 26, 8, 74, 2,  1, 1, 61, 6, 30, 7, 63, 3, 23, 
    1, 75, 8, 86, 2, 59, 4, 52, 6, 16, 7, 51, 0, 51, 5, 52, 3, 35, 
    1, 31, 8, 31, 0, 23, 3, 77, 6, 84, 2, 95, 4, 43, 5, 96, 7, 42, 
    8, 77, 6, 76, 5, 87, 1, 40, 3, 32, 2,  7, 0, 36, 4, 74, 7, 46
  };
  const int q5345[] = {
    9, 9, // Number of jobs and machines
    5, 63, 7, 19, 0, 66, 2, 37, 6, 69, 1, 81, 3, 27, 8, 19, 4, 28, 
    0, 19, 7, 62, 3, 79, 4, 48, 2, 63, 1, 25, 6, 55, 5, 61, 8, 11, 
    7, 64, 4,  6, 0, 45, 3, 72, 2, 84, 6, 66, 1, 69, 5, 35, 8, 88, 
    4,  1, 2, 48, 6, 11, 0, 22, 1, 42, 7, 94, 8, 27, 3, 47, 5, 93, 
    0, 17, 7, 86, 8, 21, 2, 97, 5,  4, 3, 22, 6, 81, 4, 85, 1, 48, 
    0, 39, 5, 87, 8, 28, 7, 25, 4, 21, 6, 18, 2, 44, 3, 42, 1, 41, 
    6,  2, 7, 51, 2, 62, 4, 30, 3, 98, 8, 79, 5, 75, 1, 29, 0, 31, 
    0, 90, 7, 77, 5, 79, 1, 17, 3, 88, 4, 80, 6, 61, 2, 60, 8,  7, 
    5, 57, 0, 51, 2, 11, 8, 90, 6,  4, 1,  4, 7, 32, 4, 63, 3, 58
  };
  const int q5346[] = {
    9, 9, // Number of jobs and machines
    4, 76, 8, 38, 5, 31, 6, 26, 7,  5, 0, 63, 1, 57, 2,  8, 3, 23, 
    1, 51, 5, 87, 6, 81, 4, 77, 0, 46, 2, 41, 7, 62, 3, 35, 8, 91, 
    2, 76, 6, 13, 3, 46, 1, 17, 5, 33, 0, 82, 7, 98, 8, 68, 4, 18, 
    6, 30, 8, 88, 3,  8, 1, 73, 4, 24, 2,  7, 7, 39, 5, 70, 0, 13, 
    0, 60, 5, 73, 8, 37, 3, 26, 1,  4, 7, 43, 4, 73, 6,  7, 2,  4, 
    5, 38, 8, 97, 6, 91, 4, 97, 7, 78, 2, 20, 3, 21, 1, 24, 0, 31, 
    2, 90, 0, 27, 3, 74, 5, 32, 7, 13, 1, 76, 6, 97, 8, 88, 4, 46, 
    1, 54, 7, 35, 8,  3, 5, 14, 0, 32, 6, 34, 3, 61, 2, 84, 4, 16, 
    7, 40, 8, 47, 5, 51, 3, 88, 1, 50, 4, 67, 2, 68, 0, 76, 6, 17
  };
  const int q5347[] = {
    9, 9, // Number of jobs and machines
    3, 18, 0, 15, 8, 69, 6, 29, 2, 86, 1, 92, 4, 44, 7, 74, 5, 92, 
    4, 59, 1, 27, 5, 78, 2, 21, 6, 23, 0, 68, 7, 38, 8, 64, 3, 55, 
    8, 28, 1, 68, 3, 71, 7, 86, 6, 45, 4,  3, 0, 88, 2, 19, 5, 28, 
    8, 56, 7, 23, 0, 73, 2, 93, 5, 74, 1, 72, 6, 57, 4, 17, 3, 15, 
    2, 19, 3, 30, 8,  3, 4, 16, 6, 57, 7, 23, 0, 40, 5, 59, 1, 40, 
    1, 64, 0, 95, 2, 41, 3, 82, 7, 98, 6, 43, 5, 14, 8, 53, 4, 92, 
    3, 10, 0, 19, 5, 92, 1, 49, 6, 17, 8, 76, 7, 61, 4, 83, 2,  9, 
    1, 52, 2, 17, 7, 58, 8, 94, 4, 33, 5, 37, 0,  2, 6, 27, 3, 17, 
    1, 84, 8, 67, 4, 18, 2, 99, 7,  4, 0, 23, 3, 58, 5, 67, 6, 40
  };
  const int q5348[] = {
    9, 9, // Number of jobs and machines
    8, 78, 7,  4, 6, 55, 3, 23, 5, 23, 1, 86, 2, 18, 0, 18, 4, 47, 
    2,  8, 8, 20, 4, 75, 5, 42, 6, 29, 7, 79, 0, 19, 1, 48, 3, 10, 
    2, 57, 6, 92, 0, 50, 4, 43, 5, 57, 8, 59, 1, 76, 3, 91, 7, 72, 
    4, 35, 3, 27, 8, 83, 7, 29, 6, 81, 2, 64, 0, 60, 1, 50, 5, 71, 
    6,  5, 7, 61, 8,  9, 2, 16, 1, 43, 0, 39, 4, 25, 3, 45, 5, 94, 
    0, 51, 4, 30, 1, 36, 6, 25, 7, 70, 3, 30, 8, 16, 5, 66, 2, 91, 
    8, 43, 7, 72, 0, 76, 6, 34, 4, 72, 3, 39, 5, 71, 2,  9, 1, 53, 
    2, 54, 3, 46, 4, 77, 1, 35, 5, 99, 6,  8, 7, 65, 0, 83, 8, 37, 
    6,  7, 3, 79, 2, 82, 4, 82, 1, 95, 5, 76, 0, 52, 8, 57, 7, 84
  };
  const int q5349[] = {
    9, 9, // Number of jobs and machines
    6, 61, 5, 80, 3, 68, 8, 19, 4, 97, 2, 27, 0, 96, 1, 26, 7, 69, 
    6, 13, 3, 51, 1, 92, 4, 87, 2, 38, 5, 53, 8, 68, 0, 95, 7, 38, 
    8, 68, 5, 77, 0, 88, 6, 63, 1, 61, 4, 37, 7, 33, 3, 67, 2, 68, 
    2, 10, 5, 23, 0, 76, 6, 32, 4, 18, 1, 78, 3, 68, 8, 61, 7, 72, 
    5, 56, 3, 33, 1, 27, 8, 82, 0, 50, 4, 97, 2, 36, 7, 24, 6, 12, 
    3, 13, 7, 77, 2, 81, 8, 68, 1, 16, 5, 52, 6, 86, 0, 29, 4, 56, 
    7,  6, 3, 44, 1, 81, 5, 77, 6, 61, 8, 99, 4, 71, 2, 64, 0,  4, 
    4, 90, 3, 14, 8, 69, 7, 92, 5, 47, 1,  5, 0, 32, 2, 96, 6, 34, 
    7, 35, 3, 21, 6, 37, 5, 14, 1, 45, 8, 77, 4, 78, 0, 40, 2, 43
  };
  const int q5350[] = {
    9, 9, // Number of jobs and machines
    8, 58, 0, 57, 4, 67, 6, 42, 3, 96, 5, 49, 7, 53, 1, 85, 2, 88, 
    8, 74, 6,  5, 7, 85, 3, 55, 1, 52, 4, 28, 2, 23, 0, 59, 5, 79, 
    4, 24, 1, 84, 5,  7, 8, 88, 2, 57, 6, 26, 0, 22, 3, 19, 7,  3, 
    0, 32, 5, 80, 8, 50, 4, 41, 1,  3, 7,  9, 6, 83, 2, 46, 3, 90, 
    5,  2, 7, 94, 0,  2, 6, 85, 1, 65, 8, 96, 3, 51, 4, 82, 2, 73, 
    8, 87, 7, 83, 1, 94, 3, 31, 5, 23, 4, 31, 6, 46, 2, 17, 0,  9, 
    5, 40, 6, 82, 2, 12, 0, 10, 4, 57, 1,  7, 3, 97, 7, 49, 8, 28, 
    7, 16, 5, 78, 0, 27, 2, 98, 3, 82, 1, 95, 6, 79, 8,  5, 4, 29, 
    1, 11, 6, 61, 5, 32, 7, 99, 0, 28, 2, 59, 3,  5, 8, 38, 4, 85
  };
  const int q5351[] = {
    9, 9, // Number of jobs and machines
    6, 32, 0, 97, 7, 33, 1, 72, 5, 69, 8, 94, 2, 10, 3, 49, 4, 96, 
    7, 35, 1, 44, 6, 36, 5, 89, 2, 57, 4, 44, 0, 15, 3, 86, 8, 14, 
    6,  5, 7, 18, 0, 84, 1, 36, 8, 93, 2, 83, 3, 87, 4, 76, 5, 94, 
    2, 49, 1, 97, 6, 86, 3, 58, 4, 55, 5, 69, 0, 85, 7, 92, 8, 21, 
    8, 94, 3, 96, 5, 72, 2, 27, 4, 85, 6,  6, 7, 97, 0, 73, 1, 51, 
    2, 54, 1, 10, 4, 83, 0, 89, 5, 27, 3, 76, 6, 12, 7, 96, 8, 59, 
    2,  8, 6, 35, 7, 55, 1, 44, 5, 90, 8, 74, 0, 53, 4, 94, 3, 56, 
    1, 41, 6, 76, 5, 26, 3, 27, 7,  2, 4, 44, 0,  3, 2, 70, 8, 20, 
    8, 73, 3, 18, 6, 79, 4, 26, 0, 95, 5, 90, 1, 26, 7, 99, 2, 54
  };
  const int q5352[] = {
    9, 9, // Number of jobs and machines
    0, 26, 4, 10, 8, 84, 7, 55, 3, 20, 2,  4, 5,  1, 6, 55, 1,  5, 
    6, 11, 4, 58, 8, 21, 5, 96, 2, 70, 3, 15, 0, 40, 1, 80, 7,  3, 
    3, 97, 6, 49, 1, 99, 7, 64, 4, 69, 2,  7, 8, 44, 0, 52, 5, 78, 
    0, 84, 3, 40, 5, 31, 1, 96, 7, 64, 2, 48, 6, 33, 8, 12, 4, 24, 
    4,  4, 7, 98, 8, 64, 5, 88, 6, 21, 0, 28, 3, 71, 1, 59, 2, 31, 
    0, 28, 5, 46, 7, 21, 3, 52, 6, 40, 4, 66, 8, 51, 1, 87, 2, 75, 
    6, 50, 2, 40, 5, 82, 3, 21, 8, 91, 7, 57, 0, 43, 4, 98, 1, 12, 
    2, 80, 6, 60, 1, 98, 8, 81, 3, 92, 7, 31, 5, 64, 0,  6, 4, 82, 
    7, 95, 0, 71, 5, 10, 2, 89, 8, 44, 3, 77, 6, 30, 4, 33, 1, 85
  };
  const int q5353[] = {
    9, 9, // Number of jobs and machines
    6,  2, 3, 36, 8,  1, 1,  4, 2, 52, 0, 53, 4, 20, 5, 42, 7, 11, 
    3, 57, 4, 53, 5, 64, 6, 57, 7, 86, 1, 59, 8,  9, 0, 19, 2, 36, 
    7, 68, 5, 61, 0, 63, 8, 63, 6, 64, 1, 58, 4, 47, 3, 28, 2, 80, 
    1, 34, 4, 75, 3, 79, 6, 71, 5, 48, 0, 20, 2, 65, 8,  5, 7, 92, 
    8, 49, 4, 11, 5, 11, 6, 23, 2,  5, 7, 76, 3, 82, 0, 88, 1, 64, 
    1, 27, 4,  3, 2, 83, 5,  2, 6, 61, 3,  6, 8, 13, 0, 87, 7, 51, 
    7,  7, 8,  2, 2, 13, 4, 21, 6, 20, 5, 35, 1, 37, 3, 25, 0, 17, 
    1, 45, 6, 85, 3, 69, 4, 65, 7, 57, 8, 27, 2, 74, 0, 12, 5, 83, 
    7, 15, 2, 87, 0, 25, 5, 27, 6, 99, 1, 53, 3, 86, 8, 19, 4, 20
  };
  const int q5354[] = {
    9, 9, // Number of jobs and machines
    1, 73, 0, 66, 5, 42, 6, 80, 3, 38, 7,  6, 2, 53, 8,  3, 4, 81, 
    8, 59, 1, 84, 0, 36, 2, 47, 7, 61, 3, 74, 5, 99, 6, 90, 4, 78, 
    7, 32, 2, 94, 5, 51, 1, 86, 4, 24, 6, 46, 3, 32, 0, 50, 8, 31, 
    3, 81, 1, 95, 6, 95, 4, 39, 5, 59, 2, 69, 8, 65, 7, 14, 0, 11, 
    3, 43, 5,  6, 6, 92, 4, 13, 1, 34, 2, 67, 7, 32, 8, 20, 0, 35, 
    0, 84, 6, 23, 2, 56, 7, 77, 8, 78, 3, 88, 4, 95, 5, 90, 1, 64, 
    6, 39, 0, 99, 8, 40, 7, 81, 1,  7, 3, 53, 2, 11, 4, 35, 5,  1, 
    0,  9, 6, 65, 8, 37, 3, 64, 1, 49, 2, 29, 5, 57, 7, 12, 4, 30, 
    6, 56, 5,  1, 3, 13, 2, 83, 7, 41, 0, 65, 4, 94, 1, 66, 8, 57
  };
  const int q5355[] = {
    9, 9, // Number of jobs and machines
    1, 17, 2, 40, 6, 31, 3, 19, 0, 59, 7, 42, 4,  5, 5, 89, 8, 40, 
    1, 31, 6, 66, 2, 93, 4, 56, 8, 30, 7, 61, 0, 15, 3, 92, 5, 65, 
    3, 98, 5, 97, 2,  4, 0, 94, 6, 17, 1,  9, 7, 77, 4, 48, 8, 88, 
    2, 49, 1,  8, 6, 72, 4, 65, 0, 44, 8, 35, 7, 65, 3, 56, 5, 83, 
    7, 52, 5, 71, 1, 63, 4, 51, 2, 78, 8, 64, 3, 33, 6, 90, 0, 49, 
    4, 60, 6, 89, 7, 17, 1,  6, 2, 99, 5, 62, 0, 37, 8, 27, 3, 89, 
    5, 17, 2,  1, 6, 20, 8, 31, 4,  8, 7,  1, 3, 29, 1, 98, 0, 33, 
    5,  3, 2, 24, 1, 67, 0, 37, 4, 28, 7,  9, 6, 98, 3, 98, 8, 97, 
    8, 18, 1, 78, 3, 58, 0, 77, 2, 78, 4, 85, 5, 93, 6, 48, 7, 56
  };
  const int q5356[] = {
    9, 9, // Number of jobs and machines
    7, 61, 0, 64, 3, 62, 5, 38, 8, 74, 4, 46, 1, 77, 6, 70, 2, 20, 
    8, 70, 1, 16, 5, 53, 6, 25, 4, 59, 3, 82, 2, 58, 0, 14, 7, 23, 
    0,  1, 6, 36, 1, 46, 2, 28, 8,  5, 7, 86, 5, 34, 4, 66, 3,  9, 
    0, 49, 5, 89, 7, 59, 8, 52, 3, 42, 1, 20, 2, 78, 6, 53, 4, 65, 
    2, 84, 0, 17, 7, 17, 6, 35, 4, 41, 8, 88, 5, 42, 3, 55, 1, 15, 
    7, 40, 4, 83, 8,  2, 1, 50, 3, 88, 0,  3, 2, 98, 5, 88, 6, 70, 
    8, 96, 3, 16, 1,  4, 7, 56, 6, 47, 0, 66, 4, 44, 2, 84, 5, 69, 
    3, 22, 2, 21, 4, 61, 0, 85, 5,  4, 6, 47, 1, 94, 7, 30, 8, 64, 
    3, 27, 7, 59, 1, 81, 5, 99, 8, 76, 6, 70, 0,  2, 4, 88, 2, 54
  };
  const int q5357[] = {
    9, 9, // Number of jobs and machines
    7, 45, 8, 18, 3, 34, 5, 20, 4, 98, 1,  1, 0, 86, 6, 67, 2, 86, 
    5, 13, 1, 42, 3, 11, 6, 30, 0, 75, 8,  9, 7, 28, 2, 25, 4, 76, 
    4, 85, 5, 25, 2,  1, 1, 11, 3, 64, 6, 48, 8, 53, 0, 50, 7, 18, 
    0,  7, 2, 87, 6, 47, 1, 93, 4,  2, 8, 19, 7, 53, 5, 26, 3, 54, 
    0, 46, 8, 58, 1, 44, 5, 39, 7, 12, 6, 11, 2, 75, 4, 19, 3, 93, 
    3, 89, 6, 68, 4, 98, 0, 53, 1, 65, 7, 44, 2, 18, 8, 45, 5, 41, 
    2, 90, 4,  9, 7, 46, 8, 76, 6, 59, 0, 26, 1, 69, 3, 71, 5, 11, 
    6, 70, 2,  5, 1,  5, 0,  9, 8,  8, 3, 17, 4, 74, 7,  1, 5, 17, 
    6, 30, 3, 92, 5, 36, 2, 22, 8, 50, 7, 98, 4, 22, 1, 20, 0, 34
  };
  const int q5358[] = {
    9, 9, // Number of jobs and machines
    2, 58, 8, 91, 0, 17, 6, 88, 1, 29, 4, 16, 3, 38, 7, 88, 5, 35, 
    6, 45, 0, 34, 8,  2, 4, 53, 3, 50, 7, 14, 2, 69, 1, 67, 5, 87, 
    4, 89, 0, 26, 3, 45, 8, 50, 5, 83, 1, 51, 7,  8, 2, 80, 6, 85, 
    6,  7, 7, 82, 0, 69, 2, 42, 8, 27, 5, 97, 1, 47, 4, 66, 3, 80, 
    4, 61, 6, 47, 2, 25, 0, 85, 5, 58, 3,  9, 8, 71, 1, 17, 7, 87, 
    0, 20, 5, 18, 1, 72, 6, 92, 7, 17, 2,  3, 4, 49, 3, 10, 8,  7, 
    8, 99, 6, 10, 3, 94, 2, 96, 5, 37, 1, 10, 0, 51, 7, 93, 4, 86, 
    2, 93, 3, 30, 4, 63, 7, 97, 8, 28, 6, 12, 0, 91, 1, 10, 5, 85, 
    2, 58, 8, 88, 3, 77, 7, 93, 6, 64, 4, 60, 5, 12, 1, 78, 0, 79
  };
  const int q5359[] = {
    9, 9, // Number of jobs and machines
    0, 53, 7, 27, 1, 77, 3,  4, 8, 68, 6, 36, 2, 19, 5, 37, 4,  6, 
    4, 19, 5, 96, 8, 87, 7, 11, 6, 62, 2, 10, 3, 29, 0, 28, 1, 19, 
    2, 49, 0,  8, 5, 46, 8, 75, 6, 99, 3,  9, 1, 23, 7,  7, 4, 66, 
    8, 26, 3, 86, 5, 52, 4, 27, 6, 52, 1, 30, 0, 72, 7, 53, 2,  1, 
    7, 80, 6,  1, 4, 42, 3, 84, 5, 89, 1, 97, 2, 13, 8, 42, 0, 24, 
    1, 48, 8, 54, 7, 49, 6, 14, 4, 54, 3, 20, 5, 30, 2, 57, 0, 92, 
    7, 62, 4, 86, 1, 22, 6, 79, 3, 78, 8, 24, 5, 83, 2, 93, 0, 37, 
    5, 67, 2,  7, 4, 36, 8, 51, 0,  1, 7, 62, 1, 65, 6, 86, 3, 94, 
    1, 42, 3, 78, 6, 88, 4, 21, 2, 57, 7, 55, 8, 25, 5, 29, 0, 76
  };
  const int q5360[] = {
    9, 9, // Number of jobs and machines
    6, 32, 7, 97, 8, 45, 1, 11, 5, 71, 4, 48, 0, 87, 3, 65, 2, 95, 
    5, 11, 1, 56, 3,  3, 6, 50, 0, 51, 8,  6, 4, 71, 2, 68, 7, 56, 
    2, 76, 6, 24, 8, 19, 1, 87, 5, 11, 3, 21, 7,  8, 0, 35, 4, 93, 
    4, 50, 8, 52, 1, 88, 0, 35, 6, 66, 5, 59, 2, 27, 7, 91, 3, 35, 
    5, 60, 8,  8, 6, 17, 7, 12, 1, 36, 4,  2, 0, 61, 3, 69, 2, 26, 
    2,  6, 6,  6, 5, 55, 8, 92, 1, 44, 3, 98, 0, 47, 4, 80, 7, 41, 
    6, 75, 3, 50, 4, 47, 0, 46, 8, 25, 5, 83, 1, 36, 7,  6, 2,  3, 
    1, 12, 8, 85, 5, 15, 6, 50, 4, 47, 3, 97, 2, 45, 7, 34, 0, 58, 
    5, 58, 7, 83, 6, 16, 1, 34, 2, 34, 3, 60, 4, 30, 0, 51, 8, 48
  };
  const int q5361[] = {
    9, 9, // Number of jobs and machines
    1, 34, 7, 46, 3,  3, 8, 17, 6, 71, 4, 47, 0,  6, 5, 40, 2, 98, 
    3, 70, 8, 28, 2, 72, 4,  2, 7, 82, 6, 95, 0,  5, 1, 74, 5,  3, 
    5, 50, 2, 13, 4, 15, 6, 34, 8,  4, 1, 25, 3, 40, 0, 16, 7, 99, 
    4, 94, 2, 92, 0,  4, 7, 96, 3, 37, 6,  3, 1, 53, 5, 72, 8, 24, 
    8, 33, 6, 87, 3, 17, 2, 93, 7, 26, 0, 84, 5, 13, 1, 67, 4, 67, 
    5, 90, 3, 13, 4, 79, 1, 95, 8,  5, 7, 48, 0, 72, 2, 62, 6, 99, 
    1,  5, 8, 68, 3, 71, 5,  1, 2, 61, 7, 93, 6, 85, 0, 19, 4, 81, 
    3, 74, 1, 45, 6, 81, 7, 56, 5, 69, 0, 28, 4, 46, 2, 52, 8, 16, 
    1, 60, 5, 91, 4, 35, 6, 27, 7, 70, 8, 16, 2, 32, 3, 16, 0, 45
  };
  const int q5362[] = {
    9, 9, // Number of jobs and machines
    4, 18, 6, 29, 1, 31, 7, 42, 2, 14, 8, 11, 5, 78, 3, 44, 0, 74, 
    6, 60, 3, 32, 4, 88, 8, 64, 0, 89, 5, 95, 7, 59, 1, 71, 2, 98, 
    1, 92, 6, 24, 4, 42, 3, 80, 2, 97, 5, 38, 0, 90, 7, 24, 8, 30, 
    8, 56, 4, 10, 7, 36, 2, 86, 0, 22, 3, 85, 1, 89, 6, 29, 5, 74, 
    5, 44, 2, 98, 1, 32, 3, 63, 6, 78, 7,  1, 0, 66, 4, 92, 8, 52, 
    0, 68, 3, 76, 1, 35, 5, 85, 7, 36, 6, 13, 2, 34, 8, 88, 4, 28, 
    8, 57, 2, 60, 0, 45, 5,  2, 3, 25, 1, 31, 6, 47, 4, 91, 7, 13, 
    7,  3, 3, 73, 1, 22, 5, 51, 6, 83, 0, 81, 4, 50, 8, 76, 2, 65, 
    4,  4, 7, 23, 2,  5, 8, 68, 6, 13, 5, 68, 3, 93, 1, 26, 0, 95
  };
  const int q5363[] = {
    9, 9, // Number of jobs and machines
    2, 39, 4, 31, 6, 74, 0, 55, 3, 59, 5, 60, 8, 79, 1, 73, 7, 88, 
    6, 85, 5, 59, 7, 23, 0, 88, 1, 27, 3, 70, 4, 22, 8, 83, 2, 42, 
    3, 67, 1, 46, 0, 81, 6, 36, 8, 46, 4, 35, 7, 61, 5, 60, 2, 84, 
    3, 14, 2, 74, 5, 14, 0,  6, 1, 43, 6, 24, 8, 50, 7, 69, 4, 59, 
    0, 65, 4, 79, 6,  1, 7, 56, 5, 45, 2, 31, 3, 86, 1, 49, 8, 45, 
    1, 77, 2,  2, 0, 27, 6, 29, 4, 64, 5, 61, 7, 28, 8,  6, 3, 45, 
    5, 41, 3, 83, 0, 83, 6, 48, 1, 53, 8, 73, 7, 77, 4, 13, 2, 95, 
    4, 63, 3, 84, 8,  4, 0, 24, 6, 73, 7, 63, 5, 98, 2, 43, 1, 66, 
    5, 59, 6, 84, 4, 82, 3, 26, 0, 72, 8, 41, 1, 98, 2, 65, 7, 67
  };
  const int q5364[] = {
    9, 9, // Number of jobs and machines
    7, 61, 2, 28, 3, 71, 0, 33, 1, 95, 5, 27, 6, 98, 4, 93, 8, 40, 
    5, 71, 7, 84, 2, 15, 1, 51, 0, 87, 4, 55, 6, 16, 8,  8, 3, 52, 
    5, 83, 3, 67, 1, 52, 7, 34, 0, 25, 4, 46, 2, 97, 6, 21, 8, 65, 
    7, 91, 4, 15, 0, 80, 5,  2, 3, 26, 1, 64, 8, 14, 6,  7, 2, 15, 
    5,  9, 1, 49, 8, 14, 3, 33, 6,  7, 7,  4, 2, 31, 4, 74, 0, 94, 
    3, 44, 8, 89, 7,  7, 2, 45, 4, 73, 6, 83, 1, 91, 5, 67, 0, 23, 
    1, 55, 0, 42, 5, 41, 8, 89, 4, 23, 3, 55, 7, 18, 2,  2, 6, 41, 
    6, 18, 1, 42, 2, 10, 0, 62, 7, 66, 5, 17, 3, 46, 4, 77, 8, 50, 
    1, 44, 3, 63, 6, 97, 2, 24, 7, 98, 8, 60, 0, 75, 4, 70, 5, 33
  };
  const int q5365[] = {
    9, 9, // Number of jobs and machines
    4, 94, 3, 21, 5, 46, 8, 35, 2, 27, 6, 25, 0, 14, 1, 39, 7, 58, 
    7, 90, 3, 37, 8, 92, 5, 56, 6, 56, 2, 34, 1, 53, 4, 77, 0, 24, 
    0, 90, 1, 10, 7, 68, 8, 34, 4, 66, 5, 14, 2, 98, 3, 51, 6, 52, 
    2, 37, 6, 34, 3, 55, 5, 91, 4, 60, 1, 15, 0, 15, 7, 95, 8, 76, 
    1, 40, 8, 72, 2, 22, 6, 68, 5, 76, 0, 43, 4, 32, 7, 53, 3, 36, 
    4, 31, 5, 82, 7, 27, 6, 94, 2, 51, 8, 70, 0, 84, 1, 43, 3, 21, 
    5, 56, 4, 87, 1, 50, 3, 61, 2, 64, 7, 88, 8, 38, 6, 93, 0, 38, 
    8, 30, 2, 95, 6,  4, 5, 29, 0, 64, 3, 72, 4, 84, 7, 53, 1, 69, 
    2, 71, 6, 36, 8, 27, 7, 73, 3, 69, 4, 97, 0, 53, 5,  7, 1, 60
  };
  const int q5366[] = {
    9, 9, // Number of jobs and machines
    4, 64, 1, 96, 7, 80, 3,  4, 5, 71, 0, 92, 2, 68, 6, 94, 8,  7, 
    6, 15, 0, 17, 2, 71, 3, 86, 5, 32, 8, 21, 7, 86, 4, 13, 1, 96, 
    7, 33, 0, 62, 4, 35, 6, 49, 2, 34, 3, 79, 5, 78, 8, 42, 1, 25, 
    4, 53, 1,  4, 6, 63, 2, 15, 7,  2, 5, 65, 8, 21, 3, 80, 0, 36, 
    6, 19, 2, 20, 3, 38, 4, 46, 5, 18, 7, 52, 8, 91, 1, 42, 0, 25, 
    1, 58, 7, 30, 3, 55, 6, 26, 2, 60, 5, 85, 4, 10, 0, 83, 8, 75, 
    4, 60, 6, 56, 8, 38, 0,  5, 5, 20, 2, 46, 7, 29, 1, 89, 3, 97, 
    3, 10, 6, 13, 4, 95, 8,  4, 7, 17, 2, 58, 1, 15, 0, 49, 5, 89, 
    8, 17, 1, 80, 3, 44, 5, 98, 0, 46, 2, 47, 7, 49, 4, 73, 6, 37
  };
  const int q5367[] = {
    9, 9, // Number of jobs and machines
    7, 97, 5, 58, 3,  5, 8, 56, 6, 35, 1, 31, 0, 89, 2, 63, 4, 99, 
    5, 47, 8, 17, 7, 93, 2, 44, 3, 85, 0, 17, 6, 93, 4, 59, 1, 91, 
    2, 86, 0, 17, 8, 90, 4, 96, 1, 76, 5, 37, 3, 38, 6, 95, 7, 91, 
    4, 82, 2,  1, 7, 72, 0, 69, 5, 36, 3, 55, 1, 59, 8,  7, 6, 25, 
    4, 47, 0, 53, 3, 75, 5,  3, 2,  9, 8, 97, 1, 51, 7, 86, 6, 71, 
    3, 42, 2, 91, 5, 32, 4, 39, 8, 14, 6, 71, 7, 90, 1, 60, 0, 96, 
    4, 69, 1, 37, 5, 55, 0, 34, 6, 76, 3, 18, 7, 39, 8, 21, 2, 61, 
    6, 78, 3, 82, 4, 40, 5, 60, 7,  7, 2, 14, 1, 92, 8, 48, 0, 93, 
    1, 10, 3, 83, 0, 91, 7, 46, 4, 36, 2, 54, 5, 13, 6, 22, 8, 19
  };
  const int q5368[] = {
    9, 9, // Number of jobs and machines
    2, 40, 7, 59, 4, 92, 0, 30, 3, 27, 6, 28, 1, 82, 8, 58, 5, 40, 
    7,  1, 4, 35, 1, 25, 6, 29, 3, 86, 0, 67, 8, 45, 5, 52, 2, 88, 
    5, 96, 8, 20, 6, 51, 0, 19, 7, 64, 2, 11, 1, 95, 3, 34, 4, 17, 
    0,  1, 2, 69, 5, 79, 1, 45, 7, 96, 8, 86, 6, 11, 4, 21, 3, 85, 
    4, 45, 6, 89, 3, 69, 7,  6, 1, 35, 5, 75, 8, 84, 2, 42, 0, 89, 
    8,  6, 6, 35, 0, 49, 4, 76, 5,  4, 1, 38, 3, 99, 7, 14, 2, 73, 
    5, 35, 7, 43, 8, 62, 1, 71, 2, 75, 4, 36, 6, 43, 0, 13, 3, 69, 
    0, 57, 8, 94, 7, 90, 1, 11, 3, 32, 4, 64, 5, 97, 6,  5, 2, 96, 
    8, 41, 2, 40, 5, 57, 3, 38, 6, 46, 7, 55, 4, 42, 1, 31, 0, 87
  };
  const int q5369[] = {
    9, 9, // Number of jobs and machines
    6, 22, 1, 16, 0, 91, 8, 69, 2, 35, 5, 91, 4, 38, 3, 60, 7, 65, 
    4, 98, 3, 63, 5, 87, 2, 33, 8, 87, 6, 80, 0, 67, 1, 85, 7, 57, 
    5,  9, 0, 58, 6, 37, 7, 92, 3,  3, 1, 18, 2,  3, 8, 68, 4, 52, 
    6, 71, 4,  9, 7, 82, 0, 14, 5, 20, 2, 91, 3, 50, 1, 80, 8, 54, 
    2, 49, 5, 41, 4, 23, 8, 63, 7, 58, 0,  3, 1, 11, 6,  2, 3, 46, 
    6, 73, 2, 58, 0, 58, 3, 62, 7, 96, 4, 30, 1, 26, 5, 94, 8, 80, 
    6, 23, 0, 71, 1, 65, 7, 47, 5, 77, 4, 17, 8, 96, 2, 47, 3, 79, 
    5,  5, 2, 84, 0, 79, 8, 97, 1,  3, 7, 33, 3, 90, 6, 96, 4, 54, 
    5, 18, 7, 28, 1,  5, 0, 80, 3, 38, 8, 93, 6, 86, 2, 78, 4, 83
  };
  const int q5370[] = {
    9, 9, // Number of jobs and machines
    7, 78, 3, 17, 0, 78, 5, 52, 2,  2, 4, 31, 6,  4, 8, 35, 1, 30, 
    4, 95, 7, 89, 1, 15, 6, 54, 0,  4, 3, 75, 2, 42, 5, 87, 8, 11, 
    2,  2, 6, 44, 1, 59, 4, 74, 8, 44, 5, 98, 7, 80, 0, 96, 3, 73, 
    2, 82, 1, 80, 5, 67, 8, 46, 4, 77, 0, 21, 7, 63, 6,  5, 3, 87, 
    4, 78, 1, 15, 2, 26, 8, 80, 6, 86, 3, 40, 5, 99, 7, 99, 0, 75, 
    0, 32, 1, 60, 2, 22, 7, 36, 6,  7, 4, 64, 3, 38, 5, 72, 8, 49, 
    3, 89, 1, 40, 6, 44, 0, 12, 5, 62, 8,  2, 4, 37, 7, 93, 2,  6, 
    0, 46, 3, 30, 6, 49, 8, 89, 5, 47, 1, 88, 2, 70, 7, 73, 4, 88, 
    2, 20, 8, 82, 6, 44, 4, 99, 0, 70, 1, 18, 5,  5, 7, 51, 3, 40
  };
  const int q5371[] = {
    9, 9, // Number of jobs and machines
    6,  2, 8, 96, 1, 65, 4, 44, 5, 30, 3, 64, 2, 34, 0, 88, 7, 21, 
    3, 81, 7, 57, 8, 72, 0, 39, 5, 10, 6, 70, 2, 14, 4, 67, 1, 55, 
    0, 27, 5, 89, 4, 68, 6, 27, 7, 27, 3, 76, 2, 85, 1, 14, 8, 89, 
    0, 99, 1, 82, 6, 66, 8, 94, 5, 44, 2, 40, 3, 22, 4, 20, 7, 18, 
    7, 25, 2, 65, 4, 47, 3,  5, 5, 54, 8,  6, 1, 50, 0, 98, 6, 15, 
    3, 98, 0, 10, 1, 99, 6, 44, 2, 82, 8, 56, 5, 94, 7, 12, 4, 36, 
    2, 86, 3, 41, 5, 49, 4, 28, 1, 56, 7, 20, 8, 52, 6, 91, 0, 98, 
    6, 18, 2, 81, 3, 95, 8,  9, 7, 98, 4,  8, 5, 18, 1, 57, 0, 25, 
    3, 27, 4, 43, 8, 43, 0,  8, 7, 59, 1, 50, 5, 56, 2, 90, 6, 83
  };
  const int q5372[] = {
    9, 9, // Number of jobs and machines
    2, 37, 7, 59, 1, 43, 0, 90, 4, 48, 8, 12, 5, 34, 6,  3, 3, 23, 
    4, 99, 2, 56, 7, 18, 8, 28, 0,  4, 5, 88, 6, 44, 1, 99, 3, 88, 
    8, 74, 1, 97, 2, 74, 4, 42, 0, 76, 5, 67, 7, 11, 3, 50, 6, 28, 
    3, 18, 1, 12, 2, 76, 7, 37, 6, 93, 0, 75, 4, 48, 5, 93, 8, 43, 
    3, 11, 7, 35, 0, 37, 6, 64, 5, 30, 8, 37, 1, 96, 2, 51, 4, 91, 
    0, 72, 6, 45, 7,  3, 5, 96, 3, 30, 4, 68, 2, 27, 1, 13, 8, 45, 
    2, 38, 4, 32, 3, 65, 5, 36, 6,  5, 7,  6, 8, 48, 1,  6, 0, 57, 
    1, 44, 6,  4, 4, 77, 3, 60, 8, 55, 7, 82, 2, 70, 5, 13, 0, 44, 
    3, 19, 7,  2, 8, 23, 4, 92, 5,  9, 6, 69, 0, 37, 2, 27, 1, 53
  };
  const int q5373[] = {
    9, 9, // Number of jobs and machines
    6, 64, 3, 20, 0, 70, 1, 83, 7, 44, 5, 90, 2, 26, 8, 77, 4, 28, 
    8, 94, 3, 32, 7, 41, 1, 86, 0, 43, 4, 27, 5, 93, 6, 71, 2, 62, 
    8, 91, 4, 60, 0, 45, 7, 86, 3, 56, 6, 16, 5, 77, 2, 58, 1, 39, 
    1, 97, 2, 12, 6, 55, 0, 95, 3, 88, 4, 70, 5, 25, 7,  4, 8, 73, 
    0, 45, 5, 26, 3, 54, 6, 17, 1, 11, 7, 91, 4, 38, 2, 94, 8, 61, 
    1, 69, 4, 40, 3, 96, 6, 99, 2, 84, 5, 66, 8, 56, 7, 31, 0, 46, 
    5, 11, 8, 71, 6, 11, 7, 32, 1, 33, 0, 91, 2, 34, 4, 83, 3, 87, 
    8, 56, 1, 11, 5, 34, 7, 11, 0, 16, 6, 63, 4, 14, 2, 80, 3, 59, 
    0, 93, 1, 71, 2, 28, 3, 21, 8, 56, 6,  2, 5, 86, 4, 20, 7, 32
  };
  const int q5374[] = {
    9, 9, // Number of jobs and machines
    6, 85, 4, 75, 1,  4, 2, 14, 5, 19, 0, 94, 8, 23, 7,  7, 3, 61, 
    7, 28, 8, 19, 4, 26, 6, 34, 5, 28, 0, 68, 2, 24, 1, 27, 3, 75, 
    0, 45, 2,  4, 7, 29, 3, 39, 6, 72, 1, 71, 4, 46, 5, 20, 8, 49, 
    3, 96, 5, 35, 2, 79, 6, 97, 4, 64, 1, 43, 0, 38, 7, 81, 8, 85, 
    0, 72, 8,  3, 6,  9, 3, 15, 1, 90, 4,  3, 5, 33, 2, 35, 7, 63, 
    5, 54, 8, 67, 3, 17, 6, 63, 2,  3, 4, 35, 1, 42, 7,  2, 0,  9, 
    0, 97, 4, 58, 5, 19, 8, 42, 3, 87, 2, 27, 1, 34, 7, 69, 6, 72, 
    6, 83, 8, 64, 5,  1, 3, 58, 7, 87, 1, 85, 0, 49, 4, 21, 2, 95, 
    4, 83, 0, 35, 5, 45, 2, 54, 6, 63, 3, 49, 7, 56, 1, 86, 8, 81
  };
  const int q5375[] = {
    9, 9, // Number of jobs and machines
    2, 26, 6, 25, 5, 34, 1, 26, 3, 87, 8, 78, 7, 96, 4, 23, 0, 11, 
    4,  7, 8, 71, 3, 93, 5, 28, 2, 80, 1, 86, 7, 37, 0, 23, 6, 34, 
    3, 92, 8, 82, 4, 43, 2, 55, 6, 91, 5,  3, 1,  3, 7, 87, 0, 95, 
    5, 43, 0, 58, 3, 37, 6, 17, 7, 65, 4, 74, 2, 22, 8, 73, 1, 23, 
    4, 45, 6, 35, 5, 58, 8,  5, 0, 10, 7, 72, 1, 10, 2, 54, 3, 56, 
    3, 63, 7, 63, 8, 53, 5, 88, 0,  9, 6, 92, 4, 76, 2, 33, 1, 35, 
    7, 94, 0, 26, 2, 59, 5, 62, 6, 15, 4, 56, 8, 18, 3, 28, 1, 89, 
    2, 88, 0, 28, 5, 99, 8, 42, 6, 35, 3, 85, 7, 53, 4, 36, 1,  9, 
    6, 64, 7, 97, 8, 70, 5,  9, 1,  8, 3, 75, 0, 33, 4,  4, 2, 69
  };
  const int q5376[] = {
    9, 9, // Number of jobs and machines
    7, 76, 6, 28, 8, 54, 1, 73, 3, 12, 0, 90, 5, 22, 4, 71, 2, 56, 
    1, 79, 8, 98, 4, 74, 5, 71, 0, 47, 6, 25, 2, 92, 3, 48, 7, 99, 
    6,  5, 1, 90, 8, 11, 3, 12, 4, 28, 5, 33, 2, 34, 0, 45, 7, 69, 
    8, 59, 2, 70, 7, 74, 4, 20, 3, 38, 5, 73, 1,  6, 0, 36, 6, 34, 
    4, 27, 0, 32, 6, 51, 2, 69, 3, 13, 5, 14, 1, 46, 8, 18, 7, 89, 
    6,  8, 0,  3, 7, 25, 2, 40, 4, 54, 1, 17, 3, 97, 8, 81, 5, 13, 
    4, 90, 8,  8, 2, 74, 6, 38, 0, 21, 1, 31, 3, 94, 5, 27, 7,  3, 
    6, 13, 0, 86, 5, 33, 4, 15, 8, 78, 7, 28, 1, 48, 2, 13, 3, 80, 
    4, 82, 1, 20, 5, 17, 6, 81, 0, 26, 8, 31, 3, 95, 2, 10, 7, 17
  };
  const int q5377[] = {
    9, 9, // Number of jobs and machines
    5,  1, 8, 14, 4, 51, 1, 40, 0, 75, 2, 80, 6, 56, 7, 41, 3, 16, 
    3, 57, 1, 83, 0, 28, 4, 80, 6, 67, 5, 80, 8, 50, 2, 96, 7, 58, 
    8, 97, 2, 95, 4, 57, 0, 99, 7, 17, 1, 57, 5, 35, 6, 36, 3,  7, 
    5, 95, 3, 58, 6, 99, 0, 76, 2, 76, 1, 18, 4, 36, 7, 36, 8, 30, 
    1, 75, 6, 84, 4, 10, 3, 17, 0, 57, 5, 23, 7, 71, 8, 72, 2,  4, 
    2, 40, 3, 63, 4, 64, 1, 90, 7, 78, 8, 16, 5, 96, 0, 30, 6, 43, 
    8, 15, 1, 65, 5,  2, 3, 23, 6,  4, 4, 54, 0, 17, 2, 44, 7, 11, 
    3, 91, 1, 89, 0, 75, 5,  3, 6, 51, 2, 17, 4, 65, 8, 20, 7, 97, 
    8, 64, 1, 91, 6, 50, 4, 30, 0, 97, 7, 25, 5, 52, 3,  6, 2, 72
  };
  const int q5378[] = {
    9, 9, // Number of jobs and machines
    5,  3, 6, 94, 7, 19, 3, 64, 0, 70, 1, 14, 8,  9, 2,  7, 4, 69, 
    5, 68, 6, 83, 8,  4, 2, 61, 3, 98, 4, 23, 7, 15, 1, 42, 0, 45, 
    4,  9, 5, 30, 7, 56, 0, 76, 2, 89, 1, 56, 6, 86, 8, 40, 3, 49, 
    0, 90, 4, 61, 2, 20, 8,  1, 5, 41, 3, 71, 6,  9, 7, 21, 1, 77, 
    0, 79, 7, 45, 2, 53, 6, 32, 8, 24, 4, 11, 1, 85, 5,  8, 3, 41, 
    8, 15, 2, 99, 7, 14, 4, 17, 3, 34, 0, 94, 6, 17, 1, 43, 5, 96, 
    8,  6, 6, 85, 1, 16, 0, 74, 7, 51, 3, 15, 4, 96, 5, 27, 2, 28, 
    8, 49, 7, 16, 4, 38, 2, 13, 5, 63, 1, 18, 3, 57, 0, 86, 6,  5, 
    0, 84, 8, 22, 4, 33, 7, 73, 3, 23, 6, 90, 2, 39, 1, 54, 5, 23
  };
  const int q5379[] = {
    9, 9, // Number of jobs and machines
    6, 97, 8, 60, 4, 65, 1, 80, 2, 21, 0, 14, 3, 83, 5, 73, 7, 28, 
    2, 90, 4, 82, 8, 75, 1, 91, 0, 63, 6, 75, 5, 46, 7,  6, 3, 63, 
    5, 66, 1, 31, 8,  1, 0, 31, 6, 82, 2, 61, 7, 91, 4, 99, 3, 23, 
    1, 49, 0, 35, 3, 62, 8, 40, 6, 23, 5, 49, 4,  4, 7, 52, 2, 68, 
    6, 61, 2,  9, 5, 62, 0, 76, 3, 52, 7,  8, 1, 33, 8, 68, 4, 46, 
    4, 66, 6, 10, 0,  5, 8, 95, 5, 15, 7, 48, 2,  8, 3, 61, 1, 26, 
    7, 40, 3, 56, 0, 83, 1, 21, 6, 49, 5, 72, 2, 67, 8, 90, 4, 25, 
    2, 45, 8, 26, 0, 10, 1, 59, 7, 34, 5, 79, 3, 49, 6, 40, 4, 29, 
    8, 90, 0, 42, 4, 43, 3, 37, 7, 47, 5, 29, 6, 37, 2, 81, 1, 37
  };
  const int q5380[] = {
    9, 9, // Number of jobs and machines
    4, 72, 6, 16, 7, 93, 0, 54, 1, 94, 5,  3, 8, 43, 2, 27, 3, 52, 
    0,  6, 2, 29, 3, 73, 6, 18, 1, 49, 4, 11, 7, 41, 8, 98, 5,  1, 
    7, 67, 1, 71, 0, 96, 8, 14, 5, 34, 4,  4, 2, 21, 6, 97, 3, 98, 
    8, 38, 6, 83, 3, 55, 7,  1, 5, 67, 0, 39, 4, 92, 1, 13, 2, 57, 
    1, 40, 0, 49, 4, 84, 6, 68, 5, 84, 2, 31, 7, 26, 8, 38, 3, 94, 
    1, 94, 2, 90, 5, 59, 4, 37, 8,  9, 7, 52, 6, 40, 3, 63, 0, 75, 
    8, 66, 7, 77, 3, 74, 5, 61, 1,  8, 6, 60, 2, 62, 0, 37, 4, 25, 
    3, 22, 6, 13, 1, 75, 0,  8, 4, 21, 7, 31, 5, 69, 8, 51, 2, 59, 
    8, 75, 0, 27, 3, 99, 2, 85, 6, 30, 5, 26, 7, 59, 4, 45, 1, 35
  };
  const int q5381[] = {
    9, 9, // Number of jobs and machines
    7, 10, 8, 89, 2,  7, 1, 42, 6, 93, 0, 60, 3, 24, 4, 50, 5, 54, 
    4, 80, 8, 11, 5,  2, 0, 98, 7, 12, 2, 70, 3, 65, 1, 79, 6, 81, 
    0, 10, 4, 44, 6, 77, 5, 66, 2, 57, 8, 10, 3, 73, 1, 54, 7,  8, 
    8,  6, 4, 33, 6, 23, 1, 58, 3, 74, 5, 92, 2, 62, 7, 20, 0, 25, 
    3, 81, 7, 75, 4,  1, 2, 72, 1, 75, 6, 18, 8,  3, 5, 99, 0, 28, 
    1, 72, 5, 91, 8, 35, 6, 53, 7, 17, 2, 83, 0, 16, 3, 54, 4, 89, 
    8, 46, 5, 94, 4, 33, 7, 42, 3, 26, 1, 34, 2, 14, 6, 64, 0, 85, 
    5, 78, 4, 61, 0, 54, 6, 19, 1, 17, 2, 59, 7, 37, 3,  8, 8, 64, 
    1, 72, 2,  6, 8, 54, 6, 79, 3, 52, 0,  9, 7, 69, 5, 63, 4, 92
  };
  const int q5382[] = {
    9, 9, // Number of jobs and machines
    2, 60, 7, 72, 8, 73, 5, 50, 0, 81, 3, 75, 1, 43, 4, 69, 6, 14, 
    7, 81, 2, 36, 4, 32, 0, 44, 1,  6, 3, 68, 6, 10, 8, 66, 5, 91, 
    6, 47, 7, 89, 0, 11, 3, 10, 2, 11, 8, 12, 5, 83, 4, 48, 1, 93, 
    0, 66, 6, 47, 7,  8, 5, 52, 1, 53, 2, 71, 3, 61, 8, 27, 4, 36, 
    5,  8, 6, 38, 8, 70, 7, 77, 0, 53, 3, 58, 2, 81, 4,  2, 1, 65, 
    3, 84, 4, 69, 2, 32, 0, 10, 1, 96, 8, 97, 7, 95, 5, 63, 6, 96, 
    4, 42, 5, 76, 7,  8, 0, 22, 3, 13, 6, 79, 1, 20, 8, 58, 2, 82, 
    3, 55, 4, 74, 6,  6, 5, 22, 0, 81, 1,  2, 7, 91, 2, 60, 8, 98, 
    8, 38, 4, 93, 0, 88, 7, 31, 2, 89, 5, 24, 1, 51, 6,  5, 3, 67
  };
  const int q5383[] = {
    9, 9, // Number of jobs and machines
    5, 37, 6, 63, 7, 53, 0, 13, 8, 12, 1, 90, 2,  3, 4, 48, 3, 96, 
    0, 29, 5, 77, 7,  5, 4, 41, 1, 57, 3, 37, 8, 57, 6, 87, 2, 97, 
    7, 52, 0, 68, 6, 19, 3, 16, 1, 50, 5, 72, 2, 15, 8, 85, 4, 32, 
    1, 95, 7, 64, 4, 95, 8, 56, 2, 60, 6, 98, 3, 20, 5, 29, 0, 44, 
    3, 17, 1, 66, 8, 70, 4, 46, 5,  2, 0, 69, 6, 18, 2, 30, 7, 56, 
    4, 25, 8, 78, 0, 54, 5, 23, 7, 73, 3, 14, 1, 13, 2, 40, 6, 62, 
    6, 40, 3, 14, 4, 57, 2, 69, 7, 70, 5, 86, 0, 42, 8, 71, 1, 46, 
    0,  7, 2, 43, 6, 16, 5, 15, 1, 26, 7, 26, 8,  8, 4, 92, 3,  1, 
    8, 65, 4,  1, 1, 98, 5, 84, 0, 21, 6, 24, 7, 78, 2, 89, 3, 46
  };
  const int q5384[] = {
    9, 9, // Number of jobs and machines
    1,  8, 8, 17, 7, 77, 4, 50, 0, 18, 6, 13, 2, 73, 5, 61, 3, 27, 
    5, 60, 6, 52, 8, 66, 7, 19, 1, 59, 3, 86, 4, 76, 0, 18, 2,  9, 
    0, 38, 6, 22, 4, 38, 3, 56, 8, 47, 5, 73, 2, 35, 7, 83, 1, 89, 
    2, 42, 8, 18, 0, 25, 7, 88, 5, 34, 6, 69, 4, 22, 1, 90, 3, 94, 
    4, 19, 0, 59, 2, 79, 3, 49, 6,  4, 8, 50, 7, 27, 5, 47, 1, 59, 
    6, 43, 4, 61, 3, 45, 7, 54, 0, 98, 1, 77, 8, 95, 2, 34, 5, 15, 
    2, 74, 3, 93, 1, 65, 0, 20, 5, 91, 8, 49, 4, 36, 6, 50, 7, 70, 
    3, 50, 6, 15, 8, 94, 7,  5, 1, 87, 4, 85, 5, 99, 0, 69, 2, 69, 
    6,  2, 8, 15, 5, 93, 4, 42, 2,  4, 3, 56, 0, 44, 7, 47, 1, 37
  };
  const int q5385[] = {
    9, 9, // Number of jobs and machines
    5, 61, 7, 22, 2, 26, 4, 55, 0, 79, 1, 87, 6, 11, 8, 23, 3, 33, 
    1, 55, 5,  6, 3, 42, 8, 38, 0, 20, 2, 39, 7, 83, 4, 43, 6, 20, 
    4, 38, 6, 58, 1, 17, 2, 80, 8,  8, 0, 84, 3, 77, 5, 79, 7, 50, 
    7, 73, 8, 83, 2, 33, 6, 17, 4,  7, 3, 32, 1,  8, 5, 15, 0,  2, 
    5, 39, 7, 48, 4, 23, 2, 56, 0, 36, 1, 50, 8, 89, 6, 74, 3, 36, 
    4, 26, 3, 42, 7,  1, 8, 47, 1,  6, 0, 85, 6, 53, 5, 34, 2, 20, 
    1, 21, 4, 32, 7, 53, 3, 66, 0, 74, 6,  4, 8, 30, 2, 34, 5, 79, 
    7, 95, 8, 95, 3, 84, 2, 64, 4, 40, 5, 91, 0, 10, 6, 21, 1, 57, 
    5,  6, 3, 52, 7, 45, 8, 98, 1, 14, 6, 95, 2, 38, 4, 40, 0, 31
  };
  const int q5386[] = {
    9, 9, // Number of jobs and machines
    1, 18, 0, 58, 3, 34, 8, 37, 6, 16, 5, 80, 2, 67, 7, 54, 4, 54, 
    6, 59, 1, 50, 5, 18, 3, 88, 7, 34, 0, 80, 4, 68, 8, 75, 2, 99, 
    3, 10, 1,  3, 5, 61, 2, 29, 0, 31, 7, 10, 8, 29, 6, 25, 4, 28, 
    6, 68, 4, 15, 0, 40, 8, 77, 7, 72, 1,  7, 3,  2, 5, 61, 2, 14, 
    7, 59, 1, 43, 8, 77, 4, 11, 5, 45, 0, 88, 6, 63, 3, 65, 2, 64, 
    8, 13, 1,  6, 3, 86, 6, 86, 7, 39, 2, 60, 4, 83, 5, 25, 0, 67, 
    5, 39, 1, 31, 7, 10, 0, 42, 2, 77, 4, 34, 6, 53, 8, 28, 3, 21, 
    4, 87, 6, 65, 2, 18, 7, 72, 3, 39, 5, 88, 1, 11, 0, 11, 8, 30, 
    1, 21, 6, 58, 3,  6, 5,  7, 8, 48, 0, 68, 4,  2, 7,  3, 2, 95
  };
  const int q5387[] = {
    9, 9, // Number of jobs and machines
    6, 76, 0, 58, 7, 45, 5, 83, 1, 51, 2,  9, 3, 76, 4,  4, 8, 40, 
    1, 69, 4, 60, 8, 85, 7, 49, 6, 93, 2, 94, 3, 30, 0,  9, 5, 40, 
    3, 49, 8, 69, 1, 35, 6, 96, 0, 50, 5, 69, 4, 65, 7, 35, 2, 73, 
    7,  1, 2, 20, 1, 44, 4,  2, 6, 43, 0, 99, 3,  3, 5, 47, 8, 52, 
    6, 67, 5, 18, 2,  8, 8, 12, 3, 90, 1, 20, 4, 91, 7,  2, 0, 87, 
    6, 94, 1,  7, 4, 75, 7, 93, 2, 17, 8, 86, 5, 81, 3,  9, 0, 24, 
    3, 86, 6, 86, 4, 59, 2, 75, 0, 29, 8, 87, 7, 76, 5, 38, 1, 73, 
    0, 16, 2, 19, 6, 42, 5, 14, 8, 49, 3, 62, 1, 44, 4, 58, 7, 79, 
    2, 67, 3, 10, 8, 31, 7, 32, 1, 76, 4, 54, 5,  2, 0, 57, 6, 72
  };
  const int q5388[] = {
    9, 9, // Number of jobs and machines
    3, 58, 1, 13, 6, 59, 2, 71, 7, 70, 8, 24, 5, 26, 0, 74, 4, 88, 
    2, 66, 7,  9, 0, 96, 8, 12, 6, 71, 3, 13, 1, 99, 5, 65, 4, 74, 
    5, 58, 6, 27, 7, 92, 3, 86, 8, 49, 0, 45, 4,  9, 1, 68, 2, 32, 
    0, 96, 7, 83, 6,  4, 3, 64, 8, 75, 4, 94, 2, 47, 5, 90, 1, 21, 
    8, 50, 2,  7, 7, 30, 3, 44, 4, 20, 1, 73, 5, 61, 6, 56, 0, 89, 
    1, 16, 7, 35, 3, 59, 5, 34, 4, 26, 2, 60, 0, 48, 8, 45, 6, 48, 
    2, 90, 3, 49, 7, 27, 1,  7, 8, 24, 6, 47, 5, 86, 4, 11, 0,  4, 
    7, 97, 0, 53, 4, 44, 3, 95, 5, 45, 8, 25, 6, 83, 1, 46, 2, 63, 
    0, 29, 4, 75, 7, 85, 2, 61, 1, 41, 8, 90, 3, 42, 5, 31, 6, 96
  };
  const int q5389[] = {
    9, 9, // Number of jobs and machines
    7, 79, 8, 33, 6, 83, 3, 15, 5, 36, 1, 26, 0, 55, 2, 44, 4, 39, 
    0, 30, 6, 66, 2, 93, 8,  5, 4, 53, 3, 83, 1, 68, 5,  6, 7, 51, 
    5, 68, 7, 88, 0, 28, 2, 67, 6, 26, 1, 21, 8, 27, 4, 77, 3,  4, 
    4, 55, 6, 74, 2, 53, 1, 30, 5, 83, 7, 74, 8, 47, 3, 54, 0, 21, 
    5,  5, 4, 82, 2, 91, 1, 47, 8, 85, 7, 94, 6,  1, 0, 52, 3, 11, 
    0, 27, 8, 78, 7, 59, 5, 33, 6, 46, 2, 75, 3, 25, 1, 56, 4, 15, 
    3, 37, 8,  1, 4, 56, 5, 52, 2, 16, 1, 19, 6, 94, 7, 12, 0, 45, 
    0, 70, 3, 56, 4, 26, 7, 45, 6, 62, 1, 78, 5, 91, 2, 73, 8, 31, 
    5, 68, 7, 13, 6, 69, 2, 62, 1, 22, 4, 85, 3, 26, 8, 96, 0, 75
  };
  const int q5390[] = {
    9, 9, // Number of jobs and machines
    0, 85, 4, 71, 6, 71, 5,  4, 3, 98, 1, 23, 7, 51, 2, 16, 8,  4, 
    6, 81, 0, 50, 3, 27, 8, 52, 7, 17, 1, 94, 2, 68, 4, 15, 5, 73, 
    4, 45, 6, 54, 1, 20, 7, 37, 8, 13, 0, 32, 5, 27, 2, 48, 3, 14, 
    6, 97, 4,  4, 1, 56, 7, 52, 2, 46, 8, 33, 0, 84, 5, 38, 3, 15, 
    8, 58, 4, 80, 3, 77, 7, 63, 0, 23, 1, 69, 2, 70, 5, 80, 6, 56, 
    0, 33, 1, 12, 6, 66, 4, 37, 8, 74, 2, 32, 5, 42, 3,  8, 7, 18, 
    1, 56, 6, 18, 7, 88, 5, 64, 2,  7, 3,  8, 4, 52, 0, 45, 8, 60, 
    5, 97, 4, 90, 8, 54, 6,  4, 3, 45, 1, 48, 2, 56, 7, 66, 0, 33, 
    6, 60, 8,  4, 7, 68, 4, 39, 0, 90, 1, 44, 5, 98, 3, 70, 2, 50
  };
  const int q5391[] = {
    9, 9, // Number of jobs and machines
    4, 13, 0, 18, 5, 99, 3, 58, 1, 21, 6, 69, 7, 75, 2, 31, 8, 11, 
    1, 53, 6, 48, 8, 17, 4, 27, 2,  1, 5, 28, 7, 29, 0, 41, 3, 47, 
    6, 12, 8, 19, 7, 27, 0, 47, 3, 30, 2, 64, 5, 43, 1,  3, 4,  4, 
    8, 26, 3, 40, 4, 56, 0, 31, 1, 43, 5, 42, 6, 36, 7, 88, 2, 27, 
    3, 23, 1, 42, 7, 25, 0,  8, 8, 25, 2, 66, 5, 91, 6, 55, 4, 11, 
    8, 89, 6, 64, 3,  7, 4, 65, 1, 41, 7, 78, 2, 65, 5, 95, 0, 62, 
    4, 71, 6, 12, 0, 86, 3, 93, 5, 14, 2, 81, 1, 49, 8, 68, 7, 25, 
    3, 80, 0, 82, 1, 99, 4, 42, 6, 95, 7, 57, 5, 21, 2, 12, 8, 93, 
    4, 37, 3, 39, 1, 15, 8, 33, 7, 12, 0, 57, 5, 40, 2, 63, 6, 28
  };
  const int q5392[] = {
    9, 9, // Number of jobs and machines
    7, 54, 4, 57, 0, 47, 1, 90, 6, 53, 5, 20, 3, 29, 8, 30, 2,  3, 
    2, 90, 0, 49, 6, 46, 7, 97, 4, 15, 8, 87, 5, 22, 3,  7, 1, 33, 
    0, 43, 7,  2, 1, 45, 3, 40, 2, 57, 4, 27, 8, 83, 6, 81, 5, 93, 
    0, 53, 2, 71, 6, 83, 3, 83, 7, 20, 4, 61, 5, 43, 8,  8, 1, 30, 
    3, 14, 4, 39, 2, 40, 5, 14, 6, 14, 0,  1, 1, 74, 8, 49, 7, 48, 
    3, 47, 7, 32, 5, 77, 8, 83, 2, 83, 6, 77, 4, 41, 1, 55, 0, 19, 
    3, 57, 5, 71, 6, 88, 7, 33, 2, 22, 1, 72, 0, 60, 8, 44, 4, 39, 
    5, 13, 1, 21, 0, 48, 7, 93, 4, 72, 3, 81, 2,  2, 8,  5, 6, 79, 
    0, 42, 8,  6, 5, 52, 6, 94, 7, 98, 1, 59, 3, 99, 2, 76, 4,  6
  };
  const int q5393[] = {
    9, 9, // Number of jobs and machines
    2, 89, 6, 10, 7, 16, 5, 93, 0, 58, 1, 61, 8, 26, 3, 81, 4, 78, 
    3, 41, 1, 58, 4, 90, 7, 91, 2, 59, 5, 46, 6, 95, 8, 28, 0, 53, 
    3, 38, 4,  5, 0, 35, 5, 52, 8, 21, 7, 21, 6, 70, 1, 29, 2, 83, 
    0, 47, 6, 99, 2, 63, 8, 66, 1, 22, 3, 65, 5, 69, 7, 60, 4, 83, 
    1, 77, 4, 17, 5, 94, 2, 47, 8, 82, 6, 33, 7, 74, 0, 22, 3, 12, 
    7, 33, 3, 26, 8, 22, 2, 74, 4, 10, 5, 33, 6, 88, 1, 75, 0, 23, 
    4, 73, 7, 60, 8, 39, 0,  6, 3, 65, 2, 19, 5, 93, 6,  5, 1, 90, 
    8, 34, 5, 72, 7, 14, 6, 42, 3,  2, 0, 75, 4,  2, 1,  3, 2, 62, 
    0, 57, 8, 74, 1, 33, 3, 17, 6, 95, 7, 67, 4, 25, 5, 26, 2, 93
  };
  const int q5394[] = {
    9, 9, // Number of jobs and machines
    6, 59, 1, 97, 2,  7, 5, 59, 3, 52, 4,  9, 0, 46, 8, 25, 7,  3, 
    5, 11, 8, 38, 4, 45, 6, 22, 1, 24, 0, 20, 7, 91, 2, 78, 3, 49, 
    1,  1, 7, 14, 5, 42, 4, 35, 2, 47, 0, 17, 3, 47, 8, 57, 6, 74, 
    8, 83, 0, 71, 3, 99, 6, 87, 5, 48, 1, 70, 7, 62, 2, 75, 4, 49, 
    0,  5, 8, 42, 6, 18, 1, 20, 5, 82, 4,  4, 7, 77, 3, 16, 2,  3, 
    5, 34, 6, 24, 1, 80, 2, 63, 4, 83, 7,  7, 3, 61, 0, 67, 8, 11, 
    3, 79, 7, 12, 4, 71, 5, 72, 0, 52, 6, 21, 8, 67, 2, 84, 1, 93, 
    8,  5, 5, 97, 6, 86, 7,  4, 0, 44, 1, 73, 2, 82, 3, 14, 4, 33, 
    3, 16, 6, 75, 4,  1, 7, 40, 1, 69, 8, 67, 5, 89, 2, 69, 0, 10
  };
  const int q5395[] = {
    9, 9, // Number of jobs and machines
    4, 90, 3, 61, 7,  3, 2, 33, 1, 70, 8, 15, 5, 75, 6, 90, 0, 37, 
    5, 48, 0, 70, 4, 36, 2, 38, 6, 48, 3, 73, 7, 69, 1,  8, 8, 68, 
    1, 11, 2, 27, 4, 24, 8, 81, 0, 77, 5, 99, 7, 79, 6, 37, 3, 64, 
    4, 43, 6, 92, 8, 36, 7, 20, 3, 84, 1, 44, 2, 97, 0, 34, 5,  2, 
    0, 30, 5, 16, 4, 10, 3,  2, 6, 63, 8, 23, 2, 83, 1,  6, 7, 82, 
    8, 29, 5, 11, 0, 82, 7,  8, 4,  8, 1, 33, 6, 24, 2, 52, 3,  3, 
    7,  9, 4, 76, 2, 66, 8, 26, 0, 44, 5, 95, 6,  5, 1, 98, 3, 76, 
    0, 14, 3, 29, 1,  5, 2, 54, 6, 48, 8, 54, 4, 41, 7, 67, 5, 65, 
    6, 70, 8, 94, 2, 52, 7, 18, 3, 83, 5, 55, 4, 61, 1, 21, 0,  4
  };
  const int q5396[] = {
    9, 9, // Number of jobs and machines
    7, 79, 6, 87, 2, 95, 1, 59, 3, 81, 4, 13, 8, 69, 5, 83, 0, 10, 
    5, 36, 2, 16, 6, 27, 1, 80, 8, 17, 4,  5, 3, 97, 7,  3, 0,  6, 
    1, 26, 8, 51, 2, 37, 0, 25, 3,  7, 4, 54, 5, 56, 7, 23, 6, 48, 
    5, 50, 7, 60, 3, 46, 2, 75, 1,  1, 4, 68, 6, 13, 0, 36, 8, 85, 
    5, 94, 6, 21, 8, 49, 3, 51, 2, 41, 7, 96, 1, 84, 4, 97, 0, 11, 
    3, 73, 5, 77, 4, 92, 0,  8, 6,  2, 8, 12, 1, 68, 7, 55, 2, 46, 
    8, 90, 0,  2, 2, 77, 5, 22, 6, 82, 1, 51, 7, 64, 3, 95, 4, 84, 
    4, 22, 5, 45, 8, 86, 3, 40, 0,  9, 2, 33, 6, 18, 7, 37, 1, 94, 
    4, 52, 6, 40, 3, 51, 1, 90, 7, 27, 5,  9, 2, 15, 8, 33, 0, 27
  };
  const int q5397[] = {
    9, 9, // Number of jobs and machines
    8, 98, 6, 92, 2, 71, 1, 85, 5, 51, 7,  4, 3, 19, 4, 24, 0, 10, 
    5,  4, 8,  7, 6, 28, 2, 62, 0, 25, 1, 96, 7, 48, 3,  9, 4, 56, 
    8, 42, 0, 13, 2, 96, 6, 40, 1, 56, 4, 31, 5, 27, 3, 73, 7, 60, 
    1, 25, 0, 72, 5, 91, 3, 28, 8, 82, 7, 48, 6, 19, 4, 89, 2, 73, 
    2, 98, 3, 58, 6, 87, 5,  1, 7, 82, 8, 16, 1, 93, 0, 61, 4,  7, 
    0, 15, 6, 79, 8,  2, 4, 31, 7, 16, 5, 22, 2, 53, 1,  9, 3, 14, 
    8, 99, 1, 36, 5, 27, 7, 74, 4, 22, 6, 88, 0, 67, 2, 96, 3, 56, 
    5, 62, 8, 10, 7, 67, 0, 38, 1, 39, 6, 68, 3,  7, 4, 68, 2, 75, 
    2, 77, 8,  6, 7, 66, 0, 30, 3, 45, 6, 74, 1, 47, 5, 15, 4, 81
  };
  const int q5398[] = {
    9, 9, // Number of jobs and machines
    5, 41, 2, 82, 4,  5, 8, 67, 1, 71, 6, 16, 7,  6, 3, 17, 0, 75, 
    1,  5, 5, 54, 7, 42, 8, 40, 2, 10, 4, 94, 6, 88, 3, 81, 0, 64, 
    5,  8, 1, 25, 3, 90, 6,  4, 8, 54, 0, 23, 4,  1, 7, 32, 2, 40, 
    5, 70, 4, 93, 6, 55, 7, 59, 0, 43, 2, 99, 8, 48, 3, 98, 1, 61, 
    2, 60, 1, 69, 0, 51, 4,  2, 3, 14, 8, 87, 5,  8, 7, 28, 6, 31, 
    6, 58, 0, 65, 8, 43, 4, 82, 1, 57, 7, 67, 5, 99, 2, 73, 3, 97, 
    4,  8, 3, 96, 1, 84, 5, 81, 7, 64, 0, 32, 2, 75, 8, 50, 6, 45, 
    7, 72, 6, 94, 2, 42, 8, 26, 4, 12, 5, 94, 1,  1, 0, 87, 3, 82, 
    8,  1, 2, 57, 6, 89, 5, 65, 3, 26, 7, 90, 0,  6, 4, 93, 1, 47
  };
  const int q5399[] = {
    9, 9, // Number of jobs and machines
    4, 90, 2, 85, 7, 14, 3, 17, 6, 80, 0, 52, 1, 78, 8, 66, 5, 94, 
    1, 81, 6, 20, 3, 68, 7, 73, 0, 93, 2, 59, 4, 56, 8, 38, 5, 35, 
    0, 81, 5, 60, 3, 12, 1, 93, 8, 23, 6,  5, 7,  4, 2, 99, 4, 94, 
    1, 18, 0, 78, 5, 15, 8, 15, 7,  9, 2, 27, 3, 50, 4,  3, 6,  4, 
    8, 67, 6, 23, 0,  8, 7, 72, 2, 91, 1, 41, 5, 67, 3,  4, 4, 81, 
    7, 58, 1, 29, 4, 50, 0, 20, 5, 56, 6, 35, 8, 72, 3,  1, 2, 38, 
    5,  4, 1, 41, 8, 13, 6, 59, 3, 80, 0, 47, 2,  3, 4, 27, 7, 31, 
    2, 87, 0, 46, 1, 47, 6, 13, 4, 15, 5, 12, 3, 33, 7, 27, 8, 88, 
    2, 50, 7, 64, 5,  4, 8, 64, 4, 46, 0, 30, 3, 30, 6, 70, 1, 46
  };
  const int q5400[] = {
    9, 9, // Number of jobs and machines
    7, 24, 8, 15, 5, 13, 1,  1, 3, 77, 4, 41, 6, 10, 2, 20, 0, 53, 
    6, 79, 7, 18, 0, 97, 3,  7, 4, 44, 1, 66, 2, 27, 5,  5, 8, 53, 
    7,  4, 0, 74, 2, 79, 3,  5, 4, 42, 1, 59, 6,  1, 8, 20, 5, 85, 
    3, 82, 6, 67, 2, 79, 4, 51, 5, 51, 8, 32, 0, 99, 1,  3, 7, 38, 
    6, 74, 1, 66, 5, 28, 0, 58, 7, 51, 2, 22, 3, 17, 8, 98, 4, 37, 
    2, 86, 7, 26, 0,  7, 5, 76, 8, 66, 1, 53, 4, 42, 3, 66, 6, 42, 
    1, 56, 0, 91, 6, 27, 7, 36, 3, 57, 4, 46, 8, 55, 5, 85, 2, 14, 
    1, 56, 4, 70, 3, 33, 0, 59, 6, 15, 5, 98, 2, 79, 7, 47, 8, 37, 
    1, 32, 5, 10, 3, 86, 4, 70, 0,  9, 8, 78, 2, 78, 6, 70, 7, 60
  };
  const int q5401[] = {
    9, 9, // Number of jobs and machines
    2, 35, 5, 82, 7, 66, 0, 82, 6, 43, 4, 12, 1, 93, 8, 83, 3, 12, 
    2, 57, 3, 79, 6, 62, 7, 37, 0, 67, 8, 88, 1, 55, 5, 53, 4, 88, 
    2, 94, 7, 82, 1, 53, 4, 65, 0, 64, 5, 13, 8, 82, 6,  1, 3, 36, 
    8, 52, 5, 68, 4, 11, 1, 33, 7, 63, 2, 61, 0, 66, 3, 55, 6,  1, 
    8, 91, 4,  7, 0,  4, 2, 37, 3, 44, 7, 93, 5, 85, 1, 49, 6, 55, 
    2, 45, 5, 97, 8, 16, 1, 41, 3, 63, 6, 56, 7,  6, 0, 17, 4, 38, 
    3, 47, 5, 79, 4, 28, 1, 26, 8, 78, 6, 79, 0, 98, 2, 35, 7, 85, 
    0, 52, 4, 33, 1,  8, 5, 35, 2, 30, 8, 48, 3, 48, 7, 56, 6, 19, 
    5, 28, 3, 64, 0, 15, 6, 55, 4, 25, 8, 65, 1,  2, 2, 24, 7, 16
  };
  const int q5402[] = {
    9, 9, // Number of jobs and machines
    7, 89, 1, 66, 8, 81, 2, 84, 4, 56, 0, 22, 6, 31, 5, 47, 3, 90, 
    7, 52, 6, 41, 4, 89, 5, 31, 3,  9, 2, 25, 0, 64, 1, 53, 8, 93, 
    6, 13, 0,  2, 8, 18, 1, 10, 2, 32, 5, 98, 3,  3, 7, 44, 4, 65, 
    4, 22, 8, 46, 5, 95, 7, 54, 1, 88, 2, 86, 6,  4, 3, 66, 0, 11, 
    7,  6, 1, 10, 0, 36, 4, 58, 3, 13, 8, 67, 2, 71, 5, 69, 6, 67, 
    6, 31, 5, 86, 7, 72, 1, 27, 0, 88, 3, 73, 4, 26, 2, 18, 8, 94, 
    1, 16, 0, 87, 4, 90, 8, 72, 6, 50, 7, 17, 5,  5, 2,  1, 3, 75, 
    0, 11, 6, 97, 4, 64, 3, 26, 8, 62, 1,  7, 7, 64, 2, 77, 5, 46, 
    6,  7, 7, 81, 3, 99, 4, 69, 1, 34, 5,  5, 2, 78, 0, 43, 8, 95
  };
  const int q5403[] = {
    9, 9, // Number of jobs and machines
    3, 15, 5, 95, 4, 69, 7,  5, 1, 67, 8, 99, 2, 68, 0, 21, 6, 12, 
    8, 77, 5, 40, 6, 66, 4, 37, 0, 85, 7,  7, 3, 57, 1, 66, 2, 79, 
    6, 58, 5, 75, 8, 84, 7, 94, 4, 13, 2, 42, 0, 98, 1, 48, 3, 57, 
    2, 44, 8, 50, 4, 84, 1,  9, 3, 77, 0, 40, 6, 55, 7, 42, 5, 19, 
    5, 92, 6, 73, 8, 22, 4, 55, 1, 77, 7, 40, 3, 82, 0, 65, 2, 14, 
    6,  7, 1, 20, 4, 86, 8, 95, 0, 88, 2,  9, 5, 94, 3, 95, 7, 28, 
    6,  1, 2, 85, 0, 46, 3, 33, 1, 22, 8, 30, 5, 46, 4, 65, 7, 80, 
    3, 30, 1, 33, 5, 35, 8, 80, 2, 66, 0, 99, 6, 47, 4, 72, 7, 46, 
    6, 76, 0, 31, 5, 50, 7,  3, 2, 31, 3, 36, 1, 50, 4, 12, 8, 27
  };
  const int q5404[] = {
    9, 9, // Number of jobs and machines
    5, 86, 3, 52, 8, 34, 4, 93, 0, 51, 1, 14, 6, 81, 7, 34, 2, 70, 
    6, 46, 7, 49, 0, 31, 5, 61, 1, 87, 3,  6, 4, 56, 2, 73, 8, 16, 
    2, 88, 0, 65, 1, 61, 4, 22, 8, 21, 5, 80, 3,  8, 6, 89, 7, 66, 
    6, 28, 3, 55, 0, 89, 4, 17, 8, 25, 5, 22, 7,  6, 2, 60, 1, 33, 
    6, 30, 4, 14, 8, 22, 0, 40, 3, 90, 7, 50, 5, 84, 1, 28, 2, 11, 
    8, 32, 7, 15, 2,  4, 0, 39, 1, 19, 3, 88, 6, 27, 4, 12, 5, 99, 
    5, 31, 4, 12, 6, 82, 7, 60, 8, 93, 1, 93, 0, 75, 2,  8, 3,  4, 
    0, 64, 5, 41, 1,  9, 4, 41, 3, 64, 7, 64, 8, 86, 2, 96, 6, 51, 
    2, 37, 0, 92, 3, 38, 8, 72, 1, 20, 6, 39, 4, 56, 7, 91, 5, 68
  };
  const int q5405[] = {
    9, 9, // Number of jobs and machines
    6, 50, 1, 97, 0, 32, 8, 93, 2, 83, 7,  5, 3, 22, 4, 13, 5, 28, 
    1, 65, 5, 64, 6, 44, 2, 48, 8, 58, 0, 12, 4, 82, 3, 45, 7, 22, 
    6, 66, 1,  5, 5, 66, 4, 90, 7, 60, 0, 86, 2, 13, 8, 37, 3, 50, 
    7, 16, 3, 70, 2, 27, 0, 23, 5, 26, 8, 61, 4, 49, 1,  7, 6, 58, 
    1,  2, 6, 66, 5, 10, 0, 63, 3, 41, 4, 19, 7, 56, 8, 82, 2,  4, 
    2, 98, 6, 79, 5, 53, 4, 31, 1, 18, 0,  9, 8, 41, 3, 16, 7, 90, 
    2, 44, 8, 83, 6,  2, 7, 12, 4,  2, 5, 77, 3, 40, 0, 76, 1, 33, 
    8, 82, 7, 48, 4, 34, 5, 94, 6,  2, 0, 21, 2, 46, 3, 25, 1,  9, 
    1, 47, 6, 24, 2, 86, 5, 57, 7, 14, 0, 73, 4, 46, 3, 19, 8, 64
  };
  const int q5406[] = {
    9, 9, // Number of jobs and machines
    6, 99, 3, 45, 0,  8, 4,  4, 8, 16, 7, 40, 5, 48, 1, 71, 2, 21, 
    6, 28, 2, 59, 3, 63, 5, 31, 7,  6, 0, 53, 4, 20, 8, 30, 1, 45, 
    3, 32, 5, 79, 8, 31, 1, 80, 4, 36, 6, 48, 7, 30, 2, 83, 0, 31, 
    2, 75, 6, 10, 1, 87, 4,  8, 3,  6, 7, 29, 5, 93, 8, 65, 0, 22, 
    0, 32, 3, 91, 7, 83, 6, 68, 1, 24, 5, 52, 2, 17, 4, 73, 8, 98, 
    6, 85, 1, 25, 3, 87, 4, 14, 5, 57, 8, 54, 7, 60, 2, 54, 0,  1, 
    8, 24, 3, 56, 7, 11, 2, 88, 6, 99, 1, 82, 4, 94, 5, 41, 0,  8, 
    7, 72, 6, 92, 4, 57, 5, 28, 8, 98, 2, 16, 3, 88, 1, 80, 0, 71, 
    5, 10, 8, 24, 6, 60, 2, 17, 4, 19, 1, 95, 3, 54, 7, 47, 0, 87
  };
  const int q5407[] = {
    9, 9, // Number of jobs and machines
    6, 72, 5, 72, 1, 43, 7, 52, 2, 36, 4, 80, 8, 41, 0, 54, 3, 10, 
    7, 86, 2, 50, 8, 19, 4, 91, 6,  2, 5, 93, 1, 23, 3, 82, 0,  9, 
    5,  8, 7, 81, 0, 69, 8, 39, 1,  8, 6, 79, 3, 80, 4, 97, 2, 63, 
    6, 86, 5, 86, 0, 97, 1, 77, 2, 26, 7, 25, 8, 51, 4, 72, 3, 94, 
    7,  1, 3, 75, 6,  9, 4, 21, 1, 87, 2, 51, 0, 22, 5, 16, 8, 91, 
    4, 74, 3, 32, 5, 32, 1, 61, 8, 17, 7, 44, 2, 26, 6, 34, 0, 20, 
    6, 55, 5, 14, 3, 43, 4, 19, 0, 76, 1, 96, 8, 88, 7, 37, 2, 55, 
    3, 57, 0, 46, 1, 89, 7, 74, 8, 68, 4, 83, 6,  6, 5, 88, 2, 73, 
    5, 71, 1, 68, 0, 68, 8, 53, 4, 50, 3, 34, 2, 29, 6, 65, 7, 94
  };
  const int q5408[] = {
    9, 9, // Number of jobs and machines
    1, 39, 2, 92, 7, 92, 6, 88, 3, 46, 8, 64, 0, 44, 5, 99, 4, 12, 
    3, 49, 0, 64, 2, 57, 1, 55, 7, 26, 4, 69, 8, 12, 5, 88, 6, 85, 
    7, 82, 6, 94, 2, 84, 8, 12, 5, 15, 4, 14, 0,  9, 1, 47, 3, 52, 
    8, 20, 2, 19, 4, 82, 6, 30, 1,  4, 0, 87, 5, 64, 3, 96, 7, 39, 
    8, 82, 0, 91, 7,  7, 6, 26, 5, 84, 2, 35, 4, 57, 3, 33, 1, 99, 
    3, 81, 2, 52, 1, 60, 0, 24, 4, 82, 5,  5, 6, 49, 8, 60, 7, 37, 
    5, 42, 3, 77, 8, 26, 0, 90, 7, 74, 4, 46, 2, 74, 1, 37, 6, 49, 
    5, 64, 1, 40, 8, 30, 4, 16, 6, 30, 3, 17, 2, 52, 7, 80, 0, 25, 
    8, 75, 1, 69, 7, 64, 2, 76, 6, 12, 0, 14, 5, 45, 3, 95, 4, 96
  };
  const int q5409[] = {
    9, 9, // Number of jobs and machines
    2, 73, 5, 64, 8, 87, 3, 32, 6, 52, 0, 71, 1, 91, 7, 65, 4, 89, 
    7, 99, 4, 31, 8,  8, 0, 95, 5, 38, 1, 43, 3,  2, 2, 25, 6,  1, 
    3, 79, 7, 82, 4,  6, 5, 23, 6, 96, 0, 69, 8, 54, 2, 72, 1, 28, 
    6, 57, 2, 10, 7, 59, 4, 57, 0, 59, 3, 87, 5, 23, 8, 91, 1, 78, 
    3, 37, 6,  8, 4, 58, 5, 72, 0, 95, 7,  1, 8, 20, 2, 93, 1, 82, 
    8,  2, 5, 34, 6, 35, 1, 82, 2, 98, 3, 24, 7, 47, 0, 43, 4, 62, 
    2, 87, 5,  1, 7, 97, 0, 12, 4, 57, 6, 67, 1, 91, 8, 38, 3, 76, 
    7, 67, 4, 54, 1, 46, 6, 15, 0, 49, 8, 10, 3, 29, 2, 88, 5,  9, 
    2, 11, 0, 36, 7, 63, 6, 36, 3, 63, 5, 93, 1, 96, 8, 42, 4, 97
  };
  const int q5410[] = {
    9, 9, // Number of jobs and machines
    0, 33, 8, 60, 1, 57, 7, 27, 6, 53, 5, 71, 2, 91, 4, 20, 3, 56, 
    0, 26, 4, 43, 5, 39, 2, 76, 1, 74, 8, 80, 3, 94, 7,  2, 6, 53, 
    6, 26, 2, 76, 5, 74, 8, 90, 1, 66, 4, 46, 0, 19, 7,  3, 3, 68, 
    3, 72, 7, 90, 8, 83, 4,  7, 5, 16, 1, 79, 0, 86, 2, 94, 6, 22, 
    0, 61, 6, 78, 7, 55, 5, 89, 4, 92, 2, 68, 8, 25, 1,  3, 3, 68, 
    4, 67, 2, 37, 6, 14, 8, 23, 5,  8, 3, 11, 0, 29, 7, 53, 1, 14, 
    8, 16, 3, 71, 4, 18, 7, 89, 0, 54, 2, 24, 1, 32, 5,  6, 6, 62, 
    6, 54, 3, 63, 0, 95, 8, 85, 5, 21, 2, 85, 1, 73, 7, 89, 4,  9, 
    2, 77, 1, 91, 4,  6, 5, 12, 0, 94, 7, 89, 3, 33, 8, 13, 6, 38
  };
  const int q5411[] = {
    9, 9, // Number of jobs and machines
    5, 47, 8, 12, 1, 86, 4,  8, 7, 52, 6, 91, 0, 69, 3, 38, 2, 82, 
    1, 87, 7, 51, 6, 49, 3, 40, 5, 23, 2, 62, 0, 30, 4, 19, 8, 76, 
    4, 96, 0, 43, 2, 20, 5, 59, 6, 26, 1, 40, 7, 32, 3, 56, 8, 29, 
    1, 15, 6, 98, 5, 89, 2, 94, 3, 55, 0, 21, 8, 54, 4, 61, 7, 21, 
    4, 58, 0, 98, 1, 79, 2, 47, 8, 99, 6, 72, 7, 68, 3, 45, 5, 82, 
    7, 99, 1,  9, 5, 44, 2, 31, 6, 82, 3, 82, 0, 91, 8,  2, 4, 48, 
    2, 17, 7, 90, 1, 94, 0, 31, 6, 49, 4, 18, 3, 35, 5,  5, 8, 51, 
    5, 24, 3, 53, 0,  9, 1, 64, 4, 98, 6, 17, 7,  5, 2, 40, 8, 99, 
    8, 69, 0, 77, 4, 86, 2, 40, 5, 20, 7, 16, 3,  4, 6, 10, 1, 78
  };
  const int q5412[] = {
    9, 9, // Number of jobs and machines
    8, 20, 4, 26, 7,  6, 2, 70, 5, 41, 3, 89, 0, 57, 6, 20, 1,  4, 
    0, 71, 5, 81, 2, 38, 3, 67, 4, 13, 6, 18, 8, 63, 1, 49, 7, 19, 
    2, 60, 0, 37, 7, 44, 5,  7, 1, 87, 3, 35, 8, 93, 6, 99, 4, 53, 
    4, 10, 6, 28, 5, 54, 3, 24, 1, 32, 0, 70, 2, 89, 7, 78, 8, 67, 
    6, 56, 4, 74, 7, 54, 0, 50, 3, 50, 1, 18, 8, 64, 2, 40, 5, 13, 
    3, 66, 2, 15, 4, 27, 5, 90, 8,  5, 7, 40, 6, 18, 0, 12, 1, 75, 
    2, 14, 4, 93, 8, 54, 0, 48, 5, 63, 1, 69, 7, 31, 3, 90, 6,  3, 
    6, 17, 5, 17, 2, 71, 0, 44, 7,  5, 4, 94, 3,  3, 1, 12, 8, 29, 
    1, 90, 4,  2, 2, 51, 5, 21, 0, 44, 8, 26, 7, 69, 6, 95, 3, 77
  };
  const int q5413[] = {
    9, 9, // Number of jobs and machines
    4, 56, 6,  1, 0, 27, 1, 80, 5, 52, 2, 27, 8, 54, 3, 14, 7, 44, 
    6, 42, 4, 27, 0, 79, 2, 18, 5,  1, 7, 73, 3, 78, 1, 33, 8, 94, 
    7, 54, 0, 61, 8, 55, 3, 35, 2, 20, 1, 95, 4, 49, 5, 55, 6, 90, 
    5, 13, 4, 96, 6, 87, 8, 96, 0, 79, 3, 92, 7,  7, 2, 14, 1, 96, 
    5, 25, 2, 20, 6, 69, 1, 50, 7, 27, 8, 55, 0, 70, 4, 96, 3, 61, 
    8, 93, 7, 32, 1, 41, 3, 20, 6, 98, 4, 91, 2,  2, 0, 54, 5, 74, 
    3, 48, 7, 34, 4, 90, 2, 28, 6, 96, 8, 25, 0, 27, 5, 77, 1, 56, 
    3, 14, 7, 54, 4, 95, 8, 58, 5, 92, 2, 66, 0, 79, 6, 83, 1, 32, 
    3, 21, 2, 98, 7, 11, 6, 52, 1, 99, 0, 28, 5, 86, 8, 72, 4, 35
  };
  const int q5414[] = {
    9, 9, // Number of jobs and machines
    0, 19, 4, 46, 7, 75, 5, 83, 3, 26, 1, 71, 8, 78, 6, 52, 2, 70, 
    1,  5, 7, 23, 4, 34, 0, 24, 2, 23, 5,  7, 3, 66, 8, 16, 6, 69, 
    4,  3, 5,  8, 1, 39, 2, 81, 8, 86, 3, 84, 0, 46, 7, 99, 6,  4, 
    1, 70, 8, 40, 0, 70, 6, 30, 4, 38, 3, 78, 7, 71, 5, 17, 2, 58, 
    8, 12, 2,  3, 0, 66, 1, 32, 3, 59, 6, 82, 7,  4, 5, 10, 4, 36, 
    1, 12, 4, 40, 7, 89, 2, 19, 3, 19, 6, 18, 5, 57, 8, 33, 0, 68, 
    7, 43, 6, 30, 2, 81, 5, 74, 0, 30, 1,  5, 3,  1, 8, 86, 4, 61, 
    1, 35, 6, 88, 2, 44, 3, 78, 0, 37, 7, 99, 8, 26, 5,  6, 4, 55, 
    6, 37, 4, 46, 1, 29, 5, 67, 8, 77, 7, 41, 3, 74, 2, 33, 0, 93
  };
  const int q5415[] = {
    9, 9, // Number of jobs and machines
    0, 29, 1, 25, 8, 11, 5, 53, 6,  8, 2, 80, 4, 12, 3, 18, 7, 15, 
    2, 24, 7, 70, 6, 14, 8, 22, 5, 98, 3, 23, 4,  7, 0, 86, 1, 49, 
    7,  4, 3, 82, 6,  3, 8, 56, 2, 78, 0, 38, 5, 96, 4, 64, 1, 57, 
    5,  1, 8, 20, 1, 15, 0, 98, 3,  4, 4, 28, 7,  1, 2, 17, 6,  5, 
    0, 21, 7, 69, 4, 69, 1, 91, 6,  5, 5, 97, 3, 96, 2, 42, 8, 25, 
    4, 27, 1, 72, 7, 59, 2, 22, 0, 98, 8, 64, 3, 13, 5, 71, 6, 88, 
    0, 18, 2, 83, 6, 14, 4, 41, 3, 34, 8, 32, 7, 84, 1, 96, 5, 72, 
    2, 58, 3, 29, 7, 20, 5,  9, 4,  9, 8,  9, 0,  9, 1, 16, 6, 84, 
    3, 33, 4, 45, 8, 40, 2, 65, 5, 80, 7, 38, 6, 18, 0, 28, 1, 52
  };
  const int q5416[] = {
    9, 9, // Number of jobs and machines
    3, 51, 5, 32, 2, 32, 1, 67, 0, 68, 6, 20, 4, 41, 7, 43, 8, 92, 
    1, 82, 0, 17, 6, 14, 3, 39, 5, 92, 4, 83, 8, 32, 7, 59, 2, 54, 
    5, 49, 7, 35, 4, 33, 3, 66, 6, 73, 8, 58, 1, 29, 0, 26, 2, 85, 
    5, 56, 3, 45, 2, 80, 0, 26, 1, 44, 7, 19, 8, 89, 6, 31, 4, 90, 
    8, 32, 6, 21, 0, 71, 3, 52, 5, 74, 4, 37, 2, 77, 7, 28, 1, 90, 
    8, 84, 5, 89, 4, 18, 0, 71, 1, 82, 6, 40, 3, 32, 2, 14, 7, 65, 
    8, 89, 1, 14, 5, 76, 4, 66, 3, 16, 7, 86, 2, 87, 0, 16, 6, 31, 
    3, 89, 7, 64, 2, 88, 0, 17, 8, 69, 6, 52, 4, 26, 5, 94, 1, 51, 
    2, 91, 4, 47, 1, 48, 8, 65, 6, 76, 5, 88, 3, 96, 7, 93, 0, 28
  };
  const int q5417[] = {
    9, 9, // Number of jobs and machines
    3, 62, 2, 47, 4, 84, 0,  7, 5, 43, 1, 65, 8, 21, 7, 10, 6, 68, 
    5, 67, 3, 67, 7, 66, 8, 48, 0,  1, 4, 12, 2, 29, 6, 49, 1, 27, 
    3, 31, 8, 20, 2, 95, 4, 89, 6, 28, 0,  3, 1, 24, 5, 75, 7, 61, 
    3, 37, 0, 99, 4, 25, 5, 73, 1, 31, 2, 28, 6, 71, 8, 96, 7, 52, 
    4, 96, 1, 55, 7, 13, 5,  1, 2, 53, 0, 38, 6, 17, 3, 26, 8, 50, 
    0, 68, 8, 94, 1, 96, 7, 65, 3, 59, 4, 14, 2, 30, 5, 87, 6, 43, 
    1, 26, 0, 78, 3, 25, 7, 88, 8, 82, 4, 82, 2, 74, 6, 71, 5, 58, 
    4, 80, 1, 84, 8, 74, 2, 58, 6,  7, 5, 14, 3, 23, 7, 10, 0, 14, 
    8, 43, 4, 70, 1,  9, 5, 68, 2, 32, 6, 73, 7, 91, 3, 67, 0, 36
  };
  const int q5418[] = {
    9, 9, // Number of jobs and machines
    1, 20, 5,  8, 0,  9, 7, 94, 6, 83, 8, 49, 3, 12, 2, 83, 4, 22, 
    1, 44, 4, 36, 6, 50, 7, 55, 0, 88, 3, 50, 5, 54, 8, 75, 2, 64, 
    0, 62, 7, 54, 3, 27, 6, 15, 8, 92, 1, 26, 5, 69, 4, 27, 2, 56, 
    7, 64, 5, 57, 0, 79, 1, 76, 6, 12, 3, 90, 4, 68, 8, 36, 2, 90, 
    5, 21, 3, 82, 8, 76, 1, 81, 4, 70, 2, 49, 6, 18, 7, 20, 0,  9, 
    6, 32, 1, 65, 0, 73, 3, 98, 8, 53, 5, 39, 7, 81, 4, 38, 2, 31, 
    3, 78, 6, 77, 5, 75, 7, 14, 0, 30, 1, 66, 4,  5, 8, 42, 2, 42, 
    4, 86, 2, 61, 7, 30, 1, 99, 6, 19, 0, 26, 5, 96, 8,  5, 3, 72, 
    7, 62, 4, 57, 5, 11, 3,  6, 0, 40, 6, 11, 1, 63, 8, 16, 2, 98
  };
  const int q5419[] = {
    9, 9, // Number of jobs and machines
    1, 49, 7, 44, 5,  2, 3, 49, 0, 97, 2, 93, 6, 28, 8, 54, 4, 82, 
    5, 70, 3, 50, 2,  6, 8, 29, 0, 90, 4, 50, 6, 45, 7, 76, 1,  8, 
    1, 51, 2, 22, 8,  1, 6, 59, 4, 40, 7, 84, 0, 11, 5, 37, 3, 16, 
    5, 64, 0, 61, 1, 24, 3, 58, 7, 76, 4, 21, 6, 97, 2, 22, 8, 73, 
    8, 71, 5, 87, 7, 17, 2, 16, 6, 82, 0, 19, 4, 10, 1, 42, 3, 98, 
    5, 72, 3, 42, 4, 38, 2, 80, 0, 94, 1,  5, 8,  5, 6, 45, 7, 65, 
    7, 74, 2, 42, 5, 90, 3, 82, 1,  9, 0, 14, 8, 23, 6, 49, 4, 36, 
    2, 27, 8, 41, 0,  9, 4,  8, 5,  9, 7, 75, 1, 81, 6, 17, 3,  5, 
    2, 59, 5, 58, 0, 97, 7, 54, 3, 90, 8, 81, 4, 68, 6, 67, 1, 74
  };
  const int q5420[] = {
    9, 9, // Number of jobs and machines
    8, 71, 2, 61, 1, 98, 4, 14, 7,  9, 3, 31, 5, 32, 0, 47, 6, 41, 
    3, 93, 6, 31, 7, 36, 8, 73, 4, 34, 5,  4, 2, 68, 0, 20, 1, 94, 
    6, 67, 2, 20, 1, 56, 7,  9, 0, 23, 4,  6, 3, 17, 8, 31, 5, 36, 
    4, 52, 8, 60, 1, 28, 0, 96, 3,  5, 6, 36, 5, 98, 2, 68, 7, 39, 
    1, 36, 7, 12, 8, 45, 4, 55, 2, 94, 0, 68, 3, 48, 6, 99, 5, 51, 
    2, 65, 1, 56, 8, 95, 7, 52, 4,  5, 3, 78, 0, 63, 5, 48, 6, 53, 
    3, 59, 7, 55, 8, 68, 5, 89, 1, 95, 4, 12, 2, 57, 0, 32, 6, 59, 
    6, 29, 8, 43, 5, 60, 4, 34, 3, 74, 0, 78, 2,  9, 7, 63, 1, 19, 
    4, 41, 5, 28, 3, 73, 0, 99, 1, 36, 2, 98, 7, 81, 6, 92, 8, 42
  };
  const int q5421[] = {
    9, 9, // Number of jobs and machines
    6, 11, 0, 81, 4, 47, 8, 16, 7, 92, 3, 20, 5, 35, 2, 70, 1, 46, 
    6, 77, 4, 67, 1, 24, 2, 59, 8, 50, 5, 42, 0, 15, 7, 85, 3, 64, 
    7, 65, 3, 95, 2, 44, 0, 96, 6, 89, 5, 73, 4, 98, 1, 97, 8, 88, 
    6, 18, 1, 67, 4, 16, 5, 42, 2, 58, 0, 52, 7, 21, 3, 18, 8, 55, 
    3, 94, 5, 29, 0, 72, 4, 34, 6, 47, 1,  1, 2, 16, 7, 83, 8, 53, 
    1, 25, 7, 47, 6, 22, 4, 77, 2, 59, 8, 39, 3,  1, 5, 71, 0, 40, 
    1, 86, 5, 20, 6, 63, 3, 73, 7, 17, 4, 64, 8, 96, 2, 36, 0, 69, 
    2, 19, 5, 92, 0, 38, 8, 74, 6, 88, 1, 69, 3, 60, 7, 84, 4, 21, 
    4,  8, 7, 48, 5, 39, 3, 50, 6, 85, 8, 19, 1, 16, 0, 33, 2, 43
  };
  const int q5422[] = {
    9, 9, // Number of jobs and machines
    6, 60, 2, 33, 7, 49, 3, 55, 0, 24, 5, 71, 1, 13, 4,  1, 8, 33, 
    7, 25, 2, 83, 6, 42, 3, 44, 1, 41, 0, 62, 4, 85, 5, 59, 8, 71, 
    2, 29, 8, 35, 4, 21, 0, 61, 7, 70, 1, 70, 5, 29, 3, 57, 6, 21, 
    6, 22, 5, 23, 7, 33, 3, 18, 0, 40, 8, 77, 4, 77, 1, 73, 2, 78, 
    1, 79, 7,  4, 8, 67, 5, 74, 2, 89, 3, 96, 6, 44, 0, 36, 4, 44, 
    1, 52, 4, 97, 0, 39, 3, 61, 5, 83, 7, 31, 2, 83, 8, 70, 6,  5, 
    3, 71, 8, 54, 2, 32, 6, 12, 4, 72, 0, 25, 5,  8, 1,  5, 7, 11, 
    6, 46, 2, 99, 1, 45, 0, 66, 8, 47, 4, 66, 5, 28, 3, 92, 7, 12, 
    6, 34, 2, 90, 3, 96, 7, 19, 8, 42, 5, 98, 1, 96, 0, 21, 4, 73
  };
  const int q5423[] = {
    9, 9, // Number of jobs and machines
    1, 18, 2, 70, 6, 57, 5, 13, 4, 18, 8, 48, 7, 65, 3, 71, 0, 22, 
    7, 97, 0, 54, 8, 36, 6, 45, 3, 83, 1, 94, 4,  7, 5, 80, 2, 61, 
    5, 23, 8, 93, 6, 71, 4,  1, 7, 10, 2,  4, 0, 39, 1, 29, 3, 79, 
    2, 32, 4, 24, 0, 49, 5, 39, 6, 97, 8, 33, 1, 49, 7, 18, 3, 36, 
    0, 85, 1, 30, 3, 21, 2, 85, 4, 86, 8, 96, 7, 47, 6, 39, 5, 36, 
    2, 90, 6, 91, 5, 73, 8, 10, 1, 29, 0, 44, 3, 18, 4, 83, 7, 27, 
    6, 64, 2, 29, 1,  7, 3, 31, 4, 70, 0,  7, 7, 88, 8, 14, 5, 75, 
    7, 78, 1, 48, 4, 66, 0, 64, 3, 20, 6, 41, 8,  3, 5, 50, 2, 31, 
    1, 88, 8, 19, 4, 16, 0,  4, 6, 69, 5, 97, 2, 71, 7, 89, 3, 93
  };
  const int q5424[] = {
    9, 9, // Number of jobs and machines
    3, 17, 6, 65, 2, 17, 0,  3, 4, 87, 8, 88, 1, 19, 5, 68, 7, 28, 
    1, 29, 4, 72, 5, 34, 2, 98, 0, 92, 8, 68, 3, 33, 6,  6, 7, 74, 
    8, 26, 0, 93, 6, 26, 4, 83, 2, 47, 7, 50, 5, 30, 3, 97, 1, 49, 
    0, 11, 6, 28, 8, 52, 5, 70, 3, 71, 1, 88, 7, 53, 2, 36, 4, 49, 
    1, 30, 0, 12, 3, 59, 7,  9, 5, 97, 4,  6, 8, 49, 2,  9, 6,  7, 
    6, 87, 0, 90, 5, 26, 7, 67, 2, 46, 1, 78, 4, 16, 3, 77, 8, 10, 
    1, 52, 5, 17, 0, 66, 6, 14, 7, 12, 4, 34, 3,  3, 2, 46, 8, 52, 
    4, 26, 8, 90, 2, 83, 5,  7, 1, 94, 6, 68, 3, 10, 7, 47, 0, 29, 
    1, 91, 7, 42, 6, 87, 0, 12, 2, 33, 5, 85, 4, 65, 8, 16, 3, 79
  };
  const int q5425[] = {
    9, 9, // Number of jobs and machines
    1,  2, 6, 48, 3, 52, 0, 16, 4, 38, 7, 18, 8, 84, 5, 96, 2, 51, 
    0, 18, 3, 20, 7, 40, 4, 80, 2, 46, 1, 37, 5, 40, 8, 40, 6, 44, 
    8, 79, 0, 39, 4, 43, 1, 68, 3, 96, 5, 54, 6, 72, 2, 94, 7, 60, 
    0, 29, 6, 51, 7, 57, 4, 67, 3,  5, 8, 90, 1, 32, 2, 21, 5, 53, 
    0, 53, 7, 87, 3, 43, 4, 89, 1, 11, 8, 90, 6, 22, 2, 32, 5, 53, 
    1, 99, 7, 11, 4,  8, 2, 88, 3, 30, 0, 28, 6, 33, 8, 55, 5, 87, 
    2, 17, 0, 66, 8,  1, 4, 22, 1, 96, 3, 89, 5, 98, 6, 67, 7,  5, 
    5, 69, 1,  2, 4, 24, 7, 44, 6, 85, 2, 69, 8, 83, 0, 21, 3, 74, 
    5, 39, 2, 76, 0, 95, 8, 87, 4, 94, 6, 71, 1, 14, 3, 56, 7, 46
  };
  const int q5426[] = {
    9, 9, // Number of jobs and machines
    5,  7, 6, 12, 3, 96, 1, 42, 4, 34, 8, 65, 7, 11, 2, 95, 0, 72, 
    3, 23, 1, 41, 2,  3, 7, 12, 6, 23, 8, 89, 4, 54, 5,  3, 0, 52, 
    2, 63, 1, 88, 3, 20, 6, 71, 8, 50, 0, 21, 4, 61, 7, 46, 5, 37, 
    3, 29, 1, 26, 8, 60, 7, 55, 0, 79, 4,  5, 6, 72, 2, 54, 5, 62, 
    0, 24, 4, 84, 6, 27, 1, 53, 7, 32, 8, 52, 5,  4, 2, 48, 3,  2, 
    8, 94, 7,  4, 1, 85, 4, 50, 2, 49, 5, 74, 0, 27, 6,  5, 3, 24, 
    3, 81, 1, 52, 5, 52, 4, 45, 7,  1, 0,  6, 8, 22, 6, 63, 2, 41, 
    6,  2, 0, 25, 5, 71, 8, 71, 2, 63, 4, 22, 7, 31, 1, 93, 3, 47, 
    7, 83, 4, 96, 6, 61, 5, 83, 0,  5, 2,  9, 1, 14, 8, 35, 3, 79
  };
  const int q5427[] = {
    9, 9, // Number of jobs and machines
    3, 63, 6, 56, 8, 28, 7,  9, 1, 35, 2, 80, 0, 34, 4, 88, 5, 89, 
    2, 26, 3, 48, 7, 36, 4, 91, 1, 30, 8, 54, 5, 65, 0, 79, 6, 92, 
    1, 26, 3, 34, 8, 45, 5, 36, 6,  5, 7, 11, 4,  5, 0, 63, 2, 83, 
    8, 46, 2, 94, 5,  7, 0, 56, 6, 99, 4, 20, 1, 87, 7, 95, 3, 68, 
    0, 31, 3, 29, 1, 38, 5, 71, 8, 74, 6, 43, 2, 93, 7, 49, 4, 94, 
    5, 94, 8, 68, 3, 48, 6, 44, 2, 23, 7, 96, 4, 35, 0, 88, 1, 27, 
    6, 44, 4, 93, 7, 23, 2, 52, 1, 97, 5, 34, 3, 45, 8, 23, 0, 71, 
    5, 56, 0, 34, 2, 79, 6, 83, 3, 87, 7,  3, 1, 10, 4, 24, 8, 19, 
    6, 22, 3, 17, 5, 28, 2, 31, 8, 70, 7, 19, 1, 11, 4, 53, 0, 97
  };
  const int q5428[] = {
    9, 9, // Number of jobs and machines
    1, 84, 7, 58, 6, 49, 8,  7, 5, 75, 3, 80, 2, 95, 0, 38, 4,  7, 
    8,  8, 3, 39, 1, 89, 2, 77, 6, 58, 5, 30, 7, 22, 0, 73, 4, 52, 
    3, 42, 4, 33, 2, 55, 0, 25, 5,  1, 1, 81, 8, 56, 6, 91, 7, 79, 
    7,  9, 8, 17, 6,  3, 1, 57, 5, 57, 2, 11, 0, 29, 3, 71, 4, 54, 
    0, 99, 4, 22, 2, 29, 1, 96, 6, 43, 7, 35, 3, 32, 8, 82, 5, 94, 
    2, 96, 8, 27, 3, 47, 0, 83, 7, 23, 1, 42, 5, 85, 4, 64, 6, 58, 
    7, 30, 6, 67, 2, 59, 4, 28, 0, 80, 1, 43, 5, 31, 8, 23, 3, 46, 
    0, 20, 3, 95, 7, 35, 1,  6, 8, 75, 6,  6, 2, 16, 5, 64, 4, 54, 
    1,  1, 0, 85, 6, 11, 3, 61, 2, 69, 5,  5, 4, 71, 8,  9, 7, 26
  };
  const int q5429[] = {
    9, 9, // Number of jobs and machines
    2, 53, 3, 49, 1, 82, 7, 33, 5, 87, 4, 29, 0, 71, 6, 25, 8, 48, 
    4, 16, 8, 86, 0, 45, 2, 72, 5, 27, 7, 47, 1, 90, 3, 34, 6, 13, 
    0, 25, 3, 56, 4, 86, 1, 56, 7, 72, 2, 92, 5, 87, 8, 73, 6,  7, 
    1, 42, 2, 32, 5, 55, 8, 17, 4, 89, 6, 69, 7, 19, 3, 28, 0, 81, 
    6, 14, 0, 80, 1,  1, 3, 31, 2,  9, 8, 99, 7, 10, 4, 85, 5, 42, 
    7, 53, 5, 86, 1, 76, 6, 67, 4, 22, 2, 74, 3, 45, 0, 14, 8, 75, 
    8, 60, 2, 29, 7, 67, 4, 18, 3, 94, 0,  3, 5, 75, 6, 28, 1, 97, 
    8, 56, 7, 13, 3, 87, 5,  6, 6, 18, 1, 71, 2, 12, 4, 75, 0, 18, 
    0, 69, 1, 64, 4, 19, 3, 37, 8, 40, 2, 30, 6, 78, 7, 62, 5, 92
  };
  const int q5430[] = {
    9, 9, // Number of jobs and machines
    8, 71, 1, 19, 2, 96, 7, 12, 3, 67, 5, 90, 0,  8, 6, 64, 4, 27, 
    8, 71, 0, 45, 3, 52, 7, 26, 1,  7, 6, 91, 5, 57, 4, 96, 2, 94, 
    1, 19, 8, 71, 6, 19, 4, 46, 0, 41, 2, 11, 7, 45, 5, 53, 3, 66, 
    4, 86, 8, 55, 7, 11, 3, 34, 6, 15, 0, 48, 2, 62, 1, 56, 5, 86, 
    1, 44, 2, 91, 3, 50, 6, 74, 4, 43, 0, 78, 7, 51, 5, 59, 8, 57, 
    0, 49, 5, 73, 8,  3, 3, 58, 4, 39, 6, 53, 1, 80, 7, 47, 2, 23, 
    8, 50, 3, 59, 0, 11, 4, 97, 5, 60, 2, 37, 1, 65, 7, 71, 6, 84, 
    0, 49, 1, 56, 6, 72, 3, 48, 5, 93, 7, 93, 4, 38, 2, 36, 8, 20, 
    3, 54, 7, 83, 6, 90, 1, 90, 8, 62, 5, 33, 4, 40, 0, 33, 2, 14
  };
  const int q5431[] = {
    9, 9, // Number of jobs and machines
    0, 90, 2,  1, 7, 48, 4, 27, 5, 49, 3, 66, 8, 36, 1, 47, 6,  3, 
    7, 90, 8, 19, 1, 16, 3, 24, 2,  1, 5, 31, 4, 24, 6, 79, 0,  2, 
    1, 82, 0, 80, 4, 57, 7, 80, 2, 56, 3, 78, 6, 36, 5, 43, 8, 53, 
    1, 34, 0, 18, 7, 62, 6, 33, 5, 93, 4, 94, 2, 53, 3, 34, 8, 96, 
    2, 22, 0, 25, 6, 34, 3,  8, 8, 24, 1, 51, 7, 30, 4, 16, 5, 55, 
    2, 21, 8, 24, 4, 26, 7, 85, 0, 85, 5, 70, 1, 67, 6, 88, 3, 38, 
    2, 14, 5, 90, 4, 36, 6, 65, 1, 78, 7, 52, 8, 10, 3, 99, 0, 78, 
    8,  6, 3, 32, 7, 45, 5, 23, 6, 17, 1, 73, 4, 63, 0, 39, 2,  3, 
    2, 42, 7, 48, 5, 61, 0, 94, 6, 81, 3, 15, 8, 84, 4, 50, 1, 29
  };
  const int q5432[] = {
    9, 9, // Number of jobs and machines
    7, 93, 1, 23, 5, 96, 4, 33, 3, 76, 8,  5, 0, 32, 6, 73, 2, 56, 
    2, 92, 5, 93, 8, 45, 0, 81, 6, 62, 4, 53, 7, 19, 3, 58, 1, 48, 
    4, 42, 5, 52, 0, 62, 1, 46, 8, 58, 7, 19, 6, 65, 3, 37, 2, 83, 
    6, 39, 0, 26, 4, 20, 3, 59, 8,  5, 1, 10, 7, 95, 2,  3, 5, 88, 
    0, 47, 5, 91, 7, 22, 6, 82, 1, 33, 3, 20, 8, 58, 2, 56, 4, 28, 
    8,  5, 1, 88, 5, 88, 4, 88, 7, 60, 3, 89, 2, 38, 0, 77, 6, 27, 
    1, 94, 7, 23, 3, 77, 0, 11, 4, 96, 2, 27, 6, 73, 5, 17, 8, 94, 
    8, 97, 0, 61, 2, 10, 4, 79, 6, 33, 3, 97, 7, 12, 5, 16, 1, 10, 
    5, 66, 1,  5, 0,  8, 8, 53, 6, 35, 7, 46, 4,  2, 2,  4, 3, 35
  };
  const int q5433[] = {
    9, 9, // Number of jobs and machines
    5,  3, 0, 95, 6, 73, 4, 39, 1, 43, 7, 77, 3,  7, 2, 33, 8, 14, 
    4, 82, 2, 57, 1, 79, 8, 33, 6, 21, 0, 21, 3, 45, 5, 35, 7, 76, 
    2, 54, 4, 78, 0, 13, 3, 38, 7,  3, 8, 86, 5, 36, 6, 39, 1, 80, 
    8, 26, 5, 52, 4, 88, 7, 72, 1, 54, 0, 14, 3, 48, 2, 88, 6, 80, 
    2, 34, 8, 42, 5, 79, 7, 22, 6, 57, 0, 44, 1,  6, 3, 22, 4, 93, 
    4, 70, 5,  6, 6, 51, 8, 76, 2, 92, 7, 14, 1, 93, 3, 39, 0, 73, 
    8, 52, 6, 23, 1, 10, 7, 33, 3, 52, 0, 17, 2, 57, 5, 74, 4, 35, 
    2, 65, 5, 15, 1,  2, 0, 36, 3, 65, 7, 21, 4, 38, 6, 71, 8, 87, 
    7, 19, 0,  8, 1, 46, 3, 82, 6, 87, 5, 50, 8,  6, 4, 99, 2, 19
  };
  const int q5434[] = {
    9, 9, // Number of jobs and machines
    7, 61, 6, 31, 3, 60, 1, 88, 2, 76, 5,  3, 4, 20, 0, 99, 8, 10, 
    4, 73, 1,  4, 7, 10, 3, 88, 6, 34, 8, 80, 5, 44, 0, 51, 2, 13, 
    7, 65, 5, 27, 2, 84, 6, 11, 1, 61, 4, 11, 8, 86, 0, 22, 3, 64, 
    1,  3, 2,  1, 6, 44, 0, 51, 3, 10, 7, 21, 5, 27, 4,  4, 8, 33, 
    7, 38, 8, 11, 4, 46, 5, 93, 3, 77, 1, 55, 6, 71, 2, 47, 0, 24, 
    0, 13, 5, 81, 2, 21, 7, 58, 4, 75, 6, 16, 8, 89, 3, 33, 1, 97, 
    4, 65, 5, 73, 3, 57, 6, 88, 7, 94, 0, 60, 1, 66, 8,  9, 2, 39, 
    2, 79, 5,  6, 7, 90, 4, 43, 6, 90, 0, 41, 8,  1, 1, 33, 3, 29, 
    3, 96, 1, 97, 4, 75, 7, 67, 6, 10, 0, 86, 8, 76, 5, 49, 2, 39
  };
  const int q5435[] = {
    9, 9, // Number of jobs and machines
    8, 28, 2, 19, 0, 95, 5, 16, 3, 97, 7, 41, 6, 56, 4, 93, 1, 71, 
    3, 95, 4,  9, 0, 45, 7, 63, 6, 56, 8, 23, 5, 90, 2, 66, 1, 29, 
    2, 77, 3, 60, 4, 35, 1, 79, 7, 83, 5, 83, 0, 51, 8, 37, 6, 49, 
    6, 89, 8, 27, 7, 59, 2, 46, 5, 77, 3, 79, 4, 39, 1, 23, 0, 12, 
    2, 32, 5, 40, 6, 27, 7, 99, 1, 98, 0, 44, 4, 22, 8, 93, 3, 71, 
    6, 37, 3, 75, 7, 66, 4, 31, 0, 87, 2, 59, 1, 98, 5, 46, 8,  8, 
    2, 74, 8, 92, 7, 71, 1, 72, 4, 63, 0, 97, 3, 42, 5, 45, 6, 89, 
    2, 36, 7, 92, 3, 63, 4, 76, 5, 63, 8, 51, 1, 38, 0, 14, 6, 97, 
    1, 35, 4,  4, 0, 29, 6, 25, 3, 80, 7, 18, 8, 91, 2, 34, 5, 72
  };
  const int q5436[] = {
    9, 9, // Number of jobs and machines
    8, 64, 6, 10, 3, 59, 4, 30, 7, 42, 0,  4, 2, 19, 5, 99, 1, 80, 
    0, 62, 1, 81, 5,  6, 8, 92, 2, 28, 7, 74, 4, 65, 6, 67, 3, 56, 
    7, 37, 2, 50, 4, 37, 3, 60, 8, 28, 0, 83, 5, 46, 6, 32, 1, 33, 
    8, 16, 6, 22, 4,  9, 1, 23, 3, 65, 0, 70, 2,  7, 7, 79, 5, 50, 
    1, 19, 0, 18, 4, 97, 7, 24, 3,  6, 8, 66, 5, 44, 2, 72, 6, 39, 
    1,  1, 3, 23, 7, 48, 4, 57, 2, 43, 5, 72, 0, 75, 6, 78, 8, 43, 
    8, 59, 3,  1, 1, 17, 6, 41, 5, 38, 2,  7, 0, 20, 7, 61, 4, 18, 
    4, 64, 8, 93, 2, 78, 5, 99, 6, 46, 0,  5, 7, 24, 3,  3, 1,  4, 
    5, 82, 8,  2, 1, 13, 0, 52, 2, 27, 3, 83, 4, 91, 6, 84, 7, 63
  };
  const int q5437[] = {
    9, 9, // Number of jobs and machines
    6, 67, 0, 64, 4, 94, 1, 18, 3, 73, 5,  5, 8, 79, 7, 26, 2,  8, 
    8, 18, 1, 93, 5, 24, 4, 67, 0, 43, 3, 40, 7, 37, 2, 60, 6, 25, 
    8, 86, 4, 76, 3, 70, 5, 31, 7, 85, 0, 89, 1, 31, 6, 30, 2, 62, 
    2, 16, 1, 12, 3, 75, 5, 82, 0, 82, 8, 35, 7, 72, 4,  5, 6, 93, 
    7, 11, 1, 22, 2, 51, 3, 19, 4, 54, 0, 52, 6, 27, 5, 39, 8, 79, 
    3, 64, 4, 60, 2, 42, 7, 46, 0,  3, 6, 12, 8, 71, 5, 14, 1, 25, 
    8, 55, 0, 16, 2, 17, 5, 20, 6, 10, 1, 20, 3, 83, 4, 66, 7, 80, 
    6, 11, 7, 36, 8, 30, 3, 75, 0, 60, 4, 54, 1, 31, 2, 50, 5,  6, 
    0, 96, 2, 46, 6, 22, 5, 38, 1, 17, 8, 50, 7, 74, 4, 59, 3, 56
  };
  const int q5438[] = {
    9, 9, // Number of jobs and machines
    0, 59, 2, 20, 7, 13, 8, 36, 1, 28, 5, 32, 3, 79, 6, 68, 4, 25, 
    6, 54, 2, 88, 3, 75, 0, 67, 8, 41, 5, 15, 7, 23, 1, 85, 4, 39, 
    3, 68, 4, 24, 5, 23, 1, 53, 7, 10, 0, 44, 2, 56, 6, 91, 8, 79, 
    5, 16, 0, 41, 1, 19, 4, 91, 6, 50, 7, 47, 8, 42, 3, 20, 2,  2, 
    0, 16, 7, 80, 8, 67, 2, 14, 6, 62, 5, 14, 1, 49, 4, 67, 3,  6, 
    2, 55, 7,  3, 6, 76, 1, 91, 3, 26, 4, 38, 8, 47, 0, 59, 5, 74, 
    7, 38, 6,  3, 8,  7, 2, 48, 5, 52, 1, 38, 0, 31, 3, 45, 4,  9, 
    8, 37, 5, 28, 1, 25, 4, 17, 2, 52, 6, 79, 0,  5, 3, 22, 7, 66, 
    5,  4, 3, 89, 0, 66, 2, 83, 7, 79, 1, 93, 4, 40, 6, 67, 8, 81
  };
  const int q5439[] = {
    9, 9, // Number of jobs and machines
    6, 95, 1, 59, 2, 79, 3, 73, 0, 57, 7,  8, 5, 68, 4, 81, 8, 50, 
    0, 82, 2, 98, 5, 22, 3, 90, 6, 89, 7, 48, 8, 88, 1, 53, 4, 49, 
    4, 74, 3,  2, 0, 33, 7,  5, 1, 40, 8,  2, 6, 43, 5, 91, 2, 68, 
    8, 20, 6, 31, 1, 19, 7, 70, 3, 67, 4, 65, 5, 98, 0, 55, 2,  1, 
    8,  2, 4,  3, 6, 77, 0, 51, 5, 65, 1, 23, 7, 90, 2, 74, 3, 54, 
    2, 81, 1, 18, 5, 18, 3, 97, 6, 64, 8, 43, 0, 81, 4, 53, 7, 57, 
    2, 36, 3,  5, 1, 33, 0, 47, 7, 87, 4, 23, 6, 80, 8, 68, 5, 45, 
    5, 43, 8, 51, 0, 16, 6, 59, 2, 26, 7, 70, 3, 53, 4, 15, 1, 41, 
    3, 83, 0, 13, 7, 35, 1, 64, 2, 16, 4, 75, 6, 85, 5, 62, 8, 49
  };
  const int q5440[] = {
    9, 9, // Number of jobs and machines
    7, 31, 4, 10, 3, 80, 8, 91, 0, 94, 1, 75, 2, 67, 6, 79, 5, 41, 
    6, 90, 7, 45, 8, 69, 3, 26, 0, 86, 1, 14, 5, 73, 2, 63, 4, 82, 
    1, 67, 4,  4, 8,  6, 3, 28, 5, 14, 0, 95, 7, 77, 2, 24, 6, 38, 
    1, 48, 3, 49, 5,  1, 2, 26, 6, 14, 4, 64, 7, 75, 0, 39, 8, 83, 
    3, 27, 1, 53, 6, 19, 2, 35, 4, 47, 0, 82, 8, 47, 7, 29, 5, 68, 
    4, 77, 3, 49, 6, 40, 7, 41, 0, 31, 1, 81, 2,  1, 5, 29, 8, 23, 
    4, 62, 3, 31, 1, 89, 6, 78, 8, 60, 0, 19, 2, 65, 5, 96, 7,  5, 
    8, 61, 3, 98, 1, 23, 0, 37, 6, 82, 4,  6, 2, 46, 5, 31, 7, 90, 
    1, 58, 8, 80, 7, 26, 3, 86, 0, 26, 4,  8, 2, 16, 6, 86, 5, 74
  };
  const int q5441[] = {
    9, 9, // Number of jobs and machines
    4, 19, 2,  6, 0,  9, 1, 29, 7, 42, 3, 92, 5, 16, 8, 11, 6,  9, 
    0, 96, 1, 57, 2,  2, 4, 85, 8, 91, 5, 66, 6,  7, 3,  5, 7, 82, 
    8, 63, 5, 86, 0, 40, 4, 25, 3, 43, 7, 20, 1,  9, 2,  7, 6, 43, 
    1, 73, 0, 47, 3, 82, 6, 85, 7, 43, 8, 80, 4, 93, 2, 33, 5, 79, 
    7, 82, 6, 66, 2, 17, 5, 42, 3, 73, 1, 40, 0, 20, 4, 88, 8,  6, 
    5, 70, 7, 46, 0, 34, 3, 74, 1, 91, 6, 41, 8, 88, 2, 66, 4, 35, 
    6, 87, 7, 22, 0, 59, 2, 68, 5, 95, 4, 39, 8, 59, 1,  5, 3, 34, 
    5, 96, 7, 82, 6,  1, 0, 24, 2, 27, 1, 73, 8, 77, 3, 77, 4, 92, 
    1, 34, 2, 38, 3, 92, 6,  1, 4, 40, 8, 20, 0, 27, 5, 60, 7, 95
  };
  const int q5442[] = {
    9, 9, // Number of jobs and machines
    3, 58, 0, 38, 4, 81, 8, 36, 5, 97, 7,  6, 2, 29, 6, 73, 1, 96, 
    8,  2, 2, 22, 5,  7, 3, 14, 0, 18, 1, 85, 7, 29, 4, 63, 6, 49, 
    5, 29, 1,  5, 8,  6, 4, 83, 2, 55, 7, 21, 6, 54, 3, 90, 0, 12, 
    0, 13, 4, 65, 6, 70, 1, 59, 5, 53, 8,  8, 7, 85, 3, 90, 2, 61, 
    7, 63, 0, 55, 3,  4, 6, 24, 8, 84, 5, 80, 2, 48, 4,  3, 1, 33, 
    5, 31, 2, 85, 7, 40, 3, 33, 4, 74, 1, 43, 6, 44, 0, 79, 8, 44, 
    5, 58, 4,  8, 2, 55, 7, 37, 3, 92, 6, 96, 8, 33, 0, 56, 1, 95, 
    5, 19, 2, 47, 4, 15, 8, 25, 1, 46, 0, 16, 6, 62, 3, 59, 7, 81, 
    4,  1, 8, 20, 2, 73, 1, 78, 0, 71, 5,  6, 7, 53, 6, 17, 3, 59
  };
  const int q5443[] = {
    9, 9, // Number of jobs and machines
    7, 43, 6, 60, 5, 55, 1, 24, 4, 38, 2, 41, 3,  1, 8, 18, 0, 94, 
    8, 26, 6, 24, 5, 51, 2, 19, 1, 32, 7, 63, 4,  8, 0, 30, 3, 56, 
    7, 86, 3, 63, 0, 22, 1, 18, 4, 77, 2, 51, 6, 45, 8, 43, 5, 51, 
    1, 79, 3, 41, 0, 25, 8, 23, 2, 30, 5, 90, 7, 44, 4, 56, 6,  4, 
    7, 99, 1, 99, 2, 95, 8, 62, 3, 49, 4, 67, 5, 51, 0, 58, 6, 90, 
    4, 67, 8, 68, 1, 51, 6, 70, 2, 65, 3, 25, 5, 70, 0, 42, 7, 74, 
    1, 93, 5, 44, 8, 11, 3, 60, 4, 25, 0, 64, 2, 20, 7, 37, 6, 73, 
    3, 23, 1, 90, 0, 91, 7, 81, 5, 14, 8, 74, 6, 12, 4, 11, 2, 34, 
    3, 46, 6, 50, 8, 55, 1,  9, 2, 62, 7, 93, 0, 60, 5, 82, 4, 18
  };
  const int q5444[] = {
    9, 9, // Number of jobs and machines
    7, 17, 1, 70, 0, 72, 3, 69, 8, 42, 4, 31, 6,  1, 2, 32, 5, 34, 
    0,  4, 4, 15, 6, 54, 2, 41, 7, 79, 5, 25, 8, 32, 1, 91, 3, 27, 
    4, 73, 0, 16, 3, 56, 6, 56, 7,  1, 2, 24, 5, 55, 8, 91, 1, 42, 
    8, 81, 3, 68, 7, 64, 2, 84, 5, 78, 1, 95, 4, 94, 6, 62, 0, 11, 
    1, 67, 8, 13, 2, 88, 3, 36, 6, 53, 0,  2, 4, 79, 5, 79, 7, 39, 
    0, 96, 1, 46, 2, 76, 7, 27, 5, 23, 8, 13, 6, 92, 3, 73, 4, 87, 
    8, 87, 6, 55, 7, 97, 4, 64, 2, 50, 3, 75, 5,  8, 0, 98, 1, 55, 
    4, 11, 3, 25, 0, 52, 6, 43, 2, 80, 8, 77, 1,  8, 5, 34, 7, 86, 
    4, 75, 0, 54, 6, 21, 3,  8, 8, 56, 5, 26, 2,  6, 7, 11, 1, 38
  };
  const int q5445[] = {
    9, 9, // Number of jobs and machines
    0, 88, 7, 56, 2, 58, 1, 76, 4, 19, 3, 78, 8, 40, 5, 30, 6, 79, 
    4, 29, 6, 95, 2, 63, 7, 73, 3,  9, 1, 76, 0, 39, 8, 97, 5,  8, 
    5, 24, 4, 43, 3, 45, 1, 36, 7,  1, 6,  4, 2, 68, 0, 49, 8, 39, 
    2, 53, 6,  4, 1, 51, 4, 66, 8, 78, 0, 56, 3,  2, 7,  8, 5,  1, 
    6, 84, 0, 72, 2, 54, 8, 85, 3, 28, 7, 68, 5, 31, 1, 70, 4,  2, 
    1, 71, 7, 67, 0, 74, 6, 68, 3, 69, 5, 40, 4, 12, 2, 65, 8, 26, 
    0, 93, 1, 10, 6, 40, 2, 75, 5, 28, 7, 14, 3, 66, 8, 77, 4, 63, 
    1, 65, 2, 60, 4, 39, 3, 96, 5, 64, 6, 97, 8, 96, 7, 26, 0, 14, 
    5, 53, 1, 44, 0, 76, 3, 99, 2, 74, 8, 86, 4, 14, 6, 83, 7, 22
  };
  const int q5446[] = {
    9, 9, // Number of jobs and machines
    1,  8, 7, 93, 3, 64, 5, 65, 0, 82, 2, 58, 4, 51, 6, 92, 8, 29, 
    1, 71, 0, 52, 8,  6, 3, 44, 2, 88, 7, 50, 5, 32, 6, 11, 4, 27, 
    5, 20, 7, 59, 6, 12, 8, 16, 0,  9, 1, 41, 2, 38, 4, 68, 3, 67, 
    6, 82, 0, 76, 4, 46, 3, 63, 2,  7, 5, 86, 8, 28, 7,  8, 1, 43, 
    8, 15, 2, 48, 1, 36, 0, 31, 5,  5, 7,  3, 6, 34, 4, 80, 3, 16, 
    1, 62, 2, 82, 0,  1, 8, 77, 3, 79, 5, 31, 4, 88, 7, 77, 6, 74, 
    6, 90, 4, 27, 3, 32, 8, 80, 7, 40, 5, 21, 2, 55, 1, 10, 0, 13, 
    8, 47, 4, 64, 1, 32, 5, 47, 3, 41, 2,  1, 7, 30, 6, 52, 0, 76, 
    0, 12, 1, 57, 8, 63, 5, 34, 7, 89, 3, 33, 4, 59, 6, 30, 2, 42
  };
  const int q5447[] = {
    9, 9, // Number of jobs and machines
    8, 44, 6, 75, 0, 59, 4, 81, 1, 76, 7, 51, 5, 56, 2, 18, 3, 39, 
    4, 48, 7, 76, 3, 98, 6, 58, 2, 42, 0, 38, 8, 34, 1, 37, 5, 38, 
    3,  9, 7, 62, 2, 23, 1, 97, 8, 34, 0, 15, 6, 39, 5, 89, 4, 87, 
    5, 74, 8, 41, 1, 34, 6, 90, 2, 64, 3, 25, 7, 76, 4, 27, 0, 42, 
    4,  3, 7, 29, 2, 18, 0, 38, 8, 19, 3, 97, 6, 58, 1, 43, 5, 94, 
    5, 24, 1, 98, 8,  3, 6, 65, 4, 81, 0, 10, 7, 27, 2, 84, 3, 50, 
    4, 46, 2, 95, 5, 89, 3, 99, 6, 92, 0, 87, 8, 65, 7, 82, 1, 99, 
    6, 61, 4, 36, 8, 87, 3, 26, 2, 50, 1,  5, 0, 94, 7, 92, 5, 14, 
    5, 98, 4, 76, 7, 69, 6, 17, 8, 83, 2, 36, 0, 66, 1, 70, 3,  8
  };
  const int q5448[] = {
    9, 9, // Number of jobs and machines
    6, 51, 3, 70, 0, 82, 7, 15, 5, 13, 1,  4, 8, 15, 2, 15, 4, 77, 
    2, 48, 1, 82, 4, 94, 0, 47, 3, 69, 7, 71, 8, 62, 5, 15, 6, 55, 
    1, 21, 3, 93, 5, 62, 4, 27, 7, 24, 6, 74, 0, 38, 8, 92, 2, 88, 
    8,  5, 3, 83, 4, 17, 5, 52, 2, 39, 0, 39, 6, 43, 7, 50, 1, 29, 
    0, 33, 8, 88, 2, 52, 7, 82, 3, 13, 6, 95, 5, 88, 1, 38, 4, 43, 
    7, 31, 6, 96, 0, 69, 3, 98, 5, 58, 1, 74, 4, 70, 2, 54, 8, 44, 
    5, 55, 3, 57, 8, 20, 1, 28, 4, 96, 7, 23, 0, 12, 6, 82, 2, 18, 
    2, 84, 8, 46, 5, 59, 6, 75, 4, 18, 1, 35, 0, 70, 3, 18, 7, 48, 
    6, 57, 5, 83, 1, 63, 3, 27, 7, 51, 2, 64, 8, 47, 0, 82, 4, 27
  };
  const int q5449[] = {
    9, 9, // Number of jobs and machines
    2, 40, 4, 29, 3, 75, 0, 82, 5,  6, 7, 79, 6, 93, 8, 19, 1, 52, 
    3,  7, 2, 85, 0, 41, 1, 18, 4, 99, 7, 75, 6, 65, 5, 61, 8, 49, 
    2, 44, 6, 80, 7, 86, 1, 36, 5, 82, 3, 38, 0, 68, 8, 13, 4, 36, 
    2, 40, 8, 55, 7, 22, 1, 50, 4, 66, 3, 92, 5, 49, 0, 63, 6, 21, 
    0, 18, 1,  7, 2,  9, 4, 88, 7, 53, 5, 20, 3, 62, 6,  2, 8, 43, 
    1, 17, 0, 19, 2,  7, 8, 21, 7, 40, 4, 89, 3, 46, 6, 81, 5, 93, 
    8,  2, 0, 61, 4, 12, 5, 57, 2, 33, 1, 18, 3, 88, 7, 58, 6, 71, 
    0, 90, 5, 48, 2, 61, 8, 21, 3, 96, 4, 57, 1, 66, 7, 85, 6, 11, 
    4, 48, 8, 86, 2, 69, 1,  1, 7, 48, 6, 70, 0, 73, 5,  8, 3, 61
  };
  const int q5450[] = {
    9, 9, // Number of jobs and machines
    0, 71, 3, 67, 7, 60, 2, 90, 6, 19, 1, 14, 8, 88, 4, 37, 5, 84, 
    2, 46, 8, 45, 6, 34, 1, 82, 0, 37, 7, 70, 5, 47, 3,  2, 4, 84, 
    8, 37, 6, 31, 0, 13, 5, 75, 7, 26, 2, 38, 3, 31, 4, 21, 1, 15, 
    7,  6, 0, 55, 3, 99, 8, 12, 1, 34, 4, 94, 5, 56, 6, 98, 2, 60, 
    7, 40, 2, 83, 8,  3, 6, 18, 5, 72, 3, 88, 4, 20, 1, 15, 0, 48, 
    1, 97, 0,  6, 3, 39, 2, 67, 7, 64, 5, 58, 8, 26, 4, 27, 6, 16, 
    5, 99, 3, 53, 7, 95, 0, 47, 2, 25, 8, 52, 1, 48, 4, 26, 6, 63, 
    2, 19, 3, 70, 7, 17, 4, 22, 5, 95, 6, 92, 1, 73, 0, 65, 8,  2, 
    3, 46, 6, 76, 2, 57, 0, 38, 1, 75, 7, 49, 8, 87, 5,  9, 4, 92
  };
  const int q5451[] = {
    9, 9, // Number of jobs and machines
    2, 58, 1, 42, 8, 71, 3, 36, 6, 80, 7, 15, 4,  1, 5, 46, 0, 16, 
    2, 57, 0,  9, 5, 70, 8,  1, 3, 31, 7, 81, 4, 18, 1, 91, 6, 81, 
    7, 29, 1, 57, 6, 84, 8,  7, 3, 50, 4, 24, 2, 98, 5, 74, 0, 54, 
    0, 13, 3, 47, 4, 89, 2, 45, 8, 99, 5, 19, 7,  9, 6, 21, 1, 59, 
    5, 84, 7, 50, 0, 76, 2, 84, 8, 34, 4, 75, 1, 55, 6, 84, 3, 25, 
    8, 51, 6,  8, 0, 86, 4,  4, 3, 26, 2,  7, 1, 11, 5, 73, 7, 18, 
    6, 68, 3, 12, 5, 60, 1, 22, 0, 20, 7, 41, 4, 37, 2, 30, 8,  1, 
    7, 24, 2, 21, 3, 30, 5, 95, 0, 78, 8, 52, 6, 84, 4, 67, 1, 84, 
    3, 65, 0, 43, 4, 57, 2, 91, 6, 50, 1, 78, 7, 37, 5, 35, 8, 10
  };
  const int q5452[] = {
    9, 9, // Number of jobs and machines
    6, 67, 2, 67, 4, 44, 7, 11, 0, 23, 8, 35, 1, 21, 5, 34, 3, 29, 
    8,  1, 4,  2, 3, 92, 6,  2, 5, 11, 0, 84, 2, 30, 7, 22, 1, 13, 
    7, 29, 2, 30, 8, 19, 6, 34, 1, 76, 0, 14, 5, 29, 4, 67, 3, 79, 
    0, 92, 8, 22, 1, 67, 4, 33, 2, 36, 3, 56, 7, 69, 6, 80, 5, 74, 
    1, 52, 8,  9, 2, 98, 5,  9, 6, 86, 7, 24, 0, 77, 3, 83, 4,  1, 
    1, 85, 2, 57, 3, 92, 5,  3, 4,  1, 8, 89, 6, 74, 0, 86, 7, 63, 
    4, 15, 0, 95, 7, 76, 1, 51, 8, 74, 6, 73, 3, 72, 2, 30, 5,  2, 
    4,  7, 2, 66, 6, 23, 7, 35, 5,  9, 0, 53, 3, 49, 8,  5, 1, 72, 
    8, 30, 7, 57, 5, 67, 6,  2, 4, 77, 0,  7, 3, 75, 2, 35, 1, 36
  };
  const int q5453[] = {
    9, 9, // Number of jobs and machines
    7, 41, 0,  6, 6, 30, 1, 73, 3, 24, 2, 47, 4, 98, 8, 14, 5, 31, 
    5, 30, 0, 16, 1, 59, 7, 16, 6, 67, 2, 82, 8, 78, 3, 41, 4, 86, 
    1, 22, 4,  8, 3, 63, 5, 57, 8,  6, 6, 19, 2, 33, 0, 72, 7, 24, 
    5, 46, 6, 79, 1, 30, 8, 84, 7, 27, 3, 80, 2, 79, 4, 71, 0, 70, 
    8,  3, 6, 13, 3, 69, 0, 26, 4, 54, 1, 79, 5, 68, 2,  7, 7, 84, 
    3, 18, 6, 33, 0, 19, 5, 61, 2, 25, 1, 31, 7, 41, 4, 55, 8, 45, 
    3, 35, 2, 84, 5, 26, 1, 69, 6, 92, 8, 57, 4,  3, 7, 70, 0, 39, 
    7, 90, 8, 45, 6, 89, 1, 44, 3, 63, 2, 58, 4, 14, 5, 60, 0, 99, 
    5, 90, 7, 18, 0, 79, 6, 97, 3, 58, 1, 31, 4, 23, 2, 12, 8, 30
  };
  const int q5454[] = {
    9, 9, // Number of jobs and machines
    7, 77, 6, 64, 5, 75, 2, 99, 3, 73, 8, 63, 4,  4, 0, 39, 1, 45, 
    2, 58, 6, 89, 5, 77, 8, 57, 1,  1, 4, 60, 3, 75, 7, 15, 0, 19, 
    7, 46, 6, 85, 0, 46, 2, 83, 5, 38, 8, 57, 3, 51, 1, 85, 4,  1, 
    8, 84, 1, 80, 4, 72, 0, 51, 3,  5, 7, 26, 6, 11, 5, 50, 2, 92, 
    1, 52, 2, 35, 6, 79, 7, 82, 0, 95, 3, 83, 5, 92, 4, 98, 8, 87, 
    1, 95, 8, 57, 5, 10, 3, 23, 0, 15, 6, 17, 4,  9, 2, 58, 7, 57, 
    1, 61, 3, 97, 5, 33, 0, 78, 6, 84, 4, 24, 8, 31, 7, 23, 2, 36, 
    5, 55, 6, 37, 8, 39, 3, 23, 1, 55, 4, 38, 0, 65, 2, 44, 7, 36, 
    3, 70, 6, 16, 1, 18, 2, 61, 0, 27, 7, 60, 8, 24, 4, 76, 5, 13
  };
  const int q5455[] = {
    9, 9, // Number of jobs and machines
    4, 78, 1, 72, 5, 27, 8, 12, 2, 51, 3, 29, 0, 87, 6,  4, 7, 16, 
    2, 25, 0, 99, 7, 56, 4,  5, 8, 24, 6,  3, 1, 23, 5, 32, 3, 49, 
    1, 66, 5,  8, 7,  1, 3, 89, 2, 26, 0, 63, 8,  8, 6,  4, 4, 53, 
    4, 45, 7,  6, 8, 83, 2, 30, 3, 80, 1, 16, 6, 75, 5, 12, 0, 21, 
    5, 18, 6, 63, 7, 13, 3, 13, 4, 13, 2, 99, 0, 68, 1,  5, 8, 26, 
    5, 86, 0, 34, 3, 34, 2, 53, 1, 48, 4, 90, 8, 13, 7, 73, 6, 88, 
    6, 52, 5, 79, 0, 17, 8, 29, 7, 76, 4, 54, 1,  1, 3, 37, 2, 28, 
    6, 59, 2, 82, 7, 42, 3, 30, 8, 73, 0, 64, 4, 71, 1, 41, 5, 56, 
    6, 54, 8, 50, 1, 32, 2, 80, 3, 73, 4, 54, 5, 91, 0, 65, 7, 14
  };
  const int q5456[] = {
    9, 9, // Number of jobs and machines
    3, 62, 2, 81, 0, 36, 1, 39, 8, 37, 4, 25, 6, 42, 7, 69, 5, 78, 
    6, 79, 4, 55, 5, 68, 7, 74, 1, 21, 0,  1, 3,  5, 2, 55, 8, 47, 
    0, 46, 2, 37, 3, 94, 5, 16, 8, 44, 1, 61, 6, 73, 7, 25, 4, 13, 
    7, 73, 2, 57, 0, 86, 5, 36, 8,  3, 4, 40, 1, 72, 3, 73, 6, 79, 
    3, 38, 8, 72, 2, 69, 5,  9, 0, 66, 1, 69, 7, 24, 4, 86, 6, 65, 
    2, 99, 5, 94, 7, 32, 3, 28, 4, 42, 0, 86, 1, 85, 8, 32, 6,  8, 
    3, 52, 5, 60, 2, 30, 1, 42, 6, 10, 0, 30, 8, 33, 7, 22, 4, 38, 
    6, 81, 3, 91, 8, 50, 4, 79, 7,  1, 0, 89, 2, 84, 1, 58, 5, 66, 
    5, 83, 1, 86, 0, 12, 2, 82, 8, 29, 7, 88, 4, 42, 6, 39, 3,  4
  };
  const int q5457[] = {
    9, 9, // Number of jobs and machines
    3, 23, 5, 57, 4,  6, 6, 64, 8, 69, 0, 79, 7, 92, 1, 41, 2, 29, 
    7, 65, 8, 54, 0, 29, 1, 89, 4, 80, 3, 95, 5, 91, 2, 79, 6, 99, 
    7, 65, 2, 69, 8, 34, 4, 66, 1,  1, 6, 66, 5, 73, 3, 65, 0,  3, 
    7, 72, 0,  6, 5, 87, 2, 19, 4, 99, 6, 60, 8, 46, 3,  2, 1, 55, 
    3, 95, 2, 59, 1, 48, 4, 18, 8, 65, 5, 21, 0, 32, 6,  4, 7, 30, 
    5, 72, 6, 85, 7, 95, 4, 52, 3, 35, 0, 15, 8, 95, 1, 23, 2, 97, 
    3,  8, 8, 96, 4, 95, 6, 43, 7, 17, 2, 28, 0, 53, 5, 19, 1, 94, 
    4, 76, 5,  4, 1, 43, 2, 93, 3, 91, 7, 56, 8, 47, 6, 97, 0, 82, 
    3, 57, 5,  8, 4, 52, 8, 44, 7, 53, 0, 70, 6, 44, 1, 95, 2, 12
  };
  const int q5458[] = {
    9, 9, // Number of jobs and machines
    3, 18, 2, 86, 5, 78, 0, 17, 6,  3, 1,  2, 7, 83, 4, 72, 8, 62, 
    0, 92, 8, 44, 2, 91, 6, 63, 1, 88, 5,  8, 3, 80, 4, 18, 7, 51, 
    8, 32, 0, 47, 2, 81, 1, 93, 6, 72, 5, 17, 4, 92, 7, 63, 3, 73, 
    2, 53, 3, 49, 1,  5, 7, 47, 5,  4, 8, 93, 4, 34, 6, 27, 0, 98, 
    4, 20, 8, 44, 0, 58, 6, 14, 1, 25, 5, 87, 7, 66, 3, 98, 2, 97, 
    7, 80, 4, 36, 2, 72, 8, 54, 6, 89, 3, 61, 1, 94, 0, 31, 5, 38, 
    1,  3, 2, 68, 5, 48, 4, 68, 6, 66, 8, 35, 3, 71, 7, 62, 0, 75, 
    0, 61, 2, 57, 4, 73, 7, 50, 6, 45, 8, 24, 5, 44, 3, 45, 1, 80, 
    2, 14, 7, 54, 1, 80, 5, 18, 0, 41, 8, 42, 4, 76, 6, 13, 3, 66
  };
  const int q5459[] = {
    9, 9, // Number of jobs and machines
    6, 26, 8, 55, 5, 49, 2, 58, 4, 81, 1, 83, 0,  1, 7, 58, 3, 71, 
    5, 64, 2, 33, 4, 42, 3, 81, 0, 19, 6, 86, 7, 59, 8, 89, 1, 48, 
    8, 90, 5, 20, 3, 80, 7, 25, 2,  9, 1, 42, 4, 22, 6, 48, 0, 17, 
    2, 26, 5,  5, 7, 64, 0, 62, 3, 45, 6,  9, 4, 38, 8, 92, 1, 18, 
    4, 15, 0, 28, 6,  9, 1, 96, 7, 40, 3, 64, 5, 25, 2, 72, 8,  8, 
    0, 51, 6, 55, 8, 74, 5, 30, 1, 22, 7, 74, 2, 21, 3, 76, 4, 86, 
    6, 47, 3, 69, 4, 33, 1, 84, 5,  1, 2, 45, 7, 20, 8, 96, 0, 14, 
    2, 31, 8, 99, 1, 35, 0,  7, 6,  7, 5, 69, 4,  4, 3, 89, 7, 30, 
    6, 17, 7, 66, 1, 79, 8, 91, 4,  5, 5, 95, 3, 10, 0, 73, 2, 78
  };
  const int q5460[] = {
    9, 9, // Number of jobs and machines
    3, 75, 0, 59, 8, 45, 2, 56, 1, 73, 6, 70, 5, 56, 4, 80, 7, 87, 
    4, 60, 6, 49, 8, 91, 5, 47, 1, 36, 3, 99, 7, 45, 0, 58, 2, 57, 
    6, 29, 7,  5, 0,  9, 8, 65, 1, 42, 5, 80, 3, 36, 2, 83, 4, 64, 
    3, 61, 7,  3, 2, 37, 8, 25, 1, 91, 5, 22, 6, 10, 0,  7, 4, 61, 
    4,  3, 7, 53, 0, 66, 2, 94, 3, 94, 5, 60, 6, 63, 1, 13, 8, 17, 
    8, 27, 7, 22, 6, 85, 4, 26, 0, 33, 3, 49, 2, 60, 1, 62, 5, 57, 
    4, 26, 8, 62, 3, 47, 1, 32, 0,  5, 7, 85, 6, 24, 5,  9, 2, 22, 
    6,  9, 4, 54, 5, 63, 7, 63, 1,  1, 0,  8, 2, 54, 8, 62, 3, 44, 
    5, 66, 7, 43, 2,  4, 4, 52, 1, 81, 6, 46, 0, 56, 3, 11, 8, 93
  };
  const int q5461[] = {
    9, 9, // Number of jobs and machines
    3,  9, 6, 17, 8, 49, 4, 26, 1, 83, 2, 18, 5, 61, 7,  6, 0, 87, 
    2, 47, 1, 71, 0, 42, 3, 87, 5, 29, 7, 24, 6, 80, 8, 27, 4, 95, 
    6, 80, 5, 60, 3, 87, 2, 42, 4, 69, 0, 68, 8, 11, 1, 95, 7, 14, 
    2, 57, 7, 11, 5, 94, 1,  1, 0, 14, 4, 34, 8, 66, 3, 47, 6,  2, 
    8, 25, 2, 50, 3, 19, 7, 66, 4, 45, 1, 88, 5,  7, 6, 42, 0,  4, 
    0, 82, 7, 60, 5, 63, 6, 47, 8, 17, 2, 44, 3, 87, 1, 66, 4, 29, 
    3, 40, 1, 75, 7, 50, 8, 19, 5, 97, 4, 67, 2, 18, 0, 84, 6, 74, 
    4, 49, 1, 24, 8, 55, 6, 69, 3,  5, 5, 68, 0, 52, 2, 41, 7, 95, 
    7, 75, 2, 41, 3, 51, 4, 86, 8, 24, 1, 82, 0, 67, 5, 84, 6, 82
  };
  const int q5462[] = {
    9, 9, // Number of jobs and machines
    0, 80, 2, 31, 4, 84, 8, 51, 6, 38, 3, 83, 1, 59, 7, 51, 5, 88, 
    6, 87, 8, 93, 2, 74, 3, 71, 1, 33, 0, 31, 4, 44, 5, 68, 7, 20, 
    7, 97, 6, 40, 3, 89, 2, 15, 5, 33, 4, 61, 8, 33, 1,  8, 0, 64, 
    5, 49, 2, 60, 4, 23, 3, 54, 7, 49, 0, 58, 6, 95, 1, 22, 8, 39, 
    7,  3, 1, 75, 0, 29, 2, 92, 4, 49, 8, 88, 5, 40, 3, 57, 6,  3, 
    2, 84, 8, 90, 0, 35, 3, 99, 4, 80, 5, 49, 6, 25, 7, 79, 1, 32, 
    2, 99, 0, 92, 1, 62, 5, 85, 4, 89, 6, 43, 3, 39, 7, 79, 8, 50, 
    3, 16, 0, 72, 1, 33, 5, 26, 8,  1, 2, 18, 4, 97, 7, 74, 6, 12, 
    2, 88, 6, 97, 0, 98, 3, 29, 4, 78, 7, 87, 5, 72, 8, 60, 1, 25
  };
  const int q5463[] = {
    9, 9, // Number of jobs and machines
    0, 49, 2, 52, 7, 22, 8, 12, 5,  2, 3, 93, 6, 25, 4, 82, 1, 62, 
    0, 36, 5, 12, 3, 77, 4, 71, 1,  5, 2, 82, 8, 57, 7, 45, 6,  5, 
    2, 83, 7, 97, 5, 51, 6, 91, 3, 79, 8, 10, 1,  2, 4, 70, 0, 49, 
    0, 83, 7, 55, 4, 32, 6, 48, 5, 27, 2, 53, 1, 83, 3, 73, 8, 76, 
    0, 40, 5, 17, 6, 28, 8, 11, 3, 59, 2, 57, 7, 85, 1, 14, 4, 84, 
    8, 29, 1, 12, 4,  9, 2, 29, 0, 99, 3, 23, 7, 12, 6, 50, 5, 53, 
    8, 22, 3, 96, 6, 98, 4, 22, 7, 91, 1, 87, 2, 20, 5, 33, 0, 99, 
    2, 62, 5, 57, 6, 49, 4, 50, 8,  5, 0, 46, 3, 89, 7, 54, 1, 93, 
    7, 85, 8, 41, 6, 21, 3, 36, 1, 13, 2, 48, 5, 19, 0, 54, 4, 44
  };
  const int q5464[] = {
    9, 9, // Number of jobs and machines
    1, 39, 7, 70, 4, 12, 2, 51, 8, 19, 0, 85, 6, 14, 3,  7, 5, 39, 
    7, 96, 1, 68, 6, 61, 5, 27, 2, 49, 8, 17, 4, 25, 0, 48, 3, 83, 
    6, 58, 2, 98, 5, 47, 0, 75, 8, 22, 7, 15, 1, 95, 4, 71, 3, 70, 
    8, 43, 3, 77, 6, 86, 0, 49, 5, 13, 2,  8, 4, 38, 1, 25, 7, 76, 
    4,  8, 2, 41, 5, 54, 1, 97, 3, 20, 0, 26, 7, 88, 8, 52, 6, 22, 
    3, 39, 5,  8, 4, 13, 7, 39, 0, 42, 1, 25, 6,  4, 2, 47, 8, 68, 
    4, 18, 5, 13, 8, 36, 6, 34, 2, 32, 0, 69, 3, 61, 7, 71, 1, 88, 
    0, 29, 5, 97, 2, 39, 8, 56, 7, 74, 1,  6, 3, 30, 4,  9, 6, 82, 
    6, 49, 5, 36, 7, 79, 1, 53, 4, 73, 8, 84, 3, 39, 2, 53, 0, 58
  };
  const int q5465[] = {
    9, 9, // Number of jobs and machines
    0, 99, 6, 70, 7, 32, 1, 79, 8, 43, 4, 37, 3, 45, 2, 62, 5,  8, 
    4, 33, 8, 91, 3, 38, 5, 67, 0, 37, 1, 91, 7, 71, 6, 74, 2, 63, 
    3, 36, 1, 49, 4, 13, 8, 84, 6, 71, 5, 57, 0, 22, 7,  8, 2, 65, 
    6, 42, 3, 90, 7, 42, 4, 83, 2, 75, 5, 45, 8, 44, 0, 50, 1, 11, 
    2, 98, 3, 83, 6, 19, 5, 43, 0,  7, 7, 10, 8, 81, 4, 72, 1, 40, 
    8, 88, 1, 89, 3, 85, 7, 14, 0, 29, 6, 61, 4, 47, 5, 25, 2, 63, 
    0, 84, 8, 39, 5, 54, 6, 60, 1, 64, 7, 41, 2, 69, 4, 25, 3, 26, 
    5, 28, 7, 10, 1, 91, 6, 35, 8, 81, 2, 47, 4, 55, 3, 37, 0, 99, 
    8, 10, 7, 74, 0, 53, 6, 46, 1, 79, 5, 10, 2, 28, 3, 93, 4, 44
  };
  const int q5466[] = {
    9, 9, // Number of jobs and machines
    6, 83, 5, 69, 2, 99, 4, 61, 3, 56, 0, 11, 7, 32, 1, 24, 8, 39, 
    8, 98, 1, 68, 2, 70, 7, 56, 5, 48, 3,  4, 4, 92, 6, 86, 0, 42, 
    3, 53, 8, 67, 1, 94, 4, 20, 0, 41, 2, 23, 5, 18, 6, 96, 7, 25, 
    4, 31, 3, 46, 8, 31, 2,  7, 5, 27, 0, 80, 7, 58, 6, 39, 1, 65, 
    2, 23, 5, 30, 0, 39, 7, 29, 6, 81, 1, 33, 8, 77, 4, 50, 3, 75, 
    8, 88, 6, 60, 2, 98, 4, 42, 5, 41, 0, 70, 7, 72, 1, 11, 3, 66, 
    3, 85, 2, 48, 1, 17, 0, 28, 6, 88, 4, 15, 8, 77, 7, 84, 5, 28, 
    5, 80, 3, 95, 0, 64, 8, 29, 7, 73, 2, 39, 4, 48, 6, 53, 1, 20, 
    1, 88, 8, 12, 3,  2, 0, 72, 6, 95, 4, 21, 5, 75, 7, 82, 2, 56
  };
  const int q5467[] = {
    9, 9, // Number of jobs and machines
    8, 24, 5, 72, 3, 65, 2, 95, 4, 51, 7, 58, 0, 62, 6, 54, 1, 36, 
    4, 12, 3, 28, 0,  9, 2,  4, 5, 13, 1, 49, 8, 68, 7, 57, 6, 61, 
    3, 85, 1, 16, 4, 22, 8, 63, 5, 28, 0,  5, 7, 81, 6, 28, 2, 82, 
    3, 88, 5, 66, 6, 80, 8,  6, 0, 59, 4, 35, 1, 20, 2, 14, 7, 11, 
    4, 50, 0, 23, 3, 77, 7, 79, 6, 85, 2, 49, 5, 33, 1, 71, 8, 95, 
    0, 38, 4, 13, 2, 39, 5, 23, 3, 24, 7,  4, 6, 29, 8, 21, 1, 28, 
    6, 58, 1, 68, 8, 17, 7, 23, 5, 10, 4, 49, 3, 11, 2,  2, 0,  5, 
    6,  2, 1, 38, 0, 42, 3, 37, 8, 66, 7, 76, 2, 18, 4, 73, 5, 92, 
    7, 73, 6, 21, 1,  8, 2, 51, 8, 46, 0, 18, 4, 79, 3, 75, 5, 76
  };
  const int q5468[] = {
    9, 9, // Number of jobs and machines
    8,  6, 6, 60, 4, 41, 7, 99, 1, 25, 0, 88, 3,  9, 5,  9, 2, 34, 
    7, 62, 2, 33, 3, 94, 1, 14, 8,  7, 4, 14, 6, 80, 0, 42, 5, 99, 
    1, 70, 5, 48, 4, 39, 8, 33, 0, 48, 2, 48, 7, 13, 6, 77, 3, 46, 
    7,  4, 5, 47, 2, 44, 4, 42, 1, 71, 8, 55, 0, 52, 3, 56, 6,  5, 
    3, 49, 8, 87, 0, 41, 4, 16, 7, 12, 5, 10, 1, 96, 6,  5, 2, 34, 
    1, 70, 8, 85, 2, 14, 6, 69, 3, 38, 5, 94, 0,  7, 7, 20, 4, 33, 
    4, 66, 3, 90, 7, 38, 1, 16, 8, 89, 0, 45, 2, 10, 6, 48, 5, 90, 
    2, 69, 8, 90, 7, 31, 3, 15, 0, 23, 1, 64, 5, 39, 4, 46, 6, 46, 
    5, 89, 1, 15, 3, 21, 7, 88, 2, 25, 4, 91, 0,  5, 8, 49, 6, 41
  };
  const int q5469[] = {
    9, 9, // Number of jobs and machines
    2, 99, 7,  4, 0, 30, 8, 82, 5, 47, 1, 70, 6, 49, 3, 93, 4,  6, 
    2, 12, 8, 69, 0, 13, 3, 91, 5, 21, 4, 58, 7, 39, 6, 14, 1, 91, 
    5,  3, 4, 44, 3, 21, 2, 63, 7, 36, 8, 30, 0, 97, 1, 24, 6, 75, 
    3,  8, 5, 21, 1, 24, 8, 92, 7,  5, 0, 94, 4, 26, 6, 33, 2, 65, 
    7, 18, 2, 93, 8, 94, 6, 89, 3, 45, 1, 66, 5, 81, 4, 42, 0,  1, 
    3,  9, 2, 89, 7, 48, 8, 87, 4, 62, 0, 18, 6, 43, 5,  7, 1, 45, 
    6, 75, 2, 32, 0, 96, 1, 61, 5, 22, 3, 82, 7, 52, 4, 90, 8, 56, 
    4, 64, 5, 57, 0, 91, 7, 25, 2, 78, 6, 68, 1, 75, 8, 21, 3, 89, 
    0, 34, 4, 93, 2, 56, 8, 36, 3, 23, 5, 43, 1, 10, 6, 23, 7, 66
  };
  const int q5470[] = {
    9, 9, // Number of jobs and machines
    7, 24, 1, 69, 4, 83, 5, 16, 6, 79, 8, 33, 2,  8, 3, 78, 0, 71, 
    6, 62, 7, 18, 8, 73, 4, 60, 2, 41, 0, 31, 5, 92, 3, 78, 1, 21, 
    6, 91, 7, 85, 3, 96, 1, 57, 5, 35, 8, 27, 2,  7, 4, 39, 0, 47, 
    6, 61, 5, 35, 0,  7, 1, 37, 2, 93, 4, 34, 8, 76, 3, 43, 7,  6, 
    8, 27, 1,  9, 5, 33, 2, 89, 0, 47, 4, 21, 6, 42, 3, 89, 7, 94, 
    8, 30, 0, 41, 6, 95, 4, 45, 2, 92, 7, 89, 3, 83, 5, 95, 1,  7, 
    5, 53, 1, 38, 0, 53, 2, 55, 4, 24, 3, 45, 6, 70, 7, 62, 8, 92, 
    8, 83, 7, 99, 2, 53, 0, 55, 1, 98, 3, 33, 6, 86, 5, 93, 4, 44, 
    4, 36, 0,  2, 7, 24, 2, 21, 3, 82, 8, 64, 6, 45, 1, 50, 5, 99
  };
  const int q5471[] = {
    9, 9, // Number of jobs and machines
    0, 28, 3, 94, 7, 58, 6, 11, 8, 73, 4, 12, 2, 31, 5, 93, 1, 46, 
    0, 20, 7, 86, 1, 31, 3, 72, 5,  6, 8, 38, 4, 98, 6,  6, 2, 85, 
    0, 36, 6, 76, 8,  8, 5, 51, 7, 44, 2, 86, 1, 75, 3, 28, 4, 39, 
    0, 60, 5, 47, 8, 61, 6, 92, 4, 94, 3, 71, 2, 20, 1,  1, 7, 18, 
    4, 62, 8, 13, 3, 88, 5, 56, 1, 11, 7,  9, 2, 50, 0, 14, 6, 83, 
    2, 84, 5, 59, 8, 89, 7, 51, 1, 94, 6, 75, 3, 43, 4, 56, 0, 16, 
    6, 96, 3, 60, 4, 28, 8, 29, 7, 67, 2, 11, 5, 94, 0, 38, 1, 24, 
    2, 47, 8, 21, 6, 96, 7, 84, 1,  3, 5,  1, 0,  2, 3, 69, 4, 29, 
    2, 51, 8, 90, 0, 37, 1, 20, 7, 36, 3, 65, 4, 36, 6, 22, 5, 66
  };
  const int q5472[] = {
    9, 9, // Number of jobs and machines
    0, 70, 5, 84, 1, 72, 3, 91, 8, 48, 4, 62, 2, 14, 7, 43, 6, 90, 
    5, 20, 3,  8, 1, 83, 6, 73, 4, 44, 2, 44, 7, 27, 0, 30, 8, 81, 
    3, 70, 1, 57, 5, 54, 2,  2, 7, 12, 6, 50, 8, 51, 4, 67, 0, 71, 
    0, 36, 2, 61, 3, 15, 6, 16, 4, 28, 1, 44, 8, 94, 7, 43, 5, 36, 
    5, 26, 1, 53, 3, 61, 6, 57, 0, 36, 7, 49, 4, 62, 8, 73, 2, 96, 
    4, 54, 8, 78, 5, 56, 3, 32, 1, 42, 6, 85, 2, 29, 0, 21, 7, 47, 
    0, 41, 2, 98, 7, 91, 6, 64, 4, 74, 1, 73, 5, 25, 8, 34, 3, 90, 
    3, 71, 6,  4, 0, 33, 1, 22, 5, 37, 7, 50, 2, 86, 8, 71, 4, 35, 
    4, 86, 6, 47, 0,  6, 8, 13, 3, 14, 5, 66, 1, 73, 7, 59, 2, 53
  };
  const int q5473[] = {
    9, 9, // Number of jobs and machines
    7, 74, 4, 78, 2, 15, 1,  2, 6, 48, 8, 28, 0, 91, 3, 47, 5, 77, 
    3,  2, 1,  1, 6, 47, 4, 26, 5, 49, 2,  5, 8, 86, 0, 54, 7, 58, 
    6, 22, 3, 73, 0, 71, 7, 43, 1,  2, 2, 46, 5, 43, 4, 78, 8, 37, 
    5, 99, 3, 92, 2,  6, 1, 64, 7, 85, 8,  9, 0, 12, 6, 24, 4, 29, 
    7, 91, 6, 65, 2, 12, 5, 91, 8, 79, 4,  3, 0, 41, 3, 28, 1, 78, 
    3, 48, 0, 56, 7, 90, 1, 37, 8,  3, 2, 31, 5, 22, 6,  2, 4, 18, 
    7,  4, 5, 96, 2, 64, 8, 62, 1, 72, 0, 31, 3, 27, 4, 35, 6, 80, 
    7, 21, 4, 67, 2, 95, 0, 82, 5, 52, 3, 96, 6, 56, 8, 91, 1, 58, 
    1, 48, 6, 31, 8, 18, 0, 23, 7, 28, 5, 34, 2, 58, 3, 59, 4, 36
  };
  const int q5474[] = {
    9, 9, // Number of jobs and machines
    4, 54, 8, 14, 5, 26, 6,  7, 0, 30, 1, 92, 7, 84, 3, 84, 2, 46, 
    8, 63, 5, 43, 4, 73, 6, 22, 7, 91, 2, 18, 0, 86, 3, 70, 1, 75, 
    2, 50, 1, 70, 3, 14, 0, 57, 8, 34, 7, 28, 4, 73, 5, 58, 6, 12, 
    7, 17, 4, 24, 0, 63, 3, 10, 1, 98, 8, 38, 5, 95, 2, 24, 6, 87, 
    6, 93, 1,  8, 3, 87, 0, 18, 5,  6, 8, 53, 7, 92, 4, 58, 2, 83, 
    8, 81, 5, 56, 1, 30, 2, 71, 3, 39, 6, 32, 7, 49, 4,  3, 0, 99, 
    8, 67, 4, 98, 6, 12, 5,  2, 1, 23, 0, 69, 2, 18, 7,  9, 3,  3, 
    6,  7, 8, 11, 5, 33, 3, 83, 4, 59, 7, 31, 0, 34, 2, 92, 1, 26, 
    2, 75, 8,  4, 3, 95, 1, 64, 0, 63, 5, 94, 6, 44, 7, 87, 4, 19
  };
  const int q5475[] = {
    9, 9, // Number of jobs and machines
    2, 60, 6, 70, 1,  9, 3, 25, 0, 20, 4, 51, 7, 36, 5, 41, 8,  7, 
    4, 86, 7, 73, 1,  1, 8, 13, 0, 11, 5, 37, 3, 66, 2, 21, 6, 71, 
    5, 10, 0, 82, 6, 54, 7, 59, 8,  2, 2, 68, 3, 67, 4, 42, 1, 34, 
    3, 36, 2, 42, 5,  4, 6, 19, 1, 77, 8, 29, 0, 72, 7, 22, 4, 99, 
    7, 38, 5, 11, 4, 47, 8,  3, 0, 68, 6, 68, 3,  4, 1, 12, 2, 52, 
    5, 99, 8, 51, 3,  8, 2,  8, 4, 73, 0, 23, 7, 22, 1, 44, 6, 30, 
    7, 55, 8, 38, 1, 12, 4,  8, 2, 20, 5, 83, 0, 71, 6, 75, 3, 65, 
    7, 41, 6, 11, 8, 21, 5, 60, 4, 17, 3, 56, 2, 58, 0, 21, 1, 96, 
    6, 72, 2, 68, 1, 24, 5,  2, 7,  8, 8, 66, 4, 63, 0, 54, 3, 31
  };
  const int q5476[] = {
    9, 9, // Number of jobs and machines
    6, 77, 1, 81, 5, 48, 3, 46, 8, 14, 2, 94, 4, 49, 0, 86, 7, 65, 
    1, 65, 5, 21, 3, 91, 8, 33, 7, 90, 2, 74, 6, 92, 4, 92, 0, 24, 
    0, 68, 2, 72, 3, 73, 6, 66, 8, 42, 4, 29, 1, 61, 7,  5, 5, 17, 
    8, 72, 7, 51, 5, 78, 3, 59, 6, 95, 2, 53, 0, 27, 1, 72, 4, 68, 
    7, 91, 1, 24, 0, 15, 3, 17, 2, 87, 5, 12, 4, 70, 6, 92, 8, 16, 
    7, 88, 8, 59, 3, 10, 5, 14, 6, 12, 4, 35, 1, 84, 0, 21, 2, 46, 
    0, 78, 1, 30, 6, 65, 7, 58, 3, 28, 8, 59, 2, 65, 5, 42, 4, 56, 
    7, 31, 6, 34, 8, 46, 1, 44, 5, 36, 0, 20, 2, 53, 4, 31, 3,  6, 
    2, 15, 3, 51, 5, 50, 8, 78, 0, 30, 6, 51, 4, 19, 1, 25, 7,  1
  };
  const int q5477[] = {
    9, 9, // Number of jobs and machines
    3, 27, 6, 52, 1, 72, 4, 46, 2, 78, 8, 11, 5, 82, 0, 53, 7, 81, 
    4, 56, 8, 91, 7, 11, 5, 10, 2,  6, 6, 10, 3, 69, 0, 95, 1, 72, 
    6, 87, 8, 82, 7, 67, 4, 67, 1,  3, 0, 41, 3,  1, 2, 55, 5, 27, 
    2, 60, 6, 98, 1, 42, 0,  7, 7, 92, 5, 52, 4, 15, 8, 62, 3, 61, 
    0, 11, 3, 56, 1, 38, 7,  7, 4, 72, 5, 13, 8, 61, 2, 18, 6, 22, 
    7, 89, 1, 67, 0, 70, 2, 52, 8,  1, 3, 73, 4, 40, 5,  3, 6, 96, 
    3, 27, 4, 23, 6, 14, 0, 74, 8, 59, 5,  2, 7,  1, 1,  9, 2, 73, 
    6, 21, 2, 91, 7, 26, 3, 70, 1, 22, 0, 39, 4, 44, 8, 13, 5,  5, 
    6, 13, 7, 64, 4, 52, 8, 69, 1, 48, 2,  3, 3, 35, 0, 97, 5, 20
  };
  const int q5478[] = {
    9, 9, // Number of jobs and machines
    0, 60, 3, 79, 1, 86, 6, 92, 8, 10, 2, 45, 5, 16, 7, 62, 4, 26, 
    0, 78, 5, 93, 1, 83, 8, 89, 4, 32, 3,  4, 2, 89, 7, 28, 6, 78, 
    3, 50, 6, 35, 2, 48, 4, 62, 1, 71, 5,  9, 8, 31, 0, 86, 7, 45, 
    2, 31, 6, 58, 3, 42, 1, 18, 4, 18, 7,  1, 8, 26, 0, 90, 5, 93, 
    5, 34, 7, 41, 4, 36, 1, 18, 8, 81, 2, 16, 6, 67, 3, 64, 0, 65, 
    1, 51, 0, 55, 4,  3, 3, 50, 7, 40, 8, 47, 6, 74, 2, 47, 5,  2, 
    5, 81, 8, 59, 0, 44, 7, 46, 2, 76, 1, 71, 4, 66, 6, 94, 3,  2, 
    7, 84, 5, 32, 1, 34, 8, 86, 3, 86, 0, 82, 2, 66, 4, 41, 6, 83, 
    4, 46, 5, 94, 2, 86, 7, 86, 1, 46, 3, 78, 8, 84, 0, 43, 6, 52
  };
  const int q5479[] = {
    9, 9, // Number of jobs and machines
    2, 94, 5, 65, 0, 98, 1, 79, 6, 91, 8, 54, 4, 33, 3, 72, 7,  6, 
    6, 56, 7, 15, 2, 78, 4, 78, 8, 78, 3, 26, 0, 49, 1, 74, 5, 30, 
    6, 23, 4, 13, 1, 23, 2, 53, 3, 17, 8, 38, 5, 79, 0, 88, 7, 92, 
    7, 45, 1, 11, 6, 32, 0, 83, 5, 30, 3, 63, 2, 10, 4, 89, 8, 17, 
    3, 76, 4, 76, 6, 31, 2, 65, 7, 99, 0, 93, 5, 57, 1, 11, 8, 66, 
    4,  9, 6, 61, 3, 15, 0, 63, 5,  4, 8, 88, 1, 16, 7, 45, 2, 40, 
    7, 25, 5, 43, 0, 61, 4, 44, 8, 80, 2,  8, 3, 99, 1, 97, 6, 79, 
    7, 58, 1,  2, 6, 91, 5, 62, 4,  1, 0, 46, 2, 56, 3, 68, 8, 94, 
    3,  5, 4, 71, 0, 36, 5, 18, 7, 44, 8, 75, 2, 84, 1, 35, 6, 73
  };
  const int q5480[] = {
    9, 9, // Number of jobs and machines
    1, 50, 2, 42, 3, 86, 4, 74, 0, 92, 6, 54, 5, 20, 8, 14, 7, 51, 
    0, 66, 2, 72, 6, 49, 7, 29, 1, 94, 5, 77, 3, 61, 8, 68, 4, 53, 
    6, 11, 8,  1, 5,  4, 1, 99, 0, 54, 3, 21, 4, 51, 7, 52, 2, 10, 
    1, 58, 6, 93, 5, 55, 8, 14, 4, 26, 7, 23, 0, 38, 2, 18, 3,  9, 
    0,  1, 1, 79, 4, 91, 2, 47, 6, 54, 8, 81, 3, 23, 5, 48, 7, 42, 
    3, 11, 8, 22, 0, 47, 5, 27, 6, 71, 1, 25, 4, 23, 7, 62, 2, 47, 
    0, 78, 5, 21, 4, 31, 6, 96, 8, 28, 1, 11, 7, 34, 3, 34, 2, 70, 
    3, 56, 0, 19, 2, 53, 5, 88, 7, 51, 6, 53, 4,  9, 1, 33, 8, 43, 
    2, 39, 5, 92, 3, 21, 8, 73, 6, 89, 1, 97, 7, 53, 0, 27, 4, 13
  };
  const int q5481[] = {
    9, 9, // Number of jobs and machines
    0, 29, 8, 51, 1, 83, 7, 50, 4, 21, 5, 13, 2, 37, 6, 39, 3,  2, 
    4, 16, 0, 31, 3, 12, 1, 89, 8, 10, 7, 97, 6, 40, 2, 60, 5, 46, 
    5, 40, 0, 10, 8, 41, 3, 77, 2, 65, 7, 76, 1, 88, 4, 45, 6, 85, 
    7, 70, 5, 49, 0, 11, 8, 98, 1, 82, 2, 93, 4, 43, 6,  2, 3, 78, 
    7, 40, 0, 87, 4, 79, 2, 43, 6, 37, 8, 38, 3, 15, 1, 64, 5, 73, 
    4, 92, 7, 45, 5, 28, 3, 10, 6, 78, 8, 95, 1,  7, 0,  3, 2, 94, 
    0, 12, 8, 22, 6, 78, 5, 39, 2, 37, 7, 53, 1, 29, 4, 36, 3, 11, 
    8, 31, 1, 91, 0, 10, 6, 79, 2, 97, 3, 70, 7, 10, 5,  7, 4, 72, 
    2, 29, 7,  4, 6,  6, 8, 58, 1, 16, 5, 17, 4,  6, 0, 65, 3, 73
  };
  const int q5482[] = {
    9, 9, // Number of jobs and machines
    0, 33, 6, 30, 2, 12, 5, 11, 8, 49, 7, 22, 4, 89, 1, 17, 3, 38, 
    2, 73, 4,  4, 5, 62, 8, 63, 6, 51, 0, 65, 1, 86, 3,  4, 7, 31, 
    1, 91, 2, 76, 4, 45, 5, 88, 6,  1, 7, 19, 3, 59, 0, 68, 8, 82, 
    8, 22, 5, 73, 4, 56, 2, 47, 3, 70, 6, 15, 0, 39, 1, 23, 7,  7, 
    7, 69, 4, 96, 0, 47, 8,  5, 2, 70, 6, 38, 1, 85, 3,  9, 5, 38, 
    8, 23, 3, 46, 1,  8, 4, 89, 2, 44, 0, 48, 7, 40, 5, 55, 6, 30, 
    8, 93, 3, 73, 5, 68, 0,  6, 6,  3, 1, 24, 4, 56, 2, 27, 7, 36, 
    4, 15, 7, 57, 3, 42, 6, 39, 8, 97, 5, 88, 0, 90, 1, 34, 2, 59, 
    6, 58, 7, 59, 2, 16, 5, 80, 3, 11, 1, 13, 8, 11, 4, 60, 0, 42
  };
  const int q5483[] = {
    9, 9, // Number of jobs and machines
    5, 65, 6, 18, 7, 29, 0, 17, 3, 87, 2, 32, 8, 74, 1, 73, 4, 46, 
    7,  5, 1, 86, 3, 48, 4, 26, 0, 33, 2, 28, 8, 55, 6, 48, 5, 13, 
    2, 93, 1,  8, 4, 15, 6, 34, 5, 54, 8, 27, 3, 20, 7, 32, 0, 34, 
    7, 21, 8, 47, 3, 18, 1, 17, 6, 50, 0, 17, 4, 73, 2, 30, 5, 36, 
    3, 93, 2, 66, 1, 32, 4, 91, 0, 63, 5,  7, 8, 24, 7, 85, 6, 98, 
    4, 73, 3, 70, 6,  1, 0, 29, 1, 35, 5,  2, 8,  9, 2,  5, 7,  3, 
    1, 96, 5, 44, 2, 79, 7, 73, 8, 56, 0, 65, 4, 89, 6, 80, 3, 29, 
    1, 10, 8, 39, 7, 51, 6, 72, 3, 66, 4, 55, 2, 31, 5, 15, 0, 98, 
    2, 38, 0, 84, 3,  8, 6, 16, 5, 61, 1, 87, 4, 48, 8, 46, 7, 18
  };
  const int q5484[] = {
    9, 9, // Number of jobs and machines
    3, 29, 8, 69, 7, 96, 1, 12, 5, 68, 4, 22, 0, 52, 2,  3, 6, 38, 
    2, 90, 7, 94, 1, 45, 3, 22, 4,  9, 0, 59, 8, 96, 5,  4, 6, 27, 
    0, 25, 3, 11, 1, 33, 8, 70, 4, 44, 2, 70, 5, 98, 7, 49, 6, 83, 
    2, 57, 6, 51, 7, 43, 4, 35, 5, 18, 0, 15, 3, 14, 1, 88, 8, 85, 
    6, 78, 8, 12, 2, 85, 1, 99, 4, 42, 3, 73, 0, 56, 7, 30, 5, 55, 
    0,  2, 1, 44, 4, 13, 5, 85, 7, 67, 6, 81, 8, 20, 2, 69, 3, 18, 
    7,  2, 2, 91, 1, 15, 8, 32, 3, 13, 5, 24, 4, 32, 0, 18, 6, 69, 
    1, 98, 7, 74, 8, 90, 2, 57, 6, 94, 3, 18, 4, 90, 5, 30, 0, 99, 
    8, 74, 6, 42, 4,  8, 3, 60, 7, 92, 2, 98, 1, 46, 5, 76, 0, 70
  };
  const int q5485[] = {
    9, 9, // Number of jobs and machines
    1, 41, 5, 90, 3,  8, 6, 42, 2, 43, 7, 15, 4, 47, 0, 65, 8, 21, 
    2, 22, 4, 30, 0, 15, 5, 33, 7, 84, 1, 19, 6, 33, 8, 79, 3, 11, 
    3, 18, 5, 25, 7, 24, 8, 28, 6, 24, 2, 26, 4,  5, 0,  9, 1,  8, 
    2, 14, 3, 12, 1, 33, 5, 72, 7, 59, 0, 95, 8, 12, 4, 23, 6, 13, 
    7, 18, 8, 42, 4,  2, 5, 95, 6, 28, 3, 84, 1, 31, 2, 92, 0, 93, 
    6, 80, 8, 35, 3, 56, 0, 63, 5, 51, 2, 46, 7, 98, 1, 30, 4, 20, 
    0, 21, 6, 44, 1,  1, 3, 62, 5, 77, 4, 31, 7, 96, 2, 52, 8, 31, 
    0, 10, 6, 60, 3, 42, 2, 48, 4, 25, 7, 45, 8, 23, 1, 22, 5, 76, 
    6, 66, 3, 34, 5, 84, 1, 78, 7, 87, 0, 74, 8, 12, 2, 77, 4, 42
  };
  const int q5486[] = {
    9, 9, // Number of jobs and machines
    4, 45, 1, 97, 6, 80, 5, 63, 2,  8, 0, 49, 3, 54, 8, 86, 7, 98, 
    2, 19, 1, 80, 4, 93, 8, 99, 6, 40, 7, 68, 3, 94, 5, 33, 0, 64, 
    3, 99, 4, 29, 7, 15, 8, 48, 5, 82, 6, 50, 1, 86, 0, 89, 2,  8, 
    6, 23, 0, 28, 5, 29, 7, 84, 8, 58, 1, 25, 2, 48, 4, 87, 3, 23, 
    1,  4, 8, 15, 3, 24, 0,  1, 4, 83, 2, 41, 5, 69, 7, 61, 6, 71, 
    0,  2, 7, 14, 8, 81, 4, 27, 2, 70, 6, 42, 3, 37, 1, 37, 5, 75, 
    1, 31, 2, 10, 8,  5, 6, 59, 5, 84, 3, 31, 0, 78, 4,  7, 7, 34, 
    7,  9, 0, 41, 4, 14, 6, 94, 8, 68, 3,  1, 5, 81, 2, 62, 1,  8, 
    0, 93, 3, 43, 4, 24, 1, 40, 2, 30, 7, 78, 5, 91, 8, 86, 6, 55
  };
  const int q5487[] = {
    9, 9, // Number of jobs and machines
    7, 87, 3, 87, 0, 71, 5, 22, 1,  9, 2, 81, 8, 42, 6, 90, 4, 50, 
    2, 94, 7, 29, 0, 25, 1, 17, 5, 45, 6, 49, 8, 62, 4, 46, 3, 16, 
    6, 79, 5,  8, 1,  9, 3, 36, 8, 61, 0,  9, 2, 73, 7, 76, 4, 59, 
    1, 74, 4, 44, 2, 43, 0, 31, 7, 65, 6, 57, 3, 47, 8, 73, 5, 18, 
    0,  7, 5, 98, 6, 45, 1, 69, 3,  1, 8,  7, 2, 75, 4, 88, 7, 73, 
    5, 83, 3, 74, 6, 85, 7, 78, 8, 16, 2, 25, 1, 28, 0, 23, 4, 44, 
    3, 69, 6, 71, 1, 80, 8, 19, 2, 54, 7, 34, 5, 32, 4, 22, 0, 50, 
    8, 45, 5, 50, 3, 23, 7, 73, 1, 55, 4, 14, 0, 32, 6, 81, 2, 15, 
    1, 24, 6,  6, 2, 69, 5, 96, 0, 99, 4, 36, 7, 62, 8, 26, 3, 26
  };
  const int q5488[] = {
    9, 9, // Number of jobs and machines
    3, 88, 2, 43, 0, 84, 1, 29, 4, 50, 7, 79, 5, 93, 8, 60, 6, 99, 
    8, 30, 7, 15, 0, 46, 1, 27, 5, 54, 2, 97, 3, 34, 6, 85, 4,  5, 
    2, 73, 1, 10, 3, 94, 6,  7, 0, 14, 5, 47, 4, 97, 8, 87, 7, 68, 
    4, 67, 5, 95, 6, 75, 7, 35, 1, 15, 3, 45, 8, 22, 0, 84, 2, 25, 
    2,  5, 3, 59, 8, 63, 1, 58, 5, 52, 4, 74, 6, 27, 7, 99, 0, 61, 
    0, 10, 7, 59, 3,  2, 4, 16, 6, 73, 8, 51, 2, 97, 1, 28, 5, 71, 
    4, 21, 3, 50, 6, 26, 1,  9, 5, 50, 2, 37, 7, 49, 8, 43, 0, 57, 
    5, 98, 8, 71, 6, 78, 3, 37, 4, 87, 1, 19, 7, 42, 0, 44, 2, 93, 
    0, 42, 8, 49, 2, 95, 4, 93, 6, 44, 3, 36, 1,  8, 7, 70, 5, 33
  };
  const int q5489[] = {
    9, 9, // Number of jobs and machines
    0, 10, 5, 28, 2, 67, 1, 24, 8, 22, 6, 68, 3, 46, 4, 98, 7, 38, 
    4, 48, 6, 76, 1, 23, 7,  5, 5, 68, 8, 93, 2, 52, 3, 26, 0, 46, 
    8,  4, 0, 33, 3, 95, 2, 24, 4,  4, 7, 96, 6, 95, 1, 24, 5, 20, 
    4, 57, 0, 79, 5,  6, 8, 57, 3, 57, 2, 36, 6, 73, 1, 11, 7, 92, 
    2, 86, 0, 44, 1, 81, 8, 98, 4, 27, 6, 65, 7, 86, 3, 78, 5, 45, 
    0, 70, 3,  1, 7, 94, 5, 93, 8, 23, 2, 20, 1, 91, 6, 75, 4, 26, 
    1, 71, 0, 41, 7, 89, 2, 46, 6, 11, 5,  7, 8, 86, 4, 76, 3, 64, 
    2, 97, 7, 36, 1, 52, 8, 31, 6, 55, 0, 32, 4, 41, 5, 64, 3, 43, 
    2, 55, 1, 26, 8, 58, 0, 52, 3, 51, 4, 97, 7, 19, 6, 24, 5, 62
  };
  const int q5490[] = {
    9, 9, // Number of jobs and machines
    7, 48, 1, 65, 8, 94, 6, 31, 4, 52, 5, 79, 2, 16, 3,  3, 0, 52, 
    5, 35, 0, 84, 6, 90, 3, 90, 4, 89, 8, 76, 2,  7, 7,  8, 1, 43, 
    5, 91, 7, 80, 6, 33, 4, 95, 2, 21, 8, 10, 3, 37, 1, 89, 0, 91, 
    5, 52, 6, 16, 2, 14, 0, 77, 8, 36, 4, 13, 7, 79, 3, 63, 1, 34, 
    5, 19, 7, 21, 3, 46, 0, 33, 1, 80, 2, 79, 8, 67, 6, 17, 4, 94, 
    0, 49, 5, 55, 8, 18, 1, 83, 6, 73, 7, 88, 2, 65, 4, 74, 3, 86, 
    0, 39, 7, 72, 4, 66, 5, 68, 6, 18, 2, 65, 3, 97, 8, 93, 1,  4, 
    8, 98, 4, 10, 7,  9, 0, 90, 5,  3, 6, 21, 3, 58, 1, 28, 2, 67, 
    8, 55, 5,  3, 2, 90, 6, 44, 0, 32, 7, 61, 4, 44, 3,  9, 1, 56
  };
  const int q5491[] = {
    9, 9, // Number of jobs and machines
    6, 26, 7, 26, 1,  2, 2, 71, 5, 45, 8, 19, 3, 45, 4, 20, 0, 60, 
    6, 89, 2, 19, 5,  5, 8, 70, 4, 60, 3, 61, 0, 36, 7, 81, 1, 37, 
    8, 92, 6, 84, 0, 44, 1,  8, 2, 84, 7, 56, 4, 89, 3, 28, 5,  6, 
    3,  7, 1, 96, 8, 35, 4, 29, 5, 48, 7, 59, 0, 83, 6, 50, 2, 95, 
    2, 94, 6, 98, 8, 21, 7, 27, 3, 56, 0, 55, 5, 78, 4, 19, 1, 66, 
    0, 80, 2, 57, 8, 23, 5, 32, 3, 29, 7, 21, 1, 44, 6, 33, 4, 30, 
    4, 87, 8, 26, 5, 28, 1, 77, 0, 25, 3, 40, 7, 24, 2,  1, 6, 31, 
    3, 77, 7, 93, 2, 41, 1, 17, 6, 44, 4, 58, 8,  9, 0, 28, 5, 68, 
    5, 75, 4, 78, 8, 34, 7, 59, 0, 75, 6, 32, 1, 65, 3, 66, 2, 83
  };
  const int q5492[] = {
    9, 9, // Number of jobs and machines
    7, 84, 6, 23, 5, 57, 8, 49, 1, 93, 4, 70, 3,  2, 2, 39, 0, 98, 
    7, 61, 2, 38, 5, 45, 1,  8, 0, 65, 4, 65, 6, 28, 3, 69, 8, 63, 
    0, 75, 3, 66, 6, 95, 2, 77, 7, 48, 5, 20, 1, 77, 4, 45, 8, 19, 
    1, 71, 8, 32, 5,  3, 0, 44, 2, 33, 6, 83, 7, 69, 4, 47, 3, 32, 
    1, 41, 3, 64, 8, 22, 4, 32, 6, 22, 0, 87, 2,  4, 5, 83, 7, 90, 
    4, 71, 5, 25, 8, 44, 2, 51, 3, 72, 6, 77, 0, 57, 7, 99, 1, 70, 
    7, 74, 4, 82, 2, 81, 6, 79, 1, 67, 3, 73, 8, 20, 5, 22, 0, 31, 
    1, 67, 6, 77, 4, 75, 0, 22, 8, 73, 5, 85, 3, 18, 2, 65, 7,  6, 
    4, 75, 7, 73, 2, 85, 8, 13, 6, 90, 0, 39, 1, 39, 5, 25, 3, 35
  };
  const int q5493[] = {
    9, 9, // Number of jobs and machines
    2, 62, 1, 24, 0, 83, 3, 53, 6, 29, 7, 47, 8,  6, 4, 37, 5, 86, 
    1, 54, 2, 43, 4, 49, 5, 65, 0, 30, 7, 38, 3, 85, 6, 35, 8,  6, 
    3,  2, 1, 92, 4, 47, 8, 65, 0, 23, 5, 58, 2, 78, 7, 23, 6, 66, 
    1,  4, 3, 97, 4, 81, 6, 65, 0, 49, 5, 28, 2, 21, 7, 78, 8, 16, 
    6, 40, 5, 66, 2, 14, 3, 68, 0, 36, 1, 99, 7, 38, 4, 47, 8, 59, 
    0, 96, 8, 56, 5, 38, 2, 71, 6,  7, 4, 57, 3, 26, 1, 68, 7, 95, 
    4, 33, 6, 83, 5, 26, 8, 78, 3, 43, 7, 20, 0, 16, 1, 53, 2, 67, 
    0, 86, 1, 51, 3, 19, 4, 24, 7,  9, 2,  5, 6, 98, 8, 59, 5, 29, 
    4, 83, 1, 67, 7, 84, 6, 73, 0, 67, 2, 93, 3, 21, 5, 68, 8, 63
  };
  const int q5494[] = {
    9, 9, // Number of jobs and machines
    1, 36, 4, 18, 6, 57, 7, 73, 5, 32, 2, 44, 3, 44, 0, 58, 8, 28, 
    6, 29, 2, 11, 3, 78, 5, 85, 4, 63, 1, 11, 0, 44, 7, 71, 8, 82, 
    8, 44, 6,  5, 4, 80, 1, 11, 5, 43, 0, 81, 7, 40, 2, 82, 3, 94, 
    2, 43, 6, 13, 0, 86, 5, 54, 8,  6, 7, 13, 1, 63, 4, 17, 3, 29, 
    4, 76, 8, 69, 5, 80, 1, 37, 7, 40, 0, 15, 6, 28, 2, 63, 3, 73, 
    3,  6, 6, 68, 7, 56, 4, 30, 5, 38, 2,  1, 1, 73, 0, 96, 8, 21, 
    6, 53, 5, 70, 7, 50, 3, 45, 4, 10, 1, 57, 2, 16, 0, 24, 8, 24, 
    1, 51, 0,  9, 8, 45, 7, 87, 4, 37, 2, 47, 6, 81, 3, 25, 5, 46, 
    4,  2, 1, 61, 0, 27, 2, 69, 8, 25, 3, 69, 7,  9, 6, 70, 5, 47
  };
  const int q5495[] = {
    9, 9, // Number of jobs and machines
    3, 13, 6, 25, 5, 40, 7, 32, 2, 81, 1, 31, 4, 25, 8, 94, 0, 71, 
    8,  5, 1, 18, 6, 39, 2, 44, 5, 70, 4, 11, 7, 78, 0, 58, 3, 89, 
    0, 32, 6, 44, 5, 39, 1, 26, 2, 17, 8, 81, 3, 42, 4, 66, 7, 32, 
    1, 58, 3, 54, 5, 70, 0, 67, 7, 34, 8, 55, 4, 23, 6, 99, 2, 28, 
    3, 13, 5, 88, 8, 43, 0, 92, 2, 57, 1, 69, 6, 74, 7, 82, 4, 25, 
    8, 50, 4, 30, 7, 31, 3,  4, 6, 84, 5, 64, 1, 76, 2, 75, 0, 42, 
    1,  5, 3, 28, 2, 69, 5, 34, 7, 81, 4, 58, 0, 76, 8, 96, 6,  2, 
    6, 19, 5, 26, 3, 40, 1, 38, 2, 58, 4, 31, 8, 40, 7, 38, 0, 19, 
    7, 67, 1, 40, 5,  3, 4, 79, 3, 71, 6, 40, 2, 31, 0, 11, 8, 49
  };
  const int q5496[] = {
    9, 9, // Number of jobs and machines
    1, 62, 7, 55, 6, 93, 2, 13, 5, 66, 4, 11, 8, 97, 3, 69, 0, 73, 
    5, 99, 0, 86, 7, 38, 3, 30, 2, 26, 8, 21, 6, 17, 1, 98, 4, 25, 
    6, 19, 0, 41, 1, 17, 7, 25, 4, 42, 5,  8, 3, 77, 8, 23, 2, 40, 
    1, 19, 6, 42, 8, 64, 7, 31, 0, 77, 2, 32, 4, 90, 5, 27, 3, 37, 
    4, 16, 5, 52, 2, 39, 7, 29, 1,  8, 0, 32, 8,  6, 3, 60, 6, 44, 
    3, 51, 0, 46, 7,  3, 5,  6, 4, 15, 1, 75, 8, 81, 2, 46, 6,  1, 
    2, 95, 3, 45, 4, 67, 8, 55, 0, 89, 7, 54, 5, 33, 1, 85, 6,  8, 
    5, 80, 1, 71, 6, 55, 0, 61, 2, 40, 3, 39, 8, 12, 4, 52, 7, 54, 
    1, 44, 7, 17, 2, 41, 3, 66, 4, 28, 5, 94, 6, 14, 8, 58, 0, 81
  };
  const int q5497[] = {
    9, 9, // Number of jobs and machines
    7, 49, 2, 81, 1, 55, 4, 77, 5, 27, 3, 18, 0, 72, 6, 32, 8, 79, 
    3, 77, 8, 34, 0, 14, 2, 62, 1, 42, 5, 96, 6, 12, 4, 31, 7, 49, 
    2, 75, 7,  8, 3, 43, 6, 60, 4, 28, 1, 90, 5, 14, 0, 76, 8, 27, 
    0, 51, 6, 80, 1, 40, 4, 39, 2, 76, 5, 40, 3, 29, 8, 81, 7, 70, 
    2, 55, 3, 11, 8, 67, 1, 56, 0, 13, 4, 62, 6, 28, 7, 93, 5, 74, 
    7, 65, 5, 53, 8, 85, 4, 15, 1, 66, 2, 34, 3, 59, 6, 89, 0, 83, 
    7, 58, 1,  4, 5, 36, 2, 81, 3, 52, 4, 49, 8, 67, 0,  5, 6, 53, 
    8, 38, 1, 58, 2, 84, 7, 37, 0, 37, 4, 63, 6, 63, 3, 45, 5, 21, 
    1, 28, 3, 88, 2, 13, 6, 95, 5, 66, 0, 72, 8, 38, 7, 38, 4, 45
  };
  const int q5498[] = {
    9, 9, // Number of jobs and machines
    1, 18, 2, 34, 3, 91, 7, 79, 6, 68, 8, 85, 5, 27, 4, 85, 0,  8, 
    8, 81, 7, 70, 5, 63, 0, 99, 6, 62, 4, 48, 2, 71, 3, 94, 1, 50, 
    8, 10, 1, 71, 3, 79, 5, 69, 0, 69, 7, 52, 4, 48, 2, 16, 6, 99, 
    3, 21, 7, 90, 0, 36, 8,  8, 5, 71, 2,  9, 1, 23, 6, 62, 4, 45, 
    4, 50, 1, 42, 2, 75, 3, 98, 5, 83, 8, 45, 6, 34, 7, 30, 0, 15, 
    1, 87, 5, 90, 8, 20, 2, 38, 7, 79, 0, 90, 3, 51, 4, 58, 6,  8, 
    5, 28, 8,  5, 2, 31, 4, 61, 7, 44, 1, 40, 6, 25, 0, 59, 3, 94, 
    4, 28, 3, 79, 5, 26, 8, 60, 2, 44, 1, 68, 6, 38, 0, 12, 7, 91, 
    5, 84, 1, 76, 8, 54, 2, 85, 6,  8, 7, 17, 0, 10, 3, 14, 4, 32
  };
  const int q5499[] = {
    9, 9, // Number of jobs and machines
    1, 37, 6,  6, 5, 89, 4, 19, 2,  5, 8, 61, 3, 38, 7, 30, 0, 89, 
    8, 94, 1,  9, 3, 19, 6, 86, 4, 98, 5, 38, 2, 15, 7, 24, 0, 80, 
    8, 65, 6, 48, 7, 28, 5, 55, 1, 17, 2, 53, 3, 30, 0, 19, 4, 32, 
    1, 77, 2, 55, 0, 79, 6, 31, 3, 30, 8, 81, 4, 54, 5, 96, 7, 32, 
    3, 77, 1, 98, 4, 36, 8, 79, 6, 50, 2, 96, 5, 41, 7, 86, 0, 56, 
    4, 95, 3, 15, 0, 41, 1, 31, 5, 38, 7, 52, 6, 93, 8, 64, 2, 76, 
    0,  7, 4, 54, 5, 16, 2, 61, 3, 20, 7, 62, 8, 55, 1, 17, 6, 22, 
    3, 39, 0, 67, 2, 84, 7, 60, 4, 12, 5, 37, 8, 47, 1, 39, 6, 66, 
    2, 47, 4,  8, 7, 91, 6, 53, 5, 20, 8, 13, 3, 67, 0, 30, 1, 91
  };
  const int q5500[] = {
    9, 9, // Number of jobs and machines
    4, 19, 2, 65, 6, 60, 5, 54, 1, 67, 7, 14, 0, 69, 8, 68, 3, 34, 
    5, 39, 7, 50, 8, 71, 6, 48, 3, 42, 2, 43, 0, 17, 4, 10, 1, 33, 
    4, 22, 1, 24, 8, 44, 2, 92, 7, 48, 0,  3, 5,  3, 6, 40, 3, 39, 
    4, 34, 8, 26, 1, 49, 3, 64, 5, 40, 7, 42, 0, 35, 2,  5, 6, 33, 
    0, 17, 4, 36, 6, 19, 8, 24, 2, 27, 7,  5, 3, 21, 1, 75, 5, 28, 
    7,  1, 3, 93, 0, 75, 4, 69, 5, 83, 6, 40, 8, 69, 1, 93, 2,  7, 
    8, 55, 6, 13, 2, 19, 0, 37, 4, 40, 3, 79, 5, 48, 1, 57, 7, 22, 
    1, 51, 0, 20, 5, 96, 7, 66, 2, 61, 6, 20, 8, 75, 4, 53, 3, 13, 
    4,  5, 1, 92, 8, 71, 3, 25, 6, 30, 0, 39, 7, 49, 5, 44, 2, 42
  };
  const int q5501[] = {
    9, 9, // Number of jobs and machines
    1, 29, 3, 99, 5, 65, 4, 76, 0, 84, 2, 33, 6, 38, 7, 18, 8, 82, 
    5, 92, 7, 14, 1, 81, 0,  9, 2, 43, 6, 64, 3, 58, 4, 71, 8, 44, 
    8, 35, 7, 17, 2, 47, 1, 86, 4, 83, 5, 13, 0, 63, 3, 30, 6, 42, 
    2, 96, 4, 92, 0, 83, 5, 78, 8, 66, 3, 53, 7, 16, 1, 46, 6, 33, 
    7, 94, 8, 12, 0, 59, 2, 51, 4, 22, 3, 34, 1, 31, 5, 37, 6, 76, 
    2, 46, 8,  5, 0, 28, 1, 68, 6, 75, 4, 67, 3, 88, 7, 82, 5, 38, 
    7, 66, 0, 78, 3, 43, 5, 91, 1, 13, 2, 87, 4, 38, 6, 20, 8, 56, 
    3, 97, 7,  8, 5, 85, 1, 38, 8, 69, 4, 95, 6, 83, 0, 88, 2,  9, 
    6, 84, 3, 20, 7,  2, 0, 98, 8, 83, 4, 27, 2, 60, 5, 97, 1, 81
  };
  const int q5502[] = {
    9, 9, // Number of jobs and machines
    6, 96, 3,  5, 8, 90, 4, 45, 0, 75, 1, 52, 7, 61, 2, 34, 5,  2, 
    6, 76, 1, 42, 7, 91, 5, 27, 2,  9, 4, 85, 3, 70, 0,  4, 8, 58, 
    2, 14, 5, 94, 0,  6, 3, 35, 4, 42, 6, 94, 1, 61, 8, 20, 7,  4, 
    0, 86, 6, 58, 1, 73, 7, 34, 3, 31, 8, 77, 2, 74, 5,  1, 4, 75, 
    8, 28, 1, 96, 4, 18, 0, 72, 6, 89, 7, 54, 2, 48, 5, 48, 3, 78, 
    0, 65, 3, 51, 5, 33, 2, 89, 1, 53, 7, 14, 6,  9, 4, 78, 8, 51, 
    8, 29, 4, 18, 7, 34, 0, 91, 5, 99, 2, 85, 1, 88, 3, 82, 6, 68, 
    5, 13, 2, 59, 3, 68, 0, 32, 8, 41, 1, 92, 4, 53, 7, 37, 6, 79, 
    0, 63, 6, 16, 3, 58, 7, 57, 4, 88, 8, 25, 2, 16, 1, 91, 5, 38
  };
  const int q5503[] = {
    9, 9, // Number of jobs and machines
    6, 36, 0,  2, 4, 91, 8, 93, 5, 59, 7, 19, 3, 97, 2, 17, 1, 71, 
    5,  3, 8, 44, 4, 31, 7,  3, 0, 94, 2, 43, 6, 68, 3, 46, 1, 69, 
    5,  1, 6, 46, 8, 32, 1, 59, 2, 60, 4, 87, 0, 35, 7, 91, 3, 69, 
    8, 97, 5, 95, 1, 24, 0, 92, 6, 23, 2,  2, 4, 63, 7, 32, 3, 75, 
    2, 49, 4, 21, 1, 47, 0, 23, 8, 89, 6, 46, 3, 76, 5, 53, 7,  8, 
    0, 12, 8, 61, 7, 17, 2, 24, 1, 81, 3, 41, 5,  7, 4, 75, 6, 20, 
    2,  5, 3,  4, 5, 74, 6, 79, 1, 74, 4, 97, 8, 58, 7, 97, 0, 72, 
    2, 45, 6, 67, 5,  5, 1, 89, 4, 57, 3, 87, 8, 45, 7, 55, 0,  8, 
    5,  4, 3,  7, 7, 57, 2, 68, 6, 48, 4, 87, 8, 24, 1, 54, 0, 91
  };
  const int q5504[] = {
    9, 9, // Number of jobs and machines
    4, 67, 2, 48, 6, 98, 7, 94, 3, 63, 0, 94, 8, 15, 1, 55, 5, 36, 
    6, 72, 4, 85, 0, 32, 3,  1, 2, 30, 8, 13, 7, 27, 1, 89, 5, 83, 
    4, 60, 0, 96, 8, 20, 7, 84, 6, 88, 1, 60, 3,  2, 2, 14, 5,  1, 
    2, 90, 1, 67, 4, 92, 7, 77, 0, 68, 5, 84, 6, 52, 3, 95, 8, 10, 
    1, 82, 2, 36, 5, 57, 8, 10, 6, 26, 4, 73, 0, 86, 3, 25, 7, 18, 
    0, 67, 2,  8, 3, 84, 4, 57, 1, 10, 6, 85, 5, 48, 8, 71, 7, 25, 
    1, 60, 7, 85, 2,  2, 3, 36, 5, 31, 6, 69, 8,  2, 0,  2, 4, 50, 
    1, 37, 0, 28, 4, 98, 5, 88, 2, 91, 3, 45, 8, 29, 6,  4, 7, 18, 
    5,  7, 7, 54, 3, 55, 6, 94, 2, 78, 8, 79, 4,  2, 0, 58, 1,  7
  };
  const int q5505[] = {
    9, 9, // Number of jobs and machines
    6, 17, 0, 97, 4,  9, 3, 90, 5, 35, 8, 93, 2,  3, 1, 16, 7, 27, 
    1, 92, 6, 65, 8, 33, 0, 72, 7, 22, 5, 26, 4, 59, 3, 65, 2, 44, 
    6, 62, 5, 49, 1, 35, 8, 35, 0, 46, 7, 23, 2, 49, 3, 58, 4, 71, 
    4, 33, 8, 12, 0, 17, 1, 96, 7, 30, 6, 90, 2, 92, 3, 84, 5, 48, 
    6, 31, 5,  5, 1, 89, 4, 49, 7, 61, 3, 66, 8, 93, 2, 12, 0, 63, 
    5, 10, 8, 12, 3, 29, 7, 11, 2, 43, 1, 62, 6, 17, 0, 24, 4, 20, 
    1, 43, 3, 81, 8, 47, 4,  9, 2, 49, 0, 65, 6,  8, 7, 23, 5, 71, 
    4, 82, 8, 98, 3, 47, 7, 25, 2, 86, 1, 15, 5, 88, 6, 99, 0, 19, 
    5, 57, 4, 67, 2, 92, 7, 77, 6,  7, 8, 34, 0,  9, 3, 97, 1, 23
  };
  const int q5506[] = {
    9, 9, // Number of jobs and machines
    0, 71, 8, 75, 1,  4, 7, 60, 2, 98, 3, 70, 4, 71, 5, 73, 6, 48, 
    2, 31, 1, 42, 6, 65, 4, 23, 3, 48, 7, 58, 8, 75, 5, 74, 0, 20, 
    3, 79, 2, 45, 1, 14, 0, 99, 8, 91, 6, 37, 7, 88, 5, 30, 4, 51, 
    2, 86, 7, 98, 5, 51, 8, 25, 3, 13, 1,  9, 4, 47, 6, 76, 0, 31, 
    6, 57, 5, 24, 1, 66, 2,  7, 0, 98, 8, 78, 3, 95, 4, 91, 7, 22, 
    8, 25, 5, 26, 6, 61, 4, 17, 3, 84, 0, 94, 1,  2, 7, 91, 2, 12, 
    6,  7, 8, 28, 3, 74, 5, 60, 4, 15, 7, 61, 1, 13, 0, 36, 2, 36, 
    5, 76, 8, 64, 6,  5, 1, 28, 0, 89, 3, 35, 4, 25, 7, 18, 2,  6, 
    8, 65, 1, 75, 2, 30, 4, 92, 7, 55, 0, 51, 6,  7, 3, 92, 5, 51
  };
  const int q5507[] = {
    9, 9, // Number of jobs and machines
    1, 48, 7, 36, 6, 76, 8, 77, 0, 59, 5, 55, 3, 70, 4, 61, 2, 72, 
    7, 86, 3,  5, 2, 65, 4, 18, 0, 61, 6, 15, 1, 17, 8, 86, 5, 67, 
    1, 12, 0,  1, 8, 44, 7, 43, 6, 35, 5,  9, 4, 63, 2, 12, 3, 27, 
    5, 39, 0, 27, 2, 76, 4, 74, 7, 45, 3, 20, 1, 35, 8, 31, 6, 15, 
    4, 69, 5, 36, 3, 23, 1, 94, 6, 19, 0, 63, 7, 13, 8, 26, 2, 58, 
    5, 71, 3, 46, 6, 72, 4, 26, 7, 69, 0, 48, 2, 41, 8,  6, 1, 62, 
    2, 20, 6, 14, 1, 91, 8, 82, 7,  9, 4, 98, 0, 35, 3, 10, 5, 52, 
    7, 69, 4, 77, 8, 73, 6, 53, 2, 40, 5, 40, 0, 82, 1,  2, 3, 42, 
    7, 19, 6, 16, 1, 12, 5, 45, 3, 65, 8, 20, 0, 23, 2, 60, 4, 57
  };
  const int q5508[] = {
    9, 9, // Number of jobs and machines
    1, 15, 7, 11, 5, 87, 4, 23, 2, 22, 8, 62, 6, 43, 3,  5, 0, 46, 
    5,  3, 2, 54, 0, 72, 4, 39, 1, 63, 8, 50, 3, 40, 7, 26, 6, 22, 
    3, 48, 7, 57, 1, 38, 0, 53, 2, 18, 6, 60, 8, 96, 4, 17, 5, 40, 
    2, 91, 1, 70, 7, 73, 0, 31, 4, 97, 8,  3, 3, 69, 6, 81, 5, 11, 
    1, 39, 4, 42, 6, 75, 7, 44, 0, 74, 5, 91, 8,  4, 3,  7, 2,  6, 
    1, 26, 5, 41, 0, 87, 2, 65, 8, 84, 4, 82, 3, 70, 6,  2, 7, 69, 
    3, 68, 4, 45, 2, 79, 5,  3, 7, 80, 1, 96, 8, 22, 0, 12, 6, 26, 
    6, 51, 8, 19, 7, 71, 1, 76, 2, 24, 4, 77, 0, 33, 5, 93, 3, 92, 
    8, 62, 6, 15, 1, 49, 0,  9, 3, 52, 4, 72, 2, 34, 7, 42, 5, 26
  };
  const int q5509[] = {
    9, 9, // Number of jobs and machines
    5, 75, 0, 84, 7, 37, 6, 93, 4,  8, 1, 84, 2, 47, 8, 87, 3, 58, 
    6,  4, 1, 33, 4, 28, 0, 53, 5, 46, 3, 20, 7, 81, 8, 95, 2, 41, 
    5, 65, 2, 54, 8, 37, 6, 16, 1,  1, 0, 12, 7, 57, 4, 16, 3, 44, 
    8, 39, 7, 91, 6, 47, 2, 81, 0, 78, 5,  2, 3, 64, 1, 59, 4, 30, 
    2, 54, 1, 62, 3, 50, 8, 26, 0, 26, 7, 64, 4, 77, 6, 35, 5, 88, 
    5, 57, 6, 23, 2, 23, 8, 55, 7, 45, 0, 29, 1,  3, 4, 99, 3, 70, 
    6, 12, 4, 20, 8, 69, 7, 65, 3,  3, 1, 13, 0, 52, 5, 54, 2, 99, 
    1, 94, 2, 56, 3, 22, 6, 17, 4, 79, 0, 26, 8, 36, 5, 37, 7,  6, 
    8, 39, 7, 61, 0, 59, 3,  8, 4, 19, 1, 72, 5,  9, 6, 76, 2, 41
  };
  const int q5510[] = {
    9, 9, // Number of jobs and machines
    1, 40, 4, 75, 6, 46, 7, 26, 0, 80, 2, 63, 5, 11, 8,  3, 3, 50, 
    1, 95, 3, 83, 0, 21, 7, 91, 8, 44, 4, 31, 6, 19, 2, 52, 5, 56, 
    0, 93, 3, 41, 1, 21, 7, 97, 2, 43, 5, 87, 6, 42, 4,  5, 8, 58, 
    3, 48, 0, 24, 2, 90, 1, 78, 4, 94, 5, 70, 6, 20, 7, 62, 8, 78, 
    8, 28, 2, 68, 3, 63, 0, 48, 6, 69, 4, 64, 5, 27, 1, 74, 7, 82, 
    8,  7, 5,  1, 1, 40, 6, 46, 0, 56, 4, 90, 3, 33, 7, 67, 2, 81, 
    1, 30, 2, 90, 8, 66, 7, 55, 4, 88, 6, 55, 0, 56, 3, 86, 5, 46, 
    0, 62, 8, 35, 3, 46, 7, 96, 4,  7, 5, 86, 1, 33, 2, 55, 6, 77, 
    2, 77, 4, 25, 5, 89, 6, 39, 8, 35, 7, 51, 1,  6, 0, 81, 3, 17
  };
  const int q5511[] = {
    9, 9, // Number of jobs and machines
    7, 17, 2,  6, 8, 21, 5, 49, 3, 70, 0, 13, 4, 99, 1, 29, 6, 22, 
    7, 16, 5, 67, 4, 35, 3, 45, 8, 15, 2, 77, 0,  9, 6, 40, 1,  5, 
    4, 75, 3, 52, 5, 86, 0, 49, 7, 24, 1, 35, 2, 90, 6, 21, 8, 48, 
    8, 38, 4, 96, 5, 77, 1,  6, 3, 75, 2, 94, 6, 56, 7, 11, 0, 90, 
    7, 53, 8,  1, 0, 56, 4, 21, 5, 35, 3, 90, 1, 21, 2, 29, 6, 26, 
    0, 18, 7, 45, 5,  4, 3, 53, 8, 83, 4, 95, 2, 13, 6, 14, 1, 83, 
    2, 30, 4,  6, 3, 29, 0, 44, 7,  5, 6, 45, 8, 57, 5, 88, 1, 12, 
    6, 72, 5, 57, 1, 44, 0, 73, 8, 42, 7, 46, 3,  4, 2, 83, 4, 17, 
    3,  9, 2, 75, 1, 25, 6, 67, 0,  1, 4, 95, 7, 73, 5, 58, 8, 61
  };
  const int q5512[] = {
    9, 9, // Number of jobs and machines
    5, 90, 2, 12, 3, 91, 4, 60, 1, 69, 8,  6, 6, 76, 7, 71, 0, 86, 
    4, 64, 3, 47, 8, 82, 0, 94, 1, 36, 5, 92, 2, 62, 6,  8, 7, 69, 
    7, 12, 2, 19, 6, 70, 0, 78, 5, 12, 3, 33, 1, 97, 8, 21, 4, 30, 
    4, 10, 3, 56, 1, 88, 7, 44, 8, 38, 2, 49, 5, 22, 0, 63, 6, 97, 
    7, 66, 6, 73, 2, 15, 0,  1, 4, 87, 3, 16, 1, 58, 5, 32, 8, 63, 
    4, 27, 0, 77, 2, 12, 1, 85, 7, 88, 5, 62, 8, 39, 6, 16, 3, 50, 
    6, 50, 1, 16, 8, 51, 5, 47, 4, 65, 2, 78, 0, 21, 7, 82, 3, 96, 
    7,  7, 6, 30, 4,  2, 0,  2, 2, 40, 8, 11, 1, 48, 3, 19, 5, 28, 
    4, 71, 5, 57, 7, 37, 3, 27, 8, 19, 6, 70, 2, 74, 1, 46, 0, 36
  };
  const int q5513[] = {
    9, 9, // Number of jobs and machines
    3,  8, 1, 58, 8, 76, 2, 28, 6, 99, 4, 62, 5, 99, 0, 36, 7, 41, 
    0, 13, 1, 82, 3,  5, 7, 20, 6, 35, 2, 92, 5, 78, 4, 61, 8, 39, 
    2, 71, 8, 82, 0, 90, 5, 41, 3, 48, 1, 61, 6, 49, 4, 33, 7, 10, 
    0, 32, 5,  6, 3, 30, 2, 21, 6, 48, 7,  3, 1,  8, 8, 69, 4, 30, 
    3, 36, 2, 13, 5, 95, 7, 72, 6, 52, 1, 45, 4, 93, 8, 54, 0, 12, 
    5,  4, 1, 47, 2, 35, 8, 60, 0, 12, 3, 81, 6, 47, 7, 80, 4, 44, 
    7, 27, 0, 73, 2, 87, 3, 56, 4, 31, 8, 16, 1, 84, 6, 20, 5, 34, 
    4,  2, 1, 92, 7, 38, 3,  8, 6, 11, 0, 15, 8, 23, 2, 91, 5, 36, 
    4, 25, 3, 51, 0, 91, 1, 35, 6, 82, 2, 46, 7, 65, 5, 20, 8, 91
  };
  const int q5514[] = {
    9, 9, // Number of jobs and machines
    8, 18, 3, 69, 1, 78, 4, 52, 2, 43, 6, 69, 7, 46, 5, 69, 0, 55, 
    3, 70, 0, 32, 2, 44, 6, 88, 4,  1, 1,  2, 5, 21, 7,  3, 8, 19, 
    1, 65, 2, 99, 6, 51, 3,  3, 8, 50, 0,  1, 5, 82, 7, 87, 4, 26, 
    5, 22, 2, 44, 3, 14, 7, 81, 8, 36, 1, 70, 6, 91, 0, 50, 4, 26, 
    3, 27, 2, 32, 1, 87, 7, 63, 4, 62, 0, 73, 8, 38, 6, 12, 5,  9, 
    6,  9, 8, 76, 3, 58, 0, 60, 1, 66, 7, 12, 2, 83, 4, 19, 5, 83, 
    0, 43, 5, 36, 1, 46, 6, 61, 2, 26, 3, 72, 7, 83, 8, 32, 4, 18, 
    5, 77, 7, 85, 4, 28, 0, 52, 8, 23, 3, 11, 1, 70, 2, 36, 6, 16, 
    2, 27, 0, 35, 3, 77, 6, 89, 7, 65, 8,  8, 4, 64, 5, 83, 1, 96
  };
  const int q5515[] = {
    9, 9, // Number of jobs and machines
    6, 66, 8, 29, 0, 71, 5, 40, 3, 36, 7, 25, 1, 58, 2, 84, 4,  9, 
    4, 70, 2, 32, 0, 64, 6, 84, 3, 38, 8,  7, 5, 17, 7, 65, 1, 73, 
    8, 74, 0, 38, 7, 75, 6, 90, 5, 30, 4, 45, 1, 87, 2, 12, 3, 26, 
    8, 44, 5, 50, 6, 58, 7, 10, 0, 32, 1, 92, 2, 98, 3, 88, 4, 68, 
    0, 71, 3, 13, 1, 67, 5, 11, 8, 87, 6, 18, 2, 80, 7, 44, 4, 87, 
    0, 44, 8, 65, 2, 96, 3, 29, 5, 94, 6,  8, 4, 37, 7, 12, 1, 33, 
    2, 13, 4, 63, 7, 60, 5, 20, 3, 99, 1, 52, 8, 99, 6, 66, 0, 41, 
    1, 47, 6, 73, 0, 48, 8, 70, 2, 45, 4, 42, 7, 74, 3, 47, 5, 28, 
    8, 16, 3, 38, 4,  8, 7, 94, 6, 96, 5, 36, 2,  2, 1, 50, 0, 92
  };
  const int q5516[] = {
    9, 9, // Number of jobs and machines
    0, 49, 1, 44, 4, 86, 5, 29, 3, 93, 2, 78, 7, 32, 6, 19, 8, 19, 
    8, 73, 5, 62, 2, 36, 7,  8, 0, 89, 6, 93, 1, 67, 4, 60, 3, 74, 
    0, 34, 3, 57, 4, 97, 8, 22, 6, 46, 7, 37, 5, 96, 2, 11, 1, 90, 
    8, 14, 1,  9, 6, 57, 4, 39, 3, 51, 7, 19, 5, 49, 0,  6, 2, 47, 
    7, 34, 3, 37, 5, 28, 2, 78, 8, 60, 6, 76, 4, 64, 0, 13, 1, 32, 
    4, 71, 1, 84, 0, 26, 6, 71, 2, 17, 3, 32, 7, 85, 5, 85, 8, 13, 
    2, 37, 0, 32, 7, 68, 4,  6, 1, 61, 8, 65, 3, 78, 5, 36, 6, 55, 
    8, 44, 6, 63, 0, 92, 2, 27, 1, 48, 7, 49, 4, 52, 5, 35, 3, 31, 
    5, 98, 8, 52, 0, 44, 4, 26, 3, 95, 7, 68, 6, 88, 1, 99, 2, 39
  };
  const int q5517[] = {
    9, 9, // Number of jobs and machines
    1, 40, 7, 75, 5, 56, 3, 72, 2, 42, 6, 15, 4, 68, 0, 70, 8, 27, 
    2,  9, 1, 15, 6, 64, 5, 30, 7, 88, 8, 51, 0, 61, 3, 38, 4, 54, 
    1, 66, 0,  4, 4, 17, 5, 65, 6, 46, 8, 83, 3, 80, 7, 35, 2,  4, 
    6, 91, 4, 82, 5, 70, 8, 95, 2, 48, 3, 95, 7, 38, 0, 91, 1, 90, 
    0, 59, 3, 92, 7, 52, 1, 96, 8, 54, 2, 43, 6, 22, 4, 88, 5, 78, 
    7, 52, 8, 63, 3, 44, 1, 27, 5, 78, 4, 49, 6, 69, 2, 50, 0, 39, 
    8,  7, 2, 78, 4,  4, 6, 43, 5, 45, 3, 35, 7,  1, 1, 69, 0, 42, 
    7, 38, 4, 17, 1, 35, 5, 45, 6, 95, 2, 74, 3, 24, 8, 96, 0, 12, 
    3, 30, 6, 31, 7, 42, 1, 50, 0, 90, 5, 71, 2, 32, 8, 19, 4, 28
  };
  const int q5518[] = {
    9, 9, // Number of jobs and machines
    3, 24, 5, 59, 8, 67, 7, 97, 1, 45, 2, 74, 0, 42, 6, 74, 4, 93, 
    4, 81, 8, 22, 6, 75, 7, 61, 5, 67, 2, 65, 0, 38, 1, 93, 3, 99, 
    1, 95, 4,  6, 5, 31, 2, 68, 6, 10, 8, 98, 7, 75, 0,  1, 3, 60, 
    3, 41, 5, 25, 4, 42, 0, 37, 1, 74, 2, 21, 7, 21, 8, 73, 6, 22, 
    0, 47, 5, 49, 6, 33, 7, 38, 3, 24, 8, 30, 4, 46, 2,  5, 1, 84, 
    0, 32, 5,  3, 1, 10, 4, 49, 3, 64, 7,  8, 2, 41, 6, 60, 8, 16, 
    2,  7, 0, 34, 5, 84, 3, 76, 4, 20, 6, 47, 1, 58, 8, 16, 7, 95, 
    0,  3, 2, 47, 4, 11, 1, 68, 6, 57, 7, 55, 8, 10, 3, 26, 5, 86, 
    0, 18, 8, 17, 1, 99, 7, 65, 3, 55, 5, 88, 6, 34, 4,  4, 2, 81
  };
  const int q5519[] = {
    9, 9, // Number of jobs and machines
    0, 18, 6, 61, 4, 19, 7, 62, 8, 41, 2, 64, 1, 92, 3, 42, 5, 19, 
    1, 48, 6, 63, 7, 69, 8, 94, 0, 18, 2, 12, 3, 69, 4, 87, 5, 13, 
    0, 48, 5, 79, 6, 13, 3, 89, 2, 79, 4, 42, 8, 82, 1, 19, 7, 85, 
    8,  2, 5, 86, 7, 88, 4, 12, 3, 62, 0, 20, 1, 26, 2,  6, 6, 34, 
    2, 68, 3, 70, 4, 65, 0, 53, 8, 47, 6, 58, 1, 27, 7, 73, 5, 85, 
    2, 73, 0, 10, 5, 97, 8, 49, 1, 64, 4, 23, 7, 11, 3, 31, 6, 73, 
    6, 11, 3, 45, 5, 64, 8, 31, 4, 74, 2, 89, 0, 97, 7, 51, 1, 19, 
    1, 29, 6,  6, 4, 27, 2, 25, 3, 24, 8, 61, 5,  8, 7, 12, 0, 44, 
    2, 25, 0, 43, 7,  5, 3, 14, 4, 10, 6, 14, 8, 81, 1, 41, 5, 82
  };
  const int q5520[] = {
    9, 9, // Number of jobs and machines
    7, 61, 1, 64, 6, 69, 2, 29, 0, 27, 4, 48, 5,  3, 3, 54, 8, 95, 
    0, 80, 6, 82, 3, 32, 2, 85, 5, 95, 8, 69, 7, 99, 4, 23, 1, 88, 
    3, 35, 6, 73, 8, 59, 2, 92, 5, 34, 4, 98, 1, 18, 7, 46, 0, 72, 
    6,  1, 5, 93, 2, 94, 7, 23, 0, 28, 1, 97, 3, 42, 8, 81, 4, 36, 
    6, 19, 3, 15, 0, 34, 7, 94, 2, 63, 4, 47, 5, 14, 8, 49, 1,  5, 
    0, 77, 5, 56, 3, 19, 6, 53, 2, 87, 8, 25, 4, 20, 7, 15, 1, 97, 
    4, 34, 0, 91, 7, 45, 3, 64, 2, 44, 1,  4, 6, 83, 5,  8, 8, 56, 
    8, 93, 1, 12, 5, 35, 7,  5, 2, 52, 4, 87, 3, 82, 6, 75, 0, 52, 
    0, 63, 6, 33, 3, 32, 1, 55, 4, 87, 8, 52, 5, 21, 7, 20, 2,  1
  };
  const int q5521[] = {
    9, 9, // Number of jobs and machines
    6, 29, 0, 38, 8, 52, 7, 57, 1, 53, 4, 78, 3,  6, 2, 38, 5, 88, 
    6, 35, 1, 94, 4, 29, 2, 90, 8, 53, 7, 28, 3, 19, 0, 24, 5, 25, 
    7, 93, 3, 47, 6, 27, 1, 33, 8,  2, 5, 19, 2, 86, 0, 25, 4, 66, 
    6, 85, 1, 75, 7, 54, 0, 18, 5, 69, 4, 49, 8, 94, 3, 35, 2, 38, 
    6, 19, 2, 89, 3,  9, 7, 97, 4, 63, 0, 65, 8, 15, 1, 46, 5, 96, 
    0, 61, 8, 24, 4, 68, 1, 20, 5, 21, 3, 76, 7,  6, 2, 61, 6, 31, 
    0, 62, 4, 66, 3, 84, 2, 18, 1, 37, 6,  1, 8, 72, 7, 95, 5,  8, 
    7, 62, 1, 16, 4, 18, 8, 28, 2, 81, 0, 60, 5, 63, 3, 65, 6, 42, 
    2, 34, 0, 61, 4, 97, 1, 54, 7, 50, 6, 66, 3, 16, 8, 27, 5, 77
  };
  const int q5522[] = {
    9, 9, // Number of jobs and machines
    2, 58, 7, 45, 1, 17, 6, 44, 3, 65, 8, 75, 4, 95, 0, 77, 5, 79, 
    5, 68, 2, 26, 0, 93, 8, 81, 3, 40, 7, 57, 6, 61, 1, 33, 4, 99, 
    1, 29, 3, 71, 7, 18, 8, 50, 5, 14, 2, 57, 4,  7, 6, 73, 0,  3, 
    2, 32, 3, 58, 5, 17, 0, 66, 1,  7, 4, 89, 6,  1, 7, 50, 8, 98, 
    2, 64, 8, 31, 3,  2, 6, 36, 0, 73, 5, 87, 7, 35, 4, 49, 1, 13, 
    3, 18, 1, 32, 4, 94, 7, 87, 2, 85, 6, 37, 0, 46, 8, 42, 5, 37, 
    4, 45, 7, 35, 8, 43, 3, 43, 0, 14, 6, 18, 2, 84, 5, 64, 1, 34, 
    1, 50, 7, 90, 2, 55, 6, 67, 4, 36, 3, 97, 5, 13, 8, 63, 0, 76, 
    2, 15, 5,  7, 4, 88, 6, 64, 8, 95, 3, 96, 1, 92, 0, 85, 7, 18
  };
  const int q5523[] = {
    9, 9, // Number of jobs and machines
    1, 63, 3, 35, 5, 21, 2, 13, 8, 20, 6, 45, 4, 73, 7, 18, 0, 38, 
    4, 64, 6, 32, 5, 11, 7, 23, 2, 80, 3, 10, 8,  2, 1, 98, 0, 43, 
    8, 91, 3, 52, 4, 75, 5, 92, 6, 65, 2,  2, 0, 11, 7, 16, 1,  2, 
    2, 49, 3, 14, 1, 87, 8, 28, 4, 32, 7, 82, 0, 88, 6,  2, 5, 63, 
    6, 13, 5, 14, 0, 48, 4, 97, 2, 18, 8, 39, 3, 35, 7, 89, 1, 42, 
    1,  5, 3, 29, 0, 70, 2, 92, 7, 66, 6, 89, 5, 33, 8, 23, 4, 71, 
    0, 85, 8, 53, 2, 34, 5, 32, 3, 16, 6, 18, 1, 28, 4, 66, 7, 37, 
    5, 70, 6, 64, 3, 87, 7, 81, 1, 72, 8, 25, 2, 26, 0, 23, 4, 88, 
    2, 76, 7, 33, 6, 65, 5, 73, 3, 88, 4, 16, 1, 51, 8, 19, 0, 98
  };
  const int q5524[] = {
    9, 9, // Number of jobs and machines
    2, 52, 6, 52, 4, 92, 7, 11, 0, 33, 8,  5, 3, 27, 5, 27, 1, 35, 
    3, 99, 8, 49, 5, 98, 6, 46, 7, 96, 1, 59, 2, 97, 4, 54, 0, 35, 
    2, 93, 6, 16, 8, 14, 4, 53, 1, 78, 7, 71, 0,  1, 3, 58, 5, 38, 
    0, 67, 3,  1, 7, 78, 4, 75, 8, 64, 5, 81, 6, 38, 2, 86, 1, 27, 
    3, 10, 2, 65, 7, 38, 0,  1, 4, 34, 6, 89, 5, 71, 1,  8, 8, 53, 
    0, 31, 7, 46, 6, 51, 8, 52, 3,  6, 4, 36, 1, 87, 5, 16, 2, 21, 
    0, 47, 7, 45, 5, 16, 8, 97, 1, 63, 3, 59, 6, 27, 2, 35, 4, 17, 
    0, 94, 5, 66, 4,  8, 3, 14, 6, 75, 8, 92, 2, 38, 7, 43, 1,  2, 
    4, 87, 5, 16, 7, 80, 1, 63, 3, 74, 6, 90, 2, 50, 0, 77, 8, 89
  };
  const int q5525[] = {
    9, 9, // Number of jobs and machines
    2, 40, 1, 55, 0, 91, 3, 60, 8, 32, 5, 55, 7, 38, 4, 67, 6, 59, 
    4, 75, 3, 32, 0, 57, 7, 52, 1, 16, 2, 92, 5, 64, 8, 65, 6, 30, 
    2, 13, 4, 88, 3, 19, 8, 53, 6, 31, 5, 79, 1, 48, 7, 58, 0, 68, 
    2, 37, 7, 65, 8, 97, 6, 70, 1, 77, 0, 25, 5, 38, 3, 75, 4, 21, 
    3, 25, 0, 87, 8, 10, 6, 89, 5, 93, 4, 80, 1, 90, 2, 44, 7, 89, 
    1, 20, 3, 51, 5, 47, 8, 21, 7, 44, 6, 34, 0, 31, 4, 72, 2, 18, 
    2, 61, 7, 74, 8,  2, 5, 96, 0, 31, 6, 88, 1, 56, 4, 70, 3, 65, 
    4, 91, 7, 19, 1, 27, 0, 19, 6, 54, 8, 61, 5, 50, 3, 67, 2, 18, 
    6, 28, 0, 83, 5, 59, 1, 53, 8, 82, 4, 89, 2, 31, 3, 61, 7, 35
  };
  const int q5526[] = {
    9, 9, // Number of jobs and machines
    8, 44, 3, 81, 6, 47, 1,  7, 7, 35, 5, 63, 2, 84, 0,  7, 4, 44, 
    0, 60, 8, 26, 3, 88, 2, 76, 7, 41, 1, 29, 5, 11, 4,  5, 6, 66, 
    2, 76, 6, 85, 1, 22, 4, 18, 8, 46, 0, 34, 7, 38, 3, 14, 5, 82, 
    5, 66, 3, 58, 0, 48, 7, 44, 2, 59, 1, 95, 6, 54, 8, 33, 4, 85, 
    8, 27, 6, 57, 2, 88, 0, 84, 4, 22, 7, 51, 3, 20, 1, 82, 5, 50, 
    7, 91, 1, 50, 0, 34, 2, 92, 4, 19, 3, 19, 8, 77, 6, 36, 5, 71, 
    8, 36, 6, 72, 3, 18, 5, 48, 2, 18, 7, 11, 1, 77, 4, 19, 0, 29, 
    5, 56, 7, 88, 8, 21, 3, 11, 2, 41, 1, 93, 0, 10, 6, 39, 4, 92, 
    2, 92, 1, 93, 8, 72, 3, 15, 7, 42, 4, 93, 6, 39, 5, 73, 0, 44
  };
  const int q5527[] = {
    9, 9, // Number of jobs and machines
    6,  4, 0, 13, 4,  7, 1, 80, 5, 26, 8, 57, 7, 99, 3, 87, 2, 38, 
    4, 99, 6, 50, 2, 64, 5, 51, 0, 61, 3, 61, 1, 21, 7, 22, 8, 95, 
    7, 47, 1, 82, 6, 37, 5, 85, 8, 38, 3, 98, 0, 95, 2, 74, 4,  3, 
    0, 98, 8, 38, 4, 33, 7, 80, 2, 11, 6, 49, 1, 87, 3, 19, 5, 11, 
    6, 38, 8, 72, 4,  8, 1, 87, 2, 41, 7, 88, 3, 60, 5, 94, 0, 84, 
    2, 97, 4, 70, 7, 59, 0, 86, 1, 57, 5, 20, 6, 73, 8, 37, 3, 56, 
    2,  1, 6, 65, 1, 43, 4, 31, 0, 70, 7,  8, 5, 13, 3, 88, 8, 40, 
    4, 26, 8, 56, 3, 85, 1, 32, 0, 55, 7, 93, 6, 25, 2, 97, 5, 56, 
    7, 38, 4, 42, 8, 91, 3, 19, 1, 64, 2, 13, 6, 75, 5, 86, 0, 47
  };
  const int q5528[] = {
    9, 9, // Number of jobs and machines
    1, 82, 7, 85, 2, 63, 4, 40, 0, 14, 5, 69, 3, 76, 8, 68, 6, 93, 
    1, 20, 7, 14, 0,  8, 4, 54, 5, 89, 2, 77, 6, 97, 8, 77, 3, 13, 
    0, 91, 2, 50, 3, 67, 6, 45, 5, 71, 4, 42, 1, 21, 7, 56, 8, 71, 
    1,  7, 6, 96, 5, 47, 8, 72, 4, 71, 3, 33, 0, 55, 2, 82, 7, 87, 
    5, 93, 8, 13, 3, 81, 1, 81, 6, 79, 2, 73, 4, 94, 0, 14, 7, 73, 
    7, 61, 1, 20, 5, 63, 0, 11, 6, 78, 8, 58, 4, 73, 2, 48, 3, 84, 
    5, 97, 7, 95, 3, 51, 4, 42, 1, 65, 8,  2, 6, 45, 0, 24, 2, 37, 
    3, 41, 5, 55, 2, 85, 0, 51, 4, 70, 8, 67, 6, 97, 7, 63, 1, 59, 
    4, 53, 6, 67, 1,  3, 7, 99, 5, 16, 2, 18, 3, 91, 8, 88, 0, 14
  };
  const int q5529[] = {
    9, 9, // Number of jobs and machines
    3, 34, 4, 54, 0, 66, 8, 84, 6, 17, 7, 16, 1, 68, 5, 96, 2, 51, 
    2,  6, 0, 43, 7, 35, 8, 43, 5, 14, 6, 95, 1, 72, 3, 55, 4, 20, 
    6, 78, 5, 53, 7, 50, 4, 63, 1,  5, 0, 91, 2, 18, 8, 24, 3, 20, 
    7,  3, 3, 56, 6,  8, 1, 47, 5, 32, 8, 75, 0, 19, 4, 60, 2, 74, 
    5, 76, 2, 46, 6, 82, 1, 18, 0,  7, 8,  7, 3, 51, 7, 45, 4, 65, 
    7, 10, 8, 71, 3, 52, 0, 35, 6, 16, 1, 84, 2, 41, 5, 83, 4, 26, 
    1, 11, 3, 48, 6, 43, 5,  3, 2, 68, 4, 70, 0, 40, 8, 25, 7, 10, 
    7, 38, 3, 35, 2, 90, 8, 74, 5, 92, 0, 73, 1, 82, 4, 18, 6,  1, 
    7, 82, 1, 16, 0, 35, 5, 79, 8, 68, 2, 88, 4, 50, 6, 20, 3, 19
  };
  const int q5530[] = {
    9, 9, // Number of jobs and machines
    2, 58, 7,  4, 1,  7, 3, 66, 5, 58, 8, 22, 4, 42, 6, 10, 0, 17, 
    6, 64, 8, 32, 0, 85, 1, 78, 2, 93, 3, 39, 5, 11, 4, 12, 7,  4, 
    1, 77, 5, 69, 7, 92, 3, 97, 8, 82, 2, 45, 6, 95, 4, 19, 0, 58, 
    1, 32, 3, 53, 5, 20, 4, 24, 8, 87, 2, 31, 7, 48, 6, 41, 0,  7, 
    8, 66, 5, 21, 3, 35, 0, 14, 2, 98, 7, 33, 1, 29, 4, 84, 6, 93, 
    1, 53, 8, 27, 2, 25, 7, 27, 4, 25, 5, 95, 3, 72, 6, 91, 0, 11, 
    3, 43, 7, 85, 6,  5, 5, 75, 4,  4, 0,  7, 2, 68, 8, 28, 1, 89, 
    7,  1, 1, 32, 0, 84, 4, 51, 3, 50, 8, 71, 5, 99, 6, 73, 2, 18, 
    4, 89, 1, 11, 7, 64, 2,  3, 6, 35, 8, 90, 0,  4, 5, 75, 3,  8
  };
  const int q5531[] = {
    9, 9, // Number of jobs and machines
    8, 21, 5, 50, 2, 91, 1, 96, 7, 81, 6, 41, 0, 70, 3, 64, 4, 76, 
    4,  6, 7, 17, 0, 21, 5, 12, 3, 12, 6, 63, 1, 85, 2, 68, 8, 52, 
    7, 40, 4, 56, 2, 18, 8, 54, 0, 55, 6, 57, 3, 23, 1, 59, 5, 12, 
    5, 92, 1, 98, 8, 72, 6,  4, 0, 54, 4, 42, 2, 35, 3, 64, 7, 71, 
    7, 38, 3, 64, 8, 81, 2, 42, 0, 95, 6, 19, 4, 84, 5, 70, 1, 78, 
    3,  9, 5, 60, 7,  2, 0, 29, 2, 33, 4, 90, 8,  9, 6, 27, 1, 35, 
    3, 25, 7, 19, 4, 28, 2, 16, 1, 67, 5, 69, 6, 49, 8,  5, 0, 66, 
    0, 33, 5, 22, 6, 69, 7, 10, 1, 27, 3, 98, 2, 27, 4, 29, 8, 31, 
    1, 43, 6, 52, 2, 96, 5, 55, 0, 54, 7, 21, 3, 38, 4, 86, 8, 48
  };
  const int q5532[] = {
    9, 9, // Number of jobs and machines
    3, 38, 8, 35, 6, 49, 0, 43, 2, 11, 7, 12, 5, 75, 1, 79, 4, 59, 
    7, 54, 2,  2, 1, 83, 5, 81, 8, 72, 6, 43, 4, 74, 3,  5, 0, 63, 
    7, 11, 5,  9, 2, 17, 6, 35, 1, 48, 3, 82, 8, 39, 0, 68, 4,  1, 
    8, 17, 6, 95, 3, 66, 4, 25, 5, 64, 7, 25, 2, 60, 1, 46, 0,  2, 
    2, 84, 7, 88, 0, 10, 3, 95, 4, 78, 1, 57, 6, 54, 5, 76, 8, 47, 
    5, 90, 3, 88, 6, 55, 8, 77, 1, 54, 0, 27, 2,  5, 4, 51, 7, 30, 
    4,  9, 8, 70, 7, 10, 3, 41, 5, 71, 2, 28, 6, 95, 1, 52, 0, 90, 
    1, 57, 3, 58, 5,  5, 4, 45, 8, 85, 0, 65, 7, 34, 6, 52, 2, 38, 
    3, 69, 7, 11, 4, 21, 1, 28, 2, 97, 0, 71, 6, 30, 5, 41, 8, 12
  };
  const int q5533[] = {
    9, 9, // Number of jobs and machines
    6, 75, 0,  4, 7,  1, 2, 83, 4,  8, 3, 85, 5, 78, 1, 40, 8, 25, 
    2, 75, 4, 55, 0, 53, 8, 38, 3, 44, 5, 66, 7, 47, 1, 57, 6, 16, 
    7, 15, 8,  8, 2,  4, 5, 19, 3, 90, 4, 86, 6,  4, 1, 83, 0, 88, 
    3, 59, 7, 86, 6, 60, 0, 10, 5, 37, 2, 33, 8,  2, 1, 50, 4, 25, 
    5,  8, 1, 10, 3, 81, 4, 39, 8,  1, 7, 59, 0, 90, 6, 18, 2, 85, 
    2, 83, 8, 67, 4, 24, 5, 43, 7, 56, 6, 16, 0, 97, 1, 66, 3, 88, 
    2,  2, 0, 10, 4,  8, 8, 88, 1, 35, 7, 87, 6, 51, 5,  1, 3, 42, 
    2, 32, 6, 10, 7, 46, 1, 65, 3, 36, 8, 82, 4, 29, 0, 48, 5, 26, 
    4,  3, 6, 18, 0, 82, 1, 30, 5, 19, 7, 57, 3, 67, 2, 15, 8, 78
  };
  const int q5534[] = {
    9, 9, // Number of jobs and machines
    7, 42, 8, 26, 5, 40, 3, 52, 6, 27, 1, 65, 4, 28, 2, 87, 0, 50, 
    7, 10, 5, 64, 4, 48, 3, 38, 1, 72, 6, 72, 8, 89, 0, 92, 2, 58, 
    8,  1, 1, 10, 2, 31, 6, 64, 0, 93, 4, 52, 5, 64, 7, 33, 3, 54, 
    8, 17, 4, 13, 5, 44, 3,  4, 0, 51, 2, 15, 1, 49, 6, 41, 7, 89, 
    6, 96, 3, 66, 1, 34, 0, 55, 5, 95, 8, 78, 7, 93, 4, 50, 2, 82, 
    6, 26, 0, 50, 4,  1, 1,  5, 8, 74, 3, 92, 5, 47, 2, 15, 7, 97, 
    8, 60, 6, 86, 7, 89, 3, 52, 4, 15, 1, 72, 2,  8, 0, 25, 5, 78, 
    8,  9, 7, 95, 6, 74, 3, 98, 5,  7, 0, 29, 1, 38, 4, 36, 2, 94, 
    5, 87, 1, 71, 0, 87, 2, 69, 3, 36, 8, 71, 6, 94, 4,  3, 7, 40
  };
  const int q5535[] = {
    9, 9, // Number of jobs and machines
    6, 59, 4, 96, 1,  7, 2, 58, 0, 78, 5,  9, 7,  8, 3, 16, 8, 23, 
    5, 67, 3, 52, 7, 84, 1, 48, 6, 84, 4, 26, 8, 14, 2, 98, 0,  7, 
    3, 73, 1, 44, 2, 56, 5,  2, 6, 86, 8, 67, 0, 57, 4, 75, 7, 10, 
    5, 22, 7, 69, 8, 22, 4,  6, 3, 99, 6, 79, 2,  6, 0, 28, 1, 70, 
    4, 67, 0, 98, 7,  9, 8, 84, 5, 27, 2, 30, 3, 11, 1, 84, 6, 73, 
    4, 13, 8, 89, 7, 75, 3, 51, 1, 69, 0, 37, 5, 41, 6, 33, 2, 66, 
    4, 44, 5, 86, 1, 56, 7, 81, 8, 90, 2, 36, 6, 26, 3,  7, 0, 40, 
    7, 45, 5, 31, 3, 66, 4, 62, 1, 83, 6, 88, 2, 16, 0, 64, 8, 17, 
    5,  4, 7, 68, 4, 72, 0, 76, 1, 63, 2, 75, 6,  2, 3, 43, 8, 31
  };
  const int q5536[] = {
    9, 9, // Number of jobs and machines
    3, 77, 8, 72, 1, 83, 4, 50, 2, 82, 7, 91, 0, 88, 5, 65, 6, 87, 
    1,  1, 7, 73, 2, 13, 3, 76, 5, 44, 8, 21, 0, 80, 6, 69, 4, 30, 
    3, 87, 7, 41, 4, 16, 0, 97, 5, 60, 1, 95, 2, 58, 6, 89, 8, 76, 
    4, 45, 3, 24, 6, 34, 8, 72, 7,  7, 5, 87, 1, 17, 0, 77, 2, 68, 
    7, 46, 4, 64, 3, 91, 0, 59, 2, 70, 1, 10, 8, 16, 5,  3, 6, 95, 
    1, 32, 6, 61, 5, 63, 3, 21, 0, 15, 7, 39, 8,  3, 4, 97, 2, 12, 
    1, 39, 0, 94, 8, 65, 3, 61, 7, 92, 6, 86, 2, 69, 4, 96, 5, 24, 
    5, 65, 4, 32, 2, 37, 3, 68, 1, 16, 8, 52, 6, 92, 7, 89, 0, 87, 
    6, 93, 4, 63, 2, 88, 3, 13, 1,  5, 7, 79, 8,  3, 0, 74, 5, 46
  };
  const int q5537[] = {
    9, 9, // Number of jobs and machines
    5, 44, 7, 15, 0, 51, 2, 89, 3, 64, 8, 69, 1, 67, 4, 16, 6, 88, 
    7, 88, 5, 75, 8, 94, 1,  3, 3,  9, 2, 93, 6, 83, 0, 40, 4, 15, 
    2, 48, 4, 54, 7, 18, 5, 50, 6,  6, 8, 47, 3, 16, 0, 44, 1, 82, 
    7, 37, 6, 16, 5, 76, 8, 69, 3,  5, 2, 68, 0, 36, 1, 41, 4, 15, 
    2, 91, 7, 13, 1,  3, 4, 35, 6, 27, 0, 71, 8, 55, 5, 75, 3, 77, 
    5,  7, 1, 25, 3,  9, 8, 73, 0, 25, 7, 13, 2, 41, 4, 57, 6, 57, 
    8,  2, 2, 24, 7, 95, 6, 66, 5, 45, 3, 42, 4, 81, 1, 22, 0, 41, 
    4, 90, 1, 95, 8, 70, 0, 12, 3, 46, 5, 98, 7, 25, 6, 31, 2, 90, 
    4, 75, 5, 37, 7, 22, 2, 65, 0, 64, 6, 21, 1, 19, 3, 89, 8,  5
  };
  const int q5538[] = {
    9, 9, // Number of jobs and machines
    6, 46, 8, 59, 1, 22, 5,  8, 0, 13, 4, 26, 2, 82, 3, 41, 7, 37, 
    7, 94, 8, 98, 5, 24, 0, 68, 2, 35, 1, 39, 3, 16, 6, 15, 4, 53, 
    5, 18, 4, 60, 2, 90, 7, 88, 0,  3, 1, 53, 6, 36, 3, 61, 8, 82, 
    0, 25, 4, 98, 5, 86, 7, 22, 2, 87, 8, 79, 1, 85, 3, 31, 6, 33, 
    7, 75, 5,  6, 4, 98, 3, 85, 0, 75, 6, 55, 1, 87, 2, 78, 8, 22, 
    7, 29, 1, 15, 2, 10, 4, 16, 3,  6, 8, 23, 0, 67, 6, 78, 5, 19, 
    6, 42, 5, 44, 8, 20, 2, 67, 7, 79, 3, 88, 0, 40, 1, 53, 4, 52, 
    3, 66, 0, 14, 1, 78, 5, 26, 6, 78, 2, 69, 8, 56, 7, 52, 4, 99, 
    1, 79, 4, 83, 7,  6, 8, 62, 5, 72, 6, 96, 2, 39, 0, 77, 3, 38
  };
  const int q5539[] = {
    9, 9, // Number of jobs and machines
    0, 67, 7, 64, 8,  9, 2, 93, 3,  8, 6, 53, 4, 12, 1, 78, 5, 69, 
    6, 68, 8, 33, 2, 90, 0, 45, 3, 39, 4, 31, 7, 75, 1, 90, 5, 16, 
    2, 26, 5, 25, 3, 25, 4, 65, 0, 86, 6, 52, 7,  2, 8, 98, 1, 45, 
    2, 66, 8, 98, 3, 82, 4, 84, 5, 37, 0, 16, 1,  5, 6, 72, 7, 90, 
    5, 54, 0, 83, 7, 71, 6, 70, 8, 61, 2, 32, 1, 17, 4, 92, 3, 31, 
    0, 19, 7, 55, 3, 95, 8, 71, 5, 21, 6, 50, 2, 59, 4, 46, 1, 74, 
    1, 64, 4, 15, 2, 67, 5,  5, 8, 98, 6, 49, 7, 14, 3, 92, 0, 78, 
    5, 92, 8, 12, 4, 31, 7, 59, 6, 78, 0,  7, 3, 13, 1, 33, 2,  2, 
    0, 59, 1, 71, 4, 21, 8, 14, 5, 65, 2, 20, 6, 69, 7, 30, 3, 25
  };
  const int q5540[] = {
    9, 9, // Number of jobs and machines
    3, 70, 1, 78, 4, 86, 6, 40, 2, 44, 7, 86, 8, 35, 0,  9, 5, 85, 
    7, 34, 2, 82, 4, 27, 5, 33, 3, 94, 0,  4, 6, 91, 8, 86, 1, 50, 
    4, 77, 1, 61, 8, 62, 0,  5, 6, 56, 5, 50, 7, 27, 3, 40, 2, 34, 
    4, 51, 8, 44, 6, 16, 0, 89, 7,  3, 3, 10, 2, 81, 1, 92, 5, 36, 
    2, 28, 0, 67, 1, 11, 6,  1, 5, 54, 7, 63, 8,  4, 3, 22, 4,  6, 
    0, 24, 7, 18, 3, 79, 5, 44, 4, 92, 2, 87, 6, 50, 8, 66, 1,  7, 
    3, 54, 2, 26, 7, 79, 6, 82, 5,  3, 4, 12, 0, 78, 1, 95, 8, 51, 
    5,  9, 8, 82, 0, 11, 3, 97, 4, 56, 2, 93, 6, 89, 1, 73, 7, 15, 
    0, 83, 3, 53, 2, 22, 4, 57, 6, 75, 5,  5, 7, 93, 1, 52, 8, 62
  };
  const int q5541[] = {
    9, 9, // Number of jobs and machines
    2, 40, 1,  5, 0, 53, 4, 89, 8, 62, 6, 98, 3, 72, 7, 23, 5, 42, 
    1, 27, 2,  7, 6,  3, 8, 97, 3, 96, 7, 73, 0, 76, 4, 17, 5, 48, 
    2, 43, 5,  8, 7, 70, 8, 57, 1, 26, 3, 34, 6,  6, 0,  2, 4, 40, 
    1, 10, 3, 49, 5, 64, 4,  7, 7, 59, 6, 83, 8, 57, 2, 62, 0,  7, 
    3, 12, 5, 44, 7, 48, 1, 28, 2,  2, 8, 91, 0, 76, 6, 30, 4, 99, 
    8, 70, 0, 50, 1, 82, 6, 67, 5, 31, 4, 13, 7, 87, 2,  3, 3,  2, 
    1, 12, 8, 69, 3, 68, 0, 92, 2, 69, 7, 21, 5, 88, 6,  9, 4, 17, 
    5, 54, 7, 85, 3, 94, 2,  2, 0, 93, 1, 74, 8, 81, 4, 98, 6, 26, 
    0, 36, 5, 96, 6, 30, 2, 48, 3, 36, 8, 37, 4, 76, 1, 92, 7, 35
  };
  const int q5542[] = {
    9, 9, // Number of jobs and machines
    0, 87, 5,  3, 6,  2, 4, 55, 7, 71, 3, 56, 2,  1, 8, 63, 1, 83, 
    4, 86, 1, 86, 8, 13, 6, 14, 3, 57, 0, 68, 2, 47, 7, 92, 5, 55, 
    4, 88, 2, 53, 3, 91, 1, 33, 7, 55, 5, 90, 0,  7, 6,  7, 8, 68, 
    8, 75, 5, 47, 4, 83, 3, 57, 6, 31, 7, 95, 2, 32, 0, 47, 1, 71, 
    6, 49, 8, 54, 4, 24, 0, 75, 5, 42, 1, 17, 2, 17, 7, 20, 3, 83, 
    6, 44, 2, 68, 8, 60, 7, 55, 1, 50, 3, 80, 0, 90, 5, 59, 4,  6, 
    4,  7, 1, 47, 6, 29, 3, 54, 5, 48, 0, 58, 2, 53, 8, 33, 7, 91, 
    0, 49, 7, 22, 1, 58, 2, 34, 8, 73, 6, 26, 5, 94, 4, 99, 3, 47, 
    1, 10, 4, 68, 8, 92, 7,  8, 2, 13, 5, 32, 3, 58, 6, 78, 0, 28
  };
  const int q5543[] = {
    9, 9, // Number of jobs and machines
    5, 74, 0, 75, 7, 95, 6, 96, 2,  8, 8, 21, 3, 67, 1, 32, 4, 45, 
    0, 28, 1, 35, 5, 62, 2, 91, 6,  4, 7, 77, 4, 69, 8, 84, 3, 99, 
    3, 40, 2, 14, 0, 76, 1,  1, 6, 68, 5, 95, 7, 17, 4,  9, 8,  7, 
    2, 37, 7, 80, 1, 23, 0, 94, 8, 54, 4, 56, 3, 45, 5, 55, 6, 44, 
    1, 92, 8, 78, 5, 17, 2, 92, 0, 15, 3, 43, 7, 26, 4, 12, 6, 88, 
    7, 99, 0,  8, 3,  4, 6, 25, 2, 59, 1, 59, 4, 59, 8, 78, 5, 69, 
    1, 68, 8, 99, 5, 71, 3, 47, 4, 42, 7, 24, 2, 14, 0, 84, 6, 20, 
    5,  4, 8, 18, 2, 78, 0, 76, 7, 95, 4,  4, 1, 43, 6,  5, 3, 68, 
    7, 50, 6, 96, 1, 87, 2,  1, 8, 81, 4, 86, 0, 85, 3, 87, 5, 57
  };
  const int q5544[] = {
    9, 9, // Number of jobs and machines
    8, 91, 6,  8, 0, 61, 7, 22, 4,  7, 5, 53, 2, 10, 1, 52, 3, 90, 
    8,  8, 6, 32, 1,  1, 3, 84, 4, 86, 5, 70, 0, 36, 7, 96, 2, 85, 
    3, 34, 2, 53, 5, 36, 7, 83, 6,  1, 0, 29, 8, 86, 1, 22, 4, 14, 
    4, 12, 3, 12, 1, 19, 8, 98, 0, 81, 2,  2, 6, 82, 5, 55, 7, 49, 
    0, 93, 4, 20, 1, 11, 8, 96, 6, 58, 3, 97, 7, 27, 5, 91, 2, 28, 
    8, 28, 5, 88, 2, 34, 6, 17, 0, 30, 4, 96, 3, 95, 7, 70, 1, 97, 
    4, 33, 6, 89, 2, 66, 0, 47, 5, 55, 1, 78, 8, 79, 3, 20, 7, 64, 
    1, 42, 0, 10, 2, 77, 5, 53, 6, 80, 7, 90, 8, 24, 4, 31, 3, 65, 
    3, 68, 1, 48, 0, 92, 5, 12, 6, 22, 8, 15, 4, 10, 2, 27, 7, 41
  };
  const int q5545[] = {
    9, 9, // Number of jobs and machines
    3, 98, 6, 99, 7, 61, 4, 50, 0, 61, 2, 23, 8, 57, 1, 87, 5,  3, 
    8, 26, 5, 71, 0, 45, 6, 40, 2, 38, 7, 54, 3, 38, 4, 57, 1, 25, 
    2, 64, 8, 25, 0, 77, 7, 78, 5, 88, 3, 47, 4, 80, 6, 12, 1, 79, 
    3, 32, 1, 93, 5, 34, 6, 73, 2, 86, 7, 32, 0, 84, 8,  8, 4, 76, 
    4, 64, 0, 81, 6, 96, 7,  1, 2, 40, 1, 84, 3, 97, 5, 25, 8, 88, 
    5, 76, 8, 56, 0, 47, 4, 62, 1, 37, 6, 88, 7,  7, 2, 92, 3, 63, 
    3, 67, 1, 78, 4, 81, 0, 31, 6, 45, 5, 93, 7, 91, 8, 96, 2, 62, 
    5, 56, 4, 30, 1, 75, 8, 18, 7,  6, 0, 23, 6, 90, 3, 33, 2,  1, 
    2,  3, 7, 23, 4,  8, 8, 88, 5, 12, 0, 62, 1, 97, 3, 80, 6, 23
  };
  const int q5546[] = {
    9, 9, // Number of jobs and machines
    1, 53, 3, 95, 0,  1, 5, 10, 4, 98, 2, 92, 8, 50, 7,  9, 6, 21, 
    1, 66, 8, 61, 4, 79, 2, 78, 0, 30, 7, 39, 5, 74, 6, 73, 3, 30, 
    3,  4, 8, 66, 4, 68, 7,  4, 1, 78, 6, 41, 0, 21, 2, 46, 5, 43, 
    5, 12, 7, 54, 1, 99, 6, 75, 4, 57, 0, 54, 8, 30, 3, 48, 2, 79, 
    1,  9, 4, 76, 0, 34, 6, 30, 7, 95, 3,  5, 5, 73, 8, 50, 2, 33, 
    5, 77, 1, 28, 3, 19, 4, 80, 6, 71, 0, 71, 8, 44, 7, 72, 2, 56, 
    0,  2, 7, 43, 3, 79, 2, 29, 6,  4, 5, 77, 1, 21, 8, 91, 4, 79, 
    6, 62, 5, 51, 2, 41, 0, 57, 3, 48, 4, 36, 1, 21, 7, 58, 8, 57, 
    2, 44, 5, 82, 1, 28, 0, 41, 3, 92, 8,  5, 6, 80, 7, 40, 4, 22
  };
  const int q5547[] = {
    9, 9, // Number of jobs and machines
    0, 19, 7, 53, 5, 56, 8, 58, 2, 27, 6, 93, 3, 13, 4, 80, 1, 54, 
    4, 75, 2, 84, 1, 65, 6, 24, 3, 25, 8, 52, 5, 59, 0, 73, 7, 26, 
    5, 61, 6, 42, 0, 49, 8, 31, 3, 50, 4, 69, 1, 66, 2, 34, 7, 68, 
    3, 54, 4, 15, 6, 13, 2, 81, 5, 39, 1, 97, 8, 24, 0, 42, 7, 26, 
    4, 65, 8,  4, 5, 75, 0, 94, 3,  8, 2, 67, 1, 34, 7, 28, 6, 49, 
    6, 11, 8, 93, 2, 20, 0, 26, 1, 75, 4, 99, 5, 34, 7, 92, 3, 44, 
    3, 24, 1, 58, 5, 86, 6, 22, 8, 91, 0, 56, 7, 25, 2, 75, 4, 84, 
    2, 44, 6, 57, 3, 41, 4, 36, 7, 88, 5, 85, 8, 47, 1, 45, 0,  7, 
    6, 82, 7, 32, 0,  8, 1, 38, 3, 31, 2, 93, 4,  8, 8, 76, 5, 75
  };
  const int q5548[] = {
    9, 9, // Number of jobs and machines
    0, 99, 2, 83, 8, 29, 7, 41, 1, 14, 4, 33, 5, 26, 6, 88, 3, 20, 
    7, 12, 0, 74, 6, 36, 5, 84, 3, 37, 8, 95, 4,  7, 2,  7, 1, 26, 
    0, 40, 1, 68, 6, 16, 4, 63, 3, 13, 5, 75, 8, 52, 2,  7, 7, 90, 
    0, 50, 8, 46, 3, 34, 5, 59, 2, 71, 6,  5, 1, 72, 4, 70, 7, 40, 
    4, 71, 1, 80, 0, 16, 8, 41, 7, 96, 5, 62, 6, 29, 3,  8, 2, 36, 
    3, 45, 5, 94, 4, 42, 0, 85, 6, 34, 1,  6, 8,  5, 2, 26, 7, 85, 
    0, 33, 1, 76, 4, 96, 7, 38, 6, 86, 2, 82, 8, 12, 3, 20, 5, 66, 
    8, 93, 4, 39, 3, 40, 7, 28, 1, 77, 5,  4, 2, 46, 6, 10, 0, 50, 
    3, 41, 6, 75, 4, 50, 0, 65, 1, 48, 7, 90, 5, 65, 8, 93, 2, 90
  };
  const int q5549[] = {
    9, 9, // Number of jobs and machines
    5, 12, 8, 59, 2, 96, 7, 38, 4, 21, 6,  9, 0, 11, 1, 66, 3, 71, 
    2, 35, 1, 34, 3, 57, 6, 11, 5, 58, 7, 56, 4, 42, 8, 38, 0,  7, 
    3, 14, 6,  4, 5, 21, 0, 75, 4, 10, 8, 66, 1, 42, 7, 62, 2,  8, 
    2, 39, 1, 38, 0, 93, 3, 64, 6, 50, 4, 60, 8, 81, 7, 81, 5, 78, 
    4, 91, 2, 53, 1, 28, 0, 58, 7, 96, 6,  6, 8, 23, 5, 52, 3, 58, 
    1, 39, 7,  7, 3, 58, 8,  8, 2, 70, 5, 91, 6, 81, 4, 42, 0, 24, 
    4, 69, 5, 51, 0, 21, 6, 77, 7, 56, 1, 86, 2, 95, 8, 46, 3, 21, 
    0, 89, 4, 28, 8, 32, 5, 78, 7, 66, 2, 48, 6, 73, 3, 20, 1, 97, 
    6, 73, 8, 96, 3, 90, 7, 53, 5, 84, 0, 91, 2, 57, 4, 70, 1,  2
  };
  const int q5550[] = {
    9, 9, // Number of jobs and machines
    2, 89, 0, 91, 7, 11, 6, 13, 5, 19, 3,  2, 1, 89, 4, 24, 8, 22, 
    6, 38, 8, 17, 5, 62, 2, 76, 7, 39, 3, 50, 4, 98, 1,  3, 0, 34, 
    6, 88, 5, 63, 7, 66, 2, 32, 1, 30, 4, 31, 0, 57, 8, 95, 3, 33, 
    7, 61, 8, 69, 0, 84, 6, 79, 3, 36, 2,  4, 5, 80, 1, 31, 4, 38, 
    2, 57, 4, 69, 3, 99, 5, 73, 7, 20, 6, 27, 1, 29, 8, 71, 0, 58, 
    6, 66, 1, 82, 5, 33, 2, 37, 3, 37, 7, 79, 4, 81, 0, 15, 8, 36, 
    3, 95, 8, 98, 4, 89, 2, 68, 5, 38, 1, 73, 7, 52, 6, 59, 0, 53, 
    5, 49, 0,  4, 4,  3, 1, 98, 3, 59, 8, 90, 6, 44, 2, 43, 7, 82, 
    2, 88, 5, 16, 1, 28, 8, 17, 3, 14, 6, 80, 7, 75, 4, 47, 0,  8
  };
  const int q5551[] = {
    9, 9, // Number of jobs and machines
    0, 39, 4, 48, 8, 19, 1,  5, 3, 38, 5, 94, 2, 61, 7, 74, 6,  5, 
    3, 94, 8, 18, 6, 96, 1, 37, 5, 59, 7, 51, 4, 23, 2, 41, 0, 77, 
    7, 82, 1, 70, 0, 97, 2, 71, 8, 62, 4,  3, 3, 49, 6, 98, 5, 99, 
    7, 39, 1,  6, 0, 62, 2, 98, 5, 42, 4, 32, 3, 46, 8, 89, 6,  3, 
    3, 58, 1, 64, 7, 60, 5, 61, 2, 98, 8, 44, 4, 19, 0, 60, 6,  7, 
    1, 84, 6, 65, 3, 55, 0, 97, 8, 39, 5, 27, 4, 78, 7, 74, 2,  8, 
    8, 24, 1, 98, 3,  7, 7, 85, 4, 22, 0, 19, 6, 72, 2,  7, 5, 71, 
    6, 14, 3, 61, 4, 82, 0, 89, 8,  5, 2, 89, 7, 81, 5, 96, 1, 88, 
    6, 45, 3, 56, 2, 23, 8, 92, 1, 99, 5, 51, 0,  5, 4,  2, 7, 76
  };
  const int q5552[] = {
    9, 9, // Number of jobs and machines
    3, 62, 6, 18, 8,  3, 4, 15, 0, 32, 1, 73, 7, 28, 2, 34, 5, 94, 
    3,  3, 2, 51, 8, 74, 0, 28, 1, 73, 7, 99, 6,  8, 4, 32, 5, 34, 
    4, 75, 5, 86, 8, 26, 0, 52, 3,  3, 1, 68, 6, 69, 2, 91, 7, 87, 
    0,  4, 1, 34, 8, 37, 6, 72, 7, 73, 4, 43, 3, 24, 2, 55, 5, 84, 
    2,  6, 5, 85, 8, 61, 0, 53, 6, 92, 1, 87, 3, 54, 4, 54, 7, 85, 
    0, 67, 8, 33, 5, 89, 6, 13, 2, 58, 7, 26, 4, 39, 1, 58, 3, 40, 
    3, 80, 8, 68, 7, 72, 6, 74, 2, 39, 5, 53, 4, 59, 0, 39, 1,  5, 
    1, 28, 7, 71, 4, 16, 5,  2, 6,  7, 3, 69, 8, 82, 0, 88, 2, 91, 
    4,  2, 1, 34, 3, 68, 5, 49, 6, 81, 0, 79, 8, 66, 2, 67, 7, 81
  };
  const int q5553[] = {
    9, 9, // Number of jobs and machines
    4, 45, 8, 17, 1,  7, 3, 39, 6, 33, 7, 74, 2, 39, 0, 31, 5, 59, 
    5, 13, 1,  9, 7, 25, 2, 96, 8,  7, 6, 42, 0,  8, 3, 87, 4, 37, 
    6, 47, 8, 89, 3, 85, 1, 55, 2,  5, 4, 31, 7, 71, 0, 82, 5, 44, 
    7, 12, 0, 51, 6, 39, 2, 10, 8, 67, 1, 32, 3, 81, 5, 10, 4, 57, 
    4, 14, 3, 94, 8, 21, 2, 25, 6, 32, 1, 83, 7, 65, 0, 23, 5, 82, 
    4, 99, 6,  6, 8, 37, 0, 67, 2, 44, 1, 68, 3, 36, 7, 73, 5, 32, 
    0, 93, 2, 46, 6, 29, 5, 65, 1, 21, 4, 34, 8, 64, 3, 90, 7, 47, 
    7, 59, 6, 50, 5, 64, 1, 83, 8, 79, 2, 42, 4, 13, 0, 30, 3, 19, 
    1, 15, 3, 69, 0,  2, 6, 31, 5, 40, 2, 86, 4, 17, 8, 41, 7, 10
  };
  const int q5554[] = {
    9, 9, // Number of jobs and machines
    4, 26, 0, 93, 7,  5, 1, 91, 8, 92, 3, 31, 5, 22, 6,  3, 2, 28, 
    6, 32, 5, 90, 1, 38, 0, 48, 2,  4, 3, 32, 4, 73, 8, 40, 7, 59, 
    1, 78, 5, 58, 0,  2, 3, 57, 6, 62, 4, 10, 7, 19, 2, 62, 8, 92, 
    5, 40, 3, 80, 4, 73, 0, 43, 1, 29, 6,  4, 8, 33, 2, 53, 7, 25, 
    3, 74, 5, 99, 7, 62, 4, 15, 0, 19, 2, 24, 6, 92, 1, 24, 8, 72, 
    0, 17, 6, 13, 8, 67, 7, 97, 5,  1, 3, 30, 1,  6, 4, 48, 2, 63, 
    4, 87, 3, 82, 2, 15, 8, 72, 1, 17, 0, 88, 5, 43, 6, 80, 7, 39, 
    3, 10, 2, 88, 5, 85, 7, 57, 0,  8, 1, 73, 6, 21, 8, 82, 4, 16, 
    5, 87, 7, 51, 0, 59, 4, 86, 1, 62, 6, 24, 2, 46, 3, 47, 8, 96
  };
  const int q5555[] = {
    9, 9, // Number of jobs and machines
    0, 46, 4, 57, 8, 11, 6, 34, 7, 56, 2, 15, 5, 32, 1, 99, 3, 20, 
    1, 14, 5, 43, 7, 29, 6,  2, 2, 59, 3, 69, 0, 94, 8, 21, 4, 31, 
    0, 18, 5, 83, 3, 37, 1, 73, 4, 75, 7, 53, 8, 17, 6, 69, 2, 15, 
    1, 68, 7, 49, 6, 33, 3, 26, 2, 10, 0, 80, 4, 57, 5, 94, 8,  9, 
    5, 64, 8, 23, 4, 57, 0, 27, 2, 60, 6, 60, 1, 69, 7,  5, 3, 73, 
    6, 41, 5, 26, 1, 89, 0,  6, 7,  1, 8,  8, 3, 37, 4, 35, 2, 61, 
    3, 63, 1, 32, 6, 97, 2, 23, 8,  9, 4, 85, 0, 53, 5, 30, 7, 46, 
    4, 12, 8, 25, 3, 73, 0, 46, 2, 20, 7,  5, 5, 78, 6, 50, 1, 58, 
    1, 73, 8, 87, 4, 77, 6,  6, 7, 36, 3, 35, 0, 25, 5, 18, 2, 94
  };
  const int q5556[] = {
    9, 9, // Number of jobs and machines
    5, 38, 3, 33, 2, 21, 6, 71, 7, 80, 4,  7, 1, 78, 0, 60, 8, 42, 
    5, 37, 0,  2, 7, 23, 2, 77, 4, 86, 8, 51, 3, 11, 1, 86, 6, 68, 
    5, 43, 1, 88, 7, 50, 4, 96, 6, 19, 2, 26, 8, 19, 0, 39, 3, 15, 
    7, 48, 8, 35, 1, 78, 3, 73, 0, 15, 6, 27, 2, 19, 5,  9, 4, 64, 
    4, 15, 8, 60, 7, 82, 1, 30, 2, 55, 5, 86, 6, 71, 3, 15, 0, 15, 
    8, 84, 2,  3, 3,  4, 5, 30, 0, 54, 6, 30, 7, 57, 4, 34, 1, 16, 
    3, 44, 4, 23, 2,  4, 6, 30, 0, 69, 8, 55, 7, 97, 5, 47, 1, 32, 
    4, 44, 0, 54, 8, 20, 2, 40, 6, 87, 7, 24, 1, 24, 3, 82, 5, 28, 
    7, 80, 3, 71, 4, 12, 1, 13, 5, 11, 0, 10, 8, 62, 2, 37, 6, 68
  };
  const int q5557[] = {
    9, 9, // Number of jobs and machines
    0,  2, 5,  7, 7, 64, 8, 73, 6, 54, 4, 63, 2, 59, 1, 34, 3, 40, 
    5, 47, 1, 26, 8,  5, 2, 55, 0, 87, 6,  7, 7, 76, 4, 99, 3,  4, 
    1,  2, 3, 39, 5, 16, 2, 89, 8, 71, 7, 11, 6, 23, 4, 53, 0, 55, 
    8, 77, 3, 29, 6, 38, 1, 68, 0, 75, 5, 68, 2, 50, 7, 31, 4, 96, 
    0, 33, 8, 88, 2, 61, 5, 23, 4, 27, 1, 51, 6,  2, 3, 57, 7, 91, 
    0, 82, 2, 84, 1, 37, 4, 78, 8, 79, 3, 80, 7, 67, 5, 70, 6, 93, 
    5, 23, 6, 62, 0, 86, 8,  5, 2, 70, 1, 92, 3,  5, 4, 68, 7, 49, 
    8, 90, 1, 96, 4,  9, 6, 75, 3,  8, 0, 85, 7, 63, 5, 53, 2, 25, 
    8, 50, 0, 96, 1,  9, 3, 40, 7, 15, 5,  5, 2, 16, 4, 14, 6, 44
  };
  const int q5558[] = {
    9, 9, // Number of jobs and machines
    1, 23, 7, 79, 4, 96, 8, 99, 2,  8, 3, 69, 5, 56, 0, 58, 6, 27, 
    1, 99, 8, 38, 5, 82, 4, 61, 3, 31, 6, 81, 7, 79, 2,  9, 0, 53, 
    4, 51, 3, 88, 2, 44, 6, 16, 8, 58, 1, 51, 7, 58, 5, 32, 0, 87, 
    3, 25, 2, 21, 1, 78, 4, 87, 6, 73, 5, 24, 8, 43, 0, 84, 7, 63, 
    4, 80, 0, 15, 5, 78, 6, 78, 3, 34, 8, 36, 7, 45, 1, 79, 2, 91, 
    1, 48, 7, 65, 5, 53, 2, 38, 3, 18, 4, 78, 0,  9, 6, 91, 8,  8, 
    3, 93, 7, 46, 2, 88, 5, 14, 8,  7, 0, 60, 4, 40, 6, 10, 1, 63, 
    4, 68, 6, 29, 0,  3, 3, 51, 1, 69, 8, 18, 7, 97, 5,  6, 2, 26, 
    6, 97, 5, 18, 3, 13, 0,  1, 1, 27, 2, 88, 8, 43, 7, 20, 4, 81
  };
  const int q5559[] = {
    9, 9, // Number of jobs and machines
    6,  3, 3, 95, 7, 93, 5, 66, 2, 10, 4, 95, 0, 29, 1, 69, 8, 31, 
    5, 70, 1, 22, 7, 86, 8, 13, 6, 64, 3, 89, 4, 97, 2, 43, 0, 46, 
    7,  3, 2, 74, 0, 32, 6, 61, 1, 33, 5, 30, 4, 11, 8, 28, 3, 87, 
    4, 63, 2, 23, 5, 40, 8, 57, 3, 44, 6, 14, 7, 97, 0, 14, 1,  7, 
    6, 51, 3, 13, 7, 60, 4, 21, 2, 18, 5, 20, 8, 98, 1, 37, 0, 48, 
    0, 23, 2, 31, 5,  7, 4, 93, 3,  9, 6, 90, 8, 91, 7, 77, 1, 83, 
    7, 39, 8, 84, 4, 93, 1, 25, 0, 75, 5, 33, 6, 59, 2, 88, 3, 51, 
    4, 57, 8, 62, 1, 30, 5, 78, 0, 71, 6,  6, 3, 86, 2, 58, 7, 15, 
    3, 39, 4, 61, 7, 54, 0, 57, 8, 71, 1, 78, 5, 91, 6, 66, 2, 79
  };
  const int q5560[] = {
    9, 9, // Number of jobs and machines
    8, 74, 2, 51, 7, 11, 4, 97, 3, 25, 6, 44, 1, 84, 5, 34, 0,  8, 
    5, 43, 3, 63, 8, 34, 6, 21, 2, 25, 7, 77, 1, 87, 4, 59, 0, 17, 
    5, 21, 8, 21, 1, 69, 7, 53, 4, 20, 6, 22, 0, 39, 2, 34, 3, 85, 
    6, 83, 8, 69, 2, 44, 5, 59, 1, 72, 0, 15, 3, 92, 7, 88, 4,  7, 
    2, 25, 6, 71, 5, 18, 0, 29, 4, 58, 1, 11, 3, 56, 8, 56, 7, 12, 
    0, 10, 7,  2, 4, 24, 8, 41, 2,  7, 5, 93, 3, 11, 6,  2, 1, 34, 
    0, 27, 2,  4, 3, 95, 1, 39, 4, 33, 7, 56, 6, 60, 5, 58, 8, 45, 
    2, 83, 0,  2, 1, 22, 5, 97, 3, 38, 4, 39, 8, 22, 6, 18, 7, 71, 
    8,  9, 3, 89, 7, 56, 1, 88, 2, 78, 6, 88, 0, 71, 5,  1, 4, 84
  };
  const int q5561[] = {
    9, 9, // Number of jobs and machines
    0, 22, 3, 52, 2,  9, 4, 83, 6, 36, 5, 24, 1, 25, 8, 90, 7, 58, 
    5, 74, 1,  5, 6, 85, 7, 55, 8, 42, 3, 79, 0, 46, 2, 53, 4, 17, 
    6, 59, 2, 11, 1, 16, 8, 67, 5, 16, 0, 78, 7, 93, 4, 57, 3, 29, 
    7, 68, 3, 67, 4, 53, 1, 72, 2, 63, 6, 98, 8, 39, 5, 96, 0, 42, 
    0, 96, 7, 93, 6, 45, 4, 90, 1, 38, 3, 23, 5, 54, 2, 25, 8, 81, 
    8, 44, 7, 62, 6, 27, 4, 42, 3, 95, 5, 19, 2, 90, 0, 97, 1,  7, 
    7, 77, 3, 43, 1, 40, 8,  8, 2,  6, 6, 31, 5, 61, 4, 18, 0, 64, 
    4, 47, 0, 61, 6, 59, 2, 42, 1, 81, 5, 65, 3, 82, 8,  6, 7, 25, 
    7, 24, 2, 33, 6, 44, 1, 24, 4, 89, 3, 32, 8, 73, 0, 69, 5, 12
  };
  const int q5562[] = {
    9, 9, // Number of jobs and machines
    8, 57, 1, 32, 6,  7, 2,  5, 0,  3, 3, 63, 5, 64, 4, 45, 7, 39, 
    2, 31, 1, 45, 4, 14, 3, 20, 0, 10, 5, 10, 6, 46, 7, 10, 8,  7, 
    2, 58, 0, 24, 3, 10, 7, 55, 6,  5, 5, 32, 1, 81, 8,  3, 4, 11, 
    2, 63, 3, 96, 0, 95, 8, 40, 1, 75, 6, 97, 4, 27, 7, 79, 5, 43, 
    1, 66, 7, 70, 6, 96, 8, 34, 4, 83, 0, 42, 2, 83, 3, 89, 5,  6, 
    3, 99, 0, 82, 5, 24, 6, 51, 4, 83, 1, 31, 2, 23, 8, 69, 7, 56, 
    6,  1, 8, 55, 2, 28, 3, 75, 7, 34, 1, 98, 5, 26, 4, 39, 0, 64, 
    6,  1, 1, 58, 5, 12, 8, 51, 7, 14, 0, 99, 4, 98, 2, 32, 3, 49, 
    8,  2, 1, 94, 3, 18, 6,  9, 0, 85, 2, 41, 5, 84, 7, 18, 4, 24
  };
  const int q5563[] = {
    9, 9, // Number of jobs and machines
    3,  6, 2, 19, 0, 39, 6, 77, 5, 40, 4, 64, 1, 36, 7, 11, 8, 34, 
    3, 33, 2, 60, 5, 53, 0, 75, 6,  5, 8, 53, 1, 39, 4, 58, 7, 26, 
    7, 25, 2, 74, 8, 97, 3, 19, 1, 76, 4, 95, 0,  2, 5, 75, 6, 65, 
    5, 77, 2, 21, 0, 75, 8, 92, 4, 81, 7, 35, 1, 93, 3, 93, 6, 13, 
    0, 69, 4, 91, 8,  9, 6, 12, 7,  6, 1, 45, 3, 17, 5,  3, 2, 91, 
    8, 36, 2, 51, 6, 77, 4, 16, 0, 56, 5, 85, 3, 17, 1, 49, 7, 88, 
    2, 63, 7, 46, 1, 46, 0,  2, 8, 88, 5, 10, 6, 28, 4, 46, 3,  8, 
    3, 12, 2, 56, 7, 53, 5, 97, 8, 73, 4, 19, 0, 39, 6,  1, 1, 44, 
    2, 60, 1, 31, 7, 94, 5, 83, 4, 14, 3, 26, 8, 29, 6, 16, 0, 23
  };
  const int q5564[] = {
    9, 9, // Number of jobs and machines
    5, 39, 7, 37, 6, 79, 0, 72, 4, 78, 1, 82, 8, 87, 2,  1, 3, 80, 
    2, 94, 4, 74, 5, 52, 1, 59, 8, 32, 3, 65, 0, 78, 7, 16, 6, 74, 
    4, 15, 2, 16, 7, 23, 5, 39, 0, 70, 8, 95, 1, 49, 3, 80, 6,  5, 
    8, 32, 7, 84, 4, 93, 5, 29, 2, 34, 0, 29, 1, 75, 3,  5, 6, 86, 
    3, 26, 0, 77, 2, 20, 6, 44, 1, 42, 5, 68, 7, 35, 4, 63, 8, 95, 
    3, 23, 5, 56, 4, 29, 7, 90, 8, 16, 0, 96, 6, 29, 1, 36, 2, 87, 
    3, 75, 8, 53, 1, 56, 0, 87, 5, 94, 4, 34, 7, 25, 6, 54, 2, 86, 
    4, 79, 7,  5, 1, 86, 2, 68, 6, 26, 3, 45, 0, 21, 5, 64, 8, 12, 
    8,  8, 6, 84, 2, 83, 3, 95, 4,  7, 0, 13, 5, 77, 1, 79, 7, 46
  };
  const int q5565[] = {
    9, 9, // Number of jobs and machines
    1, 19, 3, 44, 6, 87, 8, 73, 5, 60, 7, 22, 2, 76, 4, 16, 0, 25, 
    4, 48, 6, 66, 0, 74, 7, 71, 2, 85, 8, 39, 5, 84, 1, 74, 3, 51, 
    3, 59, 2, 72, 8, 40, 5,  5, 4, 52, 6, 54, 7, 69, 1, 74, 0, 17, 
    1, 53, 7, 56, 2, 18, 4, 76, 5, 90, 0, 43, 6, 30, 3, 33, 8, 43, 
    4, 70, 8, 27, 0, 24, 5, 39, 1,  6, 3, 34, 2, 30, 7, 59, 6, 18, 
    5, 36, 3, 12, 0, 29, 4, 54, 1, 87, 8, 83, 6, 55, 7, 42, 2, 66, 
    6, 28, 2, 17, 4, 87, 7, 55, 5, 56, 1, 90, 0, 97, 8, 26, 3, 52, 
    8, 52, 6, 91, 2, 10, 3, 42, 7, 72, 1, 84, 0, 65, 5, 14, 4,  6, 
    5, 14, 8, 83, 4, 73, 2, 22, 7, 88, 1, 24, 0, 97, 6,  3, 3,  7
  };
  const int q5566[] = {
    9, 9, // Number of jobs and machines
    0, 11, 5,  3, 6, 42, 3,  3, 7, 61, 1, 51, 2, 79, 8, 85, 4, 96, 
    3, 57, 0, 91, 5, 51, 4, 40, 1, 92, 8, 73, 2, 33, 7, 72, 6, 69, 
    4, 89, 6, 94, 5, 75, 8, 22, 2, 28, 0, 42, 3, 53, 1, 89, 7, 94, 
    1, 67, 6, 26, 2, 13, 0, 14, 5, 64, 8,  5, 4, 11, 3, 78, 7, 85, 
    4, 50, 0, 79, 3, 81, 8, 51, 7,  3, 6, 62, 1, 94, 2, 70, 5, 13, 
    2, 63, 5,  2, 0, 76, 7, 54, 1, 95, 8,  7, 4, 92, 6, 16, 3, 49, 
    6, 65, 8, 13, 1, 54, 3, 50, 0, 82, 7, 30, 2, 13, 4, 18, 5, 58, 
    1, 91, 8, 65, 7, 11, 0, 88, 5, 20, 6,  5, 2, 63, 4, 27, 3, 58, 
    1, 62, 0, 60, 8,  2, 7, 36, 4, 64, 5,  2, 2,  6, 6, 73, 3, 84
  };
  const int q5567[] = {
    9, 9, // Number of jobs and machines
    4, 41, 7, 55, 6, 72, 1, 84, 3, 89, 0, 89, 8, 73, 5, 64, 2, 95, 
    2, 19, 5, 62, 1, 24, 6, 96, 8, 14, 3, 76, 7, 59, 0, 50, 4, 97, 
    8, 92, 2, 62, 3, 87, 6, 70, 7, 63, 0, 89, 1, 25, 4,  9, 5, 87, 
    2, 80, 0,  2, 5, 68, 6, 55, 3,  7, 7, 32, 8, 99, 1, 22, 4, 71, 
    4,  2, 3, 85, 0, 72, 5, 74, 2, 38, 8, 45, 6, 39, 7, 41, 1, 30, 
    0, 50, 4, 96, 5,  6, 1, 24, 2, 15, 8,  4, 7, 83, 3, 74, 6, 91, 
    0, 31, 6, 28, 8, 95, 3, 25, 2, 35, 1, 14, 4, 84, 5,  2, 7,  9, 
    4, 88, 8, 14, 1, 36, 3, 20, 2, 38, 0, 52, 5, 66, 6, 40, 7, 64, 
    4, 16, 1, 75, 6, 81, 7, 81, 3, 82, 5, 62, 2, 60, 0, 77, 8, 48
  };
  const int q5568[] = {
    9, 9, // Number of jobs and machines
    3, 88, 5, 26, 1, 25, 6, 96, 2, 25, 0, 68, 4,  8, 8, 49, 7, 70, 
    7, 59, 3,  1, 8, 29, 1, 60, 0, 86, 6, 80, 5, 24, 4, 11, 2, 78, 
    4, 99, 1, 73, 3, 93, 6, 40, 8, 99, 7, 32, 0, 45, 5, 36, 2, 32, 
    5, 83, 7, 82, 8, 80, 4, 88, 1, 63, 6, 34, 2, 77, 0, 42, 3, 17, 
    4, 19, 3, 87, 5, 87, 0, 25, 7, 75, 8, 42, 1, 50, 2, 73, 6, 21, 
    5, 99, 0, 64, 7, 89, 1, 99, 4, 34, 2, 24, 6, 84, 8, 60, 3, 11, 
    5, 80, 0, 38, 3, 30, 7, 14, 1, 99, 8, 83, 6, 83, 4, 77, 2, 69, 
    4, 63, 2, 81, 0, 35, 5, 70, 6, 79, 3, 78, 8, 86, 1, 14, 7, 54, 
    6, 98, 0, 56, 1, 57, 2, 72, 4, 85, 8, 35, 7, 83, 3, 22, 5, 47
  };
  const int q5569[] = {
    9, 9, // Number of jobs and machines
    8, 92, 5, 14, 4, 95, 7, 36, 3, 20, 2, 81, 0, 11, 1, 68, 6, 11, 
    5, 31, 4, 19, 1, 75, 7, 13, 6, 55, 2, 22, 0, 97, 3, 27, 8, 48, 
    7, 82, 1, 22, 2, 14, 5, 86, 0, 24, 6, 98, 4, 48, 8, 60, 3, 50, 
    8, 26, 1, 37, 6, 35, 3, 83, 0, 61, 7, 44, 4, 86, 2, 21, 5, 28, 
    4, 81, 3, 84, 5, 80, 6, 67, 0, 86, 2, 86, 8, 27, 7, 34, 1, 76, 
    3, 32, 5, 19, 2, 39, 1, 99, 4, 14, 6, 15, 0,  4, 7, 25, 8, 73, 
    1, 80, 6, 72, 7, 19, 4, 53, 0, 66, 5, 55, 3, 92, 2, 74, 8, 52, 
    7,  8, 3, 57, 8, 38, 1, 52, 5,  1, 0, 94, 6, 61, 2, 24, 4, 97, 
    7, 86, 6, 35, 0, 22, 5, 82, 4, 94, 2, 93, 1, 93, 8, 60, 3, 55
  };
  const int q5570[] = {
    9, 9, // Number of jobs and machines
    7, 32, 2,  9, 3, 19, 1, 18, 8, 51, 4, 80, 5, 71, 6, 34, 0, 72, 
    3, 89, 1,  4, 8, 86, 0, 41, 7, 54, 4, 49, 6, 33, 2, 58, 5, 51, 
    7,  9, 6, 43, 4, 73, 3,  3, 8, 54, 5, 65, 0, 11, 1, 19, 2, 79, 
    7,  8, 0, 53, 1, 74, 4, 13, 5, 36, 6, 79, 3, 75, 8, 26, 2, 57, 
    5, 31, 0, 60, 4, 58, 3, 51, 2, 27, 6, 15, 1, 15, 7, 17, 8, 99, 
    7, 74, 2, 11, 6, 49, 0, 68, 8, 28, 5, 98, 4, 81, 1, 67, 3, 83, 
    6, 96, 8, 50, 5, 16, 1,  1, 3, 77, 0, 47, 7, 54, 4, 23, 2, 22, 
    5, 40, 2,  5, 3, 56, 7, 86, 6, 35, 8, 48, 0, 70, 4, 69, 1, 67, 
    2, 30, 0, 51, 4, 23, 7, 61, 5, 11, 3, 81, 8, 67, 6,  5, 1, 95
  };
  const int q5571[] = {
    9, 9, // Number of jobs and machines
    3, 81, 0, 60, 1, 64, 2, 14, 8, 32, 5, 41, 6, 83, 4, 89, 7, 88, 
    8, 50, 2, 78, 7, 13, 1, 89, 5, 52, 3, 55, 6, 61, 4, 46, 0, 67, 
    4, 39, 2, 10, 6,  3, 7, 17, 0, 51, 8, 26, 1, 43, 5, 99, 3,  5, 
    7, 67, 6, 47, 5, 36, 3,  3, 8, 83, 2, 47, 4, 77, 0, 10, 1, 46, 
    3, 27, 4, 23, 1, 51, 0, 64, 7, 61, 8, 94, 6, 90, 2, 40, 5, 54, 
    5,  5, 1,  6, 2, 62, 7, 67, 8, 64, 4, 59, 3, 30, 6, 57, 0, 35, 
    6, 86, 0, 58, 2, 69, 4, 77, 7, 83, 3, 73, 5, 47, 8, 29, 1,  7, 
    6, 23, 2, 80, 7, 88, 1, 52, 8, 18, 0, 33, 4, 44, 5,  9, 3, 13, 
    7, 37, 1, 12, 6, 15, 3, 39, 8, 66, 5, 56, 2, 65, 0, 25, 4, 29
  };
  const int q5572[] = {
    9, 9, // Number of jobs and machines
    7, 32, 1, 87, 3, 89, 4, 80, 6, 51, 8, 59, 2, 57, 0, 15, 5, 51, 
    8, 13, 3, 36, 4, 39, 7, 48, 5,  1, 1, 29, 0, 18, 2, 18, 6, 32, 
    1,  2, 7, 82, 0, 25, 4, 76, 3, 76, 8, 18, 5, 95, 2, 85, 6, 46, 
    5, 93, 7, 43, 0, 11, 8, 20, 3, 49, 2, 21, 1, 21, 6, 38, 4, 20, 
    5, 52, 7, 50, 3, 68, 8, 58, 2, 94, 0, 92, 4,  7, 6, 90, 1, 89, 
    4, 60, 3, 20, 6, 11, 5, 55, 1, 46, 8, 38, 7, 99, 2, 61, 0, 12, 
    2, 83, 4, 57, 6, 92, 3,  1, 1, 90, 5, 94, 8, 84, 7, 56, 0,  8, 
    2, 45, 1, 17, 0, 30, 5, 61, 3, 81, 8, 67, 6, 29, 4, 48, 7, 65, 
    5, 34, 7, 98, 2,  4, 4, 68, 0, 25, 8,  2, 1,  4, 3, 77, 6, 14
  };
  const int q5573[] = {
    9, 9, // Number of jobs and machines
    6, 64, 5, 79, 4, 91, 2, 50, 0, 22, 7, 48, 3, 30, 1, 13, 8, 83, 
    6, 10, 3, 43, 2, 96, 7, 97, 5, 90, 0,  8, 1, 28, 8, 68, 4, 83, 
    5, 18, 0, 95, 4, 15, 8, 71, 7, 78, 1, 90, 2, 28, 6, 14, 3, 79, 
    8, 42, 3, 59, 6, 11, 4, 35, 0, 78, 7, 14, 5, 86, 2, 68, 1, 45, 
    6, 15, 5, 87, 1, 90, 8, 94, 4, 52, 2,  8, 3, 17, 7, 21, 0, 14, 
    3, 27, 5, 78, 2, 76, 0, 35, 8, 86, 6, 94, 1, 73, 7, 63, 4, 80, 
    7, 39, 4, 19, 2, 74, 0, 46, 3, 66, 6, 14, 1, 10, 5, 21, 8, 14, 
    8, 45, 2, 91, 0, 26, 3, 10, 5, 14, 4, 14, 1, 23, 7, 24, 6, 43, 
    4, 39, 2, 64, 0, 47, 8, 94, 3, 97, 1, 72, 5, 99, 7, 55, 6,  9
  };
  const int q5574[] = {
    9, 9, // Number of jobs and machines
    6,  4, 0, 51, 4, 35, 7, 82, 8, 22, 2, 77, 3, 73, 1, 41, 5, 18, 
    1, 96, 3, 32, 8, 67, 0, 56, 4, 14, 6, 74, 5,  8, 7, 70, 2,  5, 
    1,  2, 4, 12, 2, 20, 3, 37, 6, 71, 5, 63, 0, 45, 7,  1, 8,  9, 
    1, 27, 2, 52, 6, 89, 0, 89, 3, 90, 5, 20, 7, 29, 8, 85, 4, 55, 
    2, 81, 6,  4, 4, 51, 7, 85, 1, 78, 8, 32, 3, 29, 5, 33, 0, 29, 
    1, 36, 3, 94, 6, 35, 7, 24, 0, 46, 8, 75, 2,  3, 5,  2, 4, 89, 
    8, 24, 7, 94, 2,  3, 3, 43, 0, 18, 6, 74, 5, 41, 1, 37, 4,  5, 
    1, 69, 7, 43, 4, 98, 6, 82, 0, 37, 5, 13, 2, 61, 3, 87, 8, 83, 
    6, 22, 8, 78, 1, 34, 4, 53, 5, 54, 0, 89, 7, 60, 2, 93, 3, 77
  };
  const int q5575[] = {
    9, 9, // Number of jobs and machines
    8, 85, 5, 72, 2, 54, 6, 64, 1, 23, 0, 33, 7, 72, 3, 80, 4, 64, 
    0, 97, 3, 21, 5,  4, 8, 35, 6, 34, 4, 94, 7, 97, 1, 50, 2, 98, 
    2,  8, 7, 96, 5, 33, 0, 98, 8, 79, 6, 11, 1,  8, 3, 62, 4, 91, 
    7, 27, 5, 54, 1,  7, 0, 20, 6, 46, 3, 69, 8, 32, 4, 51, 2, 48, 
    7,  8, 2, 71, 5, 59, 8, 30, 0, 22, 4, 58, 1, 30, 3, 54, 6, 84, 
    4, 92, 0, 82, 3, 75, 6, 71, 8, 44, 5, 35, 2, 27, 7,  5, 1, 24, 
    3, 30, 4, 64, 2, 45, 6, 23, 5, 76, 8, 86, 7, 24, 0, 90, 1,  8, 
    5, 25, 8, 35, 1,  7, 0,  9, 7,  4, 6, 32, 3, 71, 4, 76, 2, 62, 
    6, 59, 4, 99, 5, 41, 0, 96, 8, 49, 3, 26, 2, 13, 7, 45, 1, 78
  };
  const int q5576[] = {
    9, 9, // Number of jobs and machines
    5, 68, 2, 74, 6, 38, 3, 57, 4, 98, 8, 88, 1, 41, 7, 80, 0, 53, 
    3,  2, 8, 51, 7, 53, 4, 57, 0, 33, 5, 97, 2, 23, 6, 83, 1, 45, 
    2, 61, 1, 49, 7, 69, 3, 95, 6, 95, 8, 72, 4, 84, 5, 69, 0, 50, 
    0, 43, 7, 75, 3, 17, 4, 17, 1, 49, 2, 90, 6, 93, 8, 50, 5, 75, 
    3, 55, 6, 16, 0, 88, 7, 67, 5,  3, 2, 75, 8, 99, 1, 47, 4, 68, 
    7, 61, 6, 23, 3, 33, 4, 49, 2, 68, 8, 94, 0, 32, 5, 58, 1, 38, 
    1, 38, 2, 46, 3, 67, 4, 82, 5, 11, 7, 37, 6, 79, 0, 28, 8, 50, 
    8, 91, 0, 47, 4, 93, 5, 73, 3, 31, 1, 13, 2, 92, 6, 90, 7, 86, 
    1, 66, 7, 45, 4, 15, 0, 63, 5, 79, 2, 62, 8, 52, 3, 70, 6, 21
  };
  const int q5577[] = {
    9, 9, // Number of jobs and machines
    3,  2, 6, 58, 0, 83, 4, 70, 8, 60, 5, 23, 1, 99, 2, 38, 7, 14, 
    1, 75, 2, 58, 6, 59, 5, 91, 3, 82, 7, 42, 8, 58, 0, 80, 4, 71, 
    5, 36, 8, 53, 1, 19, 0, 39, 4, 94, 2, 32, 6, 90, 3, 36, 7, 97, 
    1, 61, 0, 84, 6, 60, 8, 79, 7, 23, 4, 86, 5, 56, 2, 65, 3, 28, 
    4, 83, 3, 49, 2, 39, 1,  8, 0, 34, 8, 92, 6, 33, 7, 15, 5, 35, 
    3,  5, 0, 54, 5,  8, 6, 20, 1, 96, 4, 75, 2, 95, 8, 24, 7, 16, 
    4, 61, 2, 62, 5, 98, 0, 69, 8, 78, 6, 93, 1, 61, 7, 67, 3, 18, 
    6, 84, 7, 44, 0, 57, 3, 93, 1, 85, 4, 34, 2, 73, 8, 41, 5, 20, 
    0, 18, 5, 71, 4, 69, 6, 70, 2, 12, 1, 40, 3, 45, 7, 14, 8, 89
  };
  const int q5578[] = {
    9, 9, // Number of jobs and machines
    8, 85, 1,  7, 4, 55, 5, 38, 0, 62, 3, 87, 2, 62, 6, 16, 7, 71, 
    3,  7, 6, 24, 4, 61, 5, 67, 2, 30, 0,  8, 1, 90, 8, 66, 7, 64, 
    3, 59, 0, 78, 6, 77, 5, 67, 8, 58, 2, 44, 7, 11, 1, 64, 4, 77, 
    4, 26, 8, 60, 0, 30, 7, 79, 3, 35, 5, 39, 6, 66, 1, 97, 2, 33, 
    8, 72, 5, 84, 0,  1, 1, 90, 7, 15, 3, 32, 6, 12, 4, 18, 2, 52, 
    6, 97, 0, 77, 4, 38, 7, 30, 2, 35, 3,  3, 8, 22, 5, 70, 1, 81, 
    6, 74, 0, 91, 3, 32, 7, 44, 1, 38, 8, 57, 5, 62, 4, 23, 2, 10, 
    2, 55, 6, 84, 8, 42, 4, 39, 1,  6, 5,  1, 0, 38, 3, 85, 7, 39, 
    7, 74, 1, 94, 3, 91, 0, 71, 6, 32, 4, 79, 5, 80, 2, 56, 8, 35
  };
  const int q5579[] = {
    9, 9, // Number of jobs and machines
    7, 59, 8, 29, 5, 79, 4, 36, 6, 79, 0, 18, 2,  3, 3, 83, 1,  1, 
    7, 48, 8,  3, 2, 42, 3, 38, 1, 11, 6, 73, 5, 76, 4,  2, 0, 61, 
    5, 76, 7, 91, 3, 35, 2, 46, 1, 40, 0, 51, 6, 56, 8, 67, 4, 57, 
    7,  1, 8, 39, 5, 46, 1,  6, 0, 86, 4, 70, 3, 80, 2, 77, 6, 76, 
    5, 86, 7,  3, 6, 66, 3, 40, 4, 79, 0, 90, 1, 76, 8, 97, 2, 17, 
    1, 24, 7, 41, 2, 81, 5, 62, 4, 47, 6, 61, 3, 19, 8, 12, 0, 35, 
    1, 85, 2, 31, 3, 38, 0, 53, 4, 13, 8, 18, 6, 73, 7,  1, 5, 64, 
    7, 79, 0, 26, 6, 42, 2, 42, 1, 58, 8, 91, 4, 36, 5, 17, 3, 44, 
    0, 22, 3, 38, 7, 15, 6, 54, 8, 66, 5, 12, 2, 25, 1, 88, 4, 64
  };
  const int q5580[] = {
    9, 9, // Number of jobs and machines
    2, 26, 3, 45, 5, 81, 1, 65, 6, 54, 7, 78, 8, 61, 4, 13, 0, 62, 
    7, 24, 4, 70, 6, 21, 8, 59, 1, 36, 2,  2, 5, 19, 0, 83, 3, 76, 
    0, 38, 6,  8, 4, 25, 3, 51, 1, 31, 2,  8, 5, 27, 7, 11, 8, 77, 
    1, 26, 5,  6, 3, 53, 0, 94, 8, 70, 4, 82, 7, 64, 2, 44, 6, 14, 
    0, 54, 3,  8, 6, 18, 5, 59, 2, 25, 1, 50, 7, 35, 4,  7, 8, 44, 
    7, 93, 5, 26, 4, 34, 8, 89, 2, 60, 1,  6, 6, 40, 0,  6, 3, 26, 
    0, 23, 6, 44, 4, 21, 5, 29, 1, 91, 8, 72, 7, 92, 3,  8, 2, 66, 
    5, 61, 1, 52, 2, 28, 4, 93, 6, 25, 0, 48, 3, 38, 7, 25, 8, 76, 
    0, 87, 7,  5, 6, 26, 4,  8, 5,  8, 1, 27, 8, 44, 2, 24, 3, 90
  };
  const int q5581[] = {
    9, 9, // Number of jobs and machines
    3, 12, 5, 85, 0, 24, 8, 79, 2, 64, 4, 99, 7,  1, 1, 17, 6, 52, 
    0,  1, 7, 67, 5, 41, 2,  8, 4, 83, 1, 55, 6, 46, 8, 43, 3, 37, 
    1, 30, 5, 59, 6, 87, 0, 93, 2, 35, 3, 65, 8, 41, 7, 83, 4, 37, 
    1, 68, 7, 23, 5, 15, 4, 58, 6, 18, 3, 58, 2, 82, 8, 41, 0, 61, 
    7, 76, 0, 53, 1, 79, 6, 51, 2, 23, 5, 67, 4, 88, 3, 41, 8, 49, 
    2, 34, 7, 16, 4, 66, 3, 13, 5, 26, 8, 48, 0, 85, 1, 26, 6, 68, 
    1, 27, 2, 46, 6, 81, 4,  5, 8, 61, 7, 69, 0, 45, 3, 50, 5,  9, 
    2, 70, 1, 41, 5, 49, 6, 26, 4, 43, 3, 35, 0, 39, 8, 79, 7, 12, 
    4, 42, 8, 33, 2, 97, 7,  8, 1, 69, 0, 66, 3, 31, 5, 36, 6, 55
  };
  const int q5582[] = {
    9, 9, // Number of jobs and machines
    0, 56, 8, 85, 5, 24, 4, 57, 2, 88, 7, 58, 6, 66, 1, 45, 3,  7, 
    6, 76, 5, 11, 8, 51, 7,  5, 0, 26, 1, 16, 2,  3, 3, 93, 4, 45, 
    8, 45, 0, 93, 3, 32, 5, 20, 1, 76, 6, 91, 2, 68, 7, 63, 4, 72, 
    0, 81, 3, 38, 1,  5, 5, 52, 8, 10, 2, 91, 4, 42, 7, 68, 6, 51, 
    8, 35, 2, 27, 6, 86, 1, 13, 4, 25, 0, 24, 3, 28, 7, 75, 5, 97, 
    6, 32, 7,  5, 2, 95, 3, 86, 8, 54, 4, 51, 0, 53, 5, 85, 1, 46, 
    5, 87, 8, 98, 6, 27, 3,  1, 7, 28, 0, 79, 1,  8, 2,  3, 4, 52, 
    2, 16, 7, 16, 3, 38, 6, 20, 5, 17, 4, 19, 8, 11, 1,  8, 0, 21, 
    7, 13, 6,  7, 3, 54, 1, 26, 8, 36, 2, 77, 0, 13, 4, 44, 5, 46
  };
  const int q5583[] = {
    9, 9, // Number of jobs and machines
    0, 32, 7, 17, 5, 97, 8, 56, 1, 90, 3, 87, 6, 85, 4, 67, 2, 13, 
    2, 96, 7, 60, 1, 89, 0, 17, 4, 17, 3, 72, 8, 57, 6, 37, 5, 91, 
    5, 48, 7, 60, 6, 15, 1, 52, 0, 34, 2, 53, 3, 15, 4, 43, 8, 57, 
    8,  9, 3, 54, 0, 90, 1, 83, 5,  4, 7, 85, 2,  6, 6,  3, 4,  7, 
    8, 60, 4, 13, 0, 88, 1, 72, 6, 12, 5, 98, 2, 83, 7,  4, 3, 79, 
    5, 44, 7, 18, 3, 29, 2, 53, 8, 49, 4,  1, 0, 11, 6, 18, 1, 91, 
    1, 80, 5, 85, 6, 61, 7, 21, 2,  5, 0, 84, 4, 96, 3, 13, 8, 25, 
    3, 67, 7, 78, 5, 92, 1, 56, 2, 87, 6, 98, 8, 79, 0, 50, 4, 81, 
    5, 27, 1, 35, 4, 64, 8, 23, 6, 38, 0, 70, 2, 11, 7, 29, 3, 38
  };
  const int q5584[] = {
    9, 9, // Number of jobs and machines
    3, 45, 7, 92, 6, 37, 8, 85, 1, 76, 0, 16, 2, 88, 4, 49, 5, 74, 
    8, 96, 1, 58, 2, 56, 4, 10, 6, 42, 3, 99, 7, 96, 0, 93, 5, 22, 
    6, 20, 3, 70, 0, 25, 2, 51, 4, 24, 8, 24, 7, 66, 1, 45, 5, 37, 
    5, 68, 3, 18, 4, 98, 0, 23, 2, 97, 6, 52, 1, 81, 7, 40, 8, 78, 
    6, 93, 1, 53, 8, 98, 5, 22, 3, 32, 2, 12, 4, 18, 7, 24, 0, 26, 
    6, 83, 1,  7, 8, 39, 3, 38, 5, 87, 7, 70, 4, 86, 2, 80, 0, 31, 
    7, 37, 3, 44, 2, 25, 0, 52, 8, 93, 4, 28, 5, 60, 1,  9, 6, 27, 
    8, 10, 7, 51, 5, 31, 1, 85, 3, 95, 2, 20, 4,  8, 0, 71, 6, 70, 
    8, 91, 7, 38, 3, 77, 2, 15, 0, 64, 5, 76, 1, 61, 4, 25, 6, 33
  };
  const int q5585[] = {
    9, 9, // Number of jobs and machines
    2, 55, 7, 70, 6, 95, 3, 25, 4, 82, 0, 28, 1, 90, 8, 61, 5,  3, 
    2, 35, 4, 58, 1, 18, 6, 49, 8, 70, 5, 76, 7, 16, 0,  3, 3, 56, 
    5, 63, 2, 48, 4, 22, 8,  2, 1, 65, 3, 92, 7, 79, 0, 28, 6, 47, 
    3, 52, 0, 10, 6, 62, 1, 76, 8, 81, 5, 29, 2, 78, 7, 24, 4,  6, 
    3, 72, 5, 79, 7, 73, 8, 58, 4, 85, 1, 98, 6, 40, 0, 22, 2, 95, 
    7, 92, 3, 92, 5, 16, 6, 38, 4, 39, 1, 51, 0, 89, 8, 27, 2, 60, 
    6, 58, 8, 88, 3, 60, 1, 88, 0, 65, 2, 90, 5, 72, 4, 47, 7, 27, 
    2, 16, 5, 86, 7, 25, 0, 51, 3, 14, 4, 23, 6, 74, 8, 93, 1, 46, 
    5, 47, 1, 94, 6, 80, 4, 34, 0, 12, 8,  8, 2, 93, 3, 55, 7, 92
  };
  const int q5586[] = {
    9, 9, // Number of jobs and machines
    2, 58, 7, 32, 5, 82, 6, 95, 0, 46, 1, 33, 3, 84, 8, 90, 4,  2, 
    3, 51, 5,  9, 0, 63, 1, 50, 4, 61, 2, 94, 6, 74, 8, 88, 7, 34, 
    6, 93, 1, 41, 2, 46, 3, 27, 0, 21, 7, 61, 4, 68, 8, 51, 5, 29, 
    5, 18, 4,  2, 7, 55, 1, 15, 2, 43, 3, 36, 0,  9, 8, 67, 6, 19, 
    8, 13, 6, 94, 5, 40, 4, 84, 7,  9, 2, 77, 1, 55, 3, 43, 0, 53, 
    7, 54, 3, 59, 0, 44, 5,  2, 8, 22, 4,  9, 2, 28, 6, 61, 1, 24, 
    5, 46, 7, 76, 6, 55, 3, 56, 4, 22, 1, 82, 2, 43, 8, 69, 0, 30, 
    1, 68, 5, 85, 8, 52, 2, 67, 7,  8, 6, 68, 4,  6, 3, 88, 0, 52, 
    1,  3, 5, 46, 0, 40, 6, 64, 2, 99, 8, 55, 3, 84, 4, 45, 7,  2
  };
  const int q5587[] = {
    9, 9, // Number of jobs and machines
    8, 64, 5,  8, 2, 35, 6, 34, 4, 30, 7, 78, 1,  3, 0,  2, 3, 10, 
    7, 56, 0, 52, 3, 45, 5, 81, 4, 28, 2, 18, 1, 43, 8, 51, 6, 76, 
    0, 24, 4, 69, 8, 58, 7, 64, 5, 22, 2, 25, 1, 20, 3, 89, 6, 92, 
    0, 89, 5, 58, 4, 47, 7, 98, 1, 31, 8, 90, 3, 25, 2, 63, 6, 70, 
    6, 90, 1, 63, 3, 32, 5, 20, 0, 90, 4, 28, 2, 27, 7, 49, 8, 84, 
    6, 75, 2, 29, 0, 90, 5, 34, 3, 10, 8, 44, 4, 18, 7, 11, 1, 93, 
    5, 70, 4, 70, 7, 80, 3,  2, 0, 29, 1, 86, 8, 44, 6, 39, 2, 54, 
    1, 48, 3, 18, 2, 97, 6, 34, 8, 15, 0, 86, 4, 75, 5, 98, 7, 47, 
    3, 78, 6, 47, 0, 95, 7, 21, 5, 52, 2, 68, 1, 84, 4, 70, 8, 64
  };
  const int q5588[] = {
    9, 9, // Number of jobs and machines
    7, 42, 6, 96, 3, 36, 4, 10, 0, 19, 5, 83, 2, 15, 8, 87, 1, 74, 
    7, 52, 5, 80, 1, 20, 4, 66, 3, 96, 6, 38, 0, 53, 8, 17, 2, 55, 
    2, 30, 3, 77, 5,  5, 8, 92, 1, 39, 6, 57, 0, 76, 4,  6, 7, 22, 
    2, 42, 8, 97, 6, 98, 4, 84, 0, 30, 1, 44, 5, 64, 3, 77, 7, 46, 
    2, 49, 7,  1, 6, 84, 1, 26, 4, 88, 8, 80, 5, 77, 0, 93, 3, 34, 
    4, 99, 7, 52, 0,  6, 1, 12, 3, 69, 8, 92, 2,  4, 5, 37, 6, 76, 
    6, 66, 4, 48, 5, 85, 2, 85, 8, 88, 7, 25, 1, 94, 3, 49, 0, 76, 
    5, 53, 1, 49, 6,  8, 2, 41, 7, 80, 0, 89, 3, 43, 4, 40, 8, 49, 
    5, 95, 4, 29, 1, 33, 6, 52, 3, 80, 8, 10, 7, 40, 0, 36, 2, 36
  };
  const int q5589[] = {
    9, 9, // Number of jobs and machines
    5, 60, 8, 13, 1,  4, 6, 45, 2, 98, 4, 73, 0,  9, 7, 37, 3, 23, 
    1, 60, 8, 85, 6, 93, 2, 38, 4,  9, 3,  5, 0, 93, 7, 86, 5, 12, 
    6, 85, 1, 64, 0, 65, 4, 51, 2, 89, 8, 52, 7, 16, 3, 83, 5, 14, 
    3, 61, 7, 75, 2, 77, 1, 32, 4, 76, 5, 17, 8, 82, 6, 10, 0, 37, 
    1, 67, 2, 21, 4,  2, 8, 59, 3, 79, 0, 61, 5, 44, 7, 73, 6, 31, 
    6, 39, 5, 51, 3, 76, 2,  9, 8, 96, 0, 66, 4, 82, 7,  9, 1, 19, 
    5, 56, 1, 60, 0, 68, 4,  9, 3, 13, 2, 25, 7, 96, 8, 40, 6,  3, 
    0, 83, 5,  1, 6, 15, 1, 47, 7, 30, 2, 52, 4, 17, 8, 97, 3, 22, 
    2, 11, 1, 56, 5, 76, 0, 49, 4, 87, 8, 51, 3,  9, 7, 73, 6, 84
  };
  const int q5590[] = {
    9, 9, // Number of jobs and machines
    0, 92, 3, 50, 5, 41, 1, 68, 6, 89, 8, 34, 2, 65, 4, 41, 7, 15, 
    3, 89, 7, 96, 5, 99, 6, 45, 8, 68, 0, 68, 4, 80, 2, 41, 1, 75, 
    6, 69, 0, 20, 5, 65, 4, 33, 1, 49, 7, 86, 8, 50, 2, 81, 3, 28, 
    8, 15, 1, 64, 7, 48, 2, 55, 4, 59, 3,  9, 6, 91, 5, 86, 0, 61, 
    8, 47, 3, 61, 6,  8, 7, 19, 0, 12, 4, 88, 1, 14, 2, 75, 5, 32, 
    4, 60, 1, 41, 8, 90, 7, 54, 2,  3, 5, 28, 0, 45, 3, 76, 6, 42, 
    4, 62, 0, 88, 8,  9, 3, 88, 6, 82, 5, 67, 2, 69, 1, 98, 7, 10, 
    0, 24, 1, 77, 8, 59, 7, 68, 3, 94, 6, 24, 5, 68, 4, 69, 2, 80, 
    2, 37, 7, 83, 6,  9, 8, 95, 4, 66, 3, 47, 1, 77, 5,  7, 0, 30
  };
  const int q5591[] = {
    9, 9, // Number of jobs and machines
    6, 16, 1, 72, 0, 76, 7, 47, 8, 98, 4, 55, 5, 69, 3, 13, 2, 29, 
    8, 73, 6, 33, 0, 58, 4, 94, 2, 96, 5, 21, 3, 62, 7,  6, 1, 66, 
    2, 29, 3, 23, 5, 31, 1, 73, 4, 87, 8, 64, 6, 62, 7, 75, 0, 47, 
    1,  7, 2, 95, 7, 34, 6,  8, 8, 74, 4, 25, 3, 34, 5, 18, 0, 71, 
    6, 35, 0, 26, 8, 77, 1, 33, 7, 78, 5, 15, 4, 27, 3, 52, 2,  2, 
    0, 35, 6, 53, 3, 68, 8, 21, 4, 49, 5, 50, 1, 32, 2, 11, 7, 75, 
    6, 28, 4, 45, 5, 11, 1, 29, 8, 78, 3, 44, 2, 40, 7, 11, 0, 31, 
    2, 98, 4, 62, 7, 22, 0, 24, 8, 18, 5, 19, 3, 86, 6, 87, 1, 37, 
    3, 23, 5,  6, 8, 28, 0, 82, 2, 99, 4, 24, 6, 56, 1, 43, 7, 71
  };
  const int q5592[] = {
    9, 9, // Number of jobs and machines
    2, 57, 5, 37, 7, 91, 4, 93, 0, 48, 8, 51, 3, 52, 1, 80, 6,  2, 
    8, 76, 3, 60, 0,  8, 7, 85, 2, 68, 6, 16, 5, 44, 4, 55, 1, 56, 
    2, 20, 8, 99, 1, 64, 3, 51, 0, 36, 6, 45, 7, 90, 4, 31, 5, 88, 
    2, 86, 6, 53, 3, 79, 7, 14, 0, 49, 1, 36, 8, 31, 5, 29, 4, 86, 
    8, 57, 7, 91, 4, 75, 0, 81, 3, 48, 1, 54, 6, 46, 2, 88, 5, 52, 
    5, 75, 0, 42, 2, 72, 3,  5, 8, 47, 6, 47, 1, 79, 7, 27, 4, 48, 
    7, 29, 4, 48, 6, 65, 2, 60, 8, 90, 3, 95, 5,  5, 0, 43, 1, 19, 
    6, 56, 1, 24, 7, 46, 0, 93, 3,  7, 8, 72, 5, 45, 2, 75, 4, 67, 
    1, 42, 4, 79, 5, 41, 8, 44, 7, 67, 3, 39, 2, 94, 6, 59, 0, 51
  };
  const int q5593[] = {
    9, 9, // Number of jobs and machines
    6, 25, 2, 40, 3, 44, 8, 30, 1,  2, 5, 91, 4, 16, 0, 84, 7,  3, 
    6, 43, 1, 19, 0, 42, 8, 36, 4, 13, 2, 40, 3, 38, 7, 29, 5, 16, 
    0, 56, 8, 12, 7, 33, 4, 89, 6, 19, 5, 37, 1, 37, 3, 41, 2, 17, 
    7, 60, 5, 33, 6, 49, 8, 19, 3, 67, 4, 86, 0, 19, 2, 75, 1, 73, 
    6,  3, 4, 69, 1, 24, 7, 57, 3, 63, 0, 65, 5,  1, 2, 51, 8, 84, 
    7, 32, 5, 37, 6, 60, 2, 82, 1, 34, 8, 69, 4, 76, 3, 67, 0, 86, 
    2, 29, 6, 43, 3,  7, 1,  5, 4, 57, 8, 51, 5,  9, 7, 69, 0,  3, 
    6, 46, 4,  6, 7, 19, 3, 15, 0, 22, 8, 51, 1,  4, 2, 80, 5, 98, 
    5, 74, 3, 32, 7, 74, 2, 80, 6, 42, 0, 29, 1, 18, 8,  7, 4, 42
  };
  const int q5594[] = {
    9, 9, // Number of jobs and machines
    5, 30, 7, 27, 2, 99, 0, 85, 4, 90, 1, 73, 3, 19, 8, 61, 6, 38, 
    6, 50, 4, 58, 5,  1, 2, 48, 0,  9, 3, 11, 8, 90, 1, 84, 7, 96, 
    2, 32, 3,  4, 8, 20, 5, 53, 0, 56, 7, 35, 1, 19, 4, 23, 6, 51, 
    7, 77, 6, 69, 5, 35, 2, 86, 1, 70, 4, 99, 3, 98, 0,  2, 8, 57, 
    4,  2, 2, 61, 7, 61, 8, 75, 5, 82, 3, 86, 6, 66, 1, 20, 0, 41, 
    1, 44, 3, 65, 4, 97, 8, 17, 6, 73, 5, 54, 2, 96, 0, 65, 7, 40, 
    5, 22, 2, 67, 7, 79, 6, 30, 0, 43, 4, 13, 1, 20, 3, 35, 8, 30, 
    5, 63, 7, 40, 2, 11, 4, 57, 6, 81, 3, 60, 0, 29, 1, 20, 8, 32, 
    1, 84, 5, 73, 3, 72, 4, 47, 7, 12, 0, 25, 6, 67, 8, 73, 2, 51
  };
  const int q5595[] = {
    9, 9, // Number of jobs and machines
    0, 59, 3, 29, 5, 22, 4, 50, 7, 58, 8, 94, 2,  8, 6, 23, 1, 58, 
    7, 87, 0, 84, 4, 91, 2, 34, 5, 57, 6, 31, 3, 20, 1, 91, 8,  2, 
    0, 55, 8, 45, 3, 48, 6, 69, 1, 91, 2, 70, 7, 61, 5, 46, 4, 88, 
    0, 62, 4, 36, 8, 24, 5, 60, 7, 40, 2, 59, 6, 54, 3, 68, 1, 54, 
    1, 88, 0, 96, 7, 42, 2, 95, 6, 94, 8, 76, 5, 52, 4, 39, 3, 84, 
    4, 59, 3, 38, 1, 94, 7, 10, 6, 52, 5, 73, 8, 27, 0, 20, 2, 28, 
    3, 75, 0, 90, 4, 83, 1, 37, 7,  2, 2, 31, 5, 90, 8, 41, 6, 82, 
    3, 63, 5, 22, 6,  3, 1, 88, 4, 17, 8, 68, 0,  7, 7, 80, 2, 59, 
    7, 53, 0, 87, 5, 72, 8, 45, 6, 29, 4, 38, 3, 65, 2, 99, 1, 88
  };
  const int q5596[] = {
    9, 9, // Number of jobs and machines
    3, 41, 4, 40, 1,  8, 0,  4, 8, 90, 6, 55, 5, 94, 2, 20, 7, 44, 
    1,  2, 0, 58, 6, 93, 3, 15, 5, 36, 8, 97, 4, 21, 2, 23, 7, 19, 
    0, 73, 3, 76, 6, 97, 4, 54, 2, 46, 1, 15, 7, 22, 8, 23, 5, 45, 
    7, 35, 2, 83, 1, 23, 4, 43, 8, 81, 5, 69, 6, 72, 3, 46, 0, 92, 
    3, 33, 5,  6, 4,  4, 1, 21, 8, 78, 0, 87, 6, 27, 2, 14, 7, 52, 
    3, 38, 1, 72, 4, 24, 6, 69, 8, 14, 5, 91, 2, 63, 7, 45, 0, 47, 
    5, 59, 4, 42, 8, 23, 7, 60, 0, 16, 3, 93, 6, 44, 1, 56, 2, 26, 
    2, 22, 7, 59, 5,  8, 8, 90, 1, 82, 6, 28, 0, 67, 4, 44, 3, 62, 
    2, 19, 0, 56, 4,  5, 3, 22, 5,  9, 6, 82, 7, 71, 1, 95, 8, 65
  };
  const int q5597[] = {
    9, 9, // Number of jobs and machines
    8, 24, 5, 72, 6,  2, 1, 82, 3, 51, 4, 78, 7, 79, 0, 82, 2, 51, 
    6, 95, 8, 37, 3, 88, 1, 40, 2, 73, 0, 94, 5, 51, 4,  4, 7, 79, 
    8,  2, 5, 98, 1, 76, 0,  1, 4, 63, 6, 39, 3, 57, 7, 58, 2, 13, 
    8, 18, 0, 45, 6, 20, 2, 52, 7, 20, 1, 83, 3, 91, 4, 73, 5, 40, 
    0, 45, 3, 21, 4, 76, 7, 96, 2, 26, 8, 89, 5, 36, 1, 28, 6, 12, 
    1,  1, 7, 88, 6,  7, 0, 52, 8, 58, 2,  9, 4, 92, 5, 12, 3, 84, 
    3, 45, 6, 85, 4, 58, 1, 29, 0, 82, 7, 50, 2, 72, 5, 21, 8, 29, 
    2, 67, 4, 73, 5,  9, 8, 45, 7, 66, 6, 64, 0, 27, 3, 39, 1, 40, 
    1, 35, 3,  8, 7, 68, 5, 66, 6, 15, 0, 94, 8, 17, 2, 42, 4, 22
  };
  const int q5598[] = {
    9, 9, // Number of jobs and machines
    2, 98, 8, 87, 7, 12, 1, 71, 5, 10, 0, 96, 4, 24, 6, 68, 3, 32, 
    7, 19, 2, 35, 6, 47, 8, 26, 5, 17, 0, 61, 3, 15, 1, 95, 4, 35, 
    1, 74, 6,  3, 5, 60, 2, 23, 8, 43, 3, 70, 4, 62, 0, 63, 7, 46, 
    0, 42, 1, 79, 7, 40, 2, 89, 4,  2, 3, 76, 6,  9, 5, 45, 8, 94, 
    8, 65, 7, 67, 2, 47, 4, 94, 5, 53, 6, 21, 1, 97, 3, 68, 0, 42, 
    3, 14, 2, 18, 8, 26, 0, 72, 7,  3, 6, 37, 4, 70, 1, 57, 5, 24, 
    2, 97, 4, 49, 6, 35, 0, 90, 1, 16, 5, 48, 7, 33, 8, 82, 3, 34, 
    6, 95, 1, 45, 4, 19, 7, 14, 8, 39, 0, 45, 3, 23, 2, 28, 5, 50, 
    4, 31, 0, 10, 2, 64, 8, 97, 3, 63, 7, 16, 1, 90, 6, 89, 5, 68
  };
  const int q5599[] = {
    9, 9, // Number of jobs and machines
    6, 32, 2, 12, 7, 93, 5, 26, 8,  1, 4, 63, 1, 79, 0, 58, 3, 92, 
    0, 90, 3, 96, 7, 25, 2, 27, 1, 40, 5, 10, 6, 74, 4, 42, 8, 24, 
    5, 65, 1, 23, 8, 32, 0, 81, 2,  3, 6, 99, 4, 37, 7, 71, 3, 64, 
    4, 34, 1, 69, 3, 93, 6, 64, 7, 89, 5, 36, 8, 88, 0, 36, 2, 29, 
    3, 20, 7, 88, 5, 68, 0, 35, 2, 92, 4, 47, 8, 84, 6, 96, 1, 35, 
    4, 70, 7, 47, 1, 30, 0, 30, 2,  9, 5, 91, 3, 81, 8, 17, 6, 69, 
    4, 19, 8, 97, 3, 11, 7, 51, 1, 56, 5, 81, 0, 38, 6, 25, 2, 75, 
    5, 93, 0, 55, 3, 41, 4, 20, 6, 95, 1, 38, 7, 74, 8, 22, 2, 97, 
    4, 21, 8,  9, 2, 75, 3, 36, 1, 74, 0, 34, 7, 27, 5, 73, 6, 32
  };
  const int q5600[] = {
    9, 9, // Number of jobs and machines
    4, 59, 6, 16, 5, 80, 8, 71, 2, 42, 1, 90, 3, 86, 7, 30, 0, 50, 
    0, 91, 1, 67, 6, 11, 2, 15, 8, 28, 3, 49, 5, 20, 4, 40, 7, 94, 
    7,  4, 2, 72, 1, 31, 0, 22, 8, 26, 6, 31, 4, 21, 3, 34, 5, 49, 
    6, 66, 5, 21, 2, 95, 7, 81, 8, 16, 1, 57, 4, 92, 0, 48, 3,  8, 
    7, 44, 3, 11, 8, 25, 0,  5, 2, 96, 4, 88, 6, 84, 5, 68, 1, 15, 
    8, 45, 6, 18, 7, 75, 0, 51, 1,  2, 3, 76, 2, 17, 5, 43, 4, 90, 
    8, 20, 5, 77, 4,  9, 2,  3, 0,  8, 1, 32, 6, 68, 3, 25, 7, 26, 
    2, 94, 7,  2, 4, 30, 5, 16, 0, 82, 6, 46, 3, 56, 1, 64, 8, 50, 
    4,  1, 3, 56, 7, 20, 0, 54, 1, 20, 8, 83, 6, 63, 5, 54, 2, 69
  };
  const int q5601[] = {
    9, 9, // Number of jobs and machines
    6, 28, 3, 26, 7, 52, 0, 20, 1, 11, 5, 41, 2, 79, 8, 75, 4, 87, 
    2, 36, 7,  9, 3, 66, 6, 80, 0, 15, 8, 20, 1, 18, 5, 81, 4, 67, 
    3, 19, 0, 66, 7, 95, 4, 95, 2,  7, 5, 52, 6, 74, 1, 40, 8, 79, 
    4, 59, 1,  8, 6,  2, 5, 95, 7, 83, 2, 78, 8, 46, 3, 57, 0, 16, 
    0, 41, 7, 21, 1, 54, 5, 17, 6, 98, 3, 66, 4, 18, 2, 57, 8, 98, 
    7, 41, 8, 69, 5, 29, 1, 73, 2, 38, 4, 74, 6, 64, 0, 46, 3, 42, 
    0, 24, 2, 96, 5, 30, 6, 48, 7, 10, 1,  2, 3, 71, 4, 68, 8, 90, 
    7,  7, 2, 92, 6, 93, 0, 74, 1, 23, 3, 56, 4, 35, 8,  2, 5, 33, 
    0, 26, 7, 32, 2, 22, 1, 97, 6, 19, 8, 83, 4, 14, 5, 27, 3, 93
  };
  const int q5602[] = {
    9, 9, // Number of jobs and machines
    0, 24, 7, 38, 6, 87, 5, 31, 3, 31, 1, 81, 4, 39, 2, 28, 8, 53, 
    0,  4, 7, 91, 8, 89, 4, 68, 3,  2, 1, 17, 6, 51, 2, 66, 5,  6, 
    4,  7, 7, 45, 6, 52, 5,  9, 8, 56, 1, 85, 0, 18, 2, 94, 3, 40, 
    7, 26, 8, 32, 5, 62, 0, 17, 3, 27, 6, 16, 2, 16, 4, 24, 1, 21, 
    3, 93, 7, 31, 4, 21, 2,  8, 6,  1, 5, 78, 8, 40, 1, 46, 0, 22, 
    7, 81, 6, 89, 4, 77, 0, 80, 5, 63, 8, 21, 1, 18, 2, 44, 3, 76, 
    0, 63, 5, 83, 1,  3, 4, 66, 3, 45, 8,  2, 2,  6, 6, 63, 7, 86, 
    5, 39, 3, 65, 6, 17, 8, 47, 1, 59, 2, 25, 4, 80, 7, 17, 0, 55, 
    3, 26, 5, 80, 6, 60, 0, 47, 1, 54, 7, 22, 4, 91, 8, 97, 2, 64
  };
  const int q5603[] = {
    9, 9, // Number of jobs and machines
    3, 42, 6,  3, 8, 51, 5, 92, 4, 71, 2, 15, 7, 89, 1, 22, 0, 44, 
    3, 25, 5, 83, 6, 78, 0, 98, 8, 90, 4, 55, 1, 93, 2, 99, 7, 14, 
    8, 76, 6, 63, 0, 45, 5, 25, 7,  4, 3, 40, 4, 23, 2, 15, 1, 15, 
    0, 49, 2,  6, 1, 33, 6, 92, 8, 10, 4, 93, 5, 37, 7, 84, 3, 86, 
    5, 40, 8, 51, 1, 19, 7, 62, 6, 72, 2, 44, 3, 21, 4, 23, 0, 26, 
    1, 86, 8, 53, 3, 94, 4, 93, 0, 75, 5, 69, 6, 50, 7, 14, 2, 69, 
    2, 10, 6, 56, 4, 40, 0,  5, 7, 44, 3, 99, 5,  1, 1,  7, 8, 67, 
    7, 65, 1, 80, 8,  9, 3, 36, 4, 26, 0,  9, 5, 87, 6, 78, 2, 87, 
    3, 18, 0, 54, 2, 40, 1, 13, 7, 88, 6, 26, 4, 77, 8, 83, 5, 26
  };
  const int q5604[] = {
    9, 9, // Number of jobs and machines
    4, 89, 6, 59, 5, 19, 3, 24, 8, 31, 0, 82, 1,  8, 7, 21, 2, 81, 
    4, 16, 2, 61, 8, 14, 7,  9, 5, 39, 3, 52, 0, 33, 1, 12, 6, 28, 
    5, 69, 2, 80, 3, 36, 7, 77, 0, 95, 1, 55, 6, 16, 8, 72, 4, 56, 
    4, 57, 5, 47, 2, 99, 7, 15, 0, 98, 1, 57, 6,  2, 8, 55, 3, 57, 
    3,  5, 7, 38, 2, 75, 0, 73, 4,  1, 8, 14, 6, 12, 5, 20, 1,  9, 
    5, 32, 1, 48, 3, 99, 6, 54, 2, 40, 4, 42, 0, 30, 8, 92, 7, 50, 
    7, 64, 0, 19, 6, 32, 4, 38, 5,  1, 8, 76, 3,  5, 1, 75, 2, 61, 
    5, 34, 3, 54, 6, 62, 7,  7, 0, 72, 2, 65, 4, 76, 1, 28, 8, 26, 
    2, 53, 4, 49, 3, 84, 0, 96, 6, 29, 1, 29, 8, 24, 5,  3, 7, 22
  };
  const int q5605[] = {
    9, 9, // Number of jobs and machines
    7, 75, 0,  9, 2,  2, 8, 81, 3,  3, 5, 90, 4, 27, 1, 40, 6, 26, 
    0, 39, 8, 13, 3, 42, 4, 47, 2, 44, 5,  1, 7, 47, 1, 70, 6, 72, 
    1, 89, 7, 27, 6, 76, 2, 20, 0, 60, 8, 12, 3, 22, 5, 96, 4, 57, 
    5, 90, 2, 70, 7, 65, 4, 49, 0, 31, 1, 42, 3, 83, 6, 78, 8, 21, 
    0, 39, 6, 27, 7,  3, 2, 10, 4, 35, 3, 54, 8, 64, 5, 94, 1, 75, 
    1, 67, 2, 91, 0, 96, 5,  1, 7, 61, 8, 49, 4,  8, 3, 88, 6, 36, 
    5, 32, 2, 23, 8, 92, 6, 16, 0, 44, 3, 54, 7, 41, 4, 89, 1,  2, 
    1, 90, 4, 28, 8, 31, 2, 52, 5, 46, 7, 91, 6, 28, 3,  9, 0, 18, 
    0, 78, 6, 36, 5, 65, 3, 32, 1, 94, 4, 81, 8, 84, 2, 47, 7, 73
  };
  const int q5606[] = {
    9, 9, // Number of jobs and machines
    8, 10, 3, 28, 5, 83, 0, 33, 6, 97, 2, 28, 4, 55, 7, 32, 1, 22, 
    4, 67, 3, 89, 6, 17, 0,  5, 8, 29, 7, 94, 1, 80, 2, 83, 5, 80, 
    6, 49, 1, 92, 8, 84, 3, 23, 4, 59, 2, 54, 0, 21, 7, 37, 5,  3, 
    2, 67, 1, 73, 8, 65, 5, 36, 3, 11, 6, 37, 7, 88, 0, 23, 4, 29, 
    5, 14, 8, 31, 4, 69, 3, 21, 1,  9, 7, 97, 6, 95, 0, 57, 2, 41, 
    1, 22, 0, 35, 8, 41, 6, 19, 2, 22, 7, 69, 5, 54, 3, 89, 4, 59, 
    3,  2, 6,  3, 4, 81, 1, 56, 7, 20, 8, 87, 0, 37, 2, 93, 5, 84, 
    4,  9, 5,  6, 2, 55, 7,  6, 8,  1, 1, 66, 0, 86, 3, 95, 6, 51, 
    2, 16, 5, 97, 7, 38, 8,  2, 3,  6, 1, 90, 4, 51, 0, 23, 6, 38
  };
  const int q5607[] = {
    9, 9, // Number of jobs and machines
    2, 73, 0,  6, 7, 29, 4,  8, 1, 95, 5,  9, 8, 41, 6, 17, 3, 16, 
    7,  1, 2, 39, 3, 49, 6, 48, 1, 91, 4, 93, 5, 58, 8, 11, 0, 12, 
    0, 65, 5, 24, 7, 35, 3,  8, 6, 11, 4,  3, 8, 28, 1, 68, 2, 42, 
    5, 23, 7, 72, 4, 56, 2, 40, 6, 97, 1, 88, 8, 92, 0, 67, 3, 37, 
    7, 66, 0, 28, 5, 57, 1, 26, 6, 76, 8, 98, 2, 65, 4, 76, 3, 68, 
    4, 52, 1, 70, 8, 74, 2, 88, 5, 86, 7, 79, 0, 49, 3, 88, 6, 58, 
    4,  2, 3, 53, 5, 45, 1, 99, 0, 56, 7, 17, 2, 75, 8, 73, 6, 70, 
    4, 43, 6, 45, 5,  8, 8, 55, 2, 32, 3, 15, 1, 15, 7, 35, 0, 33, 
    1,  5, 2, 69, 0, 51, 6, 78, 5, 91, 8,  8, 7, 71, 3, 58, 4, 15
  };
  const int q5608[] = {
    9, 9, // Number of jobs and machines
    8, 60, 3, 38, 7, 74, 5, 62, 1, 44, 2, 73, 4, 51, 6, 85, 0, 56, 
    8,  4, 7, 25, 6,  3, 4, 74, 1, 39, 3, 72, 5, 88, 0, 29, 2, 68, 
    3, 44, 7,  7, 5,  6, 2, 58, 8, 93, 6, 47, 1, 56, 0, 29, 4,  3, 
    8, 18, 2, 65, 6, 26, 0, 34, 5, 36, 7, 90, 4, 81, 1, 58, 3, 98, 
    4, 89, 0, 94, 5, 59, 3, 57, 1, 70, 6, 62, 2, 60, 8, 99, 7, 31, 
    6, 77, 0, 72, 7, 62, 8, 86, 5, 58, 1, 28, 3, 34, 2, 94, 4, 90, 
    0, 11, 2, 26, 3, 95, 1, 93, 6, 60, 4,  8, 8, 57, 5, 50, 7, 82, 
    6, 44, 7, 64, 3, 29, 2, 29, 1, 91, 5, 31, 4,  5, 0, 98, 8, 62, 
    2, 71, 5, 49, 7, 14, 0,  4, 3, 23, 1, 89, 6, 39, 4, 34, 8,  6
  };
  const int q5609[] = {
    9, 9, // Number of jobs and machines
    4, 89, 1, 90, 2, 38, 6, 54, 8, 37, 5, 57, 7, 94, 3, 28, 0, 53, 
    1, 63, 7, 97, 8, 93, 5, 24, 2, 83, 3, 88, 4, 53, 0, 30, 6, 24, 
    1, 14, 6, 29, 8, 36, 3, 72, 5, 13, 2,  7, 0, 69, 4, 50, 7, 71, 
    4, 49, 5, 79, 3, 13, 6, 53, 1, 36, 7, 14, 2, 94, 0, 48, 8, 21, 
    7,  8, 0, 90, 5, 70, 3, 50, 4, 25, 2,  6, 1, 21, 6, 15, 8, 42, 
    1, 22, 3, 14, 4, 14, 7, 55, 5,  3, 2, 80, 6, 54, 8, 29, 0, 90, 
    0, 22, 4, 19, 5, 50, 6, 87, 8, 29, 2, 98, 1,  7, 7, 88, 3, 58, 
    8,  2, 1, 27, 2, 32, 0, 56, 4,  9, 7, 65, 6, 60, 5, 70, 3, 33, 
    0, 26, 5, 95, 2, 14, 8, 63, 6, 75, 4,  5, 1, 93, 7, 39, 3,  7
  };
  const int q5610[] = {
    9, 9, // Number of jobs and machines
    5, 45, 8, 80, 1, 33, 4, 26, 3,  8, 2, 88, 7, 20, 0, 45, 6, 20, 
    0, 91, 1, 67, 3, 60, 7,  2, 5, 20, 8, 64, 2, 68, 6, 35, 4, 56, 
    4, 72, 3, 23, 2, 66, 6, 46, 8, 57, 0, 48, 1, 52, 5, 67, 7, 82, 
    8, 88, 6, 98, 1, 38, 3, 47, 7, 79, 5,  2, 2, 69, 4, 22, 0, 22, 
    2, 95, 5, 44, 6, 32, 3,  6, 7, 49, 1, 16, 4, 36, 0, 15, 8,  8, 
    5, 26, 7, 85, 6, 15, 4, 75, 1, 71, 3, 83, 2, 62, 0, 62, 8, 17, 
    7, 67, 1, 62, 8, 23, 2, 74, 3, 96, 5, 50, 4, 54, 0,  2, 6, 73, 
    1, 10, 0, 17, 5, 17, 8,  8, 6, 15, 4, 55, 2, 95, 7, 98, 3,  2, 
    7, 31, 0, 87, 2, 15, 4, 39, 3, 58, 1, 12, 8, 24, 6, 77, 5, 51
  };
  const int q5611[] = {
    9, 9, // Number of jobs and machines
    0,  2, 4, 79, 7, 91, 6, 38, 2, 97, 8, 57, 1, 93, 3,  2, 5, 82, 
    4, 70, 8, 53, 6, 51, 7, 65, 0, 24, 2, 82, 5, 28, 1, 94, 3, 92, 
    7, 73, 1, 18, 6, 38, 3, 96, 5, 42, 8, 11, 2, 54, 4, 20, 0,  1, 
    7, 84, 0, 82, 3, 59, 4, 39, 8, 74, 2, 53, 5, 21, 6, 80, 1, 11, 
    8, 55, 7, 97, 0,  6, 3, 22, 1, 28, 2, 67, 5,  4, 4, 99, 6, 70, 
    8, 67, 6, 24, 2,  4, 0, 23, 3, 80, 7, 31, 4, 49, 1,  1, 5, 74, 
    4, 12, 3, 56, 2, 33, 7, 20, 0, 86, 1, 30, 8, 57, 5, 63, 6, 21, 
    1, 77, 8, 92, 0,  5, 6, 63, 7, 18, 5, 83, 2,  1, 4, 10, 3, 66, 
    1, 49, 2, 13, 3, 53, 4, 91, 5, 20, 8, 53, 0,  9, 7, 17, 6,  6
  };
  const int q5612[] = {
    9, 9, // Number of jobs and machines
    7, 13, 5, 26, 6, 58, 4, 17, 8, 45, 0, 31, 1, 53, 3, 90, 2,  6, 
    1, 15, 5, 81, 7, 81, 3, 42, 0, 14, 2, 32, 8, 56, 6, 20, 4, 82, 
    8, 34, 0, 31, 2, 94, 3, 75, 1, 24, 5, 58, 4, 32, 6, 13, 7, 68, 
    7, 80, 8, 10, 6,  9, 0, 55, 2, 47, 4,  4, 5,  9, 1, 17, 3, 88, 
    1, 64, 2, 18, 6, 54, 3, 33, 7, 29, 8, 35, 5, 52, 4, 63, 0, 36, 
    2, 92, 3, 61, 7, 55, 8, 68, 6, 88, 0, 67, 5, 85, 4, 67, 1, 96, 
    7, 40, 1, 53, 0, 11, 3, 52, 8, 20, 2, 88, 4, 90, 6, 64, 5, 60, 
    6, 26, 7, 48, 2, 84, 4, 77, 5, 73, 8, 72, 3, 53, 1, 69, 0, 77, 
    5, 56, 4, 17, 6, 72, 1, 14, 8, 71, 3, 37, 7, 10, 0, 52, 2, 61
  };
  const int q5613[] = {
    9, 9, // Number of jobs and machines
    2, 99, 8, 10, 7, 44, 0, 49, 1,  3, 5, 62, 4, 63, 3, 93, 6, 82, 
    4, 95, 0, 58, 5, 80, 8, 18, 1, 29, 7, 54, 6, 48, 3, 58, 2, 76, 
    4, 68, 7,  7, 0, 16, 5, 45, 8, 84, 6, 42, 2, 99, 3, 27, 1, 10, 
    4, 49, 3, 36, 1, 75, 5,  2, 0, 39, 6, 36, 7, 25, 2, 87, 8, 73, 
    8, 26, 1,  7, 5, 17, 7, 92, 4, 45, 6, 69, 0, 13, 2, 66, 3,  8, 
    2, 92, 5, 32, 6,  1, 7, 14, 8,  5, 3, 67, 1, 94, 0, 12, 4, 13, 
    0,  4, 8, 63, 7, 23, 6, 26, 4, 38, 1, 80, 2, 29, 3, 57, 5, 22, 
    3,  9, 6, 38, 4, 59, 2, 78, 8, 90, 7, 22, 0, 43, 5, 26, 1, 58, 
    5, 38, 4, 72, 0, 92, 1, 93, 8, 79, 6, 76, 7, 21, 2, 28, 3, 49
  };
  const int q5614[] = {
    9, 9, // Number of jobs and machines
    1, 18, 4, 74, 3, 98, 0, 17, 8, 58, 2, 57, 6, 65, 5, 11, 7, 36, 
    3, 60, 4, 72, 5, 22, 0, 83, 7, 37, 6, 49, 8, 74, 1, 21, 2, 50, 
    7, 12, 3, 84, 0, 89, 1,  1, 4, 18, 5,  5, 8, 45, 6, 92, 2, 67, 
    0, 86, 6, 39, 3, 61, 1, 35, 5, 16, 4, 37, 2, 47, 8, 19, 7, 11, 
    0, 35, 2, 42, 8, 43, 7, 19, 6, 92, 3, 82, 5, 59, 4, 76, 1, 85, 
    2,  7, 8,  4, 5, 30, 1, 42, 0, 13, 4, 63, 7, 54, 6, 61, 3, 93, 
    7, 84, 8, 48, 3, 13, 2, 91, 6, 80, 4, 19, 1, 31, 0, 78, 5, 46, 
    5, 51, 4, 86, 6, 43, 7, 46, 3, 49, 0,  7, 1, 76, 8, 58, 2, 22, 
    8, 90, 2,  9, 3, 18, 5, 19, 1, 31, 7, 56, 0, 97, 6, 72, 4, 12
  };
  const int q5615[] = {
    9, 9, // Number of jobs and machines
    6, 21, 7, 29, 8,  3, 1, 44, 2, 12, 5, 13, 3, 32, 4, 64, 0, 75, 
    5, 73, 6, 91, 0, 33, 2, 26, 7, 67, 3, 45, 1, 98, 4, 63, 8, 27, 
    6, 67, 7, 55, 5, 32, 0, 98, 2,  6, 4, 54, 3, 65, 1, 92, 8, 78, 
    2, 12, 3, 30, 5, 72, 6, 47, 0, 86, 4, 17, 7, 68, 8,  7, 1, 43, 
    7, 69, 2,  6, 5, 64, 1, 44, 3, 88, 0, 58, 4, 84, 6, 57, 8, 65, 
    7, 99, 6,  6, 8, 75, 4, 89, 1, 98, 0, 47, 2, 78, 5, 31, 3,  9, 
    7,  8, 8, 41, 3, 95, 2, 47, 4, 13, 5, 29, 0, 47, 1, 99, 6, 84, 
    4, 88, 0, 69, 6, 69, 3, 14, 5, 23, 2, 51, 7, 21, 8, 82, 1,  5, 
    5, 86, 4, 98, 0, 86, 3, 74, 6,  1, 8, 67, 1, 56, 2, 41, 7, 90
  };
  const int q5616[] = {
    9, 9, // Number of jobs and machines
    3, 22, 7, 70, 1,  3, 8, 50, 5, 42, 4, 70, 0, 54, 2, 38, 6, 15, 
    3, 96, 8, 63, 0, 22, 5, 21, 7, 15, 6, 40, 4, 40, 1, 16, 2, 96, 
    2, 10, 0,  5, 3,  5, 8, 70, 5, 68, 7, 69, 1, 58, 4, 61, 6,  7, 
    7, 80, 3, 33, 2,  6, 8, 25, 6, 45, 1, 80, 4, 63, 5, 37, 0, 54, 
    5, 68, 7, 35, 3, 23, 1, 65, 4, 65, 8, 13, 0, 97, 6, 89, 2, 54, 
    1, 15, 7,  7, 5,  1, 3, 15, 4, 84, 0, 83, 8, 73, 2, 60, 6,  9, 
    1,  5, 2, 63, 8, 21, 5, 99, 7, 95, 3, 31, 6, 86, 0, 26, 4, 52, 
    5, 50, 8, 51, 4, 21, 2, 89, 6, 45, 7, 97, 1, 40, 3, 27, 0, 23, 
    3, 95, 5, 65, 1, 31, 2, 42, 6, 58, 4, 62, 0, 12, 7, 72, 8, 56
  };
  const int q5617[] = {
    9, 9, // Number of jobs and machines
    6, 71, 4, 35, 1, 59, 3, 82, 2, 17, 0, 33, 8, 77, 7, 95, 5, 78, 
    2, 98, 7,  5, 3, 19, 4, 89, 8, 57, 5, 44, 0, 68, 1, 46, 6, 32, 
    1, 53, 0, 57, 5, 84, 7, 19, 8,  2, 3, 23, 4, 16, 2, 74, 6,  7, 
    3, 95, 0, 50, 6, 61, 1, 54, 8, 44, 4, 44, 5, 73, 2, 24, 7, 25, 
    8, 52, 4, 86, 0, 20, 7, 38, 3, 16, 2, 73, 5,  1, 6, 52, 1, 49, 
    6, 42, 0, 55, 3, 39, 5, 78, 8, 42, 4, 10, 7,  7, 1, 98, 2, 83, 
    4, 47, 3, 18, 8, 94, 7, 79, 5, 86, 2, 54, 6,  9, 0, 61, 1,  7, 
    6, 68, 8, 85, 3, 73, 5, 65, 7, 86, 0, 58, 1, 14, 2, 45, 4, 94, 
    2, 64, 3,  9, 8, 50, 0, 78, 7, 43, 6,  5, 5, 33, 4, 80, 1, 42
  };
  const int q5618[] = {
    9, 9, // Number of jobs and machines
    5, 91, 0, 29, 7, 69, 1, 54, 3,  2, 2, 95, 4, 42, 8, 79, 6, 84, 
    3,  5, 4, 52, 2, 42, 1, 62, 5, 39, 6, 42, 0, 49, 8, 51, 7, 20, 
    4, 31, 3,  4, 1, 30, 5, 59, 7, 45, 8, 57, 2, 94, 6,  5, 0, 31, 
    5, 85, 3, 86, 7, 24, 4, 74, 2, 48, 1, 23, 8, 95, 0, 46, 6, 26, 
    7, 49, 1, 58, 5, 94, 2,  6, 3,  8, 8,  6, 6, 68, 0, 61, 4, 23, 
    6, 67, 7, 79, 1, 71, 3, 79, 4,  5, 5, 55, 2, 98, 0, 86, 8, 16, 
    8, 17, 7,  5, 6, 11, 3, 28, 0, 18, 2, 58, 4, 52, 5, 87, 1,  8, 
    4, 39, 0, 36, 3, 61, 1, 48, 6, 86, 8,  4, 2, 59, 7, 57, 5, 97, 
    8, 56, 7, 81, 6, 22, 4, 20, 5,  7, 2, 37, 0, 45, 1,  5, 3, 89
  };
  const int q5619[] = {
    9, 9, // Number of jobs and machines
    8, 59, 5, 99, 6, 74, 2, 93, 1, 15, 4, 67, 7, 98, 0, 24, 3, 17, 
    5, 40, 1, 50, 4,  5, 2, 63, 6, 32, 7, 27, 8, 54, 0, 33, 3, 40, 
    4, 54, 1, 61, 2,  5, 7, 75, 0, 84, 8, 63, 3, 55, 6, 31, 5, 80, 
    4, 61, 6, 31, 8,  6, 3, 58, 2,  7, 1,  3, 5, 77, 0, 94, 7, 12, 
    5, 32, 8, 73, 6, 21, 3,  2, 4, 77, 1, 79, 7, 23, 2, 98, 0, 10, 
    5, 38, 3, 54, 8,  1, 4, 50, 0,  1, 1, 82, 6, 55, 2, 65, 7, 67, 
    0, 41, 4, 52, 2, 42, 1, 73, 8,  9, 6, 52, 3, 50, 5, 93, 7, 54, 
    1,  4, 2, 63, 6, 65, 8, 57, 0, 17, 5, 97, 7, 88, 4, 25, 3,  2, 
    1,  9, 7, 95, 2,  6, 3, 12, 4, 47, 5, 53, 6, 54, 0, 12, 8, 32
  };
  const int q5620[] = {
    9, 9, // Number of jobs and machines
    3, 10, 8, 33, 0, 40, 1, 34, 4, 76, 2, 84, 5,  8, 6, 70, 7, 33, 
    4, 95, 5, 41, 0, 69, 8, 65, 3, 20, 2, 90, 1, 91, 7,  7, 6, 84, 
    6, 88, 7, 34, 2, 37, 8, 11, 3, 66, 4, 61, 1, 43, 5, 12, 0, 95, 
    4,  7, 1, 34, 0, 91, 8, 39, 7, 84, 6, 60, 5, 30, 2, 42, 3, 90, 
    5, 48, 7, 65, 6, 26, 3, 15, 0, 57, 8, 29, 2, 92, 4, 70, 1, 15, 
    0, 16, 7, 74, 6, 48, 2,  3, 1, 78, 3, 63, 4, 37, 5, 51, 8, 53, 
    2, 54, 7, 19, 1,  5, 3, 28, 0, 33, 5, 42, 8, 16, 4,  7, 6, 97, 
    8, 88, 4, 73, 6, 90, 0, 94, 2, 88, 1, 17, 7, 47, 5, 11, 3, 58, 
    6, 43, 7, 75, 1, 33, 5, 91, 8, 27, 4,  8, 0, 62, 2, 19, 3, 31
  };
  const int q5621[] = {
    9, 9, // Number of jobs and machines
    5, 97, 6, 57, 4, 41, 3, 83, 8, 56, 7,  8, 1, 51, 0,  3, 2,  6, 
    2, 38, 8, 64, 3, 48, 7, 98, 1, 51, 4,  9, 6, 60, 5, 91, 0, 35, 
    6, 32, 8, 83, 7, 85, 0, 32, 3, 64, 5, 42, 1, 26, 2, 82, 4, 80, 
    5, 31, 3, 95, 6, 47, 8, 81, 7, 87, 4, 11, 2,  3, 0, 48, 1,  2, 
    7, 36, 6, 32, 8, 32, 4, 17, 5, 51, 1, 35, 3, 49, 2, 37, 0, 42, 
    2, 30, 1, 51, 0, 23, 6, 39, 5, 91, 8, 58, 4, 86, 3, 98, 7, 18, 
    1, 79, 2, 52, 3, 71, 8, 64, 5, 58, 7, 75, 6,  5, 4, 75, 0, 13, 
    4, 69, 8,  8, 0, 98, 2, 70, 5, 35, 1, 87, 6, 43, 3, 99, 7, 80, 
    0,  9, 2, 23, 5, 95, 3, 49, 6, 97, 8,  6, 7, 34, 1, 16, 4, 80
  };
  const int q5622[] = {
    9, 9, // Number of jobs and machines
    7, 89, 6, 84, 0, 12, 1, 11, 8, 72, 3, 42, 2, 56, 5, 83, 4, 42, 
    1, 25, 3, 28, 8, 52, 6, 46, 7, 71, 5, 14, 4, 20, 2, 90, 0, 51, 
    7, 79, 8, 27, 4, 10, 0, 89, 2, 45, 3, 14, 5, 73, 6, 62, 1, 73, 
    3, 29, 7, 28, 6, 92, 8, 25, 4,  4, 0, 72, 5,  5, 1, 38, 2, 44, 
    2, 89, 1, 77, 3, 23, 7, 22, 0, 52, 4, 31, 6, 42, 5, 46, 8, 16, 
    4, 58, 8, 62, 0, 79, 5, 18, 2,  4, 6, 41, 1, 17, 3, 36, 7, 82, 
    5, 52, 7, 89, 3, 19, 4, 47, 2, 71, 1, 79, 6, 48, 0, 17, 8, 16, 
    5, 86, 0, 50, 2, 24, 3, 31, 4, 79, 6, 64, 7,  7, 1, 52, 8, 82, 
    7, 80, 1, 77, 0, 29, 3, 47, 6, 15, 2, 35, 8, 28, 4, 94, 5, 12
  };
  const int q5623[] = {
    9, 9, // Number of jobs and machines
    8, 52, 2, 90, 4, 39, 0, 44, 7, 99, 6, 11, 3, 19, 1, 34, 5, 45, 
    1, 68, 2, 71, 4, 56, 0, 80, 3, 15, 8, 15, 5, 95, 6, 78, 7, 95, 
    2, 56, 8, 68, 6, 29, 3, 42, 5, 32, 7, 89, 1, 50, 0, 57, 4, 12, 
    3, 38, 6, 15, 1, 57, 8, 42, 5, 97, 2, 81, 0, 77, 4, 70, 7, 13, 
    7, 22, 2,  1, 3, 84, 5, 21, 4, 22, 1, 17, 6, 86, 0, 91, 8, 31, 
    1, 83, 4, 56, 0, 84, 5, 62, 8, 44, 6, 28, 7,  9, 2, 71, 3, 51, 
    4, 75, 1, 87, 3, 42, 2, 82, 6, 13, 0, 38, 8, 75, 5, 20, 7, 15, 
    8, 93, 5, 83, 6, 54, 1, 27, 3, 27, 0, 62, 7, 93, 4,  4, 2, 26, 
    5, 87, 8, 35, 6, 33, 1, 14, 4,  1, 0, 13, 7, 92, 3, 49, 2, 68
  };
  const int q5624[] = {
    9, 9, // Number of jobs and machines
    2, 53, 7, 72, 0, 24, 4, 40, 1, 24, 5, 20, 8, 35, 6, 42, 3, 74, 
    6, 70, 7, 43, 2, 18, 8, 92, 1, 39, 0, 10, 4, 60, 3, 44, 5, 94, 
    5, 33, 1, 68, 4, 64, 0, 37, 7,  4, 3, 55, 2, 51, 8, 34, 6, 38, 
    7, 99, 0, 47, 5, 84, 2,  8, 6, 99, 4, 94, 1, 96, 8, 35, 3, 57, 
    5, 82, 0, 32, 3, 32, 8, 47, 1,  3, 4, 46, 7, 39, 2, 94, 6, 63, 
    2, 46, 0, 96, 1, 18, 7, 96, 6, 41, 4, 59, 8, 57, 3, 68, 5, 65, 
    8, 84, 5, 24, 0, 82, 2, 97, 6, 75, 1, 85, 3, 93, 4, 80, 7, 12, 
    4, 35, 7, 13, 0, 10, 2, 32, 1, 65, 3, 56, 6,  3, 5, 63, 8, 73, 
    6, 75, 4, 48, 7, 96, 3, 76, 2, 85, 0, 36, 5, 10, 1, 38, 8, 90
  };
  const int q5625[] = {
    9, 9, // Number of jobs and machines
    5, 30, 1, 67, 8, 18, 6, 11, 0, 87, 3, 63, 4, 35, 2, 88, 7, 61, 
    7, 64, 6, 64, 2, 54, 5, 51, 3, 91, 1, 36, 8, 43, 0, 70, 4, 55, 
    2, 36, 4, 22, 8, 69, 1,  2, 3, 43, 5, 12, 6, 61, 7, 59, 0, 12, 
    7, 94, 1, 82, 5, 19, 0,  6, 3, 54, 6, 44, 2, 28, 8, 34, 4, 62, 
    4, 53, 2, 61, 3, 90, 6, 18, 8, 49, 0, 89, 1, 44, 7, 63, 5, 89, 
    7, 18, 0, 45, 1, 96, 2, 90, 4, 80, 5, 21, 6, 99, 8,  3, 3, 64, 
    6, 54, 4, 99, 0, 32, 3, 81, 1, 75, 7, 50, 2, 52, 5, 33, 8, 35, 
    6, 55, 4, 59, 8, 77, 1, 23, 5, 69, 7, 85, 3, 10, 0, 34, 2, 69, 
    5, 88, 2, 41, 7,  2, 3, 99, 0, 41, 6, 48, 1, 52, 4, 91, 8,  5
  };
  const int q5626[] = {
    9, 9, // Number of jobs and machines
    1, 91, 7, 52, 5, 70, 6,  6, 8, 91, 4, 35, 0, 60, 2, 56, 3,  4, 
    3, 91, 6, 91, 1,  2, 0,  1, 2, 55, 4, 11, 5, 13, 8, 25, 7, 52, 
    4, 34, 8, 65, 2, 38, 0,  4, 6,  6, 1, 87, 3, 73, 7, 80, 5, 99, 
    7, 51, 2, 61, 5, 63, 1, 14, 6, 34, 0, 46, 4, 80, 8, 79, 3, 88, 
    5, 87, 1, 21, 4, 64, 7, 72, 3, 79, 2, 70, 8, 88, 6, 82, 0, 24, 
    4, 77, 1, 32, 6, 56, 0, 69, 2, 96, 3, 30, 8, 84, 7, 49, 5, 98, 
    3, 56, 2, 66, 8, 44, 5,  9, 7, 80, 0,  8, 6,  2, 1, 53, 4, 78, 
    2, 10, 4, 21, 0, 74, 5, 12, 7, 48, 6, 24, 3,  1, 1, 76, 8, 16, 
    2, 51, 8, 37, 5, 63, 7, 57, 4, 32, 6, 90, 1, 62, 3, 10, 0, 88
  };
  const int q5627[] = {
    9, 9, // Number of jobs and machines
    7, 48, 0, 62, 6, 13, 1, 89, 2, 87, 3, 59, 8, 14, 5,  6, 4, 53, 
    0, 48, 7, 64, 3, 88, 5, 80, 6, 63, 1, 27, 2, 10, 8, 40, 4, 13, 
    4, 50, 3, 72, 1, 56, 7, 33, 2, 19, 0, 83, 6, 18, 8, 35, 5, 51, 
    3, 94, 5, 54, 1, 10, 6, 11, 7, 44, 0, 66, 8, 40, 2,  5, 4,  2, 
    3, 13, 6, 11, 4, 97, 2, 22, 8, 49, 5, 86, 1, 64, 0,  2, 7, 75, 
    7, 37, 6, 18, 2, 71, 0,  2, 3, 27, 5, 92, 4, 77, 8, 30, 1, 44, 
    8, 43, 2, 82, 6, 67, 5, 89, 7, 25, 4,  5, 3, 23, 0, 31, 1, 36, 
    5, 10, 4, 42, 3, 28, 2, 91, 7, 10, 6,  2, 1, 19, 8, 41, 0, 78, 
    8, 71, 0, 25, 5, 32, 2, 54, 1, 92, 3, 63, 4, 30, 6, 36, 7, 33
  };
  const int q5628[] = {
    9, 9, // Number of jobs and machines
    3, 33, 2, 31, 1, 28, 6, 26, 0, 98, 8, 85, 4, 40, 7, 26, 5, 75, 
    1, 33, 0, 13, 6,  6, 8, 57, 4, 41, 2,  1, 3, 30, 7, 30, 5, 16, 
    6, 53, 3, 96, 5, 85, 2, 92, 8, 15, 0, 66, 1,  1, 7,  1, 4, 63, 
    6, 74, 3, 20, 7, 91, 0, 17, 1, 43, 4, 32, 8, 52, 5, 92, 2, 32, 
    8, 71, 6, 65, 3, 95, 7, 82, 4, 59, 0, 70, 1,  3, 2, 54, 5, 81, 
    6, 60, 1, 58, 7, 55, 5, 21, 0, 55, 3,  5, 4, 88, 2, 87, 8, 57, 
    6, 20, 8, 53, 1, 87, 7, 94, 2, 70, 3, 28, 4, 81, 5, 66, 0, 11, 
    8,  8, 1, 30, 7, 13, 3,  5, 2, 48, 4, 88, 6, 26, 5, 96, 0, 79, 
    7, 48, 0, 65, 3, 55, 4, 56, 8, 51, 6, 70, 1, 66, 2,  1, 5, 53
  };
  const int q5629[] = {
    9, 9, // Number of jobs and machines
    0, 23, 6, 25, 4, 11, 3, 26, 5, 32, 2, 85, 7, 96, 1, 27, 8, 50, 
    7, 25, 8, 18, 4, 15, 2, 50, 1,  4, 6, 91, 0, 88, 5, 30, 3, 96, 
    0, 24, 4, 48, 3, 73, 1, 40, 8, 81, 7,  1, 2, 28, 5, 84, 6, 73, 
    3, 67, 7, 29, 1, 91, 8, 87, 5, 63, 0, 46, 6, 88, 4, 76, 2, 22, 
    7, 18, 6, 88, 1, 62, 0, 17, 5, 73, 4, 57, 2, 53, 3, 80, 8, 17, 
    0, 14, 7, 90, 5, 27, 4, 81, 1, 94, 8,  7, 6,  8, 2, 48, 3, 77, 
    0, 28, 7, 96, 4, 80, 2, 80, 8, 82, 5, 45, 1, 38, 6, 18, 3, 15, 
    0, 22, 6,  1, 3, 43, 8, 46, 4, 37, 2, 70, 5, 22, 7, 57, 1, 52, 
    2, 23, 8, 14, 1, 59, 6, 44, 7, 13, 5, 43, 4, 93, 3, 78, 0,  6
  };
  const int q5630[] = {
    9, 9, // Number of jobs and machines
    7, 45, 0, 56, 3, 87, 1, 46, 5, 79, 4, 41, 8, 53, 2, 22, 6, 53, 
    8, 28, 4, 33, 6, 53, 7, 87, 1, 73, 3, 76, 0, 14, 2, 31, 5, 44, 
    3, 36, 0, 25, 2, 64, 5, 83, 7, 67, 6, 56, 8,  3, 1, 79, 4,  6, 
    3, 70, 1, 15, 0, 34, 2, 38, 7, 94, 6, 20, 8, 60, 5, 37, 4, 49, 
    2, 84, 7, 93, 8, 17, 0, 77, 1, 72, 6, 22, 5, 74, 4, 18, 3, 92, 
    5, 89, 8, 64, 7, 32, 1, 77, 6, 20, 3, 16, 2, 98, 0, 88, 4, 49, 
    5, 12, 7, 72, 0, 97, 3,  7, 1, 79, 6, 87, 8, 98, 2, 39, 4, 32, 
    3, 12, 7, 24, 2, 73, 8, 65, 0, 22, 6, 20, 4, 73, 5, 32, 1, 58, 
    1, 47, 7,  1, 2, 89, 5, 17, 4, 31, 6, 59, 8, 18, 0, 15, 3, 59
  };
  const int q5631[] = {
    9, 9, // Number of jobs and machines
    2, 92, 7, 47, 3, 80, 1, 79, 6, 63, 0, 50, 8, 57, 5, 77, 4, 18, 
    3,  3, 5, 99, 2, 52, 0, 71, 4, 28, 7, 57, 8, 57, 1, 84, 6, 98, 
    6, 45, 8,  7, 0, 67, 3,  1, 1, 66, 5, 69, 7, 75, 4, 76, 2, 91, 
    3, 66, 7, 95, 8, 47, 4, 51, 0, 53, 5, 57, 2, 55, 1, 37, 6, 18, 
    0, 93, 6, 81, 8, 62, 4, 45, 1, 36, 7,  6, 3, 61, 5, 97, 2, 85, 
    0, 78, 5,  4, 7, 70, 8, 74, 4, 40, 2, 91, 1, 26, 3, 82, 6, 96, 
    1, 50, 5, 58, 8, 86, 6, 88, 2, 37, 7, 93, 4,  1, 0, 61, 3, 93, 
    7, 87, 2, 45, 3, 82, 4, 45, 1, 27, 0,  3, 6, 92, 5, 79, 8, 26, 
    2, 87, 1, 18, 6, 46, 5, 27, 7, 37, 0, 34, 3, 46, 8, 45, 4, 39
  };
  const int q5632[] = {
    9, 9, // Number of jobs and machines
    2, 57, 6, 67, 3,  8, 7, 85, 8,  9, 5, 99, 0, 57, 4, 76, 1, 46, 
    4, 12, 0, 37, 2, 17, 7, 59, 3, 45, 6,  9, 8, 45, 1, 58, 5, 64, 
    6, 11, 3, 19, 5, 34, 7, 48, 1, 54, 2, 51, 8, 69, 4, 80, 0, 47, 
    1, 12, 8, 11, 6, 66, 3, 93, 0, 21, 2, 12, 5, 43, 7, 89, 4, 31, 
    0, 35, 5, 90, 7, 90, 3, 63, 6, 19, 8, 54, 2, 42, 4,  5, 1, 38, 
    8, 33, 2, 23, 4,  5, 1, 14, 0, 60, 7, 13, 3, 24, 5, 86, 6, 58, 
    4, 53, 1, 15, 0, 40, 2, 69, 6, 25, 8, 41, 5, 62, 7, 67, 3, 61, 
    4,  8, 1, 52, 5, 17, 6, 32, 3, 62, 7, 42, 2, 95, 8, 31, 0, 28, 
    1, 59, 7, 69, 6,  5, 8, 32, 0, 13, 3, 86, 4, 54, 5, 76, 2,  6
  };
  const int q5633[] = {
    9, 9, // Number of jobs and machines
    4, 75, 1, 21, 7, 25, 0, 69, 5,  6, 2, 85, 8, 92, 6, 78, 3, 54, 
    2, 28, 1, 66, 4, 66, 8,  7, 3, 18, 7, 21, 6, 43, 5, 68, 0, 73, 
    8, 75, 1, 96, 2, 74, 4, 51, 5, 14, 0, 93, 3, 89, 7,  9, 6, 16, 
    1, 74, 0, 63, 4,  6, 8, 99, 7, 90, 6, 40, 5, 80, 2, 74, 3,  4, 
    4, 13, 2, 10, 3, 65, 5, 42, 8,  9, 0, 96, 7, 17, 1,  7, 6, 22, 
    0, 19, 2, 85, 7, 55, 6, 98, 8, 75, 5, 49, 1, 15, 4, 83, 3, 95, 
    2, 52, 6, 51, 4, 89, 1, 55, 0, 28, 7, 72, 8, 74, 5, 50, 3, 62, 
    2, 34, 6, 67, 0, 43, 5, 19, 1, 81, 4, 74, 8, 13, 7, 36, 3, 29, 
    6,  6, 3, 49, 0, 30, 8, 25, 4, 67, 2, 67, 7, 44, 5, 92, 1, 86
  };
  const int q5634[] = {
    9, 9, // Number of jobs and machines
    4, 15, 2, 46, 7, 71, 6, 76, 8, 87, 1, 42, 0, 72, 5, 81, 3, 38, 
    0,  6, 7, 31, 1, 81, 2, 77, 3,  2, 5, 57, 6,  7, 4, 82, 8, 34, 
    5,  2, 0, 57, 6, 72, 4, 14, 7,  7, 8, 12, 3, 16, 1, 43, 2, 18, 
    1, 90, 2, 42, 3,  6, 7, 20, 5, 91, 0, 98, 8, 77, 6, 75, 4, 22, 
    6, 28, 1, 94, 8, 81, 0, 38, 3, 94, 2, 74, 5, 90, 4, 78, 7, 12, 
    1, 49, 7, 47, 6,  7, 3, 22, 0, 83, 2, 66, 5, 83, 8, 16, 4, 78, 
    1, 45, 6, 61, 8, 22, 7, 68, 4, 37, 3, 92, 2, 86, 5, 77, 0,  9, 
    5, 84, 4, 84, 3, 98, 7, 69, 1,  2, 6, 11, 8, 13, 0, 92, 2, 56, 
    1, 69, 4, 12, 5, 32, 7, 87, 2,  4, 8, 61, 6, 51, 3, 11, 0, 89
  };
  const int q5635[] = {
    9, 9, // Number of jobs and machines
    7, 59, 2, 12, 4, 87, 3, 54, 1, 49, 5, 69, 8, 69, 0, 12, 6, 95, 
    5, 90, 2, 72, 0, 61, 1, 33, 7, 53, 3, 84, 8,  1, 6, 13, 4, 76, 
    4, 19, 8, 12, 5, 38, 7, 45, 6, 68, 2,  6, 0, 91, 1, 23, 3,  1, 
    0,  3, 3, 78, 6, 89, 4, 27, 2, 38, 8, 51, 5, 30, 7,  5, 1, 68, 
    2, 41, 4, 63, 0, 49, 1, 18, 3, 99, 8, 33, 6, 26, 7, 87, 5, 14, 
    1, 59, 8, 19, 0, 12, 5, 54, 2,  4, 6,  8, 4, 83, 3, 82, 7,  6, 
    3, 59, 7,  5, 0, 15, 6, 12, 8, 54, 1, 74, 4, 79, 5, 58, 2, 45, 
    3, 62, 2,  3, 5, 48, 1, 49, 0, 60, 6, 25, 7, 97, 8,  5, 4, 57, 
    6, 80, 3, 85, 0, 81, 2, 92, 4, 74, 5, 88, 1, 34, 8, 63, 7, 32
  };
  const int q5636[] = {
    9, 9, // Number of jobs and machines
    2, 82, 1, 95, 5, 45, 8, 43, 0, 51, 6, 80, 4, 95, 3, 27, 7, 35, 
    7, 98, 2, 29, 5,  4, 8, 16, 4, 49, 3, 41, 6, 98, 1, 61, 0, 46, 
    0, 58, 8,  7, 7, 69, 3,  3, 1, 63, 2, 59, 6, 44, 4, 11, 5, 41, 
    5, 75, 6, 75, 3, 97, 0, 38, 8, 98, 2,  5, 4, 23, 1, 97, 7, 78, 
    7, 14, 3, 94, 5, 58, 4, 89, 1, 44, 6, 75, 0, 94, 2, 41, 8, 39, 
    2, 23, 3, 85, 4, 76, 7, 63, 0, 91, 6, 99, 5, 68, 8, 80, 1, 51, 
    0, 75, 1, 76, 3, 26, 5, 41, 7, 16, 2,  5, 6, 94, 8, 91, 4, 54, 
    4, 93, 6, 24, 3, 28, 8, 49, 2, 48, 5, 43, 1, 49, 7, 20, 0, 18, 
    2, 24, 0, 24, 4, 63, 7, 66, 5, 65, 6, 62, 8, 29, 1, 47, 3, 14
  };
  const int q5637[] = {
    9, 9, // Number of jobs and machines
    6, 54, 5, 21, 2, 34, 0, 24, 7, 62, 8, 16, 3, 55, 1, 72, 4, 30, 
    5, 52, 6, 16, 1, 98, 0, 41, 8, 63, 3, 56, 4, 67, 2,  4, 7, 99, 
    2, 46, 7, 58, 8, 33, 6, 38, 4,  8, 1, 90, 3, 75, 0, 17, 5, 76, 
    7, 63, 8, 87, 4, 69, 1, 17, 6, 47, 3, 96, 5, 59, 2, 93, 0, 91, 
    1, 69, 3, 40, 7, 15, 5, 66, 8, 31, 6, 18, 2, 41, 4, 61, 0, 86, 
    7, 24, 5, 35, 0, 77, 6, 95, 8, 58, 4,  5, 2, 79, 1, 29, 3, 92, 
    3, 41, 5, 76, 2, 19, 1, 84, 4, 20, 8, 98, 0,  4, 6, 70, 7, 46, 
    1, 95, 4, 31, 2, 31, 8, 10, 7, 40, 0, 61, 3,  5, 6, 69, 5, 42, 
    6, 63, 4, 35, 7, 30, 1, 47, 8, 29, 5, 20, 2, 34, 0, 59, 3, 19
  };
  const int q5638[] = {
    9, 9, // Number of jobs and machines
    1, 60, 8,  8, 3, 95, 0, 93, 7, 18, 6, 78, 5, 37, 4,  8, 2,  9, 
    4, 94, 6, 81, 0, 61, 3, 18, 2, 82, 5, 45, 7, 96, 8, 91, 1, 50, 
    8, 29, 2,  8, 4, 55, 1, 91, 6, 55, 5, 81, 3, 40, 0, 56, 7, 30, 
    8, 43, 3, 30, 4, 45, 1, 97, 2, 98, 6, 37, 7, 43, 5, 23, 0, 67, 
    8, 29, 4,  3, 3,  2, 7, 87, 5, 33, 0, 94, 1, 32, 6, 87, 2, 59, 
    7, 14, 6, 91, 0, 37, 4, 86, 2, 86, 5, 69, 8,  9, 3, 22, 1, 25, 
    0, 47, 2, 44, 5,  5, 6, 73, 3, 25, 1, 44, 7, 50, 8, 18, 4, 11, 
    2, 69, 8, 51, 1, 33, 5, 95, 7, 20, 6, 22, 3, 38, 0,  5, 4, 51, 
    7,  2, 1, 58, 2, 60, 0,  5, 5, 44, 8, 25, 4, 12, 6, 33, 3,  5
  };
  const int q5639[] = {
    9, 9, // Number of jobs and machines
    7, 79, 0, 87, 8, 29, 6, 54, 3, 91, 4, 22, 5, 50, 1,  9, 2,  4, 
    5, 12, 0, 15, 6, 42, 7, 41, 2,  4, 3, 85, 1, 48, 4, 10, 8, 44, 
    1, 99, 6, 12, 0, 27, 5, 33, 7, 19, 4, 52, 8,  9, 3, 10, 2, 26, 
    3, 63, 6, 79, 7, 84, 1, 49, 5, 91, 2, 48, 0, 75, 8, 96, 4, 47, 
    1, 87, 6, 63, 5, 69, 3, 15, 7, 91, 2, 74, 4, 30, 0, 17, 8,  4, 
    5, 74, 2, 12, 6, 72, 1, 87, 7, 97, 8, 89, 0, 69, 4, 25, 3, 15, 
    0, 38, 1, 69, 5, 67, 2, 85, 6,  1, 3, 40, 7, 31, 8, 99, 4, 37, 
    1, 13, 5, 28, 2,  3, 4, 96, 8, 14, 6, 46, 0, 46, 7, 18, 3, 96, 
    2, 29, 5, 72, 8, 91, 6, 67, 0, 78, 7,  4, 1, 39, 4, 19, 3, 86
  };
  const int q5640[] = {
    9, 9, // Number of jobs and machines
    3, 91, 8, 40, 6, 84, 4, 91, 5, 12, 2, 93, 7, 57, 0,  8, 1, 42, 
    1, 33, 0, 31, 5, 80, 6, 19, 7,  2, 3, 17, 2, 59, 4, 71, 8, 47, 
    7, 48, 8, 49, 4, 23, 6, 73, 2, 35, 0, 91, 5, 83, 3, 70, 1, 76, 
    7, 35, 3, 65, 5, 24, 8, 41, 4, 29, 2, 51, 1,  5, 6, 45, 0, 77, 
    8, 78, 0, 35, 7, 11, 5, 68, 4, 82, 3, 55, 1, 37, 6, 50, 2, 33, 
    5, 40, 2, 97, 0, 64, 8,  3, 4, 85, 1, 66, 3, 11, 6, 88, 7, 96, 
    8, 92, 5, 64, 4, 29, 7, 71, 3, 60, 1, 56, 2, 46, 0, 38, 6,  6, 
    1, 20, 5, 80, 0, 23, 8, 69, 3, 75, 4, 98, 7, 32, 2, 40, 6, 53, 
    0, 43, 4, 18, 6, 15, 8, 22, 3, 75, 7, 50, 1, 44, 2, 65, 5, 77
  };
  const int q5641[] = {
    9, 9, // Number of jobs and machines
    0, 59, 8, 99, 1, 70, 2, 30, 6, 82, 3, 15, 7, 56, 4, 14, 5, 45, 
    8, 60, 0, 17, 1, 91, 5, 53, 7,  3, 3, 23, 4, 35, 6, 17, 2, 22, 
    0, 87, 5, 84, 3, 28, 4, 17, 2, 56, 6, 78, 1, 78, 8, 60, 7, 52, 
    6, 89, 3, 62, 4, 81, 2, 26, 0, 27, 5, 15, 1, 14, 7, 32, 8, 73, 
    5, 45, 6, 27, 3, 64, 8, 50, 2, 86, 7, 94, 4, 76, 1, 50, 0, 68, 
    6, 70, 4, 25, 8, 38, 3, 24, 0, 76, 5, 67, 7, 87, 1, 51, 2, 43, 
    5, 56, 7, 68, 0, 54, 4, 32, 3, 75, 6, 74, 8, 93, 1,  5, 2, 52, 
    7, 53, 6, 15, 3, 66, 8, 18, 4, 91, 5, 46, 0, 48, 1, 82, 2, 13, 
    8,  1, 4,  9, 5, 38, 2, 98, 7, 80, 0, 25, 6, 74, 1, 51, 3, 27
  };
  const int q5642[] = {
    9, 9, // Number of jobs and machines
    4, 97, 1, 88, 7, 46, 8, 80, 0, 26, 2, 67, 3, 69, 5, 35, 6,  9, 
    1, 97, 8, 38, 5, 69, 2,  1, 3, 27, 0, 92, 4, 41, 7, 84, 6, 59, 
    2, 59, 1, 91, 6, 42, 5, 85, 8, 43, 7, 94, 3, 38, 0, 13, 4, 53, 
    1, 69, 6, 13, 4, 24, 5, 69, 2, 83, 7, 68, 0, 90, 3, 16, 8, 56, 
    4,  3, 0, 23, 8, 36, 2, 25, 6,  2, 1, 51, 7, 75, 3, 89, 5, 28, 
    3, 59, 4,  2, 7, 67, 8, 14, 6, 85, 1, 23, 2, 33, 5, 96, 0, 15, 
    6, 27, 0, 46, 4, 51, 7, 26, 3, 32, 2, 30, 5, 53, 8, 17, 1, 51, 
    3, 77, 1, 81, 6, 90, 8, 84, 0, 21, 4, 39, 7, 50, 2, 11, 5, 76, 
    6,  8, 1, 79, 4, 48, 3, 45, 8, 34, 7, 48, 2, 90, 5, 92, 0,  9
  };
  const int q5643[] = {
    9, 9, // Number of jobs and machines
    0,  1, 5, 92, 6, 39, 7, 76, 4, 14, 1, 46, 2, 43, 3, 48, 8,  4, 
    1, 72, 5, 74, 0, 30, 3, 90, 6, 86, 7,  9, 2, 69, 8, 36, 4, 69, 
    2, 25, 0, 48, 8,  8, 5, 32, 6, 36, 1, 17, 4, 52, 3, 46, 7, 95, 
    8, 56, 5, 49, 7, 54, 0, 92, 3, 61, 2, 54, 1, 85, 6, 55, 4, 73, 
    7, 19, 3, 47, 8, 38, 2, 60, 1, 27, 0,  1, 5, 11, 6,  3, 4, 37, 
    2, 85, 4, 92, 0, 91, 6, 79, 8, 84, 1, 35, 3, 77, 5, 79, 7, 30, 
    1, 43, 2, 36, 4, 49, 7, 72, 8, 30, 0, 49, 6, 22, 5, 65, 3, 27, 
    0, 43, 1, 80, 8,  8, 7, 83, 6, 93, 2, 78, 4,  8, 5, 60, 3, 12, 
    8, 43, 1, 66, 5,  8, 6, 81, 0, 50, 2, 91, 7, 34, 4, 78, 3, 41
  };
  const int q5644[] = {
    9, 9, // Number of jobs and machines
    8, 30, 1, 31, 4, 45, 7, 37, 3, 56, 5, 55, 6,  5, 2, 68, 0, 80, 
    2,  5, 3, 71, 1, 55, 7, 85, 0, 89, 4,  4, 8, 57, 5, 95, 6, 58, 
    1, 15, 5, 10, 6, 16, 3, 46, 7, 79, 0, 95, 4, 54, 2, 11, 8, 26, 
    5, 79, 3, 37, 2, 20, 8, 56, 4, 84, 7, 55, 1, 26, 0, 46, 6, 73, 
    2, 21, 3, 64, 8, 63, 5,  3, 4, 31, 6, 62, 0, 90, 1, 73, 7, 44, 
    4, 56, 1, 32, 0, 92, 2, 46, 7, 10, 6, 10, 3, 55, 8, 96, 5, 17, 
    2, 64, 1, 32, 0, 24, 7, 86, 4,  5, 3, 76, 8, 86, 5, 98, 6, 20, 
    5, 71, 2, 29, 0, 56, 4, 22, 8, 95, 3, 96, 7, 91, 1, 18, 6, 88, 
    8, 15, 3, 26, 1, 30, 5, 43, 6, 20, 7, 76, 0, 81, 4, 13, 2, 20
  };
  const int q5645[] = {
    9, 9, // Number of jobs and machines
    8, 96, 0, 64, 2, 53, 4, 33, 3, 13, 5, 66, 6, 52, 1, 68, 7, 67, 
    8, 62, 2, 70, 1, 37, 3, 95, 4, 52, 0, 69, 5, 39, 6, 40, 7, 16, 
    8, 51, 7, 65, 6, 90, 3,  4, 0, 98, 4, 51, 2, 54, 5, 30, 1, 28, 
    7, 10, 8, 14, 4, 53, 5, 17, 2, 85, 1, 75, 6, 73, 3, 77, 0, 88, 
    5, 33, 7, 21, 0, 76, 2, 34, 4, 87, 6, 17, 3, 37, 1, 21, 8, 55, 
    3, 20, 5,  5, 7,  8, 2, 26, 6, 79, 1, 22, 8, 43, 0, 30, 4, 42, 
    5, 80, 4,  4, 8,  6, 1, 55, 7, 51, 0, 37, 2, 76, 3, 17, 6, 37, 
    5, 12, 1, 88, 7, 82, 8, 65, 2, 18, 6, 12, 0, 22, 3, 20, 4, 17, 
    2, 24, 1, 99, 8, 26, 3, 99, 6, 31, 7, 98, 5, 96, 0, 51, 4,  6
  };
  const int q5646[] = {
    9, 9, // Number of jobs and machines
    2,  2, 6, 18, 7, 91, 8, 55, 1, 23, 4, 64, 5, 18, 0, 89, 3, 90, 
    7, 91, 6, 67, 1, 76, 3, 21, 5, 24, 4, 28, 8, 51, 2, 96, 0, 84, 
    0, 43, 4,  3, 5, 29, 1, 65, 3, 65, 7, 71, 8, 81, 6, 43, 2, 30, 
    3, 49, 4, 86, 7, 99, 0, 43, 2, 29, 6, 93, 5, 64, 1,  6, 8, 47, 
    0, 84, 5,  6, 8, 67, 7, 96, 4, 77, 1, 80, 2,  6, 6, 76, 3, 83, 
    2, 70, 8,  9, 3, 50, 1,  7, 7, 77, 5, 93, 4, 91, 6, 82, 0,  5, 
    2, 91, 3, 91, 0,  3, 1, 36, 8, 29, 7, 44, 4, 71, 5, 55, 6, 78, 
    3, 78, 0, 27, 1, 73, 4, 57, 6, 76, 7, 59, 8,  4, 2,  5, 5, 72, 
    4,  5, 5, 13, 2,  7, 3, 18, 6, 74, 0, 26, 7, 25, 1, 40, 8, 87
  };
  const int q5647[] = {
    9, 9, // Number of jobs and machines
    0, 41, 2, 48, 4, 54, 6,  5, 8, 69, 1, 44, 5, 48, 3, 54, 7, 30, 
    7, 69, 4, 17, 8, 42, 6, 45, 3, 16, 0,  2, 5, 66, 1, 14, 2, 15, 
    8, 59, 6, 25, 3, 11, 5, 97, 2, 41, 4, 14, 0, 71, 1,  4, 7, 32, 
    8, 94, 5,  1, 2, 42, 1, 17, 4, 95, 3, 36, 0, 54, 7, 23, 6,  9, 
    0, 75, 8, 84, 3, 10, 7, 16, 1, 15, 5, 71, 6, 13, 4, 99, 2, 86, 
    4, 48, 2, 34, 0, 44, 1, 27, 7, 25, 6, 91, 3, 77, 5,  2, 8,  6, 
    6, 54, 2, 87, 8, 33, 7, 14, 0, 56, 5, 63, 4, 27, 1, 45, 3, 63, 
    5, 76, 2,  8, 7, 31, 3, 14, 4, 39, 6, 66, 8, 22, 0, 95, 1, 15, 
    8, 64, 7,  3, 4, 17, 5, 27, 3, 60, 0, 69, 2, 72, 1, 20, 6, 49
  };
  const int q5648[] = {
    9, 9, // Number of jobs and machines
    7, 79, 0, 23, 4, 17, 2, 41, 8, 22, 1, 15, 5, 99, 6, 21, 3, 78, 
    3, 97, 7, 39, 5, 73, 1, 66, 8,  7, 6, 55, 0, 25, 2, 86, 4, 45, 
    0, 60, 3, 76, 4, 70, 2,  4, 1, 34, 5, 74, 8, 74, 7, 78, 6, 92, 
    2, 44, 7, 38, 5,  2, 4, 74, 1, 46, 0, 29, 3, 45, 8, 62, 6, 20, 
    7, 27, 8, 70, 1, 35, 4,  9, 5, 57, 3, 96, 6, 10, 0, 21, 2, 83, 
    2,  6, 5, 95, 1, 39, 3, 83, 4, 89, 0, 22, 6, 75, 7, 16, 8, 91, 
    1, 65, 0, 68, 7, 92, 6, 75, 2, 72, 4, 65, 3, 55, 5, 49, 8, 20, 
    6, 80, 1, 21, 3, 25, 0, 18, 4, 10, 2, 25, 5, 78, 7, 10, 8, 16, 
    4, 28, 8, 14, 1, 93, 3, 39, 5, 63, 0, 31, 2, 43, 7, 53, 6, 12
  };
  const int q5649[] = {
    9, 9, // Number of jobs and machines
    0, 82, 1, 15, 6, 92, 2, 90, 5, 89, 4, 24, 8, 95, 3, 19, 7, 17, 
    1,  2, 7, 49, 4, 58, 6, 12, 3, 66, 8,  6, 2, 59, 0,  5, 5, 18, 
    8, 33, 4, 78, 3, 13, 1, 85, 5, 45, 6, 35, 2, 60, 0,  9, 7, 37, 
    0, 32, 2, 46, 7,  6, 1, 21, 6, 43, 3, 61, 8, 47, 5, 93, 4, 80, 
    7, 39, 8, 41, 4, 46, 0, 46, 2, 19, 5, 17, 1, 84, 6, 65, 3, 53, 
    0, 13, 3,  6, 2, 35, 5, 64, 6, 98, 4, 10, 1, 13, 8,  8, 7, 96, 
    6,  4, 5,  6, 4, 50, 3, 44, 1, 97, 8, 21, 0, 20, 7, 49, 2, 15, 
    0, 80, 7, 40, 8, 30, 1, 25, 5, 92, 6,  6, 3, 49, 4, 26, 2, 98, 
    7, 18, 6, 84, 3, 43, 8, 64, 4, 56, 1, 42, 5, 19, 0, 48, 2, 49
  };
  const int q5650[] = {
    9, 9, // Number of jobs and machines
    5, 27, 0, 92, 6, 76, 3, 44, 1, 99, 8, 62, 4, 48, 7, 92, 2, 13, 
    2, 40, 0, 80, 5, 77, 4, 14, 6, 97, 7, 27, 8, 63, 1,  3, 3, 35, 
    4, 36, 5, 39, 3, 90, 2, 52, 8,  4, 0, 43, 6, 61, 1, 89, 7,  3, 
    0, 73, 3,  3, 8, 93, 2, 62, 4, 45, 7, 47, 5, 83, 6, 63, 1, 10, 
    7, 82, 0, 51, 3, 72, 6, 43, 5, 98, 8, 31, 4,  2, 1, 71, 2, 50, 
    1,  3, 6,  8, 3, 76, 5, 29, 7,  4, 0, 73, 8, 52, 2, 53, 4, 34, 
    2, 56, 7, 65, 6, 28, 0, 81, 3, 90, 5, 36, 1, 38, 4, 98, 8,  6, 
    5, 99, 2, 69, 3, 69, 4,  2, 6, 87, 7, 79, 0,  4, 8, 59, 1, 19, 
    6, 38, 8, 74, 0, 56, 1,  6, 5, 21, 7,  3, 4, 55, 3, 26, 2, 37
  };
  const int q5651[] = {
    9, 9, // Number of jobs and machines
    2, 93, 1, 19, 8, 75, 5, 43, 4, 15, 3, 60, 7, 10, 0, 14, 6,  2, 
    6, 95, 2,  3, 7, 93, 0, 83, 5, 40, 4, 42, 1, 20, 8, 76, 3, 56, 
    3,  7, 6, 45, 5, 29, 7, 63, 0, 66, 1, 62, 4, 48, 2, 79, 8, 62, 
    2, 64, 5, 84, 1,  9, 8, 84, 6, 79, 0, 23, 7, 29, 4, 28, 3, 86, 
    3, 97, 6, 46, 5, 15, 0, 60, 1, 88, 4, 71, 8, 32, 2, 91, 7,  6, 
    0, 85, 1,  4, 7, 52, 2, 32, 3, 98, 5,  7, 8, 55, 4, 81, 6, 51, 
    5, 53, 2, 46, 6, 24, 7, 16, 8, 16, 4, 27, 1,  8, 3, 12, 0, 19, 
    6, 22, 1, 54, 0, 17, 2, 42, 3, 78, 4, 41, 7, 35, 8, 19, 5, 62, 
    7, 96, 8, 42, 6, 34, 1, 74, 2, 66, 5, 33, 0, 61, 3,  5, 4, 69
  };
  const int q5652[] = {
    9, 9, // Number of jobs and machines
    4, 19, 6, 54, 3,  2, 0, 64, 7, 87, 1, 39, 5, 16, 8, 51, 2, 73, 
    8,  3, 2, 61, 5, 37, 6, 73, 3,  2, 7, 60, 0,  9, 1, 51, 4, 91, 
    1, 95, 3, 19, 5, 43, 2, 28, 6, 46, 7, 70, 8, 83, 4, 86, 0, 58, 
    5, 63, 2, 11, 7, 17, 8, 89, 0, 72, 1, 37, 6,  7, 4, 72, 3, 34, 
    5,  9, 3, 63, 1, 42, 0,  3, 6, 32, 8, 64, 4, 87, 7, 12, 2,  7, 
    5, 78, 3, 61, 7, 15, 2, 79, 4, 61, 0, 82, 8, 33, 1, 76, 6, 94, 
    5, 38, 6, 18, 0,  3, 2, 35, 3, 53, 8, 98, 1, 22, 4, 10, 7,  2, 
    3, 18, 7, 21, 6, 10, 0, 74, 1, 21, 4, 65, 5, 83, 2,  3, 8, 55, 
    2, 42, 3, 73, 0, 74, 6, 62, 1,  1, 8, 35, 5, 39, 7, 32, 4, 12
  };
  const int q5653[] = {
    9, 9, // Number of jobs and machines
    6, 35, 1, 58, 0, 77, 2,  7, 8,  4, 4, 35, 5, 25, 7, 75, 3, 58, 
    7, 16, 3, 63, 1, 12, 8, 53, 5, 86, 4,  5, 6, 55, 0, 79, 2, 67, 
    5, 21, 3,  1, 2, 48, 7, 67, 0, 48, 8, 99, 1, 24, 4, 97, 6, 91, 
    8, 66, 5, 26, 3, 16, 6, 39, 7, 86, 0, 24, 1,  3, 4, 74, 2, 18, 
    6, 43, 7, 61, 2, 58, 5, 21, 0, 36, 1, 62, 4, 17, 3, 77, 8, 40, 
    1, 25, 2, 11, 8, 30, 7, 33, 4, 95, 0, 82, 3, 16, 5, 87, 6, 12, 
    0, 78, 5, 87, 4, 31, 1, 44, 2, 60, 7,  4, 8, 11, 6, 98, 3, 50, 
    5, 53, 1, 48, 6, 63, 8, 45, 0, 19, 4, 32, 7, 80, 2, 86, 3, 86, 
    8, 72, 3, 17, 4, 92, 2, 91, 5, 54, 6, 65, 0, 93, 1, 35, 7, 42
  };
  const int q5654[] = {
    9, 9, // Number of jobs and machines
    2, 75, 3, 83, 6, 25, 7, 87, 4, 93, 0, 23, 1, 15, 8, 28, 5,  8, 
    8, 65, 3, 79, 0,  7, 7, 39, 2, 58, 4,  3, 5, 43, 6, 10, 1, 62, 
    6, 91, 0, 82, 5, 53, 7, 68, 3, 45, 2, 59, 8, 49, 1, 80, 4, 65, 
    2, 20, 0, 42, 5, 15, 1, 18, 4, 60, 6, 17, 7, 56, 3, 65, 8, 74, 
    0, 85, 1, 56, 5, 26, 3, 20, 6, 45, 7, 14, 2, 75, 8, 82, 4, 39, 
    5, 94, 7, 62, 6, 20, 2, 57, 8, 42, 3, 86, 0, 86, 4, 17, 1,  7, 
    3, 49, 0, 48, 5, 99, 8, 99, 4, 34, 1, 73, 2, 82, 7, 94, 6, 52, 
    2,  8, 3, 37, 8, 70, 5, 44, 1,  7, 6, 41, 7, 89, 4, 73, 0, 62, 
    0, 69, 6, 99, 4,  9, 5, 74, 7, 84, 2, 78, 8, 65, 1, 90, 3, 90
  };
  const int q5655[] = {
    9, 9, // Number of jobs and machines
    5, 91, 0, 18, 1,  9, 8, 68, 2,  3, 4, 62, 3, 88, 6, 85, 7, 22, 
    7, 95, 0, 77, 4, 35, 6, 40, 5, 26, 1, 13, 3, 69, 2, 80, 8, 81, 
    4, 72, 1, 45, 8, 48, 0, 51, 7, 44, 3, 50, 5, 15, 2, 48, 6, 15, 
    2, 41, 1, 81, 4, 41, 5, 34, 6, 14, 8, 57, 0, 98, 3, 19, 7, 14, 
    1, 37, 4, 61, 2, 97, 8, 47, 6, 86, 0, 87, 5, 33, 3, 16, 7, 71, 
    3, 10, 6, 51, 2, 37, 1, 40, 5, 14, 7, 39, 0,  8, 8, 15, 4, 10, 
    8, 35, 1, 92, 5,  8, 7, 40, 4, 34, 2, 66, 3,  6, 0, 45, 6, 48, 
    3, 46, 2, 72, 6, 24, 7, 23, 0, 89, 4, 57, 5, 23, 1, 73, 8, 73, 
    7, 78, 0, 24, 8, 43, 5, 37, 1, 53, 4, 56, 6, 84, 3, 73, 2, 48
  };
  const int q5656[] = {
    9, 9, // Number of jobs and machines
    2, 42, 6, 32, 8, 65, 4, 16, 0, 26, 5, 61, 3, 58, 7, 41, 1, 41, 
    2, 64, 1, 63, 0, 61, 6, 26, 3,  9, 7, 22, 4, 50, 8, 46, 5, 16, 
    6, 84, 8, 15, 5, 67, 0, 91, 1, 24, 4, 86, 7, 18, 3, 33, 2, 48, 
    3, 10, 0, 55, 7, 73, 1, 84, 8, 77, 4, 40, 6, 91, 5, 32, 2, 83, 
    0, 33, 4, 10, 6, 58, 3, 14, 8, 36, 5, 58, 1, 10, 2, 61, 7, 30, 
    2, 74, 1, 12, 7,  3, 8, 63, 5, 90, 3, 64, 4,  4, 6, 18, 0, 48, 
    7,  6, 6, 79, 2, 95, 4,  5, 3, 67, 5, 66, 0, 92, 8, 44, 1, 18, 
    6, 53, 8, 89, 7, 24, 2,  8, 0,  1, 1, 98, 4, 69, 5, 96, 3, 35, 
    4, 52, 3,  6, 0, 65, 1, 22, 6, 36, 2, 58, 7, 22, 8, 19, 5, 51
  };
  const int q5657[] = {
    9, 9, // Number of jobs and machines
    0, 28, 8,  4, 4, 56, 2, 62, 7, 86, 1, 13, 5, 95, 6, 14, 3, 70, 
    2, 99, 5, 11, 3, 59, 0, 73, 7, 75, 6, 70, 8, 78, 1, 46, 4, 86, 
    6, 31, 0, 36, 3, 46, 7, 24, 4, 78, 8, 62, 1, 57, 5, 29, 2, 13, 
    1, 20, 4, 29, 3, 92, 2, 78, 7, 17, 8, 75, 6, 80, 5, 74, 0, 19, 
    7, 18, 1, 33, 2, 56, 3, 82, 6, 64, 5,  6, 8, 25, 0, 13, 4,  9, 
    4, 77, 2, 11, 1, 75, 8, 29, 6, 71, 3, 85, 7, 12, 0,  6, 5, 36, 
    3, 75, 8,  6, 0,  2, 2, 16, 4, 45, 1, 79, 5, 27, 6, 35, 7, 39, 
    6, 45, 1, 23, 0, 14, 7, 21, 8, 12, 2, 91, 5, 35, 3, 66, 4, 50, 
    5,  5, 8, 96, 2, 54, 6, 23, 4, 68, 7, 29, 1, 31, 3, 14, 0, 53
  };
  const int q5658[] = {
    9, 9, // Number of jobs and machines
    3, 21, 7, 35, 2, 22, 1,  5, 6, 65, 0, 78, 4, 74, 5, 84, 8, 33, 
    6, 51, 2, 56, 7, 30, 5, 33, 0, 91, 4, 35, 1,  9, 3, 53, 8, 88, 
    7, 29, 1, 47, 3, 83, 5, 14, 2, 50, 6, 16, 0,  9, 4, 54, 8, 56, 
    0, 14, 2, 12, 6, 38, 5, 47, 7, 39, 3, 11, 8, 27, 1, 36, 4, 91, 
    5, 65, 2, 14, 6, 89, 0, 93, 8, 37, 7, 49, 1, 44, 3, 19, 4, 50, 
    6, 67, 3, 58, 5, 77, 7, 52, 2, 71, 8, 50, 4, 82, 1, 34, 0, 91, 
    2, 41, 6, 59, 5, 50, 3, 81, 7, 55, 1, 32, 8, 77, 4, 82, 0, 36, 
    0, 16, 2,  3, 8,  7, 7, 27, 1, 98, 5, 25, 3, 32, 6, 84, 4, 55, 
    7, 35, 3, 54, 0, 57, 4, 82, 6, 20, 2, 98, 1, 78, 5, 42, 8, 68
  };
  const int q5659[] = {
    9, 9, // Number of jobs and machines
    7, 29, 4, 13, 2, 86, 8, 15, 5, 16, 3,  7, 0, 85, 6, 22, 1, 18, 
    4, 38, 2, 48, 8, 50, 6, 64, 3, 71, 7, 12, 5, 34, 1, 32, 0, 83, 
    4, 86, 7, 80, 5, 17, 0, 39, 6, 93, 2, 51, 8, 24, 3, 25, 1, 29, 
    3,  3, 1, 35, 4, 60, 8, 40, 0, 87, 2, 77, 6, 70, 7, 71, 5, 13, 
    8, 48, 0, 79, 2, 84, 1,  6, 3, 20, 7, 69, 5, 17, 4, 12, 6, 35, 
    7, 34, 5, 28, 1, 34, 3, 29, 6, 31, 0, 16, 2, 13, 8, 91, 4, 99, 
    8, 76, 3, 19, 0, 29, 4, 27, 7, 83, 6, 63, 5,  9, 2, 42, 1,  7, 
    1, 20, 5, 45, 7, 44, 8, 96, 2, 55, 6, 25, 4,  1, 3, 91, 0, 31, 
    4, 33, 8, 32, 0, 52, 3, 30, 7, 25, 2, 78, 5, 37, 6, 23, 1, 47
  };
  const int q5660[] = {
    9, 9, // Number of jobs and machines
    0, 23, 7, 92, 8, 58, 5, 55, 6, 11, 1, 29, 2, 36, 4, 59, 3, 19, 
    1, 94, 0, 43, 6, 24, 3, 46, 5, 96, 8, 55, 4, 36, 7,  1, 2, 77, 
    0, 59, 3, 29, 8, 28, 1, 17, 4, 52, 6, 32, 5, 34, 2, 20, 7, 26, 
    7, 79, 3, 17, 8, 48, 5, 96, 6, 18, 1, 18, 0, 91, 4, 45, 2,  8, 
    0,  3, 1, 29, 4, 40, 6, 66, 7, 83, 8, 65, 2, 30, 5, 57, 3, 81, 
    7,  2, 8, 48, 2, 25, 1, 31, 4, 45, 3, 21, 0, 38, 6, 94, 5, 93, 
    3, 10, 7, 55, 1, 54, 6, 19, 0, 95, 8, 67, 5, 14, 4, 51, 2, 16, 
    5, 12, 6,  7, 7, 69, 2, 61, 0, 35, 8, 79, 1,  1, 4, 98, 3, 22, 
    7, 98, 0, 71, 5,  7, 4, 42, 8, 36, 1, 99, 6, 93, 2, 38, 3, 76
  };
  const int q5661[] = {
    9, 9, // Number of jobs and machines
    7, 29, 8, 45, 6,  8, 3, 33, 4, 30, 1, 65, 2, 52, 5, 33, 0, 79, 
    7, 26, 8, 90, 2, 32, 4, 84, 5, 68, 6, 50, 1,  9, 3, 32, 0, 18, 
    7,  6, 4, 38, 2, 64, 0, 40, 1, 30, 6, 15, 8, 81, 5, 83, 3, 62, 
    8, 51, 7, 37, 1, 34, 4, 83, 5, 53, 6, 17, 0, 22, 2, 62, 3, 14, 
    8, 61, 0,  4, 3, 94, 1, 95, 5, 25, 2, 78, 7, 87, 6, 98, 4, 89, 
    3, 13, 7, 53, 2, 10, 1, 57, 5, 55, 6, 24, 4, 14, 0, 73, 8, 89, 
    4, 62, 1, 73, 2, 65, 8, 47, 7,  9, 6, 97, 5, 42, 3, 88, 0,  2, 
    7, 85, 0, 52, 6, 61, 8, 53, 3, 75, 4, 80, 1, 74, 5, 51, 2, 12, 
    1, 45, 3, 62, 0, 86, 2, 58, 8, 17, 6,  6, 4, 21, 5,  9, 7, 89
  };
  const int q5662[] = {
    9, 9, // Number of jobs and machines
    2, 34, 1, 43, 7, 65, 8,  6, 3, 24, 6, 36, 5, 36, 0, 72, 4, 54, 
    7, 41, 8, 78, 4, 10, 1, 36, 2, 94, 0, 17, 6, 34, 5, 86, 3,  8, 
    8, 81, 5, 46, 2, 59, 0, 15, 7,  4, 6, 57, 3, 71, 4, 28, 1, 90, 
    8, 81, 2, 17, 4, 24, 1, 25, 5, 19, 0, 90, 6, 96, 7, 81, 3, 40, 
    5, 28, 4, 42, 8, 40, 0, 23, 6, 25, 7,  4, 3, 65, 2, 87, 1, 55, 
    3,  5, 4, 26, 2, 92, 8, 37, 7, 75, 0, 30, 6,  6, 5, 10, 1, 48, 
    2, 10, 4, 51, 6, 98, 1, 26, 8, 46, 0, 73, 7, 78, 3, 52, 5, 65, 
    4, 48, 3, 42, 5, 13, 2, 56, 6, 12, 1, 82, 8, 52, 0, 45, 7, 80, 
    5,  4, 2, 58, 4, 26, 8, 17, 0, 77, 1, 27, 7,  5, 6, 77, 3, 13
  };
  const int q5663[] = {
    9, 9, // Number of jobs and machines
    4, 50, 1, 14, 7, 45, 5, 42, 0, 46, 3, 33, 6, 67, 8, 96, 2,  6, 
    2, 93, 3,  2, 6, 97, 4, 49, 0, 83, 1, 43, 5, 37, 8, 89, 7, 81, 
    2, 90, 1,  5, 6, 85, 0, 66, 3, 82, 7, 51, 4, 30, 8, 48, 5, 89, 
    7, 43, 3, 87, 1,  4, 2, 83, 6,  7, 8, 95, 0, 70, 5, 80, 4, 80, 
    2, 39, 3, 46, 8, 68, 7, 67, 1, 48, 6, 59, 0, 66, 4, 30, 5, 86, 
    8, 82, 4, 25, 6, 19, 1, 54, 7, 33, 0, 28, 3, 80, 2,  9, 5, 60, 
    5, 65, 7, 81, 4, 17, 0, 17, 8,  5, 2, 63, 1, 63, 6, 23, 3, 30, 
    5,  4, 8, 78, 7, 14, 3, 55, 0, 23, 2, 64, 4, 82, 6, 54, 1, 43, 
    2, 42, 5, 27, 4, 93, 3, 41, 8, 68, 6, 52, 0, 16, 7, 23, 1, 53
  };
  const int q5664[] = {
    9, 9, // Number of jobs and machines
    6,  3, 8, 42, 0, 38, 2,  4, 1, 30, 5, 80, 4, 19, 3, 58, 7,  1, 
    8, 33, 3, 51, 1, 72, 4, 73, 2, 69, 6, 24, 7,  1, 0, 27, 5, 26, 
    8, 24, 3, 67, 2, 97, 4, 88, 6, 15, 7, 25, 0, 33, 5, 41, 1, 41, 
    7, 97, 1, 13, 2, 87, 5, 42, 3, 97, 8,  8, 6, 37, 0, 10, 4, 85, 
    2,  7, 3, 71, 5,  8, 7, 58, 1, 31, 4, 28, 6, 46, 8, 87, 0, 75, 
    5, 63, 8, 52, 1, 59, 4, 86, 6, 46, 2, 13, 0,  1, 7, 46, 3, 78, 
    4, 11, 1, 67, 0, 32, 7, 88, 5, 39, 6, 22, 8, 72, 2, 30, 3,  6, 
    7, 81, 6, 33, 5, 50, 8,  9, 0, 39, 4, 82, 1, 40, 3, 62, 2, 59, 
    7, 99, 0, 91, 2, 83, 4, 46, 8, 56, 5, 39, 1,  3, 3, 74, 6, 64
  };
  const int q5665[] = {
    9, 9, // Number of jobs and machines
    4, 32, 8, 43, 1,  5, 2, 31, 0, 81, 7, 15, 3, 93, 5, 64, 6, 79, 
    7, 92, 6, 34, 0, 33, 1, 10, 3, 27, 2, 55, 8, 66, 4, 84, 5, 32, 
    5, 69, 7, 81, 6, 46, 1, 63, 3, 36, 8, 13, 4, 71, 0, 84, 2, 53, 
    7, 54, 3, 19, 6, 40, 1, 60, 5, 78, 0, 12, 2, 78, 4, 95, 8, 73, 
    7, 62, 6, 58, 2, 91, 4, 30, 5, 59, 3,  8, 0, 71, 8, 25, 1, 77, 
    8, 83, 4, 88, 2, 68, 3, 61, 1, 95, 6, 45, 7, 84, 0, 64, 5, 97, 
    0, 25, 3, 62, 6, 48, 4, 64, 1, 10, 2, 44, 7, 85, 5, 18, 8, 22, 
    6, 96, 8,  8, 2, 58, 5, 72, 0, 47, 7, 12, 4,  4, 1, 24, 3, 10, 
    0, 22, 1, 78, 5, 28, 3, 19, 6, 28, 8, 49, 4, 56, 2, 33, 7, 93
  };
  const int q5666[] = {
    9, 9, // Number of jobs and machines
    0, 84, 5, 48, 1, 57, 6, 68, 4, 37, 7,  8, 2, 70, 3,  9, 8, 62, 
    5, 19, 7, 19, 0, 72, 8, 93, 1,  4, 6, 97, 4, 14, 2, 71, 3, 42, 
    3,  5, 1,  2, 5, 52, 0, 88, 2, 55, 4, 93, 8, 20, 6, 74, 7, 41, 
    0, 62, 8, 20, 1, 14, 4, 37, 2, 33, 3, 48, 7, 99, 5,  5, 6, 91, 
    4, 33, 2, 75, 6, 70, 0, 19, 7, 35, 3, 55, 5, 24, 1, 80, 8, 60, 
    6, 93, 2, 25, 1, 24, 4, 10, 0, 35, 5, 52, 8, 74, 3, 81, 7, 18, 
    3, 80, 5, 27, 4, 99, 1, 79, 2, 60, 6, 94, 0,  6, 8, 27, 7, 66, 
    2, 50, 5,  5, 7, 89, 0, 80, 3, 87, 4, 51, 1, 45, 6, 90, 8,  3, 
    0, 37, 3, 11, 5,  6, 7,  6, 1,  9, 6, 68, 4, 18, 8,  8, 2, 75
  };
  const int q5667[] = {
    9, 9, // Number of jobs and machines
    6, 27, 0, 24, 8, 61, 1, 93, 2, 17, 5, 30, 7, 64, 3, 98, 4, 81, 
    4, 89, 6, 77, 0, 57, 1, 69, 8, 61, 5, 71, 3, 22, 2, 96, 7,  2, 
    2, 45, 3, 43, 5,  2, 7, 75, 8,  2, 1, 33, 4, 47, 0,  6, 6, 93, 
    0,  3, 7, 36, 2,  3, 4, 20, 1, 61, 6, 21, 5, 37, 3, 10, 8, 93, 
    2, 60, 5, 81, 7, 31, 4, 48, 1, 27, 8, 21, 0, 20, 6,  2, 3,  6, 
    8, 79, 1,  6, 3, 34, 2, 88, 0, 46, 4, 42, 6, 12, 5, 69, 7, 12, 
    2, 87, 5, 23, 0, 16, 3,  4, 4, 75, 1, 87, 8, 98, 6, 94, 7, 19, 
    0, 24, 5, 63, 8, 69, 7, 74, 1, 98, 6, 38, 2, 13, 3, 94, 4, 69, 
    8, 64, 7, 13, 4, 31, 1, 74, 2, 27, 5, 83, 0, 25, 3, 47, 6, 23
  };
  const int q5668[] = {
    9, 9, // Number of jobs and machines
    4, 22, 6, 60, 0, 70, 1, 28, 8, 78, 3, 15, 7, 62, 2, 49, 5, 86, 
    8, 77, 0,  5, 7, 32, 1, 68, 5, 53, 3, 21, 6, 10, 2, 40, 4, 86, 
    0, 50, 3, 12, 6, 25, 5, 27, 1, 49, 7, 64, 2,  5, 4, 18, 8, 95, 
    0, 82, 5, 61, 3, 30, 6, 70, 7, 61, 8, 80, 1, 34, 2,  5, 4, 59, 
    2, 84, 1, 52, 7, 25, 6, 14, 4, 48, 8, 88, 3, 35, 0, 87, 5, 33, 
    7, 48, 3, 48, 6, 64, 4, 12, 1, 98, 2, 54, 8, 69, 5, 51, 0, 78, 
    1, 24, 8,  8, 6, 33, 5, 55, 0, 59, 7, 78, 2, 93, 3, 12, 4, 51, 
    1, 12, 3, 34, 4, 97, 6, 65, 2, 68, 0, 12, 7, 43, 5, 84, 8, 64, 
    0, 31, 3, 15, 6, 11, 7,  3, 8, 49, 1,  6, 5, 87, 2, 23, 4, 41
  };
  const int q5669[] = {
    9, 9, // Number of jobs and machines
    7, 18, 5, 93, 2, 49, 3, 51, 8, 55, 1, 45, 6, 68, 0, 90, 4, 92, 
    2, 98, 0, 35, 6, 21, 4, 53, 5, 21, 7,  8, 3, 65, 8, 43, 1, 22, 
    4, 96, 5,  9, 3, 19, 6, 46, 8, 18, 1, 80, 0,  9, 7, 49, 2, 12, 
    8, 50, 3, 95, 5, 43, 2, 42, 1,  2, 6, 75, 7, 27, 4, 75, 0, 42, 
    4, 76, 0, 14, 5, 58, 3, 49, 1, 43, 2, 70, 6, 22, 7,  9, 8, 33, 
    1, 30, 5, 49, 8, 50, 7, 53, 4, 59, 0, 75, 3,  1, 6, 28, 2, 68, 
    5, 49, 8, 14, 7, 61, 3, 75, 1, 88, 4, 91, 2, 79, 6, 54, 0,  9, 
    8, 35, 6, 45, 3, 20, 4, 72, 5, 16, 7, 32, 1, 22, 2, 38, 0, 98, 
    0, 82, 3, 33, 8,  6, 2, 88, 1, 94, 5, 83, 4, 90, 6, 67, 7, 72
  };
  const int q5670[] = {
    9, 9, // Number of jobs and machines
    7, 52, 6, 68, 0, 57, 3, 28, 8, 13, 1, 62, 4, 83, 2, 87, 5, 75, 
    3, 28, 0, 36, 7,  7, 2, 16, 8, 54, 1,  6, 4,  6, 6,  8, 5, 23, 
    0, 89, 8, 87, 2, 90, 5, 22, 6,  4, 1, 17, 7, 65, 3, 61, 4, 91, 
    6, 52, 4, 76, 0, 46, 7, 51, 8, 46, 2, 96, 1, 95, 5, 85, 3, 61, 
    3, 42, 5, 84, 0, 62, 4,  7, 6, 16, 7, 79, 8, 36, 1, 70, 2, 91, 
    8, 35, 1, 33, 7, 76, 3, 58, 4,  9, 2,  8, 6, 56, 0, 70, 5, 86, 
    3, 13, 6, 48, 8, 21, 4, 90, 5, 64, 7, 52, 0, 17, 2, 26, 1, 89, 
    4, 19, 7, 58, 6, 23, 0, 11, 1, 50, 8,  6, 2,  3, 5, 91, 3, 52, 
    8, 16, 1, 85, 7, 89, 6, 66, 0, 33, 3, 32, 5, 79, 4, 56, 2, 94
  };
  const int q5671[] = {
    9, 9, // Number of jobs and machines
    0, 53, 2, 47, 7, 42, 6, 86, 5, 97, 4, 19, 3, 65, 1, 21, 8, 30, 
    6, 51, 7, 88, 0, 52, 8, 45, 4,  5, 1, 79, 2,  9, 3, 38, 5, 33, 
    7, 89, 1, 72, 8, 16, 6,  2, 3, 29, 4, 33, 2, 18, 0, 87, 5, 66, 
    2,  7, 0, 50, 1, 36, 6, 71, 8, 79, 4, 42, 7,  3, 5, 20, 3, 16, 
    5,  7, 6, 56, 1, 77, 2, 50, 4, 76, 7, 84, 8, 38, 3, 70, 0, 62, 
    2, 84, 3, 74, 0, 96, 5,  6, 6, 89, 4, 61, 1, 95, 7, 15, 8, 10, 
    2, 42, 5, 76, 0,  5, 3, 61, 8, 83, 1, 98, 7, 89, 6, 51, 4,  3, 
    0,  2, 8, 80, 5, 35, 2, 41, 4, 24, 3, 60, 7, 25, 6, 33, 1, 35, 
    6, 61, 5, 80, 7, 43, 1, 27, 8, 23, 4, 66, 0, 97, 3, 42, 2, 61
  };
  const int q5672[] = {
    9, 9, // Number of jobs and machines
    3, 44, 2, 32, 8, 10, 7, 11, 1, 63, 4, 30, 0, 16, 6, 66, 5, 74, 
    2, 85, 8, 57, 3, 22, 4, 72, 6, 69, 1, 27, 5,  9, 7, 38, 0, 77, 
    6, 51, 4, 44, 0, 69, 2, 53, 7, 85, 3, 15, 5, 84, 8, 21, 1, 77, 
    6, 21, 3, 78, 7, 75, 1, 13, 0, 31, 4, 77, 8, 88, 5,  1, 2, 33, 
    3, 44, 7,  4, 1, 41, 0, 68, 4, 47, 6, 60, 5, 61, 8, 87, 2, 52, 
    6, 71, 2, 10, 5, 99, 1, 23, 7, 71, 0, 94, 3, 67, 4, 58, 8, 53, 
    1, 28, 2, 26, 0, 91, 3, 75, 7, 12, 6, 38, 8, 89, 5, 92, 4, 97, 
    8, 63, 1, 26, 7, 40, 6, 79, 4, 48, 0, 48, 3, 90, 2, 94, 5, 71, 
    5, 61, 4, 49, 1,  4, 7, 95, 2, 95, 6, 33, 3, 32, 8, 34, 0, 78
  };
  const int q5673[] = {
    9, 9, // Number of jobs and machines
    6, 94, 5, 74, 7, 63, 0, 43, 3,  3, 8, 52, 4, 79, 2, 71, 1,  6, 
    0, 77, 2,  5, 6, 48, 1, 15, 4, 26, 8, 12, 5, 17, 3, 64, 7, 33, 
    4, 52, 6,  4, 3, 85, 2, 62, 8, 73, 0, 76, 5, 51, 1,  1, 7, 81, 
    1,  5, 7, 52, 4, 30, 5, 45, 3, 56, 6, 34, 8, 23, 2, 95, 0, 17, 
    4, 86, 0, 44, 7, 96, 3, 98, 2, 20, 5,  3, 6, 31, 1, 70, 8, 29, 
    3, 48, 4, 87, 7, 43, 6, 96, 5, 62, 8, 45, 0, 62, 2, 64, 1, 25, 
    1, 22, 4, 62, 6, 51, 8, 81, 5, 83, 3, 90, 2, 92, 0, 98, 7, 96, 
    0, 64, 4, 12, 1, 13, 5, 98, 8, 84, 2, 99, 3, 44, 7, 62, 6, 49, 
    8,  3, 2,  8, 4, 22, 3, 21, 5,  6, 1, 63, 0, 31, 6, 31, 7, 45
  };
  const int q5674[] = {
    9, 9, // Number of jobs and machines
    4, 19, 6, 87, 7, 23, 8, 38, 2, 78, 3, 22, 1, 12, 5, 89, 0, 19, 
    6, 60, 7, 30, 8,  2, 3, 90, 2, 40, 1, 58, 0, 64, 5, 65, 4, 59, 
    7,  8, 6, 88, 2, 57, 4, 30, 3, 43, 0, 23, 8, 76, 1, 84, 5, 36, 
    8, 67, 4, 66, 3, 88, 0, 40, 5,  4, 6, 17, 7, 52, 1, 36, 2, 83, 
    1, 51, 8, 13, 6, 53, 7, 64, 0, 58, 2, 47, 5, 85, 3, 87, 4,  4, 
    8,  7, 6, 69, 1, 11, 5, 73, 7, 60, 2, 83, 4, 56, 3, 41, 0, 26, 
    0, 50, 1, 88, 5, 52, 7, 82, 4, 76, 3, 30, 6, 46, 2, 44, 8, 41, 
    7, 29, 5, 37, 6, 29, 1, 94, 0, 99, 2, 58, 4, 20, 8, 66, 3,  8, 
    3, 24, 7, 14, 5, 86, 2, 74, 0, 29, 4,  7, 6,  4, 8, 90, 1, 36
  };
  const int q5675[] = {
    9, 9, // Number of jobs and machines
    2, 15, 5, 73, 7, 79, 3, 14, 4, 62, 1, 70, 6, 27, 0, 66, 8, 42, 
    6,  4, 0, 12, 1, 78, 4, 63, 8,  4, 2, 32, 3, 77, 5, 50, 7, 47, 
    5, 27, 4, 30, 6, 48, 2, 74, 7, 85, 3, 37, 1, 10, 0,  1, 8, 23, 
    4, 21, 8, 67, 5, 82, 3, 25, 1, 60, 0, 61, 2, 35, 7, 36, 6, 12, 
    8, 79, 0, 58, 4, 48, 3, 18, 2, 48, 1, 41, 5, 51, 6,  8, 7, 32, 
    8, 17, 6, 80, 7, 84, 5,  7, 2, 62, 0, 70, 4, 91, 3, 61, 1, 63, 
    4, 56, 2, 93, 6, 31, 8, 11, 3, 16, 7, 22, 5, 46, 1, 27, 0, 48, 
    2,  4, 7, 48, 6, 14, 1,  9, 5, 98, 0, 31, 3, 54, 4, 15, 8, 53, 
    3, 25, 4, 30, 8, 62, 5, 33, 1, 88, 6,  5, 0,  7, 7, 56, 2,  5
  };
  const int q5676[] = {
    9, 9, // Number of jobs and machines
    7, 62, 1, 53, 3, 90, 8, 62, 4, 24, 0, 74, 6, 27, 2, 64, 5, 74, 
    4, 23, 3, 15, 1, 15, 7, 98, 6, 66, 2, 44, 0, 99, 5, 44, 8, 99, 
    3, 86, 6, 25, 2, 62, 7, 39, 1, 60, 4, 27, 5, 26, 8, 58, 0, 75, 
    0, 68, 5, 66, 7, 13, 1, 67, 6, 83, 8, 56, 2, 10, 4, 81, 3,  6, 
    6, 24, 4, 68, 5, 22, 8, 86, 0, 18, 3, 21, 2, 46, 1, 43, 7, 49, 
    3, 15, 8, 69, 0, 14, 2, 62, 7, 84, 1, 40, 5, 37, 6, 36, 4, 34, 
    8, 73, 1, 26, 6, 52, 7, 80, 5, 19, 3, 95, 0, 54, 2, 78, 4, 99, 
    5, 56, 0, 86, 2, 53, 4, 94, 8, 12, 7, 12, 1, 94, 3, 47, 6, 78, 
    1, 82, 5, 69, 3, 52, 4, 39, 2, 41, 7, 93, 6, 14, 8, 47, 0, 60
  };
  const int q5677[] = {
    9, 9, // Number of jobs and machines
    2, 47, 6, 74, 8, 63, 4, 87, 5, 41, 7, 43, 1, 27, 0, 91, 3, 35, 
    3, 41, 0,  8, 6, 55, 8, 19, 2, 58, 5, 11, 1, 83, 7, 94, 4, 24, 
    6, 94, 7,  1, 2, 88, 5, 65, 8, 68, 3, 11, 4, 61, 0, 43, 1, 49, 
    7, 43, 5, 53, 2, 41, 8,  9, 6, 24, 0, 11, 3, 97, 1, 94, 4, 31, 
    3, 88, 5, 41, 2, 57, 7, 84, 4, 77, 1, 64, 0, 22, 8, 13, 6, 20, 
    6, 40, 7, 44, 0,  9, 8, 97, 2,  8, 5, 59, 3,  2, 4, 78, 1, 43, 
    8, 68, 4, 28, 1, 48, 3,  7, 6, 28, 2, 20, 5, 29, 0, 41, 7, 86, 
    5, 39, 3, 43, 6, 41, 7, 37, 2, 11, 8, 17, 4, 89, 0, 28, 1, 83, 
    4, 19, 7,  2, 0, 44, 3, 55, 1, 64, 2, 49, 8,  6, 5, 47, 6, 31
  };
  const int q5678[] = {
    9, 9, // Number of jobs and machines
    4, 34, 5, 37, 1, 29, 7, 70, 6, 95, 2, 12, 3, 84, 0, 31, 8, 35, 
    8, 36, 5, 36, 0, 95, 3, 18, 1, 44, 6, 75, 7, 96, 4, 75, 2, 58, 
    8,  4, 7, 95, 4, 52, 2, 83, 3, 48, 6, 94, 0, 69, 5, 86, 1, 90, 
    8, 72, 7,  7, 6, 52, 4, 56, 1, 53, 0, 55, 2,  3, 5,  5, 3, 51, 
    1, 94, 7, 76, 3, 97, 0, 78, 4, 14, 8,  7, 6, 96, 2,  4, 5, 58, 
    1, 94, 3, 44, 6, 14, 8, 91, 0, 47, 4, 95, 5, 74, 2, 40, 7, 28, 
    3, 67, 0, 64, 1, 82, 7, 45, 4, 79, 8, 79, 2, 79, 6, 23, 5, 20, 
    6, 39, 8, 84, 1,  3, 2, 16, 5, 63, 4, 47, 3,  8, 7,  1, 0, 52, 
    5,  9, 3, 93, 4, 46, 8, 81, 6, 22, 2, 66, 7, 65, 1, 73, 0, 24
  };
  const int q5679[] = {
    9, 9, // Number of jobs and machines
    2, 11, 3, 11, 6, 69, 4,  7, 8, 54, 0, 73, 1, 49, 5, 90, 7,  1, 
    8, 55, 7, 66, 6, 81, 4, 96, 2,  2, 0,  5, 1, 50, 5, 86, 3, 79, 
    2, 99, 5, 98, 7, 72, 3, 81, 6,  7, 8, 19, 4, 39, 1,  3, 0, 98, 
    4, 68, 3, 54, 1, 21, 6, 82, 8, 21, 0, 78, 5, 48, 2, 57, 7, 18, 
    1, 64, 7, 87, 4, 70, 5, 24, 8, 90, 0, 44, 6, 76, 3, 27, 2, 63, 
    3, 17, 1, 83, 8, 52, 7, 29, 2, 15, 6, 78, 0, 72, 5, 52, 4, 78, 
    2, 15, 6, 14, 8, 41, 5, 89, 0, 66, 4, 65, 3, 26, 1, 12, 7,  2, 
    8, 22, 2, 53, 5, 65, 1, 38, 0, 66, 3, 33, 7, 96, 4, 93, 6, 86, 
    8, 15, 7, 26, 0, 57, 4, 13, 2, 76, 1, 83, 3, 16, 5, 15, 6, 64
  };
  const int q5680[] = {
    9, 9, // Number of jobs and machines
    2, 65, 0, 32, 7, 17, 8, 75, 5, 30, 3, 89, 6, 38, 1, 93, 4, 30, 
    0,  9, 4, 81, 8, 17, 7, 80, 2, 99, 5, 50, 1, 18, 6, 16, 3, 61, 
    1, 42, 5, 62, 6, 14, 3, 16, 8, 64, 0, 39, 4, 80, 2, 74, 7, 36, 
    4, 23, 6, 32, 7, 15, 5, 31, 3, 94, 2, 31, 1, 57, 0, 73, 8, 11, 
    8,  6, 4, 20, 3, 35, 6, 92, 5, 12, 1, 23, 2, 46, 0, 29, 7, 58, 
    4, 90, 3, 58, 5, 46, 6, 42, 7, 14, 2, 98, 1, 73, 0, 15, 8, 97, 
    6, 34, 0, 78, 8, 75, 7, 40, 4, 94, 1, 11, 3, 47, 2,  3, 5, 70, 
    2, 64, 1, 27, 6, 13, 8, 92, 5, 33, 3, 54, 0, 18, 4, 83, 7, 63, 
    4,  4, 2,  4, 0, 37, 7, 79, 5, 35, 6, 83, 1, 55, 3, 85, 8, 20
  };
  const int q5681[] = {
    9, 9, // Number of jobs and machines
    2, 14, 1, 36, 8, 68, 3, 28, 5, 93, 6, 59, 7, 27, 4, 58, 0, 62, 
    5, 36, 6, 78, 4, 58, 8, 64, 2, 51, 1, 74, 0, 87, 7, 51, 3, 45, 
    4, 82, 2,  5, 8, 95, 1, 49, 7, 56, 6, 51, 3, 59, 0,  6, 5, 51, 
    8, 94, 6, 67, 2, 36, 1, 30, 0, 69, 3, 84, 4, 63, 5, 98, 7, 82, 
    4, 55, 6, 95, 2, 97, 0, 22, 7, 14, 5, 13, 8,  9, 3, 69, 1, 87, 
    8, 98, 1,  3, 4, 56, 0, 16, 3, 58, 6,  7, 7, 90, 2, 44, 5, 55, 
    3, 42, 4, 26, 6, 18, 1, 86, 0, 58, 7, 75, 8, 36, 2,  1, 5, 68, 
    7, 19, 3, 91, 8, 44, 4,  9, 0, 40, 5, 82, 2, 96, 6, 79, 1, 34, 
    0, 78, 6, 71, 8, 57, 7, 84, 5, 77, 3, 95, 4, 92, 1, 56, 2, 71
  };
  const int q5682[] = {
    9, 9, // Number of jobs and machines
    7, 91, 5,  7, 2, 66, 6, 22, 4, 41, 8, 83, 3, 76, 1, 90, 0, 69, 
    5, 71, 6, 60, 2, 35, 8, 61, 3, 63, 4, 67, 7, 43, 0, 19, 1, 45, 
    0, 40, 7,  7, 5, 84, 2, 11, 6, 55, 3, 76, 1, 96, 8, 73, 4, 17, 
    8, 68, 5, 52, 4, 56, 1, 15, 7, 93, 6, 21, 2, 98, 3, 53, 0, 50, 
    2, 28, 8, 43, 0, 93, 5, 24, 7, 16, 1, 75, 3,  7, 4, 91, 6, 35, 
    3,  3, 7, 74, 2, 23, 8, 93, 6,  6, 4, 28, 1, 32, 5, 22, 0, 67, 
    7, 80, 5,  7, 1, 61, 8, 83, 2, 12, 6, 12, 0, 15, 3, 73, 4, 15, 
    2, 54, 4, 15, 7, 64, 5, 10, 8, 99, 6, 85, 3, 56, 0, 77, 1, 76, 
    2, 73, 7, 86, 3, 86, 6, 71, 1, 23, 0, 87, 4, 24, 5, 70, 8, 27
  };
  const int q5683[] = {
    9, 9, // Number of jobs and machines
    4, 49, 7, 67, 5, 85, 3, 81, 8, 16, 0, 66, 2, 65, 6, 68, 1, 30, 
    3, 86, 4, 22, 1, 44, 6, 20, 0, 93, 8, 13, 2, 14, 7, 86, 5, 86, 
    0,  6, 8, 59, 3, 37, 4,  5, 5, 88, 2, 26, 6, 64, 7, 13, 1, 16, 
    2, 78, 5, 24, 7,  7, 4, 85, 6, 65, 0, 21, 1, 44, 3, 99, 8, 67, 
    2, 67, 3, 69, 1, 40, 8, 83, 6,  4, 7, 59, 5, 29, 4, 33, 0, 12, 
    7, 87, 0, 22, 1, 65, 6, 86, 2, 50, 5, 79, 4, 52, 8, 22, 3, 76, 
    4, 61, 0, 46, 1, 12, 2, 27, 7, 60, 8, 85, 3, 42, 6, 48, 5,  9, 
    8,  5, 1, 74, 2, 51, 0, 15, 5, 31, 7, 39, 4, 36, 6, 65, 3, 88, 
    6, 56, 5, 66, 0, 36, 4, 95, 7, 90, 2,  5, 8, 64, 1, 76, 3, 45
  };
  const int q5684[] = {
    9, 9, // Number of jobs and machines
    1,  6, 2, 73, 0, 94, 5, 18, 8, 41, 3, 46, 4, 55, 7, 94, 6, 59, 
    4, 97, 3,  2, 8, 62, 7, 75, 6, 19, 2, 15, 0, 54, 5,  6, 1, 55, 
    8, 41, 7, 47, 4, 47, 1, 48, 5, 25, 3, 61, 6, 91, 2, 46, 0, 13, 
    5, 99, 2, 93, 4,  3, 3, 99, 1, 19, 6, 66, 7, 90, 0, 53, 8, 16, 
    3, 10, 6, 98, 0, 45, 2, 50, 8, 69, 1, 51, 4, 33, 5, 17, 7, 37, 
    5, 34, 7, 68, 3, 53, 6, 83, 4, 32, 1, 44, 8, 28, 2, 88, 0, 27, 
    8,  8, 6, 37, 0, 22, 1, 25, 4, 48, 3, 72, 5, 13, 2, 47, 7, 66, 
    7, 73, 3,  1, 8, 58, 4, 53, 1, 68, 2, 20, 0, 71, 6, 98, 5, 38, 
    0, 12, 2, 74, 5, 41, 7, 16, 4, 18, 6, 89, 3, 18, 1, 91, 8, 75
  };
  const int q5685[] = {
    9, 9, // Number of jobs and machines
    1, 91, 2,  8, 4, 38, 5, 59, 7, 19, 8, 47, 0, 34, 3,  5, 6, 23, 
    6, 99, 3, 61, 0, 39, 8,  9, 4,  2, 1, 42, 7, 44, 5, 40, 2, 18, 
    8, 58, 3, 15, 4, 73, 6,  1, 0, 71, 1, 40, 2, 57, 5, 43, 7, 69, 
    3, 92, 1, 27, 8, 15, 7, 39, 6, 54, 0,  1, 5, 98, 4,  3, 2, 25, 
    6, 80, 8, 89, 2, 33, 3, 37, 5, 89, 0, 88, 4, 59, 7, 24, 1, 16, 
    6, 37, 2,  2, 0, 73, 5, 32, 3, 60, 4, 48, 1, 25, 7, 12, 8, 22, 
    7, 18, 1,  7, 3, 78, 6, 19, 4, 74, 0, 60, 2, 32, 8, 27, 5,  6, 
    6, 78, 5, 88, 0,  5, 3, 23, 2, 38, 8, 84, 7, 45, 4, 17, 1, 95, 
    2, 42, 1, 97, 0, 59, 3, 60, 4, 44, 7, 28, 5, 86, 6, 31, 8, 45
  };
  const int q5686[] = {
    9, 9, // Number of jobs and machines
    1, 72, 4, 36, 8, 43, 2,  5, 5, 57, 0,  7, 6, 22, 3, 45, 7,  3, 
    3, 48, 5, 69, 4, 53, 8,  9, 6, 39, 7, 71, 2, 74, 0, 11, 1, 11, 
    5, 96, 2, 87, 0, 41, 4,  9, 6, 92, 3, 16, 1, 66, 7, 32, 8, 91, 
    1, 65, 4,  5, 7, 29, 3, 25, 2, 74, 8, 82, 5, 29, 6, 42, 0, 43, 
    6, 16, 1, 15, 8, 52, 5, 86, 2, 77, 3, 80, 4, 46, 7, 29, 0, 11, 
    2, 63, 8, 16, 4, 90, 3, 62, 0, 20, 7, 44, 6, 75, 5, 34, 1, 60, 
    6,  4, 0, 85, 1, 29, 7, 48, 8, 82, 2, 32, 3, 61, 5, 40, 4, 32, 
    6, 20, 1, 62, 4, 68, 8, 62, 7, 30, 3, 21, 2, 62, 0, 89, 5, 28, 
    3, 10, 4, 15, 0, 92, 7, 25, 2, 50, 6, 93, 8, 75, 1,  3, 5, 58
  };
  const int q5687[] = {
    9, 9, // Number of jobs and machines
    8, 45, 6, 49, 3, 49, 7,  3, 0, 30, 1,  6, 2, 36, 4, 37, 5, 75, 
    6, 14, 8, 74, 2, 31, 7, 84, 0, 48, 5, 18, 1, 30, 3, 83, 4, 51, 
    7, 97, 4, 19, 8, 97, 6, 61, 0, 29, 5, 46, 3, 34, 1,  2, 2, 65, 
    1, 16, 7, 45, 0, 18, 3, 49, 4, 23, 2, 42, 8, 91, 6, 97, 5,  7, 
    4, 80, 3, 63, 6,  1, 7,  9, 5, 28, 1, 79, 0, 19, 8, 62, 2, 34, 
    8, 77, 5, 31, 0, 63, 7, 92, 6, 31, 2, 23, 4,  9, 1, 12, 3, 28, 
    1, 47, 2,  7, 6, 81, 4, 33, 0,  1, 5, 61, 3, 97, 7, 71, 8, 44, 
    6, 91, 8, 88, 4, 24, 0, 41, 5, 93, 2, 67, 3, 52, 7, 97, 1, 47, 
    0, 31, 8, 90, 5, 42, 1, 52, 4, 88, 7, 66, 2, 59, 3, 96, 6, 20
  };
  const int q5688[] = {
    9, 9, // Number of jobs and machines
    7, 24, 2, 12, 5, 22, 3, 43, 4, 64, 1, 30, 8, 21, 0, 66, 6,  7, 
    1, 61, 2, 52, 5, 61, 7, 77, 8, 70, 6, 31, 3, 90, 4, 90, 0, 36, 
    8, 27, 3, 75, 0, 98, 1, 97, 6, 25, 4, 95, 2, 71, 5, 54, 7, 26, 
    4, 96, 0, 36, 5, 94, 1, 65, 6, 49, 7, 93, 8, 22, 3, 11, 2, 99, 
    4, 49, 8, 72, 2, 66, 0, 37, 6, 24, 7, 81, 3, 38, 5, 54, 1, 94, 
    4, 98, 3, 58, 1, 60, 5, 42, 0, 25, 6, 24, 2, 72, 7,  5, 8, 12, 
    2, 36, 0, 56, 5, 85, 3, 23, 8, 17, 7,  4, 6, 40, 1, 35, 4, 19, 
    8, 25, 3, 47, 0, 60, 5,  9, 7, 77, 2, 56, 6,  9, 4,  5, 1, 49, 
    5, 62, 8, 87, 6,  4, 1, 37, 4, 67, 3, 71, 7, 48, 2, 95, 0, 75
  };
  const int q5689[] = {
    9, 9, // Number of jobs and machines
    3, 52, 5, 12, 6, 52, 0,  8, 8, 20, 2, 46, 7, 67, 1,  5, 4, 98, 
    2, 51, 8, 81, 0, 58, 7, 25, 3, 47, 5, 96, 1, 20, 6, 96, 4, 92, 
    3, 79, 5, 80, 0, 43, 6, 19, 1, 97, 7, 24, 8, 43, 2, 86, 4,  5, 
    7, 90, 0, 87, 6, 75, 3, 52, 4, 32, 2,  2, 1, 16, 5, 71, 8, 24, 
    3, 85, 8, 95, 7, 63, 0, 51, 6, 14, 1,  9, 5, 31, 4, 28, 2, 54, 
    3, 67, 8, 46, 4, 27, 6, 97, 2, 10, 5, 63, 1, 99, 0, 68, 7, 24, 
    4, 72, 2, 74, 6, 40, 3, 70, 0, 15, 5,  3, 8, 45, 7, 69, 1, 71, 
    8, 23, 1, 39, 3, 48, 7, 43, 2, 35, 5, 32, 0, 22, 4, 94, 6, 20, 
    6, 21, 4,  6, 2, 22, 3, 69, 7, 72, 8, 16, 1, 67, 0,  6, 5, 40
  };
  const int q5690[] = {
    9, 9, // Number of jobs and machines
    8, 44, 2, 41, 5, 40, 3, 46, 6, 19, 0, 24, 4, 42, 1,  9, 7, 31, 
    1, 83, 7, 41, 6, 14, 0, 24, 3, 19, 2, 59, 4, 33, 8, 48, 5, 62, 
    4, 91, 5, 89, 3, 27, 0, 25, 2, 67, 8, 46, 7, 37, 6, 83, 1, 95, 
    8, 83, 1, 48, 2, 67, 3, 75, 4,  5, 0,  3, 7, 59, 6, 63, 5, 29, 
    8, 86, 5,  9, 2, 34, 1, 15, 6, 26, 0, 33, 7, 47, 3, 69, 4,  7, 
    0, 12, 8, 44, 7, 84, 2, 24, 6, 36, 1, 95, 5, 75, 3, 75, 4, 46, 
    0, 11, 5, 87, 4, 16, 3, 71, 1, 16, 6, 26, 8, 45, 2, 29, 7, 80, 
    7, 17, 3, 66, 1, 83, 8, 34, 4, 98, 2, 37, 0, 36, 5, 77, 6, 20, 
    8, 66, 7, 51, 1, 18, 0, 35, 2, 17, 4, 58, 3, 93, 6,  4, 5, 92
  };
  const int q5691[] = {
    9, 9, // Number of jobs and machines
    3, 53, 2, 32, 4, 89, 6, 26, 0, 36, 7, 47, 5, 15, 8,  2, 1, 22, 
    8, 60, 4, 92, 5, 33, 0, 23, 3, 60, 6, 40, 2, 67, 1, 84, 7, 95, 
    7, 47, 3, 30, 6, 77, 0,  8, 5, 55, 1, 86, 4, 44, 2, 75, 8, 22, 
    6, 40, 1, 84, 8, 25, 4, 56, 0, 71, 2, 97, 5, 62, 7,  3, 3, 16, 
    7, 87, 1,  7, 8, 26, 5, 62, 3, 93, 4, 36, 2, 86, 6, 19, 0, 90, 
    3, 24, 7,  8, 5, 65, 8, 10, 4, 88, 0, 91, 6, 77, 1, 84, 2, 84, 
    6, 10, 1, 60, 2, 44, 4, 31, 3, 92, 7, 60, 5, 92, 0, 50, 8, 54, 
    4,  1, 3, 28, 7, 86, 1, 63, 8, 40, 5, 45, 6, 48, 2,  2, 0,  4, 
    3, 39, 0, 21, 8, 43, 2, 63, 6, 41, 4, 29, 7, 64, 1, 31, 5, 26
  };
  const int q5692[] = {
    9, 9, // Number of jobs and machines
    4, 34, 1, 17, 3, 46, 8, 63, 0, 61, 7, 31, 2, 32, 6, 57, 5,  8, 
    8, 61, 6, 13, 7, 60, 2,  4, 1, 16, 3, 15, 5, 20, 0, 57, 4, 91, 
    5, 55, 7, 33, 2, 51, 0, 50, 4, 68, 6,  3, 8, 19, 1, 31, 3, 31, 
    6,  6, 0, 62, 7, 21, 5,  2, 1, 42, 3, 98, 4,  6, 2, 74, 8, 13, 
    3, 48, 4, 84, 8, 11, 7, 96, 0,  2, 5, 85, 2, 14, 1, 75, 6, 72, 
    4,  1, 3, 19, 1,  4, 8, 97, 5, 27, 2, 29, 0, 21, 6, 61, 7, 81, 
    5,  5, 2, 86, 1, 93, 6, 59, 7, 37, 3, 60, 0, 53, 8, 87, 4, 48, 
    8,  4, 6, 26, 4, 17, 2, 44, 5, 28, 7,  5, 1, 89, 3, 16, 0, 48, 
    1, 79, 7,  7, 8, 42, 3, 92, 0, 65, 5, 91, 4, 12, 6, 61, 2, 15
  };
  const int q5693[] = {
    9, 9, // Number of jobs and machines
    1, 79, 2, 23, 6, 72, 7, 82, 8,  4, 0, 52, 5, 43, 4, 49, 3, 98, 
    6, 68, 7, 27, 0, 18, 3, 95, 8, 17, 2, 71, 1, 11, 4, 90, 5, 28, 
    6, 67, 5, 27, 1, 69, 0, 32, 8, 43, 4, 97, 3, 84, 7, 29, 2, 64, 
    3, 31, 6, 70, 1, 64, 8, 17, 4,  3, 7, 24, 2, 72, 5, 78, 0, 17, 
    2, 68, 1, 54, 6, 91, 4, 29, 5, 43, 8, 11, 0, 95, 3, 69, 7, 73, 
    7, 17, 8, 99, 0, 45, 5, 63, 6, 31, 3, 44, 1, 29, 4, 41, 2, 70, 
    5, 54, 3, 42, 6, 11, 4, 88, 2,  3, 0, 53, 1,  4, 8, 31, 7, 93, 
    1, 26, 7, 61, 3, 90, 5, 24, 2, 37, 8, 26, 4, 72, 0, 53, 6, 85, 
    3, 49, 7, 48, 2, 29, 8,  1, 1, 67, 6, 68, 0, 21, 5, 40, 4, 67
  };
  const int q5694[] = {
    9, 9, // Number of jobs and machines
    8, 92, 1, 31, 7, 53, 6, 26, 3, 87, 2, 21, 4, 60, 0, 50, 5, 48, 
    7,  9, 4, 21, 6, 22, 8,  6, 1, 80, 5,  1, 3, 50, 0, 74, 2, 82, 
    7, 63, 3, 29, 0,  4, 1,  6, 6, 17, 8, 16, 5, 36, 2, 73, 4, 83, 
    5, 32, 3, 67, 0, 47, 7, 89, 8, 36, 6, 25, 2, 31, 1, 96, 4, 15, 
    6, 89, 8, 56, 2, 92, 5, 36, 4, 36, 0, 12, 3, 19, 7, 13, 1, 11, 
    5, 19, 1, 14, 3, 96, 7, 46, 6, 81, 4, 67, 8, 53, 2, 52, 0, 33, 
    5, 33, 1, 54, 2,  1, 4, 73, 6, 83, 7, 83, 0, 41, 8, 78, 3, 20, 
    8, 67, 1, 63, 5, 39, 2, 18, 4, 53, 0, 77, 3, 85, 7, 68, 6, 91, 
    3, 61, 7, 20, 4, 73, 2, 63, 1, 39, 8, 62, 0, 44, 5, 10, 6, 61
  };
  const int q5695[] = {
    9, 9, // Number of jobs and machines
    5, 18, 7, 78, 3, 62, 8, 26, 0, 59, 4, 84, 6, 77, 1, 37, 2, 17, 
    8, 67, 0, 35, 6, 44, 7, 15, 1, 95, 2,  4, 3, 13, 5, 61, 4, 81, 
    3, 52, 0, 83, 4, 30, 7, 57, 6, 12, 8, 92, 5, 58, 2, 60, 1, 16, 
    0, 84, 4, 57, 8, 84, 3, 76, 5, 37, 1, 68, 2, 98, 6, 87, 7, 25, 
    6,  4, 3, 65, 2, 75, 5, 57, 4,  5, 7, 32, 0, 55, 8, 70, 1, 70, 
    2, 59, 1, 57, 3, 70, 0, 20, 5, 85, 6,  4, 4, 96, 7, 94, 8, 95, 
    5, 70, 0, 13, 2, 98, 8,  1, 6, 69, 4, 93, 1, 58, 3, 23, 7, 75, 
    3, 86, 1, 11, 2, 88, 6, 98, 8, 36, 7, 12, 4,  5, 5, 87, 0, 86, 
    1, 22, 3, 36, 2, 31, 0, 30, 8, 47, 7, 20, 5, 26, 4, 49, 6, 51
  };
  const int q5696[] = {
    9, 9, // Number of jobs and machines
    2, 39, 6, 89, 8, 78, 4, 41, 3, 80, 1, 83, 0, 80, 5, 35, 7, 79, 
    3, 60, 4, 79, 0, 64, 6, 85, 5, 19, 1, 85, 7, 40, 2,  6, 8, 77, 
    5, 43, 0, 73, 7, 47, 1, 23, 4, 81, 3, 10, 2,  5, 6, 34, 8,  5, 
    4, 44, 7, 61, 1,  4, 0,  1, 2, 59, 8,  3, 6, 12, 5, 28, 3, 23, 
    7, 71, 6, 18, 5, 28, 4,  9, 8, 96, 2, 27, 1,  8, 3, 48, 0,  3, 
    0, 59, 7, 10, 3, 23, 5, 53, 8, 22, 2, 93, 4, 62, 1, 42, 6, 52, 
    8, 89, 6, 62, 3, 23, 7, 71, 4, 26, 1, 31, 0, 49, 2, 65, 5, 14, 
    5, 83, 8, 80, 4, 90, 3, 66, 2, 27, 1, 12, 7, 12, 0, 28, 6, 42, 
    2, 53, 3, 98, 0, 86, 5,  1, 7, 23, 6, 54, 8, 90, 1, 91, 4, 70
  };
  const int q5697[] = {
    9, 9, // Number of jobs and machines
    4, 97, 2,  9, 5, 80, 8,  1, 6, 96, 0,  8, 3, 35, 1, 70, 7, 47, 
    0, 83, 3, 75, 4,  4, 5, 58, 7,  3, 8, 61, 2,  7, 6, 37, 1, 40, 
    0, 38, 2, 85, 3, 44, 6, 71, 1, 31, 7, 81, 4, 50, 5, 59, 8,  6, 
    7, 24, 3, 26, 0, 95, 6, 27, 1, 66, 8, 25, 2,  6, 4, 41, 5, 43, 
    3, 91, 7, 96, 2, 87, 4, 72, 0, 24, 1, 77, 6, 53, 5, 36, 8, 65, 
    7, 26, 0, 52, 4, 75, 6, 30, 3, 73, 1, 27, 2, 27, 5, 64, 8, 34, 
    8, 57, 0, 77, 1, 42, 5, 53, 2, 69, 7, 24, 3, 85, 4, 97, 6, 63, 
    2, 24, 7, 45, 4, 67, 0, 48, 3, 66, 8, 91, 5, 26, 1, 44, 6, 43, 
    1, 90, 6, 11, 7,  9, 5, 10, 4, 35, 2, 60, 8, 35, 3, 42, 0, 25
  };
  const int q5698[] = {
    9, 9, // Number of jobs and machines
    7, 24, 1, 86, 6, 44, 8, 96, 2, 99, 0, 43, 4, 31, 5, 77, 3, 42, 
    0, 23, 5, 56, 6,  9, 1, 69, 8, 89, 4, 57, 3, 90, 2, 56, 7, 93, 
    1, 18, 6, 15, 2, 20, 7, 30, 4, 33, 8, 77, 5,  1, 0, 93, 3, 41, 
    2, 15, 6, 77, 5, 17, 8, 55, 4, 90, 3, 44, 7, 20, 0, 76, 1, 50, 
    1, 73, 3,  4, 4, 20, 6, 50, 2, 10, 7, 53, 8, 26, 0, 72, 5, 46, 
    1,  8, 0, 96, 5, 97, 4, 42, 6, 61, 2,  8, 8, 73, 3, 46, 7,  1, 
    6, 67, 2, 40, 1, 25, 8,  1, 3, 94, 5, 93, 0,  5, 4, 40, 7, 32, 
    3, 59, 1, 67, 6,  9, 8, 12, 7, 95, 4, 79, 2, 19, 0,  1, 5, 39, 
    5, 22, 1, 26, 3,  6, 6, 30, 7, 51, 2, 33, 4, 86, 0, 91, 8, 38
  };
  const int q5699[] = {
    9, 9, // Number of jobs and machines
    7,  8, 6, 63, 8, 55, 1, 73, 0, 76, 3, 57, 4,  2, 2, 28, 5,  1, 
    2, 29, 8, 94, 3, 11, 4, 24, 1, 13, 6, 95, 7, 88, 5, 68, 0, 21, 
    1, 43, 5, 16, 3, 49, 4, 84, 0, 88, 2,  2, 8, 69, 7, 86, 6,  2, 
    3,  4, 1, 47, 6,  9, 7, 74, 8, 53, 2, 96, 0, 30, 5, 93, 4, 23, 
    1, 64, 6, 56, 4, 37, 7, 40, 0, 71, 8, 73, 3, 57, 5, 31, 2, 78, 
    6, 19, 2, 44, 0, 22, 3, 27, 5,  7, 1, 53, 4, 71, 7, 28, 8, 11, 
    2, 49, 3, 95, 7, 15, 6, 35, 0, 46, 1, 39, 8, 74, 5, 84, 4, 74, 
    3, 12, 4, 49, 8, 82, 0, 53, 6, 83, 1, 87, 7, 92, 5, 43, 2, 13, 
    2, 78, 5, 66, 0, 72, 6, 59, 8, 61, 1, 48, 7, 98, 4, 42, 3,  7
  };
  const int q5700[] = {
    9, 9, // Number of jobs and machines
    5, 99, 8, 18, 0, 23, 1, 60, 3, 73, 6, 60, 2, 91, 4, 62, 7,  4, 
    6, 49, 5, 86, 7, 89, 0, 85, 3, 39, 2, 68, 1, 10, 4, 96, 8, 61, 
    8, 34, 0, 47, 6, 43, 5, 92, 7, 84, 3, 53, 2, 24, 1, 50, 4, 37, 
    0, 20, 6, 93, 3, 23, 8, 20, 4, 21, 5, 41, 1, 45, 7, 97, 2, 99, 
    1, 59, 6, 41, 0, 80, 8, 21, 3, 62, 2, 56, 5, 47, 7, 96, 4, 18, 
    5, 36, 3, 61, 2, 84, 0, 61, 4, 90, 8, 56, 7, 88, 6,  4, 1, 35, 
    0, 24, 5, 81, 6, 63, 1, 70, 3, 95, 2, 45, 8, 96, 4, 15, 7, 68, 
    0, 98, 2, 33, 3, 61, 7, 62, 1, 84, 6, 34, 8, 38, 4,  7, 5, 26, 
    6, 25, 0, 86, 5, 80, 3, 85, 8, 16, 7, 52, 1,  7, 4, 91, 2, 17
  };
  const int q5701[] = {
    9, 9, // Number of jobs and machines
    0, 15, 4, 20, 2, 80, 3, 63, 6, 84, 5, 19, 1, 69, 7, 40, 8, 98, 
    2, 74, 1, 78, 4, 79, 0, 39, 6,  5, 3, 94, 8, 35, 7, 74, 5, 55, 
    8, 10, 4, 35, 5, 82, 1, 37, 2, 61, 3, 97, 6, 42, 0, 74, 7, 88, 
    4, 94, 0, 18, 6, 17, 3, 59, 2, 97, 5, 32, 7, 63, 1, 25, 8, 31, 
    1, 68, 3, 96, 6, 60, 5, 60, 0, 33, 2, 20, 8, 69, 4, 75, 7, 84, 
    7, 55, 5, 45, 6,  6, 0, 65, 8, 44, 4, 73, 2, 76, 3, 99, 1, 61, 
    8,  2, 7, 48, 1, 71, 6,  7, 4, 67, 0,  8, 2, 26, 3, 47, 5, 58, 
    1, 12, 2, 66, 5, 35, 8, 60, 4, 62, 6, 47, 0, 57, 3,  1, 7, 56, 
    5, 17, 0, 25, 1, 59, 3, 14, 4, 72, 6, 11, 7, 52, 2, 59, 8, 60
  };
  const int q5702[] = {
    9, 9, // Number of jobs and machines
    6, 64, 1, 34, 7, 28, 0, 47, 5, 42, 4, 86, 8, 76, 2, 38, 3, 32, 
    6, 34, 8, 14, 5, 93, 2, 13, 4, 39, 1, 63, 7, 41, 0,  1, 3, 93, 
    2, 32, 8, 76, 1, 84, 3,  2, 6,  3, 5, 77, 0, 10, 7, 59, 4, 80, 
    4, 43, 6, 95, 3, 90, 8, 38, 5, 69, 7, 42, 1, 74, 2, 20, 0,  4, 
    8,  5, 1,  7, 2, 16, 4, 98, 6, 89, 0, 53, 5, 50, 3, 85, 7, 35, 
    4, 38, 7, 20, 0, 10, 8, 15, 5, 42, 1,  1, 3, 30, 6, 87, 2, 97, 
    5, 68, 3,  9, 7, 59, 1,  1, 4, 87, 6, 35, 2, 65, 8, 93, 0, 85, 
    4, 53, 3, 27, 1, 71, 6,  8, 7, 37, 0, 42, 2, 73, 5, 75, 8, 80, 
    4, 40, 1, 92, 8, 28, 0, 31, 5, 41, 7, 66, 6, 33, 2, 91, 3, 29
  };
  const int q5703[] = {
    9, 9, // Number of jobs and machines
    1, 39, 7, 86, 5, 32, 2, 68, 0, 57, 4, 46, 6,  1, 8, 53, 3, 89, 
    6, 54, 3, 72, 4, 12, 0, 96, 5, 31, 8, 23, 2, 60, 1, 10, 7, 71, 
    2, 95, 4, 83, 6, 49, 1, 93, 0, 49, 3, 55, 5, 79, 8, 84, 7, 97, 
    3, 60, 4,  2, 6, 96, 7, 95, 1, 89, 0, 30, 2, 69, 5, 77, 8, 77, 
    6, 83, 1, 16, 8, 26, 7, 51, 4, 58, 5, 16, 3, 96, 0, 84, 2, 30, 
    7, 63, 2, 29, 6, 39, 3, 45, 4, 85, 0, 23, 5, 25, 8, 92, 1, 61, 
    6, 51, 3, 35, 7, 66, 8, 25, 5, 87, 2, 34, 1, 84, 4, 28, 0, 97, 
    6, 88, 3, 24, 2, 94, 4, 89, 0, 20, 7, 74, 5, 11, 8, 35, 1, 85, 
    8, 40, 0,  5, 1, 62, 4, 46, 3, 60, 5, 46, 7, 41, 6, 66, 2, 30
  };
  const int q5704[] = {
    9, 9, // Number of jobs and machines
    4, 14, 8, 93, 3, 83, 7, 65, 1, 86, 2, 71, 6, 76, 5, 41, 0, 45, 
    4, 13, 2, 86, 1, 12, 6,  4, 0,  4, 5, 33, 3, 83, 7, 48, 8,  1, 
    7, 37, 6, 41, 3, 68, 8, 48, 2, 16, 0, 98, 4, 23, 5, 13, 1, 49, 
    3, 84, 2, 36, 0, 46, 7, 24, 1, 37, 8, 76, 5, 65, 4, 62, 6, 40, 
    2, 68, 4, 70, 0, 69, 7,  5, 6, 35, 5, 44, 1, 80, 8, 40, 3, 39, 
    6, 69, 0, 52, 3, 68, 1, 37, 8, 70, 7, 61, 2, 48, 5,  1, 4, 61, 
    6, 97, 8, 82, 0, 60, 1, 26, 7,  3, 2, 51, 5, 63, 4, 85, 3, 70, 
    3, 84, 6, 47, 2, 79, 8, 62, 5, 80, 4, 80, 1, 54, 0, 25, 7, 94, 
    5, 73, 1, 89, 7, 67, 4, 15, 6, 88, 3, 16, 8,  6, 0, 17, 2, 36
  };
  const int q5705[] = {
    9, 9, // Number of jobs and machines
    8, 26, 2, 91, 6, 97, 7, 56, 0, 96, 1, 96, 3, 51, 4, 63, 5, 99, 
    7,  9, 1, 71, 6,  7, 8, 10, 5, 38, 2, 98, 0, 40, 4,  1, 3, 51, 
    3, 62, 6, 18, 1, 71, 2, 65, 5, 71, 4, 98, 7, 49, 8, 18, 0, 20, 
    4, 93, 0, 44, 7, 65, 2, 77, 5, 45, 3, 71, 1, 87, 8, 38, 6, 79, 
    6, 28, 8, 87, 1, 90, 7,  7, 0, 90, 2, 38, 4, 51, 5, 38, 3, 69, 
    5, 69, 4, 35, 1, 35, 0, 95, 3, 46, 6, 73, 2,  5, 8, 16, 7, 14, 
    8, 67, 4, 35, 3, 44, 2, 41, 0, 24, 6, 42, 7, 42, 5, 91, 1, 20, 
    0, 71, 3, 92, 1, 85, 6,  1, 4, 54, 2, 32, 8, 35, 5, 35, 7, 34, 
    2,  2, 6, 61, 3, 56, 4, 59, 7, 42, 5, 15, 1, 16, 8, 93, 0, 81
  };
  const int q5706[] = {
    9, 9, // Number of jobs and machines
    4, 30, 3, 81, 0, 54, 7, 54, 8, 57, 1, 40, 6, 91, 2, 33, 5, 47, 
    3, 86, 4, 25, 7, 44, 8, 76, 5, 59, 0, 72, 2, 50, 1, 54, 6, 21, 
    1, 54, 2, 72, 3, 17, 4, 56, 7, 29, 5, 78, 6, 83, 8, 56, 0, 54, 
    1, 42, 2, 36, 8, 12, 7, 51, 4, 99, 5, 90, 0,  1, 6, 79, 3, 27, 
    5, 43, 4, 64, 7,  1, 6, 10, 1, 75, 0, 20, 3, 56, 2, 46, 8, 73, 
    8, 98, 7, 86, 0, 41, 1, 22, 2, 96, 5, 78, 6, 12, 4, 65, 3, 59, 
    1,  4, 4, 31, 0, 47, 6, 92, 7, 98, 3, 55, 2, 95, 5, 33, 8, 42, 
    3, 95, 8, 29, 2, 60, 0, 77, 7, 62, 4,  1, 1, 29, 5, 28, 6, 74, 
    5, 69, 3, 14, 8, 46, 6, 67, 2, 35, 7, 61, 1, 23, 4, 51, 0,  4
  };
  const int q5707[] = {
    9, 9, // Number of jobs and machines
    5, 60, 8, 81, 7, 59, 3, 31, 2, 43, 4, 95, 6, 32, 1, 90, 0, 96, 
    5, 92, 0, 96, 4,  3, 1, 26, 6, 21, 8, 28, 7, 24, 3, 35, 2, 42, 
    5, 84, 4, 37, 1, 35, 3, 37, 2, 97, 6, 58, 7, 59, 0, 71, 8, 22, 
    2, 16, 0, 37, 6, 87, 4, 84, 5, 93, 7, 99, 3, 75, 1, 89, 8, 78, 
    5, 86, 0, 33, 2, 66, 6, 47, 1,  7, 8, 34, 3, 88, 4, 82, 7, 25, 
    2, 29, 4, 87, 6, 36, 1, 22, 0, 63, 5,  8, 7, 49, 8, 99, 3, 71, 
    8, 25, 5, 44, 0, 15, 2, 48, 6, 51, 3, 28, 4, 69, 1, 64, 7,  7, 
    2,  1, 3, 83, 6, 78, 5, 98, 7, 71, 0, 37, 1, 28, 8, 15, 4, 23, 
    3, 69, 0, 11, 5, 95, 4, 92, 7, 29, 8, 14, 2, 28, 1, 89, 6, 53
  };
  const int q5708[] = {
    9, 9, // Number of jobs and machines
    3, 47, 7, 74, 4,  1, 2,  8, 8, 42, 6, 81, 0, 24, 1, 79, 5, 76, 
    5, 91, 3, 64, 8,  3, 4, 91, 2, 15, 6, 89, 7, 77, 1, 13, 0, 60, 
    7, 54, 3, 99, 4, 49, 2, 60, 1, 54, 0, 89, 5, 55, 8,  6, 6, 23, 
    3, 21, 4, 72, 7, 49, 5, 88, 8, 44, 1, 52, 6,  5, 0, 98, 2, 55, 
    6, 19, 5, 87, 2, 58, 3, 31, 7,  2, 1, 97, 8, 77, 4, 77, 0, 90, 
    8, 54, 5, 11, 6, 97, 3, 60, 1, 69, 7, 84, 4, 47, 2, 27, 0, 17, 
    2, 80, 5, 27, 6, 96, 8, 87, 3, 16, 7, 98, 1,  9, 0, 41, 4, 93, 
    1, 33, 7, 23, 3, 57, 5, 87, 4, 72, 6, 36, 2, 32, 8, 66, 0, 31, 
    8, 53, 3, 12, 7, 13, 5, 20, 1, 64, 4, 85, 2, 49, 0,  4, 6, 15
  };
  const int q5709[] = {
    9, 9, // Number of jobs and machines
    4, 69, 5, 64, 7,  6, 8, 33, 0, 77, 3, 89, 1, 77, 2, 31, 6, 58, 
    5, 54, 7, 47, 4, 81, 8, 53, 3, 18, 2, 81, 1, 86, 0, 60, 6, 23, 
    6, 76, 2, 81, 1, 11, 3, 82, 4, 56, 7, 38, 0, 26, 8, 57, 5, 37, 
    5, 68, 0, 16, 1, 79, 4, 86, 7,  2, 2, 59, 6, 21, 8,  7, 3, 78, 
    1, 40, 5, 26, 4, 37, 2, 16, 8, 20, 0,  8, 6, 88, 7, 75, 3, 38, 
    8, 68, 2, 95, 4, 70, 1, 67, 6, 44, 3, 51, 0, 62, 5, 42, 7,  1, 
    3, 58, 2, 54, 0, 58, 7, 12, 5, 70, 6, 17, 1, 58, 4, 25, 8, 44, 
    6, 30, 4, 98, 8,  1, 3, 61, 0, 40, 7, 99, 1, 98, 5, 80, 2, 41, 
    4, 19, 5, 19, 8, 73, 2,  9, 6, 44, 7, 51, 0,  5, 1, 97, 3, 73
  };
  const int q5710[] = {
    9, 9, // Number of jobs and machines
    8, 88, 0, 72, 1,  6, 7, 42, 4, 95, 6, 11, 2, 35, 3, 20, 5, 98, 
    1, 24, 7, 97, 4, 40, 8, 12, 3, 97, 2, 63, 0, 93, 5, 50, 6, 20, 
    5, 62, 1, 91, 0, 89, 4, 11, 8, 22, 2, 43, 7, 71, 6, 53, 3, 25, 
    1, 90, 0, 18, 2, 72, 7, 33, 8, 60, 3, 65, 6,  4, 4, 58, 5, 32, 
    8, 70, 2, 26, 1, 19, 3, 10, 4, 89, 5, 87, 0, 24, 6, 37, 7, 95, 
    1,  8, 8, 42, 5, 44, 6, 44, 3, 98, 7, 75, 4, 15, 2, 27, 0, 21, 
    6,  5, 2, 58, 5, 35, 0, 88, 1, 69, 4, 68, 3,  2, 8, 40, 7, 10, 
    0, 58, 3, 20, 2, 36, 7, 71, 8, 17, 4, 48, 6, 12, 5,  4, 1, 88, 
    4, 73, 0,  7, 6, 55, 1, 82, 2,  5, 7, 42, 8, 11, 5, 86, 3, 55
  };
  const int q5711[] = {
    9, 9, // Number of jobs and machines
    3, 45, 1, 60, 2, 62, 7, 96, 8, 76, 5, 75, 0, 98, 6,  7, 4, 56, 
    4, 75, 2, 67, 7, 96, 1, 85, 8, 33, 0, 77, 6, 28, 5, 53, 3, 25, 
    1, 10, 5, 15, 3, 85, 2, 82, 8, 78, 4, 77, 7, 41, 6, 74, 0, 88, 
    0, 41, 1, 67, 7, 18, 2, 87, 3, 28, 6,  5, 5, 45, 4, 66, 8, 40, 
    6, 95, 0, 62, 5, 39, 2, 14, 3, 36, 1, 30, 8, 71, 4, 24, 7, 87, 
    4, 70, 0, 99, 1, 64, 6, 38, 3, 89, 2, 88, 5,  3, 8, 73, 7, 92, 
    2, 42, 4, 65, 7, 76, 3, 94, 1, 36, 8, 24, 0, 40, 6, 48, 5, 62, 
    3, 84, 0, 86, 4, 81, 8, 14, 1, 46, 5, 61, 6, 41, 2, 54, 7,  3, 
    6, 39, 4, 52, 3,  8, 7, 72, 2, 52, 0, 59, 5,  9, 1, 85, 8, 84
  };
  const int q5712[] = {
    9, 9, // Number of jobs and machines
    1, 71, 7, 51, 2, 85, 0, 59, 4, 15, 5, 90, 8, 95, 6, 57, 3, 98, 
    3, 38, 2, 37, 6, 68, 7, 12, 4, 93, 0, 31, 1, 17, 8, 22, 5, 48, 
    7, 15, 0, 53, 8, 88, 2, 29, 1, 63, 6, 87, 3, 16, 5, 35, 4, 35, 
    7, 70, 4, 57, 5, 32, 6, 66, 1, 47, 2, 79, 0, 96, 3, 66, 8, 83, 
    1, 39, 5, 44, 4,  1, 8, 40, 7, 67, 6, 46, 2, 49, 0, 27, 3, 27, 
    4, 61, 8, 67, 5, 52, 0, 13, 7, 41, 6, 75, 2, 47, 1, 79, 3, 47, 
    8, 72, 6, 82, 7, 35, 3, 98, 1, 41, 2, 83, 4, 29, 0, 52, 5, 81, 
    4, 13, 8, 13, 5, 93, 6, 74, 1, 26, 0, 42, 7, 67, 3, 56, 2, 69, 
    1, 59, 8, 21, 6, 99, 3, 94, 7, 64, 5,  1, 0, 98, 4, 65, 2, 45
  };
  const int q5713[] = {
    9, 9, // Number of jobs and machines
    1, 18, 7, 36, 3, 41, 6, 54, 5, 70, 0, 59, 2, 78, 8, 50, 4, 90, 
    0, 79, 4, 79, 3, 53, 6, 74, 5, 74, 7, 70, 2, 44, 1, 94, 8, 24, 
    3, 85, 1, 82, 8, 50, 6, 46, 2, 60, 7, 67, 5,  3, 4, 69, 0, 75, 
    0, 11, 3, 73, 2, 72, 4, 61, 7, 38, 5, 62, 8, 56, 6, 39, 1, 40, 
    7, 87, 2, 48, 0, 47, 5, 28, 6, 27, 1, 31, 8, 35, 4, 10, 3, 22, 
    1, 20, 6, 45, 3, 89, 5, 38, 4, 23, 2, 86, 8,  3, 0, 49, 7, 74, 
    3, 75, 1, 80, 8, 53, 2, 45, 4, 95, 5, 31, 0, 89, 6, 34, 7, 34, 
    0, 93, 8, 58, 7, 91, 2, 32, 4, 84, 6, 34, 1, 73, 5, 72, 3, 59, 
    5, 98, 6,  5, 1, 32, 3, 75, 7, 37, 0, 21, 2, 71, 4, 15, 8,  4
  };
  const int q5714[] = {
    9, 9, // Number of jobs and machines
    6, 86, 0, 49, 5, 19, 2, 27, 1, 23, 8, 85, 7, 93, 3, 27, 4, 80, 
    2, 62, 7, 77, 3, 57, 0, 12, 1, 35, 6,  8, 4, 23, 8, 56, 5, 84, 
    7, 98, 8, 55, 0, 82, 4, 34, 6, 66, 3, 37, 2, 56, 5, 70, 1, 68, 
    6, 31, 1, 12, 4, 74, 2, 48, 0, 77, 8, 80, 7, 32, 3, 41, 5, 20, 
    6, 58, 2, 22, 4, 66, 0, 13, 1, 91, 3, 95, 5, 10, 8,  9, 7, 44, 
    4, 19, 3, 53, 6, 23, 7, 78, 0, 31, 2,  6, 1, 57, 5, 43, 8,  5, 
    4, 16, 5, 17, 6, 59, 3,  1, 0, 49, 7, 95, 8, 32, 1, 97, 2, 19, 
    4,  6, 7, 26, 6, 27, 5, 24, 1, 47, 0, 45, 8, 63, 2, 22, 3, 78, 
    4, 91, 5, 63, 7, 80, 6, 40, 1, 89, 0, 46, 8, 87, 2, 29, 3, 62
  };
  const int q5715[] = {
    9, 9, // Number of jobs and machines
    3, 70, 1, 25, 6, 49, 2, 21, 8, 49, 7, 36, 0, 20, 5, 96, 4, 90, 
    3,  1, 5, 77, 1, 44, 0, 40, 4, 94, 8, 22, 2, 81, 7, 23, 6, 33, 
    4, 33, 0, 72, 3, 37, 2,  4, 5, 29, 1, 56, 8, 41, 7, 48, 6, 56, 
    3, 15, 7, 47, 5, 54, 8, 60, 0, 32, 2, 97, 4, 95, 1, 62, 6, 47, 
    1, 32, 4,  2, 6, 88, 0, 68, 3, 46, 8,  2, 5, 27, 2, 14, 7, 33, 
    7, 35, 0, 43, 8, 36, 2, 55, 1, 94, 4,  7, 3, 57, 5, 76, 6, 38, 
    6, 22, 8, 65, 3, 53, 5, 37, 4,  8, 1, 45, 7, 70, 2, 54, 0, 12, 
    6,  5, 3, 66, 2, 31, 8, 66, 1, 61, 4,  5, 5, 80, 7, 59, 0, 83, 
    8, 13, 1, 43, 3, 93, 2, 57, 5, 64, 0, 46, 4, 25, 6, 65, 7, 92
  };
  const int q5716[] = {
    9, 9, // Number of jobs and machines
    8, 17, 6, 99, 5, 66, 7, 52, 4, 46, 3, 68, 1, 15, 0, 74, 2, 20, 
    7, 79, 2, 89, 5, 38, 8, 66, 3, 96, 0, 78, 1, 54, 4, 70, 6, 33, 
    4, 85, 6, 13, 3, 71, 0, 64, 7, 72, 8,  3, 1, 56, 2, 84, 5, 50, 
    4, 62, 6, 32, 5, 21, 2, 84, 8,  5, 0, 86, 1, 48, 7, 49, 3, 21, 
    0, 89, 1, 88, 3, 71, 6, 79, 2, 77, 5, 14, 4, 92, 8, 70, 7, 28, 
    2, 11, 8, 87, 3, 60, 0, 40, 7, 66, 4, 90, 5, 42, 6, 26, 1, 31, 
    1, 55, 3, 11, 0, 32, 6, 19, 7, 94, 4, 48, 8, 31, 5, 42, 2, 59, 
    0, 79, 2, 54, 1, 87, 7,  5, 8, 26, 6,  9, 3, 13, 5, 27, 4, 93, 
    0, 42, 5,  2, 6, 15, 8, 58, 3, 49, 4, 51, 1, 89, 2, 38, 7, 55
  };
  const int q5717[] = {
    9, 9, // Number of jobs and machines
    7, 93, 2, 88, 4, 77, 8, 43, 1, 80, 3, 77, 0, 95, 5, 49, 6, 47, 
    6, 63, 8, 45, 0, 70, 2, 10, 7, 56, 4, 31, 5, 38, 1, 25, 3, 62, 
    0,  2, 8, 55, 7, 63, 2, 31, 6, 75, 3, 59, 5, 27, 1, 14, 4, 81, 
    0, 92, 2, 21, 8, 82, 5, 59, 4, 38, 7, 88, 6, 24, 3, 84, 1, 59, 
    4, 83, 0, 96, 6, 12, 8, 80, 2, 55, 5, 86, 7, 91, 1, 45, 3, 34, 
    2, 33, 8, 68, 1, 66, 6, 99, 5, 42, 4, 98, 0, 21, 7, 52, 3, 90, 
    2,  6, 5, 32, 3, 53, 6, 42, 7, 57, 8, 24, 0, 42, 1, 43, 4, 94, 
    7,  8, 4, 60, 8, 85, 0, 39, 2, 62, 6, 41, 1, 96, 3, 86, 5, 91, 
    3, 10, 4, 35, 7,  6, 0,  7, 1, 45, 2, 57, 5, 59, 6, 68, 8, 21
  };
  const int q5718[] = {
    9, 9, // Number of jobs and machines
    1, 41, 4, 29, 6,  4, 3, 74, 5, 91, 2, 39, 8, 67, 0,  1, 7, 13, 
    0, 52, 7, 94, 5, 27, 4, 30, 3, 81, 8, 94, 6,  3, 1, 92, 2, 88, 
    5, 32, 4, 79, 8, 43, 0, 11, 6,  1, 2, 45, 7, 84, 1, 11, 3, 52, 
    0, 83, 5, 89, 6, 13, 7, 64, 1, 85, 8, 40, 3, 78, 4, 33, 2, 48, 
    1, 10, 4,  6, 6, 71, 7, 18, 8, 76, 0, 84, 3, 46, 2, 70, 5, 54, 
    5, 19, 1, 71, 4,  8, 0, 62, 3, 20, 7, 90, 8, 31, 2, 90, 6, 85, 
    7, 76, 1,  7, 8, 41, 6, 40, 0, 70, 4, 88, 2, 65, 5, 32, 3, 83, 
    8, 66, 4, 98, 0, 67, 3, 21, 5, 86, 7, 65, 6, 53, 2, 99, 1, 44, 
    8, 70, 4, 61, 0, 34, 3, 10, 7, 36, 6, 12, 5, 11, 1, 65, 2, 12
  };
  const int q5719[] = {
    9, 9, // Number of jobs and machines
    4, 72, 3, 56, 7, 32, 8, 99, 2, 46, 1, 85, 5, 87, 0, 20, 6, 50, 
    2,  1, 1, 26, 0, 40, 6, 31, 8, 61, 5, 72, 7, 49, 3, 26, 4, 24, 
    8, 66, 6, 47, 1, 30, 3, 69, 2, 78, 5, 15, 7, 50, 0, 77, 4, 48, 
    6, 62, 1, 58, 2, 39, 8, 60, 0, 31, 7,  3, 4, 39, 5, 57, 3, 19, 
    5, 55, 3, 46, 8, 92, 2, 86, 4, 26, 6, 22, 0, 53, 7, 46, 1, 11, 
    0, 54, 4, 80, 6, 99, 7, 40, 5, 23, 2, 59, 8,  4, 1, 74, 3, 61, 
    6, 37, 1, 44, 5, 60, 7, 69, 0, 65, 2, 50, 4,  8, 8, 65, 3, 67, 
    6, 32, 4,  6, 2, 79, 7, 56, 0, 53, 8, 21, 1, 42, 5,  9, 3,  4, 
    8, 89, 1, 29, 6, 73, 2, 50, 5, 18, 3, 86, 7, 82, 0, 41, 4, 44
  };
  const int q5720[] = {
    9, 9, // Number of jobs and machines
    8, 10, 6, 29, 5, 81, 4, 78, 7, 70, 3, 76, 1, 62, 0, 76, 2, 78, 
    8, 26, 0, 15, 5, 93, 7, 20, 1, 88, 6, 81, 4, 18, 3, 93, 2, 71, 
    5, 57, 3, 63, 6, 98, 7, 72, 2, 82, 0, 37, 4, 82, 1, 63, 8, 21, 
    2, 21, 3, 94, 1, 17, 4, 75, 7, 49, 6,  9, 0, 76, 8, 25, 5, 31, 
    2, 23, 0, 89, 8, 24, 1, 10, 4, 84, 5, 26, 6, 53, 3, 96, 7, 56, 
    0,  1, 8, 87, 2, 86, 6, 50, 4, 48, 5, 60, 3, 54, 7, 40, 1, 42, 
    4, 13, 3, 67, 1, 56, 0, 13, 2, 37, 7, 25, 6, 13, 8, 31, 5, 36, 
    4, 58, 1, 49, 7, 65, 8,  3, 0, 38, 6, 21, 5, 92, 3, 51, 2,  3, 
    8, 30, 7, 62, 6, 68, 0, 85, 3, 34, 1, 64, 4, 12, 5, 54, 2, 62
  };
  const int q5721[] = {
    9, 9, // Number of jobs and machines
    0, 37, 4, 29, 8, 12, 1, 77, 7, 33, 3, 56, 6, 13, 2, 29, 5, 13, 
    0, 86, 1, 77, 4, 66, 2, 18, 5, 94, 8, 67, 7, 81, 3, 98, 6, 91, 
    7, 59, 5, 19, 0, 98, 4, 76, 6,  5, 1, 33, 3, 48, 8, 15, 2, 80, 
    2, 18, 5, 55, 1, 32, 8, 72, 0, 52, 6, 22, 3, 84, 4, 24, 7, 23, 
    4, 65, 3, 99, 8, 28, 1, 66, 0, 95, 6, 78, 7, 80, 2, 34, 5, 18, 
    3, 74, 0, 61, 5,  5, 4, 19, 2,  1, 8, 78, 7, 67, 1, 79, 6, 97, 
    3, 78, 0, 26, 7, 63, 8, 70, 2, 87, 4, 33, 5, 49, 6, 57, 1, 38, 
    7, 73, 6, 60, 2, 69, 5, 39, 3,  4, 1, 83, 8, 12, 4,  4, 0, 32, 
    4, 16, 5, 57, 3, 28, 2, 60, 7, 33, 8, 35, 1, 63, 0, 40, 6,  4
  };
  const int q5722[] = {
    9, 9, // Number of jobs and machines
    7, 43, 2, 49, 1, 68, 5, 14, 3, 71, 4, 62, 8, 75, 6, 10, 0, 33, 
    5, 57, 6, 37, 3, 75, 4,  7, 0, 81, 8,  2, 7, 78, 2, 77, 1, 95, 
    4, 97, 5, 56, 3, 46, 6, 11, 2, 13, 7, 56, 8, 42, 0,  5, 1, 18, 
    3,  6, 4, 51, 6,  7, 1, 52, 7, 19, 0,  1, 2, 61, 5, 99, 8, 62, 
    1, 81, 8, 49, 6, 25, 2, 48, 3, 59, 4, 97, 7, 67, 5, 55, 0, 69, 
    3, 46, 8, 46, 0, 37, 6, 49, 2, 95, 5, 96, 1, 68, 7, 21, 4, 13, 
    8, 43, 7, 54, 3, 71, 2, 86, 5, 15, 4, 80, 1, 55, 6, 52, 0, 83, 
    0, 36, 3, 17, 2, 33, 6, 75, 4, 41, 7, 95, 8, 49, 1, 73, 5, 24, 
    3, 11, 0, 22, 6, 78, 4, 40, 7, 26, 8, 63, 2,  3, 5, 52, 1, 30
  };
  const int q5723[] = {
    9, 9, // Number of jobs and machines
    5, 71, 2, 48, 7, 32, 1, 96, 8, 36, 0,  6, 4, 84, 3, 40, 6, 58, 
    2, 46, 8, 70, 6, 94, 7, 87, 4, 39, 0,  5, 5, 26, 3, 15, 1, 19, 
    8, 35, 6, 96, 0, 80, 7, 52, 2, 87, 5, 51, 4, 85, 1, 30, 3, 98, 
    1, 12, 2, 84, 7, 73, 6, 40, 0, 56, 3, 38, 4, 88, 8, 76, 5, 92, 
    3, 15, 8,  9, 7, 83, 6,  1, 1,  2, 2, 96, 5, 94, 4, 19, 0,  6, 
    1, 40, 7, 80, 3, 17, 4, 21, 2, 56, 0,  7, 8, 99, 5, 75, 6, 35, 
    6, 11, 8,  4, 2, 49, 3,  9, 0, 93, 5,  5, 4, 52, 1, 69, 7, 23, 
    5, 87, 8,  2, 0, 47, 1, 16, 7, 79, 2, 27, 3, 67, 6,  2, 4, 46, 
    3, 48, 8, 94, 6, 81, 5, 60, 4, 92, 2, 33, 0,  5, 7, 72, 1, 23
  };
  const int q5724[] = {
    9, 9, // Number of jobs and machines
    1,  4, 3, 50, 4,  4, 2, 69, 6, 30, 7, 71, 5, 91, 8, 65, 0, 89, 
    2, 79, 8, 98, 4,  1, 5, 62, 1, 71, 3, 14, 7, 16, 6, 67, 0,  8, 
    6, 99, 0, 40, 2,  1, 7, 65, 5, 69, 1, 31, 3, 43, 8, 72, 4, 42, 
    6, 56, 3, 93, 7, 85, 5, 69, 8, 77, 2,  2, 4,  7, 1, 72, 0, 61, 
    6, 67, 1, 92, 7,  1, 0, 41, 3, 78, 8, 67, 5, 92, 2, 35, 4, 83, 
    2, 93, 6, 59, 3, 72, 0, 27, 7, 67, 5, 29, 8, 44, 4, 12, 1, 23, 
    0, 82, 2, 97, 6, 21, 7, 74, 1,  2, 8,  3, 4, 84, 5, 84, 3,  5, 
    3, 90, 4, 59, 1, 97, 0, 69, 5, 78, 6, 87, 8,  3, 2, 55, 7, 77, 
    5, 66, 6, 96, 3,  2, 8,  7, 7, 70, 1, 64, 4, 74, 2, 25, 0, 64
  };
  const int q5725[] = {
    9, 9, // Number of jobs and machines
    8, 32, 0, 48, 6, 24, 5, 78, 7, 54, 4, 69, 1, 42, 3, 76, 2, 17, 
    6, 33, 8, 19, 1, 58, 2, 39, 3, 65, 7, 23, 4, 75, 5, 19, 0, 13, 
    2, 14, 0, 75, 3,  7, 4, 46, 8, 62, 5, 61, 7, 71, 1, 23, 6, 71, 
    6,  5, 4, 32, 5, 84, 1, 83, 3, 74, 2,  6, 0, 55, 7, 79, 8, 98, 
    2, 73, 0, 38, 5,  3, 3, 92, 8, 63, 4, 67, 6, 88, 1, 21, 7, 69, 
    5,  9, 7, 14, 8, 80, 2, 19, 0, 53, 6, 50, 1,  3, 4, 57, 3, 73, 
    4, 43, 0, 45, 3, 25, 7, 12, 2, 52, 6, 79, 5, 88, 8,  9, 1, 36, 
    8, 28, 7, 85, 5,  6, 2, 26, 6, 60, 1,  7, 3, 26, 4, 36, 0, 82, 
    7, 50, 3,  5, 2, 18, 5, 87, 8, 17, 0, 35, 4, 17, 1, 59, 6, 41
  };
  const int q5726[] = {
    9, 9, // Number of jobs and machines
    8, 18, 7, 96, 6, 72, 0, 20, 2,  3, 5, 41, 3, 49, 4, 84, 1, 74, 
    0, 45, 5, 70, 6, 72, 3, 84, 1,  2, 8, 92, 7, 39, 4, 68, 2, 38, 
    2,  4, 0, 93, 1,  5, 8, 44, 5, 33, 6, 60, 7, 74, 4, 83, 3,  6, 
    5,  9, 3, 61, 0, 64, 2, 66, 8, 29, 6, 10, 1, 11, 7, 98, 4, 17, 
    0, 78, 5, 83, 6, 25, 8, 66, 4, 70, 7, 91, 3, 82, 2, 27, 1, 22, 
    0, 73, 3, 88, 1, 62, 7, 88, 4, 79, 2, 10, 5, 36, 8, 70, 6, 14, 
    2, 63, 3, 96, 7, 92, 6, 95, 4, 31, 1, 49, 0, 77, 5, 86, 8, 24, 
    8, 17, 1, 13, 5,  8, 6, 16, 7, 36, 4, 32, 3, 42, 0, 66, 2, 88, 
    3, 52, 4, 14, 8, 15, 2,  2, 6,  7, 1, 86, 0, 80, 5, 28, 7, 92
  };
  const int q5727[] = {
    9, 9, // Number of jobs and machines
    4, 12, 6, 60, 2,  1, 0, 98, 5, 69, 8, 66, 3, 76, 7, 12, 1, 46, 
    4, 39, 6, 82, 1, 52, 5, 53, 0,  7, 2, 23, 7, 74, 3, 71, 8, 13, 
    8, 91, 5, 67, 1, 91, 7, 38, 0, 24, 4, 65, 2, 65, 6, 46, 3, 39, 
    1, 26, 6, 56, 5, 31, 3, 13, 2, 56, 0, 50, 4, 83, 8, 44, 7, 39, 
    4, 44, 7, 78, 0, 32, 5, 40, 3, 48, 8, 46, 6, 55, 1, 62, 2, 56, 
    8,  1, 6, 10, 5, 17, 1, 66, 7, 40, 2,  7, 3, 22, 4, 34, 0, 78, 
    0, 50, 5, 66, 6,  7, 7, 83, 4, 29, 2, 52, 1, 14, 3, 18, 8, 24, 
    8, 87, 7, 28, 3,  3, 6, 79, 0, 70, 2, 47, 5, 46, 1, 28, 4, 52, 
    5,  4, 8, 69, 0, 22, 1, 35, 3, 90, 7, 49, 4, 43, 2, 89, 6, 30
  };
  const int q5728[] = {
    9, 9, // Number of jobs and machines
    8, 89, 7, 33, 1, 71, 4, 30, 6, 29, 2,  8, 5, 58, 0, 93, 3, 26, 
    4, 74, 7, 20, 6, 35, 3,  4, 8, 34, 5, 66, 2, 12, 1, 45, 0, 34, 
    5, 78, 6, 44, 2, 61, 8, 39, 1, 59, 4, 21, 0, 40, 7, 50, 3, 84, 
    8,  2, 1, 11, 6, 95, 3, 73, 4, 73, 2, 12, 0, 98, 5, 25, 7, 91, 
    6, 32, 0, 53, 7, 77, 5, 59, 1,  2, 2,  9, 4, 49, 3, 60, 8, 43, 
    0, 42, 1, 60, 7, 45, 3,  8, 5, 52, 2, 26, 6, 56, 4, 80, 8, 82, 
    5, 57, 3, 12, 1, 84, 7, 43, 2, 50, 8,  1, 0, 86, 6, 43, 4, 92, 
    1, 85, 7, 41, 2, 29, 8,  5, 3,  1, 6, 38, 4, 56, 0, 56, 5, 29, 
    0, 45, 3, 69, 8, 76, 1, 63, 2, 87, 7, 77, 5,  3, 4, 22, 6, 52
  };
  const int q5729[] = {
    9, 9, // Number of jobs and machines
    7, 83, 8, 24, 6, 32, 4, 16, 1, 27, 2, 35, 0, 53, 5, 33, 3, 64, 
    4, 76, 1,  6, 5, 95, 0, 33, 8, 48, 2, 39, 3, 24, 7, 85, 6, 44, 
    3, 85, 1, 79, 8, 71, 4, 89, 0,  1, 2,  9, 6, 33, 5, 58, 7, 32, 
    0, 77, 2,  1, 5, 65, 4, 58, 6, 20, 7, 77, 3,  5, 8, 88, 1, 69, 
    4,  3, 6, 35, 1, 21, 0, 75, 2, 67, 8, 72, 5, 80, 3, 10, 7, 62, 
    0, 93, 3, 33, 2, 96, 7, 43, 6, 16, 1,  3, 8, 92, 4,  4, 5, 66, 
    5, 22, 1, 86, 4, 22, 3, 56, 2, 10, 7, 73, 0, 82, 6, 52, 8, 84, 
    6, 39, 1,  5, 0, 51, 4, 48, 7,  8, 5, 77, 2, 23, 3, 60, 8, 92, 
    4,  9, 6,  3, 1, 91, 0, 66, 5, 32, 7, 29, 3, 64, 8, 67, 2, 38
  };
  const int q5730[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 92, 3,  4, 0, 90, 8, 43, 6, 44, 1, 61, 7, 64, 5, 46, 
    4, 62, 6, 35, 8, 23, 1, 10, 2, 18, 5, 22, 3, 10, 7, 79, 0, 66, 
    6, 40, 4,  7, 0, 69, 3, 31, 7, 28, 1, 43, 2, 24, 5, 66, 8, 89, 
    2, 96, 5, 93, 1, 51, 8, 10, 6, 16, 3, 70, 0,  7, 7, 81, 4, 99, 
    8,  4, 5,  6, 3, 94, 2, 57, 7, 53, 4, 45, 0, 93, 6, 32, 1, 65, 
    8, 56, 0, 74, 4, 72, 6, 34, 1, 98, 7, 38, 5, 65, 2, 61, 3, 24, 
    8,  5, 4, 90, 3, 95, 0, 21, 7, 42, 1, 62, 5, 28, 6, 16, 2, 77, 
    1, 72, 4, 92, 8, 63, 5, 85, 7,  5, 3, 45, 2, 74, 0, 36, 6, 77, 
    4, 97, 8, 99, 7, 51, 0, 78, 2, 56, 6, 66, 3, 69, 5, 67, 1, 14
  };
  const int q5731[] = {
    9, 9, // Number of jobs and machines
    7, 44, 1, 33, 8, 85, 0, 26, 3, 16, 6, 30, 2, 50, 5, 88, 4, 41, 
    4, 50, 6, 26, 1, 93, 7, 79, 2, 63, 0, 60, 8,  7, 5, 43, 3, 72, 
    6,  5, 1, 51, 3, 56, 4,  6, 7, 14, 0, 60, 8, 91, 5, 55, 2, 99, 
    2, 92, 4, 32, 7, 87, 8, 41, 3, 30, 1, 73, 5, 37, 0, 30, 6, 75, 
    8, 27, 6, 76, 2, 60, 1,  2, 5, 89, 0, 52, 3, 31, 4,  8, 7, 66, 
    2,  6, 1, 40, 7,  6, 5, 14, 6, 95, 8, 38, 4, 13, 0, 75, 3, 41, 
    6, 65, 2, 15, 3, 93, 7, 26, 8, 64, 0, 61, 4, 81, 5, 12, 1,  9, 
    1, 62, 5, 54, 8,  4, 4, 68, 6, 32, 0, 50, 3, 44, 2, 36, 7, 21, 
    0, 29, 8, 69, 2, 16, 5, 78, 4, 32, 7, 82, 6, 30, 3, 54, 1, 34
  };
  const int q5732[] = {
    9, 9, // Number of jobs and machines
    0, 14, 8, 70, 7, 27, 3, 93, 2, 77, 5, 56, 4, 55, 6, 80, 1, 69, 
    4, 94, 5, 44, 0, 25, 1, 22, 2, 88, 3, 44, 8, 93, 6, 34, 7, 69, 
    4, 18, 6, 19, 2, 70, 5,  7, 1, 47, 0, 38, 8, 42, 3, 85, 7, 36, 
    1, 48, 2, 82, 8, 29, 6, 92, 0, 69, 5, 13, 4, 57, 3, 18, 7, 99, 
    4,  9, 6, 16, 7, 84, 8, 15, 1, 67, 3, 36, 2, 37, 5, 50, 0,  6, 
    4, 60, 3, 91, 0, 76, 1, 39, 7, 12, 2, 47, 6,  8, 5, 15, 8, 10, 
    5, 77, 7, 88, 4, 57, 2, 47, 8,  7, 1, 41, 3, 21, 6, 48, 0, 63, 
    6, 70, 4, 46, 3, 72, 2, 49, 8, 78, 7, 20, 0, 83, 5, 48, 1, 82, 
    5, 70, 0, 35, 2, 43, 8, 51, 7, 65, 1, 84, 6, 37, 3, 85, 4, 43
  };
  const int q5733[] = {
    9, 9, // Number of jobs and machines
    1, 83, 4,  1, 0, 49, 2, 39, 7, 20, 8, 30, 3, 44, 6, 85, 5, 27, 
    7, 62, 0, 93, 2, 64, 8, 91, 5, 39, 6,  9, 3, 14, 1,  9, 4, 80, 
    2, 91, 6, 16, 7, 78, 4, 22, 1, 35, 8, 11, 0,  8, 5, 42, 3, 90, 
    8, 10, 0,  2, 6, 93, 7, 22, 1, 85, 2, 77, 3, 10, 5, 57, 4, 74, 
    4, 52, 2, 48, 8, 26, 7, 10, 0, 32, 6, 11, 5, 78, 3, 38, 1, 43, 
    0, 95, 1, 57, 7, 82, 2, 57, 3, 71, 5, 54, 8, 98, 6, 68, 4, 30, 
    2,  3, 5,  6, 1, 45, 4, 83, 8, 17, 7, 64, 6, 29, 3, 14, 0, 12, 
    5, 19, 6, 39, 0, 45, 7, 56, 8, 88, 1, 33, 3, 34, 4, 74, 2, 69, 
    4, 74, 2, 15, 5, 62, 7, 14, 1, 49, 8, 69, 6, 79, 0, 19, 3, 79
  };
  const int q5734[] = {
    9, 9, // Number of jobs and machines
    2, 41, 5, 27, 8, 44, 3, 21, 4, 22, 7, 98, 6, 46, 1, 73, 0, 28, 
    0, 28, 5, 32, 4,  9, 8, 61, 3, 16, 7, 19, 6,  3, 2, 91, 1, 94, 
    2, 92, 3, 36, 6, 44, 5, 51, 4, 16, 0, 58, 8, 73, 1, 66, 7, 17, 
    5, 24, 4, 72, 8, 86, 7, 99, 0, 59, 6, 60, 1, 70, 2, 15, 3, 28, 
    0, 91, 2, 19, 1, 15, 7,  8, 5, 22, 6, 43, 3, 21, 4, 16, 8, 22, 
    4, 40, 1, 58, 7, 30, 3, 82, 0, 32, 6,  9, 5, 27, 8, 95, 2, 17, 
    7, 60, 5, 21, 3, 40, 6, 59, 4, 22, 0, 75, 1, 42, 2,  1, 8, 50, 
    6, 59, 2, 73, 5, 40, 0, 53, 1, 53, 4, 54, 8, 69, 3, 31, 7, 96, 
    7, 67, 5, 53, 1, 66, 8, 30, 6, 69, 3, 15, 0, 53, 4, 89, 2, 84
  };
  const int q5735[] = {
    9, 9, // Number of jobs and machines
    6,  1, 7, 46, 8, 94, 3, 12, 5, 25, 4, 85, 1, 63, 2, 37, 0, 21, 
    4, 83, 2, 42, 5, 66, 3, 60, 0, 32, 7,  2, 6, 65, 1, 59, 8, 58, 
    1, 55, 0, 36, 3, 41, 4, 59, 6, 35, 7, 47, 8, 47, 2, 53, 5, 90, 
    7, 92, 8, 95, 4,  3, 6, 99, 5, 62, 2, 96, 1, 37, 0, 43, 3, 40, 
    8, 62, 4, 18, 5, 98, 6, 75, 0, 12, 7, 12, 1, 72, 3, 95, 2, 60, 
    4, 97, 8, 11, 5, 50, 1, 46, 7, 16, 2, 11, 3, 15, 6, 56, 0, 49, 
    0, 52, 5, 71, 3, 29, 6, 22, 8, 31, 1, 50, 4, 87, 2, 76, 7, 52, 
    2, 46, 5, 20, 0, 27, 6,  1, 1, 93, 7, 82, 4, 69, 8, 98, 3, 95, 
    7, 53, 1, 15, 4, 54, 8, 19, 6, 34, 0, 71, 5, 92, 2, 75, 3, 52
  };
  const int q5736[] = {
    9, 9, // Number of jobs and machines
    2, 10, 5, 32, 7, 43, 8,  5, 4, 60, 3, 62, 1,  6, 0, 80, 6, 85, 
    5, 70, 3, 72, 4, 48, 0, 84, 2, 58, 6, 26, 1, 52, 7, 39, 8, 53, 
    0, 66, 1, 13, 8, 84, 7, 44, 3,  8, 6, 15, 4, 47, 2, 33, 5, 70, 
    5, 94, 8, 71, 0, 73, 2, 91, 3, 79, 1, 92, 4, 83, 6, 23, 7, 91, 
    8, 55, 1, 50, 2,  5, 5, 43, 4, 79, 7, 39, 3, 60, 0, 65, 6, 33, 
    2, 87, 8, 63, 6, 66, 0, 25, 1, 26, 7, 98, 3, 62, 5, 43, 4, 62, 
    1, 54, 7,  4, 3, 37, 6, 61, 0, 62, 5, 55, 2, 46, 8,  9, 4, 88, 
    7, 14, 8, 26, 6, 90, 2, 61, 0, 28, 3, 67, 4, 89, 5, 31, 1, 82, 
    0, 35, 7, 63, 3, 19, 6, 79, 1, 93, 2, 66, 4, 68, 5, 29, 8, 30
  };
  const int q5737[] = {
    9, 9, // Number of jobs and machines
    5, 38, 4, 72, 0, 20, 8, 51, 3, 98, 2,  3, 7, 81, 6, 34, 1, 56, 
    8, 27, 5, 96, 4, 99, 0, 62, 6, 59, 1,  7, 7,  4, 2, 52, 3, 42, 
    2, 73, 5, 92, 4,  1, 3, 17, 0, 36, 6, 56, 7, 77, 1, 62, 8, 69, 
    2, 52, 1, 59, 6, 95, 3,  3, 8, 14, 0, 80, 5, 95, 7, 40, 4, 70, 
    3, 33, 8, 72, 7, 24, 1, 51, 2, 60, 6, 82, 5, 39, 4, 85, 0,  3, 
    2,  4, 7, 23, 8, 90, 5, 72, 6, 37, 4, 12, 3, 64, 0, 90, 1, 47, 
    6, 51, 0, 16, 4, 43, 5, 40, 7, 63, 8, 20, 2, 41, 1, 12, 3, 43, 
    3, 77, 5, 20, 2,  4, 8, 84, 0, 90, 6, 24, 7, 79, 1, 60, 4,  5, 
    4, 20, 0,  6, 6, 59, 8, 22, 7,  1, 3, 23, 1,  1, 2,  2, 5, 36
  };
  const int q5738[] = {
    9, 9, // Number of jobs and machines
    6, 82, 3,  1, 7, 76, 8, 83, 4,  5, 1, 37, 5, 86, 2, 34, 0, 88, 
    3, 10, 7, 14, 5, 23, 6, 57, 8,  9, 2, 67, 0, 82, 1,  4, 4, 84, 
    6, 50, 8, 75, 2, 49, 0, 15, 1,  1, 5, 17, 3, 67, 7,  5, 4, 74, 
    3, 62, 6,  2, 7, 81, 1, 60, 5, 97, 2, 76, 8, 92, 4, 44, 0, 91, 
    7, 46, 1, 85, 5, 45, 8, 37, 3, 77, 0, 62, 4, 20, 2, 66, 6, 50, 
    4,  1, 3, 50, 0,  3, 8, 92, 6, 90, 5, 29, 7, 95, 1, 99, 2, 95, 
    1,  7, 0,  6, 2, 75, 7, 22, 6, 83, 3, 59, 8, 30, 4, 40, 5, 81, 
    7, 45, 5, 70, 0, 75, 8, 43, 2, 95, 6, 92, 1, 90, 4, 96, 3, 77, 
    0,  8, 7, 57, 3, 68, 8,  1, 2, 98, 6, 82, 5,  6, 1, 59, 4, 67
  };
  const int q5739[] = {
    9, 9, // Number of jobs and machines
    8, 15, 4, 94, 5, 86, 1, 81, 7, 35, 0, 67, 2,  3, 3, 17, 6, 43, 
    7, 71, 2, 34, 0, 91, 5, 69, 1,  4, 3, 39, 8, 73, 6, 86, 4, 33, 
    8, 70, 2, 54, 0, 36, 6, 51, 5, 86, 3,  6, 7, 31, 1, 11, 4, 28, 
    1, 36, 5, 36, 8, 35, 6, 12, 3, 95, 4, 60, 2, 45, 0,  3, 7, 68, 
    8, 55, 5, 90, 3, 17, 2, 92, 0,  7, 7, 73, 4, 43, 6, 15, 1, 47, 
    5, 72, 7, 15, 4, 96, 0, 30, 6, 39, 8, 39, 1, 27, 2, 16, 3, 75, 
    5, 27, 2, 76, 1, 26, 3, 27, 8, 58, 0, 81, 7, 15, 6, 43, 4, 47, 
    7, 45, 6, 55, 8, 93, 0, 74, 3, 28, 1, 11, 5, 87, 4, 14, 2, 73, 
    8, 85, 4, 18, 6,  6, 2, 48, 7, 94, 1, 51, 3, 11, 5, 13, 0, 81
  };
  const int q5740[] = {
    9, 9, // Number of jobs and machines
    8, 24, 1, 26, 7, 13, 2, 46, 0, 37, 5, 22, 4, 18, 6, 36, 3, 95, 
    8, 51, 6,  9, 5, 80, 1, 39, 3, 23, 4, 48, 0, 22, 2, 77, 7, 60, 
    3, 40, 1, 24, 6, 92, 8, 37, 2, 82, 0, 90, 7, 56, 5, 41, 4, 52, 
    2, 70, 3, 30, 6, 54, 4, 81, 0,  9, 7, 65, 1, 45, 5, 80, 8,  2, 
    1, 16, 4, 52, 5, 72, 0, 52, 8, 37, 6, 20, 7, 87, 3, 32, 2, 89, 
    8, 11, 5, 60, 1, 60, 6, 64, 2, 81, 3, 31, 4, 82, 0, 13, 7, 56, 
    8, 29, 0, 76, 1, 28, 3, 88, 5, 79, 6, 18, 7, 21, 4, 53, 2, 53, 
    6,  5, 0, 70, 2,  7, 7, 20, 5, 73, 4, 87, 3, 70, 1, 13, 8, 99, 
    5, 78, 7, 41, 2, 70, 0, 92, 4, 86, 8, 79, 6, 10, 1, 13, 3,  4
  };
  const int q5741[] = {
    9, 9, // Number of jobs and machines
    3, 64, 6, 49, 1, 90, 4, 29, 2, 84, 0, 50, 7, 63, 5, 92, 8, 82, 
    6, 60, 3,  6, 0, 19, 2, 11, 5, 97, 1, 48, 8, 88, 4, 17, 7, 46, 
    5, 19, 1, 53, 2, 48, 4, 22, 3, 50, 8, 81, 0, 30, 6, 41, 7, 29, 
    3, 30, 5, 77, 4, 24, 2,  6, 6, 92, 8, 33, 1, 26, 7, 76, 0, 25, 
    3, 47, 5, 24, 1, 57, 0, 91, 4, 31, 7,  3, 6, 63, 8, 16, 2, 57, 
    3,  5, 2,  9, 0, 77, 7, 37, 5, 68, 8, 88, 6, 97, 1, 83, 4, 38, 
    7, 49, 0,  4, 1,  4, 2, 15, 6, 73, 4, 19, 8, 20, 5, 16, 3, 25, 
    4, 83, 2, 14, 5, 94, 0, 43, 3, 21, 8, 97, 6, 58, 1, 38, 7,  3, 
    6, 75, 5, 80, 4, 18, 7,  1, 0, 57, 8, 56, 3, 24, 1, 83, 2, 41
  };
  const int q5742[] = {
    9, 9, // Number of jobs and machines
    7, 85, 0, 16, 4, 71, 5, 21, 3, 59, 1, 44, 6, 88, 8, 27, 2, 63, 
    7, 92, 6, 76, 3, 73, 8, 19, 5, 94, 2, 93, 4, 86, 1, 57, 0,  7, 
    2, 13, 3, 36, 8, 79, 0, 96, 5, 71, 1, 78, 7, 46, 6, 45, 4, 56, 
    3, 87, 7, 90, 4, 30, 6, 62, 2, 88, 8, 41, 5, 47, 1, 13, 0, 44, 
    1, 11, 6, 62, 7, 29, 8, 12, 5, 57, 3, 62, 2, 45, 4,  9, 0, 53, 
    8, 25, 7, 76, 4, 81, 5, 50, 0, 51, 1, 93, 6, 34, 2, 72, 3, 46, 
    8, 49, 1, 57, 6, 15, 5, 63, 0, 85, 3, 81, 7, 79, 2, 23, 4, 83, 
    1, 36, 6, 92, 4, 83, 7, 51, 0, 81, 5, 31, 8, 76, 3, 61, 2, 18, 
    1, 28, 7, 62, 8, 14, 6, 53, 4, 62, 5, 47, 2, 43, 3,  9, 0,  4
  };
  const int q5743[] = {
    9, 9, // Number of jobs and machines
    4, 83, 6, 19, 0, 51, 7, 46, 5, 64, 2, 69, 3, 91, 1, 42, 8, 62, 
    0, 84, 7, 26, 8, 81, 4, 96, 3, 27, 1, 32, 2, 61, 6, 74, 5, 21, 
    7, 60, 8, 75, 2, 95, 3, 47, 4, 42, 6, 38, 5, 28, 0, 66, 1, 59, 
    0, 22, 7, 78, 4, 55, 6, 39, 3,  3, 5, 64, 1, 82, 8, 90, 2, 81, 
    4, 85, 8, 98, 7, 82, 1, 11, 3, 59, 5, 62, 0, 91, 2, 86, 6, 71, 
    2,  4, 7, 67, 1, 46, 4, 37, 8, 89, 5,  5, 6,  3, 0, 73, 3, 40, 
    5, 44, 6, 14, 7, 80, 0, 20, 1, 60, 3, 72, 4, 56, 2, 46, 8, 58, 
    3, 48, 5, 29, 2, 64, 1, 67, 8, 31, 0, 21, 4, 30, 6, 42, 7, 55, 
    4, 81, 2, 66, 0, 11, 3, 50, 1, 94, 5, 35, 7, 96, 6, 46, 8, 65
  };
  const int q5744[] = {
    9, 9, // Number of jobs and machines
    4, 89, 2, 33, 5, 98, 6, 91, 8,  5, 7, 27, 0, 76, 3, 91, 1, 99, 
    7, 36, 0, 44, 2, 82, 5, 64, 4, 91, 3, 85, 1, 54, 8, 26, 6, 35, 
    5, 25, 2, 56, 7, 24, 1, 83, 6, 21, 0, 74, 4, 70, 3, 91, 8, 22, 
    1, 60, 3, 32, 6, 10, 0, 14, 5, 34, 4, 42, 2, 96, 8, 80, 7, 30, 
    5,  3, 8, 33, 2, 73, 4, 53, 3, 51, 0,  4, 6, 46, 7,  2, 1, 94, 
    1, 53, 3, 46, 5,  4, 6, 48, 7, 64, 2, 13, 0, 28, 8, 95, 4, 62, 
    8, 62, 6, 92, 4, 11, 1, 19, 7, 26, 2, 14, 0, 82, 5, 56, 3, 79, 
    4, 67, 1,  2, 2, 79, 0, 24, 8, 81, 7, 58, 5, 49, 6, 71, 3, 57, 
    6, 49, 5, 51, 3, 49, 2, 10, 4, 95, 8, 38, 7, 67, 1, 47, 0, 77
  };
  const int q5745[] = {
    9, 9, // Number of jobs and machines
    5, 27, 0,  9, 8, 85, 2, 29, 3,  8, 6, 47, 4, 87, 1, 65, 7, 59, 
    2, 55, 4, 95, 8, 51, 6, 57, 3, 61, 5, 43, 0, 64, 1, 35, 7, 89, 
    3,  7, 4, 11, 6, 71, 5, 64, 8, 85, 7, 88, 1, 22, 0, 82, 2, 72, 
    7, 61, 4, 33, 2, 62, 0, 84, 5, 13, 6, 26, 3, 50, 1, 63, 8, 67, 
    8, 16, 0, 33, 2, 94, 5, 91, 3, 56, 4, 28, 7, 65, 1, 39, 6, 25, 
    0, 53, 7, 89, 1, 31, 4, 75, 2, 62, 8, 76, 3, 33, 6, 50, 5, 65, 
    6, 80, 5,  6, 1, 64, 0, 51, 2, 42, 8, 33, 3, 82, 4, 74, 7, 27, 
    7, 47, 8, 57, 3, 37, 1, 59, 6, 24, 5, 89, 0,  6, 2, 63, 4, 54, 
    7, 82, 8, 90, 0, 58, 1, 32, 3, 89, 4, 54, 5, 65, 2, 51, 6, 11
  };
  const int q5746[] = {
    9, 9, // Number of jobs and machines
    5, 23, 3, 87, 6, 94, 4, 33, 2, 12, 0, 24, 8, 99, 1, 68, 7, 15, 
    8, 73, 5, 76, 1, 13, 0,  5, 6, 26, 2, 38, 4, 26, 3,  3, 7,  4, 
    2, 64, 8, 60, 5, 20, 3, 95, 7, 26, 6, 45, 4, 44, 1, 45, 0, 79, 
    7, 38, 1, 71, 5, 17, 2, 53, 0, 66, 6, 51, 8, 35, 4, 67, 3, 23, 
    8, 88, 6, 22, 7, 45, 2, 88, 0, 94, 3, 62, 5, 94, 4, 26, 1, 26, 
    2, 39, 1, 57, 8, 71, 6, 50, 3, 84, 5, 45, 0, 24, 4, 50, 7, 99, 
    5, 24, 4, 17, 8, 77, 0, 43, 2,  3, 7,  2, 1, 99, 3, 58, 6, 17, 
    0, 17, 7,  6, 4, 59, 6, 33, 3, 38, 2, 63, 1, 12, 5, 66, 8, 50, 
    8, 85, 6, 77, 0, 71, 7, 93, 3, 64, 2, 90, 5, 39, 1, 38, 4,  5
  };
  const int q5747[] = {
    9, 9, // Number of jobs and machines
    4, 83, 3, 70, 0,  9, 7, 23, 5, 44, 1,  4, 2, 97, 8, 60, 6, 67, 
    7, 58, 3, 21, 2, 42, 0,  8, 4, 39, 8, 37, 6, 84, 1, 64, 5, 46, 
    8, 82, 7, 67, 6, 90, 1, 47, 4, 92, 5, 13, 2, 91, 0, 17, 3, 21, 
    5, 79, 4, 92, 8, 63, 2, 74, 1, 24, 6, 50, 0, 31, 3, 18, 7, 17, 
    7, 98, 5, 53, 0, 80, 2, 97, 4, 15, 6, 42, 3, 50, 1, 44, 8, 47, 
    0, 65, 1, 25, 2, 84, 3, 98, 5, 74, 6, 39, 4, 17, 7, 47, 8, 77, 
    1, 31, 4, 80, 7, 23, 3, 61, 5, 52, 6, 68, 0, 92, 2, 84, 8,  9, 
    4, 96, 3, 39, 7, 74, 1, 65, 2, 23, 8,  4, 6, 22, 5, 86, 0, 83, 
    7, 97, 0, 17, 4, 20, 2,  3, 3, 21, 8, 62, 1, 86, 6, 18, 5, 91
  };
  const int q5748[] = {
    9, 9, // Number of jobs and machines
    3, 57, 0, 51, 4, 59, 8, 85, 1, 62, 2, 74, 7, 45, 5, 83, 6, 80, 
    5, 47, 7, 80, 1, 57, 4, 22, 2, 31, 6, 77, 3, 24, 8,  1, 0, 47, 
    4, 23, 1,  6, 0, 35, 8, 12, 5, 31, 2, 42, 7, 71, 6, 99, 3,  9, 
    0, 96, 3, 13, 6, 51, 1, 16, 2,  1, 4, 55, 5, 40, 8, 26, 7, 83, 
    3, 60, 2,  2, 0,  8, 8, 34, 4, 23, 6, 69, 5, 52, 7, 85, 1, 90, 
    6, 28, 2, 19, 8, 62, 1, 56, 7, 19, 0, 67, 4, 25, 3, 32, 5, 16, 
    3, 64, 6, 97, 8, 82, 5, 61, 4, 35, 1, 34, 0, 22, 7, 35, 2,  9, 
    1, 29, 2, 68, 0, 21, 4, 76, 8, 32, 3, 63, 5, 66, 6, 74, 7, 82, 
    7, 24, 4,  6, 5, 53, 3, 73, 6, 75, 2, 32, 1, 49, 0, 10, 8, 28
  };
  const int q5749[] = {
    9, 9, // Number of jobs and machines
    1, 61, 7, 29, 8, 14, 5, 73, 4, 31, 6,  5, 2, 50, 0, 30, 3, 39, 
    4, 82, 3, 61, 2, 63, 6, 54, 7, 50, 0, 48, 5, 68, 8, 35, 1, 96, 
    4, 76, 8, 23, 0,  5, 2, 58, 3, 93, 1, 55, 7, 87, 5, 75, 6, 47, 
    8, 40, 4, 53, 3, 16, 1,  5, 2, 52, 6, 46, 5, 66, 7, 15, 0, 93, 
    3, 23, 0, 27, 5, 14, 1, 64, 8, 18, 7, 25, 2,  6, 4, 56, 6, 58, 
    7, 10, 3, 57, 2, 85, 5,  4, 4, 20, 6, 72, 1,  7, 0, 53, 8, 32, 
    3, 28, 1, 73, 2, 21, 6, 98, 0, 40, 4, 25, 8, 89, 5, 32, 7, 65, 
    6, 23, 7, 12, 3, 96, 2, 22, 8, 29, 0, 13, 1, 17, 5, 99, 4, 47, 
    7, 18, 3, 87, 8,  1, 4, 12, 0, 25, 2, 91, 5, 91, 1, 80, 6, 61
  };
  const int q5750[] = {
    9, 9, // Number of jobs and machines
    1, 65, 4, 42, 6, 15, 7, 85, 2, 97, 3, 20, 8, 24, 0, 76, 5, 90, 
    5, 50, 3, 34, 4, 35, 2, 23, 1, 85, 7, 49, 0, 86, 8, 77, 6, 25, 
    3,  2, 1, 23, 6, 21, 8, 12, 4, 27, 7, 62, 2,  4, 0, 86, 5, 39, 
    1, 88, 8, 43, 3, 63, 7, 66, 5,  5, 4, 13, 6, 64, 0, 74, 2, 88, 
    6, 88, 1, 51, 5, 24, 3, 23, 2, 26, 7, 77, 4, 40, 0, 45, 8, 58, 
    0,  8, 2, 41, 1, 84, 3, 84, 7, 78, 6, 30, 4,  3, 8,  2, 5, 66, 
    4, 29, 3, 47, 2, 72, 5, 85, 8, 51, 7,  2, 0, 40, 1,  2, 6, 80, 
    5, 58, 1, 20, 3, 61, 6,  8, 7, 47, 8, 29, 2, 42, 0, 10, 4, 35, 
    5, 37, 6, 46, 2,  2, 1, 78, 0, 14, 7, 18, 8, 97, 4, 11, 3, 82
  };
  const int q5751[] = {
    9, 9, // Number of jobs and machines
    6, 60, 2, 34, 5, 13, 0,  5, 3, 17, 8, 93, 1, 36, 4, 45, 7, 38, 
    5, 47, 8, 22, 1,  6, 6, 36, 0, 72, 4, 37, 2, 62, 3,  7, 7, 92, 
    2, 57, 8, 26, 7, 21, 0,  1, 6, 32, 3, 56, 1, 74, 5, 29, 4, 72, 
    3, 12, 6, 55, 4, 90, 5, 31, 0, 43, 8, 21, 2, 66, 7, 51, 1, 69, 
    6, 60, 8, 12, 4, 51, 7, 26, 1, 81, 0, 94, 2, 95, 3, 97, 5, 84, 
    4, 41, 0, 87, 5, 67, 6, 61, 7, 76, 3, 21, 1, 35, 2, 99, 8, 36, 
    5, 73, 0, 93, 3, 75, 4, 98, 7, 22, 8, 67, 6, 67, 1, 89, 2, 34, 
    8, 58, 3,  5, 6, 27, 0, 21, 2, 96, 7, 51, 4, 15, 1, 77, 5,  5, 
    6, 87, 3, 59, 1, 68, 0, 44, 5, 52, 2,  8, 8,  3, 4, 32, 7, 79
  };
  const int q5752[] = {
    9, 9, // Number of jobs and machines
    8,  2, 7, 12, 5, 51, 1, 79, 3,  5, 2, 56, 4, 26, 0, 48, 6, 97, 
    3, 26, 7, 73, 1, 36, 5, 14, 8, 38, 2, 76, 6, 70, 4, 10, 0, 48, 
    1, 76, 4, 69, 7, 12, 5, 53, 6, 85, 3, 19, 2, 63, 0, 76, 8, 13, 
    2, 43, 8, 14, 1, 23, 5, 83, 0, 17, 7, 60, 3, 41, 4,  5, 6, 74, 
    4,  3, 6, 47, 5, 21, 8, 25, 1, 48, 0, 53, 2, 13, 7, 98, 3, 62, 
    8, 40, 0, 68, 5, 67, 4, 49, 1, 42, 7, 85, 6, 81, 2, 34, 3, 68, 
    7, 18, 0, 61, 3,  9, 4, 48, 6, 40, 5, 90, 1, 83, 2, 36, 8, 48, 
    2, 96, 7, 13, 1, 63, 4, 31, 6, 62, 5, 48, 8, 72, 0,  6, 3, 86, 
    4,  4, 2, 44, 7,  9, 3, 90, 8, 97, 5, 29, 6, 80, 0,  6, 1, 35
  };
  const int q5753[] = {
    9, 9, // Number of jobs and machines
    4,  8, 2, 96, 7, 70, 3, 29, 6, 95, 8, 21, 0, 83, 5, 13, 1, 54, 
    1, 87, 0, 36, 8, 78, 6, 89, 5,  9, 2, 39, 3, 64, 4, 94, 7, 82, 
    1, 88, 7, 50, 8, 62, 4, 31, 5, 46, 3, 41, 0, 33, 6, 36, 2, 46, 
    5, 10, 8, 58, 7, 41, 2, 44, 0, 53, 4, 14, 1, 50, 3, 50, 6,  4, 
    1, 61, 0, 53, 2, 31, 6, 96, 7, 59, 8, 68, 3,  3, 5, 90, 4, 15, 
    7, 95, 5,  8, 6, 53, 0, 36, 8, 49, 2,  4, 4, 20, 3, 59, 1, 35, 
    7, 29, 4, 98, 1, 78, 2, 35, 8, 51, 0, 66, 5, 15, 3, 73, 6,  1, 
    4, 50, 7, 45, 8, 67, 6, 19, 2, 25, 0, 33, 1, 12, 5, 11, 3, 55, 
    3, 37, 6, 66, 5, 33, 2, 24, 0,  8, 8, 34, 7,  6, 1,  2, 4, 32
  };
  const int q5754[] = {
    9, 9, // Number of jobs and machines
    0, 81, 5, 83, 3,  6, 4, 68, 8, 34, 6, 86, 7, 25, 2, 49, 1, 29, 
    8, 78, 7, 36, 2, 27, 4,  7, 3, 24, 1, 79, 5,  1, 0, 44, 6,  5, 
    3, 56, 5, 64, 1, 31, 2, 59, 6, 87, 4, 46, 7, 76, 8, 69, 0, 96, 
    3, 75, 6, 44, 5, 35, 1, 51, 0, 39, 8, 59, 2, 47, 7, 69, 4, 88, 
    5, 35, 1, 45, 8, 37, 7, 84, 2, 22, 6, 20, 4, 37, 3, 58, 0, 70, 
    2, 49, 5, 14, 7, 72, 0, 73, 4, 14, 8, 89, 1, 30, 3,  3, 6, 62, 
    0, 76, 6, 51, 5, 50, 3, 84, 2, 33, 8, 66, 4, 19, 7, 35, 1, 68, 
    0, 61, 3, 36, 1, 49, 4, 77, 6, 59, 7, 41, 2, 25, 8, 18, 5, 65, 
    1, 97, 2, 67, 3, 40, 6,  5, 0, 50, 5, 44, 4, 37, 8, 91, 7, 85
  };
  const int q5755[] = {
    9, 9, // Number of jobs and machines
    1, 55, 5, 87, 8, 43, 6, 68, 3, 94, 4,  5, 0,  9, 7, 18, 2, 28, 
    2, 23, 8, 49, 1, 65, 7, 57, 5, 14, 3, 93, 6, 32, 0, 82, 4, 40, 
    5,  3, 4, 13, 0, 42, 7, 89, 2,  2, 3, 41, 6,  8, 8, 13, 1, 37, 
    4, 70, 1, 71, 2, 94, 5, 32, 3, 36, 0, 61, 7, 27, 6, 51, 8, 20, 
    4,  2, 7, 55, 6, 52, 3, 25, 2, 47, 8, 10, 1, 52, 5, 17, 0, 52, 
    1, 38, 8, 13, 7, 51, 3, 11, 4, 65, 6, 89, 2, 52, 5, 20, 0, 45, 
    7, 29, 4,  1, 1, 99, 3, 45, 5, 67, 6, 84, 2, 73, 0, 45, 8, 57, 
    7, 24, 5, 96, 8,  7, 0, 75, 2,  4, 1, 99, 4, 89, 3, 93, 6, 31, 
    6, 59, 5, 83, 0, 70, 1, 30, 2, 42, 3, 64, 4, 38, 7, 87, 8, 75
  };
  const int q5756[] = {
    9, 9, // Number of jobs and machines
    1, 39, 8, 55, 6, 52, 0, 97, 7,  2, 4, 78, 3, 79, 2, 77, 5, 94, 
    8,  9, 5, 11, 6, 92, 0, 77, 1, 79, 7, 52, 2, 33, 3, 66, 4, 12, 
    0, 34, 3, 28, 6, 31, 8, 43, 1, 98, 7, 61, 2, 35, 5,  4, 4, 51, 
    0, 82, 4, 90, 6, 50, 8, 93, 1, 42, 3, 45, 5, 96, 2, 21, 7, 78, 
    4, 75, 7, 41, 5, 25, 3, 81, 2,  5, 6, 35, 8, 73, 1,  1, 0, 79, 
    6, 56, 0, 38, 8, 23, 1, 85, 7, 98, 5,  1, 2, 45, 3, 86, 4, 31, 
    4, 18, 6,  1, 1, 57, 0, 23, 7, 10, 2, 86, 3, 20, 8, 92, 5, 66, 
    5, 39, 1, 75, 4, 34, 3, 18, 6, 28, 0, 51, 2, 72, 8,  9, 7, 99, 
    4, 12, 6,  9, 0, 55, 7, 80, 8, 35, 5, 70, 1, 96, 3, 51, 2, 86
  };
  const int q5757[] = {
    9, 9, // Number of jobs and machines
    4,  8, 8, 19, 7, 40, 3, 25, 0, 76, 2, 34, 1, 75, 5, 76, 6, 84, 
    2, 53, 7, 70, 5, 28, 4, 97, 8, 33, 1, 16, 3, 88, 0,  2, 6, 12, 
    4, 64, 5, 99, 3, 87, 6, 80, 1, 40, 7, 16, 2, 98, 8, 14, 0, 88, 
    0, 86, 5, 63, 1, 11, 4, 60, 8, 61, 3, 86, 7, 86, 6, 99, 2, 73, 
    4, 34, 1, 40, 6, 50, 8, 85, 0, 75, 2, 58, 7, 96, 5, 27, 3, 80, 
    7, 15, 2, 82, 8, 21, 1, 93, 3, 31, 4, 69, 5, 85, 0, 73, 6, 80, 
    8, 32, 7, 63, 6, 49, 2, 79, 4, 75, 1, 47, 3, 15, 0, 55, 5, 27, 
    7, 44, 2, 21, 3, 55, 5, 79, 4, 99, 6, 80, 0, 24, 1, 40, 8, 17, 
    7, 65, 2, 95, 6, 10, 4, 74, 3, 13, 0, 86, 1, 17, 8, 95, 5, 27
  };
  const int q5758[] = {
    9, 9, // Number of jobs and machines
    1, 75, 0, 35, 6, 12, 3, 76, 4, 45, 7, 50, 5, 65, 2, 66, 8, 93, 
    0, 45, 7,  9, 6, 87, 8,  3, 5, 84, 2, 22, 3, 14, 1, 87, 4, 96, 
    0, 41, 7, 93, 4, 74, 1, 22, 2, 87, 8, 14, 6, 89, 3, 58, 5, 51, 
    0, 29, 3, 56, 8, 71, 7,  1, 4,  5, 1, 22, 6, 68, 2, 61, 5,  8, 
    0, 50, 4, 14, 8,  6, 1, 92, 3, 31, 5, 49, 2, 22, 6, 23, 7, 90, 
    4, 67, 7, 84, 2, 35, 3, 85, 6, 24, 1, 55, 5, 42, 8, 11, 0, 19, 
    2, 92, 8, 79, 4, 46, 5, 24, 7,  4, 1, 46, 3, 16, 6, 28, 0, 27, 
    4, 34, 0, 83, 7, 63, 5, 93, 6, 60, 1, 80, 2, 32, 3, 78, 8, 48, 
    5, 11, 4, 74, 2, 73, 8, 51, 1, 96, 7, 95, 3, 41, 6, 23, 0, 23
  };
  const int q5759[] = {
    9, 9, // Number of jobs and machines
    6, 88, 4, 17, 7, 73, 5, 54, 8, 31, 2, 49, 1, 45, 0, 86, 3, 31, 
    5, 77, 2, 12, 1, 83, 7, 98, 6, 64, 3, 56, 8, 46, 0, 29, 4, 40, 
    2, 59, 5,  8, 7, 66, 3, 15, 4, 61, 6, 65, 8, 31, 1, 92, 0,  6, 
    7, 12, 2, 68, 5, 86, 3, 53, 8,  3, 4, 49, 6, 32, 0, 15, 1, 89, 
    6, 21, 5, 63, 3, 92, 8, 79, 1, 95, 4, 16, 7, 10, 0, 81, 2, 65, 
    0, 82, 6, 52, 2, 38, 7,  5, 1, 24, 3, 18, 4, 71, 8, 20, 5, 67, 
    4, 68, 5, 55, 2, 67, 3, 67, 0, 36, 7, 56, 6, 13, 8, 75, 1, 17, 
    5, 18, 8, 43, 1, 80, 4, 46, 7, 10, 6,  7, 3, 34, 0, 32, 2, 33, 
    5, 72, 4, 34, 0, 35, 1,  2, 2, 56, 7, 50, 8, 94, 6, 10, 3, 36
  };
  const int q5760[] = {
    9, 9, // Number of jobs and machines
    5, 67, 6, 73, 4, 14, 0, 44, 3, 59, 8, 85, 7,  9, 1, 37, 2, 80, 
    8, 88, 1, 14, 3, 91, 4,  7, 0, 46, 2, 73, 6, 10, 5, 89, 7,  4, 
    1, 15, 5, 97, 3, 47, 2, 33, 4, 45, 0, 43, 8, 51, 6, 62, 7, 33, 
    6, 96, 4, 26, 5, 65, 0, 94, 1, 32, 8, 69, 3, 79, 7, 94, 2, 48, 
    1, 43, 7, 92, 8, 38, 6, 25, 4, 16, 5, 18, 2, 19, 0, 80, 3, 45, 
    8,  9, 2, 12, 6, 80, 3, 78, 4, 85, 1,  5, 7, 63, 0, 33, 5, 26, 
    2, 16, 7, 43, 4,  3, 8, 76, 6, 46, 0, 49, 5, 91, 1, 50, 3, 99, 
    8, 10, 5, 76, 1,  7, 7, 93, 0, 45, 6, 66, 2, 13, 3, 41, 4, 26, 
    1, 16, 2, 88, 4, 78, 8, 11, 6, 89, 0, 14, 5, 96, 3,  3, 7, 98
  };
  const int q5761[] = {
    9, 9, // Number of jobs and machines
    2, 32, 7, 18, 8,  6, 0, 43, 5, 92, 1, 83, 4, 61, 3, 47, 6,  5, 
    3, 58, 4, 14, 7, 90, 8, 99, 5, 50, 2, 29, 6, 79, 1, 26, 0, 96, 
    8, 62, 5, 94, 0, 65, 3, 60, 4, 54, 1, 88, 2, 63, 6, 98, 7, 37, 
    4, 15, 6, 91, 8, 97, 5,  3, 3, 86, 0,  2, 1, 30, 7, 66, 2, 39, 
    5, 95, 7, 58, 0, 19, 3, 60, 8, 86, 2, 30, 1, 23, 6, 52, 4, 85, 
    7, 46, 6, 52, 4, 63, 8, 45, 2, 98, 3,  4, 1, 19, 0, 20, 5, 11, 
    8, 47, 2, 99, 6, 14, 5, 89, 1, 71, 7, 81, 3, 69, 4, 90, 0,  8, 
    8, 98, 5, 65, 0,  6, 3,  2, 6,  1, 7, 36, 1, 91, 4, 56, 2, 10, 
    3, 25, 0,  6, 8, 80, 1, 74, 6, 63, 4, 79, 7,  9, 5, 43, 2, 81
  };
  const int q5762[] = {
    9, 9, // Number of jobs and machines
    7, 93, 1, 13, 0, 85, 4, 93, 2, 69, 8, 39, 6, 19, 3, 59, 5, 47, 
    1, 28, 4, 23, 2,  2, 6, 47, 7, 97, 8, 33, 3, 32, 0, 59, 5, 93, 
    5, 84, 6, 55, 8, 76, 3, 58, 2, 76, 0, 49, 4, 88, 7, 77, 1, 74, 
    3, 65, 5, 58, 8, 69, 2, 34, 4, 21, 6, 57, 1, 57, 0, 18, 7, 17, 
    1, 11, 3, 53, 0, 21, 5, 86, 7, 45, 2, 90, 6, 29, 4, 15, 8, 25, 
    1, 16, 7,  5, 2, 49, 0, 39, 8, 69, 6, 44, 3, 64, 5, 38, 4, 23, 
    7, 55, 1,  3, 4, 88, 0,  2, 2, 79, 6, 39, 8, 82, 3, 14, 5, 74, 
    8, 53, 3, 47, 7, 28, 0, 51, 1, 19, 2, 19, 5, 12, 4,  7, 6, 12, 
    5, 13, 1, 16, 6, 53, 2, 92, 7, 17, 3, 54, 4, 51, 0, 48, 8, 44
  };
  const int q5763[] = {
    9, 9, // Number of jobs and machines
    6,  9, 8, 17, 2, 55, 1, 21, 7, 69, 0, 17, 5,  2, 3, 58, 4, 83, 
    6, 56, 7, 47, 2, 31, 8,  8, 1, 80, 0, 15, 4, 27, 3, 63, 5, 28, 
    4, 67, 8, 54, 1, 59, 6, 95, 3, 85, 2, 88, 0, 35, 5, 73, 7, 74, 
    3, 18, 6,  2, 1, 14, 8, 17, 4, 52, 0, 68, 5,  6, 7, 41, 2, 97, 
    0, 19, 7, 67, 6, 20, 5, 15, 8, 20, 1, 85, 3, 41, 2, 46, 4, 29, 
    8, 82, 7, 79, 5, 78, 1, 27, 0,  5, 4, 19, 2, 77, 3, 17, 6, 97, 
    5, 67, 1, 84, 7, 40, 2, 57, 3, 39, 4, 77, 6, 21, 0, 74, 8, 94, 
    8, 97, 6, 24, 3, 56, 1, 76, 7, 93, 2, 76, 5,  7, 4, 68, 0, 20, 
    4, 61, 6, 92, 7, 87, 8,  2, 0, 68, 5, 64, 3,  9, 2, 97, 1, 69
  };
  const int q5764[] = {
    9, 9, // Number of jobs and machines
    0, 71, 8, 66, 1, 52, 6, 19, 2, 49, 3, 86, 5, 34, 4, 56, 7, 37, 
    2, 28, 5, 76, 3, 60, 0, 25, 4, 97, 1, 53, 6, 96, 7, 84, 8, 91, 
    7, 55, 1, 31, 4, 46, 5, 19, 8, 91, 2,  8, 6, 86, 0, 91, 3, 28, 
    0, 45, 7, 41, 1, 59, 4,  7, 2, 86, 5, 56, 8, 21, 6, 77, 3, 52, 
    3, 23, 4, 64, 5, 38, 8, 13, 6, 14, 7, 75, 2, 95, 0,  9, 1, 23, 
    8, 72, 5, 12, 4, 24, 3, 13, 6, 48, 1, 28, 0, 13, 7, 56, 2, 30, 
    7, 18, 0, 11, 5, 15, 1, 20, 8, 51, 4, 11, 2, 84, 3, 44, 6, 53, 
    6, 78, 7, 76, 2, 54, 3, 98, 8, 43, 0, 88, 4, 64, 5, 46, 1, 36, 
    5, 10, 2, 96, 7, 20, 1, 97, 0, 32, 6, 68, 4, 50, 3, 76, 8, 38
  };
  const int q5765[] = {
    9, 9, // Number of jobs and machines
    0, 43, 8, 76, 2, 36, 4, 72, 5, 29, 7, 56, 1, 23, 3, 78, 6, 77, 
    7, 60, 1, 56, 5, 18, 0, 78, 8,  8, 3, 38, 6,  5, 2, 69, 4, 30, 
    4, 57, 0,  7, 1, 13, 5, 73, 7, 60, 8, 77, 3, 71, 6, 23, 2, 34, 
    4, 30, 2, 99, 1, 85, 8, 95, 5, 43, 6, 37, 0,  9, 3, 53, 7, 32, 
    6, 60, 2, 90, 4, 24, 8, 68, 5, 35, 1, 78, 0, 55, 7, 66, 3, 77, 
    2, 84, 7, 87, 1,  2, 3, 34, 5, 96, 0, 34, 8, 92, 6, 31, 4, 70, 
    2, 39, 6, 87, 3, 40, 7, 31, 0,  7, 1, 41, 8, 97, 5, 71, 4, 51, 
    0, 24, 3, 11, 7, 17, 1, 86, 2, 32, 6, 42, 4, 12, 8,  2, 5, 12, 
    6, 89, 1, 64, 7, 42, 4, 76, 5, 83, 2, 26, 0,  3, 3, 15, 8, 44
  };
  const int q5766[] = {
    9, 9, // Number of jobs and machines
    8, 74, 0, 85, 3, 88, 2, 90, 5, 47, 6, 16, 4, 83, 7, 44, 1, 17, 
    7, 78, 0, 25, 8, 50, 1, 12, 2, 73, 3, 87, 5, 92, 4, 60, 6, 25, 
    0, 25, 3, 53, 8, 53, 5, 12, 7, 93, 6, 65, 2, 19, 4, 54, 1, 57, 
    6, 72, 5, 94, 2, 48, 7, 70, 8, 24, 0, 74, 4, 26, 3, 28, 1, 67, 
    6, 67, 1, 57, 5, 79, 4, 33, 8, 17, 0, 52, 3, 38, 7, 73, 2, 47, 
    8, 30, 5, 65, 7, 37, 2, 13, 0, 93, 1,  3, 3, 90, 4, 52, 6, 89, 
    5, 67, 3, 47, 7, 79, 8, 63, 0, 62, 2, 40, 1, 25, 6, 59, 4, 32, 
    4, 14, 7,  3, 3, 87, 2, 21, 6,  7, 1, 46, 8, 83, 5, 32, 0, 36, 
    4, 58, 5, 48, 0,  3, 1, 19, 3, 79, 7, 10, 2, 96, 6, 87, 8, 36
  };
  const int q5767[] = {
    9, 9, // Number of jobs and machines
    8, 22, 3, 12, 5,  6, 4, 55, 7, 52, 6, 77, 0, 67, 1, 88, 2, 56, 
    5, 76, 1, 71, 2, 86, 0, 31, 7, 18, 4, 74, 8, 90, 6, 84, 3, 97, 
    0, 33, 4, 34, 8, 21, 6, 95, 5, 20, 1, 58, 7, 10, 3, 61, 2, 12, 
    0, 33, 8, 36, 1, 21, 2, 35, 3, 83, 4, 37, 5, 24, 7, 82, 6, 79, 
    1, 63, 2, 23, 3, 82, 0,  6, 5, 79, 6, 55, 7, 64, 4, 60, 8, 88, 
    6, 74, 3, 94, 8, 66, 1, 14, 4, 23, 7, 49, 5, 20, 2, 67, 0, 68, 
    5, 54, 7, 80, 6,  2, 2, 67, 1,  9, 4, 82, 8,  3, 3, 26, 0, 92, 
    8, 39, 1, 96, 3, 75, 7, 61, 2, 16, 4, 30, 6, 56, 0, 65, 5, 67, 
    0,  3, 7, 89, 3,  4, 5, 33, 6, 38, 4, 14, 1, 35, 2, 54, 8, 55
  };
  const int q5768[] = {
    9, 9, // Number of jobs and machines
    3, 59, 0, 75, 7, 24, 6, 59, 1, 31, 2, 11, 4, 49, 5, 20, 8, 27, 
    3, 90, 5, 67, 7, 72, 2, 64, 1, 13, 8, 92, 0, 36, 6, 86, 4, 37, 
    6, 27, 4, 38, 8, 16, 7, 15, 1, 53, 2, 96, 3, 89, 0, 16, 5, 68, 
    4, 78, 8,  7, 5, 38, 0, 44, 2, 19, 1, 53, 6, 76, 3,  8, 7, 79, 
    1, 23, 8, 18, 7, 55, 5, 94, 6, 43, 4, 91, 0, 55, 2, 98, 3, 43, 
    5, 89, 4, 10, 2, 21, 1, 13, 3, 72, 6, 68, 0, 47, 8, 57, 7, 85, 
    0, 55, 3, 36, 8, 14, 4, 53, 1, 93, 6, 52, 5, 46, 2, 38, 7, 39, 
    0, 56, 2, 92, 6, 36, 8, 29, 4, 94, 5, 57, 3, 68, 1, 31, 7,  2, 
    0, 61, 3,  8, 6, 55, 4, 80, 7, 98, 1, 14, 2, 79, 5, 66, 8, 69
  };
  const int q5769[] = {
    9, 9, // Number of jobs and machines
    6, 70, 2,  8, 3, 28, 0, 50, 5, 57, 1, 17, 8, 50, 4, 39, 7, 95, 
    0, 57, 3, 13, 1, 80, 6, 62, 5, 82, 4, 22, 7, 23, 2,  1, 8, 52, 
    2, 19, 6, 24, 8, 60, 5, 72, 1, 28, 4, 24, 3, 46, 7, 81, 0, 95, 
    4, 51, 7, 20, 1, 90, 8, 10, 6, 78, 5, 11, 0, 66, 2, 96, 3, 12, 
    0, 44, 7, 99, 2, 78, 1, 57, 8, 70, 3, 15, 6, 47, 5, 82, 4, 67, 
    2, 22, 4, 57, 3, 51, 1, 50, 7, 35, 8, 20, 0, 77, 6, 31, 5, 36, 
    6, 41, 2, 36, 4, 77, 5, 91, 0, 49, 8, 49, 3, 55, 1, 95, 7, 32, 
    3, 72, 4, 27, 5,  5, 2, 89, 7, 29, 1, 24, 8, 35, 6, 94, 0, 95, 
    0, 81, 1, 79, 6, 15, 4, 10, 3, 43, 7, 33, 5, 27, 2, 31, 8, 19
  };
  const int q5770[] = {
    9, 9, // Number of jobs and machines
    4, 41, 3, 35, 8, 14, 7, 93, 0, 49, 5, 24, 2, 53, 1, 94, 6,  5, 
    4, 89, 0, 78, 1, 29, 3, 30, 5, 57, 7, 37, 6, 80, 2, 59, 8, 45, 
    2, 41, 5, 49, 3, 49, 0, 85, 1, 48, 8, 92, 7,  6, 6, 68, 4, 70, 
    1,  4, 5, 45, 3, 65, 4, 66, 6, 77, 0, 11, 8, 41, 7, 51, 2, 92, 
    2, 54, 1, 15, 4,  5, 6, 67, 3, 37, 0,  7, 7, 26, 5,  1, 8, 57, 
    5, 44, 1, 53, 3, 57, 6, 30, 4, 43, 8, 81, 0, 80, 2, 68, 7, 44, 
    2, 10, 7, 69, 0, 23, 1, 34, 3, 51, 6, 86, 8, 29, 5, 97, 4, 72, 
    1, 87, 8, 46, 4, 44, 7, 69, 3, 37, 0, 75, 5, 78, 6, 75, 2,  1, 
    5, 33, 7, 71, 2, 47, 3, 28, 0,  2, 1, 18, 8, 17, 4,  1, 6, 85
  };
  const int q5771[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 46, 6, 30, 0, 57, 5, 87, 3, 92, 1, 28, 8, 81, 7, 77, 
    6, 18, 1, 39, 8, 53, 2, 43, 3, 72, 4, 86, 5, 36, 0, 65, 7, 31, 
    7, 98, 0, 35, 4, 80, 6, 69, 3, 94, 8, 31, 1, 33, 5, 97, 2, 47, 
    5, 27, 2, 12, 8, 21, 7, 36, 4, 94, 6,  7, 1, 23, 0, 59, 3, 69, 
    5, 24, 2, 54, 1, 45, 8,  4, 6, 40, 7, 79, 4, 35, 3,  3, 0, 75, 
    6, 41, 0, 13, 5, 10, 8, 61, 3, 69, 1, 56, 2, 15, 4, 44, 7, 40, 
    2, 28, 3, 69, 1, 66, 7, 74, 0, 71, 5, 55, 4, 14, 6, 17, 8, 35, 
    3,  5, 4, 92, 0, 94, 5, 83, 8, 42, 1, 53, 7, 28, 2, 57, 6, 38, 
    4, 92, 1, 27, 6, 75, 8, 82, 2, 74, 3, 24, 0, 71, 5, 66, 7, 36
  };
  const int q5772[] = {
    9, 9, // Number of jobs and machines
    8, 31, 0, 79, 6, 84, 4, 93, 7, 47, 2, 77, 3, 55, 1, 94, 5, 90, 
    5, 90, 8, 24, 6, 97, 1, 59, 3,  1, 4,  8, 0, 23, 7, 36, 2, 85, 
    4, 36, 8, 67, 5, 61, 6, 92, 2, 24, 3, 30, 1, 11, 7, 99, 0, 83, 
    8, 22, 3, 84, 4, 35, 5, 58, 7, 80, 2, 80, 6, 13, 1, 83, 0, 41, 
    3, 67, 2,  8, 0, 93, 5, 77, 8, 97, 4, 71, 6, 55, 7,  1, 1, 51, 
    5, 36, 3, 56, 0, 51, 2, 14, 8, 31, 7, 67, 4, 72, 1, 63, 6, 92, 
    0, 47, 3, 65, 2, 91, 1, 86, 7, 92, 6, 39, 4, 14, 5, 58, 8,  4, 
    6, 88, 1,  9, 2,  4, 4, 14, 3,  1, 7, 63, 0, 77, 8, 20, 5, 33, 
    2, 27, 0, 36, 7, 32, 3, 32, 5,  5, 4,  9, 8, 24, 6, 46, 1, 53
  };
  const int q5773[] = {
    9, 9, // Number of jobs and machines
    3, 52, 8, 56, 2, 63, 1, 63, 6, 56, 5, 40, 4, 24, 0, 51, 7, 80, 
    7, 18, 6, 20, 4, 34, 5, 97, 8, 40, 1, 42, 0, 35, 3, 58, 2, 26, 
    6, 97, 3, 24, 8, 43, 0,  9, 2, 66, 4, 74, 7, 23, 5, 48, 1, 58, 
    1, 10, 6, 80, 7, 29, 0, 47, 8, 35, 5, 76, 3,  3, 2, 60, 4, 16, 
    5, 61, 6, 26, 3, 35, 0, 99, 8, 36, 2, 75, 4, 38, 1, 41, 7, 23, 
    8, 12, 6,  6, 3, 73, 2, 54, 5, 28, 4, 68, 1, 92, 0, 40, 7, 78, 
    5, 13, 7, 34, 8, 36, 1, 35, 4,  1, 0, 56, 3, 58, 6, 94, 2, 11, 
    5, 67, 2, 19, 6, 31, 1, 42, 3, 93, 0, 36, 8, 50, 7, 34, 4, 75, 
    7, 55, 6, 24, 0, 78, 2, 53, 4, 95, 1, 51, 5, 63, 3, 77, 8, 97
  };
  const int q5774[] = {
    9, 9, // Number of jobs and machines
    6, 26, 7, 71, 4, 18, 1, 25, 0, 35, 3, 23, 5, 62, 8, 54, 2, 46, 
    6, 82, 2, 34, 3, 40, 5, 31, 7, 79, 8, 97, 4,  7, 1, 36, 0, 99, 
    3, 13, 1, 91, 8, 90, 4, 18, 5, 10, 2, 12, 0, 47, 6, 44, 7, 30, 
    5, 37, 3, 93, 0, 67, 2, 31, 7, 45, 4, 49, 6, 71, 8, 58, 1, 33, 
    6,  3, 5, 42, 1, 71, 8, 94, 0, 33, 2, 19, 4,  9, 3, 59, 7, 93, 
    8, 65, 7, 33, 5, 71, 6, 34, 2, 74, 0, 29, 3,  5, 1, 14, 4,  1, 
    7,  8, 1, 95, 6, 58, 8, 72, 3,  8, 4, 42, 2, 88, 5,  7, 0, 41, 
    7, 79, 1, 73, 6, 98, 3, 84, 5, 42, 0, 41, 4, 57, 2, 47, 8, 47, 
    6, 50, 2, 73, 8, 44, 0, 53, 3, 95, 5, 55, 1, 58, 4, 61, 7, 52
  };
  const int q5775[] = {
    9, 9, // Number of jobs and machines
    6, 93, 7, 46, 8, 77, 3,  7, 0, 54, 1, 32, 2, 88, 5, 24, 4, 40, 
    7, 44, 3, 70, 6, 60, 5, 78, 1,  3, 0, 54, 8, 69, 2, 29, 4, 18, 
    5, 75, 1, 28, 2, 51, 0, 59, 8, 16, 7, 68, 6, 49, 4, 37, 3, 93, 
    0, 74, 4, 42, 7, 28, 6, 77, 5,  2, 1, 47, 3, 51, 8, 99, 2, 20, 
    5, 97, 2, 68, 4, 76, 1, 44, 8, 14, 0, 87, 6, 86, 7, 28, 3, 90, 
    3, 11, 4, 78, 1, 73, 6, 39, 0,  2, 2, 53, 7,  3, 8,  1, 5, 61, 
    0,  8, 6, 33, 8, 82, 1, 24, 5, 40, 4, 35, 3, 62, 2, 62, 7,  3, 
    8, 42, 6, 13, 5, 64, 7, 36, 4, 70, 3, 67, 1, 81, 2, 99, 0, 65, 
    8, 88, 4, 76, 3, 69, 5, 39, 2, 58, 7, 24, 0, 83, 6, 16, 1, 61
  };
  const int q5776[] = {
    9, 9, // Number of jobs and machines
    4, 44, 5, 60, 7, 34, 6, 78, 0, 73, 2, 54, 1, 92, 8, 78, 3, 48, 
    6, 10, 3, 76, 8, 77, 0, 40, 7, 76, 2, 71, 1, 86, 4, 12, 5, 41, 
    0, 91, 1, 37, 8, 29, 6,  2, 4, 63, 7, 19, 3, 57, 5, 52, 2, 80, 
    1, 58, 4, 80, 2, 13, 3, 69, 8, 77, 7, 48, 5, 43, 6, 72, 0, 84, 
    4, 99, 5, 27, 1, 36, 8, 40, 0, 39, 2, 17, 7, 32, 3, 58, 6, 11, 
    7, 82, 1, 37, 3, 14, 0, 31, 2,  3, 8, 74, 4, 75, 5, 30, 6, 33, 
    8, 90, 2, 85, 6, 83, 3, 19, 7, 96, 5, 92, 0, 18, 1, 11, 4, 20, 
    8, 26, 2, 98, 3, 16, 4, 29, 6, 34, 1, 42, 0, 81, 7, 33, 5, 96, 
    8, 73, 1,  2, 3, 87, 4, 97, 6, 18, 5, 38, 0, 68, 7, 33, 2, 37
  };
  const int q5777[] = {
    9, 9, // Number of jobs and machines
    4, 58, 5,  2, 1, 43, 6,  2, 2, 37, 8,  8, 7,  6, 0, 40, 3, 40, 
    0, 86, 4, 99, 6, 15, 3,  8, 7,  3, 1, 98, 2, 71, 5, 77, 8, 59, 
    6, 17, 1, 37, 3, 84, 4, 34, 2, 43, 0, 96, 7, 60, 8, 82, 5, 37, 
    7, 37, 5, 37, 8, 62, 6, 31, 2, 97, 0, 19, 4, 60, 3, 62, 1, 98, 
    6, 41, 1, 30, 3, 40, 8, 14, 7, 19, 5, 76, 0, 79, 2, 73, 4, 15, 
    2, 65, 0, 73, 1, 85, 4, 78, 8, 62, 5, 24, 7, 63, 6, 12, 3, 14, 
    1, 10, 7, 58, 2, 18, 6, 31, 5,  4, 4, 39, 8, 23, 3, 46, 0, 65, 
    5, 88, 8, 68, 2, 12, 0, 68, 4, 74, 6, 47, 1, 96, 7, 94, 3, 15, 
    1, 28, 4, 88, 8, 56, 2, 27, 7, 60, 6, 21, 5, 32, 0, 76, 3, 82
  };
  const int q5778[] = {
    9, 9, // Number of jobs and machines
    7, 18, 1, 58, 8, 29, 3, 40, 0, 23, 5, 27, 4, 77, 2, 24, 6, 37, 
    8, 44, 7, 62, 3, 16, 0, 90, 6, 43, 1, 19, 2, 51, 4, 99, 5, 93, 
    6, 56, 7, 68, 4, 10, 1, 22, 5, 86, 0, 98, 3, 77, 8,  8, 2, 36, 
    4, 54, 8, 38, 1, 59, 3, 91, 0, 85, 7, 47, 6, 18, 5, 59, 2, 76, 
    0, 87, 6, 85, 8, 64, 5, 17, 2, 36, 4,  3, 3, 33, 1, 58, 7, 75, 
    2, 10, 6, 10, 0, 70, 8,  6, 3, 45, 7, 86, 5, 66, 1, 46, 4, 77, 
    8, 84, 1, 96, 0, 64, 5, 75, 4, 47, 3, 39, 2, 53, 6, 36, 7, 49, 
    7, 73, 2, 20, 5, 55, 0, 22, 8, 97, 1, 40, 4,  5, 3, 71, 6, 65, 
    1,  7, 3, 60, 5, 17, 7,  5, 0, 31, 8, 74, 4, 34, 2, 24, 6, 99
  };
  const int q5779[] = {
    9, 9, // Number of jobs and machines
    4, 83, 3,  2, 6, 17, 8,  8, 2, 18, 7, 96, 5, 72, 0, 83, 1, 16, 
    7, 80, 3, 11, 1, 87, 5, 43, 2, 83, 8, 56, 4, 73, 6, 80, 0, 84, 
    8, 12, 2, 39, 4,  7, 7, 39, 3, 52, 1, 13, 6, 54, 0, 72, 5, 25, 
    4, 22, 1, 57, 6, 53, 3, 11, 7, 55, 2, 90, 8, 99, 0, 28, 5,  5, 
    0, 18, 4, 73, 7, 22, 5, 88, 2, 16, 6, 74, 3, 83, 1, 92, 8,  6, 
    4, 79, 1, 96, 7, 21, 5,  7, 0,  1, 3, 20, 6, 79, 2, 74, 8, 59, 
    6, 81, 2, 64, 0, 99, 4, 55, 8, 23, 7, 85, 3, 41, 5, 96, 1,  1, 
    8, 86, 6, 19, 0, 24, 5, 20, 2, 52, 1, 52, 3, 48, 4, 95, 7, 13, 
    5, 20, 1,  9, 6, 57, 0, 11, 3, 89, 2,  6, 8,  1, 4, 71, 7,  3
  };
  const int q5780[] = {
    9, 9, // Number of jobs and machines
    5, 63, 2, 54, 7, 68, 3, 82, 0, 58, 8, 42, 6, 47, 1, 34, 4, 89, 
    3, 91, 7, 26, 8, 21, 6, 70, 5, 26, 0, 86, 2, 70, 4, 32, 1, 13, 
    6, 11, 5, 96, 4, 66, 7, 99, 2, 27, 0, 66, 3, 76, 1, 82, 8, 29, 
    1, 91, 8, 17, 5, 91, 4, 95, 7, 61, 6, 78, 2, 87, 3,  8, 0, 58, 
    5, 46, 6, 36, 1,  3, 7, 73, 2, 97, 3, 59, 0, 44, 4, 54, 8, 64, 
    2, 17, 1, 45, 6, 13, 8, 33, 4, 85, 0,  4, 7, 18, 5, 91, 3, 64, 
    6, 54, 4, 12, 7, 12, 3, 58, 1, 84, 0, 25, 5, 58, 8, 28, 2,  2, 
    6, 13, 2, 89, 3, 76, 0, 90, 5,  8, 7,  6, 4, 59, 8, 56, 1, 35, 
    4, 31, 7, 19, 6, 89, 2, 21, 1, 43, 5, 79, 3, 89, 8, 18, 0, 62
  };
  const int q5781[] = {
    9, 9, // Number of jobs and machines
    0, 28, 2, 43, 6, 95, 5, 64, 1, 38, 8, 42, 7, 23, 4, 26, 3, 78, 
    6, 10, 2, 74, 8, 26, 1, 58, 5, 16, 4, 66, 3, 35, 0,  4, 7, 85, 
    1, 80, 2, 39, 3, 96, 5, 27, 7, 66, 0, 74, 6, 28, 4, 55, 8, 12, 
    2, 54, 3, 28, 7, 51, 6, 48, 1, 31, 0, 73, 5, 74, 4, 76, 8,  9, 
    8,  2, 7, 35, 0, 87, 3, 64, 1, 93, 2, 58, 6, 61, 5, 74, 4, 55, 
    0, 89, 2, 14, 3, 19, 1, 21, 5, 12, 6, 32, 7, 82, 4, 45, 8, 15, 
    3,  9, 0, 61, 6, 74, 5, 43, 2,  3, 8, 30, 7, 99, 4, 75, 1, 77, 
    6, 78, 2, 61, 5, 81, 3, 68, 4, 12, 8, 82, 0, 15, 7, 59, 1, 33, 
    7, 13, 2, 74, 5,  9, 6, 52, 1, 10, 0, 87, 4, 62, 3, 84, 8, 14
  };
  const int q5782[] = {
    9, 9, // Number of jobs and machines
    7, 93, 4, 99, 3, 62, 2, 40, 5, 50, 1, 10, 6, 71, 8, 35, 0, 70, 
    2, 25, 5, 72, 0, 92, 8, 21, 1, 14, 3,  4, 6, 57, 4, 62, 7, 44, 
    8,  2, 2, 38, 0, 62, 4, 32, 5, 64, 3, 30, 6, 27, 1, 26, 7, 70, 
    6, 83, 4, 97, 7, 79, 5, 41, 0, 61, 2, 99, 3, 82, 1, 95, 8, 53, 
    2, 59, 4, 98, 1, 38, 0,  2, 5, 20, 8, 25, 7, 73, 6, 53, 3, 72, 
    6, 55, 0, 72, 7, 19, 5, 28, 8, 68, 1, 18, 3, 60, 2, 92, 4, 13, 
    1, 66, 0, 40, 2, 84, 8, 68, 4, 15, 3, 88, 6, 83, 7, 33, 5, 13, 
    8, 32, 4, 74, 3, 21, 6,  8, 1, 53, 5,  5, 0, 92, 7, 70, 2, 20, 
    4, 70, 7, 74, 0, 28, 8, 74, 1, 66, 2, 46, 3, 62, 6, 41, 5,  9
  };
  const int q5783[] = {
    9, 9, // Number of jobs and machines
    4, 61, 5,  3, 0, 64, 8, 98, 7, 10, 6, 91, 2, 41, 3, 92, 1, 49, 
    8,  5, 4, 45, 5, 20, 7, 75, 6, 37, 3, 77, 0, 32, 1, 73, 2, 34, 
    0, 76, 5, 44, 1, 93, 3, 76, 7, 25, 8, 22, 4,  5, 6, 21, 2, 57, 
    4,  5, 7, 39, 6, 74, 3, 67, 5, 69, 2, 46, 0, 86, 8, 67, 1, 88, 
    1, 51, 5, 66, 7, 13, 3, 29, 6, 42, 2, 28, 0, 55, 4, 30, 8, 86, 
    2, 26, 6, 41, 5, 36, 8,  1, 7, 47, 0, 96, 3, 38, 1, 29, 4, 48, 
    7, 15, 8, 81, 5, 21, 2,  7, 6, 33, 0, 22, 1, 66, 3, 69, 4, 47, 
    3, 43, 4, 51, 1, 66, 6, 58, 2, 36, 7,  1, 8, 33, 5, 18, 0, 89, 
    6, 49, 8,  1, 4, 86, 2, 14, 7, 53, 3, 80, 1, 99, 0,  3, 5, 22
  };
  const int q5784[] = {
    9, 9, // Number of jobs and machines
    2, 33, 1, 94, 6, 63, 0, 72, 4, 89, 8, 13, 7, 97, 3, 93, 5, 13, 
    0, 21, 2, 53, 3, 80, 5, 13, 8, 19, 1, 31, 4, 62, 7, 18, 6, 26, 
    4, 85, 1,  6, 7, 62, 8, 34, 3, 37, 0, 36, 6,  3, 5, 83, 2, 78, 
    4, 49, 0, 42, 5, 15, 8,  2, 7, 52, 2, 92, 6, 24, 1, 54, 3, 50, 
    8, 24, 3, 96, 1, 21, 7, 12, 6, 80, 0, 84, 2, 69, 4, 17, 5, 74, 
    3, 92, 4, 85, 0, 68, 8, 44, 1, 29, 2, 49, 7, 31, 6, 56, 5, 39, 
    3, 50, 1, 70, 0, 49, 8, 29, 4, 42, 7, 89, 6, 60, 5, 49, 2, 79, 
    2, 41, 7, 98, 8, 15, 5, 68, 6, 19, 1, 42, 3,  6, 4, 36, 0, 38, 
    6, 10, 5, 29, 3, 21, 8, 55, 0, 89, 4, 77, 1, 79, 2, 58, 7, 57
  };
  const int q5785[] = {
    9, 9, // Number of jobs and machines
    7, 83, 1, 22, 4, 55, 0, 78, 3, 60, 6, 93, 5, 63, 2, 91, 8,  1, 
    4, 48, 6,  5, 5, 77, 0, 42, 2, 13, 1,  5, 3,  5, 8, 16, 7, 65, 
    4, 45, 8,  7, 1, 88, 7, 59, 0, 86, 3, 33, 2, 25, 6, 74, 5, 73, 
    2,  4, 3, 22, 4, 80, 8, 23, 5, 57, 1,  6, 0, 81, 6, 74, 7, 82, 
    7, 51, 5, 24, 1, 63, 2, 38, 8, 95, 6,  8, 3, 61, 0, 75, 4, 65, 
    0, 39, 3, 52, 4, 23, 1, 36, 7, 54, 5, 53, 8, 61, 6, 57, 2, 13, 
    3, 23, 5, 20, 4, 98, 7, 17, 0, 99, 6, 94, 8, 34, 2, 63, 1, 32, 
    1, 62, 3, 82, 2, 38, 8, 93, 4,  3, 7, 48, 0, 90, 6, 97, 5, 65, 
    2, 69, 4, 14, 8, 84, 0, 32, 3, 76, 6, 98, 7, 52, 5, 35, 1,  3
  };
  const int q5786[] = {
    9, 9, // Number of jobs and machines
    8, 88, 7, 60, 0,  3, 4, 49, 6, 53, 5, 82, 3, 56, 1, 60, 2, 98, 
    6, 56, 0, 72, 4, 81, 5,  8, 7, 86, 8, 68, 3,  8, 1, 53, 2, 82, 
    8, 66, 3, 52, 0, 44, 4, 53, 5, 22, 6, 55, 2, 79, 7, 43, 1, 64, 
    1,  7, 8, 24, 3, 11, 4, 38, 5, 32, 0, 10, 6, 81, 2, 51, 7, 42, 
    6, 41, 1, 39, 7, 23, 4, 45, 8, 87, 2, 21, 3, 39, 0, 43, 5, 30, 
    7, 83, 3,  1, 1, 78, 0, 22, 5, 80, 2, 11, 8, 42, 4, 59, 6, 96, 
    1,  3, 7, 31, 4, 48, 3, 37, 6, 39, 0,  5, 2, 28, 5, 97, 8, 59, 
    8, 41, 6,  6, 5, 62, 3, 14, 7, 96, 4, 13, 1, 59, 0, 49, 2,  3, 
    1, 22, 6, 62, 2, 37, 4, 21, 0, 26, 5, 46, 3, 85, 7, 27, 8,  8
  };
  const int q5787[] = {
    9, 9, // Number of jobs and machines
    6, 77, 5, 21, 4, 96, 0, 35, 7, 88, 3, 42, 1, 18, 2, 81, 8, 40, 
    3, 19, 1, 35, 6, 40, 8, 67, 7, 48, 4,  7, 2, 28, 0, 18, 5, 26, 
    1, 56, 5,  9, 4, 28, 3, 78, 0, 67, 6, 78, 7, 92, 2, 14, 8, 13, 
    2, 10, 0, 89, 1, 98, 8, 26, 6, 63, 3, 36, 4, 40, 7, 64, 5, 99, 
    5, 88, 0, 84, 7, 84, 4, 50, 6, 57, 1, 68, 3, 21, 8, 20, 2, 37, 
    5,  1, 6, 72, 4, 72, 2, 99, 7, 61, 3, 51, 8,  2, 1, 52, 0, 42, 
    1, 32, 3, 57, 5, 29, 4, 76, 8, 10, 2, 90, 0, 72, 6, 67, 7, 75, 
    8, 19, 6, 76, 5, 79, 1, 37, 7,  1, 0, 57, 2, 22, 3, 88, 4, 89, 
    8, 53, 2, 54, 6, 18, 4,  1, 7,  9, 1, 38, 0, 86, 5, 93, 3, 23
  };
  const int q5788[] = {
    9, 9, // Number of jobs and machines
    1, 38, 4, 60, 3,  1, 7, 94, 5, 76, 2,  3, 6, 27, 8, 44, 0, 13, 
    5, 18, 8, 86, 1, 12, 7, 13, 4, 74, 6, 74, 0,  5, 2, 78, 3, 40, 
    2,  6, 7, 43, 0, 43, 3, 61, 1, 94, 5, 36, 8, 13, 4, 63, 6, 79, 
    0, 53, 2, 92, 7, 20, 6, 13, 4, 22, 5, 84, 8, 20, 3, 89, 1, 41, 
    6, 18, 7, 67, 0, 59, 1, 88, 3, 59, 5, 69, 8, 54, 2, 46, 4, 17, 
    2, 43, 4, 29, 7, 25, 3, 11, 5, 39, 8, 29, 1, 56, 0, 24, 6, 15, 
    4, 77, 7,  1, 8, 32, 3, 13, 5, 29, 0, 69, 1,  7, 2, 50, 6, 61, 
    8, 42, 3, 95, 7, 29, 1, 19, 0, 86, 5, 13, 6, 69, 2,  2, 4, 40, 
    5, 43, 4, 99, 6, 91, 0, 12, 8, 85, 3, 63, 1, 78, 7, 82, 2, 66
  };
  const int q5789[] = {
    9, 9, // Number of jobs and machines
    5, 72, 2, 45, 7, 20, 8, 39, 3, 90, 1, 15, 4, 66, 6, 68, 0, 14, 
    1, 49, 2, 93, 0, 76, 8, 11, 5, 71, 6,  2, 3,  8, 4, 98, 7, 31, 
    7, 47, 3,  1, 5, 83, 2,  7, 6, 38, 1, 65, 4, 51, 8, 70, 0, 17, 
    2, 76, 6, 45, 3, 25, 0,  1, 5, 28, 7, 10, 1, 90, 4,  3, 8, 39, 
    4, 96, 6, 84, 3, 28, 2, 75, 8, 52, 5, 57, 1, 62, 7, 53, 0, 23, 
    1, 78, 5, 53, 3, 49, 6, 37, 7, 38, 0,  3, 2, 80, 4,  2, 8, 34, 
    3, 21, 4, 18, 5, 48, 2, 93, 8, 63, 0, 72, 7, 63, 6, 16, 1,  3, 
    3, 76, 0, 30, 1,  9, 4, 27, 5, 81, 8,  5, 7, 67, 2, 92, 6, 85, 
    5, 57, 8, 68, 2, 89, 7, 12, 6, 49, 4, 64, 1, 22, 0, 62, 3,  5
  };
  const int q5790[] = {
    9, 9, // Number of jobs and machines
    2, 87, 4, 91, 6, 99, 8, 38, 5, 55, 7, 31, 0, 15, 3, 13, 1, 33, 
    0, 92, 6, 60, 1, 96, 4, 85, 7, 45, 3, 59, 8, 54, 2, 55, 5, 49, 
    7, 41, 6, 99, 5, 57, 3, 33, 1, 45, 8, 40, 2, 21, 0, 42, 4, 54, 
    1, 68, 4, 31, 7, 57, 6, 65, 0, 68, 8, 95, 5, 47, 3, 55, 2, 29, 
    7, 17, 5, 18, 3, 98, 0, 50, 6, 75, 1, 70, 4, 20, 8,  7, 2,  9, 
    6, 57, 4, 90, 0, 27, 7, 82, 5, 29, 2, 14, 1, 11, 3, 81, 8, 17, 
    8, 33, 2, 24, 3, 59, 7, 92, 5, 72, 0,  4, 6,  8, 1, 72, 4, 82, 
    8, 77, 7, 91, 0, 66, 2, 47, 1, 32, 4, 46, 3, 69, 6, 62, 5, 28, 
    1, 97, 0, 56, 3, 26, 8, 28, 6, 16, 2, 62, 5, 27, 7, 30, 4, 50
  };
  const int q5791[] = {
    9, 9, // Number of jobs and machines
    8, 30, 1, 42, 6, 67, 5, 57, 0, 28, 7,  4, 4, 96, 3, 54, 2, 20, 
    4, 50, 3, 77, 7, 38, 2, 50, 0, 95, 8,  8, 5,  3, 6, 80, 1, 64, 
    1, 44, 6, 74, 3, 97, 0, 89, 5, 46, 4,  9, 8, 40, 2, 32, 7, 88, 
    8, 98, 2, 44, 5, 50, 3, 43, 6, 36, 7, 90, 4, 19, 1, 88, 0, 13, 
    6, 88, 2, 89, 7, 15, 1, 51, 4, 94, 8, 90, 5, 35, 3, 39, 0, 68, 
    7, 17, 8,  6, 3, 59, 6, 52, 4, 48, 1, 16, 2, 45, 5, 23, 0, 56, 
    1, 41, 0, 43, 5, 56, 7, 20, 3, 73, 4, 41, 2, 70, 6, 63, 8, 46, 
    0, 52, 2, 23, 8,  9, 1, 87, 7, 50, 4, 65, 5, 12, 6, 89, 3,  5, 
    1, 56, 7, 57, 8, 85, 5, 19, 6, 63, 2, 49, 3, 87, 4, 60, 0, 64
  };
  const int q5792[] = {
    9, 9, // Number of jobs and machines
    5, 45, 6, 97, 4, 47, 8,  8, 1, 86, 2, 97, 7, 51, 3,  9, 0, 78, 
    6, 38, 3, 13, 1, 30, 0, 34, 4,  8, 5, 63, 8, 86, 2, 73, 7, 36, 
    1, 20, 5, 35, 2, 58, 6, 64, 0, 45, 7, 53, 3, 40, 4, 23, 8, 48, 
    5, 46, 0, 12, 4, 58, 7, 11, 8, 82, 1, 85, 6, 38, 3, 85, 2, 91, 
    3, 84, 2, 18, 4, 80, 8, 20, 0, 63, 6, 86, 7, 71, 1, 88, 5, 31, 
    6, 76, 3, 66, 1, 22, 4, 44, 5, 86, 2, 95, 0, 87, 7, 55, 8, 21, 
    7, 64, 5, 44, 4,  3, 0, 86, 2, 41, 6, 58, 1, 91, 3,  1, 8, 30, 
    5, 86, 2,  7, 0, 45, 6, 58, 3, 67, 8, 19, 4, 64, 7, 71, 1, 60, 
    3, 21, 8, 28, 6, 17, 1, 68, 0, 26, 7, 18, 4, 36, 2, 77, 5, 75
  };
  const int q5793[] = {
    9, 9, // Number of jobs and machines
    1, 32, 6, 86, 7, 37, 5, 48, 8,  3, 2, 48, 4, 57, 0, 27, 3, 31, 
    2, 55, 3, 16, 0, 64, 1, 47, 4, 19, 6, 32, 8, 12, 5, 14, 7, 27, 
    0, 48, 6, 76, 2, 30, 7, 19, 5, 40, 1, 99, 3, 55, 4, 31, 8, 79, 
    1, 54, 0, 66, 6, 52, 8, 16, 4, 98, 3, 90, 5, 18, 7, 79, 2, 82, 
    6, 14, 2, 52, 7, 77, 5, 55, 8, 70, 4, 27, 0, 55, 3, 68, 1, 28, 
    2, 96, 5, 96, 0, 94, 7, 17, 1, 99, 4, 62, 8, 38, 3, 51, 6, 26, 
    3, 30, 7, 44, 6, 49, 4, 70, 0, 97, 2, 40, 1, 53, 5, 43, 8, 17, 
    3, 73, 0, 55, 2, 79, 5, 69, 1, 50, 4, 74, 8, 65, 7, 14, 6, 37, 
    7, 61, 8, 76, 4,  8, 1, 60, 6, 60, 5, 60, 3, 86, 0,  4, 2, 28
  };
  const int q5794[] = {
    9, 9, // Number of jobs and machines
    0, 52, 7, 56, 4, 58, 6, 11, 5, 41, 2, 72, 8, 29, 3, 62, 1, 19, 
    5, 84, 7, 98, 8, 74, 0, 31, 6, 77, 4, 93, 1, 64, 3, 97, 2, 69, 
    1, 96, 3, 35, 0, 46, 2, 97, 4, 40, 8, 36, 5, 70, 7, 36, 6, 94, 
    0, 33, 8, 65, 7, 90, 1, 69, 6, 85, 4, 27, 3, 96, 2, 72, 5,  4, 
    1, 12, 2, 73, 6, 58, 7,  1, 4, 80, 5, 75, 0, 56, 8, 14, 3, 80, 
    4, 49, 3, 28, 6, 42, 5,  1, 0, 55, 1, 77, 8, 38, 7, 46, 2, 46, 
    4, 72, 0, 31, 1, 54, 8, 78, 5, 41, 2, 48, 6, 28, 7,  6, 3, 17, 
    7, 56, 4, 15, 1, 41, 0, 33, 6, 36, 8, 12, 5, 28, 3, 72, 2, 63, 
    3, 61, 4, 34, 8, 45, 6, 73, 1, 46, 2, 76, 5, 58, 0, 94, 7, 45
  };
  const int q5795[] = {
    9, 9, // Number of jobs and machines
    0, 21, 7, 31, 3, 82, 5, 28, 4, 97, 8, 77, 1, 63, 6, 97, 2, 17, 
    7, 27, 8, 31, 3, 51, 4, 90, 2, 27, 0, 53, 1, 12, 6, 81, 5, 80, 
    6, 67, 5, 19, 0, 85, 8, 69, 1, 91, 7, 39, 2, 48, 4, 96, 3, 48, 
    7, 80, 2, 88, 6, 94, 0, 44, 1, 60, 4, 11, 5, 72, 3, 68, 8, 21, 
    7, 96, 8, 14, 3, 12, 5, 32, 4, 56, 2, 32, 0, 19, 6, 45, 1, 94, 
    7, 24, 4, 27, 8, 16, 0, 85, 5, 19, 6, 73, 3, 26, 2, 90, 1, 75, 
    1, 40, 4, 81, 0, 45, 7, 40, 6, 35, 5, 84, 8, 91, 2, 69, 3, 62, 
    4, 59, 7, 88, 0, 83, 8, 13, 1, 63, 2, 92, 6, 30, 3, 87, 5, 83, 
    1, 22, 3, 17, 6, 33, 5, 44, 7, 54, 0, 58, 2,  8, 8, 39, 4, 94
  };
  const int q5796[] = {
    9, 9, // Number of jobs and machines
    6, 43, 7, 63, 1, 10, 2, 28, 8, 98, 4, 54, 0, 64, 3, 15, 5, 46, 
    3, 84, 7, 33, 1, 53, 8, 67, 5, 71, 6, 51, 2, 90, 4,  2, 0, 86, 
    4,  9, 2, 69, 7, 85, 8, 51, 6, 93, 3, 53, 1, 20, 0, 79, 5,  7, 
    5, 72, 1, 73, 6, 11, 8, 43, 7, 22, 4, 86, 2, 79, 3,  9, 0, 85, 
    1, 59, 7, 30, 8, 12, 4, 26, 0,  5, 2, 43, 3, 67, 5, 23, 6, 84, 
    2, 32, 6, 49, 5, 34, 4, 58, 3, 55, 7, 62, 8, 92, 1, 63, 0, 94, 
    8, 92, 1, 28, 6, 51, 2, 75, 3, 35, 4, 45, 5, 88, 7, 88, 0, 80, 
    0, 45, 4, 44, 5, 91, 2, 65, 8, 84, 7,  5, 6, 47, 3, 99, 1, 85, 
    8, 29, 3, 66, 6, 26, 4, 52, 2, 41, 5, 30, 1, 58, 7,  8, 0, 96
  };
  const int q5797[] = {
    9, 9, // Number of jobs and machines
    6, 31, 0, 42, 7, 13, 5, 65, 2, 58, 1, 57, 3, 78, 8, 25, 4,  2, 
    0, 18, 8, 87, 3, 96, 7, 35, 6, 46, 5, 55, 2,  2, 1,  8, 4, 85, 
    4, 58, 0, 51, 8, 98, 2, 14, 7, 53, 5, 63, 6, 13, 1, 28, 3, 57, 
    5, 74, 4,  9, 1, 86, 6, 93, 8,  3, 2,  1, 0, 60, 7, 47, 3, 32, 
    5, 51, 2, 89, 7, 96, 6, 14, 8, 67, 3, 37, 4, 29, 0, 91, 1, 24, 
    7, 99, 2, 54, 3, 84, 5, 74, 8, 81, 0,  9, 6, 89, 1, 52, 4,  2, 
    7, 24, 5, 59, 4, 36, 2, 90, 8, 77, 3, 11, 0, 36, 6, 87, 1, 78, 
    5, 60, 7, 93, 4, 45, 1, 88, 2, 68, 8, 10, 0, 38, 6, 20, 3, 96, 
    3, 86, 2,  2, 6, 53, 7, 89, 8, 28, 5, 70, 4, 68, 1, 64, 0, 58
  };
  const int q5798[] = {
    9, 9, // Number of jobs and machines
    6, 38, 2, 41, 0,  5, 5, 68, 8, 84, 4, 32, 7, 11, 1,  1, 3, 54, 
    8, 73, 1, 59, 3, 50, 5, 61, 0, 49, 7, 54, 4, 86, 6, 33, 2, 54, 
    5,  9, 2,  5, 6,  8, 1, 89, 4, 35, 3, 40, 8, 86, 7, 90, 0, 78, 
    4, 10, 8, 49, 7,  2, 3, 19, 2, 87, 0, 92, 1, 55, 5, 98, 6, 29, 
    1, 87, 4, 93, 6,  8, 2, 34, 3, 18, 7, 91, 0, 19, 5, 32, 8, 19, 
    8, 96, 2, 16, 7, 52, 0, 93, 5, 23, 1, 33, 6, 38, 4, 33, 3,  5, 
    7, 53, 3, 82, 2, 29, 6, 45, 8, 65, 5, 52, 0, 68, 4, 91, 1, 40, 
    4,  6, 0, 45, 2, 17, 7, 34, 6, 58, 3, 35, 8, 46, 5, 93, 1, 97, 
    1, 20, 7, 78, 0, 91, 3, 18, 8, 51, 4, 87, 6, 48, 2, 39, 5, 89
  };
  const int q5799[] = {
    9, 9, // Number of jobs and machines
    8, 52, 3, 72, 5, 94, 7,  9, 0, 91, 2, 44, 1, 90, 6, 69, 4, 98, 
    1, 32, 4, 67, 3, 93, 7, 75, 8, 32, 5, 93, 0, 58, 2, 52, 6, 88, 
    8, 48, 1,  2, 2, 48, 0, 99, 6, 83, 4, 52, 7, 37, 5, 55, 3, 66, 
    4, 40, 2, 53, 8, 18, 1, 25, 5, 11, 7, 68, 6, 19, 0, 65, 3, 18, 
    1, 19, 8, 24, 5, 97, 0, 90, 2, 18, 3, 84, 4, 48, 7, 93, 6, 98, 
    2, 36, 3, 73, 5, 49, 4, 25, 6, 44, 8, 75, 1, 56, 7, 36, 0,  7, 
    7, 80, 3, 46, 6, 28, 2, 73, 0, 94, 1, 83, 5, 67, 4, 78, 8,  5, 
    1, 10, 3, 79, 0, 76, 8, 58, 4, 22, 6, 45, 5, 12, 2,  3, 7, 47, 
    5, 40, 8, 49, 6, 26, 7, 57, 3,  7, 0, 66, 2, 51, 4, 75, 1, 54
  };
  const int q5800[] = {
    9, 9, // Number of jobs and machines
    1, 55, 6, 69, 2, 47, 3, 46, 5, 83, 7, 87, 0, 84, 4, 86, 8,  3, 
    6, 59, 4, 32, 1, 70, 8, 93, 5,  4, 0,  1, 7, 65, 3, 30, 2, 27, 
    3, 67, 1, 66, 7, 66, 4, 71, 5, 73, 2, 12, 6, 62, 0, 95, 8, 19, 
    1, 32, 0, 58, 5, 65, 7, 72, 3, 84, 6,  7, 8, 45, 2, 32, 4, 19, 
    2, 84, 6, 40, 4, 69, 0, 12, 3, 46, 7, 27, 1,  9, 5, 68, 8, 64, 
    1, 82, 4, 85, 3,  1, 6, 49, 2, 39, 7, 36, 5, 96, 0, 17, 8, 69, 
    0, 43, 8, 92, 3, 58, 2, 53, 5, 70, 4, 17, 7, 41, 6,  3, 1, 68, 
    8, 63, 4, 66, 3, 98, 0, 37, 5, 33, 2, 99, 6, 81, 1, 81, 7, 69, 
    2, 49, 1, 74, 4, 13, 5, 58, 6, 17, 3, 39, 0, 34, 7, 54, 8, 75
  };
  const int q5801[] = {
    9, 9, // Number of jobs and machines
    0, 83, 2, 77, 4, 85, 8, 38, 7, 56, 6, 61, 1, 33, 5, 70, 3,  8, 
    7, 69, 6, 57, 4, 34, 0, 32, 5, 68, 3, 60, 2, 27, 1, 94, 8, 54, 
    0, 53, 4, 15, 7, 62, 3, 14, 6, 36, 8, 69, 2, 16, 1, 14, 5,  1, 
    4, 53, 8, 27, 6, 50, 1, 68, 7, 61, 3, 12, 5, 18, 0, 11, 2, 91, 
    0, 48, 8, 45, 4,  9, 6, 99, 7, 22, 5, 29, 2,  3, 3, 77, 1, 28, 
    5, 20, 7, 55, 0, 48, 4, 18, 3, 30, 8, 92, 6, 76, 2, 71, 1, 63, 
    7, 93, 6, 37, 1, 98, 8, 90, 5, 75, 4, 74, 0, 93, 3, 25, 2, 22, 
    5, 26, 2, 21, 3, 35, 8, 45, 7, 19, 0, 43, 4, 89, 6, 81, 1, 79, 
    4, 83, 8, 71, 5,  3, 1, 99, 2,  6, 3, 87, 7,  3, 6,  7, 0, 84
  };
  const int q5802[] = {
    9, 9, // Number of jobs and machines
    7, 56, 3,  6, 6, 13, 0, 22, 4, 15, 5,  5, 2, 36, 8, 40, 1, 35, 
    4,  1, 7, 61, 3, 66, 5, 89, 0,  6, 6, 96, 8, 85, 1, 59, 2, 11, 
    2, 19, 0, 52, 4,  8, 8, 17, 5, 89, 3, 45, 7, 21, 1, 30, 6, 92, 
    2, 90, 4, 17, 1, 10, 0, 54, 5, 73, 3, 94, 6, 63, 8, 84, 7, 44, 
    6,  2, 8,  6, 5,  3, 7, 43, 0, 29, 4, 38, 3, 21, 2, 97, 1, 77, 
    6, 15, 4, 23, 7, 17, 3, 19, 2, 15, 5, 80, 1, 93, 0, 25, 8, 54, 
    1, 87, 7, 36, 4, 34, 3, 63, 0, 17, 8, 79, 5, 37, 2, 60, 6, 28, 
    1, 24, 7, 39, 2, 14, 8,  9, 6, 58, 0, 93, 3, 95, 5, 43, 4, 83, 
    7, 22, 1, 63, 2, 81, 6,  9, 4, 55, 8, 29, 0, 30, 3, 17, 5, 15
  };
  const int q5803[] = {
    9, 9, // Number of jobs and machines
    2,  6, 8,  4, 1, 98, 3, 58, 6, 46, 4, 88, 0, 82, 5, 36, 7, 13, 
    5, 61, 6, 54, 0, 65, 3,  3, 2, 92, 8, 72, 7, 66, 4, 48, 1,  7, 
    1, 10, 5, 38, 6, 94, 4, 73, 8, 72, 3,  6, 2, 15, 7, 15, 0, 83, 
    1, 85, 7,  3, 4, 68, 2,  7, 6, 62, 5, 57, 0, 48, 3, 89, 8, 27, 
    1, 88, 0, 81, 2, 86, 7, 72, 4,  3, 6, 68, 5, 47, 8, 32, 3, 87, 
    6, 34, 7, 30, 5, 72, 4, 93, 3, 61, 0, 41, 1, 66, 8, 41, 2, 91, 
    1, 37, 8, 61, 3, 82, 5, 53, 6, 34, 0, 67, 2, 88, 4, 20, 7, 98, 
    5, 31, 0, 77, 4, 75, 1, 70, 6,  5, 3, 76, 7, 63, 8,  9, 2, 62, 
    7, 87, 4, 53, 1, 87, 3, 23, 2, 20, 6,  7, 8, 23, 0, 59, 5, 47
  };
  const int q5804[] = {
    9, 9, // Number of jobs and machines
    7, 40, 5, 78, 2, 70, 8, 16, 4,  1, 6,  3, 3, 37, 1, 27, 0, 59, 
    4, 84, 7, 81, 2, 66, 0,  7, 6, 68, 5, 64, 1, 69, 8, 99, 3, 53, 
    7, 98, 5, 27, 0,  3, 8, 35, 2, 52, 4, 59, 6, 85, 3, 36, 1,  2, 
    6, 33, 2, 94, 1, 34, 4,  8, 3, 48, 0, 45, 8, 65, 7, 41, 5, 47, 
    3, 68, 6, 52, 4, 90, 0, 45, 2, 50, 1, 17, 8, 96, 7, 99, 5, 71, 
    5, 24, 0, 43, 4, 65, 7, 37, 8, 65, 2, 17, 3,  9, 6, 20, 1, 95, 
    0, 74, 6, 47, 2, 70, 3, 58, 1, 20, 8, 58, 7, 43, 4, 26, 5, 46, 
    2, 22, 6, 54, 0, 74, 5, 49, 7,  9, 8, 15, 3, 49, 1, 21, 4, 85, 
    4,  4, 2, 42, 8, 12, 0, 79, 6, 22, 7, 89, 3, 58, 5, 85, 1, 38
  };
  const int q5805[] = {
    9, 9, // Number of jobs and machines
    8, 13, 4, 93, 2, 35, 5, 97, 7, 40, 1, 88, 3, 52, 6, 39, 0, 76, 
    1, 27, 5, 86, 8, 35, 0, 81, 7, 30, 6,  2, 4, 18, 2, 97, 3, 33, 
    4, 41, 6, 33, 0, 24, 1, 58, 2, 90, 7, 48, 3, 10, 8,  4, 5, 88, 
    8, 19, 2, 14, 6,  3, 7, 10, 5, 22, 1, 90, 0, 94, 3, 67, 4, 91, 
    0, 16, 8, 99, 3, 26, 2, 74, 7, 35, 4, 40, 1, 73, 5,  4, 6, 94, 
    2, 60, 8, 12, 4, 39, 7, 46, 6, 86, 3, 28, 1,  6, 5,  5, 0, 77, 
    1, 54, 4, 71, 2, 71, 6, 75, 3, 47, 0, 79, 7, 14, 8, 25, 5, 93, 
    4, 45, 5, 90, 7, 92, 0,  4, 2, 40, 8, 72, 6, 36, 3, 95, 1, 77, 
    5, 41, 7, 30, 8, 40, 3, 39, 0, 67, 2, 52, 6, 52, 1, 88, 4, 32
  };
  const int q5806[] = {
    9, 9, // Number of jobs and machines
    1,  5, 6, 97, 3, 55, 0, 44, 8, 48, 2, 70, 5, 78, 4, 34, 7, 24, 
    2, 29, 1, 18, 4, 45, 7, 36, 5, 64, 0, 73, 3, 46, 8, 96, 6, 97, 
    7, 12, 0, 48, 3, 71, 5, 43, 4, 94, 8, 98, 2, 80, 1, 81, 6, 31, 
    6,  2, 7, 47, 3, 88, 8, 62, 1, 42, 2, 37, 0, 65, 5, 92, 4, 79, 
    6, 20, 0, 78, 2, 80, 4, 46, 7, 76, 3, 59, 8, 95, 5, 29, 1, 98, 
    2, 97, 6, 52, 4, 26, 8, 12, 0, 36, 1, 24, 3, 61, 5, 89, 7, 86, 
    3, 57, 2, 40, 5, 65, 1,  3, 6,  2, 0, 30, 8, 52, 7,  9, 4, 64, 
    1, 14, 2,  9, 5, 14, 3, 47, 0, 54, 6, 72, 7, 15, 4, 96, 8, 96, 
    4, 12, 8, 19, 6, 82, 7, 76, 0,  1, 1, 30, 3, 56, 5, 45, 2, 78
  };
  const int q5807[] = {
    9, 9, // Number of jobs and machines
    3, 96, 7, 62, 1, 42, 0, 41, 8, 88, 5, 82, 6, 94, 2, 89, 4, 69, 
    0, 17, 5, 89, 6, 41, 8, 34, 4, 69, 3, 63, 1, 57, 7, 57, 2, 51, 
    1, 54, 7, 29, 4, 34, 2,  2, 3, 27, 8, 60, 5, 62, 0, 98, 6, 10, 
    7, 56, 0, 12, 4, 82, 8, 40, 6, 92, 2, 64, 5, 70, 1, 86, 3, 56, 
    2, 66, 1, 34, 7, 68, 0, 14, 5, 78, 6, 58, 3,  8, 4, 82, 8, 96, 
    3, 73, 1, 36, 2, 15, 5, 90, 0, 56, 4, 73, 8, 21, 7,  9, 6, 41, 
    7, 13, 1, 71, 6, 92, 0, 12, 5, 61, 8, 51, 4, 63, 2, 88, 3, 15, 
    1, 22, 6,  2, 7, 36, 2,  1, 0, 58, 8,  7, 3, 45, 5, 34, 4, 28, 
    2,  3, 6, 57, 4,  5, 1, 61, 0, 67, 8, 71, 5, 48, 7, 77, 3, 18
  };
  const int q5808[] = {
    9, 9, // Number of jobs and machines
    7, 91, 3,  6, 5, 15, 6, 56, 4, 58, 0, 61, 2, 46, 8, 12, 1, 12, 
    8, 48, 3, 90, 4,  5, 0, 43, 5, 34, 6, 87, 1, 23, 2, 58, 7, 96, 
    4, 17, 6, 29, 2, 36, 0, 26, 7, 64, 1, 32, 8, 97, 5, 62, 3, 91, 
    4, 14, 8, 29, 7, 15, 2, 32, 3, 50, 5, 91, 1, 15, 0, 27, 6, 15, 
    6, 22, 3, 10, 0, 10, 5, 80, 8, 32, 4, 99, 1, 29, 2, 86, 7, 81, 
    1,  9, 2, 13, 0,  1, 6, 48, 4, 22, 7, 99, 3, 67, 5, 32, 8, 75, 
    1, 85, 8, 21, 7, 17, 0, 83, 6, 84, 4, 48, 5, 27, 3, 66, 2, 12, 
    1, 84, 7, 59, 8, 59, 3, 61, 4, 95, 5,  7, 6, 68, 0, 61, 2, 87, 
    8, 65, 3,  8, 4, 90, 1, 58, 6, 30, 0, 59, 5, 99, 2, 34, 7, 46
  };
  const int q5809[] = {
    9, 9, // Number of jobs and machines
    8, 34, 6, 55, 3, 23, 4, 84, 7, 43, 1, 25, 5, 98, 0, 81, 2, 58, 
    6, 75, 0, 71, 2,  2, 5, 52, 1, 89, 4, 24, 3, 37, 7, 93, 8, 42, 
    2, 14, 5, 92, 4, 79, 8, 69, 0, 97, 3,  1, 6, 92, 1, 21, 7, 20, 
    8, 40, 1, 41, 2, 92, 0, 50, 5, 55, 3, 64, 6, 91, 4, 26, 7, 31, 
    7, 81, 0, 52, 6, 25, 4, 17, 3, 66, 1, 21, 5, 25, 2, 23, 8,  6, 
    8, 53, 4,  9, 0, 13, 7,  1, 6, 96, 5, 84, 2, 72, 3, 68, 1, 54, 
    0, 85, 1, 61, 7, 38, 2, 82, 4, 48, 8, 73, 3, 84, 6, 30, 5, 28, 
    7, 97, 4, 23, 8, 88, 5, 16, 6, 94, 3,  9, 1, 98, 0, 95, 2, 94, 
    2, 51, 1, 79, 7, 10, 5, 51, 4, 20, 0, 59, 8, 68, 3, 55, 6, 65
  };
  const int q5810[] = {
    9, 9, // Number of jobs and machines
    5, 54, 4, 85, 1, 88, 8, 86, 7, 80, 0, 17, 3, 86, 2,  5, 6, 87, 
    5,  6, 4, 51, 1, 74, 2, 60, 7, 72, 8, 16, 0, 10, 6, 94, 3, 48, 
    0, 98, 7, 74, 2, 62, 8, 29, 6, 10, 4, 62, 1, 44, 3, 27, 5, 36, 
    7, 25, 6, 13, 5, 52, 3,  1, 2, 16, 8, 79, 4, 18, 0, 79, 1, 84, 
    8, 84, 1,  3, 4, 84, 7, 21, 6, 57, 3, 49, 5, 20, 2, 10, 0, 72, 
    2,  9, 6, 96, 8, 66, 7, 22, 1, 82, 5, 20, 4, 28, 3, 62, 0, 30, 
    2, 89, 0, 76, 4, 50, 3, 37, 7, 98, 5, 73, 8, 53, 6, 31, 1,  9, 
    1, 60, 5, 87, 4, 53, 7,  5, 6,  9, 8, 95, 3, 65, 2, 23, 0, 73, 
    2, 42, 8, 94, 4, 18, 6, 74, 5, 34, 0, 73, 3,  4, 1, 39, 7, 25
  };
  const int q5811[] = {
    9, 9, // Number of jobs and machines
    3, 56, 0, 89, 1,  7, 6,  8, 4, 23, 7, 44, 8, 34, 5, 99, 2, 20, 
    2, 16, 3, 80, 6, 17, 5, 50, 4, 19, 1, 99, 0,  7, 8, 75, 7, 35, 
    2, 22, 4, 53, 7, 33, 5, 78, 6, 20, 3, 70, 0,  8, 1,  2, 8, 49, 
    7, 39, 1, 76, 2, 79, 6, 96, 3, 53, 8, 33, 5, 41, 0, 40, 4, 88, 
    0, 78, 4,  8, 1, 18, 8, 83, 5, 70, 7, 36, 6, 21, 2, 46, 3, 55, 
    0,  8, 4, 15, 3, 73, 2, 42, 7, 96, 6, 31, 8, 58, 5, 81, 1, 15, 
    1, 73, 2, 60, 6, 54, 0, 17, 5, 74, 4, 80, 7,  3, 8, 46, 3, 18, 
    5, 79, 1, 77, 7, 24, 2,  1, 6, 85, 0, 89, 3, 47, 8,  9, 4, 72, 
    6,  1, 0,  1, 4, 61, 3, 49, 7,  5, 2, 91, 8, 97, 5, 60, 1, 49
  };
  const int q5812[] = {
    9, 9, // Number of jobs and machines
    4, 34, 7,  6, 5, 61, 6, 19, 2, 71, 1, 78, 0, 76, 8, 94, 3, 73, 
    2, 77, 0, 56, 7, 57, 1, 54, 5, 38, 6,  9, 3, 13, 4, 95, 8, 15, 
    4, 41, 6, 39, 0, 31, 2, 69, 7, 63, 5, 29, 3, 16, 1, 69, 8, 48, 
    0,  2, 7, 56, 8, 48, 5, 30, 1, 20, 6, 37, 2, 64, 3, 55, 4, 55, 
    2, 55, 3, 96, 4, 31, 0, 63, 7, 39, 5, 41, 8, 76, 1, 98, 6, 90, 
    3, 13, 2, 11, 1, 77, 4, 63, 5, 99, 6, 85, 7, 96, 0, 23, 8, 81, 
    6, 75, 4, 97, 1,  2, 5, 64, 8, 71, 3, 33, 2, 92, 7, 25, 0, 68, 
    1, 73, 5, 95, 3, 29, 7, 11, 4, 66, 2, 85, 0, 97, 8, 37, 6, 61, 
    6,  4, 4, 10, 0, 67, 2, 24, 3,  5, 7, 62, 5,  6, 8, 77, 1, 93
  };
  const int q5813[] = {
    9, 9, // Number of jobs and machines
    6, 42, 7, 91, 3, 30, 4, 97, 0, 48, 2, 67, 1, 32, 5, 44, 8, 76, 
    3, 79, 0, 91, 1, 16, 6,  2, 5,  5, 4, 77, 7, 68, 8, 77, 2, 95, 
    4, 75, 1,  9, 8, 21, 6, 38, 5,  9, 2, 85, 3, 43, 0, 87, 7,  8, 
    3, 66, 6, 60, 4, 29, 8, 41, 2, 43, 5, 31, 1, 11, 0, 29, 7, 86, 
    0, 26, 3, 39, 2, 48, 8, 32, 6, 94, 1, 38, 5, 83, 7, 46, 4,  8, 
    4, 66, 5,  8, 0,  4, 3,  2, 7, 83, 2, 67, 8, 23, 6, 66, 1, 30, 
    2, 23, 5, 47, 0, 41, 1, 11, 8, 47, 4, 27, 7, 96, 3, 46, 6,  4, 
    0, 78, 2, 43, 1,  8, 7, 90, 8, 22, 6, 94, 3, 35, 5, 36, 4, 13, 
    1,  4, 4, 12, 2, 57, 5, 40, 8, 41, 7, 93, 3, 88, 0, 77, 6, 10
  };
  const int q5814[] = {
    9, 9, // Number of jobs and machines
    7, 78, 2, 86, 8, 96, 4, 98, 6,  8, 5, 33, 1, 14, 3,  1, 0, 64, 
    5, 96, 1, 97, 2, 88, 3, 21, 4, 53, 8, 96, 7, 66, 0, 62, 6, 69, 
    7, 95, 0, 32, 3, 57, 1, 49, 2, 12, 6, 91, 5, 92, 4, 11, 8, 52, 
    7, 90, 0, 82, 8, 84, 5, 88, 1, 38, 6, 55, 3, 90, 2,  7, 4, 70, 
    7, 44, 2,  5, 0, 44, 1, 72, 4, 85, 3, 83, 6, 90, 8, 38, 5, 56, 
    2, 17, 0, 16, 7, 40, 8,  3, 5, 59, 6, 50, 1, 90, 4, 61, 3, 28, 
    3, 59, 6, 69, 4, 80, 0, 78, 2,  4, 1,  6, 5, 75, 7, 44, 8, 85, 
    1, 44, 2, 99, 5, 23, 3, 37, 0, 14, 8, 45, 6, 95, 4, 65, 7,  8, 
    1, 83, 2, 44, 4, 84, 3, 97, 7, 17, 8, 26, 5, 44, 6, 69, 0, 79
  };
  const int q5815[] = {
    9, 9, // Number of jobs and machines
    0, 20, 1, 54, 8, 80, 7, 45, 2, 74, 4, 63, 3, 93, 6, 31, 5,  2, 
    5, 41, 3, 37, 4, 47, 7, 39, 1, 63, 6, 99, 8, 72, 2, 35, 0, 45, 
    4,  5, 2, 40, 8, 88, 6, 16, 5, 67, 0, 53, 3, 61, 1, 61, 7, 19, 
    1, 16, 4, 10, 8, 88, 0, 92, 3, 59, 2, 20, 7, 18, 5, 15, 6, 61, 
    2, 19, 7, 89, 6, 34, 4, 79, 0, 55, 1,  5, 3, 31, 8, 48, 5, 15, 
    7, 13, 6, 52, 8, 61, 3, 79, 5, 31, 1, 21, 4, 38, 2, 49, 0, 95, 
    2, 60, 0,  9, 6, 73, 3,  7, 1, 10, 8, 73, 5, 60, 4,  1, 7,  8, 
    7, 20, 4, 86, 0,  5, 2, 80, 8, 95, 3, 50, 5, 78, 6,  9, 1,  7, 
    8, 41, 0, 17, 6, 42, 1, 94, 2, 11, 7, 18, 4,  3, 3, 62, 5, 12
  };
  const int q5816[] = {
    9, 9, // Number of jobs and machines
    7, 70, 0, 20, 5, 79, 2, 39, 4, 76, 6, 52, 3, 39, 8, 28, 1, 18, 
    4, 12, 2,  8, 1, 88, 3, 34, 7, 26, 0, 81, 6, 77, 5, 76, 8, 17, 
    1,  6, 7, 58, 6, 92, 5, 23, 4, 89, 2, 74, 0, 13, 8, 73, 3, 14, 
    5, 47, 3, 68, 2,  9, 8, 36, 6, 26, 4, 34, 7, 14, 0, 98, 1, 25, 
    4, 83, 5, 77, 2, 26, 1, 77, 0, 25, 6, 70, 7, 48, 8, 78, 3, 52, 
    0, 79, 7, 80, 4, 64, 1, 39, 3, 81, 6, 66, 8, 27, 5,  6, 2,  4, 
    6, 95, 8, 92, 3, 31, 2, 64, 0, 42, 5,  7, 7, 29, 4, 42, 1, 64, 
    3, 88, 8,  2, 5, 92, 6, 91, 4, 81, 1, 71, 7,  8, 2, 18, 0, 26, 
    2, 15, 5, 35, 0, 11, 8, 45, 1, 34, 4, 50, 3, 83, 7, 46, 6, 68
  };
  const int q5817[] = {
    9, 9, // Number of jobs and machines
    0, 81, 4, 76, 5, 43, 7, 72, 8, 46, 1, 53, 3, 62, 2, 22, 6, 52, 
    2, 17, 8, 75, 3, 22, 0, 85, 4, 99, 6, 73, 5, 20, 1, 71, 7, 94, 
    4, 41, 2, 80, 0, 93, 8, 39, 3, 48, 7, 91, 1, 74, 5, 24, 6, 89, 
    0,  7, 8, 64, 4, 31, 5, 28, 2,  7, 3,  7, 6, 51, 1, 92, 7, 39, 
    2, 77, 8, 51, 3, 44, 7,  1, 0, 86, 6, 47, 1, 31, 5, 47, 4, 29, 
    0, 92, 1, 28, 3, 91, 8, 42, 4, 90, 5, 59, 2, 67, 6, 78, 7, 50, 
    8,  4, 7, 62, 1, 90, 5, 73, 2, 79, 6, 34, 0, 24, 3, 22, 4, 42, 
    1, 27, 0, 48, 3, 70, 2, 33, 7, 64, 4, 49, 6, 49, 8, 59, 5, 26, 
    2, 21, 1, 63, 8, 64, 3, 64, 5, 34, 4, 36, 0, 95, 6, 50, 7, 30
  };
  const int q5818[] = {
    9, 9, // Number of jobs and machines
    2, 74, 4, 13, 1,  4, 6, 93, 7, 79, 0, 12, 8, 35, 3,  2, 5, 68, 
    8, 90, 5, 99, 4, 38, 0, 32, 1, 61, 6, 33, 3, 13, 2, 99, 7, 99, 
    8, 95, 0, 33, 5, 76, 3, 91, 2, 92, 6, 99, 4, 37, 7, 31, 1, 66, 
    3, 47, 8, 63, 1, 60, 2, 92, 0, 23, 7, 41, 6, 72, 5, 61, 4, 68, 
    5, 93, 4, 36, 3, 45, 0, 27, 6, 11, 7, 48, 1, 92, 8, 37, 2, 10, 
    2, 57, 8, 87, 7, 52, 3, 61, 6, 71, 5, 75, 1, 87, 0, 40, 4, 63, 
    4, 86, 8, 96, 5, 69, 3, 29, 0, 98, 6, 31, 1, 85, 2, 17, 7, 69, 
    8, 69, 4, 33, 0, 47, 3, 74, 5, 27, 2, 22, 7, 31, 6, 24, 1, 58, 
    5, 26, 6, 80, 2, 73, 8, 20, 1, 67, 7, 95, 3,  6, 4, 65, 0, 75
  };
  const int q5819[] = {
    9, 9, // Number of jobs and machines
    2, 54, 8,  8, 3,  8, 7, 72, 1, 93, 6, 33, 4,  8, 5, 95, 0, 17, 
    1, 71, 6, 91, 7, 76, 4,  3, 8, 20, 0, 20, 2, 93, 5, 77, 3, 37, 
    0, 57, 7, 21, 1, 95, 4, 27, 8, 27, 5, 17, 3, 62, 6, 76, 2, 89, 
    1, 16, 8, 15, 2, 17, 0, 30, 4, 61, 7, 83, 3, 34, 5, 20, 6, 98, 
    0, 29, 4, 36, 1, 89, 7, 36, 8, 83, 2, 75, 5,  9, 3, 65, 6, 65, 
    2, 42, 4, 41, 1, 53, 3, 41, 7, 24, 8, 10, 0, 69, 6,  7, 5, 31, 
    6, 37, 0, 49, 1,  5, 4, 47, 3, 74, 7, 65, 8, 82, 5, 11, 2, 30, 
    4, 46, 6, 32, 0, 19, 2, 63, 3, 75, 7, 68, 1, 78, 5, 31, 8, 22, 
    3, 86, 0, 56, 7,  3, 6, 99, 2, 52, 8, 60, 5,  3, 4, 22, 1, 26
  };
  const int q5820[] = {
    9, 9, // Number of jobs and machines
    4, 10, 2, 39, 0,  2, 7, 49, 8, 91, 1, 94, 5, 56, 3, 30, 6, 29, 
    1, 10, 4, 70, 0, 45, 5, 66, 2, 57, 6, 58, 7, 83, 8, 78, 3, 98, 
    2, 95, 7, 34, 0, 66, 5, 28, 1, 86, 3, 78, 4, 65, 6, 30, 8, 24, 
    0, 39, 4, 94, 8, 67, 3, 48, 6, 51, 2, 26, 1, 22, 5, 74, 7, 88, 
    6, 72, 8, 92, 2, 39, 7, 61, 5, 32, 4, 38, 0, 27, 1,  3, 3, 57, 
    4, 16, 8, 37, 0, 26, 5, 15, 6, 96, 1, 56, 2,  6, 3, 70, 7, 73, 
    7, 38, 4, 47, 2, 58, 6, 79, 5, 16, 0, 47, 3, 23, 1, 56, 8, 65, 
    0, 22, 3, 40, 7, 94, 1, 25, 2, 99, 8, 38, 4, 37, 5, 74, 6, 98, 
    3, 49, 0, 23, 8, 83, 4, 88, 7, 77, 6,  1, 5, 56, 2, 99, 1, 21
  };
  const int q5821[] = {
    9, 9, // Number of jobs and machines
    7, 76, 2, 57, 1, 20, 4, 14, 8, 24, 3, 29, 6, 63, 5, 33, 0, 35, 
    5, 26, 6, 76, 4, 82, 3,  7, 0, 73, 8, 94, 1, 92, 7, 47, 2, 68, 
    7, 71, 5, 34, 8,  9, 6, 75, 1, 42, 4, 57, 0, 34, 3, 78, 2, 49, 
    6, 59, 3, 77, 7, 40, 1, 56, 2, 18, 5, 70, 8, 63, 4, 64, 0, 53, 
    2, 28, 3, 50, 7, 79, 1, 84, 6, 44, 4, 83, 0,  2, 8, 46, 5, 49, 
    8, 26, 3, 76, 4, 93, 6,  1, 5, 25, 0, 84, 7, 33, 2,  3, 1, 29, 
    8, 97, 0, 35, 2, 13, 6, 26, 5, 30, 4, 81, 3, 78, 1, 46, 7,  4, 
    6, 24, 1, 98, 3, 59, 5, 32, 7, 21, 2, 98, 4, 30, 0,  1, 8, 43, 
    6, 92, 2,  8, 8, 48, 4, 87, 3, 12, 0, 74, 1, 68, 7, 39, 5, 23
  };
  const int q5822[] = {
    9, 9, // Number of jobs and machines
    3, 84, 6, 89, 7, 98, 5,  1, 2, 54, 8, 81, 1, 97, 0, 40, 4, 96, 
    5, 24, 3,  8, 1, 48, 2, 66, 6, 16, 7, 35, 0, 18, 4, 63, 8, 89, 
    4, 44, 6, 46, 2, 90, 7, 98, 5, 88, 8, 85, 1, 18, 3, 42, 0, 95, 
    2, 43, 0, 66, 7, 36, 5, 77, 3, 84, 1, 87, 4, 39, 6, 51, 8, 97, 
    2, 88, 0, 67, 7, 61, 8, 53, 3, 64, 6, 21, 4, 17, 5, 96, 1, 93, 
    6,  6, 2, 56, 0, 43, 3, 20, 7, 57, 5, 56, 1, 35, 8, 69, 4, 87, 
    1, 12, 2,  3, 6,  9, 3, 65, 0, 39, 7, 72, 5,  3, 8, 94, 4, 84, 
    2, 32, 7, 67, 5, 50, 1, 45, 8, 33, 0, 39, 6, 53, 3, 21, 4, 60, 
    5, 49, 4, 90, 7, 34, 3,  3, 6, 20, 2, 16, 8,  4, 1,  7, 0, 30
  };
  const int q5823[] = {
    9, 9, // Number of jobs and machines
    5, 12, 7, 80, 1, 50, 8, 82, 4, 15, 6, 14, 2, 76, 3, 21, 0, 12, 
    1, 89, 3, 64, 7, 20, 0, 92, 4, 14, 5, 53, 8, 71, 2, 20, 6, 88, 
    1, 89, 0, 30, 3, 73, 4, 66, 5, 65, 6,  7, 2, 86, 7, 23, 8,  6, 
    8, 13, 3,  6, 0, 66, 7, 20, 6, 52, 1, 31, 2, 49, 5, 33, 4, 93, 
    4, 73, 3, 11, 1, 83, 7,  9, 0, 88, 6, 38, 8, 17, 5, 66, 2,  9, 
    0, 70, 2, 95, 6, 92, 4, 83, 5, 63, 7, 10, 1, 15, 8, 37, 3, 30, 
    0, 10, 5, 69, 2, 27, 8, 78, 4, 90, 3, 73, 7, 76, 1, 98, 6, 28, 
    6, 60, 1, 19, 7, 60, 4, 97, 0, 18, 5, 41, 2, 80, 3, 93, 8, 38, 
    2, 18, 6,  6, 8, 46, 1, 22, 7, 41, 0, 38, 5, 40, 3, 91, 4, 49
  };
  const int q5824[] = {
    9, 9, // Number of jobs and machines
    5, 94, 4, 21, 2, 59, 1, 44, 0, 35, 8, 52, 3, 72, 6, 57, 7, 43, 
    8, 93, 3, 91, 0, 33, 5, 63, 1, 96, 2, 17, 4, 92, 7, 56, 6, 82, 
    3, 98, 5, 84, 0, 17, 4, 36, 1, 97, 8, 22, 7, 44, 6,  9, 2, 46, 
    1, 10, 4, 91, 6, 11, 8, 11, 3, 37, 5, 36, 2, 54, 0, 34, 7, 80, 
    0, 43, 7, 62, 2, 62, 6, 49, 1, 26, 4, 17, 5, 20, 3, 62, 8, 10, 
    0,  1, 5, 57, 8, 40, 3, 37, 7,  4, 2, 66, 4, 32, 1, 46, 6, 56, 
    4, 49, 6,  7, 8, 62, 2, 28, 3, 22, 1, 41, 7, 84, 0, 50, 5, 73, 
    4, 10, 8,  6, 5, 30, 2, 97, 3, 77, 7, 80, 1, 19, 6, 85, 0, 66, 
    2, 49, 3, 76, 1, 12, 5, 61, 7, 40, 6, 70, 0, 40, 8, 19, 4, 28
  };
  const int q5825[] = {
    9, 9, // Number of jobs and machines
    7, 17, 2, 99, 3, 23, 1, 92, 5, 59, 6, 71, 8, 44, 0, 78, 4, 39, 
    4, 77, 2, 92, 5, 13, 8, 75, 1, 97, 6, 59, 7, 61, 0, 90, 3, 85, 
    8, 84, 6, 35, 7, 70, 1, 39, 3, 53, 4,  2, 0, 23, 2, 31, 5, 43, 
    0, 22, 4, 73, 6, 51, 5, 61, 2, 16, 7, 16, 3, 48, 8, 45, 1,  5, 
    4, 50, 2, 64, 7, 24, 5, 36, 1, 96, 6, 78, 8, 44, 3, 88, 0, 10, 
    4, 13, 1, 71, 0, 49, 2, 82, 8, 67, 3, 96, 7, 14, 6, 84, 5, 54, 
    6, 11, 4, 35, 3, 96, 0, 65, 5, 60, 7, 90, 2, 99, 8, 60, 1, 98, 
    4, 96, 3, 74, 0, 40, 5, 53, 1, 60, 2, 78, 7, 52, 8, 23, 6,  5, 
    3, 57, 5,  3, 7, 89, 8, 55, 0, 90, 1, 76, 6, 36, 4, 54, 2, 40
  };
  const int q5826[] = {
    9, 9, // Number of jobs and machines
    3, 24, 7, 50, 5, 82, 1, 72, 8,  6, 4, 75, 2,  9, 6, 93, 0, 70, 
    7, 40, 4, 56, 2, 44, 6, 96, 8, 47, 0, 94, 5, 32, 3, 28, 1, 50, 
    2,  1, 5,  4, 8, 66, 4, 89, 3, 90, 0, 15, 1, 83, 7, 69, 6, 87, 
    2, 63, 4, 54, 8, 86, 7, 33, 0, 46, 3,  1, 1, 81, 5, 64, 6, 37, 
    7, 82, 5, 42, 3, 55, 8,  1, 1, 27, 6, 80, 2, 15, 0, 22, 4, 70, 
    8,  8, 7, 35, 1, 84, 0, 89, 6,  8, 4, 54, 3, 26, 5, 74, 2, 80, 
    5, 80, 1, 13, 8, 40, 2, 47, 4, 63, 7, 72, 3, 65, 6, 16, 0, 71, 
    4, 35, 6, 73, 3, 34, 1, 85, 2, 90, 8, 64, 5, 32, 7, 77, 0,  1, 
    1, 46, 6, 71, 4, 71, 3, 73, 8,  6, 7, 31, 0, 65, 2, 88, 5,  7
  };
  const int q5827[] = {
    9, 9, // Number of jobs and machines
    2, 77, 7, 72, 1, 51, 3, 26, 8, 79, 4, 87, 5, 88, 6, 76, 0, 65, 
    3,  4, 4, 93, 8, 40, 7, 87, 5, 30, 6, 29, 0, 71, 2, 10, 1,  6, 
    0, 89, 2, 88, 7, 90, 4, 98, 5, 14, 8, 22, 3, 59, 1, 57, 6, 67, 
    4, 51, 1, 42, 0, 95, 5, 35, 8,  9, 3, 40, 7, 21, 6, 51, 2, 85, 
    6, 63, 7, 41, 4, 26, 5, 58, 1, 43, 3,  9, 0, 76, 8,  3, 2, 44, 
    0, 27, 2, 22, 4, 61, 5, 86, 1, 94, 3, 86, 6, 85, 7, 67, 8,  9, 
    3, 55, 4, 86, 7, 63, 0, 99, 6, 71, 1, 17, 2, 28, 8, 74, 5, 63, 
    2, 37, 0, 37, 1, 78, 8,  9, 3, 21, 6, 15, 7, 76, 4, 48, 5, 82, 
    8, 89, 6, 43, 2, 32, 7, 57, 3, 11, 5, 92, 4, 65, 0, 91, 1, 43
  };
  const int q5828[] = {
    9, 9, // Number of jobs and machines
    1, 43, 3, 94, 6,  6, 7, 89, 4, 96, 2, 38, 0, 88, 5, 50, 8, 35, 
    8, 87, 7, 85, 2, 51, 3, 55, 6, 66, 4, 83, 1, 72, 5, 66, 0, 55, 
    6, 85, 7, 99, 1, 11, 0, 96, 3,  9, 4,  9, 8, 40, 2, 85, 5, 72, 
    4, 35, 7, 68, 3, 21, 6, 46, 1, 44, 8, 75, 0, 97, 2, 16, 5, 46, 
    6, 81, 2, 69, 8, 14, 0,  6, 3, 27, 5, 54, 7,  7, 4, 35, 1, 44, 
    1, 25, 6, 71, 5, 38, 4, 25, 0, 24, 8, 96, 3, 92, 7, 95, 2, 47, 
    4, 88, 5, 87, 8, 95, 2, 84, 0, 69, 3, 44, 7,  6, 1,  4, 6, 25, 
    5, 27, 8, 19, 2, 27, 3, 28, 4, 28, 1, 85, 6, 39, 0, 45, 7, 72, 
    5, 41, 2, 93, 7, 76, 0, 77, 3, 95, 6, 29, 1, 16, 4,  6, 8, 98
  };
  const int q5829[] = {
    9, 9, // Number of jobs and machines
    2, 66, 8, 28, 1, 35, 7, 38, 4, 79, 0,  8, 5,  6, 6, 50, 3, 34, 
    8, 73, 5, 60, 2, 23, 4, 11, 1, 62, 3, 59, 6, 77, 0, 75, 7, 58, 
    1, 12, 5, 21, 2, 96, 8, 43, 3,  4, 7, 39, 4,  2, 0, 68, 6, 89, 
    0, 42, 6, 68, 1, 47, 4, 32, 2, 77, 3, 24, 7, 17, 8, 59, 5, 94, 
    1, 85, 5, 19, 7, 37, 4, 75, 8, 98, 2, 59, 0, 29, 3, 90, 6, 67, 
    4, 46, 8, 24, 3,  1, 1, 70, 6, 75, 0, 79, 7, 85, 2, 95, 5, 43, 
    2, 98, 5, 62, 6, 38, 3, 82, 8, 62, 7, 95, 4, 54, 1, 81, 0, 27, 
    1, 80, 4, 10, 3, 51, 7, 55, 6, 85, 2, 21, 8, 42, 0, 75, 5, 60, 
    4, 10, 1, 60, 0, 55, 8, 83, 7, 16, 2, 30, 3, 70, 6, 23, 5, 31
  };
  const int q5830[] = {
    9, 9, // Number of jobs and machines
    7, 78, 5, 17, 3, 88, 2, 82, 0, 23, 1, 28, 8, 33, 6, 46, 4,  9, 
    4, 84, 8, 21, 3, 54, 1, 98, 7, 73, 2, 14, 0, 15, 6, 92, 5, 53, 
    3, 71, 4, 92, 8, 10, 7, 12, 2, 44, 0, 19, 5, 53, 1, 96, 6, 39, 
    3, 96, 2, 34, 0, 46, 1, 84, 7, 60, 4, 24, 5, 11, 8, 44, 6, 40, 
    5, 26, 8, 59, 1, 12, 0, 82, 3,  7, 4, 77, 2, 33, 6, 24, 7, 65, 
    5, 46, 3, 59, 8, 97, 4, 34, 0, 27, 2, 90, 1, 21, 7, 52, 6, 68, 
    0, 55, 3, 48, 2, 53, 1, 72, 6, 58, 5, 41, 8, 45, 4, 74, 7,  9, 
    0, 17, 6,  2, 2, 23, 5, 84, 1, 89, 7, 70, 3, 38, 4, 77, 8, 39, 
    3, 62, 7, 25, 0, 44, 6, 85, 4, 11, 1, 43, 8, 27, 5, 26, 2, 49
  };
  const int q5831[] = {
    9, 9, // Number of jobs and machines
    2, 89, 7, 79, 4, 95, 3, 73, 8, 63, 6, 12, 0, 32, 5, 87, 1, 31, 
    5,  2, 0, 66, 7, 65, 4, 55, 8, 39, 3, 87, 1, 56, 2, 26, 6, 57, 
    0, 89, 5, 13, 7, 50, 3, 88, 4, 46, 6, 34, 2, 45, 8, 22, 1, 96, 
    6, 12, 5, 78, 1, 19, 0, 65, 4, 35, 3, 24, 2, 77, 7,  9, 8, 25, 
    2, 83, 4, 26, 5, 19, 6, 27, 0, 21, 8, 65, 7, 13, 3, 49, 1, 28, 
    8, 74, 6, 61, 3, 94, 5, 40, 1, 53, 2, 15, 4, 11, 0,  6, 7, 17, 
    5, 92, 4,  3, 8, 90, 1, 69, 7, 43, 2, 48, 3, 32, 6, 23, 0, 33, 
    3, 32, 6,  4, 2, 75, 4, 81, 5, 64, 8, 27, 1, 26, 0, 57, 7, 78, 
    7, 18, 0, 74, 4, 79, 2, 71, 6, 70, 5, 89, 8, 69, 3, 46, 1, 36
  };
  const int q5832[] = {
    9, 9, // Number of jobs and machines
    4, 65, 0, 74, 3, 93, 7, 26, 5, 12, 6, 26, 1, 40, 2, 69, 8, 53, 
    6, 91, 1, 53, 7,  9, 2,  5, 8, 91, 3, 26, 4, 35, 5, 73, 0, 58, 
    0, 47, 5, 58, 7, 37, 4, 77, 6, 64, 8, 22, 2, 36, 3,  1, 1, 86, 
    3, 79, 5, 47, 8, 15, 7,  6, 4, 87, 0, 50, 1, 64, 6, 78, 2, 64, 
    5, 36, 3, 48, 8, 49, 4, 44, 0, 56, 2,  9, 7, 14, 1, 46, 6, 19, 
    6, 81, 5, 37, 0, 90, 8, 88, 1, 95, 2, 23, 4,  9, 3, 49, 7, 54, 
    4, 16, 0, 95, 1, 86, 7, 35, 2, 38, 6, 14, 5, 92, 8, 60, 3, 37, 
    1, 58, 5,  1, 4, 75, 0, 11, 3, 99, 7,  3, 2, 34, 6,  8, 8, 83, 
    7, 80, 1, 26, 0, 45, 5, 60, 2, 37, 3, 42, 4, 54, 6, 43, 8,  7
  };
  const int q5833[] = {
    9, 9, // Number of jobs and machines
    5, 95, 4, 22, 6, 94, 2, 23, 7, 53, 1, 44, 8, 97, 0, 23, 3, 86, 
    7, 89, 8, 89, 4, 47, 6, 38, 5, 86, 0, 96, 1, 74, 3, 95, 2, 31, 
    4, 85, 8, 95, 1, 88, 5, 76, 6, 72, 2, 97, 3, 38, 7,  9, 0, 34, 
    3, 57, 0, 19, 6, 47, 1, 71, 7, 81, 4,  1, 8, 36, 2, 66, 5,  9, 
    8, 54, 6, 89, 3, 66, 7,  9, 1, 55, 0, 25, 5, 13, 4, 64, 2, 33, 
    3, 28, 8, 53, 4, 81, 6,  2, 0, 74, 2, 93, 7, 77, 1, 76, 5, 38, 
    2, 74, 5, 10, 1, 25, 8, 43, 0,  5, 4, 74, 7, 66, 3, 73, 6, 65, 
    0, 83, 7, 79, 4, 42, 2, 88, 8, 82, 1, 73, 5, 64, 3, 18, 6, 61, 
    5,  7, 8, 81, 1, 56, 2, 97, 0, 82, 6, 27, 7, 33, 3, 71, 4, 48
  };
  const int q5834[] = {
    9, 9, // Number of jobs and machines
    2, 58, 1, 32, 4, 11, 7, 26, 5, 18, 3,  6, 6, 69, 8, 12, 0, 70, 
    2, 68, 7, 17, 1, 75, 3, 72, 0, 18, 6, 95, 8, 66, 4, 80, 5, 88, 
    7, 83, 5, 62, 8,  7, 4, 76, 0, 36, 1, 72, 2, 17, 3, 43, 6, 66, 
    3, 62, 6, 61, 0, 33, 8, 95, 5, 54, 4, 78, 1, 97, 2, 43, 7, 32, 
    1, 70, 4, 42, 6, 31, 8, 29, 3, 66, 2, 65, 5, 41, 7, 54, 0, 98, 
    1,  9, 3, 46, 0, 99, 8, 91, 7, 22, 4, 15, 6, 96, 2, 37, 5,  6, 
    7, 85, 4, 21, 0, 93, 8, 90, 5, 69, 6, 75, 3, 58, 1, 82, 2,  5, 
    0, 31, 8, 66, 6, 25, 5, 10, 3, 36, 7, 42, 4, 32, 2, 51, 1, 15, 
    4, 60, 1, 31, 0, 55, 7, 62, 2, 31, 6, 61, 3, 77, 8, 34, 5, 74
  };
  const int q5835[] = {
    9, 9, // Number of jobs and machines
    8,  4, 7, 89, 0, 27, 3, 76, 2,  3, 6,  4, 5,  8, 1, 13, 4, 47, 
    0, 19, 6, 62, 7, 37, 5, 50, 8, 47, 2, 79, 1, 68, 3, 90, 4, 52, 
    8, 32, 0, 42, 1, 97, 2, 57, 3, 84, 7,  9, 4, 61, 5, 21, 6, 85, 
    6, 74, 7, 46, 0, 31, 2, 50, 1, 99, 3, 98, 5, 86, 8, 25, 4, 82, 
    7,  2, 4, 18, 0, 11, 8, 26, 5, 57, 2,  5, 3, 83, 1, 96, 6, 70, 
    0, 61, 1, 74, 4, 65, 3, 29, 2, 92, 7, 22, 5, 88, 6, 88, 8, 89, 
    0,  2, 1, 48, 6, 47, 5, 67, 4, 29, 3, 46, 8, 51, 2, 52, 7, 11, 
    8, 41, 5, 90, 6, 51, 4, 22, 7, 82, 2, 19, 1, 63, 0, 38, 3, 54, 
    7, 41, 5, 26, 3, 61, 1, 38, 0,  4, 6, 60, 8, 99, 4,  4, 2, 95
  };
  const int q5836[] = {
    9, 9, // Number of jobs and machines
    3, 50, 8, 59, 5, 23, 0, 11, 7, 28, 6, 63, 4, 24, 1, 15, 2, 20, 
    1,  1, 6, 45, 5, 29, 0, 15, 4, 31, 3, 87, 7, 55, 2, 73, 8, 69, 
    2,  4, 5, 97, 0, 17, 4, 21, 7, 99, 6, 82, 1, 95, 3, 47, 8, 98, 
    0, 71, 5, 87, 3, 89, 4, 61, 7, 98, 2, 14, 1, 71, 6, 54, 8, 99, 
    7, 54, 3, 34, 2, 14, 8, 22, 1, 55, 0, 55, 4, 40, 5, 47, 6, 50, 
    1, 14, 7, 61, 4, 15, 0, 43, 8, 43, 3, 77, 5, 90, 6, 10, 2, 96, 
    0, 74, 6, 73, 4, 98, 2, 51, 1, 29, 8, 35, 5, 17, 7, 40, 3, 21, 
    1, 39, 8, 56, 2, 50, 0, 34, 3, 78, 4, 71, 5, 14, 7, 65, 6, 13, 
    8, 34, 1, 41, 2, 42, 5, 24, 3,  8, 0, 71, 4,  6, 6, 12, 7, 46
  };
  const int q5837[] = {
    9, 9, // Number of jobs and machines
    0, 62, 1, 20, 3, 77, 2, 66, 6, 85, 8, 51, 5, 59, 4, 11, 7, 53, 
    3, 26, 7, 33, 4, 92, 5, 34, 0, 66, 1, 64, 6, 55, 8, 99, 2, 65, 
    1,  1, 4, 54, 3,  3, 5, 88, 7, 80, 6, 14, 8, 76, 0, 15, 2, 45, 
    1, 68, 2, 18, 7, 51, 3, 18, 4, 21, 8, 54, 5, 98, 0, 17, 6,  5, 
    5, 64, 0, 75, 3, 44, 7,  7, 6, 49, 1, 20, 4, 69, 2, 68, 8, 75, 
    7, 30, 4, 79, 6, 69, 8, 29, 1,  4, 0, 38, 3, 17, 5, 87, 2, 77, 
    4, 53, 7, 15, 6, 58, 8, 74, 3, 88, 2, 26, 5, 21, 1, 35, 0, 23, 
    1, 81, 3,  5, 0, 83, 2, 77, 5, 44, 7, 46, 8, 33, 4, 32, 6, 40, 
    7, 12, 1, 93, 3, 60, 0, 35, 6, 21, 2, 72, 5, 22, 4, 37, 8,  1
  };
  const int q5838[] = {
    9, 9, // Number of jobs and machines
    8, 49, 6, 19, 1, 45, 0, 10, 3, 69, 4, 75, 2, 88, 5, 77, 7,  7, 
    4, 84, 8, 55, 6, 69, 1, 73, 0, 82, 5, 64, 2, 52, 3, 39, 7, 12, 
    8, 35, 4, 12, 6, 94, 0, 63, 5, 97, 2, 23, 3, 85, 1, 21, 7, 15, 
    6, 19, 3, 80, 1, 39, 0, 73, 7,  5, 2, 14, 8,  5, 4, 73, 5, 75, 
    6, 27, 3, 62, 2, 89, 0, 27, 8, 55, 7, 33, 5, 51, 1, 49, 4, 70, 
    0, 92, 5, 11, 1, 36, 7, 74, 2, 11, 4, 64, 8, 68, 3, 26, 6, 59, 
    4, 47, 5, 45, 6, 45, 7, 19, 8, 92, 1, 48, 0, 96, 3, 84, 2, 53, 
    8, 96, 3, 89, 7, 56, 2, 27, 1, 14, 6, 53, 4, 26, 0, 65, 5, 20, 
    8, 38, 6, 83, 1, 55, 4,  6, 2, 21, 0, 11, 5, 82, 7, 12, 3,  6
  };
  const int q5839[] = {
    9, 9, // Number of jobs and machines
    5, 53, 2, 73, 7, 45, 4, 87, 8, 27, 0,  3, 6, 21, 3, 62, 1, 40, 
    1,  6, 2, 70, 3, 57, 0, 26, 8, 96, 6, 58, 4, 15, 7, 97, 5, 94, 
    7, 87, 1, 43, 5, 39, 4, 15, 3, 35, 8, 81, 2, 38, 0, 15, 6, 66, 
    4, 30, 2, 95, 5, 83, 7, 94, 0, 65, 3, 90, 1,  6, 6, 51, 8, 55, 
    4,  5, 3, 67, 1, 46, 0, 94, 5, 78, 8, 53, 6, 22, 7, 39, 2, 74, 
    5, 49, 6, 41, 2, 33, 0, 68, 1, 25, 8, 44, 4, 37, 7, 59, 3, 87, 
    1, 40, 2, 69, 0, 36, 3, 73, 7, 87, 6, 95, 4, 51, 8, 95, 5, 73, 
    6, 44, 3, 59, 5, 15, 1, 82, 0, 39, 4, 10, 7, 58, 2, 58, 8, 13, 
    0, 17, 7, 74, 6,  9, 8, 15, 3,  6, 1, 62, 5, 45, 4, 47, 2, 16
  };
  const int q5840[] = {
    9, 9, // Number of jobs and machines
    5, 55, 7, 44, 6, 51, 8, 30, 4, 54, 3, 88, 1,  5, 0, 24, 2,  3, 
    6, 68, 7, 31, 2, 64, 1, 84, 8,  9, 3, 82, 4, 33, 0, 30, 5,  1, 
    2, 19, 4, 17, 5, 67, 8, 35, 3, 95, 1, 64, 6, 28, 7,  2, 0, 83, 
    5, 77, 1, 97, 3, 98, 8, 95, 6, 37, 7, 47, 0, 92, 2, 65, 4, 16, 
    0, 30, 6,  5, 5, 27, 7, 33, 8, 81, 3, 32, 2, 99, 1, 21, 4, 29, 
    8, 40, 3, 57, 6, 59, 5, 42, 0, 57, 7, 14, 1, 27, 2, 43, 4,  8, 
    1,  9, 7, 72, 4, 18, 5,  9, 8, 25, 2, 11, 0, 13, 3,  3, 6,  4, 
    3, 16, 4, 57, 0, 75, 8, 24, 5, 21, 1, 62, 2, 66, 7, 69, 6, 42, 
    6, 92, 3, 68, 2, 86, 4, 58, 5,  7, 1, 22, 0, 47, 7,  6, 8, 76
  };
  const int q5841[] = {
    9, 9, // Number of jobs and machines
    2, 49, 5, 11, 0, 94, 6, 67, 3, 87, 8, 33, 4, 41, 1, 65, 7, 38, 
    6, 75, 2, 68, 1, 45, 7, 40, 3, 72, 8,  6, 0, 64, 4, 22, 5, 38, 
    6, 53, 3, 42, 4, 78, 7, 94, 8, 24, 2, 60, 5, 52, 1, 43, 0,  2, 
    2, 18, 6, 42, 0,  5, 3, 99, 1, 92, 5, 29, 4, 50, 7, 89, 8, 88, 
    3, 70, 0, 89, 7, 77, 5, 88, 8, 72, 2, 52, 4, 62, 1, 94, 6, 30, 
    6, 24, 4, 89, 0, 37, 8, 39, 7,  6, 3, 18, 1, 82, 2, 27, 5, 47, 
    8, 87, 4, 30, 7, 24, 3, 76, 6,  4, 0, 50, 2, 84, 5, 60, 1, 90, 
    4, 31, 8, 80, 0, 76, 7, 41, 2,  4, 6, 88, 5, 86, 3, 97, 1, 64, 
    4, 16, 7,  7, 0, 79, 6, 72, 5, 52, 2, 16, 1, 43, 8, 98, 3,  3
  };
  const int q5842[] = {
    9, 9, // Number of jobs and machines
    1, 24, 6, 39, 4, 45, 7, 43, 3, 60, 5, 69, 0, 87, 2, 29, 8, 78, 
    8, 39, 1, 95, 5, 43, 3, 20, 7, 63, 4, 31, 6, 66, 0, 13, 2, 71, 
    1, 77, 5, 86, 0, 25, 3, 30, 8, 16, 4, 77, 7, 78, 2, 35, 6, 29, 
    8, 95, 2, 89, 7, 99, 3, 91, 1, 61, 4,  7, 5, 21, 6, 42, 0, 97, 
    3, 33, 1, 65, 6, 46, 8, 36, 5, 32, 4, 94, 0, 79, 7, 26, 2, 26, 
    3, 82, 4, 13, 8, 36, 7, 24, 2, 47, 1,  5, 5, 45, 0, 57, 6,  1, 
    6, 15, 4, 87, 0, 25, 8, 59, 3,  3, 2, 77, 1, 41, 5, 76, 7,  7, 
    6, 40, 8, 69, 3, 96, 4, 76, 0, 62, 2, 23, 7,  8, 5, 64, 1, 44, 
    4, 90, 8, 27, 1, 25, 3, 71, 6,  3, 5, 91, 2,  9, 7, 56, 0, 59
  };
  const int q5843[] = {
    9, 9, // Number of jobs and machines
    0, 48, 8, 74, 3, 93, 7, 30, 1, 90, 4, 21, 2, 33, 5, 16, 6, 35, 
    0, 97, 2, 65, 8, 64, 7, 59, 3, 27, 6,  9, 1, 49, 4, 54, 5, 68, 
    5, 29, 4, 42, 6, 76, 3, 42, 7,  1, 8, 88, 1, 51, 0, 24, 2, 55, 
    0, 41, 1, 53, 6, 90, 7, 12, 3, 10, 5, 90, 8, 65, 2, 91, 4, 41, 
    1, 89, 3, 72, 5, 93, 2, 64, 7, 95, 4, 19, 6,  4, 8, 10, 0, 94, 
    2, 38, 3, 49, 8, 66, 0, 85, 1, 68, 5, 19, 6, 98, 4, 65, 7, 55, 
    8, 96, 6, 15, 5, 24, 0, 56, 7, 48, 3, 45, 1, 59, 2, 25, 4, 81, 
    5, 54, 8, 22, 0, 64, 2,  9, 1, 58, 4, 26, 6, 92, 7, 44, 3, 98, 
    5, 48, 6, 94, 8, 55, 0, 48, 4,  2, 7, 24, 3,  5, 2, 23, 1, 68
  };
  const int q5844[] = {
    9, 9, // Number of jobs and machines
    0, 43, 1, 61, 2, 45, 7,  2, 6, 57, 5, 29, 3, 67, 8, 98, 4, 29, 
    0, 54, 8, 74, 4, 11, 6, 68, 7,  1, 2, 61, 3, 87, 5, 99, 1, 14, 
    2, 74, 0, 35, 5, 93, 4, 43, 8, 96, 7, 91, 3, 45, 1,  4, 6, 94, 
    8, 60, 2, 32, 3, 25, 6, 57, 7, 22, 4, 91, 0, 31, 5,  2, 1, 63, 
    2, 58, 1, 72, 6, 57, 7, 74, 8, 52, 0, 94, 3, 54, 5, 90, 4, 81, 
    1, 73, 4, 66, 8, 18, 0, 69, 6, 36, 2, 32, 3, 21, 7, 72, 5, 83, 
    3, 38, 2, 19, 5, 13, 8, 93, 6,  7, 1, 35, 0, 42, 4, 95, 7, 63, 
    8, 79, 6, 43, 1, 50, 5, 46, 3, 65, 4, 96, 2, 48, 7,  6, 0, 45, 
    7, 66, 4,  2, 6, 19, 1, 68, 8, 23, 3, 75, 0, 78, 5, 66, 2, 79
  };
  const int q5845[] = {
    9, 9, // Number of jobs and machines
    7, 35, 0, 60, 6, 86, 8, 42, 3, 80, 1, 35, 5, 55, 2, 76, 4, 36, 
    6, 67, 2, 22, 8, 64, 7, 78, 3, 58, 1,  9, 5, 93, 4, 59, 0, 82, 
    2, 88, 3, 91, 5, 75, 4, 48, 7, 85, 8, 23, 0, 73, 1, 73, 6, 23, 
    3,  8, 2, 48, 8, 93, 0, 35, 4, 62, 1, 64, 6, 55, 7, 60, 5, 27, 
    7, 24, 8, 24, 4, 20, 1, 12, 5, 99, 0, 72, 3, 53, 2, 79, 6, 64, 
    3, 97, 5, 95, 0, 34, 1, 61, 4, 19, 2, 95, 7, 73, 6, 33, 8, 18, 
    2,  2, 1, 26, 3, 10, 6, 77, 0, 93, 5, 77, 8, 28, 4, 27, 7, 13, 
    1, 32, 5, 59, 0, 88, 8, 87, 3, 30, 4, 33, 7,  2, 2, 31, 6, 88, 
    4, 24, 2, 31, 0, 46, 7, 48, 5, 96, 3, 77, 8,  6, 6,  7, 1, 21
  };
  const int q5846[] = {
    9, 9, // Number of jobs and machines
    1, 18, 2, 44, 4, 86, 6, 72, 5, 85, 7, 83, 3, 42, 0, 28, 8, 24, 
    2, 42, 8,  1, 6, 74, 4, 14, 7, 91, 1, 25, 5, 50, 0, 33, 3, 11, 
    2, 30, 5, 48, 1, 73, 0, 39, 6, 18, 8,  8, 7, 53, 4, 54, 3, 46, 
    3, 59, 6, 62, 5, 55, 2, 36, 0, 49, 4, 50, 8, 19, 7, 85, 1, 94, 
    4, 54, 1, 26, 2, 23, 8, 93, 5, 10, 6,  2, 3, 87, 7, 32, 0, 62, 
    2, 65, 8, 73, 1, 14, 4, 90, 3, 80, 5, 54, 0, 64, 6, 96, 7, 51, 
    0, 22, 7, 81, 5, 23, 6, 47, 8, 85, 2, 69, 3, 68, 4, 70, 1, 64, 
    1, 37, 8, 83, 0, 75, 5, 84, 4, 62, 3, 23, 2, 71, 7, 91, 6, 38, 
    8, 79, 3, 39, 4, 16, 7, 74, 2,  4, 1, 31, 5, 44, 6, 90, 0, 27
  };
  const int q5847[] = {
    9, 9, // Number of jobs and machines
    1, 72, 7, 68, 2, 78, 0, 39, 6, 99, 4, 85, 8,  2, 5,  8, 3, 50, 
    3, 57, 1, 95, 6, 68, 2, 50, 4, 60, 0, 62, 7, 65, 8, 23, 5, 36, 
    6, 53, 0, 78, 8, 75, 1,  6, 4, 93, 2, 53, 7, 53, 3, 26, 5, 35, 
    1,  2, 4, 63, 3, 76, 2, 12, 8, 85, 6, 88, 5, 60, 0, 20, 7, 47, 
    5, 77, 2, 81, 4, 58, 0, 68, 3, 90, 6, 87, 1, 36, 8,  8, 7, 47, 
    0, 79, 4, 36, 7, 86, 2, 48, 3, 33, 6, 77, 8, 98, 1, 66, 5, 21, 
    1, 76, 0, 99, 3, 59, 4, 90, 5, 32, 6,  5, 8, 33, 2, 58, 7,  4, 
    7, 13, 0, 97, 4, 82, 1, 61, 8, 74, 2, 59, 3,  7, 5, 11, 6, 20, 
    3, 84, 5, 34, 7, 13, 8, 90, 2, 81, 1, 86, 0, 71, 4, 65, 6, 78
  };
  const int q5848[] = {
    9, 9, // Number of jobs and machines
    0, 24, 4,  2, 3, 74, 7, 23, 2, 90, 1, 83, 8, 60, 6, 70, 5, 98, 
    3, 41, 1,  4, 6, 11, 5, 50, 0,  5, 4, 20, 2,  1, 7, 10, 8,  5, 
    4, 52, 8, 80, 6, 53, 1, 72, 2, 77, 3, 31, 5, 82, 0, 27, 7, 83, 
    5, 29, 8, 33, 6, 71, 0, 38, 2, 37, 3, 81, 1, 51, 7, 99, 4, 91, 
    0,  6, 3, 21, 7, 75, 8, 17, 1, 94, 4, 43, 5, 96, 6, 47, 2, 32, 
    1, 87, 4, 99, 8, 50, 6,  9, 3, 35, 5, 47, 0, 75, 2, 96, 7, 48, 
    5, 22, 6, 25, 1, 87, 2, 83, 8, 88, 3, 12, 4, 44, 0, 70, 7, 76, 
    0, 99, 1, 60, 5, 85, 2, 38, 4, 75, 6, 80, 3, 81, 7, 65, 8, 41, 
    7,  4, 4, 89, 2, 46, 1, 34, 0, 36, 6, 94, 5, 89, 3, 45, 8, 18
  };
  const int q5849[] = {
    9, 9, // Number of jobs and machines
    2, 94, 4, 83, 3, 87, 1, 82, 0, 68, 7, 18, 5, 58, 6, 92, 8,  9, 
    2, 12, 5, 45, 7, 42, 1, 24, 6, 18, 3, 93, 0, 68, 4, 70, 8, 99, 
    1, 73, 0, 61, 5, 73, 4, 16, 3, 68, 8,  3, 6, 96, 7, 63, 2, 66, 
    4, 49, 8, 22, 7, 93, 2, 72, 0, 36, 5, 72, 1, 50, 3, 77, 6, 39, 
    2, 43, 1, 66, 5, 13, 7, 24, 6, 78, 4, 93, 3, 23, 0, 88, 8, 97, 
    2, 49, 6, 83, 7, 56, 4, 58, 1, 36, 0, 25, 3, 47, 5, 89, 8, 41, 
    3, 71, 5, 95, 1, 27, 2, 23, 8, 13, 6, 39, 0, 67, 4, 12, 7, 61, 
    1, 21, 0, 26, 8, 80, 7, 87, 5,  1, 2, 52, 6, 17, 4, 18, 3, 14, 
    1, 47, 0, 35, 7, 75, 6, 30, 3, 80, 4,  6, 5, 11, 8,  3, 2, 47
  };
  const int q5850[] = {
    9, 9, // Number of jobs and machines
    3, 25, 8, 82, 6, 86, 0, 47, 1, 80, 4, 66, 7, 62, 2, 61, 5, 77, 
    2,  1, 7, 78, 4, 66, 5, 13, 3, 39, 8, 25, 1, 59, 6, 84, 0, 88, 
    0,  5, 5, 57, 6, 96, 3, 53, 4, 29, 8, 83, 7, 32, 2, 51, 1, 92, 
    0, 43, 7, 61, 2, 66, 6, 22, 5, 44, 4, 55, 3,  8, 1, 85, 8, 25, 
    5, 60, 8, 80, 2, 49, 3, 57, 6, 89, 1,  6, 0, 25, 7,  6, 4, 28, 
    0, 35, 2, 60, 7, 45, 6, 41, 5, 89, 8, 16, 1, 72, 3, 94, 4, 99, 
    6,  7, 0, 55, 4, 43, 7, 98, 2, 46, 5, 22, 3, 16, 8, 94, 1, 23, 
    8, 35, 6, 31, 5, 92, 0, 92, 2, 22, 3, 55, 7, 93, 4, 13, 1, 81, 
    6, 55, 4, 37, 0, 81, 8, 17, 2, 12, 5, 68, 7, 47, 3, 76, 1, 79
  };
  const int q5851[] = {
    9, 9, // Number of jobs and machines
    0, 55, 6, 70, 3, 54, 4, 59, 8, 41, 1, 65, 5, 15, 2, 36, 7, 46, 
    3, 63, 5, 17, 4, 84, 0, 47, 2, 66, 7, 34, 1, 93, 8, 30, 6, 43, 
    3, 89, 2, 62, 7, 29, 5, 23, 8, 66, 0,  3, 6,  6, 1, 75, 4, 76, 
    3, 25, 5, 17, 6,  9, 1, 73, 8, 62, 2, 62, 0, 70, 7, 86, 4, 47, 
    2, 29, 0, 46, 5, 20, 7, 54, 6, 48, 4, 46, 1, 54, 3, 83, 8, 26, 
    3, 12, 6, 76, 7, 89, 5, 45, 1, 40, 4,  4, 2, 14, 0, 34, 8, 93, 
    0, 63, 2, 57, 1, 13, 3,  2, 5, 75, 6, 46, 7, 63, 8, 39, 4, 87, 
    5, 58, 2, 51, 1, 12, 7, 97, 0,  2, 8,  3, 6, 81, 3, 31, 4, 97, 
    1, 82, 8, 46, 3, 27, 7, 56, 6, 61, 4, 94, 2, 46, 5, 66, 0, 27
  };
  const int q5852[] = {
    9, 9, // Number of jobs and machines
    2, 63, 7, 60, 0, 49, 1, 84, 5, 28, 3, 52, 6, 11, 4, 41, 8, 83, 
    3, 31, 6, 90, 1, 56, 8, 99, 2, 32, 4, 91, 7, 79, 0, 63, 5, 35, 
    8, 77, 4, 41, 3, 89, 7, 26, 2, 37, 5, 24, 6, 14, 1, 75, 0, 79, 
    1, 98, 0, 86, 7,  5, 6, 16, 4, 49, 3,  4, 8, 57, 2, 12, 5, 16, 
    1, 74, 2,  2, 0, 98, 7, 88, 3, 52, 4, 18, 8, 94, 5, 14, 6, 36, 
    3, 45, 6, 92, 7, 83, 1, 38, 0, 49, 8, 37, 5, 56, 2, 69, 4, 44, 
    6, 76, 7, 42, 4, 38, 1, 57, 3,  8, 8, 39, 5, 98, 0, 12, 2, 83, 
    6, 30, 2, 49, 3, 77, 8, 10, 4, 14, 1, 76, 0, 55, 5, 25, 7, 58, 
    8, 22, 7,  2, 0, 23, 6, 90, 2, 87, 3,  7, 1, 47, 4, 68, 5, 48
  };
  const int q5853[] = {
    9, 9, // Number of jobs and machines
    6, 24, 0, 96, 7, 23, 2, 28, 8, 43, 5, 34, 4, 93, 3, 97, 1, 11, 
    1, 64, 5, 39, 8, 28, 7, 73, 4, 57, 3, 61, 0, 74, 2, 53, 6, 62, 
    2, 97, 3, 47, 6,  9, 8,  7, 4, 95, 7, 23, 1, 18, 5, 89, 0, 11, 
    5, 88, 0, 24, 8, 95, 7,  2, 1, 38, 4, 99, 6, 72, 2, 78, 3, 51, 
    5, 86, 6, 48, 3, 72, 8, 91, 1, 61, 2, 50, 0,  6, 7,  7, 4, 75, 
    8, 29, 1, 55, 6, 70, 5, 73, 7, 74, 4,  1, 0, 80, 3, 27, 2, 46, 
    5, 28, 4, 52, 1,  5, 7, 58, 6, 24, 8, 42, 0, 79, 3, 87, 2, 29, 
    4, 10, 1, 53, 0, 90, 2, 39, 5, 75, 6, 28, 7, 21, 8, 72, 3, 98, 
    1, 70, 5, 68, 4, 66, 6, 66, 3, 14, 2, 46, 7, 76, 0, 55, 8, 51
  };
  const int q5854[] = {
    9, 9, // Number of jobs and machines
    8, 93, 0, 98, 4,  5, 1,  8, 5,  1, 3, 18, 6, 81, 7, 23, 2, 26, 
    6, 98, 5, 13, 3, 10, 4, 31, 8, 99, 2,  6, 7, 35, 1, 71, 0, 46, 
    0, 54, 1, 39, 6, 21, 2, 54, 5, 63, 7, 92, 4, 33, 8, 18, 3,  9, 
    8, 12, 6, 61, 3, 50, 2, 36, 0, 20, 7, 27, 5,  8, 1, 59, 4, 99, 
    5, 98, 8, 34, 7, 31, 4, 26, 1,  5, 2, 91, 0, 10, 6, 71, 3,  2, 
    8, 34, 1, 72, 7, 98, 3, 40, 0, 69, 6, 89, 5, 54, 4, 33, 2, 10, 
    3, 79, 0,  5, 5, 98, 7,  5, 2, 68, 8, 34, 4, 74, 6, 99, 1, 60, 
    1, 77, 2, 30, 0, 45, 8, 24, 3, 81, 6, 82, 5,  5, 4, 52, 7, 32, 
    3, 33, 6, 64, 8, 85, 2, 99, 5, 55, 7, 27, 0, 50, 4, 17, 1, 86
  };
  const int q5855[] = {
    9, 9, // Number of jobs and machines
    4, 34, 3, 75, 1, 84, 8, 76, 0, 27, 5, 91, 2, 40, 7, 85, 6, 95, 
    8, 27, 1, 18, 2, 57, 4, 85, 3, 24, 7, 22, 5, 83, 0, 76, 6, 86, 
    8, 38, 4, 46, 7, 60, 6, 30, 0, 62, 5, 83, 3, 93, 2, 90, 1, 54, 
    4, 36, 2, 67, 3, 45, 0, 98, 7, 23, 1, 54, 8, 52, 6, 38, 5, 47, 
    6, 96, 2, 87, 8, 46, 1, 87, 7, 38, 3,  3, 4, 30, 0, 90, 5, 70, 
    5, 19, 4, 55, 2, 37, 8, 98, 3, 28, 0, 97, 6, 93, 1, 43, 7,  6, 
    4, 97, 8, 33, 6, 93, 7, 32, 1, 77, 0, 62, 2, 87, 3, 66, 5,  2, 
    7, 24, 3, 69, 4, 90, 1,  8, 6, 89, 2, 43, 5, 73, 8, 71, 0, 12, 
    2, 98, 0, 29, 6, 45, 1, 39, 3, 88, 4, 65, 8, 57, 5, 29, 7, 53
  };
  const int q5856[] = {
    9, 9, // Number of jobs and machines
    7, 10, 4, 27, 3, 53, 0, 25, 5, 64, 2, 14, 1, 85, 8, 42, 6, 54, 
    3, 41, 1, 21, 0, 39, 2, 53, 8, 85, 6, 64, 5, 97, 4, 98, 7, 82, 
    7,  1, 0, 89, 8, 69, 3, 53, 6, 62, 2, 82, 5, 13, 1, 18, 4, 58, 
    7, 90, 6, 87, 5, 81, 8, 90, 2, 71, 3, 64, 1, 62, 0, 60, 4, 60, 
    6, 61, 8, 33, 2, 30, 3,  8, 0, 80, 7, 81, 4, 29, 5, 77, 1, 81, 
    2, 58, 4, 67, 6, 67, 5, 74, 1, 55, 0, 28, 8, 78, 7, 10, 3, 48, 
    7, 47, 5, 41, 0, 33, 3, 63, 6, 22, 1, 39, 8, 21, 4, 72, 2, 61, 
    8, 33, 4, 83, 5, 62, 2, 16, 7, 88, 1, 14, 3, 92, 0, 61, 6, 81, 
    8, 95, 6, 49, 1, 13, 4, 29, 5, 82, 7, 67, 0, 90, 3, 72, 2, 31
  };
  const int q5857[] = {
    9, 9, // Number of jobs and machines
    6, 16, 1, 23, 3, 32, 4,  8, 0, 23, 7, 39, 5, 64, 8,  3, 2, 25, 
    3, 87, 8, 84, 6, 44, 4, 46, 0, 35, 1, 94, 5,  1, 7, 51, 2, 64, 
    8, 89, 5, 72, 2,  8, 1, 47, 0, 68, 6, 74, 7, 77, 3, 36, 4, 96, 
    0, 90, 5, 50, 4, 40, 7, 66, 2, 82, 8, 55, 3, 38, 1, 87, 6, 23, 
    0, 48, 1, 83, 5, 66, 3, 14, 4, 25, 7, 54, 8, 44, 6, 18, 2, 97, 
    0, 59, 4, 79, 7, 61, 3, 62, 5, 79, 8, 71, 1, 76, 2, 67, 6, 64, 
    4, 98, 7, 75, 8,  4, 5, 47, 3, 83, 0, 89, 6, 55, 2,  8, 1,  8, 
    8, 59, 2, 43, 3, 34, 5, 91, 0, 25, 1, 75, 6, 34, 4, 40, 7,  2, 
    1, 76, 8, 41, 7, 68, 6, 73, 2, 85, 4,  8, 0, 27, 3, 98, 5, 95
  };
  const int q5858[] = {
    9, 9, // Number of jobs and machines
    6, 21, 0, 53, 1, 39, 8, 71, 5, 88, 7, 25, 3, 32, 2,  3, 4, 82, 
    5, 94, 2,  4, 6, 20, 8, 17, 7, 10, 4, 68, 3, 30, 0, 80, 1, 57, 
    6, 78, 8, 45, 5, 29, 0, 36, 7, 86, 3, 83, 1, 78, 4, 59, 2, 22, 
    8, 51, 7, 25, 4, 33, 0, 49, 3, 28, 5, 70, 2, 39, 6,  9, 1, 90, 
    1, 46, 4, 96, 7, 98, 6, 59, 3,  8, 2, 80, 8, 63, 0, 87, 5, 29, 
    8, 37, 7, 46, 2, 37, 0, 71, 5, 97, 6, 68, 3, 92, 1, 87, 4, 99, 
    3, 68, 0, 92, 7, 25, 1, 93, 4, 62, 2, 50, 5, 50, 8, 25, 6, 29, 
    6, 80, 1, 62, 4, 50, 8, 28, 7, 59, 5,  8, 0, 11, 2,  3, 3, 58, 
    4, 78, 7, 47, 3, 64, 1, 85, 2, 92, 6, 63, 8, 79, 0, 71, 5, 62
  };
  const int q5859[] = {
    9, 9, // Number of jobs and machines
    8, 92, 0, 62, 3, 25, 6, 60, 4, 55, 7, 75, 2, 93, 1,  1, 5, 42, 
    0,  6, 8,  4, 2, 58, 5, 16, 7, 29, 6, 80, 3, 99, 4,  4, 1, 40, 
    1, 20, 5, 89, 0, 49, 2, 21, 8, 43, 3, 59, 4, 50, 6, 65, 7, 30, 
    8, 65, 3, 58, 1, 72, 7, 90, 0, 24, 4, 44, 5, 74, 6,  9, 2, 87, 
    7, 93, 5, 73, 4, 56, 8, 61, 0, 92, 2, 59, 3, 86, 1, 15, 6, 32, 
    1, 55, 5, 73, 0, 15, 7, 87, 6, 70, 3, 58, 4, 70, 8, 63, 2, 86, 
    7, 32, 6, 36, 1, 33, 8, 55, 2, 10, 5, 81, 0,  6, 3, 85, 4,  3, 
    8, 16, 4, 15, 3, 30, 5, 41, 2, 74, 0, 50, 7, 74, 6, 97, 1, 28, 
    7, 75, 1,  7, 6, 59, 8,  2, 2, 53, 0, 94, 4, 64, 5,  8, 3, 71
  };
  const int q5860[] = {
    9, 9, // Number of jobs and machines
    2, 82, 5, 99, 4, 57, 0, 99, 1, 20, 8,  6, 3, 85, 6, 29, 7, 56, 
    3, 67, 0, 71, 1, 67, 4, 93, 8, 74, 5, 68, 6, 57, 7, 22, 2, 79, 
    3, 46, 5, 57, 6, 50, 4, 26, 1,  1, 7, 55, 0, 43, 2, 82, 8, 38, 
    2, 82, 0, 58, 4, 87, 5, 82, 3, 37, 7, 98, 8, 63, 1, 48, 6, 88, 
    1, 85, 8, 90, 0, 11, 3, 19, 7,  6, 2,  3, 6, 85, 5, 23, 4, 20, 
    0, 62, 8, 29, 3, 90, 1, 85, 4, 49, 7, 91, 5, 57, 2, 99, 6, 28, 
    0,  5, 7, 40, 3, 38, 5,  5, 1, 22, 8, 45, 2, 59, 6,  5, 4, 27, 
    0, 93, 8, 88, 2, 81, 7, 77, 6, 95, 1, 66, 3, 43, 4, 49, 5, 67, 
    4, 29, 2, 63, 6, 44, 0, 59, 1, 82, 5, 85, 8, 90, 3, 70, 7, 63
  };
  const int q5861[] = {
    9, 9, // Number of jobs and machines
    3, 76, 5,  3, 7, 69, 2, 34, 4, 86, 8, 37, 0, 26, 1, 58, 6,  2, 
    0, 99, 2, 66, 7, 29, 4, 84, 1, 65, 8, 37, 6, 97, 3, 79, 5, 42, 
    1, 88, 3, 53, 8, 33, 0, 81, 4, 87, 7,  9, 5,  6, 2, 20, 6, 50, 
    8, 25, 2, 59, 5, 83, 4, 50, 6, 38, 0, 83, 3, 86, 1, 60, 7, 97, 
    2, 33, 4, 61, 0, 77, 6, 63, 1, 82, 8, 30, 7, 95, 5, 67, 3, 32, 
    5, 32, 1, 27, 0, 47, 7, 59, 3, 52, 4, 64, 6, 48, 8, 29, 2, 43, 
    8, 80, 7, 61, 4, 85, 2, 82, 5, 89, 0, 30, 1, 14, 6, 46, 3, 77, 
    2, 26, 1,  6, 7, 47, 5, 40, 6, 47, 8, 59, 4, 96, 3, 22, 0, 27, 
    8, 23, 6, 43, 2, 26, 7, 20, 0, 15, 5, 90, 4, 97, 3, 91, 1, 10
  };
  const int q5862[] = {
    9, 9, // Number of jobs and machines
    5, 65, 8, 87, 1, 91, 3, 95, 7, 96, 6, 48, 4, 43, 2, 51, 0, 94, 
    0, 53, 6, 91, 3, 68, 5, 47, 7, 99, 1, 31, 4, 97, 2, 30, 8, 31, 
    8, 73, 2, 84, 4, 23, 7, 14, 0, 18, 6,  6, 1, 86, 3, 27, 5, 26, 
    3, 50, 6, 21, 1,  8, 4, 66, 2, 79, 0, 82, 5, 72, 7, 80, 8, 94, 
    5, 45, 4,  2, 7, 64, 1, 22, 0, 41, 6, 96, 8, 77, 3, 63, 2, 45, 
    7, 15, 5, 41, 3, 90, 8, 40, 1, 14, 6, 10, 2, 82, 4, 34, 0, 21, 
    0, 10, 4, 86, 6, 48, 3, 35, 7, 30, 1, 15, 8, 13, 2, 18, 5, 27, 
    2, 29, 8,  4, 4, 73, 1, 57, 5, 93, 0, 34, 6, 74, 7, 85, 3, 23, 
    2, 37, 0, 97, 4, 33, 6, 36, 7, 84, 5, 43, 1, 43, 8, 41, 3, 39
  };
  const int q5863[] = {
    9, 9, // Number of jobs and machines
    2, 94, 5,  7, 3, 20, 7, 16, 6, 50, 0, 87, 4, 23, 8, 14, 1, 60, 
    1, 65, 3, 36, 7, 77, 4, 34, 8, 74, 0, 88, 6,  5, 2, 36, 5, 68, 
    6, 34, 3, 41, 5, 69, 1, 21, 8, 42, 7, 93, 2, 70, 4, 73, 0, 15, 
    0, 79, 7, 32, 4, 51, 3, 97, 2, 96, 8, 19, 5, 74, 1, 97, 6, 66, 
    7, 84, 0, 42, 5, 50, 6, 86, 4, 25, 8, 67, 1, 98, 3, 73, 2, 13, 
    4, 87, 3, 83, 7, 21, 8, 27, 0, 43, 2, 81, 5, 10, 1, 86, 6, 74, 
    8, 42, 4, 31, 0,  5, 7, 41, 1, 10, 2, 76, 5, 83, 3, 64, 6, 29, 
    6, 75, 8, 75, 2, 89, 1, 15, 3, 53, 7, 89, 5, 30, 0,  2, 4, 38, 
    2, 27, 1, 88, 0, 74, 5, 17, 8, 93, 7, 91, 4, 39, 3, 85, 6, 45
  };
  const int q5864[] = {
    9, 9, // Number of jobs and machines
    3, 17, 6, 94, 2, 49, 4, 67, 7, 84, 5, 33, 1,  9, 8, 38, 0, 31, 
    8, 63, 0, 10, 2, 88, 4, 99, 7, 90, 5, 62, 1, 38, 3, 65, 6, 63, 
    8,  7, 5, 63, 2, 27, 1, 67, 3, 38, 4, 95, 7, 89, 0, 49, 6, 51, 
    7, 51, 3, 74, 6, 47, 5, 77, 0, 96, 8, 71, 2, 11, 1, 85, 4, 97, 
    7, 80, 2, 67, 3, 27, 0, 99, 4,  8, 5, 96, 1, 44, 6, 26, 8,  5, 
    6, 12, 2, 16, 3, 86, 5, 87, 8, 66, 0, 68, 1, 74, 7, 22, 4, 79, 
    7, 39, 2, 74, 8, 11, 4,  2, 0, 57, 5, 29, 1, 96, 3, 57, 6, 85, 
    0, 99, 1, 90, 6, 90, 7,  9, 2, 27, 4, 45, 3, 79, 8, 83, 5, 50, 
    0, 81, 8, 14, 7, 95, 3, 82, 6, 72, 1, 57, 5, 73, 4, 25, 2,  1
  };
  const int q5865[] = {
    9, 9, // Number of jobs and machines
    0, 12, 4, 47, 1, 96, 5, 71, 7,  1, 8, 99, 2, 26, 3, 16, 6, 74, 
    7, 59, 5, 69, 1, 49, 3, 91, 6, 31, 0, 87, 8, 42, 4, 13, 2, 44, 
    0,  4, 7, 54, 4, 80, 8, 11, 1, 12, 3, 17, 6,  7, 2, 83, 5, 65, 
    8, 23, 0, 62, 2, 69, 7, 93, 6, 73, 1, 72, 3, 67, 4, 36, 5, 82, 
    5, 59, 3, 54, 1, 53, 8, 94, 7, 20, 2, 34, 0, 43, 6, 15, 4, 12, 
    5, 20, 2, 20, 7, 81, 0,  7, 1,  7, 3, 47, 6, 56, 4, 23, 8, 27, 
    1, 61, 6, 53, 4, 61, 0, 38, 3, 87, 8, 19, 5,  8, 7,  8, 2, 80, 
    6, 15, 3, 47, 4, 37, 1, 10, 7, 48, 2, 88, 5, 78, 8, 30, 0, 11, 
    1, 91, 3, 64, 0, 60, 8, 63, 4,  7, 6, 75, 2, 86, 5, 94, 7, 52
  };
  const int q5866[] = {
    9, 9, // Number of jobs and machines
    0,  1, 6, 34, 5, 43, 2, 60, 4, 67, 7, 24, 8, 18, 3,  9, 1, 13, 
    2, 58, 5, 91, 3, 56, 6, 82, 8, 78, 0, 96, 4, 32, 7, 62, 1, 43, 
    5, 97, 7, 18, 2, 87, 1, 68, 4,  5, 0, 64, 6, 58, 8, 45, 3, 24, 
    0, 88, 6,  2, 8, 59, 7, 59, 1, 55, 5, 21, 2, 64, 4, 95, 3, 99, 
    2, 62, 3, 92, 6,  2, 7, 23, 4, 10, 8,  9, 1, 27, 0, 85, 5, 27, 
    2, 28, 7, 73, 6, 70, 0, 38, 4, 61, 5, 56, 3, 51, 1, 24, 8, 68, 
    3, 95, 1, 15, 6, 80, 4, 22, 0, 44, 7, 28, 5,  6, 2, 10, 8, 95, 
    7, 54, 5, 27, 4, 39, 1, 60, 0, 49, 2, 76, 8,  4, 6, 95, 3, 30, 
    7, 68, 0, 19, 4, 51, 6, 21, 8, 46, 2, 11, 3,  3, 5, 78, 1, 31
  };
  const int q5867[] = {
    9, 9, // Number of jobs and machines
    7, 92, 6, 82, 0, 26, 2, 18, 5, 51, 4, 19, 3, 86, 8, 98, 1, 36, 
    3, 62, 6, 60, 2, 11, 5, 25, 4, 47, 0, 10, 7, 96, 1,  9, 8, 80, 
    8, 14, 1,  3, 5, 56, 0, 85, 7, 90, 2, 31, 6, 82, 4, 20, 3, 18, 
    0, 15, 1, 56, 5, 27, 3, 53, 8, 45, 6, 68, 2, 66, 4, 64, 7, 56, 
    5, 34, 3, 80, 7, 44, 6, 19, 8, 32, 0, 13, 2, 74, 4, 21, 1, 59, 
    3, 68, 4, 11, 2, 56, 5, 66, 7, 98, 1, 55, 0, 23, 6, 58, 8,  6, 
    8, 77, 2, 62, 1, 81, 5, 84, 6, 10, 7, 23, 0, 69, 4, 68, 3, 78, 
    7,  2, 0, 19, 1, 70, 8, 92, 4, 14, 6, 53, 5, 66, 2, 33, 3, 25, 
    4,  9, 2, 51, 5, 27, 8, 63, 0, 42, 6, 49, 1, 64, 7, 73, 3,  3
  };
  const int q5868[] = {
    9, 9, // Number of jobs and machines
    1, 77, 8, 36, 7, 29, 4, 13, 6, 34, 3, 56, 2, 61, 0, 73, 5, 77, 
    6, 76, 2, 61, 7, 12, 0, 27, 3, 91, 1, 93, 4, 48, 5, 12, 8, 24, 
    2, 84, 8, 82, 3, 34, 7, 54, 0, 69, 1, 45, 5, 61, 6, 86, 4, 16, 
    5, 62, 2, 61, 3, 59, 6, 50, 1, 36, 0, 70, 8, 91, 7, 98, 4, 83, 
    5, 59, 0, 27, 3, 95, 6, 84, 1, 48, 7, 47, 2, 45, 8, 41, 4, 95, 
    0, 47, 4, 72, 3,  9, 2, 56, 6, 83, 8, 86, 1, 42, 7, 13, 5, 84, 
    2, 73, 0, 74, 7, 55, 6, 69, 8, 68, 5, 86, 3, 61, 4, 57, 1, 26, 
    0, 19, 6, 36, 7, 11, 8, 59, 5, 72, 2, 80, 3, 56, 1, 54, 4,  1, 
    1, 94, 6, 33, 2, 85, 0,  9, 5, 19, 3, 42, 8, 49, 7, 17, 4, 10
  };
  const int q5869[] = {
    9, 9, // Number of jobs and machines
    0, 11, 5, 29, 2, 34, 6, 25, 3, 64, 7, 30, 4, 92, 1, 11, 8, 73, 
    0, 98, 6, 62, 8, 81, 1,  5, 4, 99, 5, 65, 7, 15, 2,  2, 3, 69, 
    8,  6, 3, 42, 4, 59, 2, 70, 1, 22, 0, 20, 6, 57, 5, 77, 7,  2, 
    5, 28, 3, 83, 8,  4, 4, 16, 7, 37, 1, 62, 6, 55, 2, 53, 0, 92, 
    8, 91, 2, 32, 0, 40, 5, 80, 6, 43, 3, 67, 1, 25, 7, 35, 4, 76, 
    0, 13, 8, 28, 3, 89, 5, 11, 6, 72, 4, 75, 2, 54, 1, 49, 7, 37, 
    7, 40, 8, 73, 6, 11, 1, 63, 0, 70, 2, 61, 4, 39, 3, 47, 5, 60, 
    2, 74, 0, 87, 7, 25, 6,  2, 1, 76, 4, 64, 3, 66, 5, 77, 8, 43, 
    5, 12, 3, 98, 7,  5, 2, 68, 4,  3, 0, 91, 8, 88, 6, 63, 1, 68
  };
  const int q5870[] = {
    9, 9, // Number of jobs and machines
    3, 88, 8, 20, 5, 37, 2,  2, 1, 86, 0, 63, 6, 44, 4, 43, 7, 63, 
    5, 80, 4,  4, 3,  5, 7, 83, 8, 14, 1, 49, 2, 52, 6, 75, 0, 40, 
    0, 29, 3, 55, 4, 32, 7, 87, 5, 44, 6, 54, 1, 73, 2, 33, 8, 22, 
    5, 33, 3, 84, 4, 54, 1, 92, 2,  9, 7, 25, 8, 37, 6, 25, 0, 64, 
    4,  1, 3, 25, 2, 49, 8, 99, 5, 33, 6, 59, 1, 10, 7,  3, 0, 67, 
    5, 43, 3, 35, 7, 84, 0, 31, 8, 24, 1, 47, 4, 13, 6, 32, 2, 25, 
    7, 10, 8, 49, 6, 53, 3, 18, 4, 13, 5, 56, 1, 92, 2,  9, 0, 70, 
    4, 50, 0, 17, 7, 79, 3, 35, 6, 41, 1, 91, 5, 19, 8, 81, 2, 61, 
    7, 93, 0, 74, 5, 65, 2, 10, 1, 84, 3, 63, 8, 31, 6, 94, 4, 53
  };
  const int q5871[] = {
    9, 9, // Number of jobs and machines
    1, 53, 2, 61, 6, 75, 5, 63, 7, 96, 0, 37, 8, 28, 4, 22, 3, 55, 
    6, 40, 1, 62, 5,  6, 2, 44, 3, 10, 4, 90, 8, 87, 0, 36, 7, 91, 
    2, 79, 7, 78, 4, 41, 1, 88, 0, 62, 3, 11, 8, 93, 6, 87, 5, 79, 
    0, 83, 7, 20, 3, 80, 5, 11, 6, 99, 1, 88, 8, 85, 2, 80, 4, 45, 
    4, 15, 3, 31, 2, 57, 5, 93, 1, 47, 7, 82, 8, 68, 6, 90, 0, 95, 
    4, 88, 3, 89, 2,  5, 6, 57, 0, 31, 7, 36, 5, 27, 1, 54, 8, 65, 
    1, 41, 5,  9, 7, 92, 4, 58, 6, 16, 0, 33, 3, 91, 2,  4, 8, 61, 
    5, 82, 6, 44, 4, 68, 1, 84, 8, 51, 2, 63, 3, 69, 7,  7, 0, 47, 
    1, 66, 5, 96, 6, 23, 7, 15, 3, 15, 4, 59, 0, 83, 8, 94, 2, 53
  };
  const int q5872[] = {
    9, 9, // Number of jobs and machines
    2, 66, 7, 77, 8, 65, 6, 96, 5, 79, 0, 85, 4, 61, 1, 83, 3,  6, 
    5, 72, 1, 63, 6, 54, 3, 82, 2, 28, 0, 94, 4, 11, 7, 84, 8, 51, 
    2,  9, 0,  2, 1, 61, 7, 60, 8, 84, 3, 57, 5, 26, 6, 19, 4, 74, 
    0, 54, 3, 56, 4, 84, 8, 66, 7, 38, 1, 39, 6, 51, 5, 68, 2, 22, 
    2, 18, 4,  2, 5, 38, 3, 84, 8, 90, 7, 59, 1, 10, 6, 42, 0,  5, 
    3, 88, 2, 71, 6,  7, 5, 46, 7, 60, 1, 12, 8, 64, 0, 14, 4, 70, 
    4, 74, 1, 79, 2, 87, 6, 95, 3, 30, 7, 65, 5, 66, 0, 62, 8, 40, 
    3,  5, 5, 27, 2, 68, 1, 50, 8, 42, 0, 87, 4, 43, 6,  5, 7, 36, 
    7, 39, 1, 58, 2, 21, 5,  3, 0, 94, 8, 17, 3,  5, 4, 39, 6, 32
  };
  const int q5873[] = {
    9, 9, // Number of jobs and machines
    0, 63, 3, 87, 1, 69, 8, 14, 2, 13, 7, 76, 6, 65, 4, 36, 5, 72, 
    2, 47, 5, 43, 6, 14, 8, 73, 0,  7, 7, 80, 3, 65, 4, 19, 1, 82, 
    2, 45, 6, 38, 4, 63, 1, 85, 7, 33, 5, 79, 3, 75, 8, 40, 0, 59, 
    0, 63, 7, 95, 2, 83, 1, 12, 8, 52, 4, 24, 6, 84, 3, 72, 5, 58, 
    5, 76, 7, 78, 4,  4, 2, 20, 8, 73, 6, 57, 0,  5, 3, 39, 1, 75, 
    1, 40, 3, 30, 0, 74, 6, 65, 5, 35, 4, 43, 2, 40, 8, 52, 7, 52, 
    5, 87, 3, 51, 1, 71, 4, 29, 8, 36, 6, 61, 7, 62, 2, 28, 0, 25, 
    7, 49, 1, 69, 5,  2, 8, 46, 2, 90, 3, 77, 4, 64, 0, 70, 6, 79, 
    1, 44, 6, 11, 5, 27, 3, 32, 8, 35, 2,  7, 4, 49, 7, 47, 0, 91
  };
  const int q5874[] = {
    9, 9, // Number of jobs and machines
    7,  1, 2, 91, 8, 14, 6, 71, 0,  2, 3, 23, 4, 64, 1, 91, 5, 71, 
    1, 65, 0, 46, 7, 66, 4, 54, 3, 83, 2, 24, 5, 86, 6, 28, 8, 80, 
    3, 45, 0, 49, 6, 53, 5, 39, 7, 52, 8, 60, 1, 46, 4, 13, 2, 50, 
    5, 90, 1, 38, 2, 99, 7, 24, 3, 51, 6, 70, 0, 29, 4, 28, 8, 89, 
    5, 49, 2, 36, 7, 88, 8, 69, 4, 76, 0, 85, 1, 34, 6, 19, 3, 30, 
    3, 96, 5, 36, 6, 99, 1, 95, 0, 72, 2, 80, 7, 51, 8, 97, 4, 70, 
    2, 18, 6, 82, 3, 80, 7, 10, 8, 48, 0, 32, 5, 46, 4, 25, 1, 14, 
    1, 68, 2, 15, 4, 53, 6, 88, 8, 97, 7, 26, 0, 36, 3, 14, 5, 53, 
    2, 86, 8, 60, 1, 80, 6, 39, 3, 25, 0, 23, 5, 13, 4, 71, 7, 16
  };
  const int q5875[] = {
    9, 9, // Number of jobs and machines
    5, 28, 1, 46, 4,  3, 3, 93, 8, 64, 7, 41, 6, 98, 0, 80, 2, 47, 
    2, 72, 7, 44, 4,  5, 1,  5, 3, 80, 5,  8, 6, 22, 0, 50, 8, 56, 
    1, 37, 5, 61, 2, 73, 6, 96, 7, 99, 8, 96, 0, 30, 3, 46, 4, 53, 
    4, 48, 8,  7, 6, 83, 1, 11, 3, 85, 0, 96, 2, 13, 5,  2, 7, 88, 
    1, 14, 0, 53, 3, 71, 5, 31, 7, 47, 2, 35, 8, 17, 6, 71, 4, 42, 
    7, 97, 5, 11, 2, 64, 3, 15, 4, 70, 0, 12, 6, 77, 1, 43, 8, 23, 
    0, 48, 8, 59, 7, 85, 1, 40, 5, 92, 4, 79, 6, 23, 3, 45, 2,  2, 
    7, 89, 8,  4, 5, 28, 0, 56, 4, 91, 2, 71, 3, 17, 1,  6, 6, 46, 
    4, 75, 6, 95, 2, 48, 3, 65, 5, 73, 1, 60, 0, 83, 8,  1, 7, 83
  };
  const int q5876[] = {
    9, 9, // Number of jobs and machines
    0, 30, 3, 47, 4, 55, 5, 71, 8, 74, 6, 14, 7, 46, 1,  2, 2, 57, 
    4, 44, 0, 59, 3, 56, 2, 19, 7, 28, 1, 62, 6, 64, 8, 47, 5,  6, 
    0, 85, 8, 99, 7, 74, 2, 79, 6, 29, 5, 32, 3, 83, 4,  8, 1, 33, 
    3, 46, 6, 89, 5, 33, 2, 39, 4, 55, 1, 23, 8, 17, 7,  6, 0, 28, 
    2, 62, 8, 99, 7, 85, 4, 16, 5, 28, 1, 45, 6, 96, 0, 86, 3, 25, 
    2, 17, 1, 88, 8, 36, 4, 16, 7, 89, 0, 50, 6, 58, 3, 23, 5,  3, 
    1, 90, 7, 14, 6,  4, 3, 67, 5, 92, 8, 31, 4, 70, 2, 75, 0,  2, 
    4,  6, 2, 47, 3, 90, 8, 74, 0, 33, 1, 31, 5, 47, 6, 19, 7, 46, 
    6, 34, 0, 75, 2, 27, 8, 80, 3, 42, 7, 18, 5, 30, 4, 16, 1, 87
  };
  const int q5877[] = {
    9, 9, // Number of jobs and machines
    2, 47, 1, 72, 4, 80, 5, 37, 3, 14, 8, 92, 7, 98, 0, 32, 6, 34, 
    6, 74, 4, 51, 3, 57, 1,  4, 5, 44, 2, 16, 8, 84, 0, 56, 7, 71, 
    3, 60, 6, 65, 5, 39, 4, 59, 0, 10, 7, 79, 1, 75, 2, 19, 8, 31, 
    7, 18, 8, 65, 4, 81, 0, 71, 1,  2, 6, 66, 2, 38, 5, 95, 3,  7, 
    8, 61, 7, 45, 2, 46, 0,  5, 4, 58, 6, 83, 1, 65, 5, 47, 3, 97, 
    6, 45, 2,  1, 8, 21, 3, 34, 0, 96, 5, 42, 1, 32, 4, 81, 7, 97, 
    7, 99, 5, 77, 8, 74, 2, 74, 1, 58, 4, 17, 0, 68, 3, 12, 6, 75, 
    8, 25, 5,  7, 3, 30, 6, 43, 7, 61, 4,  7, 0, 87, 2, 12, 1, 42, 
    1,  5, 4, 95, 5, 14, 6, 49, 8, 76, 2, 91, 0, 44, 3, 40, 7, 49
  };
  const int q5878[] = {
    9, 9, // Number of jobs and machines
    1, 73, 2, 88, 3, 68, 7,  6, 5, 98, 6, 25, 0, 51, 4, 97, 8, 28, 
    6, 35, 2, 30, 7, 33, 0, 65, 5, 62, 4, 57, 3, 93, 1, 48, 8, 97, 
    6, 79, 4, 80, 5, 80, 7, 20, 2, 73, 0, 30, 1, 70, 3, 67, 8, 15, 
    5,  5, 2, 49, 8, 90, 1, 35, 6, 56, 0,  6, 7, 40, 4, 72, 3, 33, 
    5, 43, 7,  7, 1, 13, 6, 90, 4, 72, 2, 76, 3, 47, 0, 68, 8,  6, 
    5, 98, 4, 89, 3, 45, 6,  3, 1, 34, 7,  2, 8, 57, 2, 92, 0, 89, 
    5, 11, 8, 26, 2, 12, 6, 72, 4, 22, 0, 35, 1, 47, 3, 39, 7, 13, 
    5, 40, 2, 48, 8, 15, 0, 95, 7, 20, 1, 74, 6, 63, 3, 35, 4, 59, 
    3,  7, 5, 66, 6, 20, 1, 75, 7, 86, 2, 18, 4, 39, 8, 13, 0, 59
  };
  const int q5879[] = {
    9, 9, // Number of jobs and machines
    4, 34, 8, 18, 1, 26, 3, 62, 6, 52, 5,  6, 2, 24, 7, 94, 0, 28, 
    8, 23, 0, 47, 7, 83, 2, 36, 5, 60, 3, 44, 4, 34, 1, 15, 6, 12, 
    3, 92, 7, 77, 1, 32, 4,  3, 0, 99, 2, 69, 8, 44, 6, 22, 5, 78, 
    7, 83, 3, 51, 6, 64, 2, 92, 1, 21, 4,  2, 0,  6, 8, 66, 5, 40, 
    4, 82, 3, 42, 6, 89, 2, 39, 0, 16, 7, 26, 1, 45, 8, 89, 5, 61, 
    8, 88, 6, 55, 5, 48, 7, 68, 2, 98, 1, 74, 0, 63, 4, 61, 3, 40, 
    8, 57, 0, 82, 3, 53, 2, 34, 7, 89, 4, 34, 5, 40, 1, 69, 6, 72, 
    8, 73, 7, 32, 1, 43, 6, 88, 3, 17, 2, 84, 5, 81, 4, 31, 0, 70, 
    7, 57, 3, 40, 5, 48, 1,  1, 2, 19, 0,  6, 8, 50, 6, 46, 4, 79
  };
  const int q5880[] = {
    9, 9, // Number of jobs and machines
    6, 22, 1, 75, 0, 16, 3,  5, 7, 36, 5, 84, 8, 76, 2, 15, 4, 40, 
    3, 99, 1, 53, 4, 42, 0, 53, 8, 71, 6, 82, 7, 80, 5, 72, 2, 31, 
    0,  4, 8, 33, 6, 79, 1, 46, 7, 50, 3, 67, 4, 37, 5, 78, 2, 85, 
    8, 59, 6, 93, 1, 96, 3, 40, 5,  9, 4, 51, 0, 78, 7, 76, 2, 45, 
    8, 80, 1, 69, 3, 80, 4, 34, 0, 18, 6, 33, 2, 51, 7, 91, 5, 64, 
    5, 72, 1,  8, 0, 99, 4, 81, 6, 27, 8,  7, 7, 92, 2,  3, 3, 74, 
    0,  2, 2,  9, 8, 28, 4, 63, 6, 22, 3, 79, 7, 58, 5, 76, 1, 65, 
    0, 15, 6, 23, 8, 12, 1, 82, 3,  3, 4, 42, 7, 87, 2,  2, 5, 43, 
    3, 15, 0,  9, 4, 62, 1, 50, 7, 15, 2, 60, 8, 99, 5, 61, 6, 71
  };
  const int q5881[] = {
    9, 9, // Number of jobs and machines
    5, 13, 7,  1, 8, 52, 4, 83, 6, 52, 1, 53, 3, 50, 2,  8, 0, 57, 
    7, 35, 8,  7, 0, 60, 4, 52, 1, 28, 5, 56, 6, 58, 3, 84, 2, 95, 
    6, 97, 2, 17, 0, 22, 1, 47, 8, 50, 7, 28, 3, 32, 5, 77, 4, 89, 
    1, 12, 3, 92, 8,  8, 7, 29, 6, 42, 2, 34, 4, 18, 5, 39, 0, 62, 
    6, 60, 0, 65, 7, 31, 5, 83, 1, 88, 4, 44, 3, 71, 8,  2, 2, 22, 
    7, 85, 4, 91, 6, 25, 8, 60, 1, 15, 3, 16, 5, 19, 0, 96, 2, 82, 
    2, 50, 1, 52, 8, 73, 4, 33, 0, 25, 5, 89, 3, 91, 6, 61, 7, 46, 
    7, 19, 1, 65, 4, 44, 6, 57, 5, 93, 0, 58, 8, 39, 2, 35, 3, 27, 
    3, 41, 6, 84, 8, 30, 2, 39, 4, 34, 5, 92, 7, 89, 0, 57, 1, 84
  };
  const int q5882[] = {
    9, 9, // Number of jobs and machines
    0, 56, 3, 45, 5, 18, 7, 56, 2, 89, 8, 91, 6, 11, 1, 91, 4, 41, 
    8, 71, 7, 16, 1, 44, 6, 79, 4, 19, 5, 45, 2, 47, 0, 31, 3, 66, 
    7, 45, 1, 60, 4, 39, 5, 85, 0, 85, 6, 82, 3, 53, 2, 98, 8, 40, 
    3, 36, 4, 45, 7, 49, 1, 36, 5, 17, 2,  4, 8, 48, 6, 37, 0, 83, 
    2, 60, 4, 78, 5,  2, 1,  8, 7,  2, 8, 89, 6, 12, 3,  2, 0, 35, 
    6, 12, 4, 78, 0, 68, 2, 40, 8, 58, 7, 50, 5, 96, 3, 76, 1, 13, 
    8, 11, 5, 17, 7, 52, 6, 73, 4, 16, 3, 63, 2, 53, 0, 67, 1, 56, 
    8, 73, 5, 91, 4, 64, 1, 31, 3, 63, 7, 40, 2, 23, 6, 11, 0, 91, 
    5, 50, 3, 97, 2, 17, 7, 99, 6, 68, 4, 44, 8, 18, 0,  6, 1, 71
  };
  const int q5883[] = {
    9, 9, // Number of jobs and machines
    1,  4, 0, 74, 7, 68, 2, 93, 3,  4, 8, 15, 5, 79, 6, 12, 4, 59, 
    4, 20, 0, 96, 8, 81, 7, 20, 5, 33, 6, 19, 2, 86, 1, 17, 3,  5, 
    6, 33, 3,  6, 4, 70, 1, 65, 8, 47, 2, 51, 5, 33, 7, 58, 0, 33, 
    2,  5, 5, 99, 6,  4, 8, 48, 4, 32, 1, 21, 3, 95, 7, 98, 0, 79, 
    0, 52, 5, 89, 1,  8, 7, 94, 4, 65, 3, 39, 2,  7, 8, 21, 6, 77, 
    1, 36, 6, 67, 7, 99, 4, 19, 2, 10, 3, 20, 5, 40, 8,  7, 0, 23, 
    2, 14, 6, 33, 3,  5, 7, 33, 0, 74, 4, 32, 1, 86, 8, 72, 5, 28, 
    1, 49, 4, 94, 3, 10, 2, 27, 5,  1, 6,  7, 0, 27, 7, 70, 8, 73, 
    0, 59, 1, 27, 2, 73, 4, 20, 7, 89, 8, 98, 6, 54, 5, 89, 3, 46
  };
  const int q5884[] = {
    9, 9, // Number of jobs and machines
    6, 74, 5, 80, 2, 99, 7, 70, 8, 78, 3, 66, 1, 63, 4, 12, 0, 68, 
    7, 64, 3, 75, 4, 79, 0, 45, 8, 76, 2, 58, 1,  4, 5, 59, 6, 81, 
    7, 23, 6, 70, 0, 87, 3, 30, 8, 46, 4, 17, 5, 61, 2, 41, 1, 19, 
    4, 17, 2, 37, 7, 51, 3, 51, 6, 60, 1, 64, 8, 75, 5,  8, 0, 98, 
    5, 63, 3, 66, 7, 37, 2, 59, 4, 33, 1, 35, 6, 20, 0, 67, 8, 79, 
    4,  7, 2, 23, 6, 79, 0, 35, 1,  6, 7, 69, 5, 95, 8, 72, 3, 43, 
    5, 11, 2, 93, 4, 94, 3, 29, 0, 98, 8, 57, 6, 22, 7, 67, 1, 87, 
    4, 41, 0, 34, 5, 17, 1,  3, 6, 19, 7, 84, 2, 67, 3, 23, 8, 31, 
    5, 91, 6, 38, 1, 44, 8, 40, 2, 99, 7, 56, 4, 85, 3,  5, 0, 22
  };
  const int q5885[] = {
    9, 9, // Number of jobs and machines
    4, 70, 7, 32, 0,  3, 2, 37, 8, 58, 5, 62, 3, 51, 6,  1, 1, 82, 
    8, 81, 5, 48, 7, 85, 3, 78, 1,  9, 0, 13, 6, 82, 4, 23, 2, 61, 
    7, 98, 6, 69, 0, 78, 8, 65, 4, 67, 1, 19, 3, 89, 2, 25, 5, 46, 
    1, 68, 0, 69, 5, 56, 3, 84, 8, 83, 6, 68, 2, 26, 4, 72, 7, 43, 
    5, 23, 7, 99, 8, 91, 3, 41, 0, 37, 2,  1, 6, 46, 1, 89, 4, 86, 
    4, 69, 8, 87, 2, 22, 1, 96, 6, 45, 5, 61, 7, 45, 0, 75, 3, 68, 
    1, 59, 5, 10, 6, 47, 2, 77, 0, 64, 8, 16, 4, 51, 3, 67, 7, 39, 
    8, 67, 7, 49, 6, 39, 2, 80, 1, 15, 4, 48, 0, 45, 3,  6, 5, 45, 
    4, 54, 8, 22, 2, 20, 5, 21, 0, 97, 6, 39, 7, 37, 3, 18, 1, 63
  };
  const int q5886[] = {
    9, 9, // Number of jobs and machines
    0, 94, 5,  9, 7, 29, 3, 81, 4, 16, 6,  8, 1, 41, 8, 26, 2, 58, 
    5, 48, 7, 39, 2, 22, 4, 83, 6, 58, 1, 92, 0, 51, 8, 24, 3, 63, 
    5, 25, 7, 33, 6, 44, 4, 21, 1, 84, 3, 13, 0, 51, 2, 17, 8, 69, 
    3,  1, 1, 95, 5, 90, 6, 53, 4, 48, 0,  3, 2, 36, 7, 94, 8, 66, 
    0,  8, 3, 63, 4, 15, 6, 13, 5, 11, 8, 59, 7, 44, 2, 78, 1, 36, 
    3, 61, 2, 48, 0, 23, 5, 94, 6, 21, 1, 36, 8, 60, 7, 68, 4, 50, 
    8, 53, 4, 32, 7, 18, 3, 32, 1,  3, 0, 72, 6,  9, 5, 93, 2, 42, 
    4, 52, 6, 51, 8,  6, 7, 78, 3,  1, 1, 49, 2, 18, 5, 85, 0, 35, 
    1, 28, 0, 47, 4, 46, 5, 67, 7,  1, 8, 23, 6, 43, 2, 58, 3,  2
  };
  const int q5887[] = {
    9, 9, // Number of jobs and machines
    6, 90, 8,  4, 2, 96, 0, 76, 1, 50, 4, 62, 7, 53, 3, 43, 5, 13, 
    5, 34, 4, 58, 1, 96, 6, 12, 2, 75, 7,  1, 3, 84, 8, 20, 0, 18, 
    7, 25, 0, 33, 8, 60, 1, 30, 5, 62, 6, 76, 3, 11, 2, 94, 4, 53, 
    2, 21, 5, 89, 7, 81, 0, 53, 6, 28, 1, 31, 8, 30, 3, 22, 4,  8, 
    4, 58, 8, 11, 7, 74, 5, 73, 6, 99, 2, 35, 0, 97, 1, 28, 3, 95, 
    2, 42, 7, 17, 5, 31, 6,  2, 8, 33, 3, 74, 1, 83, 0,  9, 4, 77, 
    6, 73, 8, 37, 2, 23, 7,  8, 4, 59, 0, 96, 1, 43, 3, 30, 5, 66, 
    1, 56, 3,  5, 5,  7, 7, 18, 2, 75, 4, 41, 0, 94, 6,  1, 8, 13, 
    8, 67, 2, 47, 4,  8, 6, 27, 0, 99, 1, 97, 7, 51, 3, 62, 5,  8
  };
  const int q5888[] = {
    9, 9, // Number of jobs and machines
    4, 36, 0,  3, 5, 55, 7, 12, 2, 13, 6, 17, 8, 85, 3, 44, 1,  2, 
    4, 86, 0,  6, 3, 91, 1, 47, 8,  4, 6, 85, 7, 66, 2, 44, 5, 75, 
    0, 81, 1, 26, 7, 99, 6, 31, 2,  6, 5, 58, 8, 75, 3, 57, 4, 75, 
    1, 86, 3, 30, 6, 40, 0, 35, 7, 95, 4, 42, 2, 53, 5, 37, 8, 27, 
    0, 19, 3, 79, 4, 89, 7, 49, 1, 17, 2, 27, 8, 43, 6, 56, 5, 98, 
    4, 66, 2, 11, 3, 93, 0,  3, 1, 54, 7, 24, 5, 18, 8,  5, 6, 67, 
    1, 77, 3, 44, 2, 49, 4, 60, 8, 33, 5, 75, 7, 74, 0, 88, 6, 16, 
    4, 25, 6, 59, 8, 64, 2, 62, 5, 61, 0, 12, 3, 80, 1, 83, 7, 54, 
    1, 13, 5,  4, 3, 76, 6, 37, 7, 26, 2, 22, 0, 26, 8, 12, 4, 80
  };
  const int q5889[] = {
    9, 9, // Number of jobs and machines
    0, 42, 8, 59, 7, 21, 3, 59, 4, 95, 5, 97, 6, 95, 1, 66, 2, 88, 
    1, 94, 6, 99, 0, 37, 8, 56, 2, 70, 7, 61, 5, 55, 3, 58, 4, 87, 
    5, 43, 3, 95, 0, 63, 6, 10, 7, 35, 1, 78, 2,  8, 8, 17, 4, 32, 
    5, 75, 7, 15, 4,  6, 0, 91, 6, 28, 8, 34, 1,  3, 3, 36, 2, 80, 
    3, 75, 5, 97, 6,  4, 1, 56, 8, 78, 4, 80, 2, 97, 7, 42, 0, 65, 
    8, 90, 3, 93, 7, 62, 1, 94, 5, 25, 2, 21, 0, 44, 4,  7, 6, 87, 
    2, 65, 8, 36, 1, 58, 7, 68, 4, 20, 5, 63, 3, 50, 0,  6, 6, 91, 
    7, 49, 3, 18, 2, 49, 0, 25, 4, 79, 8, 39, 1, 42, 6, 78, 5, 50, 
    0, 46, 8, 14, 1, 64, 4, 28, 5, 42, 3, 73, 7, 80, 6, 21, 2,  8
  };
  const int q5890[] = {
    9, 9, // Number of jobs and machines
    6, 56, 0, 12, 8, 51, 5, 50, 2, 17, 3, 10, 7, 68, 4, 57, 1, 73, 
    6, 53, 3, 64, 4, 19, 5, 17, 7, 25, 8, 81, 2, 99, 1, 79, 0, 55, 
    1, 57, 5, 32, 3, 25, 7, 14, 2, 49, 0, 25, 6, 45, 4,  9, 8, 53, 
    4, 55, 7, 99, 3, 82, 0, 46, 8, 48, 1, 57, 2, 54, 5,  7, 6, 23, 
    1, 81, 6, 54, 2, 46, 8, 76, 5, 79, 3, 75, 4,  2, 7, 68, 0, 52, 
    8, 60, 3, 32, 2, 32, 7, 97, 5, 75, 6, 57, 4, 72, 0, 83, 1, 59, 
    0,  1, 4, 21, 3,  5, 8, 69, 7, 18, 6, 14, 1, 82, 2,  9, 5, 22, 
    1, 27, 0, 28, 3, 89, 2, 75, 6, 19, 7, 49, 5, 55, 4, 84, 8, 44, 
    7, 75, 1, 18, 8, 54, 0, 97, 2, 25, 6, 92, 5, 14, 3,  5, 4, 42
  };
  const int q5891[] = {
    9, 9, // Number of jobs and machines
    1, 30, 6, 36, 5, 14, 8, 58, 4, 93, 0, 57, 2, 30, 3,  7, 7, 69, 
    4, 27, 3, 59, 1, 42, 0,  5, 6, 18, 5,  6, 7,  3, 2, 83, 8, 55, 
    6, 52, 3, 77, 1, 93, 2,  6, 8, 81, 7, 89, 4, 80, 5,  7, 0, 57, 
    4,  8, 7, 42, 0, 99, 2, 98, 8, 21, 3, 69, 1, 45, 5, 71, 6, 48, 
    3, 49, 1, 44, 6, 20, 2, 93, 5, 16, 8, 37, 7, 58, 0, 50, 4, 95, 
    6, 62, 2, 11, 8, 59, 1, 10, 0,  7, 5, 11, 3, 62, 7,  7, 4, 45, 
    1, 34, 0, 76, 7,  4, 6, 82, 4, 66, 8, 55, 5, 36, 3, 62, 2, 14, 
    6, 57, 0, 43, 2, 50, 5, 59, 8, 96, 7, 51, 1, 68, 3, 33, 4, 17, 
    8, 15, 7, 21, 3, 43, 0, 86, 6, 48, 4, 71, 2, 26, 1, 67, 5, 94
  };
  const int q5892[] = {
    9, 9, // Number of jobs and machines
    5, 67, 1, 38, 8, 66, 2, 38, 4, 13, 0, 70, 3, 50, 7, 56, 6,  7, 
    5, 76, 0, 77, 1, 55, 4, 45, 2, 89, 6, 39, 3, 40, 8, 10, 7, 67, 
    2,  5, 5, 72, 6, 12, 7, 64, 8, 59, 1, 51, 0, 10, 3, 66, 4, 30, 
    3, 10, 5, 38, 2, 25, 7, 71, 8, 29, 4,  3, 6, 12, 0, 39, 1, 78, 
    4, 41, 7, 45, 8, 28, 1, 77, 0, 93, 5, 79, 3, 29, 6, 44, 2, 43, 
    2, 65, 0, 56, 3, 66, 4, 44, 6, 37, 1, 21, 8, 32, 7, 11, 5, 25, 
    3, 45, 8, 33, 2, 10, 5, 35, 0, 91, 7, 70, 1,  4, 6, 34, 4,  5, 
    5, 19, 8, 49, 6, 39, 1,  7, 0, 78, 2, 93, 3, 87, 7, 63, 4, 21, 
    0, 65, 3, 53, 2, 92, 5, 20, 7, 35, 4, 20, 8, 52, 1, 97, 6, 73
  };
  const int q5893[] = {
    9, 9, // Number of jobs and machines
    4,  8, 6, 26, 8, 90, 0, 74, 5, 74, 7, 73, 1, 47, 3, 86, 2, 97, 
    3, 34, 8, 61, 5,  3, 4, 60, 0, 79, 7, 37, 2, 59, 6,  2, 1, 50, 
    5, 55, 1, 30, 0, 20, 6, 53, 2, 63, 4,  1, 8, 97, 7, 71, 3, 20, 
    0, 48, 5, 78, 3, 36, 7, 14, 4, 45, 6, 59, 2, 91, 1, 32, 8, 72, 
    3, 74, 2, 39, 7, 15, 5, 68, 8, 28, 6,  5, 4, 82, 1, 89, 0, 97, 
    4,  9, 0, 82, 7, 55, 6, 87, 1,  6, 2, 65, 5, 41, 3, 23, 8,  8, 
    4, 69, 1, 57, 6, 42, 0,  7, 3, 15, 5, 81, 2, 77, 8, 65, 7, 41, 
    6, 43, 2, 61, 5, 47, 3, 54, 8,  1, 4, 99, 7, 28, 0, 84, 1, 91, 
    5, 46, 8, 75, 7, 86, 1, 56, 3, 81, 4, 56, 0, 78, 6, 42, 2, 67
  };
  const int q5894[] = {
    9, 9, // Number of jobs and machines
    8, 83, 3,  5, 4, 89, 7,  3, 5, 23, 6, 91, 1, 77, 2, 52, 0, 37, 
    7, 19, 2, 60, 4, 89, 0,  7, 5, 63, 1,  9, 6, 32, 8, 17, 3, 52, 
    2, 33, 4, 62, 1, 42, 0, 86, 6, 22, 8,  2, 5, 99, 3, 33, 7,  3, 
    7, 40, 0, 24, 4, 91, 5, 32, 2, 26, 3, 83, 1, 69, 6, 78, 8, 72, 
    0,  9, 5, 47, 6, 72, 3, 94, 7, 67, 4, 99, 2, 41, 1, 81, 8, 79, 
    6, 71, 0, 99, 3, 68, 8, 68, 1, 93, 7, 59, 2,  1, 4,  8, 5, 59, 
    4, 34, 8, 56, 0, 89, 2, 53, 7, 53, 5, 25, 1, 65, 6, 32, 3, 21, 
    2, 21, 4,  9, 0, 46, 8, 94, 1, 67, 6, 56, 3, 38, 7, 63, 5, 81, 
    3, 54, 7, 30, 1,  3, 5, 93, 4, 68, 2, 44, 6, 27, 0, 46, 8,  9
  };
  const int q5895[] = {
    9, 9, // Number of jobs and machines
    8, 54, 7, 77, 4, 65, 6, 50, 1, 16, 5, 91, 0, 13, 3, 48, 2, 46, 
    8, 48, 2, 95, 6, 49, 0, 12, 7,  5, 1, 94, 5, 77, 4, 62, 3, 83, 
    8, 95, 4, 88, 7, 23, 1, 78, 6, 69, 3,  9, 5, 11, 2, 20, 0, 54, 
    0, 64, 8, 50, 6,  9, 7, 33, 3, 89, 2, 51, 4, 54, 1, 78, 5, 96, 
    7, 80, 3, 49, 6, 98, 1, 45, 0, 63, 4, 24, 5, 40, 2, 75, 8, 90, 
    7, 79, 3, 85, 1, 39, 0, 20, 6, 36, 4, 76, 8, 37, 2, 54, 5, 87, 
    5, 48, 3, 91, 8, 77, 4, 53, 0, 76, 2, 16, 6, 12, 1, 97, 7, 11, 
    2, 14, 4,  1, 6, 71, 7, 68, 1,  1, 5, 74, 8, 31, 3, 68, 0,  4, 
    1,  9, 3, 27, 5, 57, 8, 72, 6, 58, 2, 12, 7, 11, 0, 31, 4, 74
  };
  const int q5896[] = {
    9, 9, // Number of jobs and machines
    8, 50, 3, 24, 5, 99, 6, 43, 0, 33, 1, 81, 7, 23, 4, 81, 2, 33, 
    5, 15, 3, 40, 7, 30, 4, 73, 0, 38, 1, 76, 2, 15, 8, 98, 6,  2, 
    8, 45, 6, 26, 4, 79, 1,  6, 5, 17, 3, 68, 7, 95, 2,  8, 0, 93, 
    4, 38, 5, 73, 7, 86, 1, 57, 6, 46, 0, 82, 2, 30, 8, 74, 3, 33, 
    4, 74, 6, 62, 7, 37, 5, 86, 2, 46, 8, 48, 3, 92, 1, 88, 0,  5, 
    5, 44, 8, 40, 6,  5, 7, 77, 2, 99, 4, 93, 0, 44, 3, 12, 1, 91, 
    0, 58, 7, 80, 2, 31, 4, 94, 1, 28, 6, 31, 5, 38, 3, 28, 8, 42, 
    7, 52, 8, 15, 6, 28, 4, 32, 2, 89, 1,  6, 0, 77, 3, 25, 5, 73, 
    5, 84, 8, 62, 3, 95, 6, 22, 7, 77, 0, 98, 4, 54, 1, 98, 2, 75
  };
  const int q5897[] = {
    9, 9, // Number of jobs and machines
    0, 88, 1, 83, 8,  8, 7, 81, 6, 87, 4, 42, 2,  7, 3, 24, 5, 78, 
    5, 26, 8, 71, 4, 69, 3, 38, 1, 44, 0, 46, 7,  6, 2, 36, 6, 74, 
    0, 79, 7, 96, 8, 32, 2, 18, 4, 65, 6, 92, 5, 83, 3, 87, 1, 10, 
    5, 41, 4, 89, 0, 45, 2, 82, 6, 50, 8, 68, 3, 88, 1, 17, 7, 14, 
    1,  1, 6, 83, 7,  9, 2, 56, 3, 18, 0, 50, 5, 48, 8, 30, 4, 76, 
    0, 71, 2, 97, 4, 14, 1, 18, 7, 33, 5, 74, 8, 17, 3, 11, 6, 23, 
    5, 86, 6, 73, 3, 99, 2, 62, 7, 75, 8, 41, 4, 32, 1, 91, 0,  1, 
    5, 50, 7, 43, 3, 85, 2, 13, 1, 32, 0, 33, 8, 41, 4, 29, 6, 41, 
    1, 97, 8,  8, 6, 78, 5, 49, 7, 33, 0, 22, 4, 84, 2, 88, 3, 85
  };
  const int q5898[] = {
    9, 9, // Number of jobs and machines
    7, 94, 4, 90, 8, 27, 0, 73, 5, 65, 2,  8, 3, 34, 1, 90, 6, 32, 
    0, 27, 1, 99, 7, 35, 8, 85, 3, 74, 2, 42, 5, 15, 4, 91, 6, 28, 
    4, 78, 6, 41, 5, 66, 7, 53, 8, 69, 0, 73, 1, 66, 2,  5, 3, 85, 
    7, 43, 6, 81, 8, 47, 5, 79, 0, 83, 1, 66, 2, 66, 3, 23, 4, 17, 
    2,  1, 5, 98, 0, 13, 1, 65, 7, 15, 8, 32, 4, 60, 6, 41, 3, 82, 
    2, 11, 0, 68, 4, 62, 1, 56, 7, 31, 5,  1, 6, 63, 8, 45, 3, 58, 
    7, 50, 5, 77, 0, 65, 6,  7, 3, 56, 1, 47, 8, 53, 4, 65, 2, 86, 
    8,  4, 6, 28, 0, 94, 4, 95, 5,  6, 3, 94, 7, 45, 1, 92, 2, 48, 
    3, 82, 5, 51, 7, 45, 4, 12, 6,  3, 0, 83, 8, 63, 1, 46, 2, 20
  };
  const int q5899[] = {
    9, 9, // Number of jobs and machines
    8, 47, 2, 75, 6, 30, 3, 99, 5, 56, 1, 19, 7, 90, 0, 74, 4, 53, 
    7, 82, 3, 99, 1, 91, 8, 79, 6, 91, 0, 62, 4, 56, 5, 87, 2, 65, 
    4, 49, 2,  1, 0, 19, 3, 58, 1, 55, 5, 23, 8, 98, 7,  4, 6, 29, 
    1, 77, 7,  4, 8, 30, 4, 51, 6, 58, 3, 85, 0,  6, 5, 88, 2, 93, 
    5, 20, 0, 72, 8, 99, 7, 14, 3, 84, 2, 99, 1, 99, 4, 34, 6, 81, 
    1, 26, 4, 20, 6, 41, 3, 31, 2, 86, 0, 71, 7, 41, 5, 26, 8, 92, 
    5, 59, 0, 92, 3, 37, 1,  3, 4, 40, 7, 34, 2, 53, 6, 11, 8, 29, 
    1, 79, 8, 34, 3, 32, 4, 62, 0, 69, 6, 19, 2,  6, 5, 79, 7, 78, 
    2, 14, 3, 86, 5, 63, 1, 82, 0, 72, 8, 47, 7,  6, 4, 45, 6, 73
  };
  const int q5900[] = {
    9, 9, // Number of jobs and machines
    3, 87, 6, 84, 8, 35, 5, 69, 1, 39, 2, 71, 4, 86, 7, 52, 0, 63, 
    3, 81, 7, 48, 6, 32, 5,  1, 0, 96, 8, 41, 1, 15, 2, 36, 4, 30, 
    6, 61, 5,  9, 2, 89, 3, 68, 8, 71, 4,  8, 1, 38, 7, 51, 0, 47, 
    6, 29, 7, 26, 8, 91, 1, 82, 5, 37, 2, 48, 3, 30, 4, 35, 0, 51, 
    1, 10, 5, 34, 6, 31, 2, 54, 3, 71, 0,  8, 7,  5, 4, 64, 8,  7, 
    1, 86, 4, 26, 7, 96, 0, 35, 8, 27, 2, 99, 5, 81, 6, 80, 3,  6, 
    6,  8, 1, 12, 2, 42, 5,  8, 3, 68, 4, 43, 0, 76, 8, 70, 7, 26, 
    0, 77, 7,  1, 5, 34, 6, 56, 4, 96, 8, 20, 2, 76, 3, 40, 1, 39, 
    4, 77, 7, 38, 8, 86, 1,  8, 5, 17, 2, 86, 0, 53, 3, 70, 6,  3
  };
  const int q5901[] = {
    9, 9, // Number of jobs and machines
    7, 11, 8, 45, 4, 18, 3, 87, 5, 15, 1, 97, 2, 82, 6, 60, 0, 36, 
    7, 77, 5, 96, 2, 78, 8, 69, 6, 34, 0, 81, 4, 98, 1, 44, 3, 62, 
    6, 14, 0, 98, 2, 97, 7, 48, 1, 88, 5, 15, 3, 66, 4, 57, 8, 31, 
    3, 77, 8, 27, 2, 76, 4, 55, 5,  4, 0,  8, 7, 41, 1, 15, 6, 18, 
    4, 53, 2, 98, 3, 11, 0, 21, 7, 28, 8, 98, 6, 90, 1, 83, 5, 35, 
    1, 90, 6,  9, 2, 50, 8, 43, 0, 24, 7, 36, 4, 41, 5, 33, 3, 69, 
    1, 63, 4, 37, 0, 73, 3, 24, 5, 46, 2, 39, 7, 49, 6, 85, 8,  2, 
    8, 23, 1, 92, 5, 92, 4, 43, 0, 38, 3, 67, 2, 98, 6, 15, 7, 58, 
    2, 97, 6, 99, 0, 50, 1, 67, 5, 85, 8, 18, 7, 18, 3, 16, 4, 87
  };
  const int q5902[] = {
    9, 9, // Number of jobs and machines
    4, 55, 3, 83, 8, 94, 7, 94, 1, 82, 6, 75, 5, 73, 0, 20, 2, 65, 
    6, 45, 2, 77, 5, 49, 8, 32, 4, 28, 0,  1, 3, 44, 7, 45, 1, 70, 
    6, 74, 5, 89, 7, 55, 4, 19, 3,  6, 2, 94, 1, 94, 8, 91, 0, 89, 
    3, 76, 0, 98, 2, 88, 8, 34, 6, 92, 4, 39, 7,  7, 1, 16, 5, 98, 
    4, 85, 1, 20, 7, 24, 0, 27, 6, 69, 5, 70, 3, 20, 2, 42, 8, 44, 
    8, 63, 0, 27, 3, 42, 7, 89, 6, 94, 5, 63, 4, 54, 1, 88, 2, 68, 
    2, 36, 0, 32, 4,  2, 6, 81, 8, 81, 5,  9, 3, 60, 1, 98, 7, 75, 
    0, 77, 5, 48, 7,  7, 6, 88, 3, 23, 8, 34, 2, 32, 4, 41, 1, 75, 
    1, 27, 6, 89, 5, 70, 0, 65, 3,  7, 4, 84, 8, 30, 7, 63, 2, 63
  };
  const int q5903[] = {
    9, 9, // Number of jobs and machines
    2, 52, 5, 86, 4, 57, 3, 46, 7, 56, 0, 16, 6, 43, 8, 54, 1, 40, 
    8, 51, 5, 27, 4, 85, 6, 63, 7, 60, 2, 73, 0, 50, 1, 45, 3, 64, 
    6, 10, 1, 58, 8, 77, 7, 67, 5, 79, 2, 87, 3, 59, 0,  5, 4, 67, 
    5, 26, 7, 27, 8, 18, 1, 25, 0, 11, 4, 27, 2, 23, 6,  7, 3, 34, 
    0, 32, 2,  4, 8, 92, 3,  2, 7, 51, 1, 12, 5, 30, 4, 64, 6, 41, 
    5, 77, 7, 23, 8, 50, 6, 39, 1, 58, 3, 11, 2, 77, 4, 28, 0, 27, 
    2, 75, 7, 15, 6, 87, 0, 68, 5, 50, 8, 44, 1, 21, 4, 28, 3, 88, 
    3, 65, 6, 40, 2, 69, 7,  8, 1, 75, 4, 41, 8, 51, 5, 92, 0, 55, 
    6, 58, 8, 73, 2, 16, 1, 41, 4, 31, 0, 87, 7,  4, 5, 14, 3, 25
  };
  const int q5904[] = {
    9, 9, // Number of jobs and machines
    4, 33, 1, 67, 5, 43, 8, 97, 3, 19, 6, 15, 0,  9, 7, 19, 2, 66, 
    4, 59, 1, 14, 3, 96, 2, 86, 7, 90, 8, 30, 5, 90, 0, 51, 6, 48, 
    4, 21, 6, 62, 5, 36, 7, 63, 0, 26, 2, 64, 8, 88, 1, 55, 3,  6, 
    7, 29, 4, 55, 2, 98, 0, 21, 3, 35, 5, 94, 8, 11, 1, 75, 6, 50, 
    5, 85, 1, 27, 7, 81, 2, 58, 6, 71, 8, 17, 3, 94, 0, 99, 4, 93, 
    5, 21, 2, 62, 8, 47, 0, 18, 1, 68, 6, 91, 7, 32, 4, 59, 3, 91, 
    6, 12, 8, 25, 2,  8, 0, 20, 1, 28, 7, 80, 3, 91, 4, 26, 5, 84, 
    1, 49, 6, 81, 4, 96, 2, 47, 5, 79, 7, 79, 0, 59, 3, 37, 8, 73, 
    0, 29, 3, 19, 6, 84, 8, 21, 5,  3, 1, 19, 2, 84, 7, 83, 4, 62
  };
  const int q5905[] = {
    9, 9, // Number of jobs and machines
    3, 70, 7, 53, 4, 93, 6, 56, 5, 42, 2, 85, 0, 96, 1,  2, 8, 93, 
    7, 49, 1, 95, 6, 23, 4, 70, 8, 24, 0, 61, 2, 62, 5, 40, 3, 98, 
    8,  3, 0,  1, 1,  2, 3, 64, 6, 89, 5, 88, 4, 87, 2, 50, 7, 50, 
    2, 29, 1, 53, 7,  8, 6,  2, 0, 85, 8, 89, 5, 88, 3, 10, 4, 47, 
    4, 12, 1, 94, 2,  4, 5, 31, 6, 47, 7, 12, 0, 40, 8, 82, 3, 20, 
    5, 77, 0, 22, 6,  5, 8, 13, 2, 33, 7, 13, 1, 12, 4, 86, 3,  8, 
    7, 29, 3,  4, 5, 51, 1, 20, 6,  6, 0, 89, 8, 74, 4, 34, 2,  9, 
    2, 89, 1, 74, 0,  5, 4, 71, 7, 14, 3, 83, 8, 64, 6, 10, 5, 51, 
    1, 70, 8, 46, 4, 14, 5,  9, 0, 60, 6, 71, 2, 50, 7, 42, 3, 62
  };
  const int q5906[] = {
    9, 9, // Number of jobs and machines
    0, 52, 8, 90, 3, 70, 4, 65, 2, 42, 5, 45, 6, 34, 7, 90, 1,  6, 
    3, 75, 2, 87, 1, 44, 6, 12, 4, 70, 5, 57, 7, 61, 8, 62, 0, 85, 
    3, 31, 2, 59, 4, 81, 6, 81, 1, 53, 0, 85, 5, 15, 8, 49, 7, 64, 
    0, 43, 2, 13, 8, 85, 5, 53, 3, 78, 4, 94, 7, 13, 6, 77, 1, 27, 
    1, 55, 7, 26, 4, 94, 6, 90, 5, 93, 2, 65, 8, 62, 0, 53, 3, 80, 
    0, 88, 1, 92, 7, 41, 5, 34, 8, 72, 3, 80, 6,  5, 2, 17, 4, 90, 
    4, 12, 5,  4, 8, 72, 7,  2, 2, 81, 0, 16, 3, 56, 1, 85, 6, 27, 
    2, 38, 8, 24, 0, 30, 3, 35, 4, 17, 7, 41, 6, 44, 5, 96, 1, 44, 
    4, 93, 0, 75, 3, 84, 8, 64, 6, 98, 2,  1, 1, 27, 5,  8, 7, 98
  };
  const int q5907[] = {
    9, 9, // Number of jobs and machines
    8,  9, 2, 35, 5,  7, 6, 58, 7, 23, 0,  5, 4, 11, 3, 76, 1, 58, 
    5, 47, 2, 96, 3, 97, 4, 98, 0, 50, 6, 55, 1,  9, 8, 87, 7,  3, 
    1, 28, 0, 61, 2, 58, 3, 31, 4,  7, 5, 37, 6, 55, 8, 47, 7, 73, 
    5, 33, 8, 77, 7, 80, 1, 64, 4, 28, 6, 45, 0, 88, 3, 30, 2, 32, 
    4, 91, 0, 70, 2, 88, 7, 77, 5, 69, 8, 84, 3,  6, 6, 52, 1, 41, 
    8, 11, 6, 54, 0, 32, 3, 85, 5, 22, 2, 21, 7, 22, 4, 25, 1, 69, 
    7, 22, 0, 66, 1, 85, 5, 35, 3, 30, 6, 70, 4,  9, 2, 71, 8, 24, 
    0, 10, 3, 62, 4, 52, 5, 26, 7, 13, 2, 11, 6, 50, 8, 93, 1, 95, 
    7, 21, 2, 19, 1, 58, 6,  6, 3, 96, 4, 93, 5, 12, 8, 58, 0, 56
  };
  const int q5908[] = {
    9, 9, // Number of jobs and machines
    5, 30, 7, 20, 2, 14, 0, 82, 4, 26, 8, 15, 1, 54, 3,  6, 6, 20, 
    5, 48, 4, 81, 8, 33, 1, 13, 0, 47, 7, 27, 6, 72, 2, 64, 3, 13, 
    8, 70, 7, 58, 3, 70, 6, 82, 4, 35, 0, 78, 2, 92, 1, 37, 5, 64, 
    6, 96, 4, 63, 8, 15, 0, 40, 2, 24, 5, 91, 1, 23, 7, 40, 3, 58, 
    2,  2, 7, 34, 8, 13, 6, 99, 3, 48, 1, 39, 4, 97, 0,  6, 5, 17, 
    0, 90, 1, 83, 6, 67, 7, 67, 2, 36, 5, 81, 8, 30, 3, 28, 4, 99, 
    3, 41, 1, 27, 8, 68, 0, 82, 4, 99, 2, 17, 5,  9, 7, 29, 6, 61, 
    0, 16, 2, 35, 6, 81, 5, 93, 1, 20, 7, 76, 8, 92, 4, 49, 3, 12, 
    6, 87, 8, 78, 2,  9, 7,  1, 0, 70, 1, 20, 3, 47, 5,  7, 4, 60
  };
  const int q5909[] = {
    9, 9, // Number of jobs and machines
    1, 60, 2, 94, 0, 72, 7, 27, 6, 51, 5, 13, 4, 70, 3,  1, 8, 20, 
    0, 68, 1, 63, 8, 10, 3, 88, 7, 19, 2, 52, 5,  6, 6, 30, 4, 69, 
    0, 98, 5, 21, 2, 81, 3, 50, 7, 54, 1, 50, 4, 51, 8, 33, 6, 90, 
    3, 95, 8, 16, 7, 10, 4, 24, 0, 95, 2, 11, 1, 43, 5, 94, 6, 58, 
    4, 89, 6, 39, 0, 28, 2,  2, 5, 75, 7, 32, 8, 52, 1, 81, 3, 73, 
    2, 55, 3, 79, 6, 86, 4, 21, 5, 95, 7, 96, 8, 63, 1, 14, 0, 28, 
    6, 34, 0, 69, 5,  9, 8, 89, 7, 96, 2, 87, 4, 68, 3, 29, 1, 14, 
    4, 43, 5, 38, 7, 70, 0,  5, 1, 61, 8, 41, 3, 24, 6, 52, 2, 89, 
    5, 87, 7, 81, 6, 22, 2, 62, 8, 75, 0, 82, 4, 66, 3, 56, 1, 12
  };
  const int q5910[] = {
    9, 9, // Number of jobs and machines
    3, 85, 0, 89, 6, 83, 2, 64, 7, 57, 4, 48, 1, 37, 5, 19, 8, 45, 
    8, 65, 0,  8, 7, 38, 3, 52, 5, 22, 2, 57, 6, 75, 1,  6, 4,  8, 
    6, 24, 2, 15, 0, 41, 4, 43, 1, 90, 8, 43, 7, 20, 3, 49, 5, 79, 
    2, 86, 3, 16, 8, 98, 5, 16, 6, 45, 0,  8, 7, 65, 1, 83, 4, 91, 
    1, 11, 5,  4, 0, 66, 2,  6, 3,  3, 6, 42, 4, 42, 7, 88, 8, 61, 
    6, 57, 1, 78, 7, 97, 5,  8, 3, 85, 4, 38, 8, 33, 2, 47, 0, 89, 
    0, 80, 2, 94, 5,  8, 3, 20, 4, 70, 1, 26, 8, 95, 6, 95, 7, 30, 
    8, 78, 7, 92, 6, 93, 2, 62, 1, 98, 4, 28, 5, 66, 0, 74, 3, 89, 
    7, 63, 3, 94, 5, 63, 8, 99, 6, 80, 2, 70, 1, 13, 4, 77, 0, 82
  };
  const int q5911[] = {
    9, 9, // Number of jobs and machines
    0, 27, 8, 77, 7, 87, 1,  4, 4, 36, 6, 85, 5, 72, 3,  2, 2, 93, 
    5,  6, 8, 89, 4, 78, 1, 64, 0, 83, 2, 24, 3, 10, 6, 33, 7, 65, 
    1, 35, 6,  7, 5, 71, 3,  9, 2, 19, 8, 58, 7, 36, 4, 64, 0, 17, 
    4, 36, 0, 43, 2, 55, 8,  6, 7, 25, 1, 51, 5, 73, 3,  7, 6, 96, 
    3, 86, 4, 95, 7, 77, 1, 25, 6, 92, 0, 55, 5, 50, 8, 47, 2, 26, 
    5, 94, 3, 82, 7, 79, 4,  1, 0,  8, 2, 90, 8, 49, 1, 51, 6,  9, 
    7, 79, 6, 71, 0, 23, 3, 27, 5, 66, 1,  5, 4,  1, 2, 45, 8, 94, 
    4, 92, 2, 89, 3, 55, 8, 96, 5, 30, 1,  8, 6, 83, 0, 31, 7,  7, 
    8, 35, 0, 15, 7, 59, 2, 65, 4, 83, 1, 53, 3, 70, 5, 74, 6, 39
  };
  const int q5912[] = {
    9, 9, // Number of jobs and machines
    4, 62, 2, 50, 6, 22, 3, 21, 7, 83, 8, 25, 5,  1, 0, 35, 1, 86, 
    8, 60, 1,  8, 3,  8, 7, 19, 5, 51, 4, 76, 0, 35, 6, 42, 2, 26, 
    6, 94, 0, 13, 7, 57, 2, 38, 1,  1, 8, 47, 4,  7, 3, 52, 5, 91, 
    0, 20, 5, 23, 3, 73, 1, 81, 6, 69, 4, 50, 2, 68, 7, 26, 8,  8, 
    7, 34, 4, 40, 2,  1, 0, 74, 8,  2, 1, 17, 3, 16, 5, 61, 6, 72, 
    4, 80, 2, 41, 8, 41, 5, 49, 7, 56, 6, 46, 0, 20, 1, 37, 3, 92, 
    7, 14, 2, 34, 6, 81, 1, 22, 5, 42, 4, 66, 3, 87, 0, 75, 8, 55, 
    3, 75, 7,  9, 0, 96, 5, 81, 1, 92, 2, 21, 6, 67, 4, 76, 8, 88, 
    7,  6, 3, 88, 0, 52, 8, 15, 1, 89, 4, 22, 2, 28, 5,  4, 6, 34
  };
  const int q5913[] = {
    9, 9, // Number of jobs and machines
    8, 98, 0, 94, 5, 68, 1,  1, 4, 18, 7, 57, 6, 50, 2, 35, 3, 77, 
    8, 16, 7,  3, 0, 81, 6, 30, 5, 51, 3, 15, 1,  6, 2, 57, 4, 51, 
    8, 95, 0, 87, 4, 34, 5, 72, 7, 71, 6, 65, 1, 80, 2, 14, 3, 66, 
    0,  7, 7, 54, 8, 60, 6, 86, 1, 83, 2, 61, 3, 41, 5, 34, 4, 91, 
    6, 19, 3, 32, 4, 30, 8, 36, 7, 89, 0, 88, 1,  8, 2, 50, 5, 28, 
    1, 89, 3, 65, 2, 65, 5, 49, 7, 91, 8, 11, 4,  9, 6, 87, 0, 50, 
    2,  4, 0,  5, 1, 67, 7, 60, 8, 43, 6, 82, 4, 26, 5, 16, 3,  8, 
    8, 15, 7, 97, 4, 96, 2, 51, 3, 28, 0, 62, 1, 90, 6, 84, 5, 54, 
    7, 28, 6, 86, 8, 78, 2, 86, 3, 21, 1, 67, 4, 24, 5, 14, 0, 42
  };
  const int q5914[] = {
    9, 9, // Number of jobs and machines
    0, 23, 1, 87, 8, 77, 4, 66, 2, 68, 7, 86, 3, 20, 5, 63, 6, 28, 
    3, 17, 1,  5, 5, 45, 2, 38, 4, 58, 0, 75, 8, 70, 6, 92, 7, 44, 
    8, 83, 7, 33, 4, 15, 1, 33, 0, 73, 2, 91, 5, 87, 6, 71, 3, 95, 
    5, 99, 8, 90, 3, 47, 1, 28, 0, 82, 6, 57, 4, 90, 2, 22, 7, 47, 
    1, 43, 0, 80, 7, 54, 5, 49, 3, 90, 8, 69, 2, 55, 4, 57, 6, 48, 
    8, 86, 5, 16, 1, 36, 2, 37, 0, 19, 4,  3, 6, 32, 7, 49, 3, 65, 
    0, 48, 3, 14, 1, 67, 4, 91, 8, 46, 5, 41, 2, 14, 6, 64, 7, 81, 
    5, 15, 4, 67, 6, 88, 2, 68, 7, 77, 8, 85, 1, 14, 0, 51, 3, 49, 
    8, 75, 1, 83, 3, 12, 4, 85, 5, 28, 2, 12, 7, 28, 6, 26, 0, 34
  };
  const int q5915[] = {
    9, 9, // Number of jobs and machines
    5, 63, 7, 11, 6, 48, 2, 59, 1, 34, 0, 80, 8, 89, 3, 13, 4, 39, 
    8, 28, 6, 27, 0, 52, 7, 93, 2, 15, 5, 69, 3, 81, 1,  1, 4, 51, 
    4, 82, 1, 64, 8, 64, 6, 79, 7, 78, 5, 99, 3,  6, 2, 15, 0, 38, 
    2, 37, 0,  8, 8, 56, 6, 58, 3, 84, 5, 64, 7, 42, 1, 71, 4, 35, 
    1, 69, 3, 24, 2, 59, 6, 66, 7, 47, 4, 86, 0, 89, 5, 37, 8, 97, 
    7, 77, 3, 71, 5,  3, 6, 93, 8, 32, 4, 98, 2, 88, 1, 26, 0, 61, 
    4, 50, 8, 38, 1, 58, 3, 36, 5, 77, 2, 43, 0,  1, 6, 49, 7, 80, 
    2, 85, 4, 17, 3,  3, 7, 54, 1, 83, 5, 84, 6, 31, 8, 85, 0, 77, 
    1, 53, 0,  6, 6,  5, 5, 85, 3, 16, 4, 19, 2, 69, 7, 25, 8, 29
  };
  const int q5916[] = {
    9, 9, // Number of jobs and machines
    3, 68, 8,  4, 2, 20, 0, 69, 5, 76, 7, 92, 6, 61, 1, 23, 4, 88, 
    2, 29, 8, 15, 4, 66, 7, 88, 3, 97, 5, 52, 6, 54, 1, 98, 0, 40, 
    8, 30, 4,  2, 7, 79, 1, 93, 2, 12, 6, 55, 3, 48, 5, 66, 0, 56, 
    1,  9, 4, 29, 7, 46, 8, 29, 3, 19, 6, 49, 5, 90, 0, 52, 2, 55, 
    1, 30, 3,  4, 7, 46, 4, 70, 8,  9, 0,  7, 2, 85, 5, 77, 6, 54, 
    2, 32, 0, 25, 8, 44, 4, 71, 3, 81, 7, 64, 6, 89, 1, 60, 5, 88, 
    5, 36, 6, 49, 7, 41, 0, 83, 1, 20, 8, 85, 2, 38, 4, 79, 3, 30, 
    3, 34, 6, 28, 0, 52, 7, 25, 2, 72, 4, 68, 5, 67, 8, 80, 1, 50, 
    3, 20, 8, 50, 5,  5, 7, 11, 4, 15, 6, 81, 0, 70, 1, 85, 2, 10
  };
  const int q5917[] = {
    9, 9, // Number of jobs and machines
    7, 21, 2, 42, 1, 77, 5, 21, 3, 46, 4, 68, 8, 89, 0, 72, 6, 46, 
    5, 52, 4, 53, 2,  6, 0, 21, 3,  1, 7, 41, 1,  7, 6, 99, 8, 66, 
    3, 95, 8,  8, 6,  8, 0, 74, 5, 15, 4, 50, 2,  8, 7, 20, 1, 26, 
    0, 82, 1, 77, 7, 70, 3, 33, 8, 71, 6,  2, 4, 31, 2, 81, 5, 65, 
    6, 47, 0,  1, 3, 60, 2, 15, 7, 97, 8, 52, 1, 43, 5, 13, 4,  1, 
    1,  4, 4,  5, 8, 72, 2, 65, 3, 86, 5, 26, 0, 64, 6,  5, 7, 55, 
    0, 54, 6,  1, 4, 29, 8, 40, 3, 10, 5, 60, 1, 27, 7, 61, 2, 42, 
    2, 50, 0,  9, 4, 27, 8, 87, 1, 76, 6, 57, 3, 34, 5, 72, 7, 86, 
    7, 69, 3,  8, 1, 42, 0, 77, 8,  6, 5, 64, 4, 87, 2, 79, 6, 43
  };
  const int q5918[] = {
    9, 9, // Number of jobs and machines
    4, 35, 1, 89, 2, 53, 5, 97, 8,  9, 6, 72, 0,  5, 3, 12, 7, 88, 
    4, 76, 5, 20, 8, 85, 1, 21, 0, 95, 3, 60, 2,  1, 6, 54, 7,  3, 
    8, 29, 4, 20, 2, 31, 5, 92, 1, 69, 3, 40, 0, 59, 7, 67, 6, 80, 
    4, 59, 1, 71, 7, 83, 2, 28, 3,  4, 8, 84, 0, 77, 5, 83, 6, 21, 
    4, 31, 0, 10, 7, 84, 2, 99, 5, 95, 8, 77, 3, 94, 1,  2, 6, 84, 
    5, 28, 6, 51, 3, 97, 1, 10, 7, 17, 0, 72, 2, 23, 4, 84, 8, 47, 
    6, 85, 1, 23, 0, 65, 2, 46, 8, 97, 4, 78, 7,  8, 3,  9, 5, 39, 
    1, 94, 2, 64, 8, 96, 4, 73, 7, 43, 0, 47, 3,  4, 6, 74, 5, 70, 
    3, 40, 6,  4, 7, 75, 5, 16, 2, 91, 8, 15, 0,  8, 1,  3, 4, 82
  };
  const int q5919[] = {
    9, 9, // Number of jobs and machines
    3,  9, 2, 40, 8, 12, 6, 79, 7, 50, 5, 42, 0, 95, 4, 34, 1, 33, 
    3, 84, 8, 60, 2, 59, 6, 79, 4, 38, 5, 99, 7, 63, 0, 23, 1, 99, 
    3, 89, 0, 98, 4, 21, 7, 80, 6, 65, 8, 67, 1, 81, 5,  7, 2, 86, 
    7, 69, 5, 27, 1, 56, 0,  3, 2, 87, 4, 85, 6, 99, 8, 87, 3, 21, 
    8, 15, 3, 16, 7, 70, 4,  9, 2, 12, 0, 11, 6, 91, 5, 25, 1, 59, 
    8,  3, 2,  1, 6, 50, 7, 59, 0, 87, 5, 53, 1, 82, 3, 59, 4, 29, 
    3, 52, 5, 51, 0,  2, 7, 73, 6, 61, 2, 79, 1, 79, 4, 86, 8, 75, 
    0, 19, 1, 14, 8, 76, 3, 32, 5, 35, 6, 39, 7, 97, 2, 61, 4, 55, 
    2, 33, 4, 51, 7, 78, 8, 21, 5, 37, 6, 64, 0, 71, 3, 21, 1, 19
  };
  const int q5920[] = {
    9, 9, // Number of jobs and machines
    6, 98, 5, 23, 2, 47, 4, 27, 8, 26, 3, 47, 0, 97, 1, 61, 7, 56, 
    5, 97, 0, 52, 6, 71, 1, 36, 3, 41, 7, 89, 2, 32, 8, 45, 4,  8, 
    5, 42, 4, 69, 2, 55, 3, 53, 8, 91, 1, 88, 0, 56, 7, 54, 6, 39, 
    6, 52, 8,  5, 7, 36, 3,  7, 5,  6, 1, 53, 2, 18, 4, 17, 0, 92, 
    6, 62, 1, 42, 7, 93, 8, 86, 4, 75, 5, 25, 2, 76, 3, 30, 0, 94, 
    5, 11, 2, 44, 3,  7, 8, 55, 6, 52, 7, 19, 1, 14, 4, 86, 0, 82, 
    4, 25, 0, 69, 7, 95, 2, 61, 1, 42, 5, 55, 3, 19, 8, 15, 6, 33, 
    2, 28, 5, 58, 3,  9, 1, 33, 7, 98, 4, 41, 6, 86, 0, 27, 8, 99, 
    0, 22, 3, 46, 2, 21, 4, 51, 6, 39, 8, 22, 5, 78, 1, 71, 7,  7
  };
  const int q5921[] = {
    9, 9, // Number of jobs and machines
    7, 81, 1,  8, 6, 57, 8, 46, 5,  2, 0, 52, 4, 59, 3, 53, 2, 49, 
    5, 29, 3, 34, 6, 14, 0, 42, 7, 49, 1, 20, 8,  9, 4, 90, 2,  3, 
    2, 38, 0, 44, 6, 34, 5, 88, 8, 70, 4, 91, 1, 96, 3, 25, 7, 38, 
    5, 82, 6, 18, 8,  1, 3, 10, 4,  8, 7, 64, 1, 58, 0, 25, 2, 16, 
    8, 92, 6, 61, 7, 72, 0, 73, 2, 33, 1, 75, 5, 28, 4, 72, 3, 98, 
    4, 20, 1, 28, 5, 13, 3,  2, 7, 96, 6, 66, 2, 58, 8, 37, 0, 72, 
    5, 76, 2, 10, 4,  3, 7, 25, 1, 19, 6, 37, 3, 49, 8, 68, 0, 25, 
    4, 92, 5, 31, 6, 13, 3, 63, 2,  6, 1,  9, 8, 93, 7, 82, 0, 73, 
    6, 55, 8, 48, 0, 48, 7, 65, 5, 63, 4, 61, 2, 61, 1, 47, 3, 56
  };
  const int q5922[] = {
    9, 9, // Number of jobs and machines
    8, 13, 7, 65, 1, 66, 5, 74, 2, 50, 4, 65, 3, 43, 6, 70, 0, 44, 
    5, 46, 4,  9, 3,  6, 2, 71, 8, 26, 1, 59, 0, 87, 6, 87, 7,  6, 
    2, 59, 3, 39, 8, 48, 4, 95, 1, 64, 6, 26, 0, 98, 5, 59, 7,  4, 
    4, 45, 3, 13, 6, 26, 1, 51, 8, 47, 7, 55, 0, 99, 5, 52, 2, 70, 
    4, 23, 6,  9, 8, 13, 5,  3, 2, 45, 1, 92, 3, 18, 0, 30, 7,  6, 
    3, 45, 8, 59, 4, 61, 0, 77, 1, 85, 5, 66, 7, 28, 6, 40, 2, 11, 
    8, 23, 0, 73, 2, 27, 7, 69, 4, 49, 5, 15, 1, 57, 6,  6, 3, 78, 
    0, 37, 7, 25, 8, 55, 1, 91, 3, 49, 2, 99, 4, 32, 5, 64, 6, 93, 
    6, 84, 5, 44, 7, 89, 4, 67, 0,  5, 1, 27, 8, 55, 3, 63, 2, 42
  };
  const int q5923[] = {
    9, 9, // Number of jobs and machines
    1, 69, 4, 61, 3, 18, 5, 47, 0, 95, 6, 29, 8, 51, 2, 66, 7,  9, 
    0, 53, 3,  5, 1, 82, 2, 89, 8, 72, 7, 70, 4, 28, 6, 93, 5, 13, 
    3, 55, 1, 32, 7, 68, 0, 84, 6, 58, 4, 15, 5, 20, 2, 84, 8, 87, 
    7, 63, 1, 56, 0,  4, 6, 23, 2, 52, 8, 47, 5, 20, 3, 32, 4, 20, 
    4, 75, 1, 87, 3, 33, 8, 78, 5, 39, 2, 25, 7, 16, 0, 36, 6, 90, 
    1, 25, 2, 53, 6, 35, 8, 82, 3, 72, 7, 36, 5, 76, 0, 10, 4, 97, 
    6, 58, 4, 93, 8, 26, 3, 80, 0, 10, 1,  5, 7, 61, 5, 21, 2,  1, 
    7, 87, 0, 50, 6, 60, 2, 20, 1, 72, 5, 50, 8, 34, 3, 11, 4, 81, 
    2, 59, 5, 74, 3, 37, 4, 57, 0,  2, 8, 70, 7, 44, 1, 15, 6, 38
  };
  const int q5924[] = {
    9, 9, // Number of jobs and machines
    0, 93, 3, 77, 1, 50, 8, 53, 4, 83, 6, 17, 7, 89, 2, 59, 5,  9, 
    2, 23, 7, 91, 4, 23, 3, 41, 1, 56, 5, 90, 0, 52, 6, 50, 8, 81, 
    8, 22, 3, 67, 4, 87, 7, 27, 5, 44, 0, 42, 1, 90, 2, 80, 6, 69, 
    1, 20, 4, 10, 2, 51, 0, 50, 8, 28, 6, 81, 3, 70, 7, 92, 5, 47, 
    0, 75, 4, 15, 6,  4, 8,  6, 1, 20, 2, 16, 7, 18, 3, 80, 5, 37, 
    3, 83, 1,  7, 5,  1, 8, 62, 7, 51, 0, 39, 6, 23, 4, 47, 2, 26, 
    8, 89, 6,  6, 7, 18, 2, 40, 4, 62, 5, 88, 1, 57, 0, 17, 3, 60, 
    4, 33, 3, 52, 8, 29, 6, 31, 0, 16, 5, 93, 7, 24, 2, 91, 1, 65, 
    8, 81, 4, 49, 1, 34, 5, 90, 6,  8, 7, 94, 3,  9, 0, 72, 2, 76
  };
  const int q5925[] = {
    9, 9, // Number of jobs and machines
    0,  3, 1, 15, 2, 57, 5, 32, 6, 41, 8, 90, 4, 51, 7, 67, 3, 34, 
    0, 91, 6, 13, 7, 15, 1, 13, 2, 70, 4, 64, 3, 95, 5,  1, 8, 99, 
    0, 75, 1, 24, 5, 90, 7, 49, 3, 94, 4, 98, 6, 98, 2,  2, 8, 28, 
    7, 91, 5, 33, 2, 14, 8, 12, 0, 86, 3, 81, 4, 45, 6, 63, 1, 96, 
    3, 70, 8,  9, 0, 25, 7, 92, 4, 27, 5, 40, 1, 57, 6, 14, 2, 89, 
    7, 74, 1, 74, 5, 95, 8, 52, 2, 59, 3, 10, 4, 26, 0, 22, 6, 16, 
    5, 68, 7, 92, 8, 74, 1, 94, 4, 95, 3, 65, 6, 88, 0, 44, 2, 43, 
    6,  9, 7, 71, 5, 86, 2, 57, 8, 95, 1, 82, 4, 57, 0, 26, 3, 29, 
    3, 78, 7, 32, 5, 45, 0, 83, 8, 26, 2,  9, 4, 36, 1, 97, 6, 67
  };
  const int q5926[] = {
    9, 9, // Number of jobs and machines
    0, 70, 7, 38, 5, 12, 3, 75, 1, 64, 4,  6, 8, 56, 6, 25, 2, 71, 
    0, 57, 8,  1, 6, 96, 4, 82, 7, 20, 1, 32, 5, 29, 3, 97, 2, 32, 
    5, 18, 7, 97, 4, 72, 1, 56, 3, 90, 2, 10, 6, 74, 8,  5, 0, 72, 
    4, 99, 7,  8, 3, 35, 6,  9, 8, 99, 2, 53, 5, 89, 0, 58, 1, 23, 
    2, 25, 0, 43, 4, 21, 6, 54, 8, 81, 1, 37, 3, 17, 5, 78, 7, 69, 
    1, 20, 5, 68, 0, 80, 2, 91, 6, 22, 7, 33, 8, 97, 4, 16, 3, 72, 
    2, 98, 7, 42, 6, 95, 8, 55, 3, 32, 4, 47, 5, 14, 0, 61, 1, 82, 
    6, 82, 0, 62, 7, 50, 8, 46, 3, 79, 2, 36, 5, 71, 4, 51, 1, 90, 
    6, 18, 5, 97, 7,  7, 3, 26, 4,  2, 0, 79, 8, 57, 2, 53, 1, 87
  };
  const int q5927[] = {
    9, 9, // Number of jobs and machines
    5, 67, 7, 15, 3, 11, 8, 72, 1, 69, 6, 25, 4, 65, 0,  7, 2, 95, 
    1, 26, 7, 74, 4, 63, 5, 52, 8, 71, 3, 16, 0,  1, 2, 89, 6, 77, 
    4, 17, 2, 19, 8, 60, 7, 76, 6, 14, 3, 26, 5, 96, 0, 56, 1, 49, 
    0, 96, 4, 10, 8, 13, 6, 84, 5, 63, 7, 69, 2, 88, 3, 45, 1, 62, 
    3, 44, 6, 97, 4, 10, 0, 94, 1, 55, 7, 19, 5, 20, 8, 75, 2, 53, 
    4, 88, 2, 14, 3, 66, 7, 78, 8, 88, 0, 56, 5, 98, 1, 91, 6, 99, 
    2, 76, 6, 71, 4, 11, 5, 10, 7, 22, 0, 33, 1, 15, 3,  5, 8, 13, 
    2, 75, 6, 82, 1, 58, 5, 70, 8, 75, 0, 34, 4, 97, 7, 20, 3, 26, 
    2, 46, 3, 30, 7, 66, 1, 66, 8, 78, 4, 53, 5, 60, 6, 92, 0, 88
  };
  const int q5928[] = {
    9, 9, // Number of jobs and machines
    4,  5, 5, 56, 7, 87, 2, 56, 3, 54, 6, 60, 8,  8, 1, 51, 0, 34, 
    7, 70, 1, 52, 5, 15, 2, 30, 0, 76, 4, 50, 8, 36, 6, 65, 3, 13, 
    7, 45, 4, 36, 5, 10, 8, 45, 0, 29, 2, 81, 1, 96, 3, 82, 6, 66, 
    2, 37, 5, 21, 4, 32, 3, 45, 0, 36, 1,  5, 8,  1, 7, 87, 6, 91, 
    4, 88, 2, 31, 5, 90, 6, 21, 1, 58, 0, 98, 7, 46, 8, 39, 3, 66, 
    7, 72, 1, 27, 2, 59, 4, 28, 6, 18, 5, 73, 8, 13, 3, 93, 0, 50, 
    1, 53, 2, 67, 3, 42, 6, 50, 0, 49, 8, 11, 7, 26, 5, 92, 4, 63, 
    0, 14, 1, 36, 7, 88, 5, 50, 2, 49, 3, 89, 6, 72, 4, 18, 8, 49, 
    8, 83, 0, 98, 3, 51, 7, 61, 4, 89, 5, 65, 2, 84, 1, 64, 6, 64
  };
  const int q5929[] = {
    9, 9, // Number of jobs and machines
    6, 31, 1, 46, 0, 33, 3, 62, 4, 62, 5, 47, 2, 56, 8, 45, 7, 30, 
    4, 18, 1, 21, 2, 79, 5, 28, 8, 35, 7, 43, 3,  3, 0, 37, 6, 30, 
    4, 44, 3, 24, 0, 58, 5, 10, 7, 99, 2,  1, 1, 41, 8, 94, 6, 93, 
    8, 88, 6, 32, 0, 18, 3, 67, 5, 90, 7, 37, 1, 79, 4, 74, 2, 17, 
    7, 90, 0, 43, 2, 69, 1, 87, 4,  4, 8, 10, 5, 61, 6, 46, 3, 18, 
    8, 39, 7, 97, 4, 25, 0, 53, 6, 12, 2, 59, 3,  5, 1, 53, 5, 61, 
    0, 26, 7, 26, 2, 36, 1, 87, 4, 81, 3, 96, 8,  5, 5, 74, 6, 91, 
    4, 77, 3, 55, 2, 94, 0, 77, 6, 32, 8, 54, 7, 76, 1,  3, 5, 18, 
    8,  6, 7,  4, 2, 94, 6, 20, 1, 59, 3, 51, 4,  8, 0, 92, 5, 53
  };
  const int q5930[] = {
    9, 9, // Number of jobs and machines
    4, 49, 7, 32, 5, 86, 8,  1, 6, 10, 2,  6, 3, 55, 0, 44, 1, 34, 
    5, 27, 1, 23, 2, 70, 3, 81, 8, 67, 0, 82, 4, 76, 6, 20, 7, 73, 
    8, 77, 6, 59, 2, 65, 1, 84, 7, 21, 4, 48, 5, 56, 3, 32, 0, 21, 
    0,  3, 3, 93, 5, 83, 2, 81, 7, 80, 4, 91, 8, 49, 1, 52, 6, 19, 
    1, 53, 0, 93, 2, 37, 4,  8, 3, 74, 7, 85, 6, 69, 5, 10, 8, 30, 
    5, 48, 4, 34, 8, 18, 7, 12, 3, 94, 6, 44, 1, 97, 0, 66, 2, 54, 
    0, 71, 8, 43, 2, 58, 4, 63, 1, 36, 3, 61, 6, 85, 5, 90, 7,  2, 
    8, 58, 5, 38, 0, 55, 1, 54, 4, 19, 2, 30, 7, 45, 6, 70, 3, 76, 
    5,  7, 2, 25, 1, 72, 8, 82, 0, 17, 6,  4, 3, 91, 4, 28, 7, 80
  };
  const int q5931[] = {
    9, 9, // Number of jobs and machines
    7, 36, 1, 93, 8, 90, 6, 67, 0, 91, 5, 27, 2, 86, 3, 16, 4, 66, 
    3,  5, 8, 61, 2, 34, 0, 47, 6, 19, 1, 13, 7, 60, 5,  4, 4, 40, 
    0, 71, 7, 29, 4, 31, 2, 71, 1, 94, 3,  9, 8, 43, 5,  3, 6, 49, 
    1, 84, 4, 28, 0, 56, 7, 26, 8, 19, 2, 51, 6, 87, 3, 97, 5, 24, 
    0, 56, 3, 66, 4, 93, 5, 97, 8, 88, 7, 31, 1, 78, 6, 98, 2, 27, 
    5, 59, 3, 29, 0, 87, 4, 41, 8, 63, 7, 90, 1, 30, 6, 59, 2, 60, 
    5, 55, 4, 93, 6, 38, 1, 99, 3, 38, 8, 51, 0, 29, 2, 46, 7, 64, 
    0, 24, 4, 10, 6, 88, 5, 19, 2,  1, 8, 15, 3, 40, 7, 64, 1, 58, 
    3, 16, 4, 14, 5, 68, 7,  2, 1, 36, 8, 81, 2, 12, 6, 92, 0, 82
  };
  const int q5932[] = {
    9, 9, // Number of jobs and machines
    5, 88, 8, 72, 7, 15, 6, 94, 4, 35, 2, 75, 0, 33, 1, 34, 3, 88, 
    3, 46, 5, 99, 1, 68, 0, 37, 8, 76, 7,  4, 4, 88, 2, 94, 6, 73, 
    5, 56, 8, 38, 4, 49, 2, 38, 0, 22, 1, 19, 6,  7, 7,  2, 3, 72, 
    2, 18, 7, 80, 6, 13, 4, 78, 5, 39, 3, 24, 8, 40, 0,  7, 1, 70, 
    4, 98, 1, 60, 0, 29, 2, 41, 7, 92, 6, 38, 8, 39, 5, 95, 3, 79, 
    7, 23, 8,  6, 1, 72, 3, 80, 2, 46, 5, 35, 0, 30, 4, 21, 6, 42, 
    2, 43, 5, 54, 6, 50, 7, 61, 4,  8, 3, 98, 1, 75, 0, 48, 8, 32, 
    7, 35, 5, 41, 8, 19, 1, 76, 0, 36, 4, 42, 6, 35, 3, 63, 2, 12, 
    4, 77, 8, 54, 0, 61, 1, 35, 5, 66, 7, 75, 3, 40, 2, 50, 6, 11
  };
  const int q5933[] = {
    9, 9, // Number of jobs and machines
    4, 84, 5, 11, 1, 52, 6,  9, 8, 35, 2, 25, 7, 76, 3,  6, 0, 89, 
    5, 95, 7, 18, 6, 72, 2, 94, 4, 97, 1, 37, 3,  1, 8, 86, 0, 65, 
    4, 82, 7, 93, 6, 16, 0, 65, 5, 54, 1, 20, 2, 34, 8, 33, 3, 90, 
    4, 82, 1, 79, 2, 72, 3,  1, 0, 59, 8, 16, 5, 64, 7, 45, 6, 97, 
    6, 34, 2, 71, 7,  7, 8, 73, 4,  1, 3, 77, 1, 87, 0, 96, 5, 64, 
    6, 54, 0, 40, 3, 19, 8, 71, 7, 36, 2, 69, 5, 19, 1,  1, 4,  9, 
    7, 75, 5, 53, 6, 50, 1, 10, 2, 41, 0, 57, 3, 53, 4, 36, 8, 79, 
    0, 99, 6, 64, 4, 89, 5, 71, 2, 18, 3, 77, 1, 60, 8, 33, 7, 83, 
    2, 93, 8, 63, 1, 78, 5,  7, 4, 91, 6, 81, 0, 64, 7, 30, 3,  1
  };
  const int q5934[] = {
    9, 9, // Number of jobs and machines
    7, 66, 0, 99, 4, 31, 5, 13, 3, 81, 1, 12, 6, 64, 8, 42, 2, 50, 
    0,  9, 7, 64, 1, 42, 5,  2, 4, 64, 8, 95, 2, 31, 3, 98, 6, 19, 
    8, 79, 4,  9, 7, 60, 1, 76, 5,  3, 0, 86, 6, 90, 2, 45, 3, 70, 
    5, 10, 6, 24, 7, 35, 3, 85, 1, 90, 4, 50, 0, 40, 2, 89, 8, 41, 
    5, 27, 6, 18, 7, 94, 1, 45, 0, 25, 8, 75, 3, 42, 4, 85, 2, 34, 
    4, 98, 0, 86, 5, 34, 3, 40, 2, 65, 8, 12, 7, 68, 1,  9, 6,  8, 
    7,  5, 1, 14, 6,  5, 4, 53, 8, 44, 5, 94, 0, 37, 2, 46, 3, 44, 
    0, 69, 8, 15, 1, 80, 3, 80, 2, 89, 4, 74, 6, 23, 7, 74, 5, 91, 
    1, 67, 0, 63, 5, 17, 4,  9, 2, 15, 3, 61, 8, 97, 6, 84, 7, 82
  };
  const int q5935[] = {
    9, 9, // Number of jobs and machines
    8,  9, 3, 45, 5, 88, 1, 56, 0, 46, 2, 74, 4, 48, 6, 64, 7, 80, 
    2, 66, 0,  1, 8, 99, 3, 25, 5, 10, 7, 83, 6, 67, 4, 47, 1, 90, 
    4, 51, 6, 83, 1, 19, 7, 47, 5, 18, 0, 32, 3, 71, 2, 59, 8, 40, 
    3, 47, 8, 74, 4, 32, 7,  2, 0, 59, 1, 15, 2,  5, 5, 32, 6, 64, 
    3, 20, 7, 56, 1, 72, 5, 17, 8, 23, 4, 57, 2, 19, 0,  5, 6, 40, 
    5, 15, 8, 46, 0, 55, 2, 46, 3, 86, 1, 15, 7, 97, 6, 93, 4, 26, 
    8, 54, 6, 85, 5,  2, 4, 89, 7, 73, 1, 88, 3, 66, 0, 38, 2, 23, 
    5, 11, 8, 54, 4, 77, 0, 23, 7, 71, 1, 41, 3, 58, 2, 81, 6, 90, 
    3, 72, 6, 25, 2, 43, 8, 49, 1, 90, 0, 75, 4, 70, 5, 17, 7, 96
  };
  const int q5936[] = {
    9, 9, // Number of jobs and machines
    1, 79, 4, 29, 6, 76, 8, 75, 2, 42, 3, 28, 7,  7, 0, 69, 5,  6, 
    3,  8, 5, 90, 8, 18, 7, 53, 4, 10, 2,  6, 0,  1, 1, 63, 6, 84, 
    0, 79, 2, 87, 8, 45, 4, 18, 1, 73, 3, 36, 6, 98, 7, 89, 5, 32, 
    0, 57, 6, 79, 5, 96, 4,  8, 7, 71, 8,  2, 3, 81, 2,  5, 1, 19, 
    2, 49, 1, 72, 4, 58, 3, 50, 0,  2, 8, 50, 6, 14, 5, 14, 7, 73, 
    0, 37, 4, 99, 2, 71, 8, 68, 7, 98, 5, 88, 1, 14, 6, 44, 3, 29, 
    4, 80, 3, 96, 1, 91, 5, 50, 0, 86, 6, 16, 7, 20, 2, 47, 8, 43, 
    3, 23, 0, 77, 4, 84, 7, 31, 5, 51, 8, 81, 2, 93, 6, 39, 1, 74, 
    4,  5, 5, 76, 8, 44, 7, 12, 1, 11, 2, 52, 0, 45, 3, 68, 6, 25
  };
  const int q5937[] = {
    9, 9, // Number of jobs and machines
    7, 80, 6,  5, 4, 28, 1, 18, 5, 14, 2, 61, 8, 65, 3, 47, 0, 30, 
    0, 68, 7, 51, 4, 91, 6, 69, 2, 67, 1, 57, 3, 94, 8, 55, 5, 95, 
    7, 96, 4, 93, 1, 53, 5, 68, 0, 59, 8, 12, 6, 80, 2, 54, 3, 52, 
    2,  4, 7, 84, 8, 29, 5, 46, 1, 19, 0, 83, 3, 60, 4,  5, 6, 37, 
    0, 48, 7, 59, 1, 66, 2, 90, 8, 38, 6,  6, 4, 37, 3, 44, 5, 56, 
    4, 86, 2, 36, 5, 79, 8, 30, 6, 38, 3,  9, 7, 77, 1, 29, 0,  1, 
    8, 34, 2, 29, 5, 38, 7, 78, 4, 92, 3, 76, 0, 36, 6, 15, 1, 59, 
    2, 78, 5,  5, 4, 36, 0, 50, 1, 25, 7, 38, 6, 29, 3, 34, 8, 81, 
    8, 65, 6, 89, 3, 38, 1, 68, 5, 64, 0, 99, 2, 69, 7,  7, 4,  1
  };
  const int q5938[] = {
    9, 9, // Number of jobs and machines
    2,  2, 5, 97, 0, 59, 8, 87, 7,  8, 3,  3, 1, 38, 6, 21, 4,  5, 
    7, 82, 6,  1, 4, 59, 5, 18, 1, 40, 2, 80, 8, 83, 3, 51, 0, 47, 
    1, 56, 7, 24, 8, 12, 5,  6, 0, 38, 3, 51, 4, 22, 6, 37, 2, 29, 
    6, 88, 3, 61, 5, 66, 1, 86, 4, 90, 2, 17, 8,  1, 0, 57, 7, 25, 
    7, 26, 5, 46, 4, 38, 6, 93, 8, 74, 0, 22, 3, 77, 2, 59, 1, 99, 
    4, 77, 5,  1, 8, 13, 7, 87, 6, 99, 3, 23, 2, 31, 0, 87, 1, 47, 
    5, 17, 6, 99, 1, 50, 3,  5, 0, 58, 7, 69, 4, 97, 2, 39, 8, 52, 
    1, 27, 8, 29, 5, 58, 6, 24, 2, 61, 7, 80, 0, 29, 3,  4, 4, 70, 
    4, 16, 8, 17, 1, 21, 7, 13, 3,  4, 2, 41, 5, 96, 0, 48, 6, 32
  };
  const int q5939[] = {
    9, 9, // Number of jobs and machines
    2, 24, 7, 16, 5, 52, 4, 97, 1, 35, 0, 29, 6, 48, 3, 77, 8, 60, 
    6, 97, 2, 26, 8, 53, 3, 45, 7, 37, 5, 43, 0, 75, 1, 41, 4, 24, 
    7, 36, 8,  2, 5, 61, 0, 97, 1, 99, 3, 56, 6, 65, 4, 33, 2, 64, 
    4, 58, 5, 48, 2, 42, 7,  4, 1, 12, 6, 98, 8, 97, 0, 37, 3,  2, 
    2, 25, 1, 71, 7, 82, 5, 47, 4, 50, 8, 52, 3, 30, 0, 93, 6,  3, 
    1, 65, 3, 83, 8, 88, 0, 17, 2, 63, 7, 23, 4, 94, 6, 98, 5, 94, 
    2, 99, 5, 60, 1, 10, 6, 47, 4, 87, 8, 70, 0,  3, 7, 12, 3, 31, 
    4, 73, 3, 67, 6, 57, 5, 89, 7, 27, 2, 78, 8, 56, 0, 83, 1, 24, 
    5, 47, 7, 62, 8, 76, 6, 68, 0, 17, 2, 96, 1, 45, 4, 63, 3, 72
  };
  const int q5940[] = {
    9, 9, // Number of jobs and machines
    1, 53, 2, 61, 8, 32, 0, 88, 7, 80, 5, 28, 4, 82, 6, 46, 3, 93, 
    4, 82, 6, 35, 0, 92, 2, 81, 8, 16, 7, 96, 1, 29, 5, 50, 3, 30, 
    0, 19, 4, 64, 2, 50, 5, 52, 3, 67, 1, 55, 6, 33, 7, 40, 8, 12, 
    1, 33, 5, 62, 8, 99, 0, 32, 6, 19, 7,  1, 3, 83, 2, 28, 4, 16, 
    5, 76, 4, 67, 0, 60, 8, 22, 6,  3, 2, 74, 7, 62, 3,  7, 1,  6, 
    2, 39, 3, 83, 0, 12, 8, 35, 6, 69, 7, 48, 4, 51, 5, 35, 1,  3, 
    6, 57, 7, 95, 0, 61, 5, 57, 8, 22, 3, 61, 2, 32, 1, 37, 4, 25, 
    0, 54, 3, 14, 4, 10, 6, 75, 8, 77, 2, 61, 1, 40, 5, 23, 7, 77, 
    6, 70, 5, 73, 8,  6, 2, 60, 7, 86, 4, 28, 1, 44, 0, 66, 3,  3
  };
  const int q5941[] = {
    9, 9, // Number of jobs and machines
    3, 68, 1, 32, 5, 86, 7,  4, 2,  7, 8, 61, 6, 87, 0, 78, 4, 85, 
    1, 13, 4, 31, 5, 27, 2, 20, 8, 77, 6,  4, 3, 55, 7, 31, 0, 30, 
    0, 36, 6,  4, 8,  4, 1, 85, 4, 26, 3, 82, 2, 37, 5, 92, 7, 26, 
    0, 27, 6, 57, 7, 71, 1, 79, 4, 38, 8, 25, 2,  6, 3, 51, 5, 63, 
    8, 89, 6, 19, 0,  6, 1, 54, 2, 87, 3, 67, 5, 39, 7, 21, 4,  3, 
    4, 34, 1, 15, 7, 16, 2, 31, 3, 17, 6, 60, 8, 98, 5, 80, 0, 73, 
    3, 20, 5, 92, 8, 86, 1, 59, 6, 93, 4, 40, 7, 98, 2, 82, 0, 21, 
    1, 52, 7, 81, 2, 47, 3, 10, 4, 71, 6, 46, 0, 45, 5, 89, 8, 16, 
    2, 30, 3, 86, 4,  3, 0, 15, 7, 64, 5, 95, 1, 59, 6, 62, 8, 53
  };
  const int q5942[] = {
    9, 9, // Number of jobs and machines
    5, 47, 2, 45, 7, 19, 1, 50, 8, 12, 6, 42, 4, 40, 0, 14, 3,  6, 
    0, 29, 4, 62, 1, 59, 2, 56, 8, 42, 6, 22, 7, 63, 5, 25, 3, 18, 
    0, 91, 3, 78, 7, 51, 1, 96, 8, 33, 4, 96, 6, 67, 2, 53, 5, 48, 
    2,  6, 5, 21, 7, 69, 0, 91, 6, 24, 1, 60, 3, 66, 8, 10, 4, 31, 
    6, 94, 4, 13, 7, 93, 3, 83, 1, 96, 8, 83, 5, 36, 2,  3, 0, 45, 
    7, 19, 4,  6, 8, 65, 5,  4, 1, 45, 6, 43, 2, 84, 3, 77, 0, 45, 
    8,  3, 2, 94, 4, 29, 3, 50, 6, 50, 5, 33, 1, 81, 7, 87, 0, 64, 
    3, 41, 7, 30, 6, 38, 4, 56, 2, 37, 0, 88, 5, 73, 1, 58, 8, 70, 
    1, 69, 5, 16, 8, 66, 2, 74, 0, 28, 6, 42, 3, 47, 4, 26, 7, 64
  };
  const int q5943[] = {
    9, 9, // Number of jobs and machines
    2, 99, 6, 87, 3, 18, 5, 98, 1,  8, 4, 40, 7, 80, 8, 68, 0, 43, 
    6, 41, 7,  4, 5, 81, 8, 23, 4, 46, 0, 73, 2, 63, 3, 94, 1,  3, 
    8, 65, 4, 90, 2, 21, 1, 67, 5, 63, 7, 19, 0,  2, 6, 26, 3, 48, 
    3, 17, 5, 66, 2, 17, 8, 86, 4, 90, 0, 29, 7, 35, 1, 15, 6, 44, 
    5, 38, 2, 31, 4, 23, 8, 57, 0, 44, 7, 37, 3, 55, 6, 42, 1, 76, 
    3, 62, 4, 63, 5, 87, 0, 71, 7, 28, 6, 46, 1, 80, 2, 24, 8, 75, 
    4, 41, 6, 56, 3, 54, 5, 76, 7, 56, 1, 30, 0, 48, 8, 10, 2, 77, 
    2, 28, 0, 47, 4, 29, 3, 14, 1, 34, 8, 38, 6, 42, 5, 62, 7, 28, 
    6, 71, 3, 32, 7, 66, 8, 37, 2,  5, 0, 31, 1, 46, 4, 18, 5, 50
  };
  const int q5944[] = {
    9, 9, // Number of jobs and machines
    2, 99, 8, 89, 7,  1, 1, 16, 6, 37, 0, 39, 5, 90, 4, 25, 3, 78, 
    2, 62, 4, 29, 8, 59, 7, 91, 6, 50, 5, 65, 0, 90, 3, 42, 1,  7, 
    2, 77, 5, 75, 6, 68, 1, 30, 4, 46, 8, 20, 7, 68, 3, 98, 0,  3, 
    3, 62, 5, 26, 1, 66, 7, 66, 2, 66, 0, 62, 4, 49, 8, 75, 6, 49, 
    8,  7, 3, 89, 2,  8, 7, 78, 5,  3, 0, 70, 1, 59, 6, 35, 4, 33, 
    6, 82, 4, 29, 7, 63, 8, 53, 3, 89, 1, 64, 5, 95, 0, 44, 2, 33, 
    5, 31, 1, 17, 7, 52, 0, 66, 8, 22, 2, 75, 4, 77, 3, 45, 6, 90, 
    7, 66, 6, 45, 5, 64, 2,  3, 3, 44, 1, 30, 8, 57, 0, 45, 4, 11, 
    2, 13, 7, 65, 3, 62, 1, 30, 0, 14, 8, 63, 6, 35, 5, 97, 4, 57
  };
  const int q5945[] = {
    9, 9, // Number of jobs and machines
    4, 41, 0, 76, 3, 25, 8, 74, 7, 64, 2, 99, 6, 83, 1, 53, 5, 57, 
    1, 44, 3, 93, 0, 64, 6, 65, 2, 78, 5, 14, 7,  7, 8, 64, 4, 29, 
    8, 96, 4, 98, 0, 74, 6, 46, 2, 24, 7,  8, 3, 88, 1, 87, 5, 56, 
    0, 74, 1, 99, 5, 15, 7,  8, 8, 77, 2, 63, 6, 66, 4, 89, 3, 41, 
    4, 49, 0, 58, 6, 48, 7, 82, 2, 91, 5,  5, 1, 59, 3,  1, 8, 29, 
    3, 42, 4, 79, 1, 64, 2, 12, 8, 79, 0, 11, 7,  3, 6, 26, 5, 65, 
    2, 91, 6, 58, 8, 15, 3, 44, 5, 55, 7, 69, 0,  2, 4, 28, 1,  2, 
    3, 21, 2, 17, 8, 13, 0, 54, 5, 58, 7, 54, 1, 51, 4,  1, 6, 19, 
    7, 63, 1, 51, 0,  7, 6, 29, 3, 40, 5, 26, 2,  6, 8, 11, 4,  5
  };
  const int q5946[] = {
    9, 9, // Number of jobs and machines
    5, 10, 4, 80, 7, 76, 3, 34, 6, 15, 1,  2, 8, 29, 2, 75, 0, 75, 
    4, 86, 6, 56, 3, 65, 8, 13, 5, 53, 7, 62, 1, 79, 2, 37, 0, 27, 
    2, 23, 3, 50, 6, 81, 8, 62, 5, 51, 4, 17, 0, 39, 7, 87, 1, 39, 
    2, 74, 6, 71, 7, 22, 8, 12, 0, 15, 5, 11, 3, 66, 1, 77, 4, 17, 
    7, 59, 3, 57, 8, 51, 2, 40, 6, 48, 5, 51, 4, 11, 0, 72, 1, 11, 
    1, 22, 2, 69, 7,  1, 5, 51, 0, 69, 8, 48, 4, 32, 6, 58, 3, 82, 
    3,  8, 2, 29, 4, 79, 8, 97, 0, 22, 7, 18, 5, 73, 1,  2, 6, 22, 
    7,  2, 2, 72, 3, 33, 5, 62, 0, 69, 6, 35, 8, 15, 4, 42, 1, 30, 
    3, 44, 8, 35, 5, 35, 2, 39, 1, 72, 7, 17, 0, 33, 4, 11, 6, 94
  };
  const int q5947[] = {
    9, 9, // Number of jobs and machines
    3, 87, 4, 97, 8, 65, 0, 34, 2, 29, 6, 56, 7, 17, 5, 14, 1, 23, 
    1, 56, 3, 14, 6, 18, 4, 81, 2, 40, 5, 14, 0, 42, 7, 47, 8,  9, 
    8, 55, 1,  5, 2, 35, 3, 54, 7, 84, 4, 68, 5, 83, 0, 60, 6, 84, 
    6, 79, 7, 47, 5, 72, 1, 85, 4, 72, 8, 50, 0, 47, 2, 75, 3, 76, 
    2, 45, 7, 61, 6, 90, 5,  3, 8, 84, 4, 59, 0, 36, 3, 65, 1, 55, 
    7, 96, 0, 21, 2, 62, 6, 91, 4, 26, 3, 57, 8, 45, 5, 25, 1, 47, 
    6,  3, 8, 18, 4, 66, 1, 39, 3,  9, 7, 84, 5, 73, 2, 99, 0, 67, 
    1, 30, 0, 89, 2,  4, 7, 21, 3, 77, 8, 68, 6, 74, 5, 26, 4, 41, 
    7, 48, 0, 47, 3, 30, 6, 84, 1, 52, 5, 54, 8,  9, 2, 24, 4, 66
  };
  const int q5948[] = {
    9, 9, // Number of jobs and machines
    4, 75, 2, 48, 7, 15, 5, 64, 1, 69, 6, 56, 0,  4, 3,  8, 8, 90, 
    0, 93, 7, 51, 8, 30, 6, 54, 4, 31, 5, 14, 3, 41, 2, 98, 1, 82, 
    0, 26, 5, 52, 1, 58, 3, 81, 8, 10, 2, 98, 7, 39, 6, 68, 4, 53, 
    5, 47, 6, 72, 4, 12, 3, 63, 2, 35, 1, 22, 7, 21, 0,  4, 8, 17, 
    6, 88, 8, 21, 2, 73, 3, 22, 5, 44, 4,  8, 0, 88, 7,  7, 1, 60, 
    5, 37, 7,  1, 2, 82, 6, 52, 8, 99, 0, 47, 3, 86, 1, 97, 4, 65, 
    6,  2, 4, 29, 1, 55, 0, 21, 3, 33, 7, 18, 8, 44, 2, 42, 5, 45, 
    1, 66, 3, 98, 7, 45, 4, 52, 2,  1, 0, 37, 6, 75, 5, 57, 8, 36, 
    0, 32, 6, 44, 3, 27, 1, 55, 8, 17, 7, 36, 5, 25, 2,  7, 4, 12
  };
  const int q5949[] = {
    9, 9, // Number of jobs and machines
    2,  5, 1,  1, 4, 92, 3, 77, 0, 11, 6,  9, 8, 56, 7,  9, 5, 96, 
    1, 66, 2, 25, 8,  9, 7, 17, 6, 46, 5, 43, 3, 21, 0, 20, 4, 24, 
    1, 31, 6, 84, 0, 43, 4, 26, 2, 32, 5, 47, 8, 91, 7,  3, 3, 15, 
    0, 99, 8, 78, 7, 98, 3, 91, 4,  9, 6, 82, 5,  9, 2, 65, 1, 38, 
    6, 51, 5, 89, 7, 65, 2, 75, 8, 18, 0,  2, 3, 11, 4, 87, 1, 17, 
    6, 21, 0, 20, 3,  8, 2, 46, 8, 79, 1, 73, 4, 82, 5, 45, 7, 67, 
    0, 47, 7, 19, 5, 64, 2,  2, 6, 26, 8, 90, 1,  8, 4, 95, 3, 44, 
    8, 84, 7, 34, 5, 10, 4,  5, 6, 69, 3, 59, 0, 76, 2, 27, 1, 34, 
    6, 61, 8, 81, 7, 65, 2,  3, 1,  6, 4, 94, 5, 23, 0, 73, 3, 24
  };
  const int q5950[] = {
    9, 9, // Number of jobs and machines
    4, 56, 3, 89, 6, 54, 5, 27, 0, 67, 1, 65, 7, 85, 2, 37, 8,  1, 
    7, 68, 1, 42, 0, 84, 5, 55, 3, 93, 4, 56, 6, 12, 8, 64, 2, 47, 
    0, 35, 5, 56, 3, 76, 4, 78, 2, 40, 6, 29, 8, 71, 1, 42, 7, 84, 
    4, 64, 2, 67, 6, 79, 1, 86, 8, 24, 7, 28, 0, 86, 5, 54, 3, 30, 
    0, 65, 4, 21, 5, 39, 7, 74, 8, 77, 3, 93, 6, 25, 1, 74, 2, 47, 
    7, 82, 4, 21, 2, 51, 5, 24, 1, 55, 0, 63, 6, 17, 3, 31, 8, 90, 
    8, 88, 5, 75, 7, 68, 2, 30, 3,  9, 0,  4, 1, 42, 6, 69, 4, 31, 
    0, 25, 3, 67, 5, 15, 2, 83, 1, 58, 4, 75, 7, 28, 8, 59, 6, 43, 
    1, 92, 7, 63, 5, 73, 0, 95, 2, 79, 4, 22, 6, 14, 8,  9, 3, 84
  };
  const int q5951[] = {
    9, 9, // Number of jobs and machines
    8,  9, 7, 25, 5,  2, 3, 97, 0, 50, 1, 58, 6, 90, 4, 73, 2, 87, 
    2, 65, 3, 54, 8, 55, 6, 42, 0, 83, 7, 31, 5, 78, 4, 18, 1, 72, 
    1, 24, 4, 50, 7, 48, 0, 80, 2, 89, 5, 45, 3, 18, 6, 56, 8, 21, 
    7, 32, 4, 37, 0, 51, 2, 93, 1, 54, 8, 64, 6, 41, 3, 28, 5, 38, 
    2, 85, 6,  7, 3, 29, 0, 45, 7, 76, 4, 41, 5, 78, 8,  9, 1, 81, 
    0, 31, 2, 16, 3, 77, 6, 35, 4, 54, 1, 39, 8, 24, 7, 48, 5, 99, 
    6, 75, 7,  5, 3, 52, 1, 18, 8, 35, 0, 75, 5, 72, 2, 91, 4, 17, 
    2, 36, 0,  7, 7, 23, 1, 99, 4, 58, 6, 22, 5, 11, 3, 76, 8, 92, 
    1, 87, 0, 70, 2, 73, 6, 77, 8, 60, 5, 31, 4, 68, 7, 25, 3, 45
  };
  const int q5952[] = {
    9, 9, // Number of jobs and machines
    1,  2, 3, 17, 2, 32, 6,  4, 0, 61, 8, 82, 4,  2, 5, 30, 7,  3, 
    6, 39, 5,  6, 3, 84, 8, 44, 4, 37, 2, 98, 1, 37, 7,  1, 0, 64, 
    5, 33, 0, 23, 4, 46, 6, 11, 3, 50, 1, 38, 8, 35, 7, 39, 2, 73, 
    2, 51, 3,  6, 4, 67, 1, 80, 5, 30, 8, 96, 6, 12, 7, 91, 0, 17, 
    1, 87, 5, 63, 4, 76, 0, 89, 7, 87, 3, 74, 2, 60, 8, 47, 6, 32, 
    5, 60, 2, 48, 7, 40, 1, 12, 3,  5, 4, 89, 8, 85, 0, 21, 6, 51, 
    2,  6, 1, 74, 6, 66, 4, 32, 3, 55, 7, 77, 8, 71, 0, 36, 5, 69, 
    8, 29, 3,  8, 1, 73, 0, 85, 2, 24, 6, 73, 5, 26, 4, 80, 7, 31, 
    8, 46, 2, 60, 6, 96, 5, 27, 3, 14, 1, 37, 4, 60, 0, 33, 7, 22
  };
  const int q5953[] = {
    9, 9, // Number of jobs and machines
    8, 33, 2, 74, 6, 92, 3, 25, 0, 90, 5,  7, 1, 80, 7, 14, 4, 34, 
    3,  9, 4, 95, 6, 70, 7, 38, 0,  8, 8, 25, 2, 43, 5, 48, 1, 45, 
    7, 25, 2, 56, 6, 49, 0, 49, 8, 76, 5, 18, 1, 51, 4, 90, 3, 92, 
    1, 35, 7, 55, 3, 16, 2, 68, 6, 46, 8,  7, 0, 66, 4, 53, 5, 91, 
    2, 13, 0, 99, 8, 60, 5, 98, 6, 97, 4, 67, 7, 31, 1, 29, 3,  5, 
    4, 62, 1, 25, 5, 20, 7, 72, 8, 96, 0, 14, 6, 81, 2, 76, 3, 24, 
    5, 12, 0, 91, 3, 38, 6, 48, 1, 37, 7, 45, 2,  3, 8, 93, 4, 14, 
    6, 17, 1, 39, 4, 75, 0, 81, 7, 62, 2, 59, 3, 59, 5, 66, 8, 30, 
    0, 10, 7, 42, 4, 81, 2, 53, 8, 87, 3,  7, 5, 91, 1, 21, 6, 27
  };
  const int q5954[] = {
    9, 9, // Number of jobs and machines
    5, 48, 7, 71, 8, 42, 0, 52, 6, 89, 3, 94, 4, 64, 2, 15, 1, 67, 
    6,  6, 0, 52, 3, 71, 1, 25, 7, 98, 4, 26, 5, 79, 2, 52, 8, 78, 
    1, 48, 5,  2, 2, 47, 6, 14, 0, 78, 4, 55, 8, 13, 7,  8, 3, 10, 
    5, 67, 8, 18, 3, 42, 1, 43, 7, 92, 6, 52, 4, 41, 0, 85, 2, 56, 
    4, 94, 3,  3, 0, 63, 5, 36, 7, 33, 8, 80, 6, 42, 1, 33, 2, 41, 
    0, 66, 5, 34, 1, 86, 7, 76, 6, 10, 4, 75, 8,  2, 3, 45, 2, 89, 
    6, 90, 7, 59, 0, 75, 4, 48, 5, 54, 2, 74, 8, 39, 1, 76, 3, 61, 
    7, 78, 4, 38, 8, 86, 5, 40, 1, 61, 0,  3, 6, 64, 2, 36, 3, 98, 
    6, 42, 7, 32, 4, 79, 8, 30, 2, 82, 1, 17, 3, 66, 0, 10, 5,  6
  };
  const int q5955[] = {
    9, 9, // Number of jobs and machines
    6, 69, 5, 82, 8, 81, 2, 33, 1, 40, 4, 91, 0, 18, 7, 84, 3, 58, 
    6, 71, 1, 84, 5, 34, 8, 13, 3, 96, 7, 56, 2, 60, 0, 66, 4,  7, 
    4, 32, 8, 80, 5,  1, 0,  6, 2, 16, 1, 85, 7, 54, 6,  7, 3, 99, 
    1, 18, 8, 52, 2, 28, 5, 48, 4, 38, 7, 84, 3, 44, 6, 39, 0, 82, 
    1, 34, 6, 49, 3, 94, 4, 47, 8, 79, 0, 73, 2,  5, 5, 91, 7,  9, 
    3, 16, 7, 73, 0, 20, 6, 54, 8, 76, 5, 30, 2, 74, 1,  4, 4, 98, 
    7, 73, 6, 89, 4, 84, 8, 36, 0, 41, 3, 69, 1, 87, 5, 12, 2, 23, 
    5, 29, 2, 23, 8, 20, 6, 78, 0, 94, 3, 76, 1,  4, 4, 48, 7, 67, 
    5, 75, 6, 52, 2, 81, 3, 14, 8, 65, 0, 43, 7, 85, 4, 56, 1, 16
  };
  const int q5956[] = {
    9, 9, // Number of jobs and machines
    5, 32, 6, 16, 7, 64, 3,  2, 0, 88, 4, 68, 8, 63, 2, 64, 1, 44, 
    2, 82, 8, 13, 4, 51, 6, 89, 5, 19, 1, 85, 7, 54, 3, 18, 0, 47, 
    7, 58, 6, 50, 3, 94, 2, 29, 5, 84, 0, 30, 4, 31, 1, 13, 8, 59, 
    7, 10, 3, 48, 8, 15, 4, 88, 0, 74, 5, 65, 2, 63, 1, 45, 6, 51, 
    3, 32, 6, 92, 2, 70, 4, 37, 0,  7, 1, 34, 8, 98, 7, 28, 5,  2, 
    1, 61, 6, 62, 3,  7, 4, 29, 7, 32, 0, 58, 8, 87, 5, 16, 2, 10, 
    0, 24, 6,  9, 3, 48, 2,  6, 5, 37, 4, 61, 7, 77, 1, 46, 8, 15, 
    4, 12, 2, 62, 5, 27, 3, 20, 1, 53, 8, 88, 0, 43, 6, 98, 7, 92, 
    3, 43, 1, 72, 2, 95, 6, 68, 5, 75, 4,  7, 0, 32, 7, 57, 8, 89
  };
  const int q5957[] = {
    9, 9, // Number of jobs and machines
    0, 43, 3, 62, 4, 28, 2, 50, 6, 64, 1, 89, 5, 43, 7,  8, 8, 30, 
    7,  9, 2, 52, 8, 14, 3, 78, 4, 81, 1, 94, 6, 98, 0, 32, 5, 93, 
    3, 39, 0, 10, 2, 25, 5, 58, 7, 61, 8,  2, 6, 93, 1, 20, 4, 57, 
    1, 24, 5, 45, 2, 24, 7, 52, 8, 64, 6, 53, 0, 69, 3, 29, 4, 11, 
    6, 28, 8, 82, 1, 45, 7, 33, 0, 79, 3, 13, 4, 59, 5, 54, 2, 24, 
    5, 94, 2, 26, 3, 15, 8, 47, 0, 53, 6, 54, 4, 47, 7, 23, 1, 16, 
    6, 25, 8,  3, 1,  7, 0, 41, 4, 57, 5, 59, 3, 19, 2, 58, 7, 33, 
    3, 34, 0, 78, 8, 80, 2, 72, 6, 86, 4, 52, 5, 13, 7, 32, 1, 51, 
    3, 17, 5, 58, 6,  5, 4, 23, 2, 33, 1, 25, 8, 42, 7, 21, 0,  8
  };
  const int q5958[] = {
    9, 9, // Number of jobs and machines
    5, 30, 6,  5, 1, 57, 0, 12, 3, 32, 2, 27, 7, 27, 8, 52, 4, 75, 
    7, 88, 3, 51, 4, 23, 6,  6, 0,  5, 1, 43, 2, 96, 8, 68, 5, 94, 
    4, 23, 0, 38, 7, 48, 3, 18, 5, 73, 6, 41, 2, 73, 8, 72, 1, 97, 
    5, 91, 8, 21, 1, 67, 2, 67, 6, 43, 0, 10, 4, 55, 7, 22, 3, 91, 
    0, 17, 8, 11, 7, 53, 6, 32, 2, 10, 1,  9, 3, 65, 5, 61, 4, 11, 
    3, 54, 7, 48, 4, 32, 2, 46, 6, 43, 8, 29, 1,  2, 5, 46, 0, 49, 
    2, 74, 6, 29, 5, 63, 7, 79, 8, 18, 3, 25, 1, 68, 0, 56, 4, 13, 
    7, 93, 2, 81, 0, 89, 1,  5, 4,  1, 5, 40, 8, 39, 3,  5, 6, 49, 
    2,  2, 0, 53, 7, 33, 8, 59, 6, 89, 5, 56, 1,  5, 3, 86, 4, 66
  };
  const int q5959[] = {
    9, 9, // Number of jobs and machines
    8, 20, 5, 64, 7, 59, 4, 17, 0, 59, 3, 44, 2, 29, 1, 79, 6, 77, 
    1,  4, 7, 61, 8, 25, 2, 67, 5, 66, 0, 23, 4, 27, 3, 49, 6, 69, 
    7, 75, 5,  8, 3, 77, 8, 50, 4, 58, 0,  5, 6, 71, 2,  8, 1, 56, 
    5, 69, 2, 98, 3, 17, 1, 18, 7,  8, 0, 71, 4,  4, 6, 88, 8, 79, 
    5, 85, 4, 95, 0, 84, 7, 17, 8, 76, 2,  5, 6, 76, 1, 79, 3, 17, 
    5,  3, 0, 39, 1, 81, 6, 43, 2,  8, 7,  2, 4, 42, 3, 64, 8, 87, 
    6, 86, 2,  4, 0, 73, 7, 78, 5, 59, 8, 87, 4,  3, 3, 39, 1, 99, 
    3, 29, 6, 17, 8, 45, 0, 89, 7, 91, 1,  5, 2, 14, 5, 20, 4, 35, 
    7, 17, 6, 66, 2, 30, 0, 36, 8, 36, 3, 31, 4, 85, 5, 11, 1, 53
  };
  const int q5960[] = {
    9, 9, // Number of jobs and machines
    4, 33, 7, 12, 5, 83, 0, 32, 2, 48, 3, 81, 1, 31, 6, 48, 8,  2, 
    5, 12, 3, 54, 2, 60, 4, 21, 1, 56, 0, 81, 6, 43, 7, 79, 8, 57, 
    8, 71, 6, 93, 5, 77, 3, 24, 1, 21, 7, 52, 0, 63, 2,  8, 4, 19, 
    5, 89, 7, 31, 8, 47, 0, 19, 6, 73, 1, 95, 2, 27, 3, 24, 4, 17, 
    6, 29, 8, 70, 2, 32, 4, 98, 1, 41, 5,  6, 0, 48, 3,  3, 7, 80, 
    3, 68, 7, 26, 4, 36, 1, 14, 6, 20, 0, 30, 8, 46, 5, 86, 2, 77, 
    8, 19, 5, 59, 7, 44, 6, 44, 2, 31, 1, 78, 3, 59, 0, 22, 4, 13, 
    1, 65, 4, 91, 7, 48, 3, 83, 2, 52, 6, 78, 5, 30, 0, 42, 8, 95, 
    2, 21, 0, 26, 1, 59, 3, 65, 5, 32, 7, 85, 8, 19, 4, 25, 6, 27
  };
  const int q5961[] = {
    9, 9, // Number of jobs and machines
    6, 57, 8, 34, 5,  4, 1, 86, 4,  7, 7, 14, 3, 75, 2, 40, 0, 24, 
    0, 38, 8, 33, 1, 72, 2, 16, 3, 26, 7, 20, 5, 44, 6, 14, 4, 86, 
    2, 77, 4, 28, 6,  5, 0, 88, 1, 58, 5, 79, 7, 86, 3, 85, 8, 72, 
    5, 99, 2, 46, 1, 68, 8, 17, 4, 68, 0, 24, 3, 21, 7, 43, 6, 91, 
    4, 52, 3,  2, 0, 99, 6, 25, 2, 96, 7, 84, 5, 77, 8, 29, 1, 37, 
    0, 28, 3, 25, 8, 94, 7, 26, 1,  5, 6, 49, 5, 72, 4, 24, 2,  5, 
    2, 56, 7, 58, 4, 88, 0, 79, 5, 94, 3, 30, 8, 70, 1, 84, 6,  5, 
    3, 19, 7, 81, 2, 49, 8,  8, 1, 35, 0, 16, 4, 30, 6, 95, 5, 92, 
    8, 54, 2, 67, 6, 44, 0, 93, 4, 82, 1, 54, 5, 28, 3, 25, 7, 57
  };
  const int q5962[] = {
    9, 9, // Number of jobs and machines
    4, 47, 8,  5, 5, 55, 7, 19, 2, 52, 3,  6, 1, 99, 0, 77, 6, 45, 
    3, 48, 8, 38, 0, 27, 4, 91, 1, 78, 2, 49, 7, 37, 5, 98, 6, 53, 
    8, 68, 6, 47, 4, 20, 2, 97, 1, 86, 0, 46, 5, 29, 3, 83, 7, 56, 
    8, 93, 5, 29, 6, 42, 2, 48, 0, 93, 1, 44, 3, 17, 4, 53, 7, 59, 
    2, 96, 5, 48, 6, 66, 4, 62, 3, 15, 1, 80, 0, 56, 8, 85, 7, 49, 
    2, 55, 8, 75, 0,  8, 1, 66, 7, 26, 5, 92, 3, 88, 4, 39, 6, 82, 
    7, 41, 4, 41, 1,  5, 6, 54, 8, 85, 0, 98, 2,  2, 3, 96, 5, 56, 
    5, 22, 7, 67, 1,  9, 2, 22, 6, 50, 0, 49, 4, 69, 8, 66, 3, 70, 
    6, 12, 5, 71, 1,  1, 0, 26, 8, 85, 2, 48, 3, 21, 7, 49, 4, 66
  };
  const int q5963[] = {
    9, 9, // Number of jobs and machines
    0, 96, 6, 27, 4, 37, 2, 81, 7, 97, 3, 28, 8, 32, 1, 75, 5, 27, 
    0, 50, 4, 11, 7, 85, 6, 32, 8, 51, 1, 25, 2, 41, 5, 16, 3, 69, 
    7, 38, 3, 54, 4, 57, 1, 89, 0, 68, 6, 33, 5, 30, 8, 39, 2, 12, 
    4, 44, 6, 53, 5, 53, 0, 59, 8, 77, 1, 30, 7, 18, 3, 12, 2, 94, 
    5, 57, 2, 98, 0,  2, 1, 17, 8, 31, 3, 56, 7, 59, 4, 57, 6, 93, 
    0, 24, 8, 71, 2, 89, 3, 71, 7,  5, 4, 84, 6, 80, 5, 33, 1, 79, 
    4, 29, 5, 99, 6,  3, 1, 94, 3, 73, 8, 26, 7, 83, 0, 98, 2, 96, 
    7, 40, 6, 79, 1, 64, 4, 98, 2, 74, 3, 75, 0,  2, 8, 71, 5,  2, 
    6, 88, 8, 10, 3, 94, 0, 19, 1, 68, 5, 25, 4, 12, 7, 38, 2, 69
  };
  const int q5964[] = {
    9, 9, // Number of jobs and machines
    4, 97, 2, 31, 0, 90, 5, 10, 8, 79, 1, 62, 7, 62, 3, 89, 6, 88, 
    4, 62, 2, 23, 5, 48, 6, 58, 8, 45, 0, 37, 7,  1, 3, 65, 1, 64, 
    0,  1, 1, 88, 3, 24, 7, 46, 6, 56, 2, 26, 5, 68, 8, 87, 4, 96, 
    0, 48, 3, 40, 5, 20, 7, 42, 6, 45, 8, 41, 2, 69, 1, 92, 4, 98, 
    3, 66, 6, 14, 7, 35, 4,  1, 0, 89, 2, 86, 8,  7, 1, 36, 5, 68, 
    3,  7, 0,  7, 6, 58, 1, 43, 7, 68, 2, 56, 8, 65, 5, 74, 4, 63, 
    5, 48, 3, 91, 8, 62, 4, 95, 7, 68, 1, 23, 0, 23, 2, 88, 6, 10, 
    4, 75, 8, 64, 5,  7, 6, 84, 0, 74, 1, 88, 2, 78, 3, 11, 7, 43, 
    0, 84, 6, 79, 5,  4, 8, 79, 7, 72, 4, 54, 2, 78, 3, 35, 1, 22
  };
  const int q5965[] = {
    9, 9, // Number of jobs and machines
    4,  4, 5, 33, 2, 36, 0, 79, 1, 51, 6, 47, 8, 40, 7, 28, 3, 44, 
    7, 88, 0, 96, 6, 12, 2, 72, 4, 43, 1, 45, 8, 62, 5,  6, 3, 50, 
    4, 35, 3, 69, 1, 70, 5,  6, 7,  4, 8, 70, 6, 61, 0, 31, 2, 79, 
    2, 11, 5, 20, 0, 24, 1, 93, 8, 14, 6, 72, 4, 50, 7, 69, 3, 20, 
    1, 60, 5, 82, 0, 92, 6, 75, 4, 41, 3, 97, 2,  5, 8,  5, 7, 76, 
    3, 79, 2, 84, 7, 46, 5, 88, 8,  9, 0, 91, 6, 60, 4, 93, 1, 85, 
    2,  1, 4, 25, 5, 78, 7,  7, 3, 43, 6, 63, 8, 48, 0, 89, 1,  6, 
    1, 98, 8, 10, 3, 85, 6, 38, 4, 58, 2, 68, 0, 64, 5, 56, 7, 31, 
    7, 66, 0, 97, 1, 69, 8, 79, 2,  5, 6, 99, 4, 12, 5, 74, 3, 24
  };
  const int q5966[] = {
    9, 9, // Number of jobs and machines
    8, 28, 2, 28, 4,  1, 3, 38, 1, 64, 0, 54, 7, 35, 5, 56, 6, 45, 
    4, 99, 6,  6, 1, 15, 5, 71, 8, 89, 0, 31, 2, 51, 7, 18, 3,  7, 
    6, 20, 5, 86, 4,  7, 7, 75, 0, 81, 3, 66, 2, 84, 8, 90, 1, 90, 
    5, 76, 3, 97, 4, 58, 2, 80, 8,  2, 0, 91, 7, 99, 1, 69, 6, 60, 
    0, 34, 6, 66, 1, 93, 3, 19, 7, 88, 5, 31, 4, 83, 8, 46, 2, 88, 
    1, 84, 7, 29, 4,  1, 8, 89, 0, 98, 3, 64, 5, 92, 6, 84, 2, 80, 
    5, 62, 3, 73, 6, 46, 0, 46, 8,  1, 7, 73, 2, 39, 4, 51, 1, 42, 
    3, 13, 8, 88, 5, 86, 0,  2, 2, 51, 4, 91, 7, 21, 1, 19, 6, 81, 
    5, 61, 3, 75, 8, 20, 0, 59, 7, 44, 6,  8, 4, 47, 1, 54, 2,  5
  };
  const int q5967[] = {
    9, 9, // Number of jobs and machines
    4, 40, 2, 79, 3, 82, 6, 13, 0, 11, 1, 81, 7, 87, 5, 91, 8,  4, 
    8, 53, 3, 34, 7, 61, 2,  5, 4, 80, 5, 70, 6, 83, 1, 24, 0, 95, 
    4, 38, 8, 21, 5,  2, 6, 54, 1, 68, 7, 68, 3, 36, 2,  3, 0, 12, 
    5, 95, 4, 55, 1, 16, 2, 48, 7, 72, 3, 22, 8, 92, 0, 99, 6, 17, 
    2, 16, 7, 86, 6, 41, 0, 70, 1, 83, 8, 18, 3,  6, 4, 34, 5,  4, 
    5, 75, 3, 84, 1, 10, 7,  5, 2, 95, 4, 24, 6, 77, 8, 87, 0, 15, 
    6, 64, 8, 63, 5, 39, 3, 13, 0, 56, 4, 59, 1, 82, 2, 45, 7, 72, 
    8, 40, 2, 59, 3, 96, 4, 15, 6, 38, 7, 17, 1, 10, 0, 41, 5, 46, 
    8, 29, 5, 87, 7, 26, 1, 51, 2, 37, 4, 93, 3, 15, 6, 99, 0, 29
  };
  const int q5968[] = {
    9, 9, // Number of jobs and machines
    6, 76, 2, 43, 5,  3, 7, 93, 4, 55, 8, 64, 1, 85, 0, 54, 3, 30, 
    4, 19, 2, 44, 1, 76, 0, 10, 5, 13, 7, 53, 8,  8, 6, 67, 3, 20, 
    8, 13, 1, 38, 7, 35, 3, 24, 2, 73, 0, 96, 6, 39, 5, 84, 4, 30, 
    4, 74, 0, 35, 1, 70, 8, 14, 3, 80, 2, 45, 5, 32, 6, 55, 7, 44, 
    4, 80, 0, 80, 6, 70, 2, 57, 7, 10, 8, 84, 1, 23, 3, 11, 5, 17, 
    2, 11, 7, 38, 8, 60, 6, 68, 1, 67, 0, 87, 4, 83, 5, 40, 3, 59, 
    0, 77, 3, 48, 8, 57, 5, 41, 4, 89, 1, 34, 2,  4, 7, 44, 6, 52, 
    3, 27, 6, 79, 4, 94, 1, 26, 5, 72, 2, 91, 8, 63, 0, 90, 7, 49, 
    2, 96, 3, 74, 4, 29, 7, 21, 0, 19, 6, 67, 5,  5, 8, 81, 1, 20
  };
  const int q5969[] = {
    9, 9, // Number of jobs and machines
    3, 92, 2, 21, 1, 86, 8, 16, 0, 37, 4, 60, 6, 94, 7, 87, 5,  5, 
    2, 27, 1,  2, 3, 17, 7, 91, 6, 73, 0,  6, 4, 22, 5, 52, 8, 37, 
    4, 38, 8, 21, 3, 67, 1, 76, 5, 48, 0, 71, 2, 32, 6, 28, 7, 30, 
    2, 35, 1, 59, 0, 21, 8, 22, 6, 94, 3, 87, 4, 58, 5, 96, 7,  3, 
    1, 87, 6, 14, 3, 95, 8, 59, 0, 24, 5,  2, 4, 20, 7, 57, 2, 19, 
    0, 55, 7, 11, 6, 94, 1, 90, 5, 34, 2, 81, 3, 51, 4, 94, 8, 69, 
    2, 34, 0, 27, 4, 20, 7, 93, 3, 82, 8, 63, 1, 96, 5, 71, 6, 84, 
    5, 17, 7, 66, 3, 32, 4, 42, 2, 29, 6, 10, 8,  1, 1,  3, 0, 26, 
    1, 24, 5, 42, 4, 83, 8, 17, 7, 51, 6, 95, 2, 66, 0, 50, 3, 45
  };
  const int q5970[] = {
    9, 9, // Number of jobs and machines
    8, 44, 2, 57, 6, 42, 1, 58, 0,  6, 4, 43, 3, 59, 5, 80, 7, 11, 
    0, 10, 5, 23, 4, 67, 2, 57, 1, 44, 6, 17, 8, 70, 3, 26, 7,  3, 
    1, 41, 5, 48, 3, 11, 0, 76, 6, 36, 4, 97, 2, 28, 7, 75, 8,  3, 
    6, 81, 3, 22, 7, 33, 0, 14, 4, 15, 5, 93, 1, 35, 8, 70, 2, 80, 
    1, 90, 8, 14, 7, 35, 3, 71, 0,  8, 6, 41, 2, 20, 5,  8, 4, 40, 
    6, 75, 1, 50, 3, 23, 2, 29, 7, 78, 4, 88, 0, 63, 5, 29, 8, 12, 
    4, 97, 1, 63, 6, 17, 0, 33, 2, 92, 3, 79, 5, 29, 7, 86, 8, 41, 
    0, 14, 2, 82, 6, 54, 5, 20, 7, 73, 8, 12, 3, 20, 4, 48, 1, 97, 
    7, 71, 0, 76, 4, 73, 5, 89, 8, 64, 3, 66, 2, 37, 6, 29, 1, 49
  };
  const int q5971[] = {
    9, 9, // Number of jobs and machines
    6, 85, 7, 43, 5, 42, 1, 28, 2, 15, 8, 74, 0, 29, 3, 88, 4, 32, 
    8, 69, 6, 69, 3, 92, 1, 45, 2, 93, 0, 45, 5, 71, 4, 98, 7, 11, 
    6, 41, 5, 19, 4,  5, 1, 12, 8, 16, 7, 89, 2,  2, 0, 32, 3, 14, 
    7, 46, 8, 85, 0, 81, 3, 24, 4, 63, 1, 50, 5, 41, 6, 31, 2, 68, 
    2, 96, 0, 80, 4, 60, 3, 84, 1, 25, 7, 33, 6, 61, 5, 40, 8, 93, 
    2, 37, 4, 38, 3, 33, 7, 10, 8,  1, 5, 46, 6, 32, 1, 84, 0, 11, 
    4, 46, 2, 35, 3, 54, 5, 23, 0,  6, 8, 54, 6, 78, 1, 78, 7, 20, 
    1, 96, 6, 75, 5, 62, 3, 70, 0, 62, 4, 30, 7, 49, 8,  3, 2,  7, 
    2, 69, 0, 94, 1, 10, 5, 80, 7, 32, 6, 32, 3, 70, 4, 36, 8, 19
  };
  const int q5972[] = {
    9, 9, // Number of jobs and machines
    2,  4, 1, 50, 6, 21, 0, 24, 3, 10, 7, 88, 4, 26, 5, 35, 8, 22, 
    0, 30, 3, 75, 4, 33, 2, 74, 7, 18, 5, 86, 6, 74, 8, 71, 1, 94, 
    5, 76, 6, 12, 1, 36, 3,  3, 8, 52, 0, 85, 2, 52, 4, 10, 7, 75, 
    1, 30, 4, 95, 8, 76, 5, 90, 2,  6, 6, 39, 0, 71, 3, 25, 7, 64, 
    7, 15, 2, 45, 0, 98, 1, 29, 5, 95, 3, 10, 8, 62, 6, 42, 4, 40, 
    7, 13, 4, 91, 2, 73, 3, 55, 6, 37, 1, 53, 8, 91, 0, 17, 5,  5, 
    3, 86, 6, 23, 5, 46, 4, 59, 0, 51, 2, 43, 7, 20, 1, 82, 8,  1, 
    4, 81, 1, 70, 2, 62, 6, 82, 7, 34, 8, 59, 0, 42, 3, 22, 5, 62, 
    3, 80, 1, 22, 7, 60, 8, 37, 5, 86, 4, 63, 6, 14, 2, 64, 0, 52
  };
  const int q5973[] = {
    9, 9, // Number of jobs and machines
    7, 74, 1, 82, 2, 83, 6, 25, 0, 11, 5,  2, 8, 59, 4, 33, 3, 22, 
    4, 23, 3, 34, 0, 77, 7, 56, 2, 66, 6, 66, 1,  3, 5, 54, 8, 87, 
    1,  9, 3, 67, 8, 44, 7, 40, 0, 97, 2, 92, 5,  7, 6, 47, 4,  8, 
    4, 93, 2, 44, 6,  6, 0, 17, 5, 36, 1, 37, 7, 95, 8, 24, 3, 44, 
    8, 40, 5, 82, 4, 78, 0, 64, 3, 15, 2, 65, 6,  1, 7, 90, 1, 61, 
    5, 34, 0, 70, 6, 80, 4, 15, 7, 90, 3, 82, 8, 73, 1, 60, 2, 24, 
    0,  9, 8, 37, 5, 68, 2, 59, 6, 47, 4, 63, 1, 40, 7, 51, 3, 65, 
    7, 34, 8,  3, 3, 44, 4, 95, 5, 74, 6, 57, 2, 86, 0, 84, 1, 69, 
    3, 18, 2, 70, 4, 21, 0, 62, 8, 90, 5, 46, 7,  1, 6, 36, 1, 69
  };
  const int q5974[] = {
    9, 9, // Number of jobs and machines
    4, 17, 1, 59, 2, 20, 6, 20, 3, 39, 5, 82, 7, 30, 0, 14, 8, 79, 
    2, 71, 7, 68, 3, 75, 8, 53, 4, 86, 5, 76, 0, 80, 6, 14, 1, 63, 
    3, 67, 1, 42, 5, 77, 2, 70, 6, 28, 8,  3, 4, 52, 0, 15, 7, 67, 
    2, 43, 6, 59, 7, 78, 3, 98, 4, 88, 8, 45, 1, 69, 5, 51, 0, 51, 
    0, 37, 8, 33, 2, 41, 6, 40, 5, 62, 7, 81, 4, 59, 1,  2, 3, 43, 
    3, 83, 7, 24, 6, 17, 1, 48, 2, 30, 8, 77, 0, 47, 5, 39, 4, 63, 
    1, 53, 3, 83, 4, 51, 6, 85, 2, 84, 0,  9, 7, 39, 5, 97, 8, 78, 
    3, 33, 7, 50, 8, 49, 0, 46, 2, 94, 4, 23, 1, 30, 6, 36, 5, 74, 
    6, 17, 8,  1, 7, 84, 1, 79, 5, 32, 2, 53, 3, 63, 4, 59, 0, 70
  };
  const int q5975[] = {
    9, 9, // Number of jobs and machines
    3, 13, 6, 80, 0, 93, 8, 75, 2, 87, 1, 10, 5, 25, 7, 55, 4, 37, 
    1, 21, 3, 20, 0, 30, 6, 86, 8, 86, 2, 65, 4, 13, 5, 25, 7, 26, 
    5, 25, 6, 17, 1, 23, 4, 97, 7, 52, 0, 75, 8, 25, 2, 59, 3, 30, 
    5, 96, 6, 66, 4, 39, 7, 22, 8, 34, 2, 10, 1, 10, 0, 72, 3, 10, 
    2, 48, 8, 87, 4, 33, 1,  5, 0, 10, 7, 41, 6, 18, 5, 92, 3, 80, 
    6, 35, 5, 93, 7, 88, 4, 60, 2, 32, 0, 94, 8, 52, 3, 93, 1,  6, 
    7, 79, 8, 25, 0,  9, 5, 37, 6, 36, 4, 56, 1, 99, 3, 64, 2, 56, 
    8, 78, 0, 17, 3, 49, 7, 99, 2, 42, 6, 91, 4, 36, 1, 28, 5, 46, 
    6, 37, 7, 73, 2, 57, 0, 68, 1, 90, 4,  5, 8, 49, 3,  3, 5, 22
  };
  const int q5976[] = {
    9, 9, // Number of jobs and machines
    4, 55, 1, 70, 8, 92, 3, 84, 2, 42, 5, 52, 6, 93, 7, 75, 0, 50, 
    6, 87, 1, 97, 5, 97, 7, 93, 0, 14, 4, 32, 8,  8, 3, 84, 2, 82, 
    6, 97, 4, 64, 1, 65, 0, 83, 7, 61, 5, 39, 3, 51, 8, 52, 2, 17, 
    8, 59, 2, 80, 1, 66, 7,  5, 3, 47, 5, 56, 4, 10, 0, 42, 6,  9, 
    6, 74, 5, 73, 0, 54, 4, 32, 1, 37, 8, 69, 2, 17, 7, 13, 3, 58, 
    0, 72, 2, 41, 7, 43, 1, 85, 6, 95, 4, 31, 8, 14, 5, 61, 3, 47, 
    4, 75, 5, 24, 6,  7, 2, 61, 3, 36, 8,  7, 1, 67, 7,  3, 0, 33, 
    7, 27, 2, 63, 1, 52, 8, 75, 0, 62, 4, 84, 6,  8, 3, 92, 5, 61, 
    4, 96, 6, 20, 2, 23, 3, 98, 1, 50, 0, 78, 8,  7, 7, 77, 5, 63
  };
  const int q5977[] = {
    9, 9, // Number of jobs and machines
    8, 13, 1, 42, 5, 42, 2, 39, 0, 71, 6, 11, 7, 65, 4, 16, 3, 39, 
    3, 19, 7, 78, 1, 19, 5, 17, 2, 54, 6, 41, 0, 75, 8, 32, 4, 82, 
    3, 57, 0, 27, 5, 93, 2, 78, 7, 37, 8, 66, 6,  9, 1, 55, 4, 40, 
    8,  1, 7, 15, 5, 18, 6, 50, 2, 41, 1, 54, 3, 42, 0, 33, 4, 76, 
    0, 15, 4, 13, 8, 94, 5, 45, 2, 99, 6, 54, 1, 39, 3, 87, 7, 87, 
    4, 60, 8, 13, 3,  9, 0, 19, 5, 99, 6, 78, 7,  8, 1,  3, 2, 58, 
    5, 65, 0, 52, 8,  2, 1, 50, 2, 41, 6, 33, 3, 65, 7, 99, 4,  9, 
    2, 31, 7, 28, 4, 46, 0, 10, 3, 64, 8, 99, 6, 56, 1, 63, 5, 87, 
    4, 44, 1, 88, 0, 36, 6, 66, 5, 77, 3, 38, 8,  4, 2, 85, 7,  3
  };
  const int q5978[] = {
    9, 9, // Number of jobs and machines
    4,  9, 1, 50, 3, 78, 0, 88, 8, 99, 2,  2, 5, 84, 7, 19, 6, 58, 
    7, 48, 2, 91, 3, 44, 4, 74, 0, 11, 8, 44, 6, 95, 5, 26, 1, 11, 
    8, 73, 3, 37, 6, 67, 2, 90, 0, 79, 4, 22, 1, 65, 7, 17, 5, 37, 
    8,  1, 3, 40, 2, 97, 4, 13, 6, 18, 5, 51, 1, 12, 7,  9, 0, 18, 
    4, 94, 7,  8, 2, 32, 5, 90, 8, 32, 6, 74, 3, 93, 0, 52, 1, 53, 
    1, 83, 3, 98, 7, 31, 8, 24, 6, 66, 4, 65, 2, 41, 5,  2, 0,  4, 
    2, 55, 0, 42, 3, 48, 1, 68, 7, 83, 4, 23, 6, 76, 5, 78, 8, 74, 
    6, 73, 1, 70, 7, 40, 4, 91, 5, 65, 0, 26, 3, 76, 2, 93, 8, 15, 
    6, 35, 2, 85, 7, 93, 0, 28, 5, 42, 1, 94, 4,  3, 8, 92, 3, 57
  };
  const int q5979[] = {
    9, 9, // Number of jobs and machines
    2, 17, 0, 93, 8, 43, 7, 36, 5, 66, 4,  3, 6,  9, 1, 91, 3, 66, 
    8, 19, 2, 76, 4, 94, 0, 38, 7, 95, 3, 85, 1,  5, 6, 17, 5, 31, 
    5, 95, 2, 12, 1, 73, 6, 53, 7, 56, 4, 94, 0, 75, 3, 87, 8, 97, 
    8, 60, 3, 42, 5, 71, 2, 47, 7, 22, 1, 36, 6, 21, 4, 35, 0,  6, 
    5, 56, 2, 13, 7, 37, 4, 48, 8, 26, 1, 33, 6, 83, 3, 44, 0, 80, 
    4, 65, 8, 46, 7, 92, 6, 86, 3, 93, 2, 96, 0, 40, 1,  1, 5, 27, 
    5, 77, 1, 43, 2, 72, 8,  1, 4, 21, 3, 73, 6, 42, 7, 62, 0, 29, 
    0, 56, 4, 80, 7, 69, 5, 56, 3, 50, 6, 53, 8, 78, 2, 61, 1, 68, 
    5, 51, 0, 20, 6, 92, 1, 93, 8, 93, 2, 36, 4, 83, 3,  4, 7, 16
  };
  const int q5980[] = {
    9, 9, // Number of jobs and machines
    7, 87, 0, 26, 5, 76, 4, 73, 2, 85, 3, 39, 1, 88, 6, 13, 8, 66, 
    8, 65, 7, 28, 3, 17, 6, 73, 5, 44, 1, 13, 0, 38, 2, 61, 4,  7, 
    3, 41, 1, 76, 8, 82, 7, 59, 0, 15, 2, 86, 4, 77, 5, 26, 6, 60, 
    2, 69, 8, 91, 4,  8, 0, 87, 1, 62, 3, 59, 6, 22, 5, 19, 7, 17, 
    0, 47, 5, 19, 6, 63, 8, 66, 3,  9, 7, 20, 4, 81, 1, 19, 2, 45, 
    7, 67, 2, 51, 3, 48, 5, 66, 0, 72, 8, 61, 4, 53, 6, 86, 1, 54, 
    7, 83, 2, 47, 8, 90, 0, 94, 3, 47, 1,  3, 5, 53, 6, 58, 4, 49, 
    6, 46, 1, 94, 7, 50, 4, 91, 8,  8, 0, 27, 2, 51, 5, 18, 3, 67, 
    6, 45, 7, 96, 5, 86, 3, 70, 2, 95, 8, 22, 1, 74, 0, 62, 4, 15
  };
  const int q5981[] = {
    9, 9, // Number of jobs and machines
    8, 35, 3, 36, 6,  5, 7, 86, 5, 39, 2, 52, 0, 13, 1, 27, 4, 98, 
    3, 17, 0, 57, 2, 72, 6, 27, 4, 66, 8, 51, 5, 63, 7, 82, 1, 45, 
    7, 56, 1, 39, 8, 48, 5, 93, 2, 57, 0, 68, 6, 39, 4, 92, 3,  8, 
    7, 69, 8, 49, 6, 57, 4, 32, 0,  6, 2, 87, 3, 63, 5, 54, 1, 28, 
    5, 73, 1, 52, 6, 12, 0,  8, 2, 31, 4, 43, 8, 15, 7, 95, 3, 48, 
    3, 37, 2, 32, 7, 51, 0, 71, 5, 59, 1, 57, 4, 46, 6, 63, 8, 47, 
    2, 85, 6, 39, 1, 67, 4, 31, 3, 68, 8, 14, 0,  8, 5, 76, 7,  1, 
    0, 97, 4, 60, 6, 89, 3, 71, 7, 19, 2, 41, 5, 37, 1, 43, 8, 42, 
    2, 82, 1,  8, 5,  6, 4, 98, 8, 96, 6, 16, 3, 27, 0,  7, 7,  7
  };
  const int q5982[] = {
    9, 9, // Number of jobs and machines
    3, 75, 5, 74, 8,  2, 1, 43, 0, 39, 2, 60, 7, 52, 6, 74, 4, 60, 
    0, 66, 6,  2, 4, 74, 3, 25, 8, 64, 2, 85, 5, 43, 7, 68, 1, 14, 
    4, 30, 8, 41, 7, 16, 5, 54, 1, 78, 6, 71, 0, 65, 3, 46, 2, 37, 
    1, 57, 6, 77, 8, 32, 3, 53, 0, 68, 5, 41, 2, 48, 7, 68, 4, 52, 
    2, 59, 5, 46, 3, 93, 6, 48, 8, 24, 7, 53, 1, 76, 0, 54, 4, 92, 
    0, 33, 8, 95, 6, 10, 1, 51, 3,  4, 5, 96, 4, 80, 2, 75, 7, 98, 
    7, 85, 1, 79, 5, 59, 2, 94, 8, 95, 6, 88, 0, 59, 4, 97, 3, 21, 
    1, 37, 0, 52, 6, 86, 2,  1, 3, 43, 4, 47, 8,  2, 5, 97, 7, 57, 
    7, 91, 3, 97, 8, 22, 5, 57, 4, 73, 1, 75, 0,  2, 2, 70, 6, 42
  };
  const int q5983[] = {
    9, 9, // Number of jobs and machines
    4,  7, 1,  4, 3, 51, 7, 37, 5, 73, 8, 70, 6, 40, 2, 10, 0, 73, 
    7, 47, 5, 13, 2, 21, 8, 17, 3, 76, 1, 96, 4, 75, 6, 60, 0, 60, 
    7, 18, 8, 59, 4, 24, 5, 55, 6, 25, 1,  5, 3, 76, 2, 27, 0,  9, 
    6, 21, 2, 96, 0, 34, 5, 63, 1, 80, 4, 71, 7, 84, 3, 73, 8, 69, 
    7, 21, 5, 86, 6, 60, 8, 89, 1, 91, 3, 64, 4, 18, 2, 82, 0, 24, 
    1, 71, 5, 63, 0, 10, 7, 79, 4, 81, 8, 35, 2, 61, 6, 94, 3, 74, 
    5, 56, 0,  2, 8, 20, 3, 48, 2, 33, 6, 72, 1, 10, 4, 74, 7, 63, 
    0, 56, 7, 18, 2, 44, 1, 15, 6, 17, 4,  3, 3, 26, 8, 99, 5, 55, 
    3, 97, 6, 86, 8, 19, 0, 68, 4, 32, 5, 56, 7, 55, 2, 94, 1, 23
  };
  const int q5984[] = {
    9, 9, // Number of jobs and machines
    3, 79, 6,  2, 2, 38, 8, 41, 1, 29, 5, 98, 7, 99, 4, 74, 0, 65, 
    4, 79, 2, 91, 6, 28, 7, 73, 0, 79, 1, 90, 5,  9, 8, 92, 3, 48, 
    2, 80, 7, 52, 4, 88, 3, 54, 0, 30, 1, 93, 8,  3, 5, 19, 6, 89, 
    1, 32, 0, 35, 3, 40, 5, 13, 7, 94, 4, 25, 6, 29, 8, 49, 2, 98, 
    5, 36, 8, 37, 7, 48, 0, 78, 3, 53, 2, 89, 4, 17, 6, 19, 1, 44, 
    3, 76, 8, 51, 5, 39, 6, 36, 4, 19, 7, 79, 0, 14, 2,  2, 1, 68, 
    8, 29, 0, 75, 1, 88, 6, 72, 3, 18, 2, 66, 7, 63, 5, 21, 4, 68, 
    5, 88, 2,  6, 3, 92, 6, 36, 1, 44, 4, 40, 8, 93, 7, 88, 0, 88, 
    0, 58, 6, 65, 8,  7, 4, 37, 1, 38, 2, 75, 3, 81, 7,  3, 5, 85
  };
  const int q5985[] = {
    9, 9, // Number of jobs and machines
    7, 38, 6, 42, 3, 30, 5, 96, 1, 12, 0, 51, 2, 12, 8, 78, 4,  8, 
    6, 99, 7, 23, 4, 25, 8, 55, 1, 99, 3, 42, 0, 46, 2, 87, 5, 64, 
    7, 33, 4,  2, 2,  5, 1, 26, 8, 46, 0,  6, 5, 41, 6, 12, 3, 31, 
    0, 94, 8, 79, 6, 32, 2, 20, 5,  4, 3, 51, 1,  1, 4, 51, 7, 31, 
    5, 90, 0, 64, 1, 69, 2, 39, 3, 43, 7, 14, 4, 18, 8, 63, 6, 18, 
    2,  5, 5, 55, 7, 37, 0, 68, 3, 95, 8, 34, 6, 37, 4,  8, 1, 28, 
    7, 70, 3, 53, 0, 85, 4, 14, 8, 62, 6, 41, 1, 73, 2, 38, 5, 59, 
    0, 25, 2, 72, 1,  2, 4, 98, 8, 92, 6, 50, 7, 61, 5, 23, 3, 56, 
    3, 85, 4, 19, 8, 15, 2, 86, 6, 15, 5,  3, 7, 98, 1, 67, 0, 26
  };
  const int q5986[] = {
    9, 9, // Number of jobs and machines
    4, 63, 2, 84, 7, 68, 0, 86, 3, 47, 5, 80, 8, 81, 6, 75, 1, 10, 
    5, 78, 0, 23, 1, 48, 7, 46, 3, 38, 2, 24, 6, 67, 8, 93, 4, 43, 
    8, 95, 0, 55, 4, 98, 2, 19, 7, 88, 6, 21, 5, 83, 1, 42, 3,  3, 
    2, 59, 4, 69, 6, 29, 1, 56, 0, 61, 5, 52, 8, 48, 3, 31, 7, 29, 
    5, 15, 7, 52, 8, 26, 1, 14, 2, 15, 3, 94, 6, 39, 4, 88, 0, 62, 
    6, 81, 1, 13, 0, 51, 7, 89, 8,  1, 5, 52, 3, 90, 2, 83, 4, 24, 
    8, 48, 4, 82, 5, 65, 2, 51, 6, 54, 0, 65, 7, 48, 3, 33, 1, 97, 
    4, 86, 2, 66, 6, 22, 7, 98, 8, 78, 5, 41, 3, 84, 0, 16, 1, 95, 
    4, 88, 6, 58, 3, 44, 2, 67, 1, 91, 0, 96, 5, 75, 7, 71, 8, 57
  };
  const int q5987[] = {
    9, 9, // Number of jobs and machines
    0, 58, 3, 48, 7, 71, 4, 72, 1, 58, 8, 37, 6,  6, 2, 17, 5, 59, 
    5, 98, 7, 45, 2, 86, 1, 68, 3, 51, 4, 33, 8, 82, 6, 48, 0,  1, 
    4, 73, 1, 83, 8, 15, 0, 62, 5, 96, 2, 30, 3, 78, 6,  9, 7, 34, 
    1, 12, 6, 34, 8, 94, 5, 52, 7, 81, 3,  7, 4,  3, 0, 67, 2, 10, 
    6, 41, 8, 64, 3, 33, 1, 31, 5, 98, 7, 18, 4, 83, 0, 27, 2, 12, 
    5, 17, 0, 70, 3, 61, 8, 67, 6, 77, 4, 79, 7, 52, 2, 51, 1, 96, 
    6, 82, 3, 60, 2,  9, 8, 31, 4, 59, 7, 85, 5, 31, 0, 51, 1, 67, 
    8, 71, 0, 10, 4, 22, 7, 10, 3, 26, 5, 71, 1, 36, 6,  3, 2, 36, 
    6, 30, 8,  2, 0, 10, 4, 76, 7,  6, 2, 56, 1, 72, 3, 63, 5, 61
  };
  const int q5988[] = {
    9, 9, // Number of jobs and machines
    5, 62, 8,  1, 6, 58, 1,  6, 4, 92, 3, 37, 7, 97, 2,  7, 0, 19, 
    1,  9, 6, 59, 3, 98, 2,  1, 4, 64, 0,  3, 7, 95, 5, 28, 8, 68, 
    2, 15, 5, 21, 0, 68, 8, 91, 1, 11, 4, 75, 7, 50, 3, 42, 6, 20, 
    4, 92, 7, 24, 3, 95, 0, 78, 5, 31, 2, 58, 8, 80, 6, 28, 1, 68, 
    3, 95, 4,  8, 5, 75, 6, 35, 8, 79, 1, 35, 7, 77, 0, 31, 2, 24, 
    6, 39, 1, 99, 0, 19, 8, 73, 4, 31, 2, 24, 5, 25, 7, 76, 3, 99, 
    2, 92, 1, 91, 5, 69, 3, 63, 7, 39, 0, 55, 6, 97, 4, 47, 8, 36, 
    4, 40, 6, 38, 3,  5, 1, 26, 7, 90, 5, 10, 2, 79, 0, 59, 8, 31, 
    4, 53, 6, 59, 7, 39, 2, 93, 1, 23, 5, 16, 8, 72, 3, 73, 0, 28
  };
  const int q5989[] = {
    9, 9, // Number of jobs and machines
    2, 44, 5, 79, 8, 17, 7, 25, 0, 84, 3, 32, 1, 72, 6, 72, 4, 19, 
    0, 68, 5, 60, 6, 42, 7, 50, 3, 38, 8, 99, 4, 94, 2, 29, 1, 41, 
    0, 11, 8, 79, 1, 45, 3, 90, 4, 71, 7, 81, 5, 52, 2,  9, 6, 85, 
    5, 87, 2, 17, 1, 83, 6, 34, 4, 71, 3, 71, 0, 18, 7, 34, 8,  5, 
    4, 34, 2, 15, 5, 13, 0, 66, 6, 58, 1, 59, 8, 86, 7,  6, 3,  3, 
    7, 14, 2, 90, 6, 25, 5, 87, 3, 19, 1, 47, 8,  2, 4, 63, 0,  7, 
    7,  6, 8, 27, 3, 35, 1, 95, 6, 89, 5, 12, 2, 76, 0, 27, 4, 20, 
    5, 73, 6, 12, 2, 23, 7, 34, 8,  4, 1, 39, 4, 49, 3, 56, 0, 70, 
    1,  3, 8, 37, 0, 89, 4, 13, 3, 80, 6, 50, 5, 36, 2, 64, 7, 82
  };
  const int q5990[] = {
    9, 9, // Number of jobs and machines
    1, 48, 8, 80, 5, 82, 3, 76, 6, 34, 0, 52, 4, 10, 2,  2, 7, 21, 
    5, 57, 4,  2, 7, 77, 2, 73, 8, 38, 1, 81, 6, 98, 3, 88, 0, 14, 
    8, 78, 3, 50, 4, 71, 1, 76, 7, 23, 5, 85, 6, 56, 0, 99, 2, 32, 
    0, 51, 8, 38, 5, 90, 3, 34, 2, 94, 4, 27, 6, 46, 7, 14, 1, 41, 
    1, 61, 0, 32, 4, 40, 8, 99, 3, 11, 5, 41, 6, 65, 7, 47, 2, 41, 
    7, 62, 1, 79, 4, 55, 0, 92, 6, 17, 3, 78, 8, 83, 5, 91, 2, 64, 
    3, 44, 4, 82, 2, 45, 0, 91, 5, 32, 6, 56, 7,  1, 8, 43, 1, 20, 
    8, 85, 0, 59, 7,  6, 5,  3, 1,  6, 4, 83, 3, 89, 2, 64, 6, 36, 
    1, 86, 7, 68, 5, 94, 2, 53, 6, 88, 4, 34, 0, 48, 8, 90, 3, 54
  };
  const int q5991[] = {
    9, 9, // Number of jobs and machines
    5, 40, 3, 62, 2, 51, 7, 73, 6,  4, 1, 24, 8, 50, 0, 40, 4, 58, 
    3, 90, 6,  3, 7, 74, 0, 69, 1, 88, 8, 80, 5, 10, 4, 12, 2, 17, 
    0, 45, 8, 28, 2, 31, 3, 42, 6, 77, 7, 22, 4, 57, 5, 31, 1, 12, 
    3, 15, 8, 98, 7, 34, 4, 55, 2, 19, 6, 15, 0, 62, 1, 65, 5, 21, 
    2, 56, 1,  4, 7, 94, 4,  8, 8, 70, 6, 75, 3,  3, 0, 95, 5, 73, 
    2, 23, 4, 76, 7, 31, 1, 19, 8, 44, 0, 58, 5, 15, 3, 54, 6, 30, 
    7, 46, 1,  4, 4,  7, 6, 36, 2, 13, 0, 69, 5, 33, 8, 30, 3, 75, 
    1, 61, 0,  1, 3, 40, 4, 52, 6, 34, 5, 97, 2, 93, 7, 61, 8, 14, 
    5, 48, 6, 19, 3, 92, 1, 44, 0, 57, 8, 94, 2, 95, 4, 50, 7, 62
  };
  const int q5992[] = {
    9, 9, // Number of jobs and machines
    6,  6, 7, 27, 3,  7, 4, 55, 1, 95, 0, 23, 8, 30, 2, 60, 5, 91, 
    2, 31, 5, 33, 8, 95, 6, 58, 7, 56, 3, 16, 0, 33, 1, 79, 4, 67, 
    7, 66, 4, 10, 2, 90, 3, 95, 6, 38, 8,  4, 5, 59, 1, 84, 0, 21, 
    2, 53, 4, 52, 7, 79, 0, 37, 1, 54, 8, 36, 5, 87, 6, 85, 3, 69, 
    2, 83, 8, 93, 0, 55, 7, 43, 3, 90, 1, 69, 4, 28, 5, 43, 6, 74, 
    2, 34, 0,  3, 7, 95, 4, 20, 3, 17, 6, 93, 1, 67, 5, 64, 8, 85, 
    2, 58, 0, 16, 4,  9, 3, 53, 6, 45, 7, 82, 8, 85, 5, 26, 1, 10, 
    3, 20, 8, 37, 0, 46, 7, 44, 5, 59, 6, 52, 1, 83, 2, 25, 4, 64, 
    5, 45, 4, 86, 3, 98, 1, 72, 7, 94, 8, 30, 6, 38, 2, 27, 0, 32
  };
  const int q5993[] = {
    9, 9, // Number of jobs and machines
    3, 98, 1, 67, 8, 44, 6, 48, 5, 46, 2, 14, 7, 55, 4, 82, 0, 47, 
    2, 20, 1, 24, 8, 12, 7, 44, 6, 39, 3, 74, 0, 17, 4, 11, 5, 33, 
    4, 80, 1, 53, 7, 75, 8, 35, 6, 30, 5, 61, 3, 39, 0, 65, 2, 71, 
    3, 61, 0, 86, 8, 74, 1, 11, 7, 91, 2, 90, 4, 92, 6, 62, 5, 81, 
    4, 72, 6, 16, 2, 41, 5, 12, 1, 42, 0, 12, 3, 36, 7, 65, 8, 94, 
    7, 54, 6, 93, 3, 73, 1,  1, 2, 17, 8,  2, 4, 23, 0, 17, 5, 78, 
    6, 95, 4, 10, 0, 29, 1, 14, 5, 19, 2, 89, 7, 63, 8, 13, 3, 69, 
    0, 39, 3, 54, 2, 25, 5, 89, 8, 63, 4, 39, 6, 10, 7, 59, 1, 70, 
    2, 31, 3, 26, 6, 27, 0,  4, 5,  4, 8, 82, 4, 34, 1, 36, 7, 21
  };
  const int q5994[] = {
    9, 9, // Number of jobs and machines
    7, 27, 6, 45, 8, 35, 2,  5, 0, 89, 1, 82, 3, 55, 4, 72, 5, 61, 
    2, 69, 4, 42, 6, 62, 8, 20, 1, 20, 0, 38, 7, 68, 3, 96, 5, 60, 
    8, 10, 2,  5, 0, 39, 5, 23, 1, 14, 6, 50, 4, 50, 3, 82, 7, 25, 
    3, 59, 6, 44, 5, 89, 7, 93, 4, 11, 8, 44, 0, 80, 1, 17, 2, 37, 
    3, 44, 2, 58, 1, 16, 5, 85, 6, 95, 8, 28, 7, 80, 0, 64, 4, 11, 
    1, 93, 3, 62, 2, 60, 7, 51, 4, 89, 8, 11, 0, 99, 6, 40, 5, 31, 
    2, 10, 3, 23, 0, 10, 5, 18, 7, 92, 4, 79, 8, 87, 1, 20, 6, 13, 
    8, 60, 3, 76, 1, 10, 7, 41, 5, 91, 2, 18, 4,  8, 6, 48, 0, 65, 
    8, 76, 5, 34, 4, 26, 3, 25, 6, 93, 2, 45, 7, 93, 1, 19, 0, 17
  };
  const int q5995[] = {
    9, 9, // Number of jobs and machines
    3, 26, 1, 94, 5, 80, 6, 28, 4, 40, 7, 59, 8, 45, 0, 37, 2, 21, 
    1, 18, 7, 76, 0, 66, 2, 51, 6, 56, 5,  9, 3, 53, 4, 88, 8, 80, 
    8, 21, 1, 45, 2,  4, 3, 89, 7, 46, 5,  4, 0, 95, 6, 56, 4, 54, 
    8, 60, 1, 78, 2, 77, 5, 96, 6, 19, 3, 21, 0, 52, 4, 60, 7, 58, 
    6, 89, 7, 99, 3, 78, 1,  5, 5, 16, 4, 41, 2, 51, 0, 78, 8, 98, 
    1, 22, 3, 83, 7, 82, 4, 12, 2, 42, 5, 15, 8, 29, 6,  9, 0,  7, 
    3, 56, 1,  9, 6, 28, 8, 61, 2, 52, 7, 27, 4, 24, 0, 96, 5, 54, 
    2, 45, 8, 72, 6, 48, 5, 16, 1, 72, 0, 57, 3, 55, 4, 95, 7, 28, 
    6, 53, 4, 64, 8, 83, 5, 10, 2, 81, 0, 19, 3, 81, 1, 83, 7, 31
  };
  const int q5996[] = {
    9, 9, // Number of jobs and machines
    4, 54, 1, 39, 3, 27, 8, 45, 2,  2, 5, 28, 6, 89, 7, 12, 0, 41, 
    6,  8, 4, 37, 5, 32, 0, 35, 1, 68, 3, 18, 2,  6, 7, 94, 8, 23, 
    0, 16, 4, 89, 1, 13, 2, 34, 7, 44, 8, 68, 6, 35, 5, 45, 3, 45, 
    7, 77, 2, 54, 1, 70, 5, 80, 4, 62, 6, 27, 0, 53, 8, 32, 3, 42, 
    3, 85, 7, 35, 8, 66, 2, 99, 1, 73, 0, 46, 4, 64, 5, 89, 6, 37, 
    3, 14, 5, 59, 2, 62, 6, 91, 4, 93, 8, 39, 7, 63, 1, 49, 0, 87, 
    0, 95, 4, 99, 8, 30, 5, 19, 3, 25, 1, 91, 2, 75, 6,  1, 7, 67, 
    0, 29, 3, 24, 6, 69, 8, 22, 5, 81, 1, 12, 7, 71, 2, 16, 4, 91, 
    8, 51, 4, 12, 7, 43, 1,  9, 3, 97, 0,  8, 5, 76, 2, 76, 6, 47
  };
  const int q5997[] = {
    9, 9, // Number of jobs and machines
    5, 81, 0, 84, 2, 13, 7, 85, 8, 90, 4, 91, 6, 42, 3, 27, 1, 97, 
    2, 53, 6, 82, 7,  4, 8, 59, 3, 43, 5, 87, 1, 10, 4, 59, 0, 46, 
    0,  6, 6, 27, 2, 94, 8, 60, 5, 58, 1, 61, 4, 35, 3, 77, 7, 10, 
    3, 27, 0, 60, 1, 10, 6, 30, 7, 12, 8, 31, 5, 58, 4, 61, 2,  1, 
    1, 17, 4, 33, 2,  2, 3, 93, 6, 66, 5, 89, 7,  3, 8, 49, 0, 45, 
    0,  8, 1,  7, 7, 14, 2, 78, 8, 37, 4, 56, 6, 74, 3, 36, 5, 72, 
    2,  7, 8, 81, 3, 63, 1, 77, 5, 43, 4, 25, 7, 70, 0,  1, 6, 96, 
    1, 30, 8, 15, 0, 38, 7, 95, 4, 97, 2, 69, 6, 55, 3, 88, 5, 60, 
    5, 72, 0, 21, 3, 14, 2, 86, 7, 61, 1,  1, 8, 94, 4, 60, 6, 84
  };
  const int q5998[] = {
    9, 9, // Number of jobs and machines
    0, 49, 6, 63, 4, 82, 2, 29, 5, 20, 3, 90, 7, 12, 8, 29, 1, 35, 
    5, 64, 4, 88, 7, 20, 0, 14, 1, 21, 2, 88, 3, 24, 8, 62, 6,  3, 
    1, 55, 5, 46, 2, 33, 4, 81, 3, 65, 8, 36, 0, 86, 6, 82, 7, 63, 
    4, 51, 5, 58, 8, 30, 2, 19, 0, 41, 3, 29, 1,  7, 6, 14, 7, 29, 
    6, 79, 7, 28, 8, 92, 2, 30, 4, 51, 0, 18, 1, 42, 5, 33, 3, 86, 
    6, 26, 1, 62, 0, 93, 4, 43, 5, 25, 8, 14, 2, 95, 3, 16, 7, 60, 
    8, 57, 2, 84, 4,  6, 5, 12, 3, 78, 0, 10, 7, 84, 1, 22, 6,  4, 
    2, 18, 4, 49, 8, 98, 0, 50, 1, 14, 6, 90, 7, 54, 3, 64, 5, 84, 
    5, 65, 3, 81, 7, 61, 6, 75, 1, 30, 8,  8, 4, 54, 2, 39, 0, 34
  };
  const int q5999[] = {
    9, 9, // Number of jobs and machines
    7, 45, 5, 46, 4, 59, 3, 76, 0, 13, 8, 55, 6, 21, 2, 67, 1, 63, 
    2, 31, 8, 73, 6,  1, 3, 11, 1, 46, 0, 14, 5, 79, 4, 53, 7, 87, 
    2, 34, 8, 14, 5, 84, 4, 88, 3, 79, 1, 11, 7,  5, 6, 94, 0, 48, 
    4, 66, 3,  6, 8, 25, 2, 94, 6, 28, 1, 62, 5, 38, 7, 67, 0, 42, 
    1, 72, 0, 35, 5, 99, 6,  6, 7, 25, 4,  4, 8, 35, 2, 87, 3, 23, 
    6, 51, 0, 93, 1, 41, 5, 30, 7, 18, 3, 70, 2, 84, 4,  9, 8, 14, 
    6, 54, 4, 35, 7, 32, 0, 50, 3, 74, 1, 46, 2, 69, 5, 39, 8,  7, 
    6, 57, 8, 77, 4, 42, 1, 99, 3, 33, 5, 63, 0, 53, 7, 85, 2, 94, 
    7, 63, 4,  8, 6, 69, 5,  1, 1, 64, 8, 95, 0, 69, 2, 26, 3, 51
  };
  const int q6000[] = {
    9, 9, // Number of jobs and machines
    4, 73, 1, 96, 5, 73, 3, 27, 8, 31, 6,  8, 2, 15, 0, 11, 7, 46, 
    0, 38, 8, 53, 3, 27, 5, 13, 1, 59, 7, 61, 2, 47, 6, 37, 4, 12, 
    1, 11, 3, 78, 5, 53, 4, 88, 8, 60, 0, 96, 6, 23, 7, 87, 2, 73, 
    6, 58, 8, 30, 1, 12, 5, 32, 2, 38, 4, 83, 0, 72, 3, 19, 7, 14, 
    7, 18, 0, 91, 5, 24, 6, 48, 2,  8, 4, 28, 1,  1, 8, 41, 3, 41, 
    1, 58, 0, 54, 5, 84, 8, 94, 6, 68, 3, 19, 7, 35, 2, 64, 4,  4, 
    4, 45, 5, 75, 2,  1, 8, 76, 6, 94, 0,  3, 1, 67, 3, 18, 7, 39, 
    8, 43, 5, 64, 2, 54, 7,  2, 3, 51, 6, 60, 1, 24, 4,  8, 0, 99, 
    5, 32, 7, 27, 6, 99, 2, 23, 1, 41, 4, 40, 0, 20, 3, 77, 8,  4
  };
  const int q6001[] = {
    9, 9, // Number of jobs and machines
    5, 71, 2, 44, 8, 92, 3, 86, 0, 10, 7, 77, 6, 30, 1, 79, 4, 68, 
    1, 22, 6, 70, 0, 75, 5,  8, 2, 85, 4, 23, 8, 71, 7, 43, 3, 14, 
    5, 61, 4, 37, 8, 35, 1, 94, 7,  5, 0, 47, 6,  6, 2, 69, 3, 30, 
    3, 60, 8, 79, 7, 90, 2,  3, 5, 72, 1, 50, 4, 52, 0, 90, 6, 60, 
    2, 82, 0, 98, 3, 39, 6, 84, 7,  3, 8, 64, 1, 52, 4, 44, 5, 60, 
    0, 68, 4, 34, 5, 40, 8, 57, 2, 48, 1, 98, 6, 69, 7, 65, 3, 95, 
    3, 51, 1, 79, 8, 20, 5, 69, 6, 44, 4, 38, 7, 48, 0, 34, 2, 62, 
    7, 60, 6, 42, 5, 60, 0,  4, 1, 68, 8, 55, 2, 42, 3, 87, 4, 74, 
    1, 40, 3, 83, 8, 31, 6, 47, 5, 54, 4, 10, 7, 80, 2, 41, 0, 42
  };
  const int q6002[] = {
    9, 9, // Number of jobs and machines
    7, 90, 4, 29, 8, 45, 2, 72, 5, 77, 6, 94, 0, 34, 1, 82, 3, 18, 
    0, 11, 5, 42, 3, 65, 4, 59, 1,  3, 7,  7, 2, 92, 8,  4, 6, 19, 
    5, 44, 7, 84, 8,  9, 6, 50, 4, 46, 0, 44, 1, 19, 3, 60, 2, 79, 
    4, 30, 7, 25, 1,  1, 2, 75, 5, 23, 6, 61, 0, 94, 3, 63, 8, 56, 
    8, 33, 3, 78, 7, 52, 5,  4, 0, 38, 1, 27, 6, 92, 2, 44, 4, 55, 
    7, 17, 6, 87, 0, 35, 3, 44, 1, 80, 5, 14, 2, 18, 8, 73, 4, 59, 
    8, 79, 4, 57, 5, 64, 1, 94, 0, 19, 6, 55, 3, 49, 7, 83, 2, 15, 
    4, 55, 2,  6, 0, 96, 5, 54, 1, 89, 6, 22, 7, 18, 8, 72, 3, 69, 
    8, 17, 4, 67, 6, 37, 3, 15, 0, 85, 2, 45, 1, 52, 5, 86, 7,  4
  };
  const int q6003[] = {
    9, 9, // Number of jobs and machines
    4, 16, 7, 33, 3, 94, 5, 56, 8, 86, 1, 39, 0, 34, 2, 51, 6, 48, 
    1, 85, 6, 61, 0, 91, 4, 41, 7,  9, 3, 51, 8, 65, 5, 20, 2,  9, 
    3, 77, 1, 59, 6, 75, 0, 38, 5, 56, 4, 50, 2, 15, 7, 81, 8, 46, 
    7, 98, 2, 80, 0,  1, 8, 83, 4, 23, 6, 79, 3, 69, 5, 29, 1, 17, 
    0, 58, 4, 99, 5, 99, 8, 22, 1, 96, 6, 77, 2, 55, 3, 26, 7, 71, 
    0, 16, 5, 33, 6, 31, 4, 27, 3, 88, 2, 40, 1, 11, 7, 15, 8, 43, 
    1, 16, 2, 46, 4, 59, 5, 23, 8, 16, 6, 50, 7, 98, 3, 19, 0, 96, 
    1, 88, 3, 47, 6, 24, 5,  3, 4, 29, 2, 42, 8, 12, 0,  6, 7, 12, 
    2, 55, 4, 21, 7, 72, 5, 65, 3,  9, 8, 27, 0, 36, 6, 64, 1, 96
  };
  const int q6004[] = {
    9, 9, // Number of jobs and machines
    3, 15, 8, 58, 1, 71, 6, 19, 7, 99, 5, 27, 2, 24, 4, 81, 0, 12, 
    0, 36, 5, 59, 3, 55, 2, 11, 1, 18, 7, 91, 8, 10, 6, 97, 4, 42, 
    7, 48, 8, 85, 2, 27, 6, 22, 1, 54, 0, 13, 4, 30, 3,  7, 5, 46, 
    0, 18, 1, 26, 2, 58, 7, 47, 6,  6, 4, 54, 8, 92, 3, 93, 5,  7, 
    2, 40, 8,  6, 0, 36, 3,  7, 7, 38, 5, 99, 6, 41, 4, 11, 1, 79, 
    5, 50, 6, 64, 1, 25, 3, 68, 4, 30, 0, 72, 2, 41, 8, 85, 7, 27, 
    2, 22, 0, 20, 4, 72, 7, 22, 6, 44, 8, 15, 3, 52, 5, 42, 1, 38, 
    5, 15, 2, 74, 6,  7, 4, 79, 8, 69, 7, 43, 1, 89, 0, 82, 3, 10, 
    2, 25, 5, 15, 1, 39, 3,  6, 8, 23, 0, 15, 6, 14, 4,  4, 7, 27
  };
  const int q6005[] = {
    9, 9, // Number of jobs and machines
    0, 44, 4, 19, 1, 11, 5, 54, 6, 82, 3, 86, 7, 13, 2, 81, 8, 91, 
    3, 37, 6, 57, 8, 57, 0, 84, 4, 95, 2, 94, 1, 82, 5, 73, 7, 19, 
    8, 14, 1, 25, 0, 66, 6, 63, 3, 73, 5, 99, 4, 22, 2,  3, 7, 40, 
    7,  3, 8, 16, 0, 66, 5, 55, 2, 77, 1, 38, 3, 82, 6, 69, 4, 56, 
    2, 46, 4, 97, 8, 68, 0, 40, 6,  1, 5, 36, 1, 62, 7, 41, 3, 24, 
    3, 71, 0,  9, 6, 31, 1, 58, 5,  5, 4,  6, 8, 22, 7, 86, 2, 76, 
    8, 44, 3,  1, 4, 55, 2, 13, 0, 81, 5, 60, 6, 71, 1, 82, 7, 37, 
    1, 77, 6,  5, 7, 86, 3, 56, 4, 30, 8, 82, 5, 20, 2, 23, 0, 40, 
    8, 48, 3,  6, 4, 46, 2, 98, 7,  1, 0, 55, 5,  7, 6, 89, 1, 90
  };
  const int q6006[] = {
    9, 9, // Number of jobs and machines
    3, 59, 7,  8, 0, 96, 4, 24, 5, 86, 6, 72, 2, 36, 1, 68, 8, 95, 
    5, 34, 0, 75, 3, 15, 8, 11, 2, 17, 1,  5, 7, 76, 6, 13, 4, 66, 
    7, 92, 5, 12, 0, 95, 8, 44, 4, 51, 2, 26, 6, 76, 1, 13, 3, 36, 
    1,  2, 2,  5, 3, 19, 7,  2, 4, 11, 5, 91, 0, 40, 8, 76, 6, 73, 
    4, 66, 2, 96, 5,  7, 6, 45, 3, 53, 8, 26, 1, 20, 7, 62, 0, 33, 
    6, 99, 7, 75, 5, 58, 8,  6, 1, 31, 4, 71, 0, 44, 3, 35, 2,  3, 
    3, 82, 1, 54, 7, 54, 6,  8, 5, 87, 0,  8, 4, 84, 2, 98, 8,  7, 
    3, 43, 7, 47, 4, 89, 6, 77, 8, 72, 0, 11, 5, 36, 1, 34, 2, 42, 
    8, 60, 2, 32, 5, 29, 1, 75, 0, 84, 7, 21, 3, 13, 4,  5, 6, 16
  };
  const int q6007[] = {
    9, 9, // Number of jobs and machines
    0, 35, 2, 85, 3, 74, 4, 68, 1, 33, 7, 43, 5, 90, 8, 36, 6, 28, 
    6, 53, 7, 87, 2, 96, 4, 25, 0, 30, 8, 92, 3, 90, 1,  9, 5, 68, 
    8, 41, 6,  2, 3,  7, 5, 17, 4, 31, 7, 39, 2, 63, 1, 70, 0,  4, 
    4, 83, 8, 41, 0, 69, 1, 89, 3, 15, 5, 38, 7, 66, 6, 81, 2, 94, 
    7, 36, 8, 88, 3, 78, 0, 35, 1, 86, 2, 84, 4, 79, 6, 26, 5, 52, 
    6, 46, 1, 58, 3, 31, 5, 95, 0, 75, 2, 63, 7, 60, 8, 20, 4, 42, 
    8, 11, 0, 90, 6, 31, 2, 23, 3, 27, 1, 32, 7,  3, 4, 51, 5, 24, 
    1, 99, 4, 24, 0, 18, 7, 45, 5,  5, 3, 87, 8, 77, 2,  9, 6,  6, 
    3, 37, 0, 89, 4, 52, 5, 97, 8, 57, 1, 87, 2, 60, 7, 72, 6, 46
  };
  const int q6008[] = {
    9, 9, // Number of jobs and machines
    3, 13, 0, 52, 6, 35, 8, 66, 7, 60, 5, 11, 4, 84, 2, 40, 1, 96, 
    5, 44, 2, 74, 3, 71, 7, 26, 8, 76, 4, 78, 6, 49, 0, 98, 1, 53, 
    7, 83, 3, 92, 0, 37, 2, 86, 8, 20, 6, 23, 4, 90, 1, 26, 5, 62, 
    2, 31, 6, 45, 7, 69, 4, 33, 3, 34, 1, 84, 0, 15, 5, 52, 8, 83, 
    2, 28, 8, 30, 6, 29, 0, 72, 3, 36, 4, 55, 1, 59, 5, 28, 7, 15, 
    3, 17, 7, 76, 5, 46, 4, 76, 1, 53, 6,  4, 8, 13, 2, 56, 0, 88, 
    5, 40, 8, 71, 3, 18, 1, 91, 6, 61, 0,  7, 2,  2, 4, 50, 7, 68, 
    4, 92, 2, 87, 8, 69, 6, 51, 5, 95, 1, 10, 0, 20, 7, 39, 3, 28, 
    1, 94, 3, 89, 6, 74, 4, 61, 5, 29, 8, 50, 0, 18, 2, 28, 7, 30
  };
  const int q6009[] = {
    9, 9, // Number of jobs and machines
    1, 20, 6, 13, 0, 39, 4, 62, 3, 42, 2, 24, 8, 49, 7, 39, 5, 92, 
    6, 45, 0, 12, 3,  3, 7, 19, 2, 98, 4,  9, 1, 91, 5, 31, 8, 23, 
    5, 68, 0, 39, 6, 18, 8, 93, 7, 71, 3, 67, 1, 55, 4, 48, 2, 82, 
    4, 28, 0, 66, 8, 49, 5, 80, 3, 53, 7, 55, 1, 82, 2, 23, 6, 11, 
    3, 68, 5, 40, 8, 92, 4, 34, 6, 25, 1, 76, 7, 51, 2, 73, 0, 42, 
    0,  2, 2, 95, 3, 19, 8, 35, 6,  3, 7, 72, 1, 31, 4, 33, 5, 93, 
    5, 32, 7, 21, 3, 34, 1, 12, 6, 81, 0, 16, 8, 74, 4, 58, 2, 38, 
    8, 70, 6, 90, 7, 78, 0, 43, 1,  6, 3, 69, 4, 25, 2, 15, 5, 18, 
    8, 73, 4, 76, 3, 35, 6, 55, 7, 28, 2, 19, 1, 30, 5, 80, 0, 62
  };
  const int q6010[] = {
    9, 9, // Number of jobs and machines
    7,  6, 3, 77, 8, 37, 1, 68, 4,  6, 6, 50, 0, 13, 2, 74, 5, 15, 
    7, 91, 3, 97, 6, 89, 5, 43, 1, 66, 8, 24, 0, 42, 4, 40, 2, 31, 
    6, 61, 5,  4, 8,  2, 4, 87, 2, 16, 1, 13, 3,  5, 0, 98, 7, 38, 
    3, 12, 0,  1, 7, 77, 4, 53, 8, 35, 2, 91, 5, 11, 1, 64, 6, 62, 
    6, 27, 0, 66, 5, 76, 4, 71, 8, 10, 1, 93, 3, 71, 7, 72, 2, 99, 
    2,  2, 7, 14, 8, 54, 3, 70, 5, 42, 6, 67, 4, 82, 1, 78, 0, 74, 
    5, 73, 0, 11, 6, 40, 7, 65, 4, 82, 1,  8, 2, 99, 8, 38, 3, 83, 
    0, 71, 7, 98, 6, 65, 5, 20, 1,  3, 8, 89, 4, 12, 3,  7, 2,  7, 
    1, 28, 7, 40, 2, 83, 0, 84, 3, 65, 4, 15, 8,  3, 6, 38, 5, 81
  };
  const int q6011[] = {
    9, 9, // Number of jobs and machines
    6, 57, 0, 62, 2,  1, 5, 84, 7, 60, 8, 35, 1, 66, 4, 37, 3, 17, 
    7, 92, 4, 45, 2, 65, 3,  5, 6, 83, 8, 80, 1, 63, 5, 77, 0, 75, 
    1, 50, 7, 40, 5, 94, 2, 10, 4, 83, 0, 79, 8, 12, 6, 98, 3,  6, 
    3, 40, 7, 64, 1, 14, 5, 83, 8,  2, 4, 14, 6, 59, 0, 39, 2, 84, 
    6, 81, 7, 51, 3, 51, 4, 97, 2,  7, 1, 38, 0,  5, 5, 19, 8, 86, 
    1, 52, 5, 91, 4, 34, 0, 69, 7, 78, 2, 96, 8,  2, 6, 76, 3, 94, 
    1, 77, 0, 53, 4, 99, 3, 45, 5, 32, 2, 10, 8, 44, 6, 94, 7, 11, 
    1, 96, 0, 28, 5, 98, 2, 18, 4, 86, 6, 85, 7, 80, 8, 63, 3, 39, 
    6, 44, 2, 35, 0, 44, 1, 59, 3, 69, 7, 86, 8, 12, 4, 29, 5, 47
  };
  const int q6012[] = {
    9, 9, // Number of jobs and machines
    5, 66, 4,  5, 1, 50, 6,  9, 0, 83, 3, 55, 2, 34, 8, 90, 7, 85, 
    8, 51, 7, 34, 4, 48, 3, 59, 0,  1, 5, 97, 6, 14, 1, 61, 2, 67, 
    6, 27, 0, 36, 7, 45, 4, 90, 2, 34, 3, 83, 8,  1, 1, 89, 5, 22, 
    4, 76, 1, 63, 0, 85, 3, 39, 7, 41, 2, 55, 8, 83, 5, 52, 6, 77, 
    2,  7, 5, 71, 6, 44, 4, 31, 3, 97, 7, 24, 0,  9, 8, 29, 1, 17, 
    4,  2, 8, 64, 6, 35, 2, 84, 5, 96, 7, 76, 1, 67, 3, 53, 0, 62, 
    7, 76, 5, 22, 8, 11, 1, 97, 6, 59, 2, 13, 4, 74, 0, 93, 3, 16, 
    0, 10, 7, 76, 8, 14, 5, 86, 4, 43, 1, 60, 6, 29, 2, 43, 3, 78, 
    0, 86, 2, 27, 6, 35, 3, 32, 4, 44, 8, 90, 7, 96, 5, 29, 1, 34
  };
  const int q6013[] = {
    9, 9, // Number of jobs and machines
    7, 12, 8, 99, 4, 93, 5, 54, 1, 78, 2, 37, 3, 27, 6, 81, 0, 75, 
    1, 41, 6, 99, 8, 76, 7, 68, 5, 17, 3, 36, 0, 75, 2, 70, 4, 72, 
    1, 21, 0, 22, 4, 42, 6, 54, 8, 60, 2, 23, 7, 27, 5, 91, 3, 86, 
    1,  2, 0, 61, 5, 90, 3, 89, 6, 64, 4, 84, 7, 78, 8, 57, 2, 12, 
    7, 24, 5, 51, 6, 10, 3, 89, 8, 57, 4,  3, 1, 63, 0, 80, 2, 86, 
    4, 74, 1,  3, 7, 60, 2, 82, 0, 48, 5, 92, 8, 42, 6, 88, 3, 42, 
    8,  5, 0, 33, 4, 21, 1, 55, 6, 90, 7, 33, 5, 14, 3, 32, 2, 45, 
    7, 69, 5, 48, 1, 94, 2, 96, 8, 38, 3,  2, 0, 59, 4, 58, 6, 79, 
    4, 32, 8, 11, 3, 84, 7, 54, 0, 95, 1, 25, 2, 81, 5, 62, 6, 36
  };
  const int q6014[] = {
    9, 9, // Number of jobs and machines
    5, 92, 0, 41, 1, 47, 4, 94, 2, 31, 8, 13, 3, 43, 6, 20, 7, 43, 
    3, 94, 7,  3, 0, 21, 8, 38, 6, 20, 1, 83, 5, 47, 4,  3, 2, 27, 
    5, 99, 4, 75, 6, 80, 2, 40, 0, 77, 7, 73, 1, 52, 8, 32, 3, 99, 
    1, 78, 2, 34, 4, 51, 8, 68, 3, 93, 7, 63, 6,  7, 0, 82, 5,  6, 
    6, 94, 8, 37, 4, 81, 5, 38, 1, 26, 2, 41, 7, 37, 0,  3, 3, 88, 
    5, 31, 8, 78, 3, 80, 0, 86, 7, 84, 6, 23, 2, 77, 1, 31, 4, 50, 
    5, 51, 0,  3, 1, 99, 6, 79, 3, 13, 8, 42, 2, 33, 7, 83, 4, 78, 
    2, 98, 6, 92, 4, 13, 8, 91, 3, 12, 0,  3, 1, 14, 5, 62, 7, 90, 
    7, 91, 3, 77, 6, 70, 8, 69, 4,  9, 0, 25, 2, 47, 5, 22, 1, 38
  };
  const int q6015[] = {
    9, 9, // Number of jobs and machines
    6, 93, 4, 39, 0, 36, 5, 36, 1, 25, 2, 42, 3, 39, 8, 41, 7, 99, 
    0, 67, 3, 89, 6, 59, 7, 12, 1, 98, 2, 60, 8, 28, 4, 42, 5, 52, 
    1, 81, 7, 17, 6, 12, 0, 12, 5, 51, 8, 92, 2, 89, 3, 12, 4, 88, 
    3, 45, 5, 18, 1, 75, 6, 59, 0, 38, 4,  5, 8, 76, 7, 43, 2, 48, 
    4, 95, 6, 66, 2, 78, 1, 39, 5, 77, 3, 53, 7, 53, 8, 81, 0, 84, 
    6, 46, 3, 15, 7, 97, 8, 34, 5, 33, 0, 98, 4, 92, 1, 10, 2, 71, 
    1, 99, 5, 42, 2,  3, 0, 65, 8, 57, 7, 61, 6, 76, 4, 40, 3,  6, 
    4, 55, 6, 80, 2, 42, 3, 62, 8, 17, 0,  9, 7, 34, 5, 11, 1, 73, 
    8, 62, 3, 79, 4, 57, 1, 99, 7, 66, 2, 24, 0, 94, 5, 65, 6, 11
  };
  const int q6016[] = {
    9, 9, // Number of jobs and machines
    4, 89, 8, 90, 0, 28, 2, 17, 5, 52, 6, 79, 3, 95, 7, 55, 1, 38, 
    6, 62, 7, 33, 2, 95, 8, 18, 4, 99, 5, 98, 1, 27, 3, 16, 0, 67, 
    3, 71, 7, 48, 2, 84, 8, 88, 6, 91, 4,  1, 5, 93, 0, 74, 1, 70, 
    6, 21, 7, 11, 8, 55, 5, 42, 0, 21, 1, 75, 2, 22, 4, 71, 3, 13, 
    5, 35, 8, 79, 2, 64, 3, 99, 4, 17, 6, 27, 7, 64, 0, 27, 1, 74, 
    3, 98, 7, 83, 5, 47, 0, 66, 4, 42, 2, 47, 6, 43, 1, 44, 8, 24, 
    4, 96, 8, 47, 6, 49, 0, 56, 3, 28, 7, 91, 1, 25, 2, 46, 5, 45, 
    3, 62, 4, 28, 5, 34, 0, 60, 8, 84, 7, 46, 1, 86, 2, 35, 6, 49, 
    4, 41, 8, 14, 1, 28, 2, 34, 0, 33, 7, 38, 3, 99, 6, 13, 5, 20
  };
  const int q6017[] = {
    9, 9, // Number of jobs and machines
    2, 73, 0, 15, 8, 55, 7, 30, 3, 52, 6, 36, 4, 44, 1, 94, 5, 73, 
    2, 40, 5, 35, 6, 56, 0, 24, 4, 17, 3, 81, 8, 53, 1, 59, 7, 41, 
    1, 87, 7, 63, 6, 66, 0, 54, 3, 57, 8, 74, 2, 94, 4,  9, 5, 64, 
    3, 86, 1, 39, 5, 49, 0, 63, 7, 24, 4, 62, 8, 13, 6,  9, 2, 50, 
    3, 33, 6, 20, 8, 26, 5, 81, 0, 74, 2, 41, 1,  1, 4, 97, 7, 16, 
    7, 22, 4, 92, 3, 99, 8, 60, 1,  2, 0, 60, 2, 53, 6, 71, 5, 73, 
    5,  2, 8,  2, 7, 35, 0,  1, 1, 92, 6, 19, 3, 93, 4, 13, 2,  1, 
    4, 42, 2, 19, 3, 60, 0, 28, 7, 60, 8,  4, 1, 55, 6,  8, 5,  8, 
    4, 61, 3, 20, 6, 91, 8, 58, 0, 53, 2, 80, 7, 66, 5,  1, 1, 13
  };
  const int q6018[] = {
    9, 9, // Number of jobs and machines
    7, 38, 3, 10, 2,  8, 0, 21, 5, 84, 4, 48, 8, 67, 1, 97, 6, 96, 
    4, 57, 1, 44, 5, 50, 3,  4, 2, 72, 7, 63, 6, 20, 8, 55, 0, 48, 
    4, 39, 3, 86, 1, 42, 2, 87, 5, 46, 0, 32, 7, 68, 6, 52, 8, 43, 
    3, 70, 5, 43, 0, 31, 1, 86, 6, 61, 8, 45, 4,  9, 7, 66, 2,  5, 
    5, 66, 8, 57, 1, 21, 4, 82, 2, 81, 0, 76, 6, 82, 3, 13, 7,  5, 
    5, 53, 6, 67, 0, 78, 4, 93, 3, 44, 7, 80, 1, 15, 8, 69, 2, 64, 
    4, 36, 0, 81, 7, 82, 3, 64, 6, 13, 1,  7, 8, 72, 2, 79, 5, 23, 
    1, 79, 6, 81, 4, 65, 3, 39, 7, 78, 8, 22, 2, 29, 5, 80, 0, 88, 
    5, 56, 2, 13, 8, 38, 6, 66, 3, 60, 1, 29, 4, 65, 0, 10, 7, 92
  };
  const int q6019[] = {
    9, 9, // Number of jobs and machines
    6, 78, 8, 25, 1, 36, 3, 14, 4, 76, 0, 73, 5, 65, 2, 88, 7, 73, 
    7, 21, 0, 86, 5,  8, 3, 36, 4, 21, 1, 49, 8, 96, 2, 70, 6, 60, 
    1, 49, 2, 11, 7, 91, 3,  3, 4, 93, 6, 92, 0, 77, 5, 40, 8, 52, 
    4, 29, 2, 97, 5, 53, 0, 56, 1, 48, 8, 46, 6, 60, 7, 17, 3, 41, 
    0, 38, 4, 44, 5, 90, 3, 51, 6, 26, 8, 28, 2, 23, 1, 98, 7, 69, 
    0, 60, 1, 49, 4, 82, 5,  9, 8, 48, 2, 23, 6, 75, 7, 24, 3,  3, 
    3, 72, 7,  1, 0,  9, 2, 44, 6, 30, 5, 83, 1, 93, 8, 14, 4, 84, 
    6, 22, 0, 45, 4, 39, 2, 92, 5, 95, 1, 57, 8,  5, 7, 70, 3, 86, 
    5,  3, 0, 76, 3, 73, 1, 13, 2, 89, 7, 81, 4, 32, 6, 83, 8, 99
  };
  const int q6020[] = {
    9, 9, // Number of jobs and machines
    5,  4, 3, 65, 2, 94, 1, 73, 7, 96, 8, 51, 0, 54, 6, 61, 4, 23, 
    4, 32, 5, 22, 8, 25, 0, 26, 1, 32, 6, 25, 2, 70, 3, 41, 7, 11, 
    2, 52, 0,  4, 4, 44, 3, 21, 5, 25, 1,  8, 8, 35, 6,  3, 7, 25, 
    8, 98, 3, 23, 5, 93, 7, 11, 0, 21, 6, 80, 4, 97, 2, 59, 1, 89, 
    5, 46, 3, 65, 4, 52, 8,  9, 0, 19, 2, 40, 1, 87, 7, 29, 6, 77, 
    8,  8, 2, 33, 1, 49, 7,  4, 4, 39, 0, 55, 5, 77, 6, 35, 3, 73, 
    2, 87, 6, 64, 5, 98, 8, 98, 0, 13, 1, 38, 3, 17, 7, 66, 4, 19, 
    2,  4, 7, 91, 1, 27, 6, 98, 8, 25, 5, 44, 4, 23, 3, 77, 0, 48, 
    6, 93, 7,  4, 8, 62, 1, 66, 3, 29, 2, 16, 5, 63, 4, 23, 0, 59
  };
  const int q6021[] = {
    9, 9, // Number of jobs and machines
    1, 21, 7,  9, 3, 83, 5, 24, 8, 62, 0, 56, 4, 20, 2, 99, 6, 46, 
    6, 27, 3, 14, 8, 96, 5, 75, 2, 25, 4, 55, 1,  7, 0, 95, 7, 56, 
    0, 59, 8, 34, 2, 26, 1, 19, 4, 31, 6, 55, 7, 10, 5, 30, 3, 85, 
    1, 87, 6, 95, 5, 48, 3, 23, 2, 26, 7, 97, 0, 10, 4,  2, 8, 38, 
    8, 18, 0, 30, 1, 40, 2, 48, 7, 54, 4, 32, 5, 49, 6, 83, 3, 35, 
    1, 55, 5,  2, 4, 13, 7, 80, 8, 22, 3, 29, 2, 97, 6, 22, 0, 98, 
    8, 36, 3, 55, 2, 86, 4, 61, 6, 50, 5, 32, 7, 75, 0, 92, 1, 45, 
    3, 62, 5, 29, 7, 25, 2, 44, 0, 11, 6, 34, 8,  8, 4, 97, 1, 82, 
    4, 58, 5, 55, 6, 69, 2, 51, 3, 90, 8, 94, 7, 92, 0, 92, 1, 48
  };
  const int q6022[] = {
    9, 9, // Number of jobs and machines
    6, 82, 3, 53, 0, 33, 7, 96, 4, 32, 1, 82, 8, 92, 5, 86, 2, 68, 
    6, 25, 8,  9, 0, 56, 7, 11, 2, 97, 4,  1, 5, 14, 1, 18, 3, 66, 
    4, 22, 5,  1, 7, 58, 1, 27, 6, 75, 3, 60, 2,  1, 8, 17, 0, 10, 
    2, 87, 3,  6, 8, 36, 1, 63, 7, 93, 5, 84, 6, 66, 4, 26, 0, 33, 
    8, 93, 3, 21, 6, 94, 5, 25, 0, 63, 1, 10, 4,  3, 2, 80, 7, 94, 
    0, 38, 8, 58, 2, 49, 6, 84, 7, 82, 1, 78, 3, 72, 5, 42, 4, 10, 
    8, 55, 2, 67, 6, 47, 0,  2, 7, 45, 5, 93, 1, 36, 3, 14, 4, 33, 
    8, 58, 3, 85, 2, 17, 7,  1, 5, 41, 1, 10, 6,  3, 4, 90, 0, 56, 
    2, 69, 6, 32, 7, 68, 5, 81, 0, 42, 8,  1, 4, 48, 1, 14, 3, 29
  };
  const int q6023[] = {
    9, 9, // Number of jobs and machines
    2, 13, 4, 24, 1, 75, 5, 32, 3, 37, 8, 81, 0, 41, 7, 19, 6, 27, 
    5, 35, 2, 31, 4, 53, 7, 18, 1, 96, 3, 66, 0, 82, 6, 88, 8, 45, 
    7, 12, 6, 15, 8, 99, 5, 53, 4, 49, 0, 44, 1, 89, 2, 34, 3, 62, 
    7, 59, 8, 54, 3, 57, 0, 18, 6, 46, 5, 79, 2, 66, 4,  8, 1, 80, 
    8,  8, 3,  2, 2, 21, 1, 71, 0, 91, 5, 51, 4, 78, 7, 77, 6, 59, 
    1, 89, 5, 42, 7, 43, 0, 40, 4, 63, 8, 86, 3, 36, 6, 49, 2, 97, 
    6,  8, 4, 70, 1, 24, 5, 63, 7, 56, 3,  7, 8, 76, 2, 59, 0, 54, 
    5, 48, 3, 66, 7,  6, 1, 69, 0, 79, 4, 34, 2, 30, 8, 90, 6, 91, 
    2, 23, 5, 12, 3, 91, 0,  4, 6, 91, 8, 60, 1, 68, 7, 49, 4, 46
  };
  const int q6024[] = {
    9, 9, // Number of jobs and machines
    3, 74, 6, 57, 0, 81, 4, 31, 7, 39, 5, 96, 2, 91, 1, 61, 8, 67, 
    3, 39, 2, 45, 4, 36, 1, 33, 8, 63, 7,  1, 6, 96, 0,  7, 5, 18, 
    1, 87, 7,  2, 3, 81, 5, 42, 8, 40, 2, 56, 4,  9, 0, 10, 6, 24, 
    2, 95, 5,  6, 8, 27, 0, 32, 3, 14, 6, 69, 4, 44, 1, 28, 7, 34, 
    8, 88, 7, 41, 2, 24, 1, 23, 4, 11, 0, 16, 6, 85, 5,  7, 3, 77, 
    8, 56, 0, 67, 1, 54, 5, 91, 6, 87, 4, 98, 3, 66, 2, 82, 7, 51, 
    2, 54, 0, 33, 3, 79, 1, 50, 8, 51, 5, 18, 6,  5, 4, 75, 7,  6, 
    6, 87, 5, 72, 4, 41, 8, 12, 2, 15, 1, 19, 7, 91, 0, 53, 3, 40, 
    6, 80, 4, 19, 7, 10, 8, 19, 5, 88, 2, 95, 1, 38, 3, 59, 0, 81
  };
  const int q6025[] = {
    9, 9, // Number of jobs and machines
    4, 72, 5, 90, 8,  6, 2, 48, 6, 56, 1, 53, 3,  6, 0, 14, 7, 49, 
    7, 44, 8, 20, 0, 76, 2, 78, 6,  5, 1, 96, 3, 49, 5, 75, 4, 74, 
    3, 50, 1, 73, 2, 31, 4, 37, 6, 15, 5,  7, 0, 35, 8, 51, 7, 12, 
    1, 98, 7, 77, 5, 51, 2, 88, 8, 71, 6,  7, 4, 42, 3, 66, 0, 25, 
    3, 62, 7, 22, 0, 79, 1, 17, 4,  1, 2, 39, 6, 35, 8, 54, 5, 88, 
    6, 54, 3, 75, 8, 73, 1, 59, 5, 72, 4, 42, 2, 74, 0, 62, 7, 35, 
    7, 34, 5, 60, 2, 28, 3, 10, 4, 28, 0,  2, 1, 55, 8, 18, 6, 74, 
    6, 22, 0, 68, 4, 78, 5, 43, 2, 48, 8, 62, 3, 43, 1, 87, 7, 19, 
    1,  5, 7, 29, 6, 84, 4, 24, 5, 43, 8, 58, 3, 27, 2, 73, 0, 27
  };
  const int q6026[] = {
    9, 9, // Number of jobs and machines
    2, 37, 4, 79, 3, 73, 5, 44, 6, 34, 0,  9, 7, 26, 8, 78, 1,  9, 
    8, 26, 7,  4, 1, 18, 4, 51, 3, 93, 2, 62, 6, 28, 0, 75, 5,  5, 
    8, 93, 4,  7, 0, 91, 6, 79, 2, 91, 1,  2, 7, 73, 5, 49, 3, 97, 
    3, 11, 1,  2, 2, 51, 8,  9, 5, 60, 4, 96, 6, 33, 0,  6, 7, 19, 
    1, 73, 0, 69, 4, 32, 2, 28, 3, 22, 7, 38, 8, 90, 6, 68, 5, 50, 
    1, 48, 2, 41, 0, 31, 7,  2, 4, 84, 6, 14, 5, 76, 3, 79, 8,  1, 
    6, 97, 7,  5, 2, 89, 3, 11, 1,  6, 0, 66, 4, 81, 8, 36, 5, 24, 
    1, 71, 2, 16, 7, 72, 3, 80, 0, 31, 8, 28, 5, 18, 6, 72, 4,  2, 
    3, 20, 2, 97, 1,  1, 6, 10, 8, 50, 0, 12, 5, 56, 7, 38, 4, 98
  };
  const int q6027[] = {
    9, 9, // Number of jobs and machines
    7, 18, 2, 22, 6, 65, 4,  6, 0, 14, 1, 78, 5, 83, 8, 45, 3, 56, 
    8,  1, 6, 47, 7, 64, 2, 34, 1, 66, 4, 58, 0, 71, 5, 89, 3, 76, 
    5, 14, 4,  5, 6, 38, 8,  6, 1, 52, 2, 61, 3, 32, 0, 53, 7, 87, 
    0, 87, 5, 54, 4, 56, 8, 47, 7, 65, 2, 23, 1, 38, 6, 43, 3, 23, 
    0, 34, 4, 30, 1, 36, 8, 79, 7, 93, 6, 73, 3, 28, 2, 22, 5,  4, 
    5, 53, 1, 12, 3, 10, 0, 50, 4, 97, 6, 77, 8, 42, 2, 67, 7, 16, 
    6,  3, 1, 55, 3, 32, 4,  3, 7, 29, 5, 77, 8, 45, 0, 44, 2, 89, 
    2, 97, 3, 87, 8, 92, 6, 38, 1, 85, 0,  6, 5, 28, 4, 28, 7, 16, 
    2, 34, 7,  8, 5, 84, 0, 45, 6, 94, 3, 85, 1, 19, 8, 10, 4, 63
  };
  const int q6028[] = {
    9, 9, // Number of jobs and machines
    1, 99, 3, 69, 5, 33, 2, 80, 4, 46, 7, 15, 6, 65, 0, 70, 8, 80, 
    2, 29, 1, 61, 4, 86, 3, 41, 5, 59, 6, 58, 7,  2, 8, 87, 0, 71, 
    7, 46, 4, 71, 5, 30, 2, 19, 6, 85, 1, 11, 8, 87, 3, 99, 0, 52, 
    7, 26, 5, 94, 1, 54, 2, 30, 3, 98, 0, 14, 4, 58, 8, 92, 6, 89, 
    1, 41, 6, 87, 8, 38, 5, 94, 3, 90, 4, 47, 7, 51, 0, 98, 2, 66, 
    3, 35, 8, 64, 1, 18, 0, 55, 2, 62, 6, 19, 4, 35, 7, 60, 5, 70, 
    3, 13, 2, 52, 1, 91, 6, 99, 8, 86, 5, 24, 0,  7, 4, 65, 7, 65, 
    1, 26, 3, 43, 4, 68, 5, 52, 7, 65, 2, 75, 6, 42, 8, 59, 0,  6, 
    8, 87, 2, 81, 0, 77, 3, 23, 5, 84, 7, 74, 4, 14, 1, 28, 6, 95
  };
  const int q6029[] = {
    9, 9, // Number of jobs and machines
    8, 26, 4, 90, 1, 74, 5,  9, 2,  3, 0,  2, 3, 45, 7, 18, 6, 71, 
    7, 28, 2, 23, 5, 37, 8, 79, 0, 53, 4, 87, 3, 11, 1, 39, 6, 66, 
    7, 16, 5, 46, 3, 31, 1, 34, 8, 72, 2,  5, 0, 34, 6, 76, 4, 66, 
    3, 32, 4, 95, 1, 91, 7,  9, 0, 81, 5, 28, 2,  8, 8, 85, 6, 15, 
    3,  5, 7, 50, 6,  8, 2,  7, 4, 10, 8,  2, 1, 40, 5, 81, 0, 65, 
    2,  5, 4, 20, 8, 90, 6, 95, 3, 87, 5, 73, 0, 34, 1, 58, 7, 10, 
    5, 79, 8, 64, 6, 36, 7, 30, 3,  1, 4, 97, 2, 84, 1, 32, 0, 97, 
    1, 12, 3,  6, 5, 68, 6, 67, 8, 32, 0, 81, 2, 32, 7, 98, 4,  2, 
    0, 10, 3, 49, 7, 40, 1, 98, 8, 55, 6, 53, 5, 11, 2, 80, 4, 98
  };
  const int q6030[] = {
    9, 9, // Number of jobs and machines
    2, 20, 7, 74, 0, 59, 5, 32, 8, 76, 1, 41, 3, 22, 6, 84, 4, 44, 
    1,  2, 5, 62, 2, 94, 7, 11, 6, 78, 8, 67, 3,  6, 0, 82, 4, 77, 
    3, 18, 1, 71, 5, 90, 2, 61, 4, 97, 7, 82, 6, 27, 0, 78, 8, 59, 
    2, 16, 0, 57, 5, 60, 7, 47, 1, 99, 8, 26, 3, 19, 6, 95, 4, 12, 
    3, 84, 2, 95, 1,  7, 4, 89, 8, 96, 6, 15, 5, 50, 7, 50, 0, 79, 
    6, 91, 8, 29, 2, 34, 4, 10, 5, 20, 0, 26, 3, 15, 7, 50, 1, 12, 
    0, 23, 1,  8, 5, 34, 4, 10, 3, 73, 2, 20, 8, 84, 7, 47, 6, 76, 
    8, 23, 7, 47, 2, 85, 3, 84, 5, 98, 6, 58, 4, 67, 1,  7, 0, 89, 
    7, 24, 2, 63, 4, 61, 8, 83, 1, 63, 5, 85, 0, 86, 3, 63, 6, 52
  };
  const int q6031[] = {
    9, 9, // Number of jobs and machines
    6, 80, 2, 90, 5, 98, 1, 87, 3, 34, 4, 49, 7, 55, 8,  2, 0, 85, 
    0, 13, 1, 27, 3, 29, 5, 33, 6, 16, 8, 25, 2, 43, 7, 92, 4, 63, 
    4,  5, 6, 48, 2, 90, 0,  1, 7, 26, 1, 85, 3, 10, 5, 89, 8, 77, 
    8, 72, 4, 52, 3,  3, 1, 17, 7, 54, 6, 87, 5, 72, 2, 52, 0, 73, 
    1, 16, 0, 11, 5, 78, 6, 53, 7, 43, 4, 95, 3, 90, 8, 75, 2, 14, 
    5, 70, 6, 42, 2, 26, 1, 21, 4, 29, 3, 15, 0, 45, 7, 95, 8, 80, 
    8, 57, 3, 90, 0, 19, 1,  6, 7, 23, 4, 89, 6, 21, 2, 53, 5, 44, 
    8,  4, 0, 54, 4, 29, 1, 84, 7, 97, 2, 59, 6, 25, 5, 37, 3, 73, 
    8, 45, 2, 59, 1, 45, 5, 91, 6,  9, 0, 47, 7, 80, 3,  3, 4, 88
  };
  const int q6032[] = {
    9, 9, // Number of jobs and machines
    5,  7, 1, 12, 6, 64, 4, 59, 3, 97, 8, 47, 2, 84, 0, 63, 7,  5, 
    4, 51, 7, 72, 8, 74, 5, 51, 1, 19, 6, 82, 0, 20, 2, 21, 3, 55, 
    6, 56, 5, 56, 8, 46, 7,  3, 2, 26, 3, 49, 1, 29, 0, 73, 4,  6, 
    6, 22, 7, 91, 5, 28, 4, 32, 1, 70, 8, 43, 3, 64, 0, 41, 2, 40, 
    5,  7, 7, 66, 2, 88, 8, 23, 6, 44, 1, 44, 4, 15, 0, 26, 3, 77, 
    8, 18, 6, 72, 7, 70, 2, 94, 5, 47, 4, 72, 3, 31, 1, 78, 0, 11, 
    2, 20, 4, 71, 7, 74, 3, 22, 0, 58, 5, 12, 8,  5, 1, 52, 6, 34, 
    2, 73, 6, 24, 7, 96, 0, 55, 8, 59, 5, 42, 3, 46, 4, 81, 1, 74, 
    8, 76, 3,  8, 5, 52, 2, 85, 1, 28, 6, 97, 4, 86, 0, 49, 7, 16
  };
  const int q6033[] = {
    9, 9, // Number of jobs and machines
    2, 24, 5,  2, 7,  2, 8,  3, 4,  5, 6, 61, 1, 10, 0, 74, 3,  1, 
    5, 60, 6, 65, 7, 77, 0, 32, 3, 26, 1, 27, 8, 49, 2,  2, 4, 87, 
    2, 74, 6, 58, 0, 34, 7, 72, 4, 65, 8, 32, 1, 15, 5, 41, 3, 23, 
    1, 35, 4, 10, 8, 44, 7, 11, 3, 29, 6, 62, 0, 75, 5, 91, 2, 58, 
    6, 11, 5, 68, 0, 34, 2,  7, 8, 28, 4, 12, 3, 74, 1, 12, 7, 11, 
    7, 90, 8, 31, 6, 53, 5, 49, 0, 31, 4, 94, 1, 88, 3, 31, 2, 21, 
    0, 75, 3,  8, 6, 17, 5, 50, 4, 63, 1, 40, 8, 13, 2,  6, 7, 62, 
    2, 37, 0, 57, 8, 75, 3, 47, 1, 32, 7, 96, 5, 75, 4, 44, 6, 27, 
    1, 61, 3, 60, 5, 39, 7, 37, 6, 70, 2, 33, 8, 39, 4, 84, 0, 85
  };
  const int q6034[] = {
    9, 9, // Number of jobs and machines
    4, 41, 7, 16, 1, 99, 5, 48, 8, 15, 3, 45, 2, 36, 6, 22, 0, 52, 
    8, 43, 7, 12, 5,  3, 0,  8, 3, 74, 4, 83, 6, 26, 2, 59, 1, 75, 
    7, 43, 1, 92, 0,  7, 4, 61, 8, 68, 5, 66, 2, 25, 6, 33, 3, 62, 
    1, 14, 6,  2, 2, 95, 0, 20, 7,  5, 5,  7, 3, 28, 8, 43, 4, 51, 
    0,  8, 2, 62, 1, 80, 6, 66, 7, 77, 8, 78, 3, 27, 5, 29, 4, 32, 
    3, 20, 2, 10, 6, 82, 1,  2, 7, 28, 0, 82, 4, 38, 8, 78, 5, 57, 
    0,  4, 2, 39, 8, 59, 5, 30, 1, 50, 3, 18, 7, 46, 6, 11, 4, 56, 
    3, 96, 6,  3, 4, 22, 8, 38, 0, 60, 1, 84, 2, 28, 7,  6, 5, 42, 
    7, 67, 5, 21, 1, 28, 4, 85, 6, 72, 0, 75, 8, 11, 3,  4, 2, 13
  };
  const int q6035[] = {
    9, 9, // Number of jobs and machines
    6, 57, 5, 50, 0,  2, 1, 43, 2, 81, 3, 75, 4, 26, 7, 47, 8, 12, 
    3, 35, 0, 28, 4, 95, 5, 31, 6, 23, 7, 93, 8, 35, 1, 14, 2, 87, 
    2, 31, 1, 23, 6,  5, 3, 53, 5, 20, 0, 11, 7, 47, 4, 30, 8, 80, 
    2, 52, 7, 54, 5, 16, 1, 53, 0, 88, 4, 98, 6, 36, 8, 58, 3, 11, 
    8, 11, 7,  4, 4, 23, 1, 47, 0, 58, 5, 19, 3,  5, 2, 76, 6, 20, 
    2, 75, 5, 77, 3, 83, 0, 87, 6, 34, 7, 63, 4, 96, 1, 95, 8, 25, 
    4, 39, 6, 91, 8, 70, 0, 54, 7, 63, 5, 99, 3, 22, 1, 81, 2, 90, 
    4, 40, 7, 57, 2, 42, 8, 49, 3, 60, 1, 20, 6, 27, 5, 72, 0, 22, 
    4, 89, 8, 10, 5, 10, 1, 43, 0, 60, 3, 23, 2, 34, 6, 94, 7, 57
  };
  const int q6036[] = {
    9, 9, // Number of jobs and machines
    1, 49, 8, 56, 7, 54, 3, 78, 5, 93, 6, 59, 4, 40, 2,  3, 0, 99, 
    5, 53, 8, 59, 6, 85, 2, 35, 4, 84, 0, 53, 3, 38, 7, 55, 1, 88, 
    0, 47, 3, 20, 4, 44, 5, 74, 8, 16, 6, 76, 1, 64, 2, 83, 7, 24, 
    8, 59, 0, 96, 3, 39, 2, 65, 1, 53, 6, 20, 4, 71, 7, 72, 5, 79, 
    7, 13, 3, 57, 4, 40, 6, 13, 0, 26, 5, 89, 8, 91, 1, 43, 2, 33, 
    1, 13, 0, 99, 4, 36, 3, 75, 5, 83, 7, 82, 2, 42, 6, 54, 8, 86, 
    7, 59, 2, 81, 5,  4, 1, 48, 4, 97, 8, 13, 6, 48, 3, 75, 0, 30, 
    0, 97, 5, 56, 1, 43, 6, 21, 8, 29, 3, 74, 7,  4, 4, 99, 2, 55, 
    8,  1, 2, 62, 1, 35, 5,  7, 0, 32, 4, 51, 7, 70, 3, 87, 6, 15
  };
  const int q6037[] = {
    9, 9, // Number of jobs and machines
    5, 91, 1, 67, 0, 29, 6,  7, 4, 26, 8, 71, 2, 62, 3,  9, 7, 88, 
    6, 64, 3, 31, 4, 72, 1, 87, 2, 64, 8, 90, 7, 94, 0, 19, 5, 89, 
    4, 46, 7, 61, 1, 96, 2, 85, 5, 27, 6, 49, 8, 52, 0, 60, 3, 57, 
    2, 73, 7, 54, 1, 47, 4, 71, 3, 61, 6, 81, 5, 40, 8, 43, 0, 73, 
    0, 67, 5, 99, 1, 73, 2, 20, 4, 27, 7, 22, 6,  6, 8, 76, 3, 58, 
    0,  7, 1, 54, 4, 70, 8, 59, 5, 77, 3, 42, 2, 63, 6, 92, 7, 86, 
    7, 80, 1, 37, 4,  4, 2, 31, 8, 33, 3, 35, 6, 18, 0,  6, 5, 41, 
    8, 42, 2,  7, 6, 80, 5, 39, 0, 66, 4, 71, 1, 69, 3, 67, 7, 35, 
    3, 87, 7, 45, 1,  9, 5, 50, 4,  2, 8,  5, 6, 98, 0, 20, 2, 66
  };
  const int q6038[] = {
    9, 9, // Number of jobs and machines
    3, 93, 5, 17, 7, 95, 1, 36, 6, 86, 0, 96, 4, 73, 8, 77, 2,  9, 
    1, 87, 8, 51, 3, 96, 5, 19, 2, 91, 7, 37, 6, 56, 4, 25, 0, 21, 
    2, 25, 6, 57, 8, 41, 7, 92, 5, 70, 1, 36, 0,  4, 3, 72, 4, 96, 
    8,  5, 4, 13, 2, 37, 6, 61, 5, 38, 3, 38, 7, 48, 1, 27, 0, 25, 
    4, 78, 2, 80, 0, 18, 7, 39, 6, 15, 1,  4, 5, 77, 3, 94, 8, 75, 
    3, 36, 6, 49, 2, 84, 7, 60, 5, 87, 8, 24, 0, 34, 4, 13, 1, 88, 
    1, 95, 8, 84, 5, 39, 2,  1, 4, 67, 7, 69, 3, 85, 6, 23, 0, 27, 
    7, 34, 0, 83, 6,  4, 1,  6, 2, 40, 5,  6, 3, 90, 8, 47, 4, 97, 
    0, 34, 2, 59, 4, 41, 8,  7, 5, 14, 7,  2, 6, 69, 1, 12, 3, 67
  };
  const int q6039[] = {
    9, 9, // Number of jobs and machines
    6, 38, 1, 79, 8, 21, 4, 89, 3, 11, 5, 10, 7, 49, 0, 61, 2, 68, 
    7, 84, 1, 12, 2, 29, 4, 73, 3, 65, 0,  2, 8, 83, 6, 40, 5, 91, 
    6, 83, 2, 16, 5, 22, 7, 97, 8, 72, 3, 86, 1, 26, 0, 37, 4, 57, 
    5, 14, 6, 73, 4, 86, 1, 85, 7, 72, 0, 68, 3, 99, 2, 42, 8,  7, 
    7, 96, 2, 48, 8,  8, 1, 26, 6, 49, 0, 64, 5, 82, 4, 37, 3, 67, 
    0, 92, 8,  7, 2, 45, 6, 62, 7, 11, 3, 14, 1, 16, 4, 35, 5, 65, 
    3, 58, 0, 26, 2, 50, 1, 27, 8, 43, 6, 24, 4, 25, 5, 75, 7, 98, 
    5, 63, 0, 49, 8, 52, 4,  8, 7, 61, 1, 81, 2, 94, 3, 25, 6, 23, 
    0, 85, 8, 51, 2, 11, 6, 65, 3, 76, 1, 41, 4,  4, 7, 74, 5, 87
  };
  const int q6040[] = {
    9, 9, // Number of jobs and machines
    4, 23, 8, 86, 0, 39, 5, 68, 3, 13, 1,  6, 2, 18, 7, 41, 6, 94, 
    1, 66, 8, 71, 2, 99, 4, 69, 6, 98, 7, 19, 5, 69, 0, 33, 3, 62, 
    3, 35, 5, 53, 1,  4, 6, 92, 0, 92, 2, 21, 4, 39, 7, 26, 8, 18, 
    0, 66, 2, 16, 5, 41, 3, 11, 7, 88, 1, 27, 8, 46, 4, 94, 6, 73, 
    3, 91, 5,  8, 0, 54, 1, 91, 2, 68, 8, 74, 4, 23, 6,  1, 7, 20, 
    4, 67, 1, 76, 3,  9, 8, 67, 0, 77, 6, 59, 2, 18, 5,  9, 7, 63, 
    3,  8, 0, 29, 6, 48, 2, 72, 5, 61, 8, 84, 7, 89, 1,  2, 4, 78, 
    0, 57, 3, 17, 8, 68, 7, 97, 5, 38, 2, 83, 1,  1, 4, 75, 6, 26, 
    8,  9, 5, 11, 1, 11, 0, 44, 7, 31, 4, 55, 3, 29, 6,  6, 2, 87
  };
  const int q6041[] = {
    9, 9, // Number of jobs and machines
    0, 45, 2, 93, 3, 81, 5, 99, 1, 87, 7, 53, 8, 98, 6, 38, 4, 44, 
    8, 21, 5, 42, 2, 35, 3, 70, 7, 64, 1,  8, 0, 61, 4, 62, 6,  7, 
    2, 10, 8, 56, 1, 70, 0, 29, 6, 91, 3,  3, 5, 47, 7, 31, 4, 39, 
    8, 70, 0, 55, 2, 31, 6, 66, 1, 19, 5, 57, 4, 87, 7, 89, 3, 72, 
    4,  2, 0,  2, 8, 57, 5, 58, 3, 31, 7, 94, 6, 20, 2, 99, 1, 37, 
    3, 48, 4, 21, 8, 74, 6, 44, 7, 50, 5, 39, 1, 77, 0, 86, 2, 16, 
    3, 18, 4, 21, 0, 49, 7, 44, 5, 81, 8, 94, 6, 43, 1, 10, 2, 84, 
    2, 67, 5, 38, 8, 56, 3, 97, 7, 87, 4, 64, 1, 47, 6, 35, 0, 38, 
    5, 95, 2, 50, 8, 24, 4,  8, 3, 24, 6, 55, 7, 43, 0, 55, 1, 39
  };
  const int q6042[] = {
    9, 9, // Number of jobs and machines
    6, 78, 2, 93, 4, 27, 0, 32, 8, 58, 1, 57, 7, 19, 3, 88, 5, 19, 
    4,  8, 1, 23, 6, 38, 7, 50, 5, 36, 2, 32, 3, 10, 0, 72, 8, 83, 
    2, 43, 3, 86, 0, 72, 4, 64, 5, 33, 6, 94, 1, 66, 7, 91, 8, 11, 
    7, 47, 2, 98, 4, 26, 3, 48, 6, 33, 0, 52, 1,  6, 5, 27, 8, 93, 
    8, 94, 7, 55, 5, 49, 0, 40, 3, 21, 2, 89, 1, 26, 6, 32, 4, 40, 
    3, 79, 7, 52, 2, 58, 8, 80, 0, 19, 5, 40, 6, 40, 4, 68, 1, 12, 
    1, 82, 7, 13, 8, 80, 5, 10, 2, 10, 3, 16, 0, 60, 6, 26, 4, 71, 
    5, 62, 7, 87, 6,  3, 4, 85, 8, 11, 2, 32, 0, 69, 3, 71, 1, 54, 
    7, 59, 1, 98, 8, 42, 0, 25, 6, 14, 3, 27, 5,  6, 2, 60, 4, 82
  };
  const int q6043[] = {
    9, 9, // Number of jobs and machines
    7, 29, 4, 99, 1, 32, 0, 33, 2, 80, 5,  8, 6, 39, 8, 39, 3, 23, 
    7, 32, 4,  8, 8, 48, 0, 97, 3, 17, 1, 66, 2, 15, 5, 27, 6,  3, 
    4, 47, 0, 48, 6, 60, 3, 50, 5, 23, 1, 25, 2, 41, 7, 28, 8,  6, 
    4, 63, 0, 27, 6, 24, 2,  9, 1, 12, 3,  6, 5, 27, 8, 29, 7, 95, 
    4, 98, 7, 46, 3,  3, 2, 26, 1, 45, 5, 52, 8, 62, 6, 40, 0, 50, 
    1, 64, 7,  4, 8, 46, 2, 55, 5,  5, 4, 64, 3, 79, 0, 10, 6, 48, 
    4,  4, 8, 20, 3, 15, 1, 27, 0, 74, 2, 35, 7, 85, 5, 98, 6,  1, 
    0, 74, 8, 23, 6, 86, 3, 41, 2, 15, 7, 36, 5, 94, 1, 70, 4, 66, 
    3, 51, 0, 82, 4, 13, 5, 36, 8, 63, 1, 74, 7,  8, 6, 95, 2, 10
  };
  const int q6044[] = {
    9, 9, // Number of jobs and machines
    2,  6, 7, 69, 3, 90, 0, 83, 1, 80, 5, 54, 4,  4, 8, 69, 6, 90, 
    8, 18, 4, 41, 0, 84, 2, 48, 5, 18, 7,  5, 3, 23, 1, 23, 6, 81, 
    7, 91, 1, 55, 5, 88, 3, 94, 8, 47, 4, 36, 2, 38, 0, 53, 6, 48, 
    1, 52, 4, 64, 8, 68, 3, 83, 2,  4, 5, 79, 0, 50, 6,  3, 7, 18, 
    4, 80, 0, 50, 1, 49, 5, 99, 7, 23, 3, 92, 6, 67, 2,  9, 8, 91, 
    0,  7, 6,  7, 4, 63, 2, 85, 3, 69, 7, 97, 8, 12, 5, 72, 1, 85, 
    3, 83, 7,  2, 8, 53, 1, 79, 6, 42, 4, 52, 2, 39, 0, 51, 5, 35, 
    7, 66, 4, 53, 8, 28, 3, 51, 1,  8, 5, 60, 6, 37, 0, 86, 2, 70, 
    4,  3, 6, 15, 2, 88, 7,  6, 5, 43, 8, 45, 0, 79, 1, 29, 3, 59
  };
  const int q6045[] = {
    9, 9, // Number of jobs and machines
    3, 87, 0, 79, 6, 28, 5, 20, 1, 34, 4, 28, 7, 24, 2,  1, 8, 86, 
    2, 24, 7, 89, 5, 25, 6, 56, 3, 82, 0, 91, 1, 80, 4, 35, 8, 88, 
    6, 68, 4, 44, 0, 16, 5, 72, 3, 91, 1,  6, 7, 41, 8, 10, 2, 42, 
    7, 44, 3,  2, 6, 73, 2, 87, 4,  3, 8, 14, 5, 85, 1, 80, 0, 73, 
    6, 13, 5, 36, 0, 46, 3, 80, 2, 34, 4, 98, 8, 11, 7, 54, 1, 60, 
    2, 62, 1, 25, 4, 48, 8,  8, 6, 98, 7, 83, 5, 93, 0, 13, 3, 39, 
    8, 36, 6, 52, 5, 93, 1, 91, 7, 45, 2, 40, 3, 42, 4, 50, 0,  1, 
    8, 50, 7, 31, 1, 15, 2, 45, 6, 51, 0, 61, 5,  4, 4, 89, 3, 17, 
    1, 39, 7, 78, 3, 74, 5, 26, 2, 42, 8, 36, 4, 71, 6, 67, 0,  4
  };
  const int q6046[] = {
    9, 9, // Number of jobs and machines
    2, 53, 5, 61, 0, 43, 1, 45, 4,  2, 3, 71, 8, 19, 6, 81, 7, 19, 
    4, 36, 1, 37, 5, 12, 8, 38, 7, 66, 0, 68, 2, 38, 3, 39, 6, 90, 
    1, 25, 8,  8, 7, 15, 3, 81, 4, 26, 2,  2, 0, 74, 5, 26, 6, 14, 
    8, 69, 6, 11, 7, 18, 0, 50, 1, 94, 5, 71, 2, 39, 4, 18, 3, 40, 
    6, 76, 5, 85, 7, 31, 4, 36, 2, 78, 1, 58, 0, 14, 3, 43, 8, 84, 
    5, 29, 4, 76, 7, 49, 3, 89, 6, 48, 8, 61, 1, 64, 2, 54, 0, 41, 
    7,  3, 4, 92, 3, 54, 6, 13, 2, 57, 5, 30, 1, 72, 8, 93, 0, 86, 
    0, 39, 8, 19, 1, 41, 5, 76, 2, 13, 3, 11, 6, 62, 7, 49, 4, 20, 
    4, 37, 8, 99, 7, 23, 6, 36, 1, 52, 5, 98, 0, 89, 3, 39, 2, 56
  };
  const int q6047[] = {
    9, 9, // Number of jobs and machines
    2, 39, 7, 50, 0, 15, 3, 93, 8,  9, 5, 21, 1, 23, 4, 29, 6, 39, 
    6, 11, 4, 65, 7, 85, 5, 94, 8, 17, 2, 19, 1, 31, 0, 51, 3,  3, 
    2, 66, 8, 50, 0, 38, 5, 97, 4, 66, 7, 19, 3,  7, 1, 38, 6, 38, 
    5,  9, 7, 10, 6, 63, 1, 44, 4, 31, 3, 87, 8, 98, 2, 88, 0, 53, 
    6, 70, 0, 12, 3, 43, 5, 13, 7, 78, 8, 41, 2, 72, 1, 37, 4, 69, 
    3, 88, 5, 55, 0, 82, 8, 25, 2, 35, 4, 57, 7, 44, 6, 52, 1, 69, 
    8,  7, 0, 91, 5, 93, 7, 12, 6, 15, 2, 37, 3, 29, 4, 45, 1,  7, 
    8, 41, 4, 59, 0, 35, 6, 14, 2, 39, 5, 81, 7, 39, 1, 20, 3, 16, 
    7, 62, 4, 69, 5, 40, 3, 64, 6, 78, 2, 45, 8, 56, 0, 98, 1,  4
  };
  const int q6048[] = {
    9, 9, // Number of jobs and machines
    7, 23, 8,  2, 4, 30, 2, 23, 3, 35, 6, 64, 0, 60, 1, 42, 5, 90, 
    6, 55, 8, 64, 3, 47, 0, 55, 4, 13, 2,  5, 1, 18, 7, 48, 5, 31, 
    6, 24, 2, 93, 5, 64, 3,  8, 4, 39, 8, 20, 0, 52, 1, 27, 7, 33, 
    4, 65, 3, 58, 7, 20, 6, 77, 5, 36, 1, 92, 0, 75, 8, 67, 2, 42, 
    7,  3, 0, 78, 3, 55, 2, 36, 1, 79, 6, 28, 8, 84, 5, 38, 4, 90, 
    3, 39, 2, 17, 0, 27, 5, 29, 1,  8, 8, 18, 4, 16, 6, 48, 7, 69, 
    7, 48, 8, 76, 3, 58, 4, 65, 2, 14, 0, 91, 5, 74, 1, 93, 6, 47, 
    2, 35, 4, 99, 7, 32, 6, 42, 0, 19, 8, 83, 1, 49, 5, 64, 3, 61, 
    7, 88, 4, 72, 1, 50, 3, 44, 0,  8, 5, 22, 2, 51, 8, 33, 6, 61
  };
  const int q6049[] = {
    9, 9, // Number of jobs and machines
    6, 70, 2, 48, 0, 25, 8, 28, 5,  3, 4,  4, 3, 65, 7, 63, 1, 54, 
    1, 60, 6, 39, 3, 36, 8, 72, 0, 90, 4, 81, 7, 59, 5, 19, 2, 59, 
    8, 28, 1, 87, 5, 51, 7, 37, 3, 76, 2,  9, 0, 59, 4, 35, 6, 20, 
    0, 57, 5, 47, 4, 49, 1, 23, 3, 26, 7, 45, 2, 55, 8, 62, 6, 84, 
    3, 63, 7, 31, 4,  6, 8, 49, 0, 53, 2, 66, 1, 55, 6, 21, 5, 93, 
    5, 48, 4, 85, 0,  5, 1, 41, 3, 92, 7, 17, 2, 35, 8, 67, 6, 94, 
    8,  9, 6, 72, 1, 71, 2,  8, 5, 25, 7, 24, 0, 44, 3, 26, 4, 51, 
    5,  1, 0, 23, 4, 23, 1, 38, 8, 70, 7, 66, 2,  6, 6, 21, 3, 64, 
    3, 28, 4, 28, 5, 15, 6, 57, 0, 44, 7, 35, 2, 30, 1, 65, 8, 11
  };
  const int q6050[] = {
    9, 9, // Number of jobs and machines
    8, 40, 4, 56, 6, 58, 0, 90, 7, 58, 1, 71, 2, 58, 3, 86, 5, 55, 
    7, 27, 5, 64, 0, 40, 8, 25, 2, 23, 3, 64, 4, 49, 1, 91, 6, 22, 
    4, 86, 8,  5, 5, 52, 0, 87, 3,  9, 2, 24, 7,  8, 1, 81, 6, 51, 
    8, 48, 5, 99, 0, 25, 3, 35, 1, 96, 7, 11, 4, 76, 2,  4, 6, 21, 
    5, 11, 7, 56, 1, 47, 0, 93, 2, 14, 6, 52, 4, 21, 8,  4, 3, 94, 
    3, 38, 7, 46, 6, 81, 2, 84, 4, 72, 5,  6, 0, 43, 1, 78, 8, 43, 
    7, 58, 2,  2, 1, 55, 0, 95, 6, 18, 3, 29, 8,  2, 4, 31, 5, 38, 
    4, 96, 6, 32, 5,  5, 2, 65, 1, 69, 8, 87, 0, 32, 3, 78, 7, 24, 
    0, 52, 8, 47, 3, 69, 6, 94, 7, 38, 4, 19, 1, 44, 5, 58, 2, 62
  };
  const int q6051[] = {
    9, 9, // Number of jobs and machines
    8, 54, 7, 11, 0, 65, 1, 39, 2, 66, 6, 66, 4, 71, 5, 89, 3,  5, 
    6, 51, 8, 87, 1, 90, 3, 33, 5, 47, 7,  4, 2, 72, 4, 97, 0, 10, 
    0, 81, 7, 82, 5, 69, 6, 82, 2, 54, 8, 59, 3, 74, 1, 17, 4, 71, 
    0, 95, 3, 79, 5, 83, 4, 64, 7, 34, 1, 35, 8, 26, 6, 77, 2,  8, 
    1, 82, 0, 15, 8, 16, 6, 13, 5, 66, 4, 43, 2, 45, 3, 87, 7, 23, 
    1, 96, 8, 48, 7, 79, 0,  1, 6, 16, 4,  7, 2, 95, 5, 83, 3, 31, 
    4, 45, 7, 85, 0, 85, 8, 49, 2, 70, 6, 38, 3, 28, 5, 77, 1, 38, 
    5, 84, 4, 59, 1, 91, 2, 78, 6, 22, 0, 14, 3, 73, 7, 22, 8, 19, 
    7, 25, 5, 43, 6, 67, 1, 14, 4, 97, 3, 85, 8, 17, 0, 76, 2,  6
  };
  const int q6052[] = {
    9, 9, // Number of jobs and machines
    0, 92, 6, 50, 3, 55, 7, 40, 5, 44, 2, 86, 1, 68, 4, 81, 8, 83, 
    4, 51, 7, 18, 1,  3, 2, 33, 8, 27, 0, 92, 6, 82, 3, 61, 5, 11, 
    2, 66, 7, 32, 5, 31, 4, 16, 8, 76, 1, 58, 3, 30, 6, 62, 0, 18, 
    1,  6, 0, 64, 8, 36, 4, 24, 5, 44, 6, 72, 3, 19, 7, 79, 2, 34, 
    4, 18, 3, 16, 7, 65, 5, 82, 8, 66, 1, 66, 6, 74, 2, 50, 0, 32, 
    4,  2, 8, 71, 5, 52, 3,  8, 2, 18, 6, 27, 1, 46, 7, 72, 0, 76, 
    2, 13, 5,  2, 7, 87, 6, 78, 4,  4, 3, 27, 0, 12, 1, 85, 8, 78, 
    5, 16, 7, 29, 6, 64, 3, 71, 1, 64, 2, 33, 4, 60, 8, 86, 0, 51, 
    4, 49, 0, 53, 3, 41, 5, 10, 2, 77, 6, 40, 1, 62, 8, 11, 7, 58
  };
  const int q6053[] = {
    9, 9, // Number of jobs and machines
    4, 30, 6, 66, 2,  1, 0, 60, 1, 57, 8, 50, 5, 67, 3, 15, 7, 97, 
    4, 60, 7, 10, 2, 40, 3, 29, 1,  6, 6, 62, 5, 64, 8, 29, 0, 35, 
    0, 28, 3, 53, 7, 35, 5, 95, 4,  9, 1, 49, 8,  3, 2, 46, 6, 80, 
    3,  1, 0, 43, 7, 75, 5, 82, 1, 19, 6, 43, 4, 23, 8, 13, 2, 64, 
    8, 59, 5, 94, 1,  1, 7, 61, 6,  7, 3, 61, 4, 20, 0,  3, 2,  2, 
    5, 71, 1, 40, 4,  9, 7, 70, 3, 82, 2, 11, 8, 87, 6, 67, 0, 49, 
    6, 91, 0, 90, 2, 97, 5, 91, 1, 60, 4, 56, 8, 17, 7, 47, 3, 99, 
    7, 36, 5, 41, 8, 81, 6, 78, 4, 48, 3, 38, 2, 98, 0, 93, 1, 51, 
    5, 52, 0, 47, 1, 76, 3, 13, 8, 98, 2, 98, 4,  7, 6, 74, 7, 11
  };
  const int q6054[] = {
    9, 9, // Number of jobs and machines
    1, 52, 2, 66, 6, 58, 3, 52, 5, 68, 8, 41, 7, 17, 0, 80, 4, 78, 
    2, 61, 5,  4, 8, 91, 7, 61, 6, 19, 3, 98, 1, 28, 4, 62, 0, 33, 
    5, 58, 1, 48, 7, 92, 0, 89, 2, 41, 3, 28, 4, 48, 8, 83, 6, 70, 
    0, 53, 6, 71, 7, 91, 8, 88, 1, 91, 5, 88, 4,  1, 3, 92, 2, 65, 
    8, 25, 3, 56, 6, 39, 2, 91, 5, 74, 0, 60, 7, 51, 4, 77, 1, 78, 
    1, 30, 5, 79, 0, 80, 2,  8, 8, 67, 3, 62, 7, 92, 6,  9, 4, 63, 
    4, 43, 6,  1, 0, 16, 7, 40, 8, 31, 5, 86, 1, 33, 3, 98, 2, 66, 
    5, 56, 3, 79, 2, 85, 7, 94, 6, 21, 4, 80, 1,  1, 0, 37, 8, 42, 
    5, 35, 0, 22, 4, 72, 6, 57, 7,  6, 1, 33, 3,  4, 2, 15, 8, 70
  };
  const int q6055[] = {
    9, 9, // Number of jobs and machines
    2, 12, 6,  1, 3, 92, 4, 16, 7, 40, 1, 29, 0, 72, 8,  4, 5, 14, 
    1,  5, 3, 95, 6, 37, 8, 69, 2, 98, 0, 85, 4, 39, 5, 65, 7,  1, 
    2, 84, 1, 80, 8, 43, 0, 28, 3, 81, 7, 59, 6, 46, 4, 63, 5,  7, 
    3, 67, 0, 86, 1, 34, 8, 71, 2,  1, 4, 92, 5, 76, 6, 72, 7, 56, 
    8, 96, 1,  4, 6, 77, 4, 21, 5,  8, 7,  4, 2, 94, 3,  5, 0,  2, 
    1, 35, 4, 49, 5, 10, 2, 72, 8, 70, 3, 68, 0, 25, 7, 75, 6, 61, 
    3, 97, 6, 60, 7, 87, 2, 41, 0, 78, 5, 97, 4,  3, 1, 12, 8, 27, 
    7, 70, 1, 58, 5, 21, 6, 29, 3, 12, 0, 19, 4, 50, 8, 46, 2, 69, 
    4, 83, 6, 57, 8, 60, 7, 17, 2, 45, 0, 92, 1, 16, 5, 28, 3, 19
  };
  const int q6056[] = {
    9, 9, // Number of jobs and machines
    4, 28, 0, 10, 1, 91, 7, 34, 8, 92, 2, 75, 3, 34, 6, 43, 5,  7, 
    8,  4, 5, 71, 2, 80, 7, 16, 4, 87, 1, 45, 6, 67, 0, 23, 3,  6, 
    3, 45, 4, 43, 8, 71, 1, 39, 0, 19, 5, 88, 2, 85, 6, 92, 7, 99, 
    3,  9, 4, 88, 7, 54, 8, 40, 0, 45, 6, 14, 5, 13, 2, 52, 1, 40, 
    4, 38, 2, 19, 1,  9, 8, 20, 0, 20, 6, 50, 7, 27, 3, 49, 5, 26, 
    2, 49, 1, 45, 8, 65, 3, 87, 4, 47, 7, 47, 0, 62, 6, 10, 5, 31, 
    2, 63, 5, 23, 3, 48, 4, 63, 8, 94, 6, 22, 7, 32, 0, 23, 1, 81, 
    4, 74, 7, 89, 1, 60, 6, 86, 3, 89, 5, 95, 8, 53, 2, 44, 0,  1, 
    1, 29, 8, 18, 5, 94, 2, 84, 4, 70, 0, 92, 7, 35, 3, 53, 6, 96
  };
  const int q6057[] = {
    9, 9, // Number of jobs and machines
    8, 31, 1, 12, 6, 91, 4, 48, 5, 79, 3, 51, 2,  5, 7, 16, 0, 61, 
    5, 78, 2,  3, 3,  6, 6, 70, 0, 28, 4,  8, 1, 34, 7,  7, 8, 66, 
    6, 83, 2, 65, 5, 90, 8, 85, 4, 62, 0, 36, 3, 39, 1, 62, 7, 70, 
    3, 46, 6, 79, 1, 85, 4, 52, 2, 50, 5, 85, 7, 48, 0, 77, 8, 69, 
    1, 10, 0, 59, 7, 61, 6, 52, 8, 91, 5, 72, 4, 90, 2, 87, 3, 43, 
    4, 79, 0, 20, 1, 47, 7, 85, 2, 12, 8, 56, 6, 63, 5, 57, 3, 71, 
    8, 87, 3, 67, 7, 44, 0, 86, 5, 36, 1, 18, 6, 11, 4, 81, 2, 35, 
    5, 91, 0, 39, 8,  5, 3, 80, 1, 66, 2, 87, 7, 66, 6, 64, 4, 55, 
    0, 51, 2, 59, 4, 32, 1, 95, 7, 70, 3, 32, 5, 84, 8, 32, 6, 42
  };
  const int q6058[] = {
    9, 9, // Number of jobs and machines
    8, 57, 5, 53, 6, 62, 2, 13, 3, 74, 0,  2, 1, 53, 4, 12, 7, 11, 
    2, 36, 0, 71, 7, 63, 8, 11, 5, 23, 4, 72, 1,  4, 3, 28, 6, 34, 
    6, 91, 7, 44, 4, 50, 8, 10, 2, 60, 5, 27, 3, 22, 0, 68, 1, 98, 
    1, 99, 7, 65, 3, 86, 8, 58, 2, 49, 4, 56, 5, 18, 6, 11, 0, 86, 
    4, 11, 2,  4, 5, 48, 3, 98, 7, 13, 0, 24, 8, 37, 1, 69, 6, 50, 
    5, 56, 3, 89, 8, 75, 2, 57, 0, 46, 1, 13, 7, 45, 6, 58, 4, 52, 
    5, 85, 8, 13, 2, 32, 7, 97, 0, 41, 6, 93, 4,  6, 1, 13, 3, 10, 
    2, 38, 5, 86, 7, 88, 0, 85, 1, 16, 8, 65, 6, 88, 4, 46, 3, 28, 
    4, 48, 8, 33, 2, 77, 3, 75, 7, 79, 5, 53, 0, 46, 6, 87, 1, 39
  };
  const int q6059[] = {
    9, 9, // Number of jobs and machines
    3, 14, 5, 69, 0,  1, 1, 90, 6, 13, 4,  5, 2,  1, 7, 41, 8, 88, 
    4, 26, 3, 89, 1, 94, 2, 50, 6, 15, 5,  2, 0, 53, 8, 92, 7, 55, 
    0, 50, 2, 39, 7, 93, 8, 35, 3, 46, 1,  9, 4, 91, 5, 57, 6, 87, 
    5, 22, 4, 51, 7, 76, 0, 97, 8, 46, 1, 90, 2, 42, 3, 94, 6, 31, 
    4, 48, 6, 93, 0, 53, 7, 95, 1, 69, 3, 57, 8,  8, 5, 61, 2, 12, 
    1, 79, 0, 12, 7, 82, 3, 83, 4, 39, 2, 88, 5, 28, 6, 27, 8, 86, 
    8, 25, 6, 35, 2, 32, 4, 94, 5, 82, 0, 31, 3, 30, 7, 10, 1, 14, 
    0, 85, 8, 54, 2, 54, 3, 94, 7, 96, 6, 19, 1, 49, 5, 27, 4, 36, 
    3, 13, 8, 36, 4, 67, 7, 21, 1, 31, 6, 75, 0, 72, 5, 79, 2, 76
  };
  const int q6060[] = {
    9, 9, // Number of jobs and machines
    4, 12, 2, 47, 3, 36, 7, 88, 0, 57, 6, 77, 8, 49, 5, 97, 1, 81, 
    2, 95, 6, 89, 3, 13, 5, 49, 7, 16, 4, 94, 0,  5, 8, 32, 1,  4, 
    0, 21, 3, 17, 7, 96, 4, 20, 5, 65, 2, 77, 6,  9, 1, 46, 8, 46, 
    1, 33, 5, 47, 3, 94, 6, 57, 8,  3, 7, 28, 0, 98, 4, 68, 2, 51, 
    3, 95, 1, 39, 2, 98, 7, 94, 6, 61, 5, 50, 0, 42, 4, 42, 8, 10, 
    7, 51, 1, 49, 5, 12, 3, 96, 2, 56, 0, 53, 4, 19, 6, 79, 8, 25, 
    4, 64, 8, 31, 2, 10, 0, 83, 7, 57, 6, 64, 1, 56, 3, 41, 5, 16, 
    7, 99, 0,  1, 2, 46, 8, 36, 3,  6, 4, 30, 5, 92, 6, 25, 1, 32, 
    0, 82, 8, 91, 1, 57, 5, 32, 3,  7, 6, 81, 4, 82, 7, 81, 2, 15
  };
  const int q6061[] = {
    9, 9, // Number of jobs and machines
    6, 58, 4, 73, 2, 52, 1, 13, 8, 12, 5,  7, 0, 43, 7, 42, 3, 96, 
    2, 16, 5, 80, 3, 56, 4, 77, 6, 40, 1, 40, 7, 63, 8, 12, 0, 64, 
    7, 18, 0, 94, 1, 41, 4, 81, 2, 56, 3, 53, 8, 43, 6, 67, 5, 24, 
    1, 41, 4, 10, 8, 26, 6, 70, 5, 78, 2, 53, 0, 19, 7, 11, 3, 45, 
    5, 91, 1, 25, 8,  5, 4, 54, 7, 79, 0, 82, 6, 19, 3, 88, 2, 78, 
    8, 10, 7, 29, 5, 80, 6, 63, 0, 16, 1, 71, 4, 24, 2, 89, 3, 63, 
    7, 43, 5, 14, 6, 45, 0, 55, 8,  4, 2, 40, 4, 59, 3, 99, 1, 46, 
    4, 94, 3, 83, 0,  4, 1, 17, 2, 88, 8, 25, 7, 71, 6, 46, 5, 62, 
    0, 16, 6, 85, 5, 46, 7, 46, 1, 26, 8, 88, 2, 25, 3, 67, 4, 42
  };
  const int q6062[] = {
    9, 9, // Number of jobs and machines
    4,  4, 2, 58, 8,  2, 7, 61, 0, 34, 6, 43, 1, 61, 3, 62, 5, 57, 
    7, 42, 5, 80, 6, 51, 4, 93, 0, 31, 3, 53, 2, 13, 8, 70, 1, 85, 
    3, 46, 0, 41, 8, 16, 4, 99, 2, 68, 6, 66, 1, 21, 5, 54, 7, 91, 
    7, 13, 0, 21, 2, 73, 6, 25, 1, 91, 4, 65, 3, 21, 8, 66, 5, 70, 
    3, 83, 1, 45, 0, 69, 4,  5, 5, 89, 8, 25, 6, 30, 7, 94, 2, 86, 
    0, 94, 2, 15, 4, 56, 6, 94, 1, 10, 7, 75, 3, 26, 5, 28, 8, 17, 
    7, 76, 3, 25, 0, 90, 5, 48, 2, 55, 8, 57, 4, 31, 1, 96, 6, 56, 
    2, 97, 3, 15, 7, 38, 1, 82, 6, 57, 0,  1, 4, 86, 5, 86, 8,  8, 
    4, 21, 2, 36, 7,  7, 6, 84, 0, 78, 8, 79, 1, 22, 3,  9, 5, 60
  };
  const int q6063[] = {
    9, 9, // Number of jobs and machines
    1, 56, 2, 78, 5, 56, 3, 33, 7, 84, 4, 31, 8,  6, 6, 62, 0, 32, 
    6, 50, 1, 23, 7, 53, 8, 51, 0, 27, 4, 67, 3, 92, 5, 84, 2, 98, 
    3, 55, 2, 32, 5, 94, 4, 17, 1, 59, 8, 83, 6, 64, 0, 11, 7, 82, 
    8, 15, 7, 13, 1, 44, 3, 45, 4, 53, 6,  7, 0, 91, 5, 85, 2, 57, 
    6, 70, 1, 86, 0, 14, 2, 93, 3, 73, 4, 38, 7, 70, 8, 48, 5, 29, 
    0,  5, 7, 68, 2,  3, 8, 94, 6, 58, 5, 65, 3, 84, 4, 70, 1, 48, 
    4, 53, 5, 46, 3, 99, 6, 78, 1,  6, 7, 94, 2, 38, 0, 21, 8, 98, 
    5, 32, 2,  5, 7, 92, 1, 43, 3, 22, 0, 27, 4, 20, 8, 43, 6, 45, 
    7, 69, 2, 40, 1, 61, 0, 45, 6, 43, 5, 75, 3, 70, 4, 63, 8, 70
  };
  const int q6064[] = {
    9, 9, // Number of jobs and machines
    6, 80, 5,  2, 3, 68, 7, 81, 8, 36, 4, 71, 1,  6, 0, 29, 2, 29, 
    3, 40, 6, 82, 2, 49, 5, 36, 8, 46, 1, 12, 0,  4, 4,  1, 7, 11, 
    5, 60, 2, 82, 6,  4, 8, 85, 3, 78, 7, 84, 4,  1, 1, 27, 0,  5, 
    2, 52, 5, 25, 6,  8, 7, 43, 8, 99, 4, 34, 0, 53, 3, 15, 1, 96, 
    5,  5, 0, 10, 2, 46, 1, 83, 8, 18, 7, 23, 6, 48, 4, 27, 3, 28, 
    3, 30, 2, 81, 1, 14, 5,  2, 0, 61, 6, 81, 7, 37, 8, 32, 4, 96, 
    2, 82, 6, 50, 7, 75, 4, 21, 1, 98, 0, 63, 8, 79, 5, 25, 3, 28, 
    3, 42, 1, 11, 2, 34, 4, 11, 6,  3, 0, 84, 5, 40, 8, 30, 7, 84, 
    5, 93, 2, 19, 3, 38, 8, 49, 1, 95, 7, 81, 0, 51, 6, 40, 4, 50
  };
  const int q6065[] = {
    9, 9, // Number of jobs and machines
    0, 13, 3, 28, 1, 85, 8, 17, 2, 83, 6, 69, 4,  1, 5,  5, 7, 79, 
    2, 64, 7, 18, 6, 70, 0, 50, 1, 64, 4, 63, 3, 13, 5, 58, 8, 36, 
    5, 74, 7, 91, 6, 58, 0, 31, 2,  3, 4, 84, 3, 96, 1, 46, 8, 15, 
    3, 15, 2,  8, 6, 55, 4, 40, 7, 19, 5, 67, 1, 85, 0, 37, 8, 14, 
    5, 32, 3, 13, 2, 39, 0, 67, 8, 70, 6, 48, 1, 22, 4, 73, 7, 72, 
    6, 38, 2, 58, 1, 56, 7, 18, 8,  5, 0, 97, 4, 11, 5, 54, 3, 44, 
    6,  2, 5, 54, 4, 48, 3,  1, 1, 55, 0, 70, 8, 20, 2, 83, 7, 31, 
    2, 18, 7,  2, 4, 35, 5, 95, 6, 35, 3, 98, 0, 70, 1, 74, 8, 95, 
    3, 80, 0, 58, 4,  6, 6,  6, 5, 61, 1, 67, 2, 68, 7, 20, 8, 66
  };
  const int q6066[] = {
    9, 9, // Number of jobs and machines
    5, 72, 8, 84, 6, 85, 4, 15, 0,  4, 3, 67, 7, 85, 1, 99, 2, 38, 
    5, 83, 0, 85, 7, 66, 1,  4, 4, 89, 2, 52, 3, 78, 8, 72, 6, 16, 
    8, 41, 0, 93, 7, 35, 6, 45, 5, 59, 2, 28, 1, 53, 3, 38, 4,  2, 
    5, 15, 7,  4, 3, 69, 0, 57, 8, 95, 2, 46, 1, 95, 6, 42, 4, 63, 
    8, 46, 4, 62, 2, 63, 1, 65, 0, 98, 6, 49, 3, 33, 7, 83, 5, 84, 
    7, 95, 8, 92, 0, 38, 5, 10, 2, 96, 1, 62, 3, 82, 6,  5, 4, 92, 
    0, 23, 2, 95, 4, 83, 1, 40, 6, 14, 8, 38, 3, 54, 5, 98, 7, 47, 
    7, 76, 6,  4, 1, 56, 4,  9, 5, 72, 8, 73, 3, 59, 0, 34, 2, 26, 
    1, 31, 7, 92, 3, 19, 8, 47, 2,  4, 5, 53, 4, 80, 0, 22, 6, 67
  };
  const int q6067[] = {
    9, 9, // Number of jobs and machines
    2, 85, 7, 38, 5, 12, 4, 61, 8, 60, 3, 84, 0, 24, 6, 96, 1, 15, 
    4, 47, 7, 91, 8,  6, 1, 59, 3, 11, 0, 72, 6, 70, 5, 25, 2, 28, 
    7, 67, 1,  5, 0, 97, 5, 93, 8, 28, 6, 73, 3, 94, 4, 73, 2, 67, 
    7, 72, 3, 95, 0, 79, 8, 80, 2, 19, 5, 94, 1, 13, 4, 49, 6, 14, 
    5,  4, 3, 16, 8, 17, 4, 20, 6, 10, 7, 15, 1, 76, 0, 18, 2, 61, 
    7, 61, 0, 86, 1, 93, 3, 80, 6, 77, 4, 38, 2, 23, 5, 92, 8, 42, 
    1, 90, 0, 12, 7,  2, 3, 94, 8, 95, 2, 85, 6, 75, 4, 19, 5, 52, 
    7, 65, 2, 65, 5, 54, 3,  4, 8, 45, 6, 73, 0, 15, 1, 30, 4, 49, 
    8, 45, 7, 30, 5, 69, 2, 24, 1, 92, 6, 89, 3, 51, 0, 22, 4, 71
  };
  const int q6068[] = {
    9, 9, // Number of jobs and machines
    1, 15, 6, 54, 5, 50, 0, 99, 4, 28, 7, 25, 8, 94, 2, 32, 3, 37, 
    0, 37, 2, 42, 5, 21, 3,  4, 1, 81, 4, 11, 8, 27, 7, 91, 6,  2, 
    1, 80, 8, 19, 6, 59, 0, 76, 2, 79, 3, 52, 7, 56, 4, 39, 5, 54, 
    2, 35, 6, 49, 4, 22, 5, 82, 3, 21, 0, 45, 8, 61, 7, 17, 1, 19, 
    6, 74, 7, 87, 3, 33, 8, 42, 1, 34, 0, 55, 4, 59, 2, 78, 5, 62, 
    3, 51, 8, 33, 5, 93, 6, 63, 7, 95, 2, 47, 0, 90, 4,  4, 1, 70, 
    8, 52, 2, 81, 0, 73, 4, 32, 6,  6, 5, 64, 1, 15, 7, 74, 3, 35, 
    8, 26, 6, 11, 1, 26, 3, 59, 4, 42, 5,  3, 2, 72, 0, 76, 7, 68, 
    6, 74, 5, 47, 3, 46, 4, 98, 7,  4, 0, 88, 8, 72, 2, 43, 1, 46
  };
  const int q6069[] = {
    9, 9, // Number of jobs and machines
    2, 92, 3, 91, 7, 38, 6, 39, 0, 33, 5, 86, 8, 81, 4, 66, 1, 84, 
    5, 64, 8,  9, 4,  3, 7,  9, 6, 53, 0, 52, 2, 22, 3, 48, 1, 60, 
    2, 96, 1, 59, 8,  8, 0,  1, 4, 16, 7, 50, 6,  2, 5, 88, 3, 33, 
    0, 70, 2,  1, 4, 58, 3,  9, 6, 88, 1, 66, 7, 71, 5, 79, 8, 13, 
    3, 96, 4, 66, 6, 10, 5, 27, 2,  4, 0,  8, 1,  8, 8, 81, 7, 13, 
    8, 17, 5, 84, 3, 23, 1, 78, 7, 24, 6, 47, 4, 68, 2, 32, 0, 66, 
    5, 31, 0, 30, 4,  7, 8, 75, 3, 21, 7, 43, 6, 44, 2, 32, 1, 28, 
    3, 71, 5, 87, 7, 11, 6, 40, 2, 42, 4, 49, 1, 61, 8, 93, 0, 51, 
    5, 23, 4, 85, 3, 73, 8, 42, 0,  6, 2, 92, 6, 88, 1, 39, 7, 93
  };
  const int q6070[] = {
    9, 9, // Number of jobs and machines
    8, 62, 5, 49, 4, 57, 7, 49, 3, 74, 0, 69, 2, 22, 1, 76, 6, 21, 
    8, 98, 7,  8, 6, 85, 0, 45, 4, 11, 5, 49, 2, 50, 1, 30, 3, 28, 
    8, 16, 0, 26, 6,  8, 4, 53, 2, 88, 7, 39, 3, 51, 1, 85, 5,  2, 
    1, 46, 7, 78, 3, 10, 8, 70, 4, 60, 0, 13, 6, 79, 2, 29, 5, 48, 
    4, 25, 1, 49, 3, 64, 6, 47, 0, 18, 5, 31, 7, 57, 8, 70, 2, 23, 
    8, 22, 7, 21, 5, 77, 2,  2, 0, 41, 4, 58, 6, 14, 3, 74, 1, 83, 
    4, 85, 5, 80, 8,  8, 7, 50, 0, 48, 2,  9, 3, 36, 1, 81, 6, 29, 
    8, 91, 7, 99, 4, 35, 5, 44, 0,  1, 6, 41, 3,  3, 1, 80, 2, 42, 
    8, 15, 7, 44, 1, 88, 4,  9, 6, 20, 5, 51, 3, 67, 0, 30, 2, 14
  };
  const int q6071[] = {
    9, 9, // Number of jobs and machines
    5, 49, 6, 79, 1, 49, 4,  6, 0, 23, 2, 23, 8, 68, 3, 61, 7, 37, 
    3, 54, 2,  3, 4, 12, 7, 76, 1, 38, 6, 15, 0,  5, 5, 35, 8, 92, 
    7, 83, 3, 96, 5, 26, 2, 52, 1, 29, 0, 97, 4, 18, 6, 91, 8, 31, 
    5, 61, 6, 55, 1, 45, 4, 83, 8, 86, 0,  8, 2, 69, 3, 76, 7, 35, 
    3, 90, 5, 42, 7, 60, 0, 91, 1, 92, 8, 93, 4, 31, 6, 13, 2, 14, 
    2, 54, 8, 68, 3, 20, 1, 92, 7, 92, 6, 40, 4, 81, 0, 54, 5, 99, 
    0, 95, 1, 90, 3, 77, 5, 26, 2, 27, 6, 94, 7, 90, 8, 10, 4,  3, 
    3, 62, 6, 23, 5, 61, 0, 49, 7, 60, 1, 95, 2,  5, 4, 26, 8, 27, 
    7, 19, 1, 71, 3, 82, 6, 36, 4, 71, 8, 72, 5, 75, 0, 23, 2, 40
  };
  const int q6072[] = {
    9, 9, // Number of jobs and machines
    0, 42, 2, 78, 6, 42, 1, 88, 3, 52, 5, 14, 4, 10, 8, 50, 7, 80, 
    2, 29, 3, 48, 6, 42, 4, 97, 5,  6, 7, 93, 1, 23, 8, 18, 0,  1, 
    4,  8, 8,  6, 7, 80, 0, 18, 2, 89, 6, 16, 5,  6, 1, 90, 3, 30, 
    0,  8, 7,  6, 6,  4, 2, 98, 1, 40, 4, 85, 3, 25, 5, 92, 8,  5, 
    7, 53, 1, 50, 3, 68, 8, 33, 2, 20, 5, 14, 0, 82, 4, 86, 6, 26, 
    0, 46, 2, 40, 4, 63, 5, 88, 8, 80, 3, 30, 1, 57, 6, 98, 7, 28, 
    3, 46, 2,  6, 6, 38, 4, 49, 8, 44, 1, 67, 5, 10, 7,  1, 0,  8, 
    7, 19, 6, 15, 5, 57, 3, 73, 1, 56, 2, 17, 4, 45, 8, 21, 0, 96, 
    8, 24, 1, 26, 6, 32, 3, 85, 2, 45, 5, 76, 7, 50, 0, 79, 4,  5
  };
  const int q6073[] = {
    9, 9, // Number of jobs and machines
    4,  2, 8, 36, 2, 47, 5,  8, 1, 62, 7, 60, 0, 97, 3, 54, 6, 57, 
    1, 49, 0, 72, 3, 93, 7, 21, 6, 40, 5, 80, 2, 67, 4, 68, 8, 53, 
    3, 83, 6, 32, 8,  3, 4, 29, 7, 24, 0, 28, 1, 34, 5, 19, 2, 16, 
    1, 98, 6, 47, 2, 24, 0, 13, 7, 41, 5, 85, 4, 59, 3, 53, 8, 79, 
    3, 75, 6, 32, 7, 31, 1, 80, 5, 12, 4,  8, 8, 99, 2, 50, 0, 62, 
    1, 34, 2, 88, 6, 96, 7, 90, 3, 50, 4, 74, 8, 98, 0, 67, 5, 91, 
    2, 54, 8, 87, 1, 49, 5, 76, 0, 96, 7, 28, 3, 93, 6, 31, 4, 92, 
    5, 62, 3, 14, 8, 56, 6, 74, 2,  9, 4, 53, 7, 88, 1, 48, 0,  3, 
    7, 54, 6, 17, 2, 57, 3, 16, 4, 53, 0, 18, 5, 41, 8, 54, 1, 76
  };
  const int q6074[] = {
    9, 9, // Number of jobs and machines
    0, 47, 1, 60, 2, 88, 6, 86, 3, 84, 8,  7, 7, 15, 4, 20, 5, 92, 
    6, 62, 3, 67, 8, 64, 5, 67, 1, 69, 0, 89, 2, 49, 4, 58, 7, 41, 
    3, 28, 5, 76, 2, 45, 6, 56, 0, 60, 4, 34, 8, 80, 7, 84, 1, 90, 
    3, 90, 0, 32, 8, 18, 7, 19, 5, 33, 4, 62, 1, 86, 2, 83, 6, 20, 
    3, 80, 8, 94, 1, 93, 7, 51, 5, 57, 6, 58, 2,  4, 0, 13, 4, 27, 
    6, 19, 8, 22, 1,  8, 4, 64, 7, 87, 2, 62, 5, 15, 3, 60, 0, 31, 
    2, 99, 1, 67, 7, 44, 3, 16, 6,  7, 0, 58, 5, 88, 8, 86, 4, 48, 
    4, 45, 8, 75, 6, 86, 5, 15, 0, 88, 3, 87, 7, 78, 1, 19, 2, 98, 
    7, 49, 1, 50, 3, 73, 5, 85, 6, 86, 2, 13, 4, 17, 8, 36, 0, 99
  };
  const int q6075[] = {
    9, 9, // Number of jobs and machines
    0, 79, 1, 87, 5, 82, 3, 14, 8, 63, 2, 66, 4, 70, 7, 44, 6, 66, 
    0, 50, 3, 44, 1, 99, 7, 23, 8, 81, 5, 73, 2, 72, 4, 67, 6, 22, 
    3, 79, 6, 91, 2, 50, 5, 96, 4, 22, 0, 31, 7, 69, 8, 13, 1,  5, 
    1, 99, 4, 26, 5, 23, 2, 67, 8, 65, 6, 26, 7, 78, 3, 36, 0, 38, 
    4, 91, 1, 22, 0, 31, 3,  5, 2, 82, 8, 66, 5, 66, 6, 48, 7, 62, 
    2, 96, 4, 77, 0, 66, 8, 21, 1, 91, 7, 18, 3,  7, 5, 23, 6, 50, 
    4, 71, 1,  8, 7, 36, 3, 71, 0, 75, 8, 49, 2, 59, 5, 33, 6, 47, 
    3, 32, 8, 98, 4, 55, 7,  2, 2, 50, 5, 55, 0, 33, 1, 84, 6, 96, 
    8, 41, 6, 27, 2, 34, 7, 96, 5, 35, 1, 84, 0, 86, 3, 95, 4, 74
  };
  const int q6076[] = {
    9, 9, // Number of jobs and machines
    8, 13, 2, 47, 7,  5, 5, 22, 1, 27, 6, 77, 3, 64, 0, 88, 4, 16, 
    7, 95, 5, 40, 3, 63, 4, 81, 8,  9, 6, 62, 1, 74, 2, 70, 0, 37, 
    4, 72, 1, 52, 5,  9, 8, 12, 6, 63, 7, 28, 2, 88, 0, 31, 3, 89, 
    2, 20, 6, 85, 3, 67, 8, 73, 7, 71, 4, 94, 0, 14, 5, 97, 1, 48, 
    4,  9, 0, 56, 2, 94, 1, 53, 3, 98, 6, 38, 5, 97, 8, 21, 7, 13, 
    2, 50, 6, 83, 0,  3, 8, 98, 7,  6, 3, 39, 5, 57, 4, 85, 1, 89, 
    4, 46, 6,  4, 8, 91, 1, 40, 3, 12, 0, 25, 2, 42, 5, 65, 7, 41, 
    4, 10, 2,  7, 3, 78, 7, 76, 6, 41, 0, 14, 1, 67, 5, 10, 8, 52, 
    5, 52, 2, 13, 3, 88, 0, 40, 7, 16, 6, 14, 8,  2, 1, 64, 4, 41
  };
  const int q6077[] = {
    9, 9, // Number of jobs and machines
    3, 78, 7, 79, 0, 26, 2, 98, 5, 92, 6, 16, 1, 59, 4, 91, 8, 67, 
    2, 72, 0, 73, 8, 71, 7, 15, 3, 30, 6, 92, 5,  9, 4, 90, 1, 73, 
    4, 67, 2, 82, 6, 22, 8, 90, 3, 53, 7, 79, 1, 40, 5, 53, 0, 47, 
    6, 33, 8,  8, 1, 81, 0, 23, 7, 54, 5, 63, 2, 86, 3, 16, 4, 94, 
    4, 23, 6, 17, 2, 40, 5, 69, 7, 35, 0, 58, 3, 90, 1, 54, 8, 86, 
    2, 89, 8, 96, 5, 93, 0, 71, 4, 68, 7, 40, 1, 82, 6, 22, 3, 86, 
    6, 35, 4, 17, 0, 99, 2, 44, 5,  4, 3, 40, 1, 47, 7, 86, 8, 99, 
    2, 54, 8, 84, 6, 93, 4, 85, 0, 12, 7, 85, 3, 25, 5, 13, 1, 34, 
    7, 65, 1, 48, 3, 91, 5, 32, 6, 19, 4, 12, 0, 34, 8, 22, 2, 50
  };
  const int q6078[] = {
    9, 9, // Number of jobs and machines
    4, 58, 2, 32, 6, 29, 0, 65, 7, 74, 3, 59, 5, 85, 8, 17, 1, 27, 
    2, 14, 4, 63, 0, 20, 8, 40, 6, 75, 1, 74, 3, 90, 5, 13, 7, 50, 
    6, 43, 3, 70, 0, 20, 1, 29, 7, 46, 8, 42, 2, 73, 4, 77, 5, 16, 
    0, 75, 2, 29, 8, 86, 1, 76, 4, 42, 3, 94, 5, 50, 6, 25, 7, 41, 
    2, 34, 1, 89, 4, 47, 0, 67, 6, 66, 5, 15, 3, 66, 8, 46, 7, 74, 
    6, 37, 5, 35, 8, 43, 0, 84, 2, 12, 4, 76, 1, 64, 3, 36, 7, 15, 
    2, 81, 8, 11, 5, 58, 0, 24, 7, 45, 4, 82, 6, 77, 1, 81, 3, 50, 
    3, 91, 4, 31, 0, 69, 5,  3, 1, 23, 2,  2, 8, 42, 7, 66, 6, 15, 
    6,  3, 4, 99, 0, 40, 1, 88, 7, 98, 2,  8, 5, 77, 8,  2, 3, 79
  };
  const int q6079[] = {
    9, 9, // Number of jobs and machines
    4, 65, 3,  2, 0, 88, 5, 23, 1, 38, 7, 73, 6, 13, 2, 37, 8,  9, 
    4, 98, 0, 88, 2, 92, 3, 37, 6, 44, 8, 67, 1, 82, 5,  1, 7, 97, 
    3,  9, 4, 52, 8, 25, 1, 30, 5, 80, 7,  2, 2, 50, 0, 54, 6, 95, 
    3, 71, 6, 13, 5, 43, 4, 97, 8, 90, 1, 66, 0, 59, 2, 27, 7, 88, 
    3, 68, 4,  3, 5, 53, 7, 41, 2,  4, 0, 89, 8, 88, 6, 89, 1, 33, 
    7, 99, 8,  9, 2, 87, 3,  3, 4, 21, 6, 59, 1, 45, 0, 67, 5, 78, 
    3, 97, 2, 29, 4, 23, 0, 79, 1, 52, 8, 95, 5, 90, 7, 38, 6, 77, 
    1, 87, 6, 28, 3, 27, 0, 25, 4, 24, 5, 67, 2, 13, 7, 84, 8, 79, 
    4, 87, 0, 30, 1, 54, 6, 68, 8, 58, 2, 97, 3, 88, 5, 84, 7, 78
  };
  const int q6080[] = {
    9, 9, // Number of jobs and machines
    1, 13, 4, 75, 6,  2, 2, 90, 3,  5, 8, 29, 5, 64, 0, 45, 7, 46, 
    2, 49, 0, 66, 4, 58, 5, 82, 6, 29, 3, 90, 7, 44, 8, 15, 1, 19, 
    1,  4, 3, 54, 0, 27, 5, 48, 2, 20, 7,  4, 4, 15, 8, 43, 6,  9, 
    3, 89, 5, 17, 7,  3, 6, 89, 8,  2, 1, 45, 4, 33, 0, 98, 2, 76, 
    5, 26, 4, 74, 2, 25, 7, 14, 1, 61, 6, 33, 3, 31, 0, 98, 8, 94, 
    4, 98, 6, 63, 3,  3, 0, 25, 8, 29, 7, 44, 1, 34, 5, 49, 2, 56, 
    6, 78, 8, 27, 0, 70, 3, 86, 4, 64, 1, 50, 5, 43, 2, 83, 7, 76, 
    7, 85, 8, 60, 0,  8, 3, 37, 1, 13, 5, 66, 2,  2, 6, 84, 4, 29, 
    0, 53, 8, 62, 3, 72, 5, 90, 6, 12, 1, 44, 7, 18, 4, 99, 2, 81
  };
  const int q6081[] = {
    9, 9, // Number of jobs and machines
    8,  7, 6, 44, 7, 17, 1, 98, 0, 30, 4, 50, 3, 92, 5, 60, 2, 16, 
    3, 88, 7, 20, 6, 21, 0, 24, 2, 26, 8, 37, 4, 36, 1, 69, 5, 75, 
    0,  2, 7, 42, 1, 28, 8, 47, 6, 81, 5, 64, 4, 47, 3, 74, 2, 89, 
    0, 78, 7, 92, 5,  4, 2, 11, 4, 33, 6, 99, 8, 82, 1, 99, 3, 79, 
    7, 99, 5, 49, 8, 13, 2, 63, 1, 35, 4, 31, 3, 40, 0, 51, 6, 74, 
    6, 26, 0, 27, 2, 71, 7, 74, 4, 57, 1, 78, 8,  6, 5, 60, 3, 37, 
    3, 65, 0, 58, 6, 87, 2, 25, 4, 64, 1, 55, 5, 12, 8, 83, 7, 30, 
    0, 51, 1, 79, 3, 34, 6, 82, 4, 82, 2, 97, 8,  4, 7, 90, 5,  1, 
    1, 21, 8, 65, 0, 17, 2, 76, 4, 70, 7, 18, 5, 11, 3, 47, 6, 80
  };
  const int q6082[] = {
    9, 9, // Number of jobs and machines
    3,  5, 8, 42, 2, 85, 1, 62, 6, 41, 7, 59, 5, 41, 4, 39, 0, 96, 
    8, 47, 3, 79, 6, 38, 7, 88, 1, 87, 2, 96, 4, 56, 0, 15, 5, 66, 
    4, 61, 6, 91, 5, 42, 1, 44, 8, 51, 7, 76, 2, 12, 3, 62, 0, 25, 
    7, 43, 4, 44, 6, 11, 5, 30, 0, 54, 8, 51, 3, 72, 1, 38, 2, 27, 
    7, 47, 6, 61, 3, 82, 1, 54, 4, 63, 2, 89, 8, 54, 0, 85, 5, 75, 
    1, 35, 2, 35, 6, 71, 8, 69, 0, 24, 4, 94, 3, 59, 5, 13, 7, 83, 
    2,  9, 5,  1, 3, 58, 4, 97, 6, 47, 7, 18, 8, 90, 0, 50, 1, 48, 
    8, 42, 4, 54, 7, 30, 0, 12, 5, 49, 3, 88, 2, 33, 1, 73, 6, 68, 
    4, 52, 0,  1, 7, 46, 5, 89, 6, 45, 3, 35, 1, 71, 2, 29, 8, 14
  };
  const int q6083[] = {
    9, 9, // Number of jobs and machines
    1, 23, 5, 42, 4, 66, 7, 54, 6, 92, 0, 38, 2, 48, 8, 21, 3, 59, 
    3, 15, 2,  2, 6,  8, 7, 49, 0, 31, 5, 77, 8, 62, 1, 54, 4, 78, 
    0, 35, 7, 10, 6, 42, 2, 56, 8, 87, 3, 59, 5, 97, 4, 11, 1, 65, 
    5, 12, 3,  8, 7,  4, 4, 58, 1, 59, 0, 32, 6,  4, 8, 75, 2, 21, 
    6, 29, 4, 54, 8, 87, 3, 45, 5, 67, 0, 75, 7, 64, 1, 85, 2, 13, 
    7, 62, 0, 63, 8, 59, 5, 88, 1, 78, 4, 22, 6, 98, 3, 78, 2, 91, 
    1, 21, 5, 32, 3, 16, 4, 20, 6, 13, 7, 57, 8, 28, 2, 57, 0, 62, 
    8, 68, 7, 95, 4, 81, 1, 52, 5, 49, 2, 95, 0, 95, 3, 61, 6, 23, 
    8,  2, 6, 51, 5, 72, 7, 23, 2, 80, 1, 24, 3, 19, 4, 95, 0, 21
  };
  const int q6084[] = {
    9, 9, // Number of jobs and machines
    3, 93, 7, 72, 0, 95, 8, 87, 2, 55, 4, 72, 5, 32, 1, 65, 6, 48, 
    8, 44, 3, 29, 5, 90, 6, 99, 2, 14, 0, 47, 7, 11, 1, 77, 4, 64, 
    8,  4, 3, 81, 2, 83, 1,  1, 4, 36, 0, 34, 5, 60, 7, 32, 6, 89, 
    2, 32, 5, 60, 6, 74, 1, 79, 3, 72, 8, 84, 7, 87, 0, 14, 4, 69, 
    5, 28, 4, 91, 6, 31, 0, 15, 1, 73, 3, 19, 2, 39, 8, 91, 7, 59, 
    5, 48, 0, 39, 4, 17, 8, 66, 1, 93, 3, 81, 7,  8, 2, 31, 6, 50, 
    1, 50, 6, 27, 3, 97, 5, 75, 8, 91, 7, 34, 2, 80, 0, 20, 4, 47, 
    7, 74, 0, 24, 5, 32, 8, 11, 3, 49, 4, 30, 2, 40, 6, 88, 1, 35, 
    6, 75, 4, 69, 7, 17, 8, 70, 2, 11, 0, 98, 5, 14, 3, 63, 1, 18
  };
  const int q6085[] = {
    9, 9, // Number of jobs and machines
    5, 35, 2, 17, 6,  3, 8, 61, 4, 97, 0, 14, 1, 75, 7, 56, 3,  8, 
    4, 92, 2, 21, 6, 66, 3, 16, 7, 99, 5, 36, 8, 49, 1,  7, 0, 98, 
    1, 20, 5, 92, 7, 12, 4, 74, 2,  3, 0, 87, 8, 70, 3, 11, 6, 97, 
    2, 61, 3, 45, 6, 89, 0, 12, 7, 60, 8, 38, 5, 76, 4,  1, 1, 52, 
    2, 26, 5, 77, 0, 65, 3, 87, 6, 87, 4,  4, 7, 97, 1, 48, 8, 59, 
    5, 29, 6, 47, 0, 47, 7, 76, 3, 34, 8,  9, 1, 32, 2, 61, 4, 27, 
    8, 46, 5, 11, 6, 37, 7, 30, 2, 79, 1, 52, 0, 18, 3, 81, 4,  1, 
    8, 98, 6, 18, 5, 10, 4, 73, 1, 41, 2, 84, 7, 16, 3, 64, 0, 20, 
    8, 14, 4, 88, 7, 99, 0, 91, 1, 69, 5, 98, 2, 25, 3, 70, 6, 59
  };
  const int q6086[] = {
    9, 9, // Number of jobs and machines
    2, 10, 6, 97, 3, 39, 8, 45, 0, 65, 7,  7, 4, 39, 5, 88, 1, 58, 
    0, 95, 5, 15, 1, 98, 8, 81, 3, 74, 2, 26, 6, 18, 4, 27, 7, 72, 
    0, 95, 4, 87, 2, 26, 8, 95, 7, 77, 6, 92, 5, 86, 1, 54, 3, 52, 
    5, 35, 8, 11, 6, 75, 2, 81, 4,  3, 0, 98, 1, 55, 3, 81, 7, 56, 
    8, 87, 3, 13, 2,  8, 0, 23, 7, 60, 5, 59, 4, 68, 1, 95, 6, 67, 
    8, 87, 4, 78, 6, 23, 7, 95, 0, 72, 5, 17, 3, 52, 1, 82, 2,  3, 
    4, 22, 8, 10, 6, 30, 1, 87, 0, 44, 7, 76, 2, 49, 3, 64, 5, 90, 
    0, 86, 1, 83, 6, 99, 8, 78, 3, 59, 7, 99, 2, 82, 4, 74, 5, 61, 
    1, 42, 5, 93, 2,  7, 6, 96, 7, 32, 4, 74, 8, 25, 0, 88, 3, 33
  };
  const int q6087[] = {
    9, 9, // Number of jobs and machines
    6, 87, 8, 44, 2, 66, 3, 26, 0,  6, 7, 56, 1, 61, 5, 61, 4, 79, 
    0, 63, 2, 14, 4, 79, 1, 72, 3, 95, 6, 10, 5, 55, 7,  9, 8, 95, 
    4, 75, 1, 58, 0, 90, 8, 73, 3, 83, 6, 14, 2, 66, 7, 67, 5, 96, 
    2, 30, 0,  3, 8, 82, 3,  4, 7, 69, 5, 80, 1, 34, 6, 50, 4, 69, 
    4, 85, 2, 33, 1, 24, 8, 42, 0, 61, 5, 24, 3, 78, 6, 94, 7, 54, 
    5,  3, 8, 95, 7, 19, 1, 87, 2, 80, 6, 44, 3, 30, 4,  7, 0, 80, 
    0, 94, 8, 12, 1,  8, 2, 71, 3, 33, 5,  4, 7, 78, 4, 87, 6, 94, 
    4, 73, 0, 20, 8, 70, 7, 51, 2, 64, 5, 25, 1, 39, 6, 30, 3, 22, 
    2,  4, 0,  4, 6, 77, 5, 16, 1, 80, 8, 97, 7, 34, 4, 36, 3, 29
  };
  const int q6088[] = {
    9, 9, // Number of jobs and machines
    7, 90, 4, 46, 1, 71, 5, 63, 2, 47, 3, 10, 6, 51, 8, 82, 0, 25, 
    0, 78, 1, 92, 5, 35, 7, 30, 8, 50, 4, 76, 2, 44, 3, 62, 6, 86, 
    7, 61, 0,  6, 3, 21, 6, 14, 2, 55, 5, 86, 1, 89, 8, 87, 4, 28, 
    4, 90, 6, 80, 5, 99, 1, 26, 3, 71, 7, 92, 2, 11, 8, 32, 0, 27, 
    1, 27, 8, 31, 0, 27, 3, 57, 6, 54, 7, 11, 4, 74, 5, 55, 2, 47, 
    6,  5, 5, 95, 8, 56, 7, 43, 0, 59, 4, 81, 1,  9, 2, 91, 3, 65, 
    7, 99, 4, 63, 0,  6, 5, 90, 1, 46, 2, 77, 6, 58, 3, 85, 8, 22, 
    4, 69, 8, 44, 0, 59, 6, 34, 3, 78, 1, 16, 5, 65, 7, 62, 2, 75, 
    4, 17, 5, 17, 6, 34, 3, 82, 8, 86, 1, 94, 7, 46, 2, 90, 0, 41
  };
  const int q6089[] = {
    9, 9, // Number of jobs and machines
    3,  9, 2, 35, 1, 64, 4, 62, 7, 94, 0, 22, 5, 23, 6, 39, 8, 57, 
    1, 97, 2, 24, 5, 63, 0,  3, 6, 19, 4, 28, 8, 19, 3, 15, 7, 30, 
    7, 21, 5, 73, 4, 31, 3, 31, 2, 42, 6, 10, 0, 89, 1, 67, 8, 45, 
    2, 53, 6, 74, 1, 92, 4, 15, 0,  1, 8, 95, 7,  5, 5, 88, 3,  9, 
    2, 15, 5, 42, 3, 78, 4, 41, 8, 29, 1, 38, 7, 31, 6, 56, 0, 22, 
    7, 31, 6, 54, 3, 29, 8, 36, 5, 17, 4, 31, 2, 47, 0, 48, 1, 33, 
    7, 24, 1, 86, 8,  3, 6, 83, 4,  4, 2, 49, 0, 18, 5, 69, 3, 65, 
    1, 56, 3, 43, 7, 67, 2,  8, 8, 60, 5, 96, 6, 91, 0, 56, 4, 56, 
    6, 98, 2, 59, 8, 69, 1, 14, 3, 80, 7, 79, 5, 26, 4, 30, 0, 45
  };
  const int q6090[] = {
    9, 9, // Number of jobs and machines
    7, 43, 8, 72, 1, 61, 0, 89, 4, 97, 2, 30, 5, 62, 3, 71, 6, 15, 
    8, 44, 5, 77, 0, 77, 3, 47, 2, 10, 4, 65, 1, 16, 7, 59, 6,  7, 
    7, 54, 2, 79, 4, 43, 1, 78, 3, 63, 0,  7, 8,  8, 5, 83, 6, 74, 
    0, 22, 8, 89, 3, 44, 4,  5, 7, 92, 2, 30, 6, 40, 1, 28, 5, 32, 
    7, 16, 2, 49, 3, 14, 5, 81, 0, 51, 1, 26, 4, 84, 6, 83, 8, 71, 
    6, 50, 4, 94, 0, 51, 1, 14, 8,  9, 3, 64, 7, 83, 5, 68, 2, 78, 
    8, 60, 4, 33, 3, 27, 1, 31, 0, 62, 7, 86, 2,  5, 5,  6, 6,  1, 
    1, 26, 2,  6, 8, 32, 7, 34, 5, 52, 0, 56, 3, 14, 4, 57, 6, 72, 
    8, 87, 4, 16, 3, 41, 6, 48, 2, 78, 0, 23, 1, 34, 7, 95, 5, 68
  };
  const int q6091[] = {
    9, 9, // Number of jobs and machines
    0, 53, 6, 95, 7,  4, 4, 63, 2,  7, 1, 72, 5, 47, 8, 93, 3, 44, 
    1, 20, 0,  4, 6,  6, 4, 77, 3,  5, 7, 42, 8, 56, 5, 25, 2, 70, 
    2, 33, 3, 44, 8, 31, 6, 24, 7, 14, 4,  2, 5, 14, 1, 29, 0, 76, 
    4, 91, 0, 39, 6, 38, 5, 37, 7,  4, 3, 76, 2, 52, 1, 37, 8, 62, 
    0, 56, 8, 19, 3, 34, 7, 85, 6, 10, 5, 45, 1, 47, 4, 42, 2, 72, 
    5, 41, 3, 48, 4, 28, 0, 88, 6, 31, 7, 43, 2, 63, 8, 88, 1, 24, 
    7, 87, 3, 66, 1, 53, 2, 47, 5, 49, 6,  3, 8, 91, 0, 77, 4, 98, 
    4, 99, 1, 80, 2,  3, 6,  8, 8, 14, 3, 12, 7, 44, 0, 91, 5, 91, 
    7, 15, 5, 57, 8, 76, 3, 50, 1, 37, 6, 22, 4, 46, 2, 83, 0, 94
  };
  const int q6092[] = {
    9, 9, // Number of jobs and machines
    1, 45, 0, 66, 3, 38, 6, 26, 8, 13, 5, 35, 2, 84, 7, 55, 4, 66, 
    7, 80, 8, 18, 3, 50, 0, 51, 6, 65, 4,  6, 2, 78, 1, 34, 5, 85, 
    7, 54, 6, 74, 2, 89, 8, 98, 5, 51, 4, 14, 0, 34, 1,  6, 3, 90, 
    0, 22, 8, 85, 1, 72, 4, 26, 5, 81, 7, 29, 3, 71, 6, 55, 2, 41, 
    2, 79, 6, 68, 7, 97, 1, 17, 5,  2, 4, 69, 0, 61, 3, 48, 8, 11, 
    0,  9, 4, 80, 5, 31, 3, 75, 8, 81, 7, 28, 1, 43, 6,  6, 2, 98, 
    4, 14, 3, 44, 6, 79, 5, 82, 0, 32, 8, 65, 2, 91, 1, 64, 7, 58, 
    2, 50, 5, 43, 7, 35, 6, 29, 3, 75, 8,  1, 0, 70, 1, 76, 4, 36, 
    5, 56, 6, 59, 1, 41, 4, 98, 3, 61, 0, 88, 2, 43, 8, 62, 7, 21
  };
  const int q6093[] = {
    9, 9, // Number of jobs and machines
    2, 82, 5, 61, 4, 45, 8, 55, 3,  5, 6, 93, 7, 72, 1, 42, 0, 45, 
    8, 94, 0, 79, 3, 91, 2, 41, 7, 97, 1,  6, 5, 74, 6, 73, 4, 89, 
    5, 47, 6, 69, 3, 82, 8, 29, 2, 18, 4, 20, 7, 28, 0, 92, 1, 49, 
    7, 61, 6, 20, 8,  1, 1, 23, 3, 41, 0, 49, 2, 42, 5, 50, 4, 28, 
    7, 29, 0, 67, 5, 63, 8,  8, 6, 11, 1, 20, 3, 77, 2, 65, 4, 96, 
    7, 82, 8,  3, 1, 55, 5, 66, 3, 48, 2, 93, 4, 52, 0, 48, 6, 42, 
    6, 87, 7, 19, 3,  6, 1, 15, 0, 21, 2, 14, 4,  9, 8, 82, 5, 42, 
    0, 43, 6, 23, 8, 26, 4, 73, 3, 95, 5, 58, 1, 92, 2, 86, 7, 14, 
    1,  5, 7, 41, 0, 91, 8, 71, 3, 67, 5, 95, 6, 42, 4, 19, 2, 36
  };
  const int q6094[] = {
    9, 9, // Number of jobs and machines
    7, 82, 0, 93, 5, 54, 6, 33, 8, 39, 4, 35, 2, 61, 3,  7, 1, 93, 
    0, 74, 4, 41, 3, 13, 8,  6, 6,  1, 5, 55, 2, 47, 1, 85, 7, 35, 
    1, 23, 4, 67, 0, 55, 7, 50, 2, 94, 8, 36, 5, 91, 3, 63, 6, 61, 
    6, 91, 2, 31, 8, 53, 5, 36, 1, 22, 0, 19, 7, 84, 3, 53, 4, 91, 
    3, 81, 2, 91, 7, 18, 1, 15, 6, 43, 5, 94, 4, 54, 0, 61, 8, 95, 
    2, 93, 5, 17, 4, 16, 3, 78, 1, 25, 7, 59, 8, 46, 0, 60, 6, 47, 
    3, 94, 4,  7, 0, 31, 7,  9, 6,  6, 1, 30, 2, 34, 8, 60, 5, 20, 
    5, 82, 4, 92, 6, 37, 1, 73, 0, 73, 3, 98, 7, 99, 8,  7, 2, 13, 
    6, 71, 3, 96, 7, 61, 8, 51, 1,  2, 0, 48, 5, 28, 4, 73, 2, 45
  };
  const int q6095[] = {
    9, 9, // Number of jobs and machines
    3, 36, 0, 97, 7, 22, 2, 26, 8, 56, 6, 85, 4, 30, 5, 74, 1, 36, 
    4, 70, 3, 64, 7,  4, 2, 94, 5, 62, 6, 17, 1, 66, 8, 93, 0, 65, 
    3, 62, 8, 23, 6, 31, 5, 33, 2, 34, 0, 24, 7, 33, 4, 47, 1, 11, 
    1, 25, 5, 83, 6, 60, 8, 31, 4, 27, 3, 65, 0, 42, 2, 47, 7, 14, 
    1, 34, 6, 63, 8, 82, 3, 92, 7, 15, 5, 22, 2, 39, 4, 31, 0, 90, 
    5, 95, 1, 86, 7, 92, 0, 56, 2,  8, 4, 84, 3, 58, 6, 27, 8, 74, 
    5, 82, 6, 14, 1, 34, 4, 99, 7, 91, 8, 50, 0, 49, 2, 59, 3,  3, 
    2, 95, 3, 37, 7, 39, 5, 49, 8, 63, 0, 10, 4, 88, 6, 11, 1, 10, 
    8, 57, 1, 11, 0, 56, 3, 96, 7, 93, 6, 29, 2, 35, 5, 71, 4, 96
  };
  const int q6096[] = {
    9, 9, // Number of jobs and machines
    3, 35, 7, 52, 8, 46, 6, 58, 2, 93, 1, 90, 5, 61, 0, 18, 4, 50, 
    6, 16, 5, 92, 0, 31, 7, 46, 3, 77, 2, 14, 8, 68, 1,  4, 4, 74, 
    1, 82, 0, 87, 2, 76, 3, 57, 4, 34, 8, 88, 5, 79, 6, 73, 7, 34, 
    6, 13, 5, 32, 7,  9, 4,  9, 2,  5, 3, 34, 8, 77, 1, 54, 0, 89, 
    1,  5, 8, 81, 5, 83, 3, 82, 4, 39, 2, 37, 7, 53, 6, 77, 0,  7, 
    4,  1, 2, 42, 7, 99, 1, 62, 0, 94, 3, 93, 5, 28, 6, 33, 8, 14, 
    3, 51, 7, 33, 2, 34, 4, 59, 1, 56, 5,  8, 8, 29, 6, 59, 0, 11, 
    5, 52, 2, 29, 6, 88, 7,  5, 8, 57, 3, 39, 0, 47, 4, 89, 1,  6, 
    3, 55, 0,  1, 7, 90, 5, 64, 4, 14, 1,  3, 6, 43, 2, 86, 8, 21
  };
  const int q6097[] = {
    9, 9, // Number of jobs and machines
    8, 68, 1, 68, 6, 65, 3, 27, 4, 79, 0, 46, 7, 59, 5, 43, 2, 38, 
    8, 48, 7, 67, 6, 49, 0, 84, 2, 61, 5, 30, 1, 27, 4, 75, 3, 10, 
    8, 10, 4,  8, 1, 65, 2, 49, 6, 68, 0, 98, 7, 47, 3, 89, 5, 92, 
    1, 29, 5, 42, 6,  4, 7, 24, 2, 35, 0, 99, 3, 12, 4, 59, 8, 28, 
    7, 30, 6, 27, 0, 12, 5, 34, 4, 10, 1, 56, 8, 45, 2, 58, 3, 27, 
    5, 45, 1, 53, 7, 71, 0, 70, 6, 83, 2, 38, 4, 93, 8, 69, 3, 44, 
    8, 29, 0, 94, 4, 64, 3, 60, 1, 10, 7,  7, 2, 63, 5,  7, 6, 94, 
    3, 67, 5, 64, 8, 40, 6, 70, 7, 26, 2, 10, 4, 27, 1, 80, 0, 39, 
    5, 80, 1, 71, 7, 44, 8, 26, 4, 57, 6, 21, 0, 62, 3, 44, 2, 63
  };
  const int q6098[] = {
    9, 9, // Number of jobs and machines
    1, 59, 5, 76, 2,  1, 3, 51, 0,  8, 6, 66, 8, 16, 4, 96, 7, 29, 
    1, 97, 5,  3, 3, 94, 6, 85, 8, 21, 4, 98, 0, 54, 7, 85, 2, 54, 
    1, 93, 8, 57, 4, 63, 3, 35, 5, 83, 0, 58, 7, 99, 6, 77, 2, 50, 
    2, 33, 7, 56, 3, 61, 8,  9, 6,  4, 1, 50, 0, 42, 4, 31, 5,  1, 
    6, 19, 0, 60, 1, 50, 4, 59, 8, 93, 2, 15, 3, 87, 5, 93, 7, 30, 
    4, 79, 5, 62, 1, 53, 0, 61, 6, 18, 2, 19, 7, 32, 8, 41, 3, 27, 
    8, 96, 3, 56, 5, 54, 6, 83, 4, 37, 2, 94, 1, 87, 7, 12, 0, 19, 
    3, 64, 2, 28, 7, 93, 8, 64, 6, 27, 4, 58, 1, 66, 5, 71, 0, 59, 
    1, 60, 8,  9, 0, 63, 7, 16, 5,  4, 4, 68, 2, 83, 3, 61, 6, 73
  };
  const int q6099[] = {
    9, 9, // Number of jobs and machines
    1, 62, 8, 83, 6, 15, 2, 29, 5, 92, 7, 89, 0, 90, 4, 80, 3, 71, 
    2, 98, 4,  5, 5,  4, 8, 66, 1, 63, 3, 43, 7, 89, 0, 93, 6, 58, 
    6, 72, 4, 50, 1,  1, 2,  9, 7, 20, 5, 55, 0, 52, 8,  3, 3, 33, 
    6, 23, 7, 13, 1, 86, 4, 96, 3, 67, 0, 54, 8, 66, 2, 51, 5, 72, 
    6, 32, 0, 55, 1, 75, 7, 57, 2, 47, 3, 11, 5, 96, 4, 45, 8, 37, 
    6,  6, 2, 43, 4, 50, 3, 52, 7, 63, 5, 94, 1, 78, 0, 63, 8, 81, 
    3, 15, 6, 41, 7, 19, 1, 10, 2, 17, 8, 12, 0, 63, 4, 14, 5, 59, 
    8, 78, 3,  7, 4, 33, 5, 22, 1, 24, 7, 66, 2, 83, 0, 35, 6, 75, 
    7,  6, 2, 63, 3,  8, 0, 86, 8, 72, 1, 36, 4, 21, 5, 73, 6, 32
  };
  const int q6100[] = {
    9, 9, // Number of jobs and machines
    8,  2, 6, 56, 1, 55, 7, 54, 0, 40, 5, 29, 2, 41, 4, 16, 3, 70, 
    2, 86, 8, 15, 3, 81, 4, 51, 6, 60, 5, 71, 0, 68, 7, 57, 1, 77, 
    2, 66, 4, 79, 3, 53, 0, 27, 8, 20, 5, 63, 1, 59, 7, 16, 6, 46, 
    5, 18, 7, 96, 2,  9, 0, 74, 3, 57, 6, 26, 4, 95, 1, 75, 8, 22, 
    1, 56, 7, 81, 5, 74, 2, 91, 6, 15, 8, 99, 0, 73, 4,  9, 3, 66, 
    1, 23, 4, 82, 3, 77, 6, 80, 5,  9, 7, 19, 8,  1, 0, 84, 2,  4, 
    5, 99, 6, 88, 2, 83, 1, 22, 7, 18, 0, 85, 4, 95, 3, 19, 8, 94, 
    8, 78, 3,  9, 4, 90, 2, 70, 5, 86, 6, 75, 7, 83, 0, 82, 1, 30, 
    0, 81, 1, 24, 7, 78, 4, 58, 3, 39, 8, 77, 5, 81, 2, 27, 6, 79
  };
  const int q6101[] = {
    9, 9, // Number of jobs and machines
    5, 34, 6, 23, 3, 67, 8, 27, 4, 27, 2, 58, 7, 91, 1, 41, 0, 36, 
    5, 15, 4, 99, 0,  9, 3,  8, 2, 87, 6, 79, 1, 68, 8, 11, 7, 67, 
    5, 60, 8, 24, 6, 27, 2, 27, 1, 28, 7, 99, 0, 77, 3, 41, 4,  1, 
    3, 29, 1, 35, 8, 97, 2,  1, 7, 89, 4,  9, 0, 91, 5, 96, 6, 22, 
    4, 68, 2, 19, 3, 17, 7, 70, 0, 77, 1, 68, 6, 43, 5, 54, 8, 51, 
    4, 33, 7, 59, 0, 18, 5, 80, 1, 91, 8, 90, 2, 72, 6, 18, 3, 31, 
    7,  5, 4, 23, 8, 95, 2, 34, 5, 20, 3, 32, 0, 50, 6, 77, 1, 97, 
    8, 90, 6, 38, 5, 81, 4, 96, 3, 20, 0, 10, 1, 74, 2, 96, 7, 93, 
    7, 71, 6, 81, 1, 32, 8, 22, 3, 34, 5, 81, 0, 86, 2, 39, 4, 13
  };
  const int q6102[] = {
    9, 9, // Number of jobs and machines
    3, 33, 2, 75, 8, 19, 7, 20, 4, 43, 6,  9, 0, 85, 5, 98, 1, 64, 
    4, 48, 2,  7, 5, 80, 1, 35, 8, 28, 0, 76, 7, 84, 3, 14, 6, 81, 
    7, 83, 0, 66, 5, 16, 3, 67, 6, 56, 8,  3, 2, 17, 1,  4, 4, 23, 
    6, 19, 5, 28, 8, 13, 1, 46, 2, 50, 0, 85, 4, 11, 7,  2, 3, 71, 
    6, 49, 0, 30, 4,  2, 1, 42, 5, 88, 8, 58, 7, 58, 3, 54, 2, 88, 
    2, 65, 5, 56, 8,  4, 7, 62, 4, 26, 3, 33, 6, 47, 0,  6, 1, 79, 
    2, 70, 7, 52, 6, 99, 0,  5, 5, 52, 4, 88, 8, 90, 1, 37, 3, 22, 
    3, 79, 4, 80, 8, 65, 0, 53, 7, 92, 2,  1, 1, 90, 5, 51, 6, 17, 
    4, 56, 0,  1, 6, 62, 5, 18, 2, 52, 7, 50, 8, 31, 1, 80, 3, 83
  };
  const int q6103[] = {
    9, 9, // Number of jobs and machines
    0, 47, 5, 68, 4, 27, 2, 71, 3, 51, 8, 83, 6, 53, 7, 65, 1, 96, 
    1, 33, 7,  8, 8, 38, 6, 60, 4, 64, 3, 33, 0, 94, 2, 77, 5, 47, 
    6, 16, 0, 35, 4, 23, 1, 56, 8, 67, 5, 32, 2, 48, 3, 31, 7, 94, 
    7, 53, 2, 19, 4, 63, 1, 41, 6, 45, 3, 56, 8, 21, 5, 81, 0, 90, 
    0, 48, 7, 26, 5, 97, 2, 76, 6,  9, 1, 10, 4, 81, 3, 81, 8, 14, 
    0, 44, 4, 44, 7, 30, 1, 83, 6, 24, 3, 60, 5, 86, 8, 40, 2, 71, 
    7, 68, 6, 36, 3, 59, 1, 61, 5, 86, 8,  6, 2, 41, 0, 20, 4, 87, 
    0, 16, 6,  7, 2, 91, 7, 36, 1, 52, 8, 89, 4, 30, 5, 60, 3, 98, 
    1, 28, 3, 72, 6, 18, 0, 46, 8, 18, 2, 27, 5, 50, 4, 95, 7, 62
  };
  const int q6104[] = {
    9, 9, // Number of jobs and machines
    2, 49, 0, 83, 1, 78, 7, 22, 8, 51, 5, 63, 6, 35, 3, 56, 4, 85, 
    3, 54, 7, 48, 0, 74, 6, 98, 5,  3, 1, 74, 8, 90, 2, 27, 4, 83, 
    0, 37, 5, 43, 6, 48, 7, 68, 1, 57, 4, 62, 2, 69, 3, 73, 8, 84, 
    8, 73, 3, 66, 5, 95, 4, 60, 6, 53, 0, 35, 2, 18, 1, 95, 7, 30, 
    7, 58, 2, 72, 8, 79, 1, 74, 6, 93, 3, 91, 4, 79, 0, 77, 5, 38, 
    0, 23, 3,  9, 8, 81, 5, 48, 2,  1, 7, 44, 1,  4, 6, 36, 4, 85, 
    1, 22, 3, 56, 4, 18, 5, 14, 6, 34, 2, 37, 0, 48, 8, 74, 7, 62, 
    8, 54, 0, 46, 1, 55, 4, 73, 2, 63, 5, 39, 7, 48, 6, 98, 3, 82, 
    5, 75, 7,  8, 2, 40, 4,  5, 3, 39, 6, 10, 0, 27, 1,  4, 8, 56
  };
  const int q6105[] = {
    9, 9, // Number of jobs and machines
    3, 15, 7, 93, 8, 52, 1, 21, 2, 14, 5, 32, 4, 75, 0, 76, 6, 97, 
    7, 86, 0, 39, 6,  2, 4,  5, 8, 74, 1, 62, 5,  3, 3, 45, 2, 42, 
    5, 41, 1, 11, 7, 14, 0, 91, 4, 24, 2,  4, 3, 35, 8, 32, 6, 83, 
    2, 24, 6,  6, 5, 82, 7, 12, 8, 16, 4, 74, 1, 13, 3, 47, 0, 36, 
    3, 42, 1, 65, 2, 59, 5, 42, 0, 57, 7, 24, 6, 17, 8, 67, 4, 94, 
    7, 98, 1, 29, 5, 29, 4, 82, 8, 83, 0, 73, 6, 48, 3, 13, 2, 89, 
    8,  1, 4, 40, 3, 29, 5, 46, 6, 66, 7, 76, 2, 74, 0, 46, 1,  1, 
    8, 20, 6, 89, 0, 18, 3, 57, 7, 29, 2, 94, 4,  3, 5, 52, 1, 82, 
    0, 39, 8, 20, 3, 88, 1, 24, 6, 14, 4, 31, 2, 17, 5, 73, 7, 57
  };
  const int q6106[] = {
    9, 9, // Number of jobs and machines
    7, 70, 8, 42, 0, 30, 1, 76, 4, 90, 5, 51, 2,  2, 3, 45, 6, 82, 
    7, 85, 1,  5, 0, 75, 6, 39, 8, 60, 2, 28, 5, 85, 3, 55, 4, 70, 
    3, 39, 8, 38, 4, 69, 0, 32, 6, 76, 7, 59, 5, 52, 2, 60, 1, 97, 
    4, 49, 2,  4, 0, 99, 3, 45, 1, 11, 5, 18, 8, 70, 6, 49, 7, 48, 
    6, 98, 4, 56, 5, 53, 7, 70, 0, 18, 3, 85, 2, 21, 1, 23, 8, 70, 
    2, 18, 7, 35, 0, 87, 1, 32, 3, 16, 8, 18, 4, 30, 5, 31, 6,  5, 
    3, 46, 7, 43, 6, 30, 0, 21, 4, 47, 5, 45, 2,  4, 8, 37, 1, 38, 
    4, 45, 5, 56, 8, 12, 6, 63, 7, 94, 3, 75, 1, 96, 0, 65, 2, 85, 
    5, 90, 1, 23, 4, 62, 6, 55, 8, 61, 2, 58, 7, 76, 0, 23, 3, 60
  };
  const int q6107[] = {
    9, 9, // Number of jobs and machines
    2, 45, 0, 32, 8, 64, 3, 81, 5, 40, 7, 69, 6, 64, 4, 71, 1, 44, 
    8, 88, 2, 41, 6, 15, 4, 65, 0, 68, 5, 55, 7, 20, 1, 45, 3, 38, 
    7, 28, 2,  6, 1, 40, 6, 20, 8, 95, 0, 64, 4, 42, 3, 93, 5, 39, 
    1, 91, 8, 43, 6, 74, 0, 91, 4, 43, 2, 62, 7, 80, 3, 69, 5,  6, 
    3, 29, 1, 85, 6, 99, 2, 53, 0, 96, 8,  8, 4, 38, 5, 74, 7, 11, 
    6, 73, 5, 28, 1, 59, 2, 14, 8, 40, 4, 63, 0, 88, 3, 52, 7, 99, 
    5, 67, 4, 35, 0, 81, 1, 50, 6, 77, 2, 11, 8, 93, 7, 27, 3, 80, 
    4, 60, 8, 74, 6, 62, 2, 10, 5, 57, 3, 68, 1, 11, 0, 92, 7,  8, 
    3, 59, 8,  9, 7, 40, 2, 80, 1, 23, 4, 74, 0, 12, 5, 22, 6, 95
  };
  const int q6108[] = {
    9, 9, // Number of jobs and machines
    2, 66, 4, 46, 3, 47, 0, 72, 6,  8, 5, 72, 1, 89, 7, 23, 8, 50, 
    1, 24, 2, 90, 0, 86, 3, 83, 4, 37, 7, 44, 5, 28, 6, 52, 8, 27, 
    4, 45, 6, 18, 3, 74, 8, 31, 1, 28, 2, 27, 0, 71, 5, 31, 7, 26, 
    2, 55, 7, 73, 8, 18, 4, 89, 5, 59, 6, 43, 1, 70, 3, 33, 0, 61, 
    4, 65, 0, 82, 5, 38, 2, 47, 3, 43, 7, 42, 6, 86, 1, 10, 8, 96, 
    3, 95, 6, 58, 0, 97, 8, 86, 4, 34, 5, 59, 1, 54, 7, 18, 2, 87, 
    1, 23, 4, 80, 3, 19, 2, 55, 5, 49, 8, 56, 7, 85, 6, 70, 0, 40, 
    7, 21, 1, 70, 5, 36, 2, 12, 4,  6, 0, 42, 6, 51, 3, 36, 8, 95, 
    5, 33, 2, 34, 7, 90, 0, 32, 4, 21, 1, 25, 6, 32, 3, 47, 8,  2
  };
  const int q6109[] = {
    9, 9, // Number of jobs and machines
    7, 71, 0, 74, 6, 43, 3,  1, 4,  3, 2, 63, 8, 52, 1, 16, 5,  3, 
    0,  4, 5, 74, 1, 17, 3, 30, 7, 86, 6, 99, 4, 17, 2, 50, 8, 37, 
    5, 71, 6, 37, 0,  6, 3,  3, 8, 46, 7, 98, 4, 93, 1, 61, 2, 13, 
    3, 91, 5, 86, 8, 98, 0, 71, 2, 99, 6, 31, 7, 88, 1, 79, 4, 73, 
    3, 70, 6, 14, 4,  3, 1, 52, 2, 27, 5, 49, 0, 13, 8,  1, 7, 32, 
    2, 90, 3, 90, 4, 38, 8, 70, 0, 75, 5, 30, 7, 22, 6,  4, 1, 51, 
    0, 25, 5,  9, 8, 84, 7, 86, 3, 64, 4, 17, 1, 34, 6, 89, 2, 95, 
    8, 82, 4, 71, 1, 15, 7, 41, 6, 63, 2, 17, 0, 27, 5, 98, 3, 75, 
    1, 62, 5, 43, 4,  3, 8, 47, 6, 36, 3, 26, 0, 62, 2, 33, 7, 74
  };
  const int q6110[] = {
    9, 9, // Number of jobs and machines
    0, 51, 4, 47, 5, 93, 6, 68, 7,  5, 3, 80, 1, 53, 2, 89, 8, 36, 
    1, 29, 0, 49, 6, 56, 7, 19, 8, 70, 3, 58, 4, 80, 5, 77, 2, 24, 
    2, 86, 1, 50, 7, 77, 3, 95, 6, 89, 4, 69, 0,  3, 5, 97, 8, 63, 
    2, 38, 0, 97, 8, 93, 6, 58, 7, 16, 1, 46, 5, 47, 4, 76, 3, 28, 
    7, 95, 8, 16, 6, 88, 1, 96, 3,  9, 2, 63, 5, 80, 4, 76, 0, 58, 
    8, 87, 5, 93, 1, 41, 3, 12, 0, 83, 4, 27, 7,  8, 2,  3, 6, 44, 
    5, 93, 2, 27, 8, 37, 6, 99, 7, 76, 3, 58, 1, 69, 4, 88, 0, 69, 
    1, 40, 5, 65, 7,  3, 2, 62, 6, 26, 4, 24, 0, 68, 3, 52, 8, 37, 
    2, 33, 7, 10, 1, 74, 6, 52, 5, 36, 8, 57, 0, 20, 4, 45, 3,  8
  };
  const int q6111[] = {
    9, 9, // Number of jobs and machines
    2, 96, 8, 70, 4, 42, 5,  9, 3, 85, 7, 68, 6, 88, 1, 62, 0, 95, 
    8, 77, 7,  3, 5, 14, 6, 69, 3, 17, 4, 82, 1, 90, 0, 84, 2, 70, 
    7, 75, 5, 90, 3,  6, 6, 14, 0, 37, 4, 61, 2, 51, 1, 27, 8, 45, 
    6, 45, 5, 66, 1, 94, 4, 95, 2, 74, 8, 66, 7, 98, 3,  2, 0,  1, 
    7,  4, 0, 43, 1, 97, 6,  8, 3, 53, 4,  9, 2, 82, 5, 89, 8, 85, 
    3, 87, 7, 32, 5, 49, 1, 84, 0, 67, 8, 21, 2, 74, 6, 90, 4,  9, 
    2, 37, 8, 21, 0, 25, 3, 37, 1, 87, 6, 50, 5,  2, 7, 67, 4, 26, 
    0, 89, 4, 19, 7,  2, 6, 32, 8, 11, 1, 28, 3, 77, 5, 52, 2, 64, 
    1, 57, 0, 44, 4, 23, 8, 57, 7, 17, 2, 41, 5, 93, 6, 37, 3, 48
  };
  const int q6112[] = {
    9, 9, // Number of jobs and machines
    7,  1, 2, 55, 0, 95, 3, 75, 5,  6, 4, 88, 6, 85, 1, 39, 8, 64, 
    2, 27, 6, 41, 4, 47, 1, 61, 8, 89, 3, 65, 5, 38, 0, 20, 7, 92, 
    6, 21, 5, 55, 7, 46, 3, 68, 4, 16, 1, 40, 0, 22, 2, 47, 8, 42, 
    3, 39, 4, 57, 0,  7, 8, 89, 6, 32, 2, 35, 5, 92, 7, 29, 1, 32, 
    7, 33, 6, 56, 3, 98, 2, 45, 8, 20, 4, 24, 0, 93, 5, 41, 1, 52, 
    0, 62, 1, 39, 4, 38, 6, 74, 3, 70, 7, 17, 2, 38, 5, 11, 8, 61, 
    1, 38, 5, 49, 6, 82, 2, 62, 4, 70, 3, 97, 8, 93, 0, 49, 7, 21, 
    3, 11, 6, 65, 8, 91, 1, 19, 5, 60, 7,  9, 4, 33, 2, 59, 0, 20, 
    1, 99, 7, 94, 4, 94, 0, 64, 5, 31, 8, 23, 3, 60, 2, 10, 6, 46
  };
  const int q6113[] = {
    9, 9, // Number of jobs and machines
    2, 32, 0, 79, 7, 26, 1,  2, 6, 78, 3, 81, 5, 11, 8, 73, 4, 80, 
    1, 69, 4, 57, 6, 96, 3, 77, 0, 49, 5, 87, 7, 38, 8, 70, 2, 51, 
    6, 67, 8, 20, 3, 17, 0, 42, 7, 47, 2, 56, 1, 98, 4, 66, 5, 52, 
    2, 44, 3, 46, 7, 92, 8, 90, 1, 54, 0, 23, 5, 97, 6, 59, 4, 64, 
    5, 50, 1, 10, 2,  5, 7, 86, 4, 45, 8, 72, 3, 11, 6, 56, 0, 59, 
    3, 94, 7, 12, 1, 59, 6, 17, 4, 76, 0, 38, 8, 15, 2, 28, 5,  9, 
    8, 60, 7, 52, 4, 85, 0, 37, 5, 28, 6,  2, 2, 10, 3,  6, 1, 74, 
    4, 90, 3, 72, 7, 49, 2, 79, 0, 78, 5, 31, 8, 31, 1, 88, 6, 75, 
    4, 88, 8, 14, 3, 25, 2, 17, 1, 74, 5, 11, 7,  5, 6, 20, 0, 78
  };
  const int q6114[] = {
    9, 9, // Number of jobs and machines
    2, 79, 3, 51, 5, 45, 1, 88, 0, 73, 8, 95, 4, 74, 7, 88, 6, 63, 
    6, 39, 1, 83, 2, 47, 3, 29, 7,  1, 8, 12, 4, 93, 0, 29, 5,  7, 
    8, 56, 6, 93, 7, 38, 2, 78, 4, 78, 0, 72, 1,  7, 3, 97, 5, 38, 
    8, 51, 2, 28, 5, 70, 7, 86, 0, 63, 1, 79, 4, 91, 3, 84, 6, 89, 
    3, 22, 2, 83, 7,  1, 1, 55, 5, 85, 0, 28, 6, 86, 8, 45, 4, 95, 
    8, 76, 1, 45, 6, 65, 2, 61, 4, 52, 7, 54, 0, 91, 3,  3, 5, 41, 
    6, 70, 7, 21, 8, 16, 3, 11, 2, 12, 4, 76, 1, 50, 5, 97, 0, 43, 
    3, 98, 4, 82, 2, 74, 6, 32, 8, 98, 7, 19, 5, 91, 1, 44, 0,  6, 
    5, 74, 6,  1, 2,  5, 0,  1, 7, 20, 3, 47, 1,  9, 8,  5, 4, 34
  };
  const int q6115[] = {
    9, 9, // Number of jobs and machines
    8, 98, 1, 74, 5, 51, 6, 57, 4, 96, 0,  3, 7, 99, 3, 30, 2, 37, 
    4, 29, 2, 34, 3, 26, 8, 41, 7,  8, 5, 50, 0,  3, 1, 55, 6, 57, 
    0, 94, 6, 70, 2, 76, 8, 16, 5, 60, 4, 42, 7, 31, 1,  6, 3, 77, 
    8, 55, 2, 56, 7, 71, 5, 36, 1, 10, 4, 41, 0, 39, 3,  2, 6, 87, 
    3,  2, 7, 73, 1, 84, 2, 71, 6, 79, 0, 53, 5, 47, 8, 46, 4, 87, 
    6, 73, 4, 12, 2, 53, 3, 64, 8, 36, 5, 58, 1, 12, 7, 18, 0, 81, 
    1, 83, 4, 33, 6,  6, 0,  1, 5, 20, 3, 72, 7, 44, 2, 16, 8, 23, 
    4, 84, 6, 10, 3, 49, 7, 45, 2, 67, 0,  1, 5, 28, 8, 60, 1,  2, 
    5, 22, 0, 12, 4, 66, 2, 46, 7, 64, 3, 40, 6, 22, 1, 44, 8, 87
  };
  const int q6116[] = {
    9, 9, // Number of jobs and machines
    5,  4, 0, 90, 2, 43, 6, 34, 4, 81, 7, 95, 8, 59, 3, 21, 1, 18, 
    4, 44, 3, 55, 6, 42, 5, 52, 1, 95, 2, 87, 0, 78, 8, 79, 7,  3, 
    4, 34, 8, 81, 0,  3, 2, 54, 7, 35, 5, 41, 6, 24, 1, 87, 3, 65, 
    6, 42, 8, 73, 7, 79, 0, 84, 1, 12, 5, 19, 4, 36, 3, 34, 2, 53, 
    5, 93, 7, 34, 0, 44, 1, 14, 4, 64, 3, 62, 2, 17, 8, 37, 6, 48, 
    6, 10, 0, 41, 7,  1, 5, 60, 8, 18, 2, 77, 1, 83, 4, 55, 3, 67, 
    1, 26, 0, 38, 4, 22, 6, 79, 3, 44, 2, 18, 7, 87, 8, 64, 5,  4, 
    8, 44, 0, 64, 5, 86, 4, 64, 7, 71, 6, 81, 3, 70, 1, 22, 2, 30, 
    6, 52, 1, 36, 0,  7, 4, 42, 3, 96, 8, 75, 2, 98, 5, 72, 7, 40
  };
  const int q6117[] = {
    9, 9, // Number of jobs and machines
    6, 91, 8, 47, 2, 61, 3, 58, 5, 10, 7, 75, 1, 79, 4, 60, 0, 56, 
    0, 31, 5, 94, 7, 89, 6,  9, 3, 53, 8, 47, 4, 90, 1, 63, 2, 69, 
    1,  8, 8, 66, 3, 43, 0, 12, 5, 20, 6, 55, 2, 78, 7, 70, 4, 57, 
    8, 61, 1,  4, 6, 19, 5, 44, 4, 44, 2, 62, 3, 29, 0, 74, 7, 98, 
    5, 29, 8, 89, 3, 53, 6, 95, 4, 57, 1, 51, 0, 70, 7, 25, 2,  1, 
    8, 87, 0, 53, 3, 94, 1, 93, 7, 47, 6, 57, 5, 99, 4, 89, 2, 63, 
    1, 11, 2, 17, 7, 69, 0, 93, 8, 56, 5, 90, 6, 82, 4, 20, 3, 17, 
    0, 89, 7, 95, 5, 79, 4,  8, 2,  2, 3, 56, 1,  6, 6, 39, 8, 23, 
    2, 53, 7, 87, 3, 12, 5, 17, 0, 79, 6, 73, 1, 13, 8,  7, 4, 67
  };
  const int q6118[] = {
    9, 9, // Number of jobs and machines
    8, 11, 3, 36, 5, 88, 6, 53, 2, 84, 7, 38, 1, 65, 4, 48, 0, 16, 
    6, 81, 1, 16, 5, 81, 8, 81, 2, 70, 4, 96, 7,  9, 3, 68, 0, 96, 
    3, 89, 2,  6, 1,  3, 8, 78, 4, 59, 5, 64, 6, 52, 7, 27, 0, 10, 
    7, 68, 0, 45, 6, 39, 2, 70, 4, 19, 8, 74, 3,  7, 5,  4, 1,  9, 
    0, 32, 7, 96, 2, 45, 8, 62, 6, 41, 1, 37, 3, 84, 4,  5, 5, 80, 
    0, 53, 3, 88, 1, 87, 2, 47, 7, 34, 6, 23, 5, 57, 4, 61, 8, 74, 
    3,  3, 4, 14, 0, 48, 1, 68, 6,  3, 8, 79, 7, 40, 5, 32, 2, 12, 
    2, 72, 5, 42, 7, 10, 6, 50, 8, 68, 1, 88, 0, 16, 4, 53, 3, 35, 
    6, 25, 4, 57, 7,  3, 3, 24, 0, 33, 2, 84, 5, 30, 1, 91, 8, 66
  };
  const int q6119[] = {
    9, 9, // Number of jobs and machines
    2, 14, 4, 43, 5, 85, 0, 76, 7, 42, 8, 30, 3,  8, 6,  7, 1, 36, 
    3, 69, 4, 83, 1, 94, 7, 96, 6, 86, 5,  3, 8, 84, 2, 26, 0, 89, 
    3, 78, 5, 11, 2, 58, 7, 87, 4, 61, 1, 49, 0, 56, 6, 76, 8, 16, 
    5, 29, 7, 37, 8, 26, 6,  1, 3, 77, 0, 28, 4, 85, 1, 22, 2, 30, 
    4, 94, 6, 36, 3, 39, 0,  2, 1, 93, 7, 72, 5,  3, 2,  3, 8, 39, 
    4, 48, 1, 53, 0, 19, 2, 26, 3, 82, 5, 28, 6, 49, 8, 91, 7, 40, 
    1, 71, 3, 51, 4,  1, 6, 40, 5, 16, 0, 80, 7, 43, 8, 92, 2, 37, 
    8,  5, 6, 33, 2, 94, 3, 93, 4, 85, 1, 12, 5, 64, 7, 84, 0, 89, 
    5, 96, 8,  9, 4, 51, 3, 18, 1, 57, 7, 89, 2, 18, 6, 57, 0, 64
  };
  const int q6120[] = {
    9, 9, // Number of jobs and machines
    3, 89, 1, 51, 0, 84, 2,  3, 6, 61, 5, 65, 4, 52, 7, 17, 8, 88, 
    5, 42, 7, 81, 2, 27, 0, 37, 1, 89, 3, 34, 8, 93, 6, 16, 4, 82, 
    6, 80, 2, 65, 7, 57, 1, 89, 8, 69, 3,  8, 4, 75, 5, 76, 0, 25, 
    4, 29, 3, 56, 1, 28, 7, 16, 5, 45, 2, 67, 8, 37, 0, 57, 6,  9, 
    8, 65, 6, 86, 3, 96, 7, 41, 5, 43, 0, 93, 1, 86, 2, 92, 4, 46, 
    0, 36, 7, 57, 3, 13, 6, 90, 2, 31, 4, 55, 8, 53, 5, 35, 1, 92, 
    8,  6, 6, 94, 1, 16, 2, 59, 3, 22, 5, 40, 7, 42, 0, 80, 4, 44, 
    4, 23, 3, 84, 7, 98, 1, 65, 2, 31, 8, 98, 5, 11, 6, 74, 0, 22, 
    7, 86, 6, 13, 3, 42, 4, 36, 1,  5, 5, 63, 2, 96, 0, 62, 8, 58
  };
  const int q6121[] = {
    9, 9, // Number of jobs and machines
    3, 99, 2,  6, 1, 47, 8, 60, 5, 75, 4, 14, 6, 47, 7,  8, 0, 73, 
    3, 54, 2, 11, 7, 36, 1, 18, 5, 26, 6, 29, 4, 49, 0, 66, 8,  2, 
    3, 80, 8, 11, 5, 79, 0, 21, 1, 17, 4, 67, 2, 71, 7, 29, 6, 80, 
    4, 13, 7, 36, 6,  3, 0, 87, 3, 87, 2, 37, 1, 82, 8, 94, 5, 98, 
    3, 74, 6, 54, 1, 23, 2, 96, 8, 93, 4, 30, 0, 68, 7, 45, 5, 57, 
    6, 19, 3, 79, 4, 81, 0, 99, 2, 65, 8, 84, 5, 33, 1, 57, 7, 25, 
    2,  7, 3, 85, 6, 41, 4, 26, 8, 32, 7, 79, 0, 72, 1, 37, 5, 33, 
    6, 64, 8, 58, 1, 45, 4, 10, 0, 40, 3, 65, 2, 85, 7, 91, 5,  8, 
    1, 90, 4, 39, 2, 26, 0, 68, 6, 53, 7, 73, 8, 31, 5, 43, 3, 30
  };
  const int q6122[] = {
    9, 9, // Number of jobs and machines
    3,  4, 2, 43, 8, 74, 1, 55, 5, 15, 6, 88, 7,  8, 4, 34, 0, 40, 
    2,  7, 1, 79, 3, 45, 4,  6, 5, 84, 8, 92, 0,  5, 7, 85, 6, 85, 
    2, 96, 5, 97, 8, 27, 1, 34, 7, 54, 6, 13, 0, 44, 4, 97, 3, 65, 
    5, 58, 6, 67, 7, 70, 4, 40, 3, 68, 1, 43, 2, 97, 8, 42, 0, 62, 
    4, 41, 5,  2, 1, 36, 2, 55, 0, 77, 8, 68, 7, 41, 6, 71, 3, 24, 
    4, 34, 3, 11, 2,  9, 8, 35, 6, 23, 1, 94, 7, 90, 0, 47, 5, 68, 
    1, 26, 8, 20, 6, 57, 7, 80, 2, 93, 0, 40, 5, 48, 3, 53, 4, 29, 
    6, 45, 0, 36, 7, 13, 3, 89, 8, 74, 4, 10, 2, 84, 1, 38, 5, 41, 
    7, 77, 8, 17, 3, 28, 1, 82, 5, 74, 6, 76, 2, 95, 0, 27, 4, 75
  };
  const int q6123[] = {
    9, 9, // Number of jobs and machines
    1, 31, 8, 11, 3, 88, 4,  8, 7, 32, 2, 16, 5, 47, 0, 72, 6, 89, 
    3, 91, 4,  2, 7, 58, 2, 12, 6, 75, 5, 45, 8, 63, 1, 64, 0, 15, 
    1, 10, 6, 63, 3, 10, 8,  8, 4,  7, 0, 65, 2, 90, 5, 26, 7, 29, 
    3, 94, 7,  8, 5, 38, 6, 93, 2, 21, 8, 11, 0,  1, 1, 86, 4, 10, 
    0, 56, 7, 50, 1,  9, 8, 66, 3, 92, 6, 92, 5, 45, 4, 15, 2, 47, 
    5, 49, 1, 68, 6, 71, 2, 90, 0, 48, 4, 29, 7, 22, 8, 50, 3, 12, 
    0, 68, 3,  1, 4, 62, 1, 81, 6, 90, 8, 42, 7, 46, 2, 55, 5, 53, 
    6, 43, 1, 24, 8, 91, 4, 12, 3, 34, 5, 13, 0, 28, 7, 72, 2, 30, 
    5, 74, 1, 88, 0, 16, 8, 35, 4, 30, 6, 66, 3, 54, 7, 97, 2, 78
  };
  const int q6124[] = {
    9, 9, // Number of jobs and machines
    8, 86, 4, 13, 6, 81, 5, 94, 1, 78, 7, 16, 0, 34, 2, 99, 3, 28, 
    3, 87, 2, 73, 5, 70, 7, 81, 1, 54, 8, 39, 4, 40, 6, 93, 0, 33, 
    3, 73, 1,  2, 8, 67, 6, 16, 4, 79, 5, 41, 7, 83, 2, 74, 0, 67, 
    7, 13, 6, 79, 8, 47, 2,  7, 5,  5, 4, 99, 3, 67, 0, 98, 1, 10, 
    1, 49, 2, 59, 5, 47, 0, 98, 3,  8, 6, 22, 8, 85, 4, 92, 7, 64, 
    2, 64, 8, 18, 5, 33, 1, 74, 0, 89, 6,  1, 4, 20, 7, 11, 3, 25, 
    7, 31, 2, 24, 4, 86, 6, 43, 1,  9, 3, 42, 5, 73, 8,  1, 0, 49, 
    8, 17, 7, 13, 5, 78, 1, 23, 0, 87, 3, 86, 6, 10, 4, 52, 2, 72, 
    0,  4, 6,  3, 2, 47, 3, 23, 4, 95, 1,  6, 5, 91, 8, 45, 7,  2
  };
  const int q6125[] = {
    9, 9, // Number of jobs and machines
    0, 51, 6, 17, 2, 35, 1, 64, 5, 96, 8, 75, 7, 83, 3, 55, 4, 26, 
    3,  7, 4, 18, 6, 95, 2, 27, 1, 39, 0, 54, 5, 91, 7, 94, 8, 94, 
    7, 72, 6, 40, 4,  3, 0, 56, 3, 82, 5, 62, 1, 37, 2, 99, 8, 21, 
    6, 98, 8, 96, 4,  2, 7, 16, 0, 16, 5, 35, 2,  4, 3, 96, 1,  2, 
    1, 39, 6, 53, 7, 64, 8, 32, 5, 65, 4, 28, 3, 53, 2, 45, 0,  4, 
    8, 40, 5, 15, 0, 35, 6, 65, 4, 67, 7, 94, 1, 56, 3, 94, 2, 75, 
    2, 42, 7, 43, 4, 43, 0, 12, 1, 58, 8,  6, 5, 85, 6, 67, 3, 34, 
    5, 66, 6, 36, 2, 52, 0, 48, 7,  5, 4, 14, 3, 10, 1, 53, 8, 98, 
    1, 26, 7, 88, 3, 69, 4, 45, 0, 39, 6, 95, 2, 78, 5, 63, 8, 29
  };
  const int q6126[] = {
    9, 9, // Number of jobs and machines
    5, 33, 1, 35, 7, 97, 3, 46, 4, 58, 0, 83, 2, 46, 8,  1, 6, 35, 
    2, 10, 5, 67, 0, 96, 8, 13, 7, 63, 4, 58, 1, 42, 6, 68, 3, 80, 
    5, 18, 8, 58, 3, 52, 0, 27, 7, 46, 1, 68, 6, 17, 2, 94, 4, 85, 
    4, 61, 0, 55, 3, 80, 1, 70, 7, 89, 5, 90, 2, 26, 6, 70, 8, 83, 
    8, 83, 5, 36, 2, 72, 4, 31, 0, 58, 6, 28, 7, 36, 3, 53, 1, 83, 
    8,  7, 2, 46, 0, 82, 4, 19, 1, 64, 3, 57, 5,  1, 7, 90, 6, 15, 
    6, 88, 3, 88, 4, 72, 7, 17, 2, 85, 1, 94, 8, 46, 5, 28, 0, 36, 
    5, 89, 1, 50, 3, 28, 7, 83, 8, 71, 2, 65, 6,  2, 4, 98, 0,  7, 
    3, 11, 7,  1, 2, 24, 6, 28, 4, 85, 1,  3, 8, 31, 0, 12, 5, 48
  };
  const int q6127[] = {
    9, 9, // Number of jobs and machines
    4, 58, 5, 41, 1, 97, 8, 26, 2, 73, 3, 40, 7, 27, 0, 58, 6, 42, 
    2, 77, 3, 38, 7, 87, 5, 88, 1, 59, 8, 68, 6, 13, 4, 91, 0, 35, 
    0,  2, 1, 49, 5, 15, 6, 99, 4, 94, 7, 35, 3, 71, 2, 59, 8, 39, 
    1, 19, 5, 32, 7, 13, 2, 24, 0, 19, 3, 19, 4, 98, 6, 19, 8, 12, 
    0, 37, 5,  1, 8, 88, 7, 40, 4, 68, 3, 18, 2, 24, 6, 64, 1, 73, 
    7, 51, 1, 90, 0, 90, 2, 40, 6, 79, 4, 22, 8, 25, 5, 50, 3, 53, 
    5, 50, 2, 74, 6, 82, 7, 68, 4, 32, 3, 50, 8, 52, 1,  9, 0, 22, 
    6, 24, 8, 54, 4, 29, 7,  4, 2,  4, 5, 28, 0,  2, 3, 51, 1, 56, 
    3, 40, 2, 33, 1, 13, 8,  1, 6, 64, 7,  7, 0, 53, 5, 93, 4, 46
  };
  const int q6128[] = {
    9, 9, // Number of jobs and machines
    4, 78, 3, 89, 2, 83, 1, 26, 8, 85, 5, 38, 6, 34, 7, 60, 0, 21, 
    3, 86, 2, 64, 4, 83, 7, 87, 5, 86, 8, 43, 6, 44, 0, 91, 1, 68, 
    4, 71, 1, 91, 6, 92, 5, 36, 0, 28, 2,  7, 3, 56, 7, 34, 8, 29, 
    7, 53, 0, 55, 5, 70, 4, 55, 8, 69, 3, 46, 6, 86, 2,  5, 1, 21, 
    5, 40, 3, 45, 1,  9, 0, 53, 2, 47, 7, 98, 6,  3, 4, 74, 8, 49, 
    6, 25, 7, 51, 4, 15, 8, 96, 5, 54, 2,  3, 0, 17, 3, 61, 1,  4, 
    1, 55, 8, 11, 5, 71, 7, 20, 4, 26, 6, 98, 0, 44, 2, 31, 3, 86, 
    2, 93, 3, 53, 4, 98, 1, 51, 6, 12, 5,  5, 7, 28, 8, 99, 0, 76, 
    7, 51, 6, 99, 5, 20, 3, 61, 1, 69, 8, 81, 0, 74, 4, 47, 2,  5
  };
  const int q6129[] = {
    9, 9, // Number of jobs and machines
    4, 89, 3, 65, 8,  9, 6, 59, 2, 56, 0, 85, 1, 69, 5, 43, 7, 17, 
    1, 84, 0, 19, 4, 92, 2, 60, 7, 25, 6, 30, 5, 46, 8, 60, 3, 80, 
    2, 73, 6, 52, 1, 14, 3, 69, 8, 48, 7, 14, 5, 10, 0, 48, 4, 75, 
    3,  1, 2, 44, 6, 26, 1, 74, 7, 46, 8, 32, 5,  4, 0, 56, 4, 86, 
    3, 63, 0, 26, 5, 56, 4, 65, 8, 82, 1, 13, 2, 75, 7, 80, 6, 61, 
    2, 31, 1,  8, 8, 69, 6, 71, 4, 87, 0, 31, 3, 45, 5, 25, 7, 27, 
    1, 79, 2, 29, 4, 31, 6, 11, 7, 87, 8, 90, 3, 99, 0,  5, 5, 84, 
    2, 62, 8, 32, 4, 24, 5, 80, 3, 94, 7, 91, 1, 21, 6, 39, 0, 19, 
    6, 38, 0, 51, 5, 70, 1, 34, 3, 45, 7,  9, 8, 96, 2, 91, 4, 25
  };
  const int q6130[] = {
    9, 9, // Number of jobs and machines
    8, 25, 0, 66, 2, 70, 3, 46, 6, 49, 1, 44, 4, 81, 7, 63, 5, 57, 
    4, 58, 5, 93, 7, 34, 2, 72, 3, 70, 0, 51, 8, 72, 6, 93, 1, 57, 
    5, 27, 4, 95, 8,  8, 7, 72, 1, 72, 6, 63, 0, 51, 2, 33, 3, 65, 
    1, 68, 8, 83, 5, 55, 3, 99, 2, 19, 7, 56, 4,  3, 0, 70, 6, 44, 
    8, 42, 2,  1, 1, 76, 3, 81, 5, 66, 6, 79, 7,  2, 0, 65, 4, 25, 
    8, 15, 3,  6, 7, 37, 1, 36, 0, 72, 6, 14, 5, 36, 2, 34, 4, 52, 
    5, 66, 7, 52, 0,  5, 4, 73, 3, 77, 2, 62, 6, 65, 8, 67, 1, 34, 
    3, 49, 8, 19, 0, 38, 2, 53, 7, 98, 6, 34, 5, 25, 4, 17, 1, 24, 
    5, 15, 8, 83, 6, 15, 7, 82, 3, 21, 4,  8, 0,  8, 2, 20, 1, 81
  };
  const int q6131[] = {
    9, 9, // Number of jobs and machines
    2, 20, 1, 82, 0, 96, 8, 14, 3,  7, 7,  7, 4,  8, 6, 95, 5, 37, 
    8, 21, 3, 36, 6, 12, 7, 58, 2, 18, 0, 68, 5, 56, 4, 66, 1, 87, 
    7, 28, 4, 74, 6, 49, 5, 94, 2, 41, 8,  4, 0, 58, 1, 26, 3, 96, 
    1, 65, 5, 75, 4, 25, 2, 20, 6, 53, 0, 84, 8, 49, 3, 37, 7, 67, 
    1, 34, 7, 88, 6, 92, 3, 65, 5, 25, 8, 92, 4, 38, 0, 38, 2, 95, 
    7, 27, 3, 27, 1, 23, 5, 48, 4, 80, 8,  7, 0, 71, 2, 64, 6, 13, 
    7, 60, 3, 93, 1, 61, 4,  8, 8,  3, 6, 70, 0, 76, 2, 85, 5, 66, 
    7, 62, 3, 77, 6, 41, 2, 54, 8, 13, 5,  6, 1, 83, 0, 11, 4, 47, 
    4, 35, 2, 53, 1, 41, 6, 45, 8, 86, 3, 55, 0, 18, 5, 43, 7, 48
  };
  const int q6132[] = {
    9, 9, // Number of jobs and machines
    6, 73, 5, 82, 3, 27, 7, 82, 8, 63, 4, 36, 2, 64, 1, 38, 0, 59, 
    1, 93, 2, 62, 0, 95, 4, 30, 6, 72, 8, 14, 7, 22, 5, 45, 3, 28, 
    3,  6, 1, 92, 5,  1, 6, 20, 2, 42, 0, 63, 7, 91, 8, 72, 4, 56, 
    6, 31, 5,  2, 8, 10, 0, 19, 1, 84, 2, 57, 4, 77, 7, 63, 3, 55, 
    6, 46, 2, 44, 7, 86, 3, 17, 0, 69, 1, 19, 5, 10, 8, 18, 4, 99, 
    6, 29, 0, 40, 1, 33, 7, 47, 5, 28, 4, 78, 2, 97, 8,  1, 3, 72, 
    0, 97, 7, 18, 4, 87, 3, 39, 6, 41, 1, 79, 8, 92, 2,  2, 5, 59, 
    7, 26, 6,  3, 5, 45, 1, 70, 0, 63, 3, 68, 8, 60, 2, 11, 4, 52, 
    4, 82, 6, 91, 2,  6, 0, 70, 5, 40, 7, 66, 1, 35, 8, 67, 3, 57
  };
  const int q6133[] = {
    9, 9, // Number of jobs and machines
    3, 28, 7, 94, 8, 96, 4, 58, 5,  3, 6, 69, 1, 17, 0, 77, 2, 13, 
    5, 85, 7, 51, 6, 15, 3, 36, 0, 24, 8, 50, 1, 53, 4, 21, 2,  8, 
    2, 15, 5, 25, 8, 23, 0, 13, 7, 53, 3, 34, 6, 95, 4, 11, 1, 61, 
    2, 17, 4, 62, 6, 88, 3, 81, 8, 26, 5,  4, 7, 64, 1, 93, 0, 33, 
    0, 92, 3, 63, 1, 24, 5, 17, 8, 35, 6, 65, 2, 60, 4, 87, 7, 65, 
    5, 34, 0, 99, 1, 16, 6, 63, 8, 72, 2, 69, 3, 67, 4, 60, 7,  7, 
    7, 88, 1, 44, 6, 34, 3, 22, 4, 75, 2, 73, 0, 66, 5, 63, 8, 85, 
    5, 14, 7, 62, 3, 54, 2, 46, 4, 73, 0, 65, 6, 34, 1,  2, 8, 75, 
    1,  6, 3, 91, 2, 12, 7, 63, 5, 36, 8, 58, 4, 65, 0, 64, 6, 26
  };
  const int q6134[] = {
    9, 9, // Number of jobs and machines
    2, 61, 4, 24, 3, 86, 7,  1, 0, 51, 6, 71, 1, 45, 8, 25, 5, 86, 
    8, 68, 2, 40, 5, 78, 7, 62, 0, 87, 3, 95, 1, 27, 6, 51, 4, 45, 
    3, 96, 7, 48, 1, 38, 5, 85, 8, 49, 6, 29, 2, 64, 4,  9, 0, 12, 
    6, 82, 0, 56, 8, 34, 1, 47, 5, 77, 4, 62, 3, 91, 7, 60, 2, 73, 
    5,  9, 0, 33, 2, 28, 7, 11, 6, 97, 8, 78, 4, 52, 1, 60, 3, 43, 
    8, 58, 4, 12, 0, 26, 7, 62, 1, 51, 6, 44, 2, 71, 3, 77, 5, 84, 
    6, 42, 8, 23, 2, 37, 3, 76, 1, 27, 0, 44, 5, 85, 7, 51, 4, 94, 
    6, 69, 8, 41, 0, 14, 1, 23, 2, 29, 4, 67, 3, 75, 5, 82, 7, 82, 
    5, 49, 4, 42, 0,  8, 2,  7, 6, 60, 1, 75, 7, 74, 8, 23, 3, 71
  };
  const int q6135[] = {
    9, 9, // Number of jobs and machines
    5,  1, 0, 43, 4, 80, 8, 31, 6, 39, 3, 81, 7,  1, 1, 53, 2, 55, 
    2, 24, 5, 63, 8, 67, 6, 62, 0,  6, 3, 71, 7, 59, 1, 85, 4, 30, 
    2, 60, 1,  7, 3, 72, 5,  8, 7, 85, 8, 21, 6, 46, 0, 93, 4, 35, 
    0, 90, 8, 26, 5, 42, 1, 46, 7, 47, 4, 67, 3,  6, 2, 74, 6, 55, 
    5, 14, 8,  2, 1, 82, 4, 39, 0, 39, 3,  2, 2, 52, 6, 30, 7, 42, 
    2, 68, 6, 34, 3, 54, 1, 80, 5, 18, 0, 23, 4, 63, 8, 37, 7, 66, 
    7, 58, 4, 94, 0, 45, 2, 15, 6, 89, 3, 11, 5, 82, 8, 38, 1, 69, 
    3, 27, 2, 89, 6, 95, 0, 39, 8, 30, 4, 99, 1, 93, 5, 98, 7, 64, 
    4, 19, 2, 64, 7, 37, 0, 57, 3,  4, 8, 46, 5, 93, 6, 64, 1, 15
  };
  const int q6136[] = {
    9, 9, // Number of jobs and machines
    0, 51, 5,  2, 1, 58, 4, 86, 3, 75, 8, 29, 6, 73, 7, 42, 2, 95, 
    7, 87, 1, 64, 8,  3, 6, 31, 0, 18, 4, 87, 3, 34, 2, 13, 5, 59, 
    0, 17, 7, 43, 5,  1, 3, 21, 1, 64, 6, 77, 8, 96, 2, 48, 4, 75, 
    0, 95, 7, 31, 6, 41, 3, 84, 5, 29, 8, 76, 4, 90, 1,  7, 2, 12, 
    5, 40, 3, 36, 4, 15, 2, 13, 6, 18, 0, 81, 1,  5, 7, 96, 8, 74, 
    7, 50, 5, 97, 3,  2, 0, 75, 4, 10, 6, 54, 8, 62, 2, 49, 1, 46, 
    5, 39, 0, 87, 2, 96, 3, 40, 4, 22, 6, 62, 8,  9, 1, 58, 7, 56, 
    4, 32, 7, 17, 3, 75, 1, 79, 2, 24, 0, 90, 8, 14, 5, 40, 6, 50, 
    3, 79, 8, 45, 4, 87, 6, 20, 2, 53, 5, 52, 7,  4, 1, 59, 0, 29
  };
  const int q6137[] = {
    9, 9, // Number of jobs and machines
    4, 10, 2,  3, 1, 12, 3, 20, 0, 95, 7, 32, 5, 11, 6,  9, 8, 57, 
    6, 69, 8, 29, 1,  3, 3, 54, 5, 56, 0, 79, 4, 22, 2, 97, 7, 31, 
    4, 71, 0, 94, 5, 89, 1,  6, 8, 95, 7, 77, 2, 55, 3, 87, 6, 56, 
    7, 49, 8,  4, 5, 97, 1, 22, 0, 49, 2,  3, 4, 13, 6, 60, 3, 84, 
    1, 96, 7,  9, 5, 88, 2, 87, 8, 12, 4, 94, 3, 51, 6, 28, 0,  1, 
    8, 32, 1, 47, 6, 79, 7, 28, 2, 37, 4, 46, 0, 66, 5, 88, 3, 45, 
    8, 21, 1, 87, 4, 20, 2, 40, 7, 27, 6, 50, 5, 95, 3,  7, 0, 70, 
    7, 23, 2, 48, 0, 13, 6, 39, 8, 38, 3, 79, 5, 12, 4,  6, 1, 93, 
    8, 94, 5,  5, 2, 36, 0, 67, 3, 89, 1, 15, 4, 84, 6, 70, 7, 37
  };
  const int q6138[] = {
    9, 9, // Number of jobs and machines
    3, 64, 4, 48, 1, 21, 0, 97, 8, 51, 2, 41, 6, 16, 5, 59, 7, 55, 
    0, 71, 2, 80, 3, 48, 6, 42, 1, 36, 8, 18, 5, 38, 7, 99, 4, 97, 
    5, 60, 4, 94, 1, 81, 3, 30, 0, 66, 8, 97, 7, 16, 2, 30, 6, 98, 
    3, 10, 7, 85, 5, 28, 8, 73, 6, 68, 2, 45, 4, 73, 1, 32, 0, 78, 
    0, 52, 6, 94, 1, 34, 7, 95, 3, 55, 8, 79, 4, 22, 5,  1, 2, 18, 
    2, 56, 8, 61, 3, 23, 7, 61, 0, 43, 5, 22, 1, 20, 4, 15, 6, 26, 
    1, 13, 8, 59, 3, 39, 4, 80, 5, 70, 7, 75, 2,  5, 6, 46, 0, 49, 
    0, 95, 5, 95, 7, 27, 8, 91, 3, 27, 4, 72, 1, 14, 6, 92, 2,  5, 
    0, 20, 7, 29, 5, 59, 1, 82, 2, 15, 3, 36, 8, 37, 6, 56, 4, 40
  };
  const int q6139[] = {
    9, 9, // Number of jobs and machines
    2, 45, 8,  1, 5, 75, 1, 81, 3,  5, 7,  6, 4, 99, 6, 58, 0, 97, 
    1, 76, 2, 61, 4, 77, 5,  7, 0, 28, 8, 25, 7, 90, 6, 58, 3, 71, 
    6, 39, 5, 67, 3, 11, 1,  9, 2, 57, 0, 43, 4, 43, 7, 29, 8, 39, 
    5, 14, 0, 64, 6, 13, 4, 23, 8, 93, 2, 69, 7, 71, 3, 50, 1, 65, 
    7, 96, 5, 49, 1, 94, 2, 96, 0, 49, 4, 53, 6, 91, 8, 43, 3, 51, 
    6, 38, 5, 92, 1,  5, 7, 46, 0, 86, 2, 68, 8, 79, 3, 60, 4, 74, 
    2, 35, 0, 81, 8, 34, 7, 95, 6, 62, 5, 89, 1, 83, 4, 26, 3,  3, 
    0, 89, 6,  2, 3, 73, 7, 96, 5, 74, 2, 26, 1, 27, 8, 32, 4, 21, 
    3, 61, 0, 89, 5,  7, 7, 98, 6, 39, 2, 68, 8, 73, 1, 85, 4, 96
  };
  const int q6140[] = {
    9, 9, // Number of jobs and machines
    7, 45, 4, 85, 6, 40, 1, 54, 5,  7, 8, 46, 3, 93, 0, 84, 2, 79, 
    0, 40, 1, 81, 4, 78, 8, 42, 5, 88, 2, 35, 3, 60, 6, 21, 7, 91, 
    1, 41, 8, 30, 7, 93, 6, 98, 3, 21, 4, 64, 5,  9, 0, 89, 2, 71, 
    3,  5, 2, 19, 0, 79, 1, 85, 8, 29, 6, 85, 5, 30, 4, 34, 7, 57, 
    2, 42, 7, 84, 4, 67, 6, 90, 1, 30, 3, 67, 8, 36, 0, 93, 5, 59, 
    2, 48, 1, 63, 6, 94, 3, 24, 8, 89, 4, 83, 7, 50, 0, 99, 5, 91, 
    2, 39, 5, 32, 1, 10, 3, 31, 6, 13, 0, 11, 7,  6, 4, 18, 8, 30, 
    7, 24, 6, 27, 2, 78, 0, 59, 5, 24, 4, 32, 3, 54, 1, 72, 8, 70, 
    3, 11, 5,  6, 7, 75, 2, 32, 8, 89, 6, 55, 1, 95, 0, 15, 4, 92
  };
  const int q6141[] = {
    9, 9, // Number of jobs and machines
    0,  2, 6, 10, 5, 83, 1, 68, 3, 58, 4, 17, 2, 79, 8, 32, 7, 40, 
    2,  8, 0, 62, 7, 95, 8, 10, 3, 68, 5, 51, 1, 95, 6, 49, 4, 63, 
    5, 49, 4, 92, 7, 77, 1, 85, 2, 62, 3, 65, 0, 65, 8, 93, 6, 37, 
    1, 22, 5, 92, 4, 63, 2, 33, 3, 21, 7, 73, 8, 82, 6, 46, 0, 80, 
    7, 52, 1, 60, 6, 73, 5, 86, 2, 91, 0, 37, 8,  3, 4, 90, 3, 83, 
    7,  9, 6, 99, 0, 12, 1, 25, 2, 49, 4, 42, 8, 37, 3, 21, 5, 43, 
    6, 92, 5, 11, 0, 47, 1, 85, 4,  7, 2, 99, 7, 55, 8, 26, 3,  2, 
    0, 68, 5, 57, 6, 22, 2, 38, 1, 38, 7, 42, 8, 70, 4, 61, 3, 51, 
    3, 30, 0, 49, 8, 22, 6, 94, 2, 13, 5, 81, 1, 71, 4, 71, 7, 50
  };
  const int q6142[] = {
    9, 9, // Number of jobs and machines
    2, 87, 7, 34, 8,  6, 3, 51, 0, 30, 6, 51, 5, 32, 4, 98, 1, 95, 
    3, 32, 4, 87, 5, 36, 1, 60, 8, 48, 7, 70, 2, 41, 6, 84, 0, 69, 
    0,  6, 1, 26, 7, 26, 8, 70, 6, 64, 5, 27, 2, 37, 4, 85, 3, 49, 
    8, 38, 2, 21, 4, 94, 5, 95, 0, 55, 1, 75, 6, 15, 7, 69, 3, 12, 
    8, 34, 3, 54, 7,  3, 6, 66, 1, 50, 5, 52, 2, 78, 0,  3, 4, 98, 
    7, 10, 1, 85, 6, 14, 8, 10, 5, 46, 3, 13, 4,  5, 0, 39, 2, 74, 
    1, 70, 6, 15, 8, 30, 5,  3, 2, 34, 3, 11, 4, 90, 0, 90, 7, 13, 
    7,  5, 8, 62, 6, 54, 0, 93, 2, 28, 3, 34, 5, 86, 4, 88, 1, 77, 
    7, 71, 5, 64, 0, 75, 8, 51, 3, 28, 4, 27, 6, 66, 2, 50, 1, 48
  };
  const int q6143[] = {
    9, 9, // Number of jobs and machines
    3, 71, 6, 21, 8, 21, 2, 27, 4, 90, 0, 60, 1, 76, 5, 42, 7, 32, 
    6, 30, 4, 19, 1,  4, 7, 80, 5, 76, 0, 46, 8, 13, 3, 45, 2, 49, 
    1,  3, 8, 45, 6, 56, 2, 93, 7,  5, 0, 20, 4, 50, 5, 44, 3, 58, 
    5, 38, 6, 53, 2, 96, 7, 65, 1, 97, 4, 22, 3, 37, 8, 17, 0, 36, 
    2, 53, 4, 86, 0, 33, 5, 44, 6, 18, 1, 62, 8,  6, 3, 59, 7, 52, 
    3, 59, 0, 10, 5, 40, 1, 46, 2, 79, 4, 62, 8, 35, 6, 41, 7, 95, 
    2, 43, 3, 45, 0,  3, 4, 61, 6, 69, 5, 68, 1,  5, 8,  3, 7, 73, 
    3, 95, 8, 80, 2, 67, 1, 71, 0, 12, 5, 38, 4, 60, 7, 79, 6, 43, 
    4, 87, 8, 50, 1, 97, 6,  8, 2, 26, 7, 71, 3, 63, 5, 38, 0, 89
  };
  const int q6144[] = {
    9, 9, // Number of jobs and machines
    7, 95, 1,  4, 6, 27, 5,  8, 2, 59, 8, 90, 4, 13, 0, 93, 3, 86, 
    6, 84, 5, 81, 2, 28, 8,  3, 1, 11, 7, 61, 3, 39, 4, 70, 0, 82, 
    3, 79, 2, 10, 4, 51, 7, 56, 8, 18, 1, 68, 5, 44, 6, 29, 0, 31, 
    7, 14, 2, 17, 5, 69, 6, 64, 0, 17, 1, 82, 4, 43, 8, 43, 3, 29, 
    0, 95, 7, 18, 8,  6, 2, 48, 3, 62, 5, 65, 1, 81, 4, 26, 6, 66, 
    8, 52, 0, 32, 5,  1, 7, 57, 4, 77, 2, 86, 1, 85, 3, 85, 6,  7, 
    6, 29, 2, 12, 4, 53, 5, 11, 0, 63, 7,  7, 8, 34, 1, 39, 3, 26, 
    3, 65, 6, 32, 4, 81, 2, 94, 0, 56, 7, 48, 1, 12, 8, 60, 5, 28, 
    8, 30, 5,  3, 7, 52, 3, 76, 1, 98, 6, 84, 0, 80, 2, 37, 4, 93
  };
  const int q6145[] = {
    9, 9, // Number of jobs and machines
    7, 77, 1, 51, 5, 36, 3, 49, 2, 79, 4,  4, 8, 92, 0, 59, 6,  4, 
    3,  2, 7, 29, 2, 23, 8, 74, 4, 39, 0, 70, 1, 61, 5,  7, 6, 37, 
    2, 70, 1, 99, 0, 66, 4, 14, 5,  5, 3, 50, 6, 72, 8, 70, 7, 68, 
    6, 24, 2, 10, 8, 86, 0, 74, 1, 29, 5, 87, 7, 26, 3, 46, 4, 45, 
    6, 39, 4, 64, 2, 43, 8, 96, 5, 30, 3, 61, 7, 60, 0, 47, 1, 30, 
    4, 94, 3, 47, 6, 74, 1, 18, 7, 69, 0, 59, 8, 10, 2, 77, 5, 17, 
    7, 47, 8,  1, 6, 16, 4, 11, 3, 13, 2, 44, 5, 44, 1, 31, 0, 40, 
    6,  3, 2, 82, 4, 14, 7, 11, 0, 20, 8, 86, 1, 20, 5, 96, 3,  7, 
    3, 28, 4, 45, 1, 29, 8,  2, 5,  6, 6,  8, 7, 62, 2, 92, 0, 70
  };
  const int q6146[] = {
    9, 9, // Number of jobs and machines
    2, 87, 0, 97, 6, 87, 7, 83, 3, 28, 5,  6, 8, 65, 4, 51, 1, 14, 
    2, 46, 5, 87, 7, 51, 0, 45, 3, 23, 6, 65, 1, 10, 4, 72, 8, 93, 
    4, 72, 3, 92, 7, 52, 8, 96, 1,  7, 0, 86, 6, 63, 2, 87, 5, 52, 
    2,  6, 7, 61, 3,  5, 5, 58, 8, 24, 6, 63, 1, 75, 0, 72, 4, 12, 
    3, 24, 0, 22, 5, 22, 6, 46, 8, 42, 2, 60, 7, 77, 4, 33, 1, 62, 
    4, 95, 1, 68, 3, 36, 2, 63, 6, 33, 8, 12, 7, 16, 0, 10, 5, 90, 
    1, 30, 4,  1, 3, 60, 6, 47, 8, 69, 7,  5, 2, 77, 0,  9, 5, 79, 
    0, 27, 1, 36, 7, 21, 8, 44, 5,  2, 4, 22, 3, 66, 2, 76, 6, 45, 
    2,  3, 4, 50, 8, 45, 7, 64, 5, 87, 1, 19, 0, 48, 3,  7, 6, 16
  };
  const int q6147[] = {
    9, 9, // Number of jobs and machines
    8, 96, 6,  8, 7, 39, 1, 69, 4, 16, 2,  9, 3, 11, 5, 90, 0, 34, 
    0, 97, 7,  8, 3, 38, 8,  7, 1, 94, 5, 22, 6, 42, 2, 25, 4, 20, 
    0, 91, 2, 42, 4, 84, 8, 25, 1, 91, 5, 41, 6, 85, 3, 94, 7, 14, 
    4, 77, 2, 16, 3, 20, 5, 74, 1, 59, 6, 79, 7, 89, 0, 97, 8, 66, 
    7, 60, 4,  1, 2, 78, 1, 69, 6, 34, 3, 84, 0, 93, 5, 69, 8, 75, 
    5, 26, 2, 71, 4, 45, 6, 74, 8, 28, 3, 42, 1, 79, 0, 58, 7, 55, 
    8, 94, 1, 82, 7, 76, 0, 30, 5, 90, 4, 46, 3, 96, 6, 14, 2, 70, 
    0, 49, 1, 75, 5, 18, 4, 29, 8, 53, 2, 78, 3, 16, 6, 28, 7, 77, 
    8, 47, 5,  7, 2, 93, 4, 56, 1,  8, 7, 15, 6, 97, 0, 61, 3, 77
  };
  const int q6148[] = {
    9, 9, // Number of jobs and machines
    6, 60, 4, 81, 0, 34, 7,  2, 1, 30, 8, 72, 5, 88, 2, 29, 3, 96, 
    1, 65, 5, 52, 0, 41, 7,  9, 2, 99, 6, 27, 3, 99, 4, 94, 8, 64, 
    1, 40, 4, 41, 7, 29, 0, 91, 3, 65, 5, 60, 8, 88, 2, 61, 6, 22, 
    8, 43, 0, 57, 6, 31, 3, 79, 2, 13, 4, 62, 7, 47, 5, 38, 1, 71, 
    1, 36, 8, 51, 7,  2, 4, 96, 3, 96, 2, 88, 0, 87, 5, 50, 6, 30, 
    1, 82, 3, 34, 7, 68, 4, 46, 8,  7, 2, 82, 5, 46, 6,  7, 0, 18, 
    6, 85, 1, 83, 4, 14, 3, 66, 7, 61, 5, 42, 2, 51, 0, 62, 8, 26, 
    1, 32, 3, 38, 8, 69, 5, 53, 7, 50, 4, 22, 2, 27, 6, 33, 0, 66, 
    1, 54, 2, 37, 5, 65, 0, 98, 4, 42, 7, 35, 3, 45, 8, 76, 6, 35
  };
  const int q6149[] = {
    9, 9, // Number of jobs and machines
    0, 32, 2, 40, 7, 50, 3, 38, 1, 46, 4, 46, 8, 84, 6, 99, 5, 39, 
    0, 88, 3, 85, 4, 83, 7, 19, 5, 32, 2, 83, 8, 88, 6, 56, 1, 66, 
    0, 80, 5, 97, 2,  2, 1, 46, 3, 96, 7,  9, 8, 71, 6, 69, 4, 22, 
    7, 48, 3, 39, 2, 69, 4, 98, 0,  3, 8, 38, 5, 40, 6, 27, 1, 41, 
    1, 64, 5, 76, 7, 33, 2,  2, 8, 63, 3, 57, 0, 26, 4, 27, 6, 44, 
    5, 57, 7, 35, 4, 97, 1, 66, 6, 91, 2, 50, 3, 34, 8, 30, 0, 97, 
    6, 74, 2, 86, 4, 33, 8, 43, 0, 29, 3, 67, 7, 63, 5, 54, 1, 45, 
    6, 91, 7, 45, 4, 85, 8, 50, 2, 66, 1, 43, 0, 29, 3,  5, 5, 11, 
    2, 45, 3, 53, 4, 81, 6, 15, 8, 83, 0, 53, 7, 87, 5, 75, 1, 91
  };
  const int q6150[] = {
    9, 9, // Number of jobs and machines
    6, 58, 1, 60, 4,  4, 2, 93, 0, 18, 3, 50, 5, 28, 7, 59, 8, 74, 
    5, 56, 7, 47, 0, 76, 4, 11, 2, 41, 8, 16, 3, 44, 1, 83, 6, 21, 
    1, 14, 7, 92, 0, 67, 4, 92, 2, 64, 6, 24, 8, 60, 3, 47, 5, 50, 
    4,  4, 2, 40, 1, 79, 0,  8, 6, 43, 5, 52, 3, 49, 7, 57, 8, 93, 
    1, 24, 4, 40, 6, 26, 7, 81, 3, 24, 0, 84, 2, 49, 5,  2, 8, 91, 
    2, 53, 4, 88, 3, 44, 6, 10, 8, 35, 1, 90, 5, 20, 7, 54, 0, 10, 
    1, 92, 0, 44, 5, 27, 6, 24, 3, 10, 7, 46, 2, 12, 8, 91, 4, 53, 
    1, 19, 5,  7, 6,  7, 2, 56, 8, 94, 3, 29, 0, 21, 4, 39, 7, 36, 
    7, 92, 6, 73, 3, 13, 5, 77, 4, 46, 1, 19, 2, 93, 8, 25, 0, 24
  };
  const int q6151[] = {
    9, 9, // Number of jobs and machines
    5, 66, 2, 20, 7,  2, 0, 27, 8, 31, 6, 97, 1, 28, 4, 63, 3, 21, 
    3, 94, 5, 98, 4, 85, 0, 73, 2, 40, 1, 21, 8, 20, 6, 38, 7, 20, 
    2, 75, 1, 10, 5, 93, 4, 13, 8, 65, 6, 86, 0, 27, 3, 97, 7,  2, 
    6, 56, 4, 70, 1,  3, 3, 29, 0, 59, 7, 99, 5, 71, 8, 60, 2, 25, 
    1, 73, 5, 37, 6, 35, 7, 99, 4, 52, 2, 34, 0, 41, 8, 65, 3,  4, 
    7, 24, 2, 91, 4, 94, 0, 69, 6, 96, 5, 67, 3, 47, 1, 31, 8, 48, 
    0, 81, 2, 24, 3, 73, 6, 33, 1, 47, 5, 13, 7, 52, 4, 80, 8, 66, 
    5, 95, 4, 53, 6, 31, 1, 34, 3, 72, 8,  7, 0, 40, 2, 22, 7, 53, 
    7, 19, 8, 53, 2, 10, 5, 53, 0, 59, 1, 63, 4, 76, 6,  3, 3, 87
  };
  const int q6152[] = {
    9, 9, // Number of jobs and machines
    3, 17, 8, 19, 7, 31, 4, 78, 0, 15, 5, 76, 6, 18, 2, 40, 1, 90, 
    5, 64, 1, 10, 8, 90, 3, 45, 0, 52, 2, 22, 4, 10, 6,  1, 7, 67, 
    2,  3, 3, 95, 4, 93, 5, 70, 6, 19, 8, 14, 7, 83, 0,  9, 1, 10, 
    0, 83, 4, 87, 2,  3, 1, 93, 5, 96, 3, 15, 8, 89, 6, 43, 7, 73, 
    1, 62, 6, 55, 3, 32, 4, 66, 2, 22, 5, 93, 7, 91, 0, 23, 8, 57, 
    3, 18, 0, 91, 1, 94, 7, 95, 5, 55, 4, 44, 8, 16, 2, 84, 6, 29, 
    7, 13, 8, 80, 6, 39, 2, 81, 5, 69, 3, 57, 0, 85, 4, 95, 1,  9, 
    2, 99, 7, 89, 0, 92, 8, 74, 5,  4, 3, 10, 4, 79, 6, 19, 1, 67, 
    0, 23, 7, 32, 8, 84, 6, 96, 5, 86, 2, 82, 4, 30, 1, 14, 3, 47
  };
  const int q6153[] = {
    9, 9, // Number of jobs and machines
    1, 99, 8, 31, 0, 56, 2, 13, 3, 94, 6, 93, 7, 90, 5, 38, 4, 18, 
    0, 10, 4, 59, 2, 64, 1, 68, 8, 92, 5, 34, 6, 45, 7, 75, 3, 99, 
    7,  6, 4, 33, 3, 24, 1, 23, 6, 51, 5, 35, 2, 63, 0, 42, 8, 53, 
    0,  4, 3, 19, 1, 18, 4, 38, 2, 88, 8, 59, 6, 63, 7, 11, 5, 71, 
    7, 20, 2, 90, 0, 83, 4, 13, 5, 55, 6, 16, 1, 43, 3, 60, 8, 47, 
    8, 76, 6, 32, 5, 85, 1, 41, 2, 65, 0, 52, 7, 19, 3, 62, 4, 45, 
    8, 43, 0,  4, 2, 35, 5, 76, 6, 74, 1, 72, 3, 48, 4, 77, 7, 21, 
    5, 36, 4, 30, 7,  5, 2, 87, 8, 12, 0, 17, 6,  3, 1, 98, 3, 96, 
    1, 21, 4, 63, 6,  1, 3, 19, 2, 77, 8,  6, 7,  3, 0, 76, 5, 60
  };
  const int q6154[] = {
    9, 9, // Number of jobs and machines
    3, 57, 7,  2, 2, 57, 4, 91, 5, 32, 1, 15, 6, 59, 8, 41, 0, 12, 
    6, 95, 3, 65, 7, 82, 2, 88, 4, 43, 1, 87, 0, 59, 8, 91, 5, 87, 
    8, 21, 1, 18, 3, 84, 0, 62, 7, 25, 2, 73, 6, 29, 4, 80, 5, 84, 
    4, 50, 7, 99, 8, 16, 5, 61, 1, 89, 6, 68, 3, 85, 0, 81, 2, 48, 
    0, 57, 5, 31, 4, 48, 3, 36, 1, 33, 8, 38, 2, 57, 7, 88, 6, 80, 
    5, 94, 8, 35, 3, 16, 2, 31, 4,  4, 7, 86, 1, 49, 6, 56, 0, 61, 
    7, 79, 1, 62, 6, 85, 8, 19, 5, 15, 4, 98, 2, 51, 3, 61, 0, 23, 
    0, 50, 7, 44, 3, 71, 1, 82, 5,  5, 6, 44, 2, 68, 4, 94, 8, 64, 
    0, 51, 1, 36, 2, 76, 3, 63, 6, 35, 4, 62, 7, 71, 8, 63, 5, 75
  };
  const int q6155[] = {
    9, 9, // Number of jobs and machines
    3, 34, 6, 44, 1, 93, 7, 41, 4, 88, 2, 29, 5, 96, 0, 29, 8, 14, 
    3, 78, 7,  7, 6, 78, 1, 25, 5, 53, 4, 89, 8,  9, 0,  9, 2, 25, 
    4, 39, 7, 59, 1, 56, 0, 15, 2, 12, 6, 28, 5, 54, 8, 28, 3, 11, 
    6, 12, 5,  1, 8, 77, 4, 70, 7, 57, 0, 24, 1, 77, 2,  3, 3, 95, 
    0, 19, 5, 32, 7, 69, 6, 82, 3, 14, 8, 45, 1, 13, 2, 90, 4, 69, 
    2, 87, 1, 46, 7, 95, 3, 81, 5, 16, 6, 78, 0, 95, 8, 59, 4, 71, 
    4, 47, 8, 22, 0, 91, 2, 38, 7, 51, 6, 47, 3, 15, 5,  8, 1,  8, 
    0, 45, 6, 35, 7, 55, 8, 63, 1, 41, 4, 35, 3,  4, 5, 64, 2, 38, 
    7, 67, 5, 44, 3, 66, 1, 13, 2, 33, 4, 17, 0, 58, 8, 64, 6, 68
  };
  const int q6156[] = {
    9, 9, // Number of jobs and machines
    3, 74, 5, 29, 1, 54, 4, 66, 0, 52, 7, 25, 8, 91, 2,  6, 6, 27, 
    2, 91, 0,  5, 3, 40, 1, 42, 8, 46, 5, 44, 4, 50, 7, 85, 6, 17, 
    7, 24, 3, 51, 6, 33, 4, 40, 1, 20, 8, 94, 0, 52, 2, 67, 5, 41, 
    4, 58, 3, 74, 7, 45, 1, 71, 0, 22, 8, 56, 6, 17, 5, 90, 2, 14, 
    8, 79, 4, 70, 1, 62, 6, 38, 0, 58, 5,  8, 7, 88, 3, 51, 2, 96, 
    1, 78, 3, 35, 5, 66, 4, 68, 6, 21, 0,  6, 2, 84, 8, 73, 7, 52, 
    2, 77, 0, 98, 7, 18, 8, 67, 6, 72, 4, 66, 3, 97, 1, 71, 5, 45, 
    1, 71, 5, 94, 4,  2, 2, 61, 3, 45, 0,  7, 6, 63, 8, 75, 7, 30, 
    0, 10, 5, 51, 1, 31, 7, 65, 4, 47, 2, 47, 8, 63, 3, 38, 6, 20
  };
  const int q6157[] = {
    9, 9, // Number of jobs and machines
    4, 34, 3, 37, 8, 19, 7, 11, 1, 81, 2, 54, 5, 53, 6, 99, 0, 78, 
    1, 11, 8, 93, 3, 97, 4, 78, 2,  6, 6, 48, 5, 59, 0, 51, 7, 44, 
    4, 30, 5, 22, 1, 98, 0, 74, 6, 13, 3, 53, 8, 55, 7, 71, 2, 67, 
    7, 92, 8, 99, 4, 98, 0, 56, 5, 65, 2, 53, 3, 37, 6, 86, 1, 25, 
    8, 26, 7, 50, 4, 56, 2, 75, 0,  9, 5, 59, 1, 39, 6, 56, 3, 25, 
    3, 28, 0,  7, 6, 91, 4, 89, 1, 71, 8,  7, 7, 48, 2, 97, 5, 85, 
    2, 80, 7, 39, 6, 51, 5, 15, 3, 43, 4, 79, 1, 80, 0, 65, 8, 93, 
    2, 45, 1, 36, 8, 96, 6, 65, 0, 64, 7, 97, 3, 82, 4,  5, 5, 99, 
    5, 65, 0, 78, 3, 86, 2, 24, 8, 81, 6, 37, 7, 50, 4, 86, 1,  3
  };
  const int q6158[] = {
    9, 9, // Number of jobs and machines
    2, 15, 6, 15, 3, 56, 5, 24, 1, 98, 8, 60, 4, 70, 7, 32, 0,  9, 
    6, 39, 7, 15, 2, 14, 8, 16, 1, 43, 3, 32, 5, 50, 4, 20, 0, 79, 
    2, 67, 7, 69, 1, 12, 6, 96, 5, 53, 8, 78, 0, 28, 4, 14, 3, 14, 
    5, 58, 2, 83, 6, 64, 1, 24, 0,  2, 7, 50, 4, 35, 3, 54, 8, 61, 
    3, 70, 7, 95, 5, 30, 4, 47, 1, 15, 6, 86, 2,  9, 0, 32, 8, 39, 
    5, 27, 8, 89, 4, 57, 6, 90, 7, 39, 3, 36, 2, 25, 0, 24, 1, 16, 
    8, 18, 7, 54, 0,  8, 5, 45, 2, 33, 6, 27, 1, 61, 3, 10, 4, 27, 
    0,  3, 8, 99, 1, 47, 4, 72, 2, 86, 3, 81, 5, 88, 7, 77, 6, 32, 
    5, 91, 8, 51, 2, 29, 1, 20, 6, 23, 0, 56, 3, 58, 4, 57, 7, 21
  };
  const int q6159[] = {
    9, 9, // Number of jobs and machines
    4, 87, 5, 94, 0, 56, 8, 69, 2, 15, 1, 77, 7, 78, 6, 81, 3, 97, 
    5, 14, 1, 97, 3, 54, 8, 48, 4, 97, 7, 55, 6, 63, 2, 93, 0, 85, 
    4, 47, 2, 93, 5, 48, 6, 73, 3, 74, 0, 60, 1, 38, 8, 63, 7, 98, 
    7, 18, 5, 17, 1, 21, 8,  5, 0, 47, 2, 15, 3,  9, 6, 19, 4, 85, 
    1, 91, 6, 48, 5, 61, 2, 64, 3, 51, 7,  9, 0, 64, 4, 62, 8, 58, 
    4, 83, 2, 12, 0, 48, 1, 73, 5, 83, 3, 65, 8, 69, 7, 13, 6, 83, 
    8,  1, 6,  7, 2, 91, 0, 49, 5, 18, 1, 13, 3, 14, 4,  3, 7, 65, 
    4, 10, 0, 66, 3, 31, 2, 38, 5, 22, 8, 91, 6, 39, 7, 33, 1, 14, 
    1, 16, 8, 36, 6, 20, 5,  8, 2, 17, 3, 87, 7, 36, 0, 68, 4, 47
  };
  const int q6160[] = {
    9, 9, // Number of jobs and machines
    4, 12, 5, 38, 7, 79, 2, 71, 8, 17, 3, 18, 6, 39, 1, 24, 0, 92, 
    7, 42, 8, 24, 3, 94, 0, 50, 4, 35, 1,  4, 6, 10, 2, 58, 5, 17, 
    5, 64, 6, 93, 0, 84, 2, 54, 4, 20, 3, 28, 7, 34, 1, 81, 8, 73, 
    0, 21, 1, 14, 3, 10, 7, 78, 5, 42, 8, 70, 6, 10, 4, 98, 2, 68, 
    2, 51, 5, 70, 6,  4, 1, 62, 7, 53, 3, 66, 4, 67, 0, 72, 8, 58, 
    7, 88, 2, 83, 6, 59, 3, 74, 5, 22, 1, 76, 8, 89, 0, 92, 4, 58, 
    0, 35, 5,  8, 3, 55, 1, 13, 8, 80, 2, 19, 6, 14, 4, 17, 7, 52, 
    0,  2, 8, 38, 1, 73, 4,  6, 3, 96, 5, 58, 7, 62, 2, 15, 6, 37, 
    5, 12, 7, 23, 4, 75, 3, 44, 0, 92, 1, 40, 8, 97, 6, 18, 2, 54
  };
  const int q6161[] = {
    9, 9, // Number of jobs and machines
    0, 47, 4, 83, 6, 59, 7, 45, 5, 96, 3, 36, 2, 75, 1, 38, 8, 53, 
    3, 82, 2,  9, 5, 36, 4, 72, 6, 32, 7, 49, 0, 61, 8, 66, 1, 74, 
    5, 51, 6,  8, 4, 80, 1, 28, 2, 92, 7, 39, 8, 94, 3, 37, 0, 19, 
    0, 98, 7, 15, 8, 80, 6, 80, 1, 91, 2, 98, 3, 59, 5, 11, 4, 81, 
    7, 52, 6, 92, 4, 22, 3, 91, 0, 12, 2, 70, 8, 50, 5, 18, 1, 20, 
    2, 34, 0, 14, 5, 86, 4, 32, 8,  5, 6, 85, 3, 79, 1, 88, 7, 53, 
    7, 61, 1, 15, 5, 80, 3, 56, 4, 60, 8, 86, 0, 20, 6, 12, 2, 30, 
    0, 31, 8, 45, 6, 94, 3, 20, 1, 42, 5, 71, 2, 74, 7, 91, 4, 36, 
    6, 61, 8, 12, 0, 57, 1, 76, 4, 26, 3, 47, 5, 91, 7, 72, 2, 92
  };
  const int q6162[] = {
    9, 9, // Number of jobs and machines
    1, 52, 6, 62, 3,  1, 7,  2, 8, 14, 0,  8, 5, 38, 2, 56, 4, 29, 
    6, 72, 7, 86, 0, 41, 1, 61, 3, 43, 2, 76, 8, 88, 5, 21, 4, 75, 
    4, 19, 1, 28, 8, 13, 7, 98, 0, 13, 6,  9, 5, 90, 2,  4, 3, 88, 
    5, 47, 3, 15, 8, 30, 2, 16, 7, 46, 0, 60, 4, 23, 1, 76, 6, 99, 
    8, 64, 1, 14, 7, 47, 0, 70, 6, 61, 3, 27, 5, 55, 4, 53, 2, 18, 
    2, 43, 8, 44, 4, 41, 5, 98, 0, 87, 7, 40, 3, 75, 1, 49, 6, 55, 
    6, 41, 8, 30, 7, 81, 4, 92, 1, 62, 5, 52, 0, 23, 2, 97, 3,  6, 
    5, 28, 3,  6, 7, 21, 1, 30, 8, 96, 6, 92, 0, 42, 2, 82, 4, 12, 
    8, 75, 7, 68, 6, 68, 5, 60, 3,  8, 2, 72, 1, 83, 0, 58, 4, 77
  };
  const int q6163[] = {
    9, 9, // Number of jobs and machines
    0, 75, 7, 81, 1, 32, 6, 46, 3, 44, 5, 94, 2, 53, 4, 79, 8, 40, 
    2, 81, 6, 60, 0, 34, 7, 66, 4, 31, 3, 61, 8, 12, 5, 32, 1, 44, 
    2, 40, 1, 56, 5, 56, 7, 91, 0, 44, 4, 87, 6, 26, 3,  7, 8, 73, 
    6,  6, 7, 27, 8, 57, 3, 15, 0, 79, 1, 20, 5, 78, 4, 84, 2, 87, 
    1, 28, 2, 78, 4, 18, 0, 76, 3, 98, 5, 71, 6, 65, 7, 92, 8, 42, 
    1, 49, 0, 85, 8, 58, 3, 15, 5, 40, 7, 63, 6, 80, 2, 48, 4, 95, 
    5, 77, 2, 97, 7, 52, 3, 65, 4, 88, 0, 71, 1, 48, 6,  9, 8, 29, 
    0, 56, 3, 29, 2, 24, 1, 41, 4, 23, 7, 16, 5, 50, 6, 44, 8, 94, 
    2, 86, 4, 76, 0,  9, 1, 85, 6, 48, 7, 36, 8, 56, 5, 11, 3, 31
  };
  const int q6164[] = {
    9, 9, // Number of jobs and machines
    6, 71, 2, 65, 1, 68, 7, 48, 5, 20, 0, 15, 4, 13, 3, 46, 8, 27, 
    2, 89, 5, 57, 4, 28, 0, 38, 7, 61, 3, 94, 1,  5, 6, 94, 8, 33, 
    0, 78, 1, 91, 2, 76, 6, 25, 3, 89, 5, 44, 4, 95, 8, 69, 7, 68, 
    7, 53, 3, 70, 8, 14, 0, 22, 6, 21, 2, 73, 1, 16, 5, 58, 4, 40, 
    7, 76, 0, 35, 8, 42, 5, 52, 3, 85, 6, 47, 4, 57, 2,  1, 1, 60, 
    0, 68, 7, 99, 2, 90, 1, 83, 8, 14, 5, 98, 6, 70, 4, 84, 3, 90, 
    2, 72, 7, 26, 8, 57, 5, 97, 1, 23, 6, 28, 0, 21, 4, 66, 3, 41, 
    7, 46, 3, 78, 8, 14, 6,  4, 2, 18, 4,  2, 5, 77, 0, 58, 1, 32, 
    2, 35, 0, 94, 5, 20, 4, 92, 6, 54, 8, 63, 7, 36, 1, 74, 3, 29
  };
  const int q6165[] = {
    9, 9, // Number of jobs and machines
    4,  9, 2, 29, 1, 83, 5, 93, 3, 66, 8, 63, 6, 47, 7, 88, 0, 40, 
    2, 82, 8, 17, 4, 97, 3, 24, 7, 96, 1, 39, 5,  4, 0,  4, 6, 46, 
    0, 52, 4, 11, 3, 44, 7, 19, 6, 51, 1, 16, 5, 98, 8, 89, 2, 54, 
    3,  1, 0, 99, 5, 92, 6, 39, 8, 55, 2, 26, 7, 69, 1, 68, 4, 52, 
    1, 92, 8, 41, 5, 68, 3, 45, 0, 45, 7, 27, 4, 74, 6, 70, 2, 36, 
    6, 74, 1, 75, 7, 95, 3, 48, 0, 10, 5, 71, 8, 93, 2, 54, 4, 73, 
    5, 40, 7, 90, 3, 59, 2, 74, 6, 63, 8, 83, 4, 23, 1, 90, 0, 47, 
    7, 18, 5, 58, 4, 97, 1, 23, 6, 68, 2, 31, 0, 55, 8, 16, 3,  1, 
    7, 63, 1, 36, 8, 39, 5, 53, 4, 35, 2, 53, 3, 73, 6, 53, 0, 72
  };
  const int q6166[] = {
    9, 9, // Number of jobs and machines
    0, 93, 4, 20, 1, 63, 7, 29, 6, 77, 3, 65, 2, 25, 8, 94, 5, 77, 
    2, 90, 4, 95, 0, 51, 1, 91, 5, 79, 7, 71, 3, 16, 8, 73, 6, 89, 
    6, 57, 2, 27, 8, 85, 3, 42, 1, 28, 7, 25, 4, 24, 5, 28, 0, 32, 
    1, 32, 0,  4, 7, 80, 4, 39, 5, 48, 2, 92, 8, 95, 6, 34, 3, 46, 
    2, 44, 0, 20, 1, 17, 5, 59, 8, 54, 4, 32, 7, 44, 3, 44, 6, 51, 
    0, 52, 2, 23, 7, 19, 1, 42, 6, 89, 5,  7, 4, 53, 8, 87, 3, 72, 
    4, 29, 2, 92, 1, 30, 8,  6, 0,  1, 5, 61, 6, 99, 3, 34, 7, 88, 
    0, 61, 2, 63, 3, 97, 4,  7, 7, 73, 6, 84, 1, 71, 8, 22, 5, 37, 
    6, 91, 3, 59, 1, 38, 8, 50, 2, 35, 4, 85, 5, 89, 0, 30, 7, 39
  };
  const int q6167[] = {
    9, 9, // Number of jobs and machines
    7, 59, 5, 49, 1, 58, 4, 56, 2, 13, 8,  9, 0, 23, 3, 28, 6, 35, 
    7,  1, 8, 60, 1, 46, 4, 41, 2, 22, 0, 80, 3,  3, 6,  3, 5, 87, 
    2, 45, 8,  6, 4, 57, 5, 64, 3, 56, 7, 72, 6,  6, 0, 27, 1, 26, 
    1, 46, 6, 39, 0, 55, 2, 84, 7, 18, 5,  8, 8,  1, 4,  6, 3, 60, 
    7,  5, 2, 94, 5, 87, 3, 23, 1, 71, 8, 81, 6, 76, 4, 75, 0,  9, 
    1, 65, 8, 45, 4,  8, 6, 78, 2, 84, 0,  9, 5, 27, 3, 46, 7, 14, 
    0, 78, 8, 17, 2,  5, 3, 99, 5, 64, 6, 42, 7,  7, 1, 68, 4, 25, 
    7, 78, 5, 48, 8, 87, 6, 19, 1, 21, 3, 15, 4, 44, 0, 56, 2, 65, 
    7, 40, 1, 24, 0, 15, 3, 34, 2, 70, 8,  1, 5, 62, 4, 52, 6, 43
  };
  const int q6168[] = {
    9, 9, // Number of jobs and machines
    4, 20, 2, 74, 6, 60, 1, 56, 0, 14, 8, 94, 7,  4, 5, 73, 3,  2, 
    8, 40, 2, 91, 1, 17, 4, 69, 0, 35, 5, 60, 3, 74, 6, 48, 7, 24, 
    6, 50, 4, 43, 7, 11, 8, 32, 3, 27, 0, 29, 2, 42, 5, 23, 1, 66, 
    1, 88, 8, 88, 2, 12, 6, 54, 5, 28, 4, 40, 0, 91, 7, 77, 3, 58, 
    2, 36, 0, 16, 8, 91, 7, 84, 1, 23, 6, 74, 5, 78, 3, 50, 4, 30, 
    3, 62, 4, 50, 8,  5, 5, 15, 2, 15, 1, 88, 6, 95, 0, 46, 7, 70, 
    3, 46, 4, 76, 8, 57, 7, 63, 0, 39, 1, 62, 2, 31, 6, 54, 5, 88, 
    8, 98, 6, 18, 2,  7, 7, 65, 4, 64, 1, 40, 3, 22, 0, 40, 5,  1, 
    1, 77, 3, 27, 8, 90, 6, 18, 5, 58, 2, 14, 0, 76, 7,  2, 4, 51
  };
  const int q6169[] = {
    9, 9, // Number of jobs and machines
    7,  3, 2, 67, 4, 91, 3, 48, 6, 14, 0, 59, 8, 57, 1, 63, 5, 17, 
    3, 99, 0, 50, 6, 31, 7, 87, 2, 25, 5, 64, 1, 98, 8, 98, 4, 68, 
    4, 50, 6, 29, 8, 78, 3, 17, 2, 75, 1, 78, 7, 18, 5, 83, 0, 44, 
    0, 82, 5, 41, 4, 41, 1, 15, 8, 45, 3, 95, 2, 72, 6, 66, 7, 60, 
    1, 42, 8, 36, 2, 79, 4, 99, 5, 40, 0, 40, 3, 93, 6, 71, 7, 12, 
    5, 34, 1, 50, 2, 76, 8, 85, 0, 68, 3, 51, 7, 36, 6, 14, 4, 11, 
    2, 30, 8, 58, 5, 20, 3, 38, 6, 18, 1, 47, 7, 49, 4, 83, 0, 16, 
    7, 39, 1, 14, 5, 88, 8, 87, 6, 32, 4, 83, 0, 23, 2, 56, 3, 52, 
    3, 64, 6,  2, 0, 54, 1, 47, 4, 56, 7,  4, 8, 60, 5, 88, 2, 30
  };
  const int q6170[] = {
    9, 9, // Number of jobs and machines
    0, 15, 5, 57, 2, 92, 8, 22, 6, 51, 4, 43, 3, 82, 7, 95, 1,  1, 
    6, 56, 1, 51, 3, 11, 5, 66, 7, 27, 4, 63, 0, 78, 2, 74, 8, 71, 
    4, 97, 3, 73, 1, 95, 5, 61, 7, 40, 8, 51, 6, 66, 0, 42, 2, 59, 
    2, 41, 8, 91, 3, 79, 5, 22, 0, 44, 1, 77, 4, 15, 7,  8, 6, 33, 
    1, 80, 7, 56, 6, 58, 0, 59, 5,  8, 8, 91, 3, 78, 2, 44, 4, 24, 
    7, 31, 4, 88, 3,  7, 2, 88, 8, 64, 0, 39, 5, 49, 1, 32, 6, 36, 
    4, 93, 2, 16, 6, 51, 1, 61, 5, 94, 3, 73, 0, 31, 8,  7, 7,  7, 
    4, 83, 8, 78, 2, 86, 1, 28, 6, 32, 0, 85, 5, 88, 3, 37, 7, 91, 
    1, 18, 2, 11, 7, 17, 5,  8, 4, 35, 6, 98, 0, 52, 3, 83, 8, 87
  };
  const int q6171[] = {
    9, 9, // Number of jobs and machines
    3, 46, 8, 16, 2, 73, 7, 51, 6, 47, 5, 47, 1, 70, 4, 32, 0, 69, 
    0,  7, 6, 63, 5, 89, 4, 18, 1, 63, 2, 64, 8, 89, 7, 25, 3, 28, 
    7, 88, 0, 42, 3, 36, 6, 40, 8, 67, 2, 81, 5,  3, 4, 49, 1,  2, 
    6, 49, 4, 32, 5, 69, 3, 31, 0, 81, 8, 16, 2, 78, 1, 27, 7, 25, 
    4, 67, 6, 74, 1, 99, 2, 62, 8, 32, 0, 98, 5, 90, 3, 98, 7, 82, 
    4, 99, 8, 24, 0, 34, 5, 13, 3, 54, 1, 10, 6, 88, 7, 19, 2, 62, 
    1, 10, 3, 13, 8, 44, 4, 27, 2, 75, 6, 99, 5, 49, 7, 30, 0, 37, 
    5, 27, 4,  4, 1,  2, 0, 67, 2, 86, 8, 48, 3, 72, 6, 34, 7, 16, 
    1, 82, 3, 35, 6, 97, 5, 54, 0, 21, 2, 87, 7, 71, 8, 40, 4, 25
  };
  const int q6172[] = {
    9, 9, // Number of jobs and machines
    5, 67, 1, 93, 0, 25, 2,  6, 8, 78, 6, 38, 3,  3, 4, 88, 7,  9, 
    3, 79, 2, 77, 1, 74, 6, 76, 7, 34, 5, 37, 0, 83, 8, 92, 4, 96, 
    3, 59, 7, 72, 6, 96, 5, 96, 8, 17, 0, 96, 1, 13, 2, 76, 4, 59, 
    5, 79, 1, 21, 4, 83, 3, 26, 6, 65, 0, 17, 8, 34, 2,  9, 7, 51, 
    7, 52, 4, 98, 5, 25, 6, 98, 1, 23, 0, 44, 3, 75, 2, 43, 8, 72, 
    3, 15, 0, 32, 2, 67, 4, 37, 8, 49, 5, 41, 1, 53, 6, 70, 7, 35, 
    2, 89, 8, 27, 6, 61, 4, 86, 7, 41, 5, 74, 0, 13, 1,  7, 3, 31, 
    0, 54, 4, 97, 1, 70, 2, 65, 7, 51, 8, 73, 6, 78, 3, 41, 5, 96, 
    2, 33, 7, 26, 6, 75, 8, 49, 0, 53, 4, 58, 5,  4, 1, 86, 3, 47
  };
  const int q6173[] = {
    9, 9, // Number of jobs and machines
    0, 65, 4, 85, 6, 38, 5, 62, 3, 82, 7, 22, 2, 30, 1, 99, 8, 13, 
    3, 32, 7, 20, 0, 45, 8, 76, 5, 83, 2,  7, 6, 50, 4, 74, 1, 13, 
    7,  4, 0, 23, 3, 87, 8,  4, 1, 29, 4, 52, 5, 48, 2, 32, 6,  6, 
    5, 43, 1,  8, 6, 72, 7, 64, 8, 63, 0, 46, 4, 29, 2, 78, 3, 47, 
    2, 27, 5, 67, 0, 41, 3,  6, 1, 91, 8, 70, 4, 98, 7, 47, 6, 51, 
    4, 14, 5, 77, 8, 55, 2, 13, 1, 96, 6, 99, 0, 28, 3, 53, 7, 60, 
    3, 87, 8, 78, 4, 73, 2, 79, 0, 49, 5,  5, 6, 77, 7, 76, 1, 40, 
    3, 78, 7, 31, 1, 26, 0, 66, 6, 20, 4,  6, 2, 75, 5, 54, 8, 59, 
    6, 68, 8, 39, 4, 16, 7, 74, 2, 20, 3, 59, 0,  8, 1, 62, 5, 25
  };
  const int q6174[] = {
    9, 9, // Number of jobs and machines
    8, 46, 5, 20, 0, 51, 1,  1, 4, 67, 3, 65, 2, 87, 6, 17, 7, 15, 
    7, 94, 0, 36, 8, 98, 2, 10, 5,  8, 3, 14, 4,  1, 6, 38, 1,  1, 
    4, 56, 2, 36, 0, 79, 8, 66, 6, 72, 1, 74, 5, 18, 7, 93, 3, 10, 
    8, 71, 7, 75, 0, 55, 6, 15, 4, 23, 3, 68, 1, 39, 2, 65, 5, 57, 
    7, 77, 3, 87, 1, 87, 6,  9, 8, 46, 5,  9, 0, 45, 2, 71, 4, 17, 
    8, 25, 5, 60, 0, 13, 2, 29, 7, 22, 6, 10, 4, 25, 1, 66, 3, 38, 
    7, 76, 2, 37, 5, 63, 3, 53, 1, 89, 8, 53, 4, 55, 0, 18, 6, 82, 
    7, 82, 3, 22, 6, 37, 8, 14, 1, 23, 0, 78, 4, 26, 2, 13, 5, 81, 
    2, 64, 0, 89, 8, 91, 4, 22, 3, 22, 6,  9, 5, 93, 7,  4, 1, 59
  };
  const int q6175[] = {
    9, 9, // Number of jobs and machines
    3,  5, 5, 79, 6, 62, 8, 20, 7, 58, 2, 73, 4, 32, 0, 42, 1, 57, 
    4, 10, 5, 56, 6, 10, 8, 90, 0, 39, 3, 43, 1, 68, 2, 65, 7, 46, 
    1, 25, 7, 32, 0, 60, 4,  1, 3, 69, 2, 89, 5, 29, 6, 90, 8, 24, 
    5, 88, 4, 73, 2, 29, 7, 85, 1, 37, 3, 15, 8, 99, 6,  2, 0,  3, 
    1, 33, 3, 94, 5, 58, 6, 58, 0, 55, 2, 36, 7, 10, 8, 35, 4, 29, 
    2, 89, 3, 57, 0, 34, 7, 36, 4, 30, 6, 36, 1,  1, 5, 47, 8, 42, 
    1, 82, 5, 10, 3, 21, 4, 76, 7, 94, 6, 47, 8, 49, 0, 73, 2, 56, 
    2, 59, 4, 93, 5, 86, 1, 86, 0, 72, 8, 12, 7, 11, 3, 10, 6,  2, 
    1, 19, 4, 63, 8, 70, 0, 44, 6, 47, 3, 99, 5, 98, 7, 46, 2, 30
  };
  const int q6176[] = {
    9, 9, // Number of jobs and machines
    7,  3, 2, 74, 1, 97, 0, 98, 8, 33, 5, 38, 6, 56, 4, 46, 3, 93, 
    6, 24, 0, 28, 5, 82, 4, 15, 8, 36, 7, 69, 1, 33, 3, 43, 2, 81, 
    2,  8, 8, 65, 0, 82, 5, 90, 1, 85, 6, 87, 3, 67, 4,  2, 7, 42, 
    0,  9, 1, 68, 5, 20, 7, 63, 8,  5, 3, 99, 4, 75, 6, 74, 2, 27, 
    4, 16, 0, 64, 1, 65, 7, 72, 5, 53, 8, 15, 6, 49, 2, 57, 3, 77, 
    3, 81, 2, 76, 0, 19, 1, 41, 4, 98, 5,  6, 8, 43, 7, 10, 6, 73, 
    8, 20, 2,  7, 3, 62, 1,  8, 6, 19, 0, 74, 5, 36, 7,  7, 4, 99, 
    5, 70, 3, 80, 0, 15, 4, 66, 6, 66, 1,  1, 8, 17, 2, 53, 7, 36, 
    1, 16, 7, 32, 2, 35, 4, 18, 6, 13, 5, 98, 0, 84, 8, 98, 3, 91
  };
  const int q6177[] = {
    9, 9, // Number of jobs and machines
    3, 41, 7, 41, 8, 75, 5,  3, 2, 83, 0, 95, 1, 58, 6, 70, 4, 91, 
    7, 83, 8, 29, 5, 16, 3, 45, 6, 49, 1, 25, 0, 46, 2,  8, 4, 99, 
    4, 45, 6, 79, 2, 48, 8, 80, 1,  5, 3, 55, 5, 53, 0, 62, 7, 60, 
    4, 28, 1, 76, 7, 37, 3, 46, 2, 86, 5, 69, 8, 66, 0, 91, 6, 18, 
    8, 56, 4, 62, 1, 44, 0, 81, 7, 68, 2, 30, 6,  6, 3, 66, 5, 10, 
    5, 75, 1, 73, 0, 95, 3, 82, 6, 57, 2, 70, 4, 28, 7, 94, 8, 50, 
    6, 60, 8, 66, 2, 15, 0, 48, 1, 59, 4, 21, 7, 77, 3, 88, 5, 15, 
    2, 30, 5, 68, 8, 39, 0, 38, 4, 74, 3, 33, 6, 74, 7, 93, 1, 10, 
    8, 41, 4, 64, 7, 85, 2, 67, 3, 37, 5, 13, 0, 81, 1, 45, 6, 51
  };
  const int q6178[] = {
    9, 9, // Number of jobs and machines
    8,  9, 4, 57, 1, 25, 0, 61, 2,  1, 5, 98, 6, 26, 3, 24, 7, 42, 
    1, 35, 5, 25, 8, 37, 6, 87, 0, 48, 2, 88, 3, 43, 7, 55, 4, 60, 
    5,  3, 6, 67, 1, 32, 4,  6, 7, 64, 2, 89, 3,  2, 0, 58, 8, 64, 
    7,  7, 1, 13, 2, 80, 5, 89, 8, 34, 0, 30, 4, 50, 6, 45, 3,  7, 
    8, 78, 0, 15, 1, 85, 3, 73, 2, 66, 4, 63, 7, 65, 6, 57, 5, 13, 
    1, 92, 5, 57, 7, 75, 6, 84, 8,  3, 0, 61, 3, 84, 2, 97, 4, 67, 
    7, 52, 4,  6, 3,  3, 2, 51, 5, 72, 1, 68, 0,  2, 6, 66, 8, 38, 
    3, 80, 0, 28, 4, 75, 1, 87, 7, 17, 5, 56, 8, 12, 2, 97, 6, 11, 
    6, 18, 0, 29, 1, 12, 8, 81, 5, 76, 3, 63, 4, 94, 2, 12, 7, 87
  };
  const int q6179[] = {
    9, 9, // Number of jobs and machines
    2, 91, 5, 27, 4, 88, 7, 27, 0, 81, 8, 30, 6, 81, 3, 46, 1, 28, 
    7, 58, 4, 66, 2, 69, 8, 81, 6, 57, 1, 15, 3, 68, 0, 97, 5,  6, 
    6, 58, 7, 90, 8, 97, 3, 65, 4, 50, 5, 16, 2, 21, 0, 73, 1, 49, 
    8,  4, 4, 28, 0, 89, 7, 50, 3, 25, 5, 40, 2, 77, 6, 80, 1, 80, 
    1, 58, 4, 72, 6, 42, 2, 53, 5, 50, 7, 75, 0, 75, 8, 78, 3, 18, 
    7,  5, 3, 37, 4, 83, 5, 60, 2, 79, 1, 50, 6, 21, 0, 20, 8, 41, 
    8, 56, 4,  5, 1, 13, 0, 35, 3, 17, 7, 93, 6, 27, 5, 53, 2, 21, 
    7, 78, 8, 74, 4, 89, 1, 84, 5, 82, 0, 69, 2, 71, 6, 71, 3, 33, 
    8, 63, 3, 22, 0, 10, 1, 67, 7,  7, 5, 33, 6, 47, 2,  1, 4, 55
  };
  const int q6180[] = {
    9, 9, // Number of jobs and machines
    6, 14, 7, 17, 8, 41, 3, 68, 5, 27, 0, 96, 2, 94, 4, 11, 1, 58, 
    2, 16, 1, 89, 8, 45, 4, 86, 5, 43, 3, 87, 6, 79, 7, 84, 0, 83, 
    7, 85, 3, 14, 2, 75, 6, 60, 0, 11, 5, 67, 4, 62, 1, 15, 8, 72, 
    2, 33, 3, 35, 1,  1, 5, 89, 6, 89, 4, 41, 7,  2, 8, 22, 0, 47, 
    5,  7, 0, 43, 8, 58, 1, 50, 4, 28, 2, 23, 7, 54, 6, 84, 3, 47, 
    1, 29, 0, 66, 7, 55, 5,  5, 4, 13, 8,  5, 2, 71, 6, 65, 3, 84, 
    5, 56, 4, 57, 0, 79, 7, 67, 3, 68, 8, 53, 2, 43, 6, 47, 1, 21, 
    7, 83, 5, 29, 4,  1, 1, 27, 2, 98, 6, 46, 0, 20, 3, 70, 8, 99, 
    3, 31, 8, 41, 2, 13, 4, 90, 6, 31, 1, 12, 7, 96, 0, 57, 5, 91
  };
  const int q6181[] = {
    9, 9, // Number of jobs and machines
    5, 80, 2, 69, 1, 99, 0, 39, 4, 94, 8, 68, 7, 82, 6, 90, 3, 16, 
    2, 91, 3, 60, 8, 35, 4, 80, 1,  4, 5, 50, 7, 38, 0, 71, 6, 44, 
    0, 86, 4, 45, 5, 37, 8, 80, 3, 36, 2, 29, 7, 59, 6, 39, 1, 43, 
    7, 63, 8, 66, 0, 64, 3, 96, 6, 39, 5, 34, 2, 83, 1, 28, 4, 65, 
    6, 56, 7, 86, 4, 85, 2, 81, 5, 97, 1, 37, 0,  3, 3, 72, 8, 30, 
    0, 46, 1, 63, 4, 77, 7, 55, 2, 44, 3, 73, 8, 78, 6, 90, 5, 51, 
    6,  5, 2, 80, 8, 51, 4,  2, 7, 65, 0,  5, 3, 27, 1, 87, 5, 97, 
    1, 53, 3, 36, 8, 98, 7, 92, 2, 86, 4, 95, 6, 44, 0, 56, 5, 68, 
    0, 15, 4, 25, 3, 55, 8, 34, 2, 34, 1,  5, 7, 21, 6, 13, 5, 67
  };
  const int q6182[] = {
    9, 9, // Number of jobs and machines
    1, 52, 5, 40, 8, 43, 6,  1, 2, 85, 0, 79, 7, 33, 4, 58, 3, 46, 
    6, 61, 2, 48, 3, 32, 8,  5, 5, 37, 1, 86, 0, 34, 7, 83, 4, 35, 
    8, 22, 7, 32, 1, 34, 2, 37, 3, 83, 4, 76, 5, 57, 0, 67, 6, 42, 
    7, 98, 5, 56, 1, 78, 3, 30, 8, 39, 2, 46, 0,  1, 4, 95, 6, 20, 
    8, 65, 3, 65, 6, 65, 1, 57, 0, 63, 7, 55, 5, 52, 4, 36, 2, 58, 
    2, 54, 7, 91, 0, 80, 8, 44, 6, 13, 1,  6, 5, 15, 4, 95, 3, 80, 
    6, 74, 8, 52, 4, 65, 1, 98, 2, 13, 3, 86, 5, 23, 0, 88, 7, 12, 
    8, 84, 6, 52, 0, 37, 4, 71, 1, 65, 2, 26, 7, 87, 3, 64, 5,  9, 
    8, 97, 6,  9, 7, 42, 2, 12, 4, 71, 5, 52, 3,  5, 1, 14, 0, 31
  };
  const int q6183[] = {
    9, 9, // Number of jobs and machines
    8, 37, 6, 29, 1, 59, 4, 76, 7, 88, 0, 66, 5, 41, 2, 51, 3, 96, 
    7, 91, 6, 56, 2, 66, 8, 68, 3, 45, 1, 12, 4, 90, 0,  9, 5, 36, 
    5,  8, 3, 19, 4, 73, 8, 69, 0, 41, 6, 46, 1, 20, 2, 18, 7, 90, 
    7, 34, 1, 72, 0, 61, 2, 39, 5, 65, 4,  4, 3, 69, 6, 72, 8, 85, 
    8, 58, 0, 63, 4, 53, 2, 43, 7, 14, 1, 46, 5, 78, 3, 70, 6, 98, 
    4, 92, 6, 81, 0, 77, 8, 31, 1, 12, 7, 66, 2, 64, 5, 62, 3, 35, 
    7, 29, 5, 77, 3, 55, 6, 11, 8, 98, 1, 74, 0,  2, 2, 74, 4, 46, 
    6, 80, 3, 69, 0, 88, 4, 44, 8, 56, 7,  5, 5, 12, 1, 61, 2, 66, 
    6, 71, 1, 13, 5, 99, 3, 81, 4,  3, 7,  7, 8, 26, 0, 64, 2, 75
  };
  const int q6184[] = {
    9, 9, // Number of jobs and machines
    8,  3, 3, 69, 4, 74, 6, 70, 2, 80, 7, 49, 1, 56, 0, 45, 5, 73, 
    3, 50, 8, 79, 4, 61, 0, 79, 1, 52, 5, 99, 6,  2, 7, 93, 2, 20, 
    8, 53, 5, 82, 2, 57, 6, 31, 7, 56, 0,  5, 3, 62, 1, 42, 4, 43, 
    0, 37, 7, 30, 4, 57, 5, 18, 2, 48, 1,  2, 3, 53, 6, 46, 8, 67, 
    2,  3, 3,  9, 4, 84, 5, 11, 8, 55, 0,  2, 7, 92, 1, 29, 6, 24, 
    5, 87, 8, 16, 4, 13, 6, 50, 1,  7, 7, 84, 3, 73, 0, 47, 2, 56, 
    2, 88, 3, 83, 1, 93, 6, 21, 5, 58, 0, 79, 4, 55, 7, 71, 8, 18, 
    0,  4, 2, 82, 1, 54, 8, 46, 5, 42, 3, 85, 6, 81, 7, 84, 4, 58, 
    0, 95, 8, 46, 4, 93, 5,  9, 2,  3, 7, 84, 3, 35, 6, 10, 1, 64
  };
  const int q6185[] = {
    9, 9, // Number of jobs and machines
    6, 22, 3, 71, 8, 55, 2, 44, 0, 45, 5, 18, 7, 65, 1, 30, 4,  7, 
    2, 92, 6, 54, 7, 91, 4,  3, 0, 38, 5, 45, 3, 17, 8, 55, 1, 53, 
    5, 95, 7,  4, 1, 47, 3, 49, 6, 60, 0, 13, 8, 46, 4, 67, 2,  4, 
    0, 97, 8, 15, 6, 16, 5, 61, 4, 69, 7, 73, 2, 71, 3, 95, 1, 29, 
    3, 69, 7, 77, 5, 28, 8, 78, 6,  2, 0, 99, 4, 34, 2, 83, 1, 94, 
    7, 35, 0, 45, 2, 18, 8, 60, 3, 24, 6, 76, 1, 58, 4,  2, 5, 35, 
    3, 47, 0, 55, 8, 58, 1, 48, 5, 50, 2,  1, 4, 98, 6, 38, 7, 27, 
    5, 11, 4, 33, 6, 82, 3,  4, 1, 49, 8,  2, 7, 30, 0, 73, 2, 78, 
    4, 36, 1, 56, 2,  1, 0, 17, 6, 65, 5, 21, 3, 80, 8, 27, 7, 15
  };
  const int q6186[] = {
    9, 9, // Number of jobs and machines
    7, 50, 5, 13, 4,  7, 3, 37, 1, 87, 6, 67, 0, 92, 8, 61, 2, 42, 
    1,  7, 2, 70, 0, 95, 6, 82, 5, 62, 3, 62, 4, 18, 7, 86, 8, 73, 
    8, 61, 1, 49, 6,  9, 4, 70, 2, 97, 3, 17, 0, 35, 7, 94, 5, 78, 
    0, 63, 6, 63, 8, 29, 2, 21, 7, 78, 5, 95, 4,  9, 3, 36, 1, 31, 
    5, 32, 4, 80, 0, 78, 8, 22, 1, 68, 7, 25, 6, 58, 3, 93, 2, 55, 
    4, 98, 2, 48, 6, 85, 0, 29, 7, 80, 3, 93, 5, 44, 8, 94, 1, 52, 
    8, 79, 1, 61, 5, 52, 3, 21, 2, 49, 0, 31, 7, 98, 6, 66, 4, 75, 
    8, 74, 0, 83, 3, 11, 6, 44, 1, 59, 5, 21, 7, 73, 2, 89, 4, 75, 
    6, 19, 5, 20, 3, 18, 7, 16, 0, 53, 4, 31, 2, 20, 1, 93, 8, 62
  };
  const int q6187[] = {
    9, 9, // Number of jobs and machines
    1, 95, 0, 30, 2, 88, 5, 94, 3, 94, 6, 85, 8, 78, 7, 36, 4,  5, 
    0, 50, 6, 93, 4, 56, 8,  1, 3, 55, 5,  7, 7, 75, 1, 15, 2, 37, 
    8, 23, 4,  4, 0, 35, 5, 55, 7, 40, 6, 82, 2, 34, 1, 46, 3, 21, 
    7, 46, 2, 46, 6, 86, 5, 21, 1, 15, 3, 74, 0, 31, 8, 26, 4, 74, 
    5, 11, 3, 62, 4, 28, 8, 86, 0, 34, 7, 17, 1, 86, 2, 17, 6, 23, 
    5, 24, 3, 30, 2, 69, 4, 12, 7, 65, 1, 42, 0, 18, 8, 88, 6, 69, 
    3, 49, 0, 19, 5, 52, 4, 96, 8, 59, 2, 22, 7, 35, 1, 28, 6, 23, 
    8, 40, 2, 90, 4,  1, 7, 12, 0, 52, 6, 52, 5, 57, 1, 54, 3, 25, 
    4, 45, 5, 56, 8, 98, 3, 59, 7, 24, 0, 25, 1, 10, 6,  7, 2, 84
  };
  const int q6188[] = {
    9, 9, // Number of jobs and machines
    1,  5, 2, 16, 4, 11, 6,  2, 3, 94, 7, 44, 8, 66, 5, 64, 0, 13, 
    8,  1, 3, 11, 0, 21, 1, 15, 7, 78, 2, 84, 6, 44, 5, 35, 4, 73, 
    6, 32, 1, 61, 4, 39, 0, 89, 5, 78, 2, 59, 8, 29, 7, 19, 3, 16, 
    4, 12, 5, 90, 7, 52, 2, 55, 0, 79, 8, 84, 1, 12, 3, 46, 6, 71, 
    3, 89, 6, 59, 1, 80, 7, 50, 8, 67, 0, 56, 2, 79, 4,  7, 5, 36, 
    6, 59, 1, 99, 7, 10, 5, 97, 8, 15, 2, 48, 0, 71, 3, 65, 4, 61, 
    8, 95, 7, 13, 3, 90, 0, 27, 4, 94, 6, 25, 1,  8, 2, 87, 5, 13, 
    7, 70, 5, 82, 0, 38, 6, 21, 4, 19, 2, 37, 8, 72, 3, 34, 1, 14, 
    0, 72, 4, 42, 3, 44, 8, 25, 6, 19, 1, 32, 5, 40, 7, 64, 2, 82
  };
  const int q6189[] = {
    9, 9, // Number of jobs and machines
    8, 88, 4, 28, 7, 48, 2, 63, 6, 16, 5, 87, 3, 78, 0, 56, 1, 85, 
    8, 68, 7, 46, 6, 71, 1, 13, 0, 25, 3, 62, 2, 55, 4, 15, 5, 57, 
    5, 82, 4, 25, 1, 79, 7, 23, 2, 36, 0, 99, 3, 59, 8, 48, 6, 51, 
    1, 94, 6, 28, 4, 77, 2, 44, 5,  8, 8, 24, 7, 21, 3,  4, 0, 91, 
    0, 93, 1, 50, 7, 13, 3, 61, 6, 95, 4, 84, 2, 97, 5, 60, 8, 51, 
    7, 71, 8, 13, 4,  7, 3, 62, 1, 69, 5, 65, 2, 97, 6, 96, 0, 82, 
    8, 35, 7, 29, 0, 44, 3, 30, 1, 69, 4, 30, 5, 34, 2, 87, 6, 12, 
    8, 56, 1, 41, 3, 98, 0, 75, 4, 38, 5, 96, 7, 50, 6,  9, 2, 48, 
    1, 69, 7, 59, 2, 63, 6,  2, 8, 94, 3, 31, 0, 30, 4, 60, 5, 22
  };
  const int q6190[] = {
    9, 9, // Number of jobs and machines
    5, 58, 4, 50, 0, 46, 6, 16, 7, 46, 2, 80, 8,  4, 1, 16, 3, 80, 
    5, 76, 1, 28, 3, 69, 7, 19, 0, 19, 2, 49, 4, 61, 6, 25, 8, 24, 
    8, 85, 0, 87, 7, 48, 6, 95, 3, 23, 4, 34, 1, 36, 2, 10, 5, 98, 
    3, 62, 1, 57, 4, 82, 7, 87, 6, 41, 2, 70, 0,  7, 5, 98, 8,  8, 
    7, 63, 5, 91, 3, 92, 0, 52, 4, 47, 6, 61, 1, 93, 2, 47, 8, 60, 
    5, 37, 8, 74, 1, 34, 2, 44, 6, 69, 0, 25, 7, 60, 4, 41, 3, 39, 
    2, 90, 0, 42, 4, 77, 8,  2, 3,  1, 1,  2, 6, 90, 5, 73, 7, 78, 
    0, 17, 5,  2, 7, 16, 3,  8, 6, 52, 1, 89, 4, 73, 8, 82, 2, 93, 
    7, 53, 5, 32, 6, 68, 0, 46, 3, 74, 8, 64, 2, 53, 1, 69, 4, 48
  };
  const int q6191[] = {
    9, 9, // Number of jobs and machines
    3, 30, 1, 94, 4, 17, 0, 29, 8, 59, 2, 11, 5,  6, 6, 86, 7,  7, 
    3, 59, 8, 36, 1, 75, 0, 63, 2, 14, 7, 47, 5, 26, 6, 52, 4, 59, 
    8, 54, 4, 71, 5, 25, 6, 25, 3, 70, 1, 49, 7, 29, 0, 91, 2, 96, 
    4, 10, 0, 25, 6, 20, 3, 80, 8, 52, 1, 57, 5, 16, 7, 31, 2, 41, 
    1, 60, 2, 61, 5, 82, 0, 10, 6,  4, 4, 74, 8, 39, 7, 66, 3, 77, 
    2, 39, 8, 23, 3, 74, 0, 93, 1, 51, 7, 22, 4,  7, 5, 92, 6, 38, 
    2, 47, 1,  2, 8, 17, 3, 85, 5, 69, 0, 74, 4,  8, 7,  5, 6, 88, 
    1,  1, 8, 94, 2, 56, 6, 67, 3, 91, 7, 55, 0, 96, 4, 38, 5, 29, 
    0, 29, 4, 10, 7, 12, 2, 53, 3, 54, 5, 40, 1, 22, 6, 68, 8, 19
  };
  const int q6192[] = {
    9, 9, // Number of jobs and machines
    2, 24, 1, 74, 8, 90, 3, 59, 4, 79, 0, 17, 7, 81, 6, 52, 5, 36, 
    7, 92, 5, 22, 3, 60, 0, 98, 1, 82, 4,  4, 6, 71, 2, 30, 8, 76, 
    6, 53, 1, 54, 0, 57, 2, 59, 3, 32, 5,  3, 8, 76, 7, 16, 4, 77, 
    1, 52, 8, 98, 3, 36, 4, 78, 6, 13, 2, 33, 0, 39, 7, 49, 5, 57, 
    6, 61, 1, 70, 2, 24, 8, 21, 0, 55, 3, 50, 5, 46, 7, 60, 4, 83, 
    5,  5, 6, 58, 2, 98, 7, 12, 1, 52, 0, 54, 3, 51, 4, 19, 8, 81, 
    3, 22, 6, 66, 7, 85, 1,  5, 5, 47, 8, 94, 4, 41, 0, 33, 2, 92, 
    6, 25, 5, 67, 7, 29, 2, 53, 1, 72, 4, 23, 3, 22, 0, 76, 8, 66, 
    5, 81, 4, 75, 1, 68, 7, 38, 2, 46, 3, 90, 8, 65, 6,  2, 0, 74
  };
  const int q6193[] = {
    9, 9, // Number of jobs and machines
    1, 75, 5, 73, 0,  8, 7, 62, 8, 79, 2, 79, 6, 72, 3,  2, 4, 63, 
    7, 26, 3, 59, 0, 76, 6, 23, 5, 92, 8,  3, 2, 42, 1,  6, 4, 85, 
    3, 70, 7, 97, 8, 26, 0,  3, 1, 90, 4, 13, 2, 32, 6, 60, 5, 74, 
    3, 95, 5, 56, 7, 97, 2, 58, 8, 48, 4, 14, 1, 81, 0, 57, 6, 20, 
    0, 43, 3, 32, 6, 39, 2, 23, 8, 24, 7, 49, 1, 85, 5, 36, 4, 73, 
    6, 27, 7, 30, 4,  2, 3, 65, 2, 20, 8, 89, 5, 48, 0, 78, 1,  3, 
    0, 38, 8, 75, 1, 22, 3, 50, 2, 47, 4, 69, 7, 73, 5, 89, 6, 29, 
    6, 54, 5, 73, 2, 29, 4, 98, 0, 85, 8, 47, 3,  7, 1, 64, 7, 90, 
    2, 84, 5, 39, 3, 22, 4, 95, 6, 13, 0,  6, 7, 73, 1, 94, 8, 86
  };
  const int q6194[] = {
    9, 9, // Number of jobs and machines
    3, 35, 2, 87, 4,  8, 5, 85, 1, 82, 8, 51, 6, 56, 7, 27, 0, 47, 
    7, 77, 4, 91, 5, 54, 2, 54, 6, 57, 8, 28, 3, 98, 0, 49, 1, 52, 
    5, 51, 8, 93, 1, 56, 6, 66, 3, 89, 2, 12, 4,  3, 0, 29, 7,  3, 
    4, 18, 3, 86, 2, 95, 8, 27, 5, 63, 1, 64, 7, 43, 0, 74, 6, 43, 
    3, 98, 8, 35, 6, 90, 4, 40, 0, 33, 5, 49, 2,  7, 7, 17, 1, 20, 
    5, 66, 4, 17, 0, 32, 8, 23, 6, 40, 2,  5, 7, 85, 3, 43, 1, 89, 
    0, 89, 2, 28, 7,  2, 1, 40, 8, 56, 6,  7, 4, 35, 3, 80, 5, 98, 
    6, 69, 7, 71, 5, 45, 1, 71, 4, 87, 3, 95, 0, 59, 2, 41, 8, 54, 
    6, 91, 4,  5, 5, 63, 2, 20, 7, 33, 3, 96, 0, 87, 8, 49, 1, 45
  };
  const int q6195[] = {
    9, 9, // Number of jobs and machines
    8, 55, 7,  1, 2, 35, 5, 74, 4, 95, 0, 43, 1, 61, 3, 57, 6, 60, 
    0, 70, 5, 49, 2, 19, 3, 47, 7, 34, 4, 22, 1, 22, 6, 66, 8, 81, 
    3, 11, 7, 14, 6, 66, 0, 35, 5, 51, 8, 83, 1, 40, 4, 61, 2, 72, 
    4, 42, 1, 79, 8, 46, 2, 73, 7, 30, 6, 22, 0, 23, 3, 98, 5,  5, 
    1, 15, 2, 83, 0, 81, 5, 91, 8, 66, 7, 39, 6, 44, 4, 28, 3, 62, 
    6, 64, 5, 62, 1, 97, 4, 29, 0, 72, 3, 40, 8, 27, 2, 59, 7, 76, 
    1, 64, 0, 50, 7, 30, 8,  4, 3, 90, 2,  7, 4, 93, 5, 24, 6, 29, 
    6, 73, 5, 50, 0, 61, 7, 63, 1, 73, 4, 37, 3, 27, 8, 30, 2, 77, 
    2, 50, 8, 47, 6, 39, 4, 72, 0, 20, 7, 17, 3, 65, 5, 75, 1, 92
  };
  const int q6196[] = {
    9, 9, // Number of jobs and machines
    3, 89, 8, 14, 1, 31, 5, 60, 6, 88, 7, 73, 4,  5, 0, 71, 2, 52, 
    7,  9, 2, 31, 0,  7, 1, 74, 8,  2, 4, 44, 5, 28, 3, 88, 6, 33, 
    6, 49, 2,  6, 0, 24, 3, 26, 4, 31, 7, 25, 1, 48, 5, 83, 8, 95, 
    6,  6, 1, 72, 7,  9, 4, 29, 5, 52, 2, 67, 8, 47, 0, 22, 3, 55, 
    7, 49, 2, 66, 6, 12, 4, 73, 0, 61, 1, 88, 3, 67, 8, 75, 5, 50, 
    0, 84, 3, 73, 2, 51, 7, 76, 5, 28, 1, 13, 6, 58, 8, 22, 4,  6, 
    3, 63, 2,  2, 6, 56, 1, 26, 0, 81, 7, 37, 5, 25, 4, 35, 8, 17, 
    1, 66, 8, 66, 0,  1, 5,  1, 4, 87, 3, 44, 6, 52, 2, 45, 7, 29, 
    1, 95, 2, 19, 7, 55, 4, 12, 8, 82, 0, 99, 5, 78, 6, 26, 3, 27
  };
  const int q6197[] = {
    9, 9, // Number of jobs and machines
    4, 58, 6, 65, 5, 59, 7,  7, 1, 69, 3, 83, 8,  7, 2, 92, 0, 94, 
    3, 24, 0, 74, 2, 96, 4, 58, 1, 45, 7, 71, 5, 34, 8,  4, 6, 41, 
    8, 51, 1, 95, 4,  1, 2, 94, 5, 74, 3, 35, 0, 60, 7, 52, 6, 64, 
    8, 10, 5, 59, 1, 65, 7,  6, 6,  1, 2, 90, 3, 79, 0, 45, 4,  7, 
    5, 34, 1, 71, 3, 97, 2, 27, 8, 76, 0, 87, 6, 71, 4, 61, 7, 47, 
    1, 90, 8, 68, 0, 41, 3, 26, 4, 30, 2, 64, 6,  5, 5, 57, 7, 22, 
    2, 97, 8, 95, 0, 30, 4, 19, 5, 22, 1, 35, 6,  4, 3, 21, 7, 39, 
    5, 82, 0, 94, 7, 51, 4, 73, 8, 49, 1, 46, 3,  9, 2,  2, 6, 87, 
    3, 44, 2, 58, 1, 25, 8, 69, 7, 33, 4, 57, 5,  4, 0,  1, 6, 49
  };
  const int q6198[] = {
    9, 9, // Number of jobs and machines
    4, 45, 8,  6, 7, 64, 1, 47, 0, 17, 5,  1, 3, 95, 6, 15, 2, 58, 
    1, 90, 3, 17, 0, 17, 5,  1, 4, 80, 2, 49, 7, 88, 6, 52, 8, 50, 
    4, 62, 1, 54, 6, 89, 3, 19, 0, 65, 5, 52, 8, 17, 7, 69, 2,  1, 
    7, 21, 0, 33, 5,  3, 3, 20, 6, 67, 8, 43, 1, 47, 2, 26, 4, 15, 
    0, 11, 2, 89, 4, 15, 1, 29, 7, 21, 5,  9, 6, 99, 8, 25, 3, 24, 
    5,  2, 7, 60, 3, 13, 8, 32, 2, 85, 1, 85, 6, 34, 4, 48, 0, 88, 
    1, 43, 5, 17, 0, 14, 7, 26, 8, 85, 4, 55, 3,  6, 2, 90, 6, 17, 
    6, 64, 7, 11, 3, 30, 4, 41, 0, 47, 8, 13, 1, 38, 5, 94, 2, 52, 
    3, 21, 0, 70, 2,  2, 6, 40, 7, 91, 1, 59, 4, 63, 8, 11, 5, 12
  };
  const int q6199[] = {
    9, 9, // Number of jobs and machines
    0, 83, 5, 68, 6, 66, 1, 87, 3, 31, 8, 87, 4, 43, 2, 26, 7, 93, 
    8, 56, 4, 91, 7, 93, 3, 77, 6, 31, 2, 26, 0, 93, 5, 26, 1, 63, 
    3,  2, 8, 91, 5, 14, 2, 98, 4, 48, 1, 89, 7, 72, 6, 23, 0, 24, 
    5, 87, 3, 56, 8, 86, 1, 72, 6, 13, 0, 44, 2, 92, 4,  4, 7, 81, 
    8, 24, 5,  7, 3, 68, 0, 22, 2, 33, 6, 61, 7, 83, 1,  3, 4,  5, 
    3,  4, 2, 94, 6, 34, 4, 36, 0, 89, 8, 96, 1, 21, 5, 28, 7, 50, 
    7, 58, 4, 41, 0, 87, 3, 35, 6, 13, 5, 26, 2, 31, 1, 77, 8, 31, 
    2, 65, 5, 76, 0, 17, 4, 30, 8, 18, 1, 92, 7,  5, 3, 59, 6,  8, 
    8, 94, 4, 87, 7, 82, 6, 74, 5, 80, 1, 81, 2, 93, 0, 81, 3, 71
  };
  const int q6200[] = {
    9, 9, // Number of jobs and machines
    0, 38, 1, 15, 6, 47, 7, 54, 8, 17, 4, 48, 2, 73, 5, 49, 3, 95, 
    3, 51, 0, 18, 2,  5, 4, 42, 1, 73, 5,  5, 8, 40, 6, 85, 7, 41, 
    5, 64, 3, 28, 8, 63, 4, 79, 0, 40, 1,  7, 7, 19, 2, 25, 6, 49, 
    2, 95, 0, 78, 6, 63, 1, 63, 3, 58, 4, 72, 8, 55, 5, 78, 7, 76, 
    5, 29, 7, 14, 0, 44, 6, 11, 8, 39, 3, 46, 1,  6, 4, 27, 2, 46, 
    4, 10, 7, 60, 1, 92, 5, 54, 2, 59, 3, 38, 6, 63, 8, 58, 0, 85, 
    2, 81, 6,  3, 1, 68, 8, 31, 4, 34, 7, 12, 5, 50, 3,  1, 0, 48, 
    5, 68, 6,  5, 1, 87, 8, 42, 3, 28, 2, 94, 7, 51, 4, 57, 0,  4, 
    4, 74, 1, 64, 7, 40, 6, 23, 8, 60, 0, 56, 5, 33, 2, 79, 3, 97
  };
  const int q6201[] = {
    9, 9, // Number of jobs and machines
    5, 76, 2,  5, 0, 74, 1, 98, 3, 27, 6, 96, 8, 52, 7, 71, 4, 87, 
    7, 64, 6, 29, 0, 67, 4, 47, 2, 19, 8, 80, 1, 35, 3, 17, 5, 26, 
    7, 53, 4, 89, 3, 55, 0, 83, 2, 33, 6, 48, 5, 83, 1, 19, 8, 60, 
    2, 14, 1,  3, 6, 46, 7, 89, 0, 23, 5, 68, 4, 67, 8, 41, 3, 56, 
    4, 67, 6, 99, 8, 67, 2, 29, 0, 85, 7, 26, 3, 64, 1, 13, 5, 41, 
    6, 18, 5, 55, 2, 96, 4, 69, 3, 13, 0, 51, 1, 72, 8, 59, 7, 35, 
    0,  9, 4, 72, 3, 68, 6, 22, 7, 60, 8, 39, 2, 94, 1, 30, 5,  9, 
    0, 60, 8, 54, 1, 85, 6, 23, 7, 35, 2, 42, 5, 79, 3, 24, 4, 58, 
    3, 23, 0, 57, 1, 36, 2, 66, 6, 28, 8, 82, 4, 65, 7, 80, 5, 32
  };
  const int q6202[] = {
    9, 9, // Number of jobs and machines
    3, 52, 7, 58, 6, 12, 0, 63, 5, 41, 8, 80, 4, 25, 2, 85, 1, 35, 
    8, 42, 4,  1, 1, 93, 0, 39, 6, 90, 5, 25, 7, 22, 2, 99, 3, 54, 
    5, 91, 2, 73, 4, 76, 3, 76, 0, 34, 7,  6, 1, 29, 6, 81, 8, 11, 
    6, 10, 3, 52, 7, 67, 1, 33, 4, 26, 8, 74, 0, 98, 2, 68, 5, 33, 
    3, 17, 0, 81, 8, 83, 4, 23, 1, 39, 7, 16, 6,  4, 2, 78, 5, 93, 
    7, 86, 2, 39, 5, 19, 3, 72, 0,  6, 4,  9, 8, 28, 1, 28, 6, 83, 
    7,  8, 5, 10, 3, 47, 4, 74, 8, 30, 6, 70, 2, 35, 1, 31, 0, 48, 
    0, 47, 8, 62, 4, 10, 6, 95, 1, 38, 5, 76, 3,  1, 7, 29, 2, 56, 
    6, 20, 4, 66, 3, 98, 0,  1, 1, 37, 2, 83, 8, 52, 7, 32, 5, 17
  };
  const int q6203[] = {
    9, 9, // Number of jobs and machines
    7,  3, 5, 76, 2, 81, 0, 28, 8, 38, 3, 85, 6, 52, 1, 39, 4, 10, 
    0, 81, 2, 12, 1, 13, 3, 37, 7, 93, 5, 46, 6, 10, 4, 91, 8, 31, 
    8, 54, 6, 61, 5, 11, 0, 57, 1, 78, 2, 81, 7, 67, 4, 34, 3,  5, 
    5, 22, 2, 71, 1, 48, 8, 53, 6, 59, 3, 47, 7, 25, 0, 74, 4, 54, 
    6, 27, 1, 22, 4, 87, 8,  9, 2,  2, 7, 25, 0, 47, 5, 87, 3, 32, 
    3, 96, 5, 50, 6, 33, 2, 11, 4, 92, 0, 78, 8, 97, 1,  7, 7, 33, 
    7, 10, 0, 10, 2, 75, 4, 23, 3, 19, 8, 45, 5, 85, 6, 44, 1, 53, 
    4, 38, 0, 94, 7, 70, 5, 47, 2, 12, 6, 62, 8, 27, 1, 94, 3, 71, 
    1, 87, 3, 24, 2, 11, 7, 69, 6, 87, 8, 41, 0, 98, 4, 57, 5, 88
  };
  const int q6204[] = {
    9, 9, // Number of jobs and machines
    4, 26, 5, 24, 7, 99, 2,  6, 3, 89, 8, 51, 6, 14, 1, 15, 0, 44, 
    6, 55, 0, 38, 5, 73, 8, 42, 4, 82, 1, 44, 3, 71, 7, 97, 2,  3, 
    3, 90, 0, 11, 8, 27, 2, 91, 5, 43, 6, 14, 7, 17, 1, 56, 4, 15, 
    8, 13, 3, 40, 0, 35, 4, 15, 5, 65, 2, 26, 1, 80, 6, 96, 7, 95, 
    0, 38, 7,  5, 5, 99, 1, 37, 8, 17, 2,  9, 3, 84, 6, 35, 4, 27, 
    4, 50, 0, 67, 6, 43, 1, 23, 7, 47, 8, 20, 2, 52, 3, 57, 5, 11, 
    5, 90, 3, 52, 7, 36, 4, 91, 8, 68, 0, 97, 1, 58, 2, 76, 6, 42, 
    8, 62, 0, 87, 2, 22, 5, 74, 3, 83, 1, 62, 6, 96, 4, 66, 7, 91, 
    2, 53, 1, 69, 5, 77, 8, 33, 0, 43, 3,  6, 6, 80, 4, 50, 7, 66
  };
  const int q6205[] = {
    9, 9, // Number of jobs and machines
    3, 29, 7, 77, 1, 92, 2, 58, 5,  3, 6, 90, 4, 78, 8, 92, 0, 60, 
    3, 24, 8,  5, 7, 84, 2, 97, 6, 22, 1, 50, 0, 58, 5, 83, 4, 89, 
    8, 39, 4, 71, 2, 23, 1, 23, 7,  8, 6, 36, 0, 66, 3, 40, 5, 71, 
    5,  3, 1,  1, 4, 43, 2, 45, 6, 70, 0, 71, 8, 67, 7, 57, 3, 82, 
    3,  5, 0, 58, 7, 35, 6, 70, 1, 74, 4, 36, 2, 58, 5,  4, 8, 84, 
    8, 81, 0, 43, 3, 31, 4, 40, 7, 66, 1, 17, 6,  5, 5, 76, 2, 25, 
    6, 21, 3, 13, 0, 35, 2, 63, 4, 88, 7, 22, 8, 21, 5, 22, 1, 59, 
    6, 15, 1, 39, 4, 73, 7, 79, 2,  3, 5,  2, 8, 92, 3, 65, 0, 79, 
    7, 76, 3, 53, 4, 47, 6, 91, 1, 61, 0, 34, 8, 98, 2, 56, 5,  8
  };
  const int q6206[] = {
    9, 9, // Number of jobs and machines
    8, 73, 6, 17, 2, 63, 0, 84, 1, 73, 3, 67, 5, 54, 7, 78, 4,  9, 
    2, 17, 6, 56, 8, 10, 1, 15, 0, 91, 3, 72, 7, 11, 4, 27, 5, 89, 
    4, 88, 8, 85, 6, 34, 5, 11, 2, 89, 1, 40, 7, 53, 0,  3, 3, 28, 
    5, 36, 2,  2, 0, 35, 3,  2, 7, 31, 1, 32, 4, 50, 8, 14, 6, 51, 
    0, 95, 6, 35, 2, 32, 7, 56, 1, 33, 5, 25, 4, 47, 8, 38, 3, 56, 
    7, 41, 2, 89, 8, 72, 3, 87, 5, 85, 4,  8, 6, 89, 0, 77, 1, 78, 
    1, 49, 4, 10, 6, 46, 8, 84, 3,  2, 0, 32, 5, 93, 7, 59, 2, 43, 
    7, 27, 3, 24, 8, 20, 0, 80, 6, 87, 1, 29, 5, 44, 4, 76, 2, 70, 
    0, 99, 5, 74, 4, 39, 3, 65, 2, 99, 8, 79, 7, 57, 6, 38, 1, 93
  };
  const int q6207[] = {
    9, 9, // Number of jobs and machines
    5, 86, 6, 73, 8, 87, 4, 97, 1, 23, 0, 97, 2, 48, 3, 53, 7, 21, 
    4, 19, 1, 88, 0,  3, 2, 24, 3, 91, 6, 21, 5, 89, 8, 79, 7, 98, 
    3, 36, 8, 80, 5, 72, 0, 28, 2, 50, 6, 47, 1, 52, 7, 94, 4, 98, 
    2,  5, 5, 14, 4, 77, 0, 27, 3, 23, 6, 35, 8, 42, 1, 97, 7, 72, 
    7, 22, 4,  8, 5, 99, 8, 86, 1, 35, 0,  1, 3, 97, 6, 48, 2, 35, 
    6,  3, 8,  6, 5, 30, 3, 66, 4, 35, 0, 36, 2,  1, 1, 17, 7, 15, 
    8, 69, 6, 42, 2, 69, 5, 15, 3, 22, 7, 35, 4, 90, 0, 97, 1, 44, 
    6, 25, 0, 33, 5, 23, 2, 20, 4, 70, 3, 98, 7, 47, 1, 29, 8, 71, 
    5,  2, 2,  6, 4, 73, 6, 20, 1, 14, 7, 81, 3, 11, 8, 60, 0, 12
  };
  const int q6208[] = {
    9, 9, // Number of jobs and machines
    4, 22, 8, 98, 0, 58, 1, 35, 2, 95, 6, 33, 3, 20, 5, 90, 7, 49, 
    6, 13, 7, 83, 8, 51, 3, 48, 4, 20, 5, 23, 2, 20, 1, 30, 0, 39, 
    8, 38, 0, 95, 3, 64, 1, 73, 2, 72, 7, 45, 5,  7, 6, 76, 4, 21, 
    2, 44, 1, 52, 7, 27, 3, 81, 8, 51, 5, 76, 6, 73, 4, 44, 0, 37, 
    5, 85, 2, 87, 3,  2, 7, 95, 8, 53, 6, 84, 1, 28, 0, 23, 4, 64, 
    5, 11, 8, 71, 1, 51, 7, 90, 3, 91, 6, 29, 2, 88, 0, 94, 4, 60, 
    1, 28, 2, 40, 8, 93, 5, 87, 3, 37, 6, 45, 0, 69, 7, 16, 4, 67, 
    3, 81, 7, 62, 8, 89, 6, 83, 4, 49, 1, 52, 0, 51, 2, 90, 5, 55, 
    8,  8, 2, 11, 5, 57, 0, 69, 3, 97, 1,  4, 6, 76, 4, 68, 7, 79
  };
  const int q6209[] = {
    9, 9, // Number of jobs and machines
    3, 62, 8, 17, 1, 37, 2, 21, 4, 32, 7, 46, 5, 13, 6, 11, 0, 41, 
    3, 85, 0, 61, 4, 35, 6, 88, 7, 48, 5, 18, 2, 83, 1, 85, 8, 14, 
    3, 98, 4, 27, 7, 22, 8, 67, 5, 16, 2, 17, 1, 79, 6, 91, 0, 37, 
    4,  4, 6, 73, 8, 42, 0, 13, 3,  5, 1, 57, 5, 93, 7, 75, 2,  6, 
    3, 20, 5,  6, 8,  7, 2, 11, 0, 88, 6, 11, 1, 34, 4, 58, 7, 30, 
    8, 11, 0, 93, 6, 56, 2, 66, 7, 92, 5, 74, 4, 73, 1, 77, 3, 98, 
    0, 23, 4,  6, 3, 33, 8, 86, 2, 30, 1, 78, 5, 17, 7, 85, 6, 87, 
    1, 31, 6, 62, 3, 98, 8, 26, 5, 91, 7, 18, 4, 82, 0, 96, 2, 14, 
    1, 79, 4, 80, 8,  2, 2, 45, 7, 97, 3, 54, 0, 22, 5, 68, 6,  7
  };
  const int q6210[] = {
    9, 9, // Number of jobs and machines
    8,  4, 4, 88, 7, 77, 0, 91, 1, 99, 2, 73, 5, 37, 6, 33, 3, 91, 
    8, 83, 1, 21, 3, 65, 2, 25, 4, 46, 7, 13, 5, 19, 6, 39, 0, 10, 
    4, 10, 2, 19, 0, 25, 7, 93, 1,  5, 3, 42, 6, 80, 8, 75, 5, 94, 
    8, 47, 2, 87, 5, 64, 1, 53, 4, 97, 7, 85, 6, 88, 3,  7, 0, 50, 
    2, 22, 6, 90, 1, 11, 0, 61, 3, 62, 4, 66, 8, 50, 7, 63, 5,  4, 
    7,  6, 5, 22, 1, 40, 3, 52, 6, 30, 8, 20, 2, 57, 0, 19, 4,  4, 
    4, 59, 3, 85, 8, 80, 5, 83, 7, 53, 0, 30, 2, 82, 1, 67, 6, 15, 
    3, 81, 1, 55, 0, 41, 8, 80, 5, 53, 4,  4, 6, 61, 2, 16, 7, 74, 
    7, 54, 2,  8, 5, 66, 3, 41, 8,  1, 6, 63, 1, 59, 4, 68, 0, 29
  };
  const int q6211[] = {
    9, 9, // Number of jobs and machines
    7,  6, 5, 36, 8, 38, 1, 84, 6, 41, 3, 30, 4, 70, 0, 67, 2, 73, 
    6, 43, 1, 91, 2,  5, 3, 54, 5, 11, 0, 76, 7, 90, 4, 66, 8, 46, 
    7, 32, 4, 94, 1, 25, 0, 79, 6, 57, 8, 25, 2, 99, 5, 73, 3, 78, 
    3, 19, 7, 42, 8, 80, 5,  9, 4, 31, 6, 47, 1, 32, 2, 12, 0, 79, 
    8, 19, 2, 74, 3,  2, 1, 20, 0, 24, 6,  9, 7, 24, 5, 43, 4, 65, 
    2,  7, 6, 87, 1, 42, 3, 18, 5, 14, 8,  9, 7, 34, 0, 19, 4, 93, 
    2, 81, 7, 12, 6, 91, 4, 36, 5, 99, 3,  2, 8, 39, 0, 18, 1,  6, 
    0, 52, 4, 21, 1, 98, 3, 29, 7, 85, 8, 70, 5, 69, 6,  3, 2,  9, 
    1, 18, 0, 58, 5, 53, 8, 41, 7, 52, 6, 27, 3, 94, 2,  6, 4, 12
  };
  const int q6212[] = {
    9, 9, // Number of jobs and machines
    5, 30, 2,  3, 8, 43, 0, 41, 4, 75, 7, 47, 3, 28, 6, 57, 1, 17, 
    4, 91, 0,  8, 6, 47, 2, 33, 1, 66, 3, 12, 5, 37, 7, 10, 8, 29, 
    5, 57, 1, 82, 6, 75, 7, 21, 2, 94, 8, 11, 0, 94, 4, 18, 3, 50, 
    1, 12, 8,  3, 0, 59, 4, 78, 7, 68, 2, 57, 6, 61, 3, 70, 5, 70, 
    1, 68, 4, 40, 5, 41, 3, 90, 7, 96, 6, 68, 8, 30, 2, 24, 0, 49, 
    3,  5, 5,  3, 2, 66, 6, 28, 4, 62, 1, 89, 0, 42, 7, 59, 8, 38, 
    0, 79, 6, 11, 5, 96, 1, 69, 4, 62, 3, 71, 7, 46, 8, 10, 2, 45, 
    7, 65, 3, 59, 0, 55, 5, 91, 6, 68, 4, 36, 2, 60, 1, 24, 8, 22, 
    2, 29, 4, 17, 6, 63, 7, 62, 8, 57, 1, 64, 0, 27, 5, 16, 3, 12
  };
  const int q6213[] = {
    9, 9, // Number of jobs and machines
    4,  7, 2, 72, 6, 30, 7,  6, 1, 49, 8, 63, 3, 13, 0, 11, 5, 75, 
    0,  5, 5, 47, 7, 94, 1, 67, 3, 47, 4, 55, 6, 29, 2, 29, 8, 12, 
    6, 27, 2, 27, 3, 23, 8, 97, 4, 66, 0, 18, 1,  3, 5, 80, 7, 87, 
    4, 52, 5, 68, 7, 47, 6, 88, 1, 95, 8, 77, 2, 95, 0, 34, 3, 72, 
    7, 41, 1, 25, 4, 90, 8, 76, 2, 64, 5, 45, 6, 90, 3, 11, 0, 29, 
    0, 50, 7, 56, 8, 98, 2,  3, 3, 95, 6, 28, 5,  8, 4, 84, 1, 63, 
    8, 87, 3,  1, 4, 60, 5, 54, 0, 95, 6, 13, 7, 93, 1,  5, 2, 49, 
    2, 74, 8, 13, 0, 86, 4,  1, 6, 68, 3, 59, 5, 40, 1, 95, 7, 33, 
    0,  3, 6, 18, 4, 20, 3, 50, 8, 23, 7, 18, 2, 36, 5, 66, 1, 48
  };
  const int q6214[] = {
    9, 9, // Number of jobs and machines
    5,  8, 2, 35, 4, 93, 7, 51, 3, 56, 8, 64, 0, 39, 6, 64, 1,  8, 
    4,  2, 7, 48, 0, 92, 8, 47, 2, 70, 6, 75, 5, 68, 3, 80, 1, 97, 
    3, 85, 0, 34, 5, 28, 8, 85, 1, 96, 7, 69, 6, 55, 4, 68, 2, 59, 
    0, 84, 8, 85, 2, 40, 6, 46, 5, 78, 4, 37, 1, 50, 7, 54, 3, 24, 
    2, 57, 7, 10, 5, 67, 8,  8, 6, 86, 1, 11, 4, 61, 0, 43, 3, 96, 
    4, 44, 2, 32, 8, 17, 1,  3, 6, 44, 0, 66, 3, 38, 5, 27, 7, 11, 
    8, 17, 4, 36, 1, 21, 5, 45, 3, 84, 0, 10, 6, 22, 7, 77, 2, 94, 
    0, 53, 1, 45, 7, 90, 3, 29, 5, 57, 8, 90, 2, 13, 6, 79, 4, 97, 
    1, 49, 2, 18, 0, 20, 4, 85, 5, 94, 8, 68, 3, 51, 6, 94, 7, 73
  };
  const int q6215[] = {
    9, 9, // Number of jobs and machines
    1,  9, 4, 23, 8, 82, 5, 72, 7, 59, 6, 19, 0, 57, 3, 38, 2, 69, 
    7, 19, 8, 39, 1, 42, 3, 36, 5, 87, 0, 16, 4, 35, 6, 78, 2, 29, 
    6, 29, 1, 82, 3, 52, 0, 49, 7, 93, 2, 24, 8, 26, 5,  5, 4, 71, 
    3, 34, 0,  9, 7, 87, 2, 80, 4, 80, 5, 45, 1,  5, 8, 96, 6, 15, 
    3,  2, 4, 38, 5, 60, 1, 52, 2, 22, 7, 67, 6, 83, 0, 72, 8, 18, 
    6, 16, 0, 99, 5, 18, 2, 79, 8, 33, 1, 24, 3, 95, 7, 79, 4, 74, 
    3, 49, 2, 72, 4, 80, 8, 43, 6, 14, 5, 82, 1, 98, 0, 99, 7, 62, 
    4, 64, 5, 81, 7, 34, 6, 72, 0, 58, 8, 55, 3, 82, 2, 38, 1, 73, 
    0, 71, 3, 29, 2, 18, 5,  3, 8, 42, 4, 30, 6, 63, 7, 49, 1, 39
  };
  const int q6216[] = {
    9, 9, // Number of jobs and machines
    0, 14, 8, 49, 2, 61, 6, 97, 1, 13, 3, 78, 4, 18, 7, 91, 5, 87, 
    3, 87, 5,  5, 2, 26, 7, 60, 1, 64, 8, 42, 4, 82, 6,  6, 0, 60, 
    0,  3, 2, 17, 3, 28, 5, 31, 7, 21, 6,  3, 1, 15, 4, 27, 8, 44, 
    0, 40, 8, 95, 7, 56, 2, 59, 3, 16, 1,  5, 4, 13, 6, 79, 5, 55, 
    5, 28, 6, 26, 0, 26, 1, 71, 7, 75, 4,  4, 2, 11, 8, 43, 3, 43, 
    4, 82, 2, 24, 3, 48, 0,  2, 5, 25, 6, 54, 1,  8, 8, 78, 7, 61, 
    2, 65, 8, 43, 4, 45, 0, 31, 5, 34, 1, 89, 6, 96, 7, 29, 3, 62, 
    1, 44, 2, 95, 6, 15, 4,  3, 8,  9, 3,  2, 0, 89, 5, 19, 7, 86, 
    0, 43, 5,  5, 2, 82, 3, 38, 7, 42, 8,  3, 1, 78, 4, 70, 6, 17
  };
  const int q6217[] = {
    9, 9, // Number of jobs and machines
    2, 68, 6, 19, 5, 22, 0, 47, 7,  5, 4, 28, 3, 47, 8, 98, 1, 53, 
    3, 19, 6, 63, 0, 60, 2, 72, 8, 59, 4,  2, 1, 86, 7, 66, 5, 72, 
    2, 58, 1, 54, 3, 88, 5, 62, 0, 45, 4, 61, 6, 40, 8, 94, 7, 69, 
    4, 66, 5, 90, 7, 80, 0, 29, 2, 55, 6, 14, 3,  4, 8, 78, 1, 99, 
    0, 77, 7, 25, 3,  1, 8, 59, 2, 76, 4, 19, 6, 70, 1, 76, 5, 59, 
    6, 94, 3, 28, 5, 85, 0, 54, 7, 59, 1, 80, 4, 54, 2, 22, 8, 95, 
    0, 24, 1, 44, 6, 26, 7, 91, 2, 85, 5, 36, 3, 16, 4, 76, 8, 72, 
    8, 56, 2, 28, 4, 59, 3, 39, 6, 96, 1, 27, 0,  7, 5, 56, 7, 44, 
    5, 43, 3, 90, 7, 69, 0,  4, 8, 32, 1, 26, 2, 69, 4, 31, 6, 36
  };
  const int q6218[] = {
    9, 9, // Number of jobs and machines
    2, 51, 5,  6, 3, 43, 0,  8, 8, 44, 1, 80, 6, 60, 7, 20, 4, 23, 
    3, 68, 4, 73, 1, 22, 6, 20, 5, 31, 2, 58, 7, 41, 8, 15, 0, 39, 
    5, 82, 8, 82, 7, 77, 1, 74, 3, 18, 6,  4, 2, 84, 0,  2, 4, 38, 
    0, 52, 7, 63, 5, 10, 8, 95, 2, 29, 1, 56, 6, 69, 3, 41, 4, 82, 
    7, 53, 5, 24, 8, 35, 6, 62, 1, 27, 2, 31, 0, 82, 4, 76, 3, 26, 
    0, 13, 8, 42, 3, 23, 7, 67, 1, 78, 6, 80, 4, 17, 5, 41, 2, 23, 
    1, 33, 8, 11, 7, 52, 4, 78, 5, 32, 2,  8, 3, 64, 0, 80, 6, 16, 
    6, 97, 5, 38, 0, 56, 2, 26, 4, 29, 1, 85, 3, 87, 7, 79, 8, 70, 
    1, 91, 4, 29, 6, 54, 5, 58, 2, 95, 0, 61, 8, 44, 7, 28, 3,  3
  };
  const int q6219[] = {
    9, 9, // Number of jobs and machines
    4, 27, 5, 42, 0, 22, 1, 90, 7, 50, 2, 21, 3, 67, 8, 35, 6, 14, 
    8,  5, 4, 92, 5, 23, 7, 22, 3, 36, 2, 62, 1, 72, 6, 51, 0, 56, 
    4,  6, 5, 76, 6, 92, 3, 48, 7, 66, 0, 75, 8, 52, 2, 26, 1, 53, 
    6, 70, 2, 75, 1, 54, 7, 62, 0, 66, 4, 70, 3, 67, 8, 36, 5, 42, 
    5, 76, 1, 74, 4, 52, 6, 32, 0, 18, 3, 38, 8,  6, 2, 40, 7, 78, 
    1, 51, 0, 52, 8, 81, 3, 93, 5,  4, 2, 45, 4, 10, 7, 34, 6, 71, 
    7, 35, 5, 97, 1, 99, 3, 10, 4, 19, 8, 12, 2, 13, 6, 76, 0, 75, 
    8, 14, 2, 86, 4, 67, 0, 26, 5, 88, 7, 98, 1, 62, 6, 53, 3, 23, 
    7, 79, 5, 22, 8, 70, 1, 92, 6, 58, 4,  9, 0, 84, 2, 75, 3, 85
  };
  const int q6220[] = {
    9, 9, // Number of jobs and machines
    2, 54, 5, 38, 4, 62, 3, 17, 1, 73, 6, 76, 8, 80, 7, 93, 0, 61, 
    2, 61, 4, 52, 7, 28, 0, 69, 5,  9, 8, 43, 1, 48, 3, 57, 6, 27, 
    2, 13, 6,  8, 0, 68, 3, 95, 1, 45, 7, 22, 5, 34, 4,  8, 8, 53, 
    5, 74, 3, 40, 1, 15, 4, 21, 2, 99, 0, 93, 7, 50, 6, 68, 8, 66, 
    6, 46, 4, 27, 3, 54, 8, 88, 0, 41, 1, 81, 2, 11, 5, 68, 7, 19, 
    0, 74, 1, 11, 6, 29, 7, 81, 4, 19, 5, 25, 3, 49, 2, 29, 8, 34, 
    3, 39, 4, 73, 1, 71, 8, 14, 7, 50, 6, 77, 5, 76, 0, 81, 2,  5, 
    2, 69, 4, 39, 8, 17, 5, 97, 6, 67, 7, 38, 3, 38, 0, 46, 1, 76, 
    8, 64, 3, 35, 0, 98, 7, 29, 5, 55, 4, 46, 6, 91, 2, 12, 1, 62
  };
  const int q6221[] = {
    9, 9, // Number of jobs and machines
    6, 60, 4, 20, 1, 74, 0, 14, 5, 51, 8, 33, 3, 13, 2, 35, 7, 93, 
    2, 43, 0, 12, 4, 87, 8, 52, 7, 10, 6, 72, 3, 38, 1, 77, 5, 56, 
    4, 89, 6,  6, 7, 18, 3, 37, 5,  1, 1,  5, 8, 55, 0, 96, 2, 95, 
    8, 41, 2, 45, 3, 99, 5, 21, 6, 93, 4, 30, 1, 82, 7, 22, 0, 11, 
    0, 36, 3, 26, 5, 42, 6, 98, 1, 39, 4, 56, 2,  3, 7, 83, 8, 81, 
    0, 67, 5,  8, 8, 22, 1, 81, 4, 59, 6, 58, 3, 89, 7, 94, 2, 84, 
    1, 32, 5, 94, 8, 77, 3, 95, 7, 25, 4, 98, 0, 12, 2, 31, 6, 70, 
    2, 17, 4, 54, 5, 42, 7, 63, 6, 51, 0, 77, 1, 84, 3, 56, 8, 21, 
    3,  5, 5, 96, 0, 75, 7, 71, 4, 74, 2, 49, 1, 94, 6, 12, 8, 25
  };
  const int q6222[] = {
    9, 9, // Number of jobs and machines
    5, 22, 8, 72, 0, 41, 7, 30, 1, 42, 3, 30, 6, 21, 4, 78, 2, 26, 
    7, 18, 1, 37, 5, 22, 3, 72, 2, 38, 4,  7, 0,  8, 6, 50, 8, 26, 
    0, 47, 4, 94, 1, 44, 8, 46, 6, 96, 2, 47, 3, 79, 5, 68, 7, 29, 
    3,  9, 6, 62, 0, 44, 4, 51, 1, 29, 2, 46, 7, 72, 5, 18, 8, 92, 
    7, 89, 0, 25, 1, 35, 4, 36, 8, 86, 2, 44, 5, 41, 3, 13, 6, 84, 
    2, 56, 4, 99, 7,  5, 0,  3, 1, 98, 5, 51, 6, 50, 8, 32, 3, 27, 
    1, 27, 6, 87, 8, 52, 3, 21, 0, 97, 5, 46, 7, 56, 4, 85, 2, 93, 
    3, 94, 6, 54, 2, 50, 1, 33, 7, 21, 8, 46, 4, 54, 0, 46, 5, 69, 
    7, 94, 5, 40, 6, 84, 2, 22, 1,  9, 3, 71, 4, 55, 0, 35, 8, 92
  };
  const int q6223[] = {
    9, 9, // Number of jobs and machines
    2, 57, 5, 76, 3,  4, 8, 62, 6,  1, 1, 80, 7, 90, 0, 65, 4, 16, 
    7, 58, 8, 56, 3, 78, 5, 10, 1, 87, 2, 41, 0, 36, 4, 22, 6, 35, 
    3, 83, 4, 70, 1, 97, 2, 36, 0,  5, 8, 20, 6, 54, 5, 84, 7, 69, 
    2, 52, 7, 79, 4, 21, 8, 64, 5, 52, 3, 29, 6, 20, 0, 40, 1, 61, 
    8, 41, 7, 10, 3, 37, 4, 39, 5, 55, 6, 20, 1, 14, 2, 75, 0,  2, 
    1,  9, 7, 92, 2, 34, 4, 48, 0, 41, 5, 17, 3, 24, 8, 48, 6, 30, 
    2, 88, 0, 28, 5, 84, 8, 17, 4, 24, 1, 12, 3, 75, 7, 71, 6, 91, 
    5, 65, 1, 13, 7, 97, 6, 90, 8, 32, 4, 20, 3,  8, 2, 98, 0, 21, 
    0, 99, 7, 62, 5, 23, 2, 95, 8, 52, 4, 68, 6, 73, 1, 66, 3, 42
  };
  const int q6224[] = {
    9, 9, // Number of jobs and machines
    7, 34, 0, 22, 5, 14, 2, 18, 3,  6, 4, 75, 1, 38, 8, 82, 6, 16, 
    3, 31, 6, 43, 7, 86, 1, 66, 4, 80, 0, 45, 5, 86, 8, 26, 2, 53, 
    3, 27, 1, 68, 0, 34, 6, 66, 2, 80, 4, 55, 7, 16, 8,  1, 5, 44, 
    4, 88, 2, 91, 1, 22, 5, 56, 7, 72, 3, 22, 0,  2, 6, 79, 8, 85, 
    8, 12, 3, 53, 7, 41, 1, 47, 6, 31, 0, 55, 4, 70, 2, 18, 5,  8, 
    8, 94, 3, 11, 2, 10, 7, 39, 4, 16, 6, 28, 5,  1, 1, 41, 0, 12, 
    6, 15, 2, 75, 0, 23, 3, 37, 8, 75, 1, 93, 5,  3, 7, 48, 4, 19, 
    6, 16, 0, 26, 5, 55, 1,  4, 7, 63, 8, 87, 4, 76, 2, 40, 3, 73, 
    3, 86, 8, 99, 0,  2, 5, 31, 6, 30, 4, 40, 2, 51, 1, 84, 7, 80
  };
  const int q6225[] = {
    9, 9, // Number of jobs and machines
    8, 29, 3, 90, 7, 86, 2, 11, 5, 43, 0, 42, 6,  4, 4, 66, 1, 58, 
    7, 13, 2, 78, 4, 11, 5, 33, 8, 33, 1, 74, 3, 10, 6, 70, 0, 55, 
    6,  5, 3, 95, 8, 43, 4, 72, 5, 40, 0, 11, 7, 90, 1, 87, 2,  3, 
    3, 67, 2, 71, 4, 94, 0, 97, 7, 65, 6, 16, 1, 33, 5, 90, 8, 13, 
    7,  9, 6, 69, 1, 70, 0, 68, 5, 79, 2, 59, 4, 23, 3, 80, 8,  7, 
    2, 39, 8, 55, 0, 24, 5, 17, 4, 45, 7, 98, 3, 32, 1,  7, 6, 73, 
    3, 70, 1, 62, 6, 82, 7, 92, 0, 35, 4,  3, 8, 98, 2, 91, 5, 68, 
    4, 10, 8, 98, 7, 10, 6, 50, 0, 47, 5, 56, 3, 56, 1, 39, 2, 74, 
    1, 48, 8, 61, 5, 71, 0, 55, 3, 56, 7, 34, 2, 35, 6, 27, 4, 91
  };
  const int q6226[] = {
    9, 9, // Number of jobs and machines
    6, 71, 5, 34, 0, 63, 7, 10, 2, 85, 3, 42, 1, 69, 4, 22, 8, 10, 
    2, 53, 1, 58, 7, 89, 8, 33, 4, 13, 6, 84, 5, 63, 0, 94, 3, 45, 
    6,  2, 7, 24, 2, 18, 3,  9, 1, 64, 0,  1, 4, 37, 8, 12, 5, 79, 
    2, 72, 0, 51, 6, 62, 8, 75, 4, 56, 7, 97, 1, 42, 3, 83, 5, 46, 
    5,  9, 1,  5, 7, 65, 0, 52, 8, 45, 2, 43, 4, 83, 3, 89, 6, 61, 
    7, 53, 1, 43, 5, 99, 2, 29, 8, 99, 6, 27, 0, 13, 4, 60, 3, 34, 
    2, 48, 8, 11, 1, 49, 3, 26, 0, 51, 7, 95, 4, 54, 6, 27, 5, 36, 
    4, 98, 8, 82, 7, 16, 2, 40, 6, 26, 0, 70, 5, 95, 3, 79, 1,  9, 
    1, 94, 8, 10, 5, 82, 6, 48, 4, 67, 0, 80, 7,  9, 2, 45, 3, 46
  };
  const int q6227[] = {
    9, 9, // Number of jobs and machines
    7, 56, 0,  2, 2, 97, 4, 19, 1, 96, 3, 29, 5, 69, 8, 73, 6, 32, 
    5, 89, 8, 74, 4, 17, 6,  1, 3, 58, 2, 22, 0, 74, 7, 43, 1, 70, 
    0, 67, 6, 40, 1, 40, 4, 86, 8, 46, 3, 57, 7, 52, 5, 26, 2, 43, 
    7, 65, 4, 17, 1, 88, 3,  4, 5, 22, 2, 40, 6, 27, 0,  3, 8, 82, 
    2, 29, 3, 81, 4, 94, 0, 15, 1, 21, 5, 53, 6, 10, 8, 54, 7, 43, 
    0, 86, 3, 32, 8, 90, 6, 85, 7, 91, 1, 14, 2, 68, 5, 25, 4, 19, 
    7, 80, 5, 63, 1,  4, 8, 49, 0, 72, 3, 80, 6, 66, 2, 67, 4,  9, 
    5, 22, 0, 76, 8, 24, 1, 48, 7, 78, 6, 75, 4, 77, 3, 75, 2, 74, 
    8, 99, 2, 12, 4, 33, 6, 66, 0, 12, 5, 13, 1, 88, 7, 69, 3, 55
  };
  const int q6228[] = {
    9, 9, // Number of jobs and machines
    3, 75, 8, 54, 7, 45, 6, 34, 2,  4, 4, 30, 0, 57, 1, 18, 5, 34, 
    0, 49, 4, 89, 6, 59, 2, 93, 1, 77, 7, 11, 3, 96, 5, 87, 8, 48, 
    4, 35, 6, 46, 1, 50, 5, 13, 7, 67, 8, 93, 0, 55, 3, 97, 2, 39, 
    6, 32, 0,  6, 4, 53, 1, 90, 3, 37, 5,  2, 8, 81, 7, 81, 2, 77, 
    2, 82, 0,  2, 5, 14, 4, 58, 1,  2, 7, 61, 3, 89, 6, 95, 8, 39, 
    8, 12, 1, 77, 2, 70, 7, 35, 6, 30, 0, 22, 3, 65, 4, 93, 5, 62, 
    5,  7, 2, 85, 0, 53, 8, 92, 6, 44, 3, 72, 7, 46, 1, 47, 4, 72, 
    0, 17, 4, 13, 1, 94, 2, 94, 6, 42, 5, 65, 8, 15, 7, 30, 3, 44, 
    6, 94, 3, 34, 7,  3, 8, 50, 0, 74, 5, 36, 4, 87, 2, 14, 1, 69
  };
  const int q6229[] = {
    9, 9, // Number of jobs and machines
    7, 28, 0, 70, 6, 98, 4, 39, 2, 28, 5, 93, 8, 19, 3, 66, 1, 35, 
    5, 18, 7, 25, 2, 87, 8, 35, 4, 81, 6, 10, 3, 51, 0, 64, 1, 31, 
    1, 90, 2, 70, 8, 78, 4, 81, 0, 89, 6, 77, 7, 59, 3, 98, 5, 57, 
    5, 31, 1, 65, 3, 44, 8, 87, 2, 68, 6, 45, 7, 58, 0, 21, 4, 16, 
    5, 64, 1, 31, 8, 15, 6, 26, 3, 79, 2,  1, 4, 84, 0, 20, 7, 52, 
    2, 77, 8, 68, 5, 16, 3, 88, 6, 67, 4, 37, 7, 53, 0, 99, 1, 45, 
    3,  9, 8, 32, 7, 83, 6, 60, 1, 25, 4, 10, 5, 33, 2, 57, 0,  7, 
    3, 60, 0,  4, 6, 29, 4, 91, 2, 24, 8, 36, 1, 36, 7, 56, 5, 91, 
    5, 22, 0,  9, 6, 12, 3, 40, 1, 82, 8, 48, 4, 22, 7, 60, 2, 97
  };
  const int q6230[] = {
    9, 9, // Number of jobs and machines
    1, 71, 3,  6, 6, 41, 5, 57, 7, 61, 0, 29, 8, 84, 4, 23, 2,  2, 
    5, 20, 3, 66, 2, 68, 1, 85, 0, 11, 6, 75, 8, 66, 4, 48, 7, 39, 
    3, 17, 2, 80, 7, 84, 4, 68, 8, 86, 6, 22, 0,  9, 5, 29, 1,  1, 
    2, 51, 5, 84, 8, 66, 0, 24, 7, 28, 1,  7, 6, 16, 3, 86, 4, 13, 
    7, 89, 5, 84, 3, 66, 1, 65, 4, 29, 2, 84, 0, 86, 8,  6, 6, 85, 
    0, 64, 7, 23, 4, 96, 3, 78, 1, 52, 8, 15, 5, 99, 2, 35, 6, 40, 
    6, 17, 2, 36, 3, 13, 5, 24, 8,  3, 1, 54, 0, 37, 4,  3, 7, 73, 
    3, 62, 4, 13, 7, 92, 8, 21, 5, 98, 6, 78, 1, 99, 0, 25, 2, 52, 
    5, 55, 2, 83, 6, 15, 0, 39, 3, 90, 7, 60, 1, 73, 4, 47, 8, 52
  };
  const int q6231[] = {
    9, 9, // Number of jobs and machines
    6, 34, 3, 19, 7, 24, 5, 66, 8, 79, 2, 56, 4, 94, 1,  4, 0, 77, 
    0, 28, 4,  4, 1, 82, 7, 38, 6, 57, 8, 54, 5,  6, 3, 32, 2, 67, 
    6, 75, 7, 77, 8, 65, 4, 27, 1, 63, 0, 65, 5, 54, 2,  8, 3, 46, 
    6, 46, 1, 32, 0, 88, 5, 62, 2, 48, 4, 84, 8, 20, 3, 23, 7, 87, 
    8, 88, 4, 83, 3, 88, 7, 12, 5, 11, 0, 21, 1, 35, 6, 30, 2, 65, 
    7, 37, 8, 11, 4, 69, 0, 99, 1, 66, 2, 40, 5, 50, 3, 85, 6, 14, 
    8, 42, 3, 93, 7, 82, 4, 51, 1, 25, 6, 93, 2, 58, 5,  7, 0, 22, 
    2, 16, 7, 64, 0, 52, 8, 36, 4, 26, 3, 36, 6, 28, 5, 45, 1, 41, 
    1, 89, 0, 54, 7, 73, 2, 12, 5,  5, 4, 72, 3, 91, 6, 30, 8, 78
  };
  const int q6232[] = {
    9, 9, // Number of jobs and machines
    4, 85, 0, 71, 6,  9, 5, 36, 8, 46, 3, 88, 7, 36, 1, 45, 2, 20, 
    1, 87, 6, 83, 4, 21, 0, 85, 7, 13, 2, 46, 5, 59, 8, 57, 3, 80, 
    7, 80, 6,  9, 5, 83, 8, 52, 4, 28, 1, 67, 3, 80, 2,  7, 0, 24, 
    3,  4, 5,  4, 4, 56, 8, 92, 0, 96, 1, 23, 6, 26, 2, 33, 7, 15, 
    7, 25, 2, 83, 3, 38, 0, 72, 6, 56, 4, 24, 8, 20, 1, 72, 5, 21, 
    3, 22, 6, 46, 5, 98, 0, 37, 2, 39, 7, 11, 4, 78, 1, 14, 8, 91, 
    5, 84, 4, 21, 7,  6, 8,  5, 1, 19, 0, 64, 6, 68, 3, 58, 2,  8, 
    5, 61, 0, 54, 6, 89, 7,  8, 1, 12, 4, 99, 2, 63, 8,  7, 3, 90, 
    0, 86, 3, 85, 6, 17, 8, 71, 1, 84, 5,  6, 4,  6, 2, 15, 7,  4
  };
  const int q6233[] = {
    9, 9, // Number of jobs and machines
    6, 24, 3, 34, 2, 36, 0, 88, 7,  3, 1,  6, 4, 83, 5, 41, 8,  3, 
    1,  7, 7, 22, 8, 39, 3, 59, 6,  1, 4, 59, 5, 95, 2, 19, 0, 71, 
    8, 95, 7,  7, 3, 79, 0, 69, 2, 82, 4, 14, 1, 89, 5, 63, 6, 26, 
    5, 59, 7, 18, 0, 99, 2, 48, 6, 14, 3, 24, 4, 67, 8, 17, 1, 28, 
    6, 65, 4, 16, 3,  7, 2, 48, 5,  4, 1, 64, 0,  7, 7, 54, 8, 96, 
    5,  1, 0, 85, 2, 52, 7, 23, 4, 21, 1, 74, 6, 29, 3, 81, 8, 27, 
    6, 24, 5, 59, 8, 56, 0, 40, 1, 48, 7, 45, 2, 24, 3, 43, 4, 58, 
    6, 21, 8, 22, 4, 80, 3, 60, 7, 94, 2, 49, 5, 71, 1, 95, 0, 94, 
    4, 12, 6, 41, 0, 20, 7, 13, 3, 30, 2, 24, 1, 43, 5, 94, 8, 47
  };
  const int q6234[] = {
    9, 9, // Number of jobs and machines
    0, 27, 1, 87, 8, 55, 3, 96, 5, 73, 4, 65, 2,  9, 6, 41, 7, 41, 
    0, 83, 8, 49, 5, 73, 3, 79, 7, 49, 1, 74, 4, 13, 6, 95, 2, 47, 
    2,  4, 7, 17, 8, 72, 4, 68, 6, 77, 5, 46, 0, 73, 3, 87, 1, 45, 
    0, 61, 5, 25, 7, 18, 1, 15, 3, 14, 6, 35, 4, 23, 8, 37, 2, 85, 
    1, 25, 3, 75, 7, 83, 5,  3, 0, 53, 8, 69, 4, 25, 6, 44, 2, 87, 
    8, 34, 5, 89, 7, 58, 2, 22, 3,  3, 6, 55, 4, 34, 1, 13, 0, 18, 
    4, 98, 3, 47, 2,  4, 1, 90, 8, 43, 6, 57, 5, 43, 0,  7, 7,  6, 
    5, 41, 8, 63, 2, 92, 7, 49, 1, 46, 6, 83, 0, 18, 3, 58, 4, 68, 
    8, 32, 3,  3, 1, 19, 0, 57, 7, 75, 5,  1, 6, 84, 2, 27, 4, 53
  };
  const int q6235[] = {
    9, 9, // Number of jobs and machines
    7, 23, 2, 39, 8, 76, 0, 52, 5, 34, 6, 73, 4, 53, 3, 47, 1, 12, 
    7, 48, 1, 71, 0, 85, 4, 19, 2, 87, 5, 21, 6, 18, 8, 15, 3, 19, 
    1, 45, 3, 83, 7, 12, 0, 74, 6, 49, 2, 65, 5, 80, 4, 16, 8, 21, 
    0, 49, 3, 56, 8, 60, 4, 24, 5, 36, 6, 24, 7, 45, 1, 40, 2, 29, 
    5, 88, 2, 44, 1,  3, 6, 61, 0, 49, 3, 92, 8, 16, 7, 89, 4, 37, 
    7, 71, 3, 59, 5,  3, 0, 13, 1, 79, 2, 28, 6, 48, 4, 71, 8,  8, 
    7, 15, 2, 60, 0, 62, 3, 27, 6, 26, 5, 29, 8, 28, 1, 55, 4, 35, 
    3, 49, 5, 76, 2, 92, 7, 11, 4, 35, 6, 85, 0, 68, 1,  7, 8, 18, 
    1, 26, 6, 77, 4, 91, 0, 34, 5, 94, 7, 28, 2, 20, 3, 50, 8, 57
  };
  const int q6236[] = {
    9, 9, // Number of jobs and machines
    8, 11, 3, 72, 4,  4, 2, 51, 7, 90, 5, 11, 0, 49, 6,  5, 1,  3, 
    1, 82, 5, 63, 2, 11, 4, 88, 8, 78, 0,  8, 6, 84, 7, 21, 3, 72, 
    1, 51, 6,  9, 8, 69, 2, 10, 3, 81, 4, 94, 5,  7, 7, 33, 0,  8, 
    0, 11, 2, 71, 1, 88, 7, 48, 6, 89, 8, 97, 3, 82, 4, 72, 5, 96, 
    6,  4, 4, 29, 2,  2, 8, 99, 7, 78, 5, 11, 0, 59, 1, 94, 3, 68, 
    7, 54, 0, 84, 3, 28, 6, 33, 1, 49, 4, 87, 2, 46, 5, 75, 8, 54, 
    0, 36, 7,  9, 1, 61, 6, 29, 5, 42, 8, 88, 3, 52, 2, 37, 4, 30, 
    7,  9, 1, 71, 3, 86, 6, 70, 8, 78, 4, 97, 5, 72, 2, 14, 0, 36, 
    6, 88, 7, 92, 8, 31, 4, 31, 1,  8, 2, 74, 3, 60, 5, 22, 0, 67
  };
  const int q6237[] = {
    9, 9, // Number of jobs and machines
    5, 46, 8, 43, 7, 12, 4, 27, 0, 66, 2, 75, 6,  4, 3, 79, 1, 92, 
    0, 75, 6, 38, 3, 99, 4, 69, 8, 78, 7, 96, 1, 19, 2, 83, 5, 82, 
    6, 58, 0, 74, 3,  4, 8, 48, 5, 78, 1, 29, 2, 26, 4, 76, 7, 14, 
    3, 17, 0, 28, 8, 38, 7, 97, 1, 97, 2, 87, 6, 60, 4, 12, 5, 25, 
    6,  2, 7, 29, 0, 36, 4, 34, 5, 72, 2, 28, 8, 36, 1, 58, 3, 19, 
    1, 63, 5, 63, 3, 38, 8, 52, 4, 99, 7,  1, 0, 19, 2, 90, 6, 35, 
    2, 78, 7, 71, 8, 49, 1, 26, 0, 62, 4, 30, 3, 21, 5, 23, 6, 11, 
    8, 96, 5,  9, 2, 57, 6, 16, 0, 23, 1, 49, 7, 73, 3, 57, 4, 82, 
    2, 52, 1, 69, 0, 28, 6, 93, 3, 13, 7, 21, 5, 45, 4, 40, 8, 97
  };
  const int q6238[] = {
    9, 9, // Number of jobs and machines
    7, 22, 4, 81, 2, 57, 8, 22, 0, 99, 3, 44, 6, 48, 5, 65, 1,  9, 
    8, 89, 3, 20, 6, 28, 5, 28, 4, 78, 2, 68, 1, 24, 0, 40, 7, 79, 
    6, 66, 3, 67, 4, 69, 8, 36, 1, 95, 5, 99, 0, 32, 2, 16, 7, 31, 
    2, 46, 0, 36, 6, 85, 5, 91, 7, 61, 8, 64, 1, 25, 3,  4, 4, 94, 
    4,  1, 6, 85, 7,  4, 2, 52, 1, 56, 8,  1, 3, 72, 5, 83, 0, 26, 
    1, 90, 0, 49, 8, 52, 5,  2, 2, 69, 3, 40, 7,  2, 6, 48, 4, 42, 
    4, 66, 7, 86, 8, 66, 5, 52, 0, 19, 3, 82, 6, 61, 1, 31, 2, 44, 
    4, 68, 3, 40, 7, 21, 2, 16, 5, 25, 6,  5, 1, 63, 0, 73, 8, 94, 
    5, 67, 0, 41, 2, 72, 8, 84, 4, 99, 7,  1, 6, 23, 1, 33, 3, 26
  };
  const int q6239[] = {
    9, 9, // Number of jobs and machines
    7, 22, 8, 61, 2, 32, 4, 33, 3, 14, 1, 24, 6, 36, 5, 83, 0, 11, 
    8, 76, 2, 64, 1, 15, 4, 40, 7, 41, 5,  9, 3, 52, 0, 67, 6, 70, 
    2, 10, 4, 83, 1, 60, 3, 40, 6, 74, 7, 33, 0, 27, 8, 13, 5, 94, 
    5, 86, 7, 97, 6, 42, 4, 68, 3, 34, 0, 59, 1, 15, 8, 87, 2, 97, 
    6,  5, 0,  9, 4,  9, 2, 64, 7, 80, 3, 91, 8, 63, 5, 86, 1, 10, 
    6, 23, 0, 43, 2, 76, 5, 20, 7, 81, 3, 75, 4, 65, 8, 55, 1, 87, 
    0, 51, 7, 60, 4, 32, 8, 45, 1, 46, 6, 92, 3, 14, 5, 55, 2, 24, 
    3, 19, 6, 59, 0, 40, 5, 10, 8, 15, 1, 24, 4, 53, 7, 82, 2, 37, 
    2, 33, 4, 12, 5, 38, 3, 20, 6, 68, 0, 35, 8, 48, 7, 88, 1, 41
  };
  const int q6240[] = {
    9, 9, // Number of jobs and machines
    5, 30, 4, 24, 3, 15, 6,  5, 0, 92, 8, 69, 7,  1, 1, 86, 2, 41, 
    4, 46, 1, 74, 5, 20, 8, 52, 3, 62, 2, 98, 7, 79, 0, 93, 6, 18, 
    7,  2, 4, 80, 6, 33, 8, 98, 2, 32, 1, 89, 0, 79, 3,  2, 5, 12, 
    7, 16, 0, 33, 8, 76, 2, 89, 1, 93, 3, 57, 4, 18, 5, 95, 6, 41, 
    6, 71, 2, 92, 5, 71, 8, 76, 1, 56, 3, 90, 7, 95, 0, 46, 4,  7, 
    1, 64, 7, 32, 0, 43, 5, 80, 4, 60, 8, 81, 6, 40, 2, 50, 3, 16, 
    0, 26, 4, 58, 7, 29, 1, 16, 3, 13, 5, 54, 8, 42, 6,  4, 2, 53, 
    1,  1, 7, 54, 5, 23, 4, 35, 8, 80, 6, 48, 2, 99, 0, 30, 3, 71, 
    1, 55, 4, 15, 6, 24, 2, 78, 8, 60, 5, 62, 7, 38, 0, 76, 3, 83
  };
  const int q6241[] = {
    9, 9, // Number of jobs and machines
    8, 41, 3, 12, 6, 82, 4, 96, 0, 24, 5, 89, 1, 67, 2, 97, 7, 92, 
    2,  6, 5, 45, 0,  5, 8, 47, 1, 80, 7, 75, 6,  4, 4, 83, 3, 27, 
    1,  2, 4, 81, 6, 33, 3, 11, 5, 53, 7, 97, 0, 54, 2, 41, 8, 63, 
    2,  8, 1, 32, 4, 77, 5, 98, 0, 37, 7,  9, 8, 42, 3, 88, 6, 19, 
    3, 76, 6,  1, 2, 54, 8,  6, 0, 95, 4, 88, 1, 86, 7, 63, 5, 64, 
    1, 38, 0, 20, 7,  4, 8, 58, 4, 40, 6, 13, 3,  9, 5, 46, 2, 95, 
    6, 66, 2, 80, 7, 26, 8, 35, 0, 44, 4, 25, 1, 64, 3, 59, 5, 94, 
    8,  5, 6, 94, 4, 75, 7, 97, 2, 86, 0, 53, 1, 58, 3, 27, 5, 62, 
    8,  3, 2, 76, 5, 49, 3, 11, 4, 25, 6, 11, 7, 62, 1, 50, 0, 37
  };
  const int q6242[] = {
    9, 9, // Number of jobs and machines
    4,  7, 5, 53, 3, 92, 0, 87, 7, 16, 1, 72, 6, 30, 2, 16, 8, 43, 
    6, 96, 4, 24, 5, 19, 7, 91, 8, 87, 1, 50, 2, 21, 3, 41, 0, 58, 
    1, 19, 7,  4, 3, 80, 2, 16, 4, 20, 5, 37, 0, 74, 8, 52, 6, 32, 
    8, 55, 3, 28, 0, 92, 2, 60, 5, 93, 4, 61, 6, 62, 1, 83, 7, 86, 
    4, 49, 3, 61, 2, 62, 1, 41, 7, 87, 6, 50, 8, 76, 5, 53, 0,  4, 
    8, 81, 6, 48, 0, 89, 7,  2, 2, 40, 5, 64, 3, 39, 1, 89, 4, 95, 
    7, 97, 2, 22, 1, 37, 4, 32, 5, 33, 6, 10, 8, 13, 0, 84, 3, 22, 
    3, 84, 1, 21, 7,  3, 4,  5, 2, 83, 8, 36, 5, 29, 6, 53, 0, 11, 
    7, 51, 8, 32, 3, 78, 5, 79, 1,  9, 4, 18, 0, 54, 2, 66, 6,  1
  };
  const int q6243[] = {
    9, 9, // Number of jobs and machines
    1, 31, 4, 84, 6, 54, 8, 25, 5,  7, 7, 52, 0, 51, 3,  7, 2,  7, 
    0, 87, 3, 52, 7, 43, 8, 67, 5, 50, 6, 36, 4, 60, 2, 78, 1, 17, 
    6, 84, 2, 64, 4, 10, 3, 77, 0, 59, 8, 70, 7, 72, 5, 70, 1, 37, 
    2,  3, 6, 84, 3, 57, 4, 79, 5, 62, 8, 44, 1,  4, 7, 48, 0, 91, 
    1, 69, 3, 67, 8, 74, 4, 89, 2, 55, 6, 90, 0, 98, 7, 65, 5, 35, 
    5, 95, 2, 22, 7,  1, 8, 20, 3, 24, 4, 67, 6, 53, 0, 49, 1, 70, 
    6, 79, 8, 10, 3, 43, 1, 42, 4, 37, 2, 56, 7, 11, 5, 57, 0, 32, 
    0, 27, 6, 85, 1, 52, 5,  8, 7, 88, 4, 26, 2, 25, 8, 70, 3, 50, 
    4, 90, 7, 45, 1, 95, 0,  1, 3, 92, 5, 47, 2, 90, 6, 10, 8, 10
  };
  const int q6244[] = {
    9, 9, // Number of jobs and machines
    1, 35, 3,  9, 0, 17, 4, 93, 8, 86, 6, 83, 7, 97, 2, 11, 5, 11, 
    6, 28, 2, 94, 7, 11, 4, 51, 3, 32, 1, 18, 0, 94, 5, 97, 8, 22, 
    3, 70, 0, 28, 6, 54, 1, 44, 7, 20, 4, 21, 2,  3, 5,  9, 8, 14, 
    8, 39, 2, 98, 3, 57, 5, 95, 6, 53, 4, 88, 1, 55, 7, 30, 0, 44, 
    0, 74, 3, 95, 6, 64, 2, 46, 8, 62, 5, 21, 4,  3, 1, 47, 7, 22, 
    6, 20, 2, 78, 0, 61, 7, 14, 1, 70, 4, 87, 5, 45, 8, 62, 3, 15, 
    0, 61, 2, 82, 6,  1, 1,  7, 5, 10, 7, 77, 8, 99, 4, 24, 3, 90, 
    2, 28, 0, 85, 7, 22, 8, 87, 3, 38, 1, 61, 4, 64, 5, 84, 6, 66, 
    7, 50, 6, 26, 3, 10, 1, 55, 8, 15, 2,  1, 5, 32, 0, 71, 4, 37
  };
  const int q6245[] = {
    9, 9, // Number of jobs and machines
    4, 39, 3, 45, 7, 91, 1, 51, 0,  8, 5, 30, 2, 48, 8, 68, 6,  2, 
    5, 45, 4, 22, 2, 33, 8, 75, 0, 45, 7, 89, 1, 12, 6, 61, 3, 29, 
    0, 27, 6, 19, 1, 12, 5, 37, 4, 41, 8, 71, 2, 59, 7, 83, 3,  8, 
    1, 64, 2, 49, 8, 14, 4, 86, 5, 33, 7, 19, 0, 21, 6, 33, 3, 29, 
    8, 60, 6, 53, 1,  2, 4, 59, 7, 92, 0, 64, 5, 47, 3, 91, 2, 72, 
    3, 54, 7, 61, 6, 54, 8, 60, 2, 81, 1,  6, 4, 13, 0, 82, 5, 15, 
    2, 35, 3, 96, 8, 94, 7, 31, 5, 22, 0, 62, 4, 83, 6, 52, 1, 93, 
    6, 28, 4, 26, 1, 87, 7, 14, 5, 40, 2, 48, 3, 93, 0, 72, 8, 80, 
    1, 64, 7, 22, 0,  5, 4, 50, 3, 27, 6, 68, 2, 98, 5, 69, 8, 55
  };
  const int q6246[] = {
    9, 9, // Number of jobs and machines
    1, 85, 7, 38, 5,  3, 4, 11, 2, 86, 8, 59, 3, 91, 6, 29, 0, 95, 
    2, 78, 4,  9, 7, 12, 3, 59, 6, 71, 5, 94, 8, 13, 1, 44, 0, 57, 
    7,  5, 1,  9, 0, 24, 3,  9, 4, 41, 5, 79, 6, 56, 2, 58, 8, 19, 
    2, 64, 7, 46, 5, 43, 6, 34, 4, 81, 1, 65, 3, 76, 8, 87, 0, 43, 
    5, 90, 3, 13, 0, 42, 6,  9, 1, 57, 2, 90, 7, 79, 4, 75, 8, 59, 
    4, 66, 0, 91, 7, 10, 1,  7, 3, 60, 2, 59, 8, 53, 5,  1, 6, 35, 
    4, 33, 1, 57, 0, 18, 8, 62, 5, 16, 7,  2, 6, 69, 3, 78, 2, 72, 
    0, 50, 8, 32, 4,  3, 6, 29, 3, 81, 1, 63, 5, 73, 7, 67, 2, 30, 
    4, 76, 5, 81, 7, 58, 0, 43, 6, 11, 1, 47, 3, 70, 8, 51, 2, 79
  };
  const int q6247[] = {
    9, 9, // Number of jobs and machines
    2, 23, 3, 37, 8, 83, 6, 59, 4, 63, 0, 20, 1, 56, 5, 57, 7, 80, 
    3, 34, 7, 56, 4, 96, 1, 64, 2, 79, 8,  2, 0, 18, 5, 12, 6,  2, 
    0, 61, 4, 12, 8, 79, 3, 12, 6,  2, 7, 68, 5,  3, 2, 57, 1, 30, 
    0, 35, 4, 47, 2, 84, 1, 59, 7,  7, 6, 79, 8, 16, 5, 88, 3, 28, 
    2, 21, 8, 18, 1, 67, 4, 55, 6, 59, 7, 84, 5, 98, 3, 65, 0, 43, 
    2,  7, 5, 45, 7, 14, 3, 45, 0, 73, 1, 30, 6, 84, 4, 47, 8, 30, 
    2, 52, 0,  4, 4, 35, 7, 91, 8, 62, 6, 67, 5, 77, 3, 64, 1, 32, 
    6, 19, 3, 35, 8, 74, 1, 17, 2, 65, 7, 28, 0, 23, 5, 59, 4, 81, 
    1, 56, 5, 82, 0, 20, 8, 91, 3, 73, 7, 97, 4, 23, 2, 66, 6, 84
  };
  const int q6248[] = {
    9, 9, // Number of jobs and machines
    6, 20, 2, 94, 1, 79, 8, 40, 7, 29, 5, 74, 3,  6, 0, 46, 4, 64, 
    4, 97, 2, 58, 3, 58, 8, 61, 1, 69, 6,  7, 7, 45, 5, 60, 0, 12, 
    0, 71, 7, 71, 5, 10, 1, 91, 8, 59, 2, 86, 4, 96, 3, 72, 6, 89, 
    0, 64, 7, 72, 2, 50, 1, 84, 6, 52, 8, 53, 3, 77, 4, 94, 5, 77, 
    5, 17, 3, 29, 0, 20, 8, 53, 4, 48, 7, 51, 1, 95, 2, 72, 6, 54, 
    7, 15, 3, 40, 8, 20, 4, 24, 2, 35, 6, 72, 1, 54, 5, 82, 0, 21, 
    7, 92, 0, 98, 5, 69, 1, 45, 3, 29, 8, 82, 6, 72, 2, 85, 4, 84, 
    1, 31, 8, 52, 7,  6, 6, 47, 3,  4, 5, 85, 4, 60, 2, 70, 0, 26, 
    1, 81, 4, 33, 8, 32, 5, 22, 7, 16, 0, 98, 3, 27, 2, 23, 6,  6
  };
  const int q6249[] = {
    9, 9, // Number of jobs and machines
    8, 26, 6, 14, 5, 65, 7, 89, 1, 53, 2, 21, 3, 55, 4, 69, 0, 14, 
    2, 81, 1, 51, 6, 12, 5, 38, 0,  5, 8, 78, 4, 26, 7, 60, 3, 62, 
    0, 83, 3, 27, 5,  6, 4, 64, 6, 56, 8, 98, 2, 81, 1, 36, 7, 92, 
    7, 90, 0, 66, 3,  5, 4, 54, 6,  3, 1, 55, 5, 28, 8, 26, 2, 61, 
    5,  9, 7, 23, 6, 69, 1, 45, 3, 62, 4, 84, 2, 60, 8, 20, 0, 43, 
    2,  2, 0, 38, 8, 15, 4, 35, 7, 11, 1, 64, 5, 82, 6, 78, 3, 54, 
    4, 35, 1, 15, 2, 47, 7, 25, 0, 30, 5, 37, 6, 66, 8, 95, 3, 87, 
    2, 92, 8, 43, 1, 74, 4,  1, 3, 31, 7, 67, 5, 54, 6, 66, 0, 93, 
    8,  1, 7, 54, 5, 85, 0, 91, 3, 36, 1,  4, 2, 35, 4, 66, 6, 54
  };
  const int q6250[] = {
    9, 9, // Number of jobs and machines
    4, 82, 8, 47, 6, 90, 3, 83, 5, 95, 7, 70, 1, 63, 0, 36, 2, 19, 
    4, 27, 7,  1, 6, 11, 1, 16, 2, 41, 3, 78, 0, 20, 5, 11, 8, 70, 
    7, 87, 1, 22, 2, 65, 5, 38, 6, 87, 4,  3, 3, 63, 8, 61, 0, 77, 
    8,  5, 5, 36, 1, 56, 6, 27, 7, 87, 2, 31, 0, 70, 4, 67, 3, 39, 
    2, 19, 5, 22, 3, 96, 1, 96, 6, 91, 4, 47, 0,  4, 7, 54, 8, 23, 
    7, 86, 4, 50, 1, 58, 6, 16, 5,  3, 0,  3, 3, 17, 2, 28, 8, 45, 
    2, 15, 5, 30, 7, 27, 0, 70, 3, 52, 1, 62, 6, 87, 8, 96, 4, 67, 
    6, 79, 5, 58, 8, 17, 4, 73, 0, 62, 3, 91, 2, 12, 1, 95, 7,  1, 
    0, 96, 5, 11, 8, 11, 4, 29, 7, 61, 6, 61, 2, 79, 1, 40, 3, 23
  };
  const int q6251[] = {
    9, 9, // Number of jobs and machines
    5, 98, 2, 96, 3, 12, 1, 57, 4, 66, 7, 17, 8,  9, 6,  2, 0, 97, 
    4, 60, 6, 46, 1, 17, 8,  1, 2, 89, 0, 95, 3, 79, 7, 71, 5, 46, 
    6, 47, 7, 77, 5, 62, 1, 83, 8, 23, 4, 80, 0,  9, 3, 42, 2, 74, 
    0,  3, 5,  8, 2, 74, 4, 43, 3, 51, 6, 94, 1, 34, 7, 80, 8, 27, 
    1, 59, 6,  9, 4, 86, 7, 44, 5, 79, 0, 36, 8, 72, 2, 10, 3, 80, 
    2, 35, 1, 58, 6, 63, 5, 11, 3, 17, 4, 54, 0, 73, 8, 27, 7, 33, 
    2, 90, 1, 80, 8, 87, 3, 80, 6, 94, 4, 15, 0, 78, 7, 82, 5, 17, 
    3, 45, 7, 98, 0, 76, 2, 46, 4, 71, 5, 95, 6, 67, 1, 85, 8, 13, 
    1, 80, 0, 31, 3, 22, 5, 26, 7, 46, 6, 61, 8, 82, 4, 91, 2, 67
  };
  const int q6252[] = {
    9, 9, // Number of jobs and machines
    5, 71, 7, 86, 1, 89, 3, 68, 4, 21, 2, 56, 6, 27, 0, 49, 8, 15, 
    3, 72, 2, 92, 7, 38, 4, 96, 8, 70, 0, 24, 1, 33, 6, 76, 5, 91, 
    1, 22, 5, 54, 4, 48, 0, 33, 8, 30, 7, 32, 3, 19, 2, 97, 6, 43, 
    8,  3, 3,  7, 6, 84, 5,  2, 2, 64, 0, 46, 4, 74, 7, 83, 1, 28, 
    2,  4, 6, 54, 0, 32, 5, 10, 7, 82, 8, 27, 3, 20, 1, 83, 4, 78, 
    3,  3, 2, 48, 0, 10, 5, 44, 6, 26, 8,  8, 1, 40, 4, 30, 7, 25, 
    0, 63, 7, 81, 6, 21, 8, 70, 2, 37, 3, 84, 5, 79, 1,  2, 4, 32, 
    6, 88, 4, 69, 3, 80, 8, 47, 1, 63, 0, 63, 2, 14, 5, 89, 7, 65, 
    1, 51, 5, 90, 4, 54, 8, 13, 0, 82, 7, 61, 6, 79, 3, 90, 2, 45
  };
  const int q6253[] = {
    9, 9, // Number of jobs and machines
    0, 95, 5, 64, 6, 17, 8, 24, 1, 95, 2, 73, 4, 49, 7, 20, 3, 70, 
    6, 15, 8, 98, 1, 60, 2, 13, 4, 54, 0, 33, 5, 34, 7, 62, 3, 12, 
    2, 76, 5, 34, 3, 27, 8,  4, 4, 55, 0, 34, 7, 29, 1, 37, 6, 95, 
    3, 55, 8, 41, 0, 17, 1, 22, 6, 93, 7, 72, 4, 89, 2, 26, 5, 85, 
    5, 34, 8, 94, 3, 25, 7, 43, 6, 88, 0, 23, 2, 13, 1, 25, 4, 81, 
    1, 98, 2, 24, 7, 10, 5,  9, 4, 17, 3, 87, 0, 51, 8, 45, 6, 71, 
    6,  3, 1, 92, 3, 69, 4, 58, 5, 70, 2, 36, 8, 11, 7, 34, 0,  5, 
    1, 40, 2, 38, 5, 50, 4,  2, 8, 47, 3, 63, 7, 93, 6, 83, 0, 44, 
    5, 68, 1, 37, 8, 85, 4, 88, 2, 46, 7, 76, 0, 29, 3, 28, 6, 10
  };
  const int q6254[] = {
    9, 9, // Number of jobs and machines
    6, 91, 8, 20, 1,  4, 5, 24, 4, 74, 7, 19, 0, 92, 3, 90, 2, 62, 
    6, 91, 2, 22, 1, 57, 8, 89, 3, 16, 7, 54, 5, 83, 0, 22, 4, 71, 
    2, 54, 6, 22, 7, 25, 1, 75, 3, 34, 0, 91, 8, 70, 5, 40, 4, 77, 
    8, 62, 4, 12, 2, 23, 5, 86, 1, 94, 6, 40, 7, 51, 3,  9, 0, 76, 
    4, 72, 5, 83, 8, 31, 2, 28, 7, 98, 0, 20, 3, 97, 1, 37, 6, 17, 
    4, 21, 5, 89, 1, 71, 7, 89, 8, 52, 3, 44, 2, 17, 6, 29, 0, 39, 
    3, 49, 7,  5, 4, 37, 6, 73, 1, 97, 2,  8, 5, 40, 8,  2, 0,  4, 
    5, 53, 4, 89, 3, 57, 1, 49, 0, 48, 6, 23, 2, 84, 7, 15, 8, 45, 
    3, 18, 4, 42, 8, 40, 6, 44, 5, 63, 2, 24, 1, 49, 0, 97, 7, 13
  };
  const int q6255[] = {
    9, 9, // Number of jobs and machines
    0, 41, 7, 43, 2, 99, 6, 27, 5, 42, 4, 70, 1, 85, 3, 42, 8, 15, 
    5, 50, 3, 80, 4, 76, 2, 73, 1, 56, 0, 49, 6, 17, 7,  6, 8, 62, 
    5, 68, 0, 83, 2, 57, 1, 69, 7, 92, 3, 71, 8, 73, 6, 22, 4, 15, 
    1, 88, 4, 93, 2, 91, 7, 72, 0, 88, 6, 14, 8, 97, 5, 63, 3, 59, 
    4, 40, 7, 76, 6, 69, 5, 13, 8, 27, 1, 39, 2, 95, 0, 68, 3, 88, 
    2, 91, 5, 16, 1, 96, 8, 54, 4, 40, 0, 50, 3, 47, 6, 98, 7, 45, 
    1, 15, 8,  4, 2, 11, 5, 88, 7, 37, 4, 33, 6, 39, 0, 64, 3, 93, 
    2, 21, 4, 70, 6, 79, 8, 55, 7,  6, 0, 28, 5, 79, 3, 67, 1, 24, 
    4, 89, 3, 44, 2, 33, 6, 46, 7, 65, 1, 65, 5, 69, 0, 88, 8, 28
  };
  const int q6256[] = {
    9, 9, // Number of jobs and machines
    5, 53, 0, 49, 2,  2, 4, 79, 3, 90, 8,  5, 7, 77, 1, 99, 6, 70, 
    5, 61, 2, 52, 1, 91, 8, 36, 3, 63, 0, 51, 4, 52, 7, 52, 6, 65, 
    7, 68, 1,  6, 2,  1, 3, 13, 5, 57, 8, 12, 4, 63, 6,  8, 0, 57, 
    2, 14, 5, 61, 7, 41, 6, 67, 0, 51, 8, 78, 4, 35, 1, 33, 3, 28, 
    8,  3, 1, 14, 3, 83, 5, 23, 7,  4, 4, 75, 0, 46, 6, 77, 2, 59, 
    1, 13, 8, 44, 0,  8, 6, 40, 3, 11, 2, 78, 7, 19, 4, 20, 5, 91, 
    7, 80, 1, 72, 5, 48, 6, 18, 0, 54, 3,  1, 4, 73, 2, 64, 8, 61, 
    6, 51, 4, 14, 1, 76, 8, 72, 0, 99, 7, 86, 5, 27, 2, 70, 3, 68, 
    6, 98, 0, 17, 2, 58, 7, 58, 5,  1, 4, 35, 1, 14, 3, 28, 8, 88
  };
  const int q6257[] = {
    9, 9, // Number of jobs and machines
    0, 78, 6, 86, 3,  6, 5,  8, 1, 47, 7, 72, 2, 83, 4, 19, 8, 70, 
    1,  7, 0,  9, 7, 98, 8, 80, 6, 32, 2, 67, 5, 94, 4, 40, 3, 99, 
    1, 44, 3, 82, 2, 14, 6, 80, 4, 89, 8, 19, 5, 24, 7, 57, 0,  2, 
    6, 77, 5, 38, 8, 37, 2, 42, 7, 41, 1, 95, 4,  7, 0, 95, 3, 37, 
    0, 13, 4, 67, 2, 78, 5, 68, 3, 85, 1, 14, 7, 87, 8, 82, 6, 92, 
    2, 68, 0, 44, 7,  5, 4, 73, 5, 38, 3, 89, 8,  5, 1, 55, 6, 34, 
    3, 71, 6, 82, 0,  2, 5, 92, 2, 43, 1, 15, 4, 29, 7, 64, 8, 13, 
    5, 17, 7, 95, 2, 24, 4, 61, 0, 68, 6, 51, 8, 28, 3, 53, 1, 34, 
    8, 86, 5, 28, 3, 97, 2,  5, 0,  2, 6, 88, 7, 23, 4, 39, 1, 66
  };
  const int q6258[] = {
    9, 9, // Number of jobs and machines
    4, 19, 2, 70, 5, 77, 0, 47, 7, 44, 3, 83, 6,  8, 8, 23, 1, 86, 
    5, 31, 2, 13, 1, 21, 3, 73, 4, 41, 6,  9, 0, 41, 8, 44, 7,  7, 
    2, 84, 6, 76, 5, 86, 7, 17, 1, 75, 0, 24, 4, 98, 3, 47, 8, 99, 
    8,  9, 0, 11, 6, 63, 1, 74, 7, 82, 3, 74, 2, 68, 4, 23, 5, 65, 
    1,  2, 6, 65, 8, 21, 7, 80, 3, 47, 2, 80, 5,  6, 4,  2, 0, 76, 
    4, 67, 5, 57, 2, 64, 8, 99, 7, 67, 1, 30, 0, 33, 6, 47, 3, 86, 
    6, 73, 4, 85, 1, 89, 2, 97, 7, 69, 0,  1, 3, 53, 5, 17, 8, 15, 
    2, 36, 6, 63, 5, 72, 1, 33, 8, 76, 7, 90, 3, 62, 0, 10, 4, 16, 
    3, 13, 7, 46, 6, 73, 2, 47, 5, 14, 0, 79, 4, 48, 8,  9, 1, 21
  };
  const int q6259[] = {
    9, 9, // Number of jobs and machines
    6, 93, 3, 93, 1, 51, 2, 36, 8, 40, 4, 43, 0, 43, 5, 89, 7, 46, 
    3, 13, 1, 28, 6, 56, 4, 24, 2, 86, 5,  9, 7, 72, 8, 59, 0, 28, 
    3, 22, 1, 89, 6, 11, 4, 39, 8, 10, 0, 38, 7, 10, 2, 19, 5, 43, 
    4, 77, 0, 21, 8, 92, 7, 39, 1,  5, 3, 44, 2, 57, 5, 84, 6, 38, 
    3, 91, 8, 92, 0, 85, 1, 52, 2, 90, 4, 32, 6, 96, 5, 24, 7, 20, 
    8, 82, 5, 55, 2, 36, 1,  6, 4, 18, 7, 14, 3,  9, 6, 59, 0, 22, 
    0, 63, 3, 19, 8, 39, 5, 38, 7, 86, 4, 10, 1, 14, 2, 83, 6, 76, 
    7, 56, 4, 68, 5, 43, 1, 76, 3, 53, 8, 47, 6, 28, 2, 37, 0, 29, 
    5, 76, 2,  9, 4, 88, 0, 84, 8, 29, 3, 28, 1, 47, 7,  6, 6, 65
  };
  const int q6260[] = {
    9, 9, // Number of jobs and machines
    7, 84, 0, 74, 3, 81, 4, 33, 8, 16, 1, 35, 5, 30, 6, 85, 2, 70, 
    7, 56, 5, 30, 4, 63, 6, 98, 1, 43, 2, 13, 3, 63, 8, 97, 0, 44, 
    3, 30, 1,  6, 4, 78, 6, 82, 7, 38, 2, 49, 8, 42, 0,  2, 5,  9, 
    3, 25, 2, 63, 1, 67, 8, 72, 0, 33, 5, 40, 6, 67, 7, 42, 4, 42, 
    0,  1, 2, 67, 6, 12, 5, 98, 7, 42, 3, 56, 1, 72, 8, 84, 4, 19, 
    7, 80, 4, 11, 2,  9, 0, 97, 1, 52, 5, 64, 6, 74, 8, 14, 3, 74, 
    6, 84, 7, 59, 8, 70, 1, 80, 5, 40, 2, 20, 4, 10, 3, 69, 0, 29, 
    3, 20, 0, 24, 2, 40, 7, 17, 6, 68, 8, 39, 5, 40, 1, 92, 4, 22, 
    5, 54, 0, 97, 4, 23, 6, 95, 1, 63, 3, 24, 8, 19, 7, 76, 2,  8
  };
  const int q6261[] = {
    9, 9, // Number of jobs and machines
    2,  4, 6,  3, 0, 38, 1, 44, 7, 24, 8, 17, 5, 84, 3, 60, 4, 62, 
    4, 86, 5, 28, 1, 29, 3, 37, 0, 99, 8, 58, 6, 46, 7, 29, 2, 56, 
    1, 32, 4, 34, 0, 97, 3, 98, 8, 96, 5, 51, 7, 71, 2, 97, 6, 77, 
    2, 12, 7, 51, 4, 17, 5,  2, 8, 17, 0,  9, 6, 35, 1, 95, 3, 70, 
    5, 73, 6, 33, 3, 16, 2, 10, 7,  7, 8,  4, 4, 14, 1, 43, 0, 30, 
    6,  5, 3, 38, 7, 50, 5, 44, 1, 27, 4, 21, 2, 38, 8, 68, 0, 83, 
    1,  8, 5, 39, 4, 26, 0, 47, 7, 74, 2, 56, 3, 15, 8, 42, 6, 80, 
    7, 75, 0, 80, 1, 63, 4, 68, 6, 58, 2,  7, 8, 57, 3, 45, 5, 40, 
    8, 63, 4, 80, 1, 39, 2, 15, 6, 59, 5,  5, 3,  8, 0, 92, 7, 29
  };
  const int q6262[] = {
    9, 9, // Number of jobs and machines
    3, 15, 0, 30, 2, 64, 1, 51, 7,  9, 6, 23, 8, 59, 5, 35, 4, 91, 
    0, 96, 7, 25, 6,  5, 2, 93, 5, 44, 8, 70, 1, 40, 3, 36, 4, 73, 
    4, 64, 2, 66, 6, 97, 7, 69, 0,  6, 5, 15, 3, 24, 8, 94, 1, 74, 
    7, 84, 4, 42, 0, 10, 5, 37, 3, 45, 6,  5, 2, 57, 8, 63, 1, 66, 
    5,  2, 3, 80, 6, 33, 0, 23, 1, 43, 7, 81, 4, 90, 2, 40, 8, 74, 
    7, 27, 5, 18, 0,  2, 4, 21, 8, 38, 2, 26, 1, 57, 3, 91, 6, 23, 
    5, 61, 0, 83, 2, 57, 3, 55, 4, 34, 7, 93, 1, 49, 8, 21, 6, 98, 
    1, 74, 4, 53, 8, 78, 3,  3, 7, 29, 2, 48, 6, 41, 5, 70, 0, 16, 
    5, 89, 7, 44, 4, 89, 0, 28, 3, 41, 2, 79, 1, 82, 8, 32, 6, 61
  };
  const int q6263[] = {
    9, 9, // Number of jobs and machines
    8, 90, 7, 76, 6, 22, 4, 77, 0, 95, 5, 46, 3, 21, 1, 11, 2, 91, 
    8, 83, 5, 21, 2, 21, 4, 19, 7, 98, 0, 77, 6, 10, 1, 20, 3, 45, 
    5, 30, 8, 79, 2, 74, 3, 95, 4, 46, 1, 10, 6, 93, 7, 72, 0, 60, 
    4, 96, 0, 44, 1, 38, 6, 36, 8, 91, 3,  6, 7, 22, 2, 42, 5, 72, 
    4, 67, 2, 94, 6, 98, 8, 45, 1, 34, 3, 63, 0, 89, 5, 84, 7, 47, 
    3, 58, 0,  1, 4, 58, 1, 34, 7, 23, 6, 81, 8, 47, 5, 58, 2, 44, 
    6, 40, 3, 95, 8, 79, 0, 12, 7, 28, 5, 96, 1, 98, 4, 85, 2, 48, 
    3,  6, 0, 55, 2, 40, 7, 32, 1, 33, 5, 91, 6,  8, 4, 44, 8, 38, 
    5, 48, 1, 21, 6,  2, 8, 67, 2, 64, 3, 68, 0, 51, 7, 45, 4, 36
  };
  const int q6264[] = {
    9, 9, // Number of jobs and machines
    6, 70, 3, 93, 4, 40, 1, 46, 7, 35, 5, 96, 2, 63, 8, 93, 0,  3, 
    0, 84, 8, 75, 1, 60, 5, 68, 7, 84, 3, 41, 4, 90, 6, 60, 2,  9, 
    5, 99, 8, 15, 0, 67, 2,  5, 4, 17, 7, 53, 6, 53, 1, 16, 3, 87, 
    6, 96, 0, 55, 5, 76, 3, 37, 8, 65, 7, 34, 1, 86, 2, 35, 4, 73, 
    7, 57, 4, 22, 6, 49, 0, 59, 5, 97, 3, 86, 2, 76, 8, 18, 1, 55, 
    7, 81, 4, 27, 6, 89, 1,  5, 3, 87, 0,  9, 2, 28, 5, 29, 8, 71, 
    2, 56, 8, 91, 7, 67, 1, 48, 6, 28, 0, 63, 5,  2, 4, 39, 3, 86, 
    2, 29, 7, 29, 3, 40, 6, 76, 0, 96, 5, 75, 8, 88, 4, 54, 1, 16, 
    1, 10, 6, 96, 3, 18, 7, 13, 0, 98, 8,  6, 5, 99, 4, 83, 2, 38
  };
  const int q6265[] = {
    9, 9, // Number of jobs and machines
    1, 51, 8, 18, 2, 18, 5, 78, 7, 54, 3, 43, 0, 61, 6, 55, 4, 97, 
    7, 79, 6, 63, 2, 72, 8, 72, 1, 63, 5, 14, 0, 20, 3, 25, 4, 32, 
    0, 88, 6, 81, 1, 89, 4, 50, 8, 51, 5, 41, 3, 10, 7, 82, 2, 80, 
    3, 28, 8,  5, 1, 42, 7, 63, 4, 67, 5, 70, 0, 41, 2, 97, 6, 34, 
    8, 13, 7, 66, 0,  9, 5, 35, 2, 20, 1,  6, 3, 48, 6, 93, 4, 48, 
    5, 43, 8, 13, 3, 11, 1,  1, 6,  4, 0, 24, 7, 56, 4, 65, 2, 86, 
    7, 10, 5, 17, 1, 66, 0, 46, 2, 14, 6,  3, 3, 91, 8, 33, 4, 22, 
    8, 91, 0, 21, 3, 47, 1, 86, 6, 13, 2, 77, 4, 59, 7, 63, 5, 30, 
    7, 73, 8, 39, 2, 89, 6, 73, 1, 65, 3, 57, 5, 43, 4, 11, 0, 65
  };
  const int q6266[] = {
    9, 9, // Number of jobs and machines
    7, 74, 1, 39, 4, 23, 0, 32, 6, 71, 2, 69, 5, 86, 3, 77, 8,  3, 
    7, 39, 0, 57, 2, 56, 5, 12, 8, 75, 4,  7, 1,  9, 6, 77, 3, 48, 
    1, 30, 4, 28, 8, 40, 6, 26, 7, 49, 3, 48, 5,  5, 0, 59, 2,  7, 
    1, 30, 3, 90, 6,  2, 0, 92, 4,  9, 5, 96, 8, 52, 7, 20, 2, 36, 
    6, 25, 2,  9, 1, 22, 7, 48, 0,  4, 5, 27, 8, 70, 4, 62, 3,  5, 
    4, 87, 7, 82, 3, 90, 1, 97, 0,  2, 6, 89, 2, 35, 5, 32, 8, 61, 
    8, 39, 4, 96, 2, 85, 1, 26, 0, 14, 3, 36, 6, 93, 5, 34, 7, 90, 
    7,  9, 3, 81, 6, 15, 8, 78, 4, 51, 5, 36, 1, 99, 2,  6, 0,  4, 
    3, 85, 5, 23, 2, 72, 4, 21, 7, 25, 6, 24, 0, 80, 8, 19, 1, 71
  };
  const int q6267[] = {
    9, 9, // Number of jobs and machines
    3, 92, 8, 68, 4, 67, 5, 65, 1, 19, 0, 51, 7, 39, 6, 44, 2, 71, 
    8, 11, 6, 11, 1,  5, 5, 51, 4, 63, 7, 36, 0,  8, 2,  6, 3, 57, 
    1, 48, 6, 35, 7, 93, 2, 97, 3, 16, 5, 53, 4, 20, 8, 43, 0, 63, 
    8, 87, 1, 80, 3,  4, 0, 18, 2, 88, 7, 52, 6, 79, 4, 10, 5, 35, 
    1, 45, 8, 16, 2,  2, 3, 21, 0, 83, 7, 78, 5, 13, 4,  1, 6, 20, 
    7,  6, 8, 69, 2, 42, 0, 30, 4, 90, 3, 80, 1, 11, 6, 37, 5, 43, 
    0, 84, 4, 45, 7, 84, 1, 48, 5, 93, 3,  3, 6, 59, 8, 45, 2, 83, 
    4, 53, 1, 31, 8, 88, 2, 94, 3,  3, 5, 11, 7, 96, 6, 13, 0, 75, 
    6, 75, 5, 19, 7, 11, 4, 84, 1, 90, 2, 49, 3, 32, 0, 62, 8, 86
  };
  const int q6268[] = {
    9, 9, // Number of jobs and machines
    7,  5, 6, 76, 5, 73, 2, 92, 0, 27, 4, 75, 1, 34, 8, 62, 3, 32, 
    8, 27, 4, 20, 0, 33, 7,  7, 2, 35, 1, 22, 5, 33, 6, 75, 3, 33, 
    2,  5, 0, 56, 1, 51, 3, 22, 5, 98, 4,  8, 7,  8, 8, 60, 6, 63, 
    1, 50, 7, 58, 6, 54, 3,  1, 4, 38, 5, 40, 0, 57, 8,  2, 2, 36, 
    5, 45, 3, 92, 6, 79, 2, 83, 0, 74, 8,  9, 1, 95, 7, 17, 4, 31, 
    4, 67, 3,  9, 8, 37, 0, 34, 5, 92, 6, 23, 1, 67, 7, 99, 2, 79, 
    0, 23, 2, 62, 3, 11, 5, 93, 6,  5, 7, 45, 4, 80, 8, 84, 1, 44, 
    6, 67, 4, 92, 1, 55, 2, 66, 3, 81, 5, 41, 8, 92, 0, 72, 7, 35, 
    0, 35, 2, 91, 7, 29, 6, 91, 8, 27, 5, 21, 4, 97, 1,  1, 3, 81
  };
  const int q6269[] = {
    9, 9, // Number of jobs and machines
    8,  9, 0, 35, 5, 82, 2, 33, 6, 68, 4, 76, 1, 84, 3, 78, 7, 25, 
    0, 39, 7,  2, 5, 65, 1, 90, 2, 93, 3, 19, 8, 24, 4, 59, 6, 85, 
    2, 77, 5,  7, 8, 60, 7, 14, 4, 96, 6, 16, 1, 81, 0, 90, 3, 46, 
    2, 90, 0, 74, 6, 83, 4, 33, 3, 39, 5, 59, 7, 18, 1, 56, 8, 48, 
    6, 66, 5, 13, 7, 60, 0, 37, 3, 43, 1, 67, 4, 43, 2, 72, 8, 81, 
    4, 79, 0, 85, 1, 85, 3, 14, 7, 61, 8, 23, 2, 49, 5, 26, 6, 72, 
    3, 73, 5, 21, 8, 39, 1, 47, 4, 88, 2, 65, 0, 89, 7, 14, 6, 99, 
    1, 82, 8, 34, 0, 98, 6, 73, 2, 58, 5, 28, 4,  3, 7, 17, 3, 20, 
    0, 79, 3, 35, 1,  4, 8, 76, 2, 68, 7, 78, 5, 22, 6, 27, 4, 79
  };
  const int q6270[] = {
    9, 9, // Number of jobs and machines
    5, 22, 8, 39, 3, 87, 6, 40, 7, 64, 0, 10, 4, 19, 1, 61, 2, 15, 
    1, 35, 6, 17, 7, 17, 5, 12, 2, 73, 3, 37, 8,  1, 4, 46, 0, 44, 
    4, 64, 3, 96, 0, 65, 6, 56, 7, 98, 2, 92, 1, 69, 5, 52, 8, 66, 
    4, 96, 8, 29, 5,  9, 0, 37, 1, 89, 7, 86, 3, 28, 6, 39, 2, 86, 
    4, 63, 2, 35, 8, 45, 6, 73, 7, 66, 3, 10, 1, 80, 5,  3, 0, 85, 
    5, 13, 1, 35, 3, 87, 0, 10, 2, 72, 6,  7, 7, 82, 8, 42, 4,  4, 
    4, 81, 2, 98, 8, 87, 7, 35, 6,  3, 3, 73, 1, 66, 5, 69, 0, 72, 
    7, 81, 1, 62, 8, 45, 6, 82, 0, 12, 3, 56, 4, 24, 2, 77, 5, 76, 
    3, 85, 0, 24, 1,  2, 7, 74, 2, 89, 6, 94, 5,  4, 4, 21, 8, 71
  };
  const int q6271[] = {
    9, 9, // Number of jobs and machines
    7, 57, 4, 96, 0, 78, 1, 65, 8, 69, 2, 85, 5, 56, 6, 38, 3,  9, 
    7,  8, 8, 37, 4, 36, 5, 69, 0, 11, 6, 37, 1,  1, 3, 76, 2, 88, 
    2, 85, 5, 24, 0, 43, 3, 75, 4, 80, 6, 43, 7, 54, 8, 93, 1, 45, 
    3, 52, 4, 53, 0, 54, 5, 93, 2, 75, 1, 15, 7, 80, 6, 56, 8, 19, 
    6, 25, 2,  8, 0, 80, 8, 52, 3,  8, 5, 51, 4, 73, 7, 21, 1, 41, 
    1, 63, 2, 32, 3, 59, 0, 30, 4, 55, 8, 24, 7, 94, 5, 35, 6, 26, 
    5, 57, 6, 93, 0, 65, 8, 37, 4,  3, 2, 33, 3, 41, 7, 77, 1,  9, 
    2, 67, 3, 84, 1, 24, 4, 17, 5, 97, 7, 97, 0, 31, 6, 18, 8, 22, 
    0, 37, 3,  1, 1, 77, 7, 62, 8, 89, 5, 66, 6, 14, 4,  7, 2, 36
  };
  const int q6272[] = {
    9, 9, // Number of jobs and machines
    8, 26, 7,  8, 4, 71, 3, 27, 2, 24, 0, 99, 6, 96, 1, 35, 5, 55, 
    5, 58, 4, 21, 0, 20, 6, 89, 1, 24, 3, 26, 7, 19, 2, 40, 8, 82, 
    5, 38, 3, 50, 0, 32, 7, 97, 1, 20, 8, 42, 2, 13, 6, 83, 4, 53, 
    3, 33, 0, 43, 1, 55, 7, 42, 2, 35, 8, 95, 4, 14, 5, 31, 6, 31, 
    8, 47, 5, 99, 6, 35, 1, 27, 4, 22, 2, 95, 7, 54, 3, 34, 0,  4, 
    0, 12, 2, 29, 3, 65, 6, 99, 4, 59, 5,  9, 8, 80, 1, 30, 7, 21, 
    8, 79, 1, 69, 0, 43, 7,  8, 3, 33, 4, 26, 2, 42, 6, 50, 5, 46, 
    1, 75, 0, 68, 6, 23, 2,  2, 8, 25, 3, 97, 4, 35, 7, 72, 5, 60, 
    4, 53, 0, 18, 1, 10, 2, 57, 7, 33, 5, 55, 3, 69, 8, 14, 6, 29
  };
  const int q6273[] = {
    9, 9, // Number of jobs and machines
    7, 12, 6, 84, 5, 97, 2, 99, 8, 85, 3, 45, 4, 64, 0,  5, 1, 24, 
    4, 80, 1, 43, 5, 63, 0, 22, 3,  5, 8, 38, 6, 47, 7, 55, 2, 57, 
    1, 23, 5, 50, 7, 95, 3, 38, 0, 79, 2, 42, 6, 75, 8, 50, 4, 21, 
    7,  9, 6, 75, 8, 13, 0, 70, 4, 78, 3, 85, 1, 96, 5, 22, 2, 41, 
    0,  6, 8, 59, 7, 78, 6,  6, 1, 91, 3, 14, 5, 76, 4, 43, 2, 50, 
    7, 61, 8, 69, 5, 94, 2, 58, 1, 33, 0, 35, 6, 43, 3, 92, 4, 40, 
    3, 17, 1, 54, 5, 36, 0, 36, 4, 95, 7, 46, 8, 98, 6, 71, 2,  6, 
    3, 28, 5, 38, 2, 62, 0, 34, 1, 45, 6, 89, 4, 37, 7, 85, 8, 48, 
    0, 70, 2, 23, 3, 21, 6, 12, 8, 65, 7, 42, 5, 13, 1, 50, 4, 53
  };
  const int q6274[] = {
    9, 9, // Number of jobs and machines
    2, 48, 7, 67, 0, 15, 1, 10, 8, 68, 3, 28, 5,  6, 4, 64, 6,  1, 
    5, 63, 7, 58, 1, 85, 3, 40, 0, 15, 8, 42, 2,  3, 6, 64, 4, 62, 
    6, 15, 7, 13, 5, 84, 0, 15, 4, 81, 2, 10, 1, 11, 8, 14, 3, 92, 
    2,  7, 6, 42, 3, 91, 0, 19, 4, 48, 7, 86, 1, 36, 5, 74, 8,  7, 
    4, 36, 7, 33, 1, 56, 2, 43, 5, 33, 6, 10, 3,  6, 0, 15, 8, 38, 
    0, 43, 8, 37, 2, 37, 3, 75, 4, 48, 5, 72, 7, 18, 1, 91, 6, 29, 
    4, 88, 1, 51, 8, 41, 6, 15, 2, 66, 0, 34, 7, 47, 3, 37, 5, 31, 
    7, 19, 1, 10, 4, 74, 3, 86, 5, 40, 0, 11, 8, 18, 2, 18, 6, 31, 
    8, 41, 1, 22, 6, 96, 7, 75, 2, 39, 4, 28, 5, 92, 0, 32, 3, 72
  };
  const int q6275[] = {
    9, 9, // Number of jobs and machines
    2, 84, 3, 94, 7, 75, 8, 62, 6, 51, 5, 35, 1, 80, 4, 41, 0, 11, 
    8, 16, 3, 33, 0, 23, 6, 66, 2, 91, 5,  2, 7, 28, 4, 48, 1, 55, 
    1, 37, 3, 20, 2, 60, 7, 50, 0, 27, 6, 92, 8, 27, 5, 14, 4, 47, 
    3, 12, 8, 89, 1, 76, 7, 86, 4, 55, 6, 33, 0, 86, 5, 97, 2, 13, 
    2, 47, 8,  9, 1, 17, 7, 85, 3, 54, 0, 46, 4, 66, 5,  1, 6, 22, 
    8, 63, 7, 69, 4, 70, 5, 94, 0, 37, 2, 22, 1, 41, 6, 84, 3, 51, 
    2, 21, 7, 62, 6, 23, 4, 78, 8, 36, 3, 56, 1, 84, 0, 25, 5, 20, 
    3, 48, 6, 48, 8,  1, 0,  2, 4, 94, 7, 64, 1,  1, 5, 85, 2, 11, 
    8, 99, 3, 92, 0, 77, 7,  7, 4, 72, 1, 10, 2, 66, 5, 77, 6, 89
  };
  const int q6276[] = {
    9, 9, // Number of jobs and machines
    8,  9, 0, 98, 4, 35, 3, 24, 1,  8, 6, 76, 2, 52, 7, 71, 5, 65, 
    5, 60, 6, 48, 8, 41, 2, 82, 1, 69, 7, 71, 4, 12, 0,  1, 3, 29, 
    8,  6, 5, 54, 6, 95, 3, 15, 7, 43, 1,  9, 2,  5, 4, 59, 0, 96, 
    6,  6, 3, 52, 7, 27, 0, 72, 1, 53, 4,  3, 2, 67, 8,  7, 5, 87, 
    3, 94, 1, 49, 0, 50, 4, 31, 2, 92, 7, 60, 8,  4, 6, 66, 5, 78, 
    1, 49, 2, 72, 8, 13, 7, 32, 3, 58, 6, 12, 5, 54, 0, 57, 4, 38, 
    6, 37, 4, 12, 1, 17, 8, 95, 0,  5, 3, 71, 7, 18, 2, 43, 5, 82, 
    3, 16, 0, 92, 8, 74, 7, 15, 1, 89, 6, 80, 2, 95, 4, 14, 5, 34, 
    6, 98, 5, 54, 2, 72, 8, 44, 4, 62, 7, 59, 1, 11, 3, 88, 0,  4
  };
  const int q6277[] = {
    9, 9, // Number of jobs and machines
    8, 91, 7, 56, 6, 15, 4,  7, 3, 11, 0, 81, 1, 54, 5, 85, 2, 52, 
    0,  1, 2, 26, 8, 96, 7, 45, 5, 63, 6, 28, 3, 53, 1,  7, 4, 37, 
    1, 33, 5, 48, 7, 90, 8, 16, 0, 79, 4, 67, 6, 26, 2, 76, 3, 33, 
    6, 59, 5, 28, 8, 47, 2, 59, 4, 88, 1, 59, 7, 63, 3, 34, 0,  4, 
    8, 57, 1, 10, 6, 79, 2, 94, 7, 54, 3, 41, 0, 16, 5, 64, 4, 81, 
    0, 90, 3, 84, 4,  8, 1,  8, 6, 46, 7, 58, 5, 54, 8, 82, 2, 25, 
    1, 92, 8, 67, 4, 45, 0, 25, 6, 50, 5, 27, 2, 93, 3, 73, 7, 24, 
    7, 19, 4, 21, 3, 76, 5, 63, 0, 10, 6, 54, 2, 60, 8, 49, 1, 18, 
    6, 19, 3, 92, 8, 16, 7, 43, 2, 60, 5, 57, 1, 84, 4, 99, 0, 87
  };
  const int q6278[] = {
    9, 9, // Number of jobs and machines
    0, 68, 3, 58, 4, 87, 7, 57, 1, 22, 6, 97, 8, 35, 5, 53, 2, 40, 
    3, 34, 7,  3, 1, 61, 0, 52, 6,  6, 4, 59, 5, 14, 2, 16, 8, 21, 
    4, 12, 5, 40, 6, 83, 8,  9, 2, 95, 3, 16, 7, 37, 1, 36, 0, 42, 
    7,  3, 2, 37, 8, 10, 0, 86, 4, 56, 3, 59, 5,  1, 6, 71, 1,  6, 
    3, 25, 7,  4, 5, 43, 0, 49, 1, 54, 6, 23, 8,  4, 2, 44, 4, 47, 
    1, 67, 8, 96, 6, 60, 4, 53, 7, 10, 3, 94, 2, 11, 5,  7, 0, 67, 
    4, 47, 5, 71, 8, 82, 0, 75, 6,  1, 1, 79, 2, 77, 3,  3, 7, 68, 
    3, 26, 2, 21, 1, 53, 7, 46, 4, 82, 6, 72, 0, 48, 8, 61, 5, 26, 
    2, 87, 4, 49, 8, 87, 1, 84, 6, 88, 5, 65, 7, 10, 3, 17, 0,  6
  };
  const int q6279[] = {
    9, 9, // Number of jobs and machines
    2, 67, 1, 11, 4, 11, 6, 25, 7, 85, 8, 56, 3, 93, 5, 64, 0, 27, 
    4, 74, 1,  6, 2, 86, 5, 67, 7, 16, 0, 92, 8, 40, 6,  5, 3, 94, 
    4, 45, 1, 93, 2, 99, 8, 90, 5,  6, 6, 61, 0, 26, 3,  6, 7,  4, 
    1, 22, 3, 93, 5, 17, 0, 62, 4, 81, 7, 57, 2, 82, 6,  6, 8, 90, 
    3, 34, 8, 24, 6, 42, 4, 19, 5, 22, 0, 75, 1, 90, 2, 26, 7, 64, 
    1, 41, 0, 12, 2, 35, 3, 39, 7, 55, 4, 41, 8, 64, 6, 35, 5, 81, 
    2, 76, 0, 24, 3,  2, 4, 47, 7, 60, 8, 95, 1, 33, 6, 60, 5, 35, 
    6, 82, 2, 97, 5, 64, 1,  3, 0, 51, 4, 24, 7,  2, 3, 10, 8, 37, 
    1, 57, 8, 68, 7,  6, 4, 16, 6, 13, 3, 89, 0, 20, 5, 91, 2, 65
  };
  const int q6280[] = {
    9, 9, // Number of jobs and machines
    3, 58, 1, 21, 6, 81, 5, 81, 0, 79, 2, 79, 7, 59, 4, 13, 8, 41, 
    6, 61, 5, 23, 8, 47, 7, 36, 1, 68, 2, 26, 4, 25, 0, 28, 3, 29, 
    2, 61, 0, 69, 4, 53, 8, 44, 7,  6, 6, 79, 1, 52, 5, 87, 3, 13, 
    8, 11, 4, 15, 2, 88, 3, 45, 6, 50, 7, 83, 5, 50, 1, 89, 0, 49, 
    0,  1, 4, 57, 1, 27, 7,  4, 5, 21, 3,  2, 8, 59, 6, 13, 2, 42, 
    2, 26, 1, 15, 5, 53, 4, 40, 8, 75, 7, 17, 0, 62, 6, 55, 3, 23, 
    2, 81, 7, 24, 5, 76, 8,  9, 0, 57, 4, 70, 6, 99, 3, 87, 1, 34, 
    3, 71, 1, 23, 8, 82, 0, 35, 2,  2, 5,  5, 4, 74, 6, 49, 7, 42, 
    5, 38, 7, 57, 3, 70, 1, 53, 4, 28, 8, 95, 0,  1, 2, 26, 6, 17
  };
  const int q6281[] = {
    9, 9, // Number of jobs and machines
    5, 19, 2, 82, 8, 75, 6, 44, 3,  1, 0, 89, 4, 68, 1, 65, 7, 53, 
    4,  7, 0, 12, 3, 56, 1, 33, 5, 23, 2, 30, 6, 19, 8, 25, 7, 54, 
    5, 96, 0, 42, 2, 65, 6, 40, 3, 77, 1, 37, 8, 40, 7, 64, 4, 67, 
    3, 48, 6, 72, 4, 63, 8,  8, 7, 77, 5, 76, 1, 92, 2, 99, 0, 48, 
    5, 35, 2, 13, 3, 12, 7, 84, 6, 70, 1, 69, 0, 81, 4, 96, 8, 88, 
    7, 37, 1, 93, 4, 36, 0, 33, 8, 28, 2,  4, 3, 19, 6, 91, 5, 88, 
    6, 67, 0, 98, 4, 18, 7, 96, 1, 86, 8, 34, 5, 22, 3, 90, 2, 38, 
    5, 59, 7, 94, 2, 92, 6, 93, 4, 80, 0, 62, 8, 20, 3, 52, 1, 76, 
    5, 22, 2, 68, 7, 10, 4, 28, 6, 97, 3, 59, 8, 19, 0,  6, 1,  6
  };
  const int q6282[] = {
    9, 9, // Number of jobs and machines
    2, 26, 7, 49, 8, 80, 4, 97, 6, 75, 1, 26, 5, 88, 0,  3, 3, 14, 
    7, 86, 6, 34, 2,  8, 3, 17, 1, 32, 8, 76, 4, 92, 0, 13, 5, 26, 
    0, 12, 7, 64, 6, 29, 2, 65, 4, 29, 1,  6, 8, 80, 3, 90, 5, 52, 
    7, 83, 4, 48, 1, 97, 8, 26, 0, 33, 6, 77, 2, 20, 3, 35, 5, 57, 
    7, 30, 6, 44, 0, 36, 1, 11, 8, 36, 2, 54, 5, 67, 4, 46, 3,  3, 
    0, 82, 7,  7, 2, 89, 1, 59, 4, 95, 6, 19, 3, 52, 5, 71, 8,  2, 
    1, 58, 0, 21, 4, 97, 5, 90, 3, 68, 6, 73, 8,  6, 2, 18, 7, 38, 
    7, 88, 6, 78, 5, 73, 4, 11, 8,  3, 0, 90, 2, 45, 3, 30, 1, 73, 
    7,  9, 2, 24, 3, 54, 1, 42, 8, 71, 4, 88, 0,  1, 5, 36, 6, 40
  };
  const int q6283[] = {
    9, 9, // Number of jobs and machines
    3, 86, 0, 96, 8, 66, 2, 72, 1, 67, 6, 78, 5, 42, 7, 43, 4, 29, 
    1, 91, 3, 61, 6, 53, 2, 49, 0, 81, 7, 71, 4, 14, 5, 47, 8, 18, 
    7, 72, 2, 89, 1, 24, 6, 35, 8, 96, 0, 29, 5, 68, 3, 36, 4, 11, 
    1, 51, 3, 10, 6, 34, 0, 89, 2,  1, 5, 52, 8, 39, 4, 39, 7, 51, 
    6, 60, 7, 51, 8, 78, 1, 65, 4,  7, 0, 69, 5, 24, 2, 13, 3, 52, 
    0, 97, 5, 77, 2, 25, 7, 20, 4, 49, 3, 92, 1, 17, 8, 72, 6, 12, 
    7, 45, 2, 44, 8, 16, 1, 28, 5, 28, 4, 53, 3, 41, 6, 28, 0, 75, 
    8, 16, 5, 79, 2, 13, 7, 14, 1, 44, 6, 23, 4, 58, 3,  9, 0, 73, 
    5, 94, 4, 99, 2, 46, 3, 62, 0, 49, 8, 68, 6, 84, 7, 68, 1, 86
  };
  const int q6284[] = {
    9, 9, // Number of jobs and machines
    1, 31, 5, 38, 0, 33, 4, 31, 8, 35, 3, 76, 7,  1, 6, 90, 2, 60, 
    0, 81, 2, 58, 3,  1, 1, 87, 6, 23, 7, 12, 4, 47, 5, 96, 8,  3, 
    5, 16, 7, 50, 4, 66, 6, 49, 2, 67, 3, 15, 1, 87, 0, 99, 8, 74, 
    3, 88, 6, 74, 2, 45, 7, 43, 8, 38, 5, 11, 0, 76, 1, 37, 4,  1, 
    1,  7, 3, 86, 6, 56, 5, 54, 2, 82, 7, 96, 8, 67, 0, 22, 4, 54, 
    7, 68, 2, 29, 0, 74, 6, 61, 5, 60, 3, 61, 1, 83, 4,  2, 8, 30, 
    1, 50, 7, 94, 5, 94, 2, 36, 3, 95, 0, 14, 8, 93, 6, 96, 4, 31, 
    3, 78, 2, 52, 1,  3, 6, 90, 0, 90, 8, 19, 5, 40, 4, 23, 7, 34, 
    0, 73, 5, 92, 1, 88, 4, 17, 6, 94, 7, 23, 8, 57, 2, 56, 3, 69
  };
  const int q6285[] = {
    9, 9, // Number of jobs and machines
    2, 67, 6, 40, 0, 54, 8,  5, 1, 97, 5, 37, 7, 54, 4, 98, 3, 45, 
    5, 80, 2, 33, 4, 81, 1, 15, 6, 50, 0,  4, 8, 13, 3, 11, 7,  8, 
    8, 15, 0, 12, 1, 67, 5, 21, 3, 61, 6, 92, 4, 27, 7, 31, 2,  6, 
    1, 92, 0, 83, 7, 47, 6, 97, 8, 47, 2, 89, 4, 70, 3, 26, 5, 32, 
    0, 17, 1, 14, 7, 72, 8, 98, 5, 65, 3, 89, 4, 91, 6, 31, 2, 84, 
    6, 98, 8, 25, 1, 51, 0, 77, 7, 25, 4, 39, 3, 73, 5, 31, 2, 77, 
    6, 62, 5,  5, 1, 93, 2, 56, 7, 10, 4, 19, 8, 35, 3, 58, 0, 76, 
    7, 61, 8, 65, 5,  8, 3,  2, 1, 94, 4, 58, 6,  7, 0, 49, 2, 27, 
    4,  4, 2, 59, 0, 93, 3, 72, 6, 86, 5, 16, 1, 20, 8,  8, 7, 20
  };
  const int q6286[] = {
    9, 9, // Number of jobs and machines
    0, 53, 8,  8, 3, 87, 7, 91, 2, 46, 1, 86, 5, 65, 4, 71, 6, 12, 
    6, 14, 5, 19, 1, 15, 2, 54, 3, 25, 0,  2, 4, 44, 7, 46, 8, 41, 
    3, 72, 6,  8, 0, 49, 5, 52, 1, 83, 8,  2, 7, 93, 4, 23, 2, 59, 
    4, 91, 3, 47, 8, 28, 5, 93, 2, 28, 0, 29, 7, 61, 6, 47, 1, 16, 
    3, 93, 7,  6, 6, 18, 8, 95, 4, 72, 2, 15, 0, 45, 1, 90, 5, 84, 
    3, 86, 4, 45, 1, 19, 0, 84, 2, 51, 8, 67, 6, 72, 7, 61, 5, 18, 
    0, 14, 5, 74, 4, 93, 2, 47, 8, 53, 6, 86, 3, 79, 7, 59, 1, 53, 
    7, 17, 4, 80, 1, 34, 2,  3, 8, 31, 0, 46, 3, 88, 6, 33, 5, 56, 
    6, 69, 2, 21, 7, 69, 0, 33, 3, 71, 8, 45, 4, 69, 1, 44, 5,  2
  };
  const int q6287[] = {
    9, 9, // Number of jobs and machines
    1, 15, 8, 15, 0,  6, 5, 93, 6, 57, 4,  7, 2,  1, 3, 75, 7, 83, 
    6, 74, 0, 62, 8, 21, 5, 38, 4, 34, 1, 71, 2, 91, 3, 10, 7, 98, 
    0,  4, 5, 18, 6, 84, 3, 38, 8, 41, 4, 32, 2, 19, 1, 66, 7, 20, 
    0, 66, 7, 54, 3, 64, 4, 75, 2, 88, 1, 29, 6, 56, 8, 82, 5, 59, 
    0, 79, 1, 29, 6,  3, 4, 40, 5, 83, 8, 54, 3, 89, 2,  1, 7, 50, 
    6, 70, 7, 68, 5, 98, 3, 51, 4, 56, 8, 23, 1, 14, 2,  8, 0, 61, 
    6, 39, 3, 31, 5, 37, 0, 48, 7, 84, 1,  9, 2, 31, 4, 20, 8, 18, 
    7, 43, 0, 24, 6, 51, 8,  8, 3, 84, 1, 35, 4, 90, 5, 15, 2, 64, 
    6, 76, 1, 24, 8, 14, 0, 21, 5, 59, 4,  1, 7, 87, 2, 54, 3, 58
  };
  const int q6288[] = {
    9, 9, // Number of jobs and machines
    7, 62, 4, 28, 8, 78, 6, 72, 3, 35, 0, 47, 1, 41, 2, 82, 5, 39, 
    5, 18, 4, 77, 1, 71, 7, 20, 3, 46, 6, 17, 2, 43, 0, 27, 8, 64, 
    2,  9, 8, 76, 3, 36, 1, 36, 0, 36, 6,  4, 4, 39, 5, 70, 7, 85, 
    5,  9, 4, 35, 7, 48, 3, 83, 0, 72, 8, 11, 6, 93, 1, 58, 2, 30, 
    1, 61, 4, 24, 0, 22, 8,  7, 5, 19, 7, 57, 6, 76, 2,  9, 3,  3, 
    0, 47, 5, 45, 2, 10, 7, 51, 6, 50, 3,  9, 1, 32, 4, 94, 8, 46, 
    3, 19, 5, 51, 4, 93, 7, 82, 0, 85, 8, 52, 2, 52, 1, 87, 6, 57, 
    7, 94, 2, 63, 0, 17, 1, 93, 6, 82, 5, 33, 3, 91, 8, 64, 4, 32, 
    4, 93, 5, 56, 2, 27, 1, 18, 8, 82, 6, 69, 0, 31, 7, 97, 3, 96
  };
  const int q6289[] = {
    9, 9, // Number of jobs and machines
    1, 23, 0, 58, 4, 95, 3,  4, 2, 66, 6, 44, 5, 63, 7, 86, 8, 31, 
    6, 99, 5, 54, 1, 45, 0, 28, 7, 42, 2, 80, 4, 84, 3, 19, 8, 57, 
    5, 40, 3, 35, 7, 31, 0, 56, 4, 32, 2, 49, 6, 35, 1, 15, 8, 72, 
    6, 25, 8, 89, 5,  2, 3, 65, 4, 86, 0,  6, 2, 74, 1, 38, 7, 15, 
    4, 30, 6, 85, 1, 42, 0, 25, 7, 77, 3, 49, 5, 82, 8, 59, 2, 18, 
    8, 57, 6, 43, 5,  8, 3, 72, 4, 79, 2, 19, 1, 33, 7, 27, 0, 43, 
    3, 36, 8, 91, 6, 29, 1, 68, 5,  6, 0, 30, 7, 94, 2, 43, 4, 90, 
    6, 96, 4, 45, 2, 34, 3,  7, 0, 29, 5, 35, 1,  2, 7, 17, 8, 17, 
    6, 85, 3, 97, 1, 51, 4, 14, 7, 94, 8,  3, 2, 45, 0, 73, 5, 55
  };
  const int q6290[] = {
    9, 9, // Number of jobs and machines
    7, 34, 6, 75, 4, 20, 1, 47, 3, 35, 0, 54, 8,  9, 5, 37, 2, 73, 
    3, 24, 5, 53, 8, 82, 0, 89, 1, 64, 7, 86, 6, 35, 2, 58, 4, 42, 
    2, 99, 0, 42, 8, 12, 3, 77, 1, 89, 7, 22, 5, 38, 6, 83, 4, 37, 
    6, 58, 0, 49, 1, 55, 2, 47, 3, 30, 4, 80, 8, 90, 5, 63, 7, 22, 
    6, 34, 7,  6, 5, 85, 4, 66, 8, 82, 1, 15, 3, 39, 2, 24, 0, 21, 
    2, 68, 1,  5, 0, 78, 6, 87, 5, 71, 3, 41, 4, 42, 8, 43, 7, 68, 
    5, 78, 2, 92, 8, 58, 6, 44, 1, 37, 7, 94, 0,  4, 3, 68, 4, 34, 
    8, 65, 5, 23, 2, 52, 3, 79, 4, 11, 6, 52, 1, 63, 7, 50, 0, 18, 
    0, 74, 5, 11, 1, 83, 8, 26, 2, 97, 3, 83, 6, 56, 4, 50, 7, 43
  };
  const int q6291[] = {
    9, 9, // Number of jobs and machines
    7, 72, 5, 95, 3, 99, 2, 94, 6, 93, 8,  5, 0,  9, 4, 42, 1, 13, 
    6, 29, 0, 58, 3, 52, 4, 39, 2, 26, 8, 62, 7, 70, 1, 65, 5, 60, 
    0,  2, 4,  5, 3, 91, 5, 55, 2, 58, 7, 15, 1, 42, 6, 16, 8, 24, 
    1, 20, 6, 24, 2, 88, 5, 88, 4, 86, 8, 60, 0, 91, 3, 39, 7, 53, 
    6, 73, 0, 72, 7, 33, 2, 91, 3, 48, 4, 11, 8, 32, 1, 66, 5, 34, 
    7, 32, 3, 19, 0, 43, 6, 16, 5, 69, 2,  1, 1, 46, 4, 16, 8, 48, 
    8, 49, 4, 29, 6, 10, 7, 78, 2, 54, 3,  6, 5, 98, 0, 70, 1, 94, 
    3, 81, 1, 86, 4,  3, 7, 24, 2, 90, 5, 41, 6, 53, 8,  7, 0, 82, 
    2, 62, 7, 83, 3, 69, 8, 84, 1, 43, 0, 69, 5, 29, 4, 16, 6, 22
  };
  const int q6292[] = {
    9, 9, // Number of jobs and machines
    8, 29, 2, 80, 5, 24, 6, 55, 0, 55, 7, 87, 4, 80, 3, 39, 1, 81, 
    6, 13, 2, 89, 4, 85, 3, 21, 1, 86, 0, 25, 8, 95, 5, 50, 7, 15, 
    4, 75, 3, 14, 8, 88, 0,  3, 7, 73, 5, 62, 1, 71, 2, 92, 6, 17, 
    5, 12, 1, 16, 7, 28, 3, 78, 0, 26, 6, 72, 4, 50, 2, 46, 8, 50, 
    0, 78, 7, 37, 4,  3, 2, 90, 6, 68, 5, 90, 8, 88, 3, 31, 1, 15, 
    8, 52, 3, 81, 7, 90, 0, 67, 1, 69, 2, 56, 6, 61, 4, 91, 5, 72, 
    7, 85, 5, 34, 0,  4, 6, 17, 2,  3, 1, 11, 8, 94, 3, 45, 4, 75, 
    5, 46, 2, 54, 8, 96, 1,  3, 6, 40, 7, 24, 0, 95, 4, 77, 3,  2, 
    4, 77, 7, 57, 3, 80, 1, 44, 5, 10, 0, 54, 6, 81, 8, 53, 2, 32
  };
  const int q6293[] = {
    9, 9, // Number of jobs and machines
    1, 48, 6, 63, 5, 22, 3, 67, 8, 89, 2, 66, 7, 77, 0, 73, 4, 66, 
    5,  7, 0,  2, 2, 17, 6, 51, 8, 85, 3, 37, 1, 51, 4, 94, 7, 89, 
    4,  7, 5, 43, 2, 48, 3, 41, 7, 24, 8, 67, 1, 27, 6, 46, 0, 17, 
    4, 54, 7, 76, 0, 81, 8, 38, 5, 79, 2,  2, 1, 46, 3, 76, 6, 42, 
    7, 75, 8, 48, 0, 78, 2, 74, 5, 19, 4, 24, 1, 98, 3, 41, 6, 59, 
    3, 61, 2, 63, 8, 31, 5, 17, 7, 92, 1, 12, 6, 65, 4, 85, 0,  1, 
    5, 56, 1, 83, 8, 97, 6, 78, 2, 25, 4, 88, 0, 81, 7, 78, 3,  2, 
    3, 49, 7, 54, 0, 24, 1,  6, 5, 64, 6, 61, 8, 85, 2, 68, 4, 26, 
    1,  8, 8, 47, 4, 82, 5, 64, 7,  6, 6, 85, 3, 23, 0, 52, 2,  8
  };
  const int q6294[] = {
    9, 9, // Number of jobs and machines
    5, 38, 0,  8, 7,  2, 8, 77, 2, 72, 1, 46, 4, 66, 6, 57, 3, 12, 
    5, 88, 6, 82, 7, 63, 2, 55, 4, 54, 8, 68, 1, 31, 0, 39, 3, 70, 
    3, 39, 8, 97, 5, 34, 1, 20, 0, 59, 4, 97, 7, 16, 6, 89, 2, 79, 
    2, 48, 5, 40, 0,  2, 4, 75, 7, 22, 1, 39, 8, 29, 3, 62, 6, 88, 
    7, 58, 6, 26, 8, 10, 3, 86, 5, 50, 2, 17, 4,  6, 0, 92, 1, 28, 
    4, 98, 2, 89, 7, 73, 5, 23, 8, 51, 6, 12, 0, 23, 1, 85, 3,  6, 
    2,  7, 0, 51, 1, 65, 4, 43, 8, 48, 7, 54, 5, 24, 6, 66, 3, 28, 
    0, 87, 5, 18, 4, 24, 7, 34, 3, 45, 2,  9, 6, 75, 1, 97, 8, 78, 
    1, 17, 3, 43, 8, 97, 0,  5, 2,  6, 5, 30, 6, 14, 7, 92, 4,  5
  };
  const int q6295[] = {
    9, 9, // Number of jobs and machines
    6, 72, 1, 73, 2, 89, 4, 56, 0, 61, 5, 40, 7,  5, 8, 90, 3, 79, 
    0, 66, 1,  8, 3, 63, 8, 72, 5, 67, 2, 36, 6, 82, 4,  1, 7, 13, 
    3, 63, 7, 72, 0,  4, 1, 18, 4, 21, 5, 60, 8, 49, 6, 12, 2, 27, 
    6, 21, 3, 36, 2, 41, 4, 36, 8, 66, 5, 33, 0, 64, 1, 80, 7, 37, 
    7, 59, 4, 28, 3, 66, 5, 76, 1, 35, 2,  3, 0, 50, 6, 28, 8, 38, 
    5, 77, 3,  8, 4, 38, 2, 36, 0, 40, 1, 52, 6, 61, 7, 13, 8,  4, 
    1, 68, 7, 50, 2, 17, 3, 25, 4,  9, 0, 61, 8, 82, 5, 75, 6, 91, 
    5, 72, 6, 92, 2, 78, 0, 50, 8, 97, 1, 47, 7, 84, 4, 81, 3, 40, 
    8, 74, 4, 51, 7, 51, 3, 81, 2, 52, 0, 15, 5, 33, 1, 68, 6, 43
  };
  const int q6296[] = {
    9, 9, // Number of jobs and machines
    3, 52, 6, 61, 5, 14, 1, 52, 4, 52, 7, 59, 8, 55, 0, 45, 2, 23, 
    3, 87, 0, 19, 4, 40, 7, 15, 2, 31, 5, 87, 1, 85, 8, 53, 6, 42, 
    3, 52, 5, 32, 4, 81, 0, 94, 2, 82, 8, 39, 7, 20, 6, 74, 1, 49, 
    4, 97, 5, 11, 6, 98, 1, 67, 3,  5, 2, 78, 0, 41, 8, 29, 7, 37, 
    1, 25, 0,  4, 5, 85, 2, 79, 6, 23, 7, 95, 3, 71, 8, 40, 4, 73, 
    3, 61, 6, 95, 4, 18, 2,  7, 1, 24, 7, 27, 5, 97, 0, 66, 8, 98, 
    5, 43, 2, 36, 7, 50, 4, 38, 1, 80, 0, 10, 3, 65, 6,  2, 8, 39, 
    5, 89, 0, 42, 7, 14, 6, 51, 1, 79, 3, 58, 4, 29, 2, 52, 8,  9, 
    3, 30, 6, 28, 1, 34, 7, 16, 4, 82, 5,  4, 2, 46, 0,  8, 8, 41
  };
  const int q6297[] = {
    9, 9, // Number of jobs and machines
    0, 15, 4, 74, 8, 56, 6, 86, 7, 55, 2,  6, 3, 12, 1, 48, 5, 68, 
    6, 22, 0, 20, 5, 95, 8, 44, 1, 28, 4, 91, 2, 86, 7, 78, 3, 29, 
    0, 10, 2, 50, 8, 21, 7, 78, 1, 28, 3, 37, 4, 95, 5, 20, 6, 75, 
    8,  8, 5, 37, 1, 95, 3, 56, 6, 21, 4, 89, 0, 45, 7, 62, 2, 61, 
    6, 98, 2, 72, 7, 25, 3, 54, 4, 41, 1, 17, 8, 56, 5, 64, 0, 10, 
    6, 79, 5, 19, 7, 51, 2, 98, 1, 45, 0, 31, 3, 53, 8, 21, 4, 33, 
    7,  8, 5, 17, 2, 26, 3, 70, 8, 20, 1, 15, 4, 91, 6, 11, 0, 99, 
    7, 51, 6,  3, 4, 53, 2, 72, 0, 82, 5, 33, 1, 22, 3,  7, 8, 19, 
    5, 35, 2, 39, 7, 40, 8, 34, 3, 51, 6, 97, 4, 98, 1, 62, 0, 77
  };
  const int q6298[] = {
    9, 9, // Number of jobs and machines
    4, 96, 7,  3, 5, 76, 6, 10, 3,  4, 1, 86, 8, 89, 2, 49, 0, 46, 
    4, 79, 7, 27, 5, 24, 6, 87, 0, 31, 2, 36, 3,  4, 1, 48, 8, 17, 
    4, 33, 5, 19, 7, 80, 6, 71, 8, 95, 1, 31, 3, 45, 2, 28, 0, 76, 
    8,  1, 7, 31, 5, 53, 3,  1, 4, 80, 1, 70, 2, 90, 6, 34, 0,  9, 
    8, 62, 7, 76, 3, 26, 5, 32, 6, 74, 4, 98, 0, 83, 1,  4, 2, 56, 
    5, 31, 4, 59, 8, 24, 0, 13, 1, 47, 2, 74, 3, 87, 6, 40, 7, 35, 
    2, 58, 6, 89, 7, 91, 3,  5, 8, 97, 0, 62, 5, 68, 1, 89, 4, 88, 
    6,  6, 1, 35, 5, 78, 3,  7, 8, 51, 2, 80, 4, 28, 0, 25, 7, 17, 
    4, 35, 0, 54, 1, 34, 6,  1, 7, 73, 3, 53, 8, 67, 5, 86, 2,  7
  };
  const int q6299[] = {
    9, 9, // Number of jobs and machines
    8, 98, 2, 34, 7, 46, 3, 70, 1, 43, 6, 28, 0,  8, 5, 50, 4, 84, 
    6, 31, 0, 63, 4, 81, 5, 76, 1, 28, 3, 41, 2, 19, 8, 45, 7, 96, 
    0, 11, 1, 18, 7, 47, 2,  5, 6, 84, 8, 86, 4, 83, 3, 98, 5, 87, 
    4, 40, 3, 66, 0, 76, 1, 56, 2, 57, 6, 78, 7, 82, 8, 51, 5, 83, 
    8, 70, 0, 98, 1, 77, 4, 82, 2, 89, 6, 53, 3, 60, 7, 88, 5, 43, 
    0, 71, 2, 16, 3, 40, 6, 17, 7, 60, 5, 56, 4, 67, 8, 96, 1,  3, 
    8, 12, 7,  1, 0, 43, 2, 30, 5, 96, 4, 30, 3, 69, 6, 43, 1, 46, 
    0, 43, 7, 21, 8, 71, 5,  5, 4, 17, 1, 98, 6, 20, 2, 90, 3, 93, 
    5, 52, 7,  8, 8,  9, 2, 51, 6, 22, 1, 32, 0, 37, 4, 61, 3, 61
  };
  const int q6300[] = {
    9, 9, // Number of jobs and machines
    0, 81, 1, 87, 5, 15, 8,  3, 7, 38, 3, 24, 4, 84, 6, 89, 2, 74, 
    6, 61, 0, 43, 4, 35, 8, 34, 1, 56, 7, 68, 5, 35, 2, 38, 3, 93, 
    2, 99, 6, 15, 5,  9, 4, 83, 7,  3, 8, 83, 0, 36, 1, 69, 3, 23, 
    4, 13, 1, 68, 0, 87, 6, 16, 7, 71, 2, 50, 8, 86, 3, 70, 5, 70, 
    6, 52, 0,  5, 8, 59, 5, 64, 2, 17, 4, 61, 1, 25, 3, 82, 7, 78, 
    2, 60, 3, 17, 4, 79, 8, 53, 7, 52, 0, 77, 6, 65, 1,  8, 5, 29, 
    1, 94, 5, 44, 4, 12, 8, 60, 7,  5, 6, 66, 2, 91, 3, 84, 0, 93, 
    3, 31, 5, 48, 2, 39, 8, 65, 6, 97, 4, 79, 0,  4, 7, 26, 1,  2, 
    3, 25, 6, 86, 0, 44, 2, 39, 1, 43, 4, 40, 8, 34, 7, 22, 5, 29
  };
  const int q6301[] = {
    9, 9, // Number of jobs and machines
    8, 40, 0, 76, 1, 46, 3, 24, 7, 66, 6, 79, 4, 58, 2, 58, 5, 28, 
    7, 70, 4, 34, 8, 34, 2, 77, 0,  5, 6, 91, 3, 24, 1, 60, 5,  3, 
    5,  6, 6, 11, 8, 39, 7, 59, 0, 24, 1, 65, 2, 51, 3, 35, 4, 98, 
    6, 82, 2, 65, 7, 17, 0, 75, 1, 96, 3, 57, 4, 27, 5, 17, 8, 52, 
    1, 83, 8, 66, 6, 43, 5, 83, 7,  8, 0, 31, 2, 70, 4, 27, 3, 62, 
    7, 18, 8, 33, 4, 36, 5, 99, 6, 20, 3, 42, 0, 96, 2, 62, 1, 11, 
    6, 24, 0, 82, 2, 39, 7, 15, 1, 57, 4, 65, 5, 63, 8, 19, 3, 74, 
    3, 11, 5, 66, 6, 97, 8,  4, 2, 25, 4, 48, 0, 14, 7, 29, 1, 62, 
    4, 45, 3, 17, 0, 87, 8, 81, 2, 64, 6, 74, 7, 32, 1, 24, 5, 35
  };
  const int q6302[] = {
    9, 9, // Number of jobs and machines
    1, 25, 7, 72, 8, 69, 5, 76, 0, 93, 2, 57, 3, 22, 4, 38, 6, 74, 
    3, 98, 2, 80, 0, 54, 1, 48, 6, 41, 8, 30, 7, 85, 5,  3, 4, 48, 
    8, 80, 5, 57, 3, 65, 6, 42, 0, 33, 4, 30, 2, 81, 1, 80, 7, 58, 
    1, 38, 0, 51, 6, 45, 7, 86, 2, 10, 3, 68, 5, 70, 8, 95, 4, 81, 
    5, 79, 4, 33, 0, 57, 2, 58, 7, 76, 3, 99, 6, 45, 1, 96, 8, 94, 
    7, 76, 4, 76, 1, 36, 2, 33, 0, 78, 5, 48, 3, 87, 8, 10, 6, 90, 
    4,  4, 5, 98, 6, 27, 2, 86, 7, 13, 1, 31, 3, 43, 8,  8, 0, 16, 
    2, 54, 7, 27, 4, 78, 3, 14, 8, 24, 6, 15, 1, 52, 0, 56, 5,  1, 
    3, 94, 6, 89, 4, 12, 8, 42, 7,  8, 0, 47, 1, 26, 5, 36, 2, 52
  };
  const int q6303[] = {
    9, 9, // Number of jobs and machines
    3, 44, 5, 37, 4, 15, 1, 66, 7, 51, 2, 91, 0, 43, 8, 12, 6, 20, 
    3, 13, 1,  9, 6, 23, 7, 20, 2, 39, 4, 12, 8, 29, 5, 76, 0, 18, 
    7, 90, 6, 16, 2, 67, 3, 39, 1, 46, 0, 51, 5, 99, 4, 84, 8, 30, 
    3, 26, 6, 70, 2, 92, 5, 33, 1, 61, 0, 55, 7,  1, 8, 78, 4, 32, 
    4, 59, 5, 24, 7, 54, 3, 85, 6, 60, 1,  1, 8, 97, 2, 93, 0,  5, 
    4, 83, 2, 70, 3,  7, 1, 23, 8, 90, 0, 80, 5, 85, 7, 66, 6, 62, 
    0,  8, 2, 73, 7, 62, 6, 60, 3, 18, 8, 93, 4, 76, 5, 36, 1, 53, 
    4, 78, 0, 78, 1, 39, 5, 86, 7, 27, 3, 85, 2, 95, 6, 14, 8, 62, 
    8, 16, 7, 70, 5, 92, 3, 59, 6, 57, 2, 81, 4, 48, 0, 23, 1, 58
  };
  const int q6304[] = {
    9, 9, // Number of jobs and machines
    6, 19, 3,  4, 4, 42, 5, 91, 7, 43, 1, 62, 8,  8, 2,  3, 0, 86, 
    0, 50, 5,  9, 4, 26, 8, 49, 3, 65, 1, 99, 7, 86, 2, 44, 6, 39, 
    8, 43, 1, 34, 3, 22, 6, 43, 5, 53, 2, 28, 4, 32, 0, 74, 7, 77, 
    0, 12, 5, 29, 2, 87, 7, 78, 1, 99, 4, 19, 8, 93, 6, 31, 3, 72, 
    4, 20, 0, 55, 5,  3, 2, 90, 6, 23, 3, 19, 1, 73, 8, 18, 7, 10, 
    8, 81, 3, 62, 2,  6, 5, 22, 6, 10, 1, 91, 0, 83, 4, 64, 7, 33, 
    8, 31, 5, 12, 6, 74, 7, 40, 1, 40, 2, 97, 0, 33, 4, 82, 3, 43, 
    0, 68, 2, 81, 6,  3, 8, 98, 7, 47, 1, 49, 5, 88, 4, 97, 3, 34, 
    1, 27, 7, 98, 6, 62, 0, 90, 4, 89, 3,  6, 5,  6, 8, 41, 2, 28
  };
  const int q6305[] = {
    9, 9, // Number of jobs and machines
    3, 84, 1, 23, 7, 46, 6, 42, 8, 30, 0, 94, 4, 57, 5, 94, 2,  3, 
    1, 61, 2, 19, 5, 24, 4, 96, 8, 69, 0, 37, 6, 90, 7, 81, 3, 66, 
    6, 78, 0, 13, 4, 16, 5, 92, 1, 44, 8, 60, 3, 70, 7, 77, 2, 15, 
    3, 41, 1, 69, 2, 31, 8, 18, 6, 67, 4, 30, 0, 71, 5, 54, 7, 19, 
    7, 97, 8, 77, 3, 89, 0,  9, 5, 72, 1, 52, 6, 47, 4, 42, 2, 36, 
    7, 10, 4, 80, 0, 69, 5, 25, 8, 38, 2, 20, 3, 57, 1,  3, 6, 81, 
    8, 83, 2, 61, 0, 58, 7, 29, 3, 54, 6, 91, 5, 23, 4, 27, 1, 57, 
    8, 88, 6, 98, 3, 90, 7, 71, 4, 75, 1, 93, 2, 31, 0, 99, 5, 79, 
    8, 78, 7, 92, 3,  4, 0, 98, 5, 86, 6, 90, 2,  5, 4, 75, 1, 73
  };
  const int q6306[] = {
    9, 9, // Number of jobs and machines
    4, 81, 7, 87, 3, 88, 6,  1, 2,  6, 8, 68, 5, 35, 0, 91, 1, 30, 
    1, 36, 8, 37, 3, 81, 4, 44, 2, 44, 7, 11, 0,  7, 5,  4, 6, 44, 
    1, 83, 3, 94, 8, 55, 6, 95, 0, 71, 4, 48, 2, 65, 7,  7, 5, 53, 
    5, 16, 4, 61, 0, 72, 2, 90, 8, 37, 6,  5, 3, 82, 1, 30, 7,  1, 
    0, 15, 2, 22, 5, 76, 4, 14, 7, 25, 3, 16, 8,  1, 1, 16, 6, 15, 
    7, 18, 0, 65, 6, 69, 1, 84, 2, 23, 4, 49, 5, 41, 8, 50, 3, 51, 
    1, 91, 3, 52, 4, 37, 0, 68, 6, 75, 8, 46, 5, 98, 7, 66, 2, 45, 
    0, 49, 5, 36, 1,  2, 8, 73, 4,  1, 7, 13, 3, 53, 6, 68, 2, 30, 
    5, 31, 8, 38, 2, 37, 0, 58, 7, 78, 4, 10, 6, 53, 3,  5, 1, 25
  };
  const int q6307[] = {
    9, 9, // Number of jobs and machines
    8,  5, 7, 40, 0, 79, 1, 13, 4, 16, 5, 56, 2, 56, 6, 14, 3, 11, 
    2, 92, 7, 65, 3, 60, 1, 85, 4, 81, 8,  6, 5, 75, 0, 95, 6,  6, 
    5, 88, 1, 39, 7, 17, 0, 67, 2, 60, 3,  3, 4,  5, 8, 75, 6, 73, 
    6, 96, 2,  3, 3, 29, 1, 78, 5, 28, 7,  3, 8, 67, 4, 74, 0, 61, 
    6, 56, 0, 58, 3, 35, 4,  6, 5, 31, 8, 85, 7, 29, 2, 92, 1, 47, 
    1, 44, 4, 35, 2, 38, 5, 90, 8, 47, 6, 14, 0, 46, 3, 57, 7, 18, 
    3, 85, 5,  5, 7, 62, 0, 46, 4,  3, 1,  3, 6, 11, 2, 22, 8, 95, 
    3, 58, 8,  4, 5, 99, 1, 65, 4, 27, 0, 60, 6, 29, 7,  3, 2, 32, 
    5, 33, 2, 70, 3, 82, 0, 64, 4, 16, 1, 10, 8, 86, 7, 83, 6, 99
  };
  const int q6308[] = {
    9, 9, // Number of jobs and machines
    4, 42, 7, 94, 6, 61, 0, 36, 5,  7, 1, 23, 3, 29, 8, 46, 2, 91, 
    1, 77, 5, 64, 2, 95, 3, 78, 8, 22, 7, 15, 6, 26, 4, 46, 0, 49, 
    7, 38, 4, 92, 1, 90, 5, 27, 0, 83, 6, 42, 3, 94, 8, 59, 2, 17, 
    8,  5, 1, 90, 7, 50, 5, 77, 3, 23, 0, 62, 6, 91, 2, 51, 4, 91, 
    4, 83, 5, 71, 6, 97, 8, 25, 0,  7, 2,  8, 1, 56, 7, 43, 3, 90, 
    0, 66, 6, 78, 8, 21, 2, 54, 1, 70, 3, 19, 4, 49, 7, 28, 5, 33, 
    3, 53, 2, 84, 8, 85, 0,  8, 4, 37, 6, 89, 1, 89, 7, 59, 5, 37, 
    2, 60, 6, 95, 8, 31, 7, 97, 0, 71, 3, 91, 5, 10, 4, 83, 1, 53, 
    3, 88, 1, 16, 6, 47, 0, 84, 4, 26, 8, 51, 5, 97, 2, 39, 7, 13
  };
  const int q6309[] = {
    9, 9, // Number of jobs and machines
    1, 38, 6, 98, 7, 21, 8, 23, 0, 71, 3, 36, 4,  4, 2, 49, 5, 50, 
    4, 55, 6, 99, 3, 70, 2, 71, 0, 32, 8, 46, 1, 83, 7, 12, 5, 37, 
    7,  8, 0, 52, 6, 16, 1, 43, 2,  2, 8, 68, 3, 43, 5, 28, 4,  1, 
    7, 11, 1, 77, 0, 90, 5, 84, 6, 45, 4, 39, 2, 99, 3, 18, 8, 90, 
    8, 77, 6, 86, 5, 72, 7, 65, 2, 52, 1, 71, 0,  3, 3, 79, 4, 30, 
    5,  2, 7,  2, 2, 51, 8, 48, 3, 96, 0, 87, 6,  3, 4, 66, 1, 28, 
    6, 18, 7, 33, 3, 24, 1, 51, 4, 36, 2, 84, 0, 67, 8, 68, 5, 78, 
    4, 21, 2, 94, 6, 11, 5, 66, 1, 60, 0, 45, 7, 94, 3, 91, 8,  1, 
    3, 35, 1, 60, 8, 21, 0, 54, 7, 94, 2, 96, 5, 16, 6, 58, 4, 24
  };
  const int q6310[] = {
    9, 9, // Number of jobs and machines
    6, 97, 3, 87, 1, 90, 7, 17, 8, 34, 2, 76, 0, 60, 4, 14, 5, 45, 
    8, 75, 3, 29, 0, 25, 1, 39, 2,  3, 5,  4, 6, 11, 7, 72, 4, 12, 
    1, 84, 4, 55, 5, 21, 8, 54, 0, 31, 6, 41, 7, 72, 2, 46, 3, 50, 
    4, 82, 0, 25, 1, 89, 8, 12, 7, 21, 6, 54, 5, 30, 3, 55, 2, 82, 
    1, 27, 7, 90, 4, 29, 8, 57, 6,  2, 3, 20, 2, 20, 5, 73, 0, 33, 
    6, 51, 2, 93, 4, 36, 7, 48, 8, 76, 1, 54, 5, 67, 3, 57, 0, 22, 
    2, 25, 7, 70, 1, 44, 8, 60, 5, 18, 3, 49, 4, 27, 0,  3, 6, 97, 
    8, 69, 4, 70, 6, 60, 0, 54, 1, 85, 5, 83, 7, 30, 3, 14, 2, 39, 
    1, 96, 5, 34, 0, 17, 8, 86, 6, 74, 2, 45, 4, 80, 3, 97, 7, 73
  };
  const int q6311[] = {
    9, 9, // Number of jobs and machines
    6, 18, 2, 99, 7, 57, 8,  7, 3, 51, 1, 15, 0, 40, 5, 10, 4, 81, 
    1, 32, 3, 87, 7, 82, 0, 15, 8, 56, 6, 81, 4, 18, 2, 84, 5,  8, 
    2, 68, 7, 62, 8, 77, 3,  7, 5, 45, 1,  1, 0, 69, 6, 22, 4, 91, 
    6, 68, 7,  8, 1, 78, 0, 49, 4, 85, 3, 63, 8, 23, 5, 96, 2, 83, 
    0,  8, 4, 76, 1,  2, 5, 75, 8, 91, 2,  9, 6, 19, 3, 38, 7, 93, 
    8, 65, 6, 22, 1, 30, 4, 76, 3, 18, 7, 60, 0, 87, 2, 17, 5, 89, 
    7, 27, 1, 75, 6, 23, 2, 23, 0, 75, 5, 81, 3, 50, 4, 79, 8, 20, 
    7, 80, 6, 25, 3, 53, 4, 21, 5, 19, 1, 69, 2, 83, 0, 33, 8, 57, 
    4, 73, 0, 59, 2, 78, 7, 24, 3, 12, 6, 39, 8, 14, 5, 55, 1, 42
  };
  const int q6312[] = {
    9, 9, // Number of jobs and machines
    5, 52, 8, 10, 3, 62, 0, 81, 6, 26, 7,  7, 4, 33, 1, 19, 2, 89, 
    0, 79, 4, 20, 2, 94, 7, 92, 3, 57, 5, 91, 8,  6, 6, 79, 1, 53, 
    5, 59, 2,  2, 0, 80, 4,  6, 1, 14, 7, 66, 6, 73, 3, 73, 8, 40, 
    3, 55, 5, 80, 8, 88, 4, 69, 6, 16, 7, 60, 1, 93, 2, 82, 0, 21, 
    8, 23, 4, 29, 2, 90, 1, 97, 7, 44, 3, 25, 0, 59, 6, 14, 5, 35, 
    5, 43, 2, 68, 0, 93, 6, 53, 8, 74, 1, 78, 4, 95, 3, 22, 7, 56, 
    0, 53, 1, 88, 4, 43, 7, 63, 3, 40, 6, 95, 8, 87, 5, 90, 2, 30, 
    2, 46, 8, 75, 0, 88, 6, 29, 5, 28, 4,  3, 1, 82, 7,  5, 3, 97, 
    7, 88, 5, 30, 3, 95, 6, 30, 8, 99, 0, 30, 4, 74, 2, 13, 1, 61
  };
  const int q6313[] = {
    9, 9, // Number of jobs and machines
    8, 11, 5, 36, 4, 48, 2, 36, 0, 79, 3, 68, 7, 50, 6, 48, 1, 69, 
    1, 27, 4, 44, 8, 90, 5, 41, 3, 41, 2, 27, 7, 24, 6, 14, 0, 97, 
    4, 30, 2, 88, 6, 54, 5, 42, 7, 11, 0, 19, 8, 90, 3, 40, 1, 33, 
    5, 22, 4, 37, 7, 95, 0, 10, 1, 55, 3, 96, 8, 58, 2, 70, 6, 60, 
    4,  4, 0, 24, 2, 96, 6, 42, 8, 34, 5,  5, 1, 75, 3, 55, 7, 13, 
    3, 77, 7,  3, 8, 19, 5, 69, 6, 68, 0,  6, 4, 53, 1, 43, 2, 78, 
    4, 89, 2, 48, 1, 72, 8, 83, 5, 61, 6, 75, 3, 62, 0, 41, 7, 69, 
    0, 74, 4, 95, 1, 91, 5, 72, 7, 36, 6, 61, 3, 88, 2, 29, 8,  5, 
    2, 94, 3, 10, 0, 68, 5, 50, 6, 97, 8, 16, 7, 10, 4, 41, 1, 78
  };
  const int q6314[] = {
    9, 9, // Number of jobs and machines
    2,  4, 8,  7, 4, 89, 1, 42, 3, 53, 0, 22, 7, 51, 6, 34, 5, 80, 
    2, 68, 0, 44, 3, 78, 8,  2, 7, 55, 6, 58, 5, 52, 4, 58, 1, 69, 
    4, 79, 7,  7, 1, 61, 0, 79, 8, 57, 3, 20, 2, 73, 5, 23, 6,  1, 
    3, 18, 4,  9, 0, 78, 2, 59, 5, 53, 7, 67, 6, 72, 8, 27, 1, 74, 
    8, 21, 4, 77, 0, 22, 2, 26, 7, 62, 3, 99, 6, 31, 1, 94, 5, 31, 
    2, 61, 8, 44, 1, 83, 7, 26, 6, 51, 5, 34, 4, 13, 0, 87, 3, 11, 
    6,  8, 0, 75, 4, 26, 8, 65, 2, 36, 1, 13, 3, 82, 5, 23, 7, 64, 
    4, 39, 3, 35, 0, 12, 7, 31, 5,  4, 1, 68, 8, 70, 6, 85, 2, 31, 
    4, 55, 1, 66, 8, 98, 0, 19, 3, 76, 5, 73, 6, 71, 7, 24, 2, 13
  };
  const int q6315[] = {
    9, 9, // Number of jobs and machines
    0, 65, 6, 68, 5, 22, 4, 69, 8, 20, 2, 10, 7, 72, 1, 55, 3, 24, 
    0, 48, 8, 25, 7, 73, 5, 32, 2, 28, 6,  3, 1, 38, 3, 25, 4, 72, 
    4, 69, 3, 18, 5, 91, 8, 24, 0, 57, 2, 77, 1, 41, 6, 26, 7, 35, 
    1, 19, 8, 53, 2,  3, 5, 66, 0, 25, 7, 14, 4, 73, 6, 25, 3, 30, 
    3,  4, 8, 74, 1, 80, 0, 93, 4, 45, 5, 69, 7, 80, 2, 60, 6, 60, 
    0, 34, 3, 89, 1, 89, 2, 55, 7, 82, 6, 63, 8, 15, 4, 46, 5, 91, 
    5, 76, 4, 55, 0, 83, 1,  1, 6, 30, 3, 57, 7, 13, 2, 38, 8, 24, 
    4, 84, 8, 58, 1, 40, 0, 22, 3, 75, 2,  1, 5,  4, 6, 11, 7, 52, 
    0, 74, 6, 10, 4, 50, 3, 87, 7, 45, 5, 43, 2, 84, 1, 87, 8, 95
  };
  const int q6316[] = {
    9, 9, // Number of jobs and machines
    8, 19, 4, 99, 0, 56, 1, 13, 3, 50, 7, 98, 5, 49, 2, 46, 6, 90, 
    1, 89, 6, 31, 7, 43, 4,  2, 3,  9, 0, 74, 2, 22, 8, 48, 5, 70, 
    3, 73, 1, 76, 6, 13, 4, 50, 0, 74, 2, 92, 7, 33, 8, 92, 5, 71, 
    0, 12, 8, 56, 4, 64, 5, 93, 7, 42, 1, 47, 2,  8, 6, 64, 3,  1, 
    5,  9, 0, 47, 6, 84, 1, 22, 4, 50, 7, 44, 2, 96, 3, 80, 8, 75, 
    7, 84, 8, 15, 5, 74, 3, 95, 0, 65, 2, 87, 1, 70, 6, 32, 4, 82, 
    3, 36, 8, 46, 1, 66, 4, 21, 6, 96, 0, 14, 5, 58, 7,  6, 2, 53, 
    4, 26, 0,  1, 1, 29, 2, 35, 7, 31, 8, 72, 6, 83, 3, 18, 5, 44, 
    3, 45, 5, 56, 1, 13, 7, 55, 4, 14, 6, 29, 2, 33, 8, 20, 0, 33
  };
  const int q6317[] = {
    9, 9, // Number of jobs and machines
    0, 57, 1, 30, 4, 96, 2, 85, 5, 30, 3, 24, 8, 66, 7, 69, 6,  8, 
    8, 41, 4, 81, 7,  3, 2, 14, 3, 80, 0, 61, 6, 81, 1, 86, 5, 14, 
    3, 93, 2, 73, 0, 49, 8, 16, 6, 22, 1, 44, 5, 54, 4, 73, 7, 89, 
    8,  4, 1, 50, 6, 35, 3, 24, 4, 29, 0, 62, 7, 56, 2, 42, 5, 26, 
    5, 48, 6, 59, 1, 77, 3, 19, 2, 50, 7, 77, 0, 18, 8, 30, 4, 76, 
    8, 90, 4, 16, 3, 80, 7, 11, 6, 58, 0, 37, 5, 55, 2, 57, 1, 20, 
    0, 18, 2,  1, 6, 36, 5, 60, 3, 39, 7, 96, 1, 55, 8, 70, 4, 27, 
    2, 66, 3, 18, 8, 19, 5, 99, 4, 60, 7, 49, 1, 39, 6,  4, 0, 52, 
    2, 16, 5, 10, 0, 83, 1,  3, 6, 21, 3,  5, 7, 74, 8, 72, 4, 79
  };
  const int q6318[] = {
    9, 9, // Number of jobs and machines
    4, 92, 0, 99, 2, 98, 5, 75, 1, 38, 3, 85, 7, 72, 6, 15, 8, 75, 
    5, 29, 2, 57, 1, 25, 0, 34, 6, 85, 4, 55, 7, 72, 8,  9, 3, 32, 
    1, 26, 7, 12, 0, 90, 8,  4, 2, 37, 6, 15, 3,  8, 5, 25, 4, 78, 
    5, 24, 4, 18, 8,  9, 2, 72, 0, 91, 1, 89, 7, 58, 3, 77, 6, 12, 
    1, 38, 7, 47, 6, 94, 8, 69, 0, 13, 4, 29, 5, 33, 3, 53, 2, 13, 
    5, 61, 1,  6, 2, 69, 3, 35, 8, 11, 6, 90, 4, 46, 0, 13, 7, 73, 
    3, 40, 8, 35, 4, 23, 5, 94, 2, 40, 7,  5, 6, 76, 0, 23, 1, 17, 
    2, 11, 6, 21, 1, 67, 5, 24, 7, 89, 8, 31, 4, 10, 0, 12, 3, 48, 
    1, 60, 3, 94, 2, 19, 0, 31, 7, 86, 4,  9, 5, 33, 8, 78, 6, 41
  };
  const int q6319[] = {
    9, 9, // Number of jobs and machines
    6, 15, 3, 88, 7, 26, 4, 38, 2, 36, 0, 99, 5, 59, 8, 68, 1, 16, 
    4, 24, 2, 65, 8, 65, 7, 46, 5, 15, 3, 74, 0, 82, 6, 73, 1, 25, 
    3, 18, 1,  1, 8, 34, 0, 58, 2, 67, 7, 42, 4, 25, 5,  7, 6, 47, 
    6, 22, 1, 35, 8, 50, 2, 80, 0,  7, 5, 55, 3, 46, 4, 54, 7, 55, 
    6, 51, 5, 60, 0, 87, 1, 24, 2, 39, 8, 33, 7, 52, 4, 46, 3, 94, 
    6, 69, 2, 26, 5, 83, 4, 34, 3, 60, 7, 63, 1, 56, 8, 22, 0, 53, 
    4, 40, 0, 60, 1, 16, 3, 53, 7, 68, 5, 92, 6, 48, 8, 21, 2, 83, 
    7, 49, 8, 82, 4, 22, 1, 92, 2,  3, 5, 94, 6, 16, 0, 88, 3, 28, 
    7, 93, 1, 13, 6, 21, 4, 40, 0,  2, 8, 38, 5, 51, 2, 90, 3, 81
  };
  const int q6320[] = {
    9, 9, // Number of jobs and machines
    8, 17, 3, 39, 7, 49, 6, 64, 4, 92, 0,  2, 1,  5, 5, 60, 2, 63, 
    0,  2, 1, 15, 8, 11, 6, 70, 7, 67, 4, 58, 3, 96, 5, 95, 2, 39, 
    1, 21, 8,  9, 0, 37, 4, 73, 6, 11, 2,  3, 7, 19, 3, 53, 5, 66, 
    7, 64, 1, 76, 2, 65, 8, 13, 4, 51, 3, 73, 6, 69, 0, 81, 5, 22, 
    2, 23, 1,  9, 4, 44, 3, 42, 6, 24, 7, 66, 8,  1, 0, 54, 5, 45, 
    4, 56, 5, 20, 0, 62, 8, 13, 7, 13, 1,  3, 3, 46, 2, 12, 6, 66, 
    6, 63, 0, 64, 7, 40, 2, 46, 4, 41, 5, 87, 8, 87, 1, 37, 3, 65, 
    3, 71, 0, 60, 7, 61, 6, 77, 1, 38, 4, 52, 8,  8, 5,  8, 2, 34, 
    6, 51, 2, 52, 1, 97, 4, 53, 5, 65, 3, 96, 0, 34, 7, 16, 8, 14
  };
  const int q6321[] = {
    9, 9, // Number of jobs and machines
    4, 95, 3, 93, 7, 50, 5, 83, 8, 89, 0, 61, 6, 73, 1, 54, 2, 42, 
    6, 44, 7, 62, 3, 89, 1, 57, 2, 24, 4, 17, 8, 33, 5, 74, 0, 80, 
    4, 97, 3, 14, 0, 21, 8, 46, 7, 79, 6, 20, 5, 51, 2, 77, 1, 39, 
    5, 70, 7, 30, 6, 44, 3, 30, 1, 65, 4, 63, 8, 97, 0,  6, 2, 45, 
    6, 14, 8, 86, 1, 16, 5, 41, 7, 40, 0, 71, 4, 77, 3, 35, 2, 54, 
    1,  3, 0, 94, 3, 76, 7, 58, 6, 54, 4, 62, 8, 33, 2, 80, 5,  5, 
    5, 12, 0, 40, 1, 84, 3, 12, 2, 46, 6, 68, 8, 40, 7,  5, 4, 71, 
    3, 35, 1, 15, 0, 33, 6,  1, 8, 85, 7,  9, 4, 65, 5, 37, 2, 96, 
    4, 71, 0, 69, 5,  9, 1, 37, 3, 11, 6, 66, 2, 14, 7, 60, 8, 40
  };
  const int q6322[] = {
    9, 9, // Number of jobs and machines
    4, 83, 1, 25, 7, 25, 2, 85, 8, 50, 6,  7, 5, 59, 3, 89, 0, 82, 
    5,  7, 6, 23, 2, 52, 0, 56, 4, 70, 1, 16, 8, 58, 3, 18, 7, 97, 
    8, 58, 1, 39, 6,  9, 5, 21, 3, 32, 7, 97, 2, 71, 0, 35, 4, 71, 
    4, 46, 7, 42, 5, 19, 1, 91, 2, 16, 0, 46, 6, 69, 3, 57, 8, 48, 
    3, 27, 1,  5, 4, 31, 0, 70, 7, 29, 2, 19, 8, 85, 6, 42, 5, 74, 
    1,  2, 3, 83, 8,  3, 0, 57, 6,  6, 2, 44, 5, 33, 4,  5, 7, 55, 
    1, 86, 8,  3, 0, 36, 6, 43, 4, 66, 7, 89, 3, 99, 5, 90, 2, 96, 
    1, 67, 8, 92, 2, 33, 7, 92, 0, 28, 6, 69, 3, 24, 5, 38, 4, 36, 
    2, 98, 3, 36, 6, 40, 0, 77, 4, 35, 8, 39, 1, 71, 7, 76, 5, 90
  };
  const int q6323[] = {
    9, 9, // Number of jobs and machines
    4, 21, 7, 40, 8, 35, 5, 42, 0,  4, 3, 52, 2, 14, 6, 39, 1, 69, 
    8, 97, 2, 68, 0, 36, 1, 41, 6, 57, 7, 81, 3, 48, 4,  6, 5, 65, 
    1, 60, 6, 18, 3, 79, 4, 32, 7, 69, 0,  6, 8,  1, 5, 25, 2, 93, 
    0, 76, 7, 49, 2, 96, 3, 59, 8, 58, 4, 97, 5, 76, 1, 79, 6, 20, 
    4, 85, 3,  1, 2, 15, 6, 81, 8, 64, 7, 71, 5, 75, 0, 67, 1,  6, 
    7, 19, 2, 78, 3, 72, 4, 20, 8, 62, 0, 50, 5, 90, 1,  4, 6, 21, 
    0, 54, 6, 14, 5, 61, 8, 11, 1, 33, 7, 51, 4,  7, 2, 29, 3, 14, 
    4, 72, 7, 53, 0, 73, 3, 60, 5, 93, 6, 49, 1, 20, 2, 88, 8, 91, 
    8, 93, 7, 74, 4, 48, 3, 47, 5, 82, 0, 47, 2, 45, 6, 49, 1, 97
  };
  const int q6324[] = {
    9, 9, // Number of jobs and machines
    5, 98, 7, 45, 1, 61, 8, 44, 0, 35, 3, 52, 2, 61, 4, 32, 6, 14, 
    4, 56, 6, 24, 8,  4, 5, 69, 3, 24, 0, 39, 1, 21, 2, 78, 7, 69, 
    5, 18, 8, 40, 2, 54, 1, 76, 3, 96, 7, 93, 6, 34, 4, 76, 0, 26, 
    5, 60, 7, 95, 1, 29, 6,  6, 2, 85, 8, 22, 4, 19, 0, 23, 3,  8, 
    3, 87, 0, 55, 8, 60, 6, 59, 5, 43, 7, 17, 2, 15, 1, 19, 4,  5, 
    7, 44, 8, 17, 0, 11, 2, 33, 1, 84, 5, 15, 3, 13, 4, 88, 6, 72, 
    7, 91, 1, 95, 0,  5, 8, 88, 2, 93, 3, 77, 4, 51, 6, 68, 5,  6, 
    8, 11, 6, 24, 4, 10, 1, 59, 2, 86, 0, 35, 3, 52, 5, 25, 7, 36, 
    1, 67, 0, 18, 7, 39, 6, 45, 8, 69, 4,  8, 3, 20, 5,  5, 2, 59
  };
  const int q6325[] = {
    9, 9, // Number of jobs and machines
    3, 15, 1, 98, 7, 52, 6, 79, 0, 57, 8, 28, 4,  5, 2, 18, 5, 51, 
    0, 98, 4, 59, 1, 31, 8, 63, 3, 71, 7, 84, 6, 75, 2, 81, 5, 47, 
    7, 75, 3, 42, 8,  7, 0, 33, 5, 78, 4,  8, 2, 19, 6, 78, 1,  3, 
    8, 67, 3, 81, 0,  4, 7, 18, 2, 77, 1, 90, 5, 95, 4, 29, 6, 44, 
    3, 52, 8, 10, 4, 22, 0, 40, 5, 29, 1, 69, 2, 79, 7, 63, 6, 82, 
    0, 41, 8,  1, 1, 41, 4, 70, 7, 66, 5, 24, 3, 43, 2, 24, 6, 65, 
    4, 65, 2, 24, 5, 98, 6, 49, 1,  1, 0, 47, 3, 72, 8, 88, 7, 39, 
    6, 43, 1, 43, 7, 58, 8, 30, 2, 14, 0, 28, 3, 71, 5, 42, 4, 78, 
    1, 82, 8,  3, 5, 31, 4, 70, 0, 15, 3, 31, 7, 75, 2, 86, 6, 76
  };
  const int q6326[] = {
    9, 9, // Number of jobs and machines
    2, 11, 7, 81, 0,  8, 1, 43, 8, 96, 3, 71, 4, 65, 5, 54, 6, 82, 
    0, 57, 2, 96, 8, 39, 5, 73, 7, 27, 1,  3, 4,  6, 6, 85, 3, 46, 
    1, 40, 4, 14, 0, 25, 8, 51, 6, 97, 2, 49, 3, 14, 7, 36, 5,  8, 
    1, 22, 4, 92, 7, 75, 0, 65, 3, 99, 6, 42, 8, 74, 5, 90, 2, 32, 
    1, 21, 8, 95, 6,  4, 7, 95, 5, 64, 2, 72, 3, 17, 0, 60, 4, 49, 
    5, 26, 7, 29, 8, 61, 2, 34, 4, 54, 3, 46, 6, 16, 1, 35, 0,  9, 
    3, 76, 7, 68, 6, 73, 4, 99, 5, 93, 1, 14, 0, 37, 2, 95, 8, 25, 
    7, 66, 8, 73, 6, 51, 0, 28, 2, 76, 1, 87, 4, 93, 3, 20, 5, 40, 
    7, 10, 1, 24, 4, 95, 0, 48, 5, 10, 8, 59, 6, 30, 2,  2, 3, 81
  };
  const int q6327[] = {
    9, 9, // Number of jobs and machines
    0, 48, 4, 78, 3, 44, 8, 82, 1, 22, 5, 20, 2, 40, 6, 71, 7, 30, 
    5, 15, 0, 98, 7, 93, 8,  5, 3, 91, 6,  6, 1, 43, 4, 38, 2, 27, 
    7, 87, 4, 74, 1,  8, 8, 69, 0, 14, 6, 63, 2, 78, 5, 40, 3,  2, 
    2, 56, 1, 11, 7, 66, 3, 38, 6,  1, 5, 69, 8, 14, 4,  8, 0,  4, 
    4, 57, 2, 69, 7, 12, 1, 45, 8, 14, 3, 75, 6, 19, 0, 45, 5, 45, 
    4, 56, 5, 82, 6, 25, 1, 67, 2, 44, 3, 91, 8, 40, 0, 78, 7, 50, 
    6, 41, 5, 10, 7, 32, 2, 49, 1, 90, 0,  2, 4, 90, 3, 77, 8, 44, 
    6, 74, 3, 50, 2, 59, 1, 90, 0, 48, 8, 21, 5, 33, 4, 38, 7, 85, 
    3, 14, 4,  4, 0, 96, 8, 23, 2, 54, 1, 38, 6,  7, 7, 94, 5, 98
  };
  const int q6328[] = {
    9, 9, // Number of jobs and machines
    5, 54, 1, 44, 6, 85, 0, 82, 3, 97, 7, 44, 2, 42, 8, 78, 4, 48, 
    5, 59, 0, 64, 3,  1, 8, 91, 1,  7, 6, 40, 2, 87, 7, 64, 4, 54, 
    0, 40, 2, 82, 3, 75, 1, 33, 7, 63, 4, 37, 5, 81, 6, 36, 8, 65, 
    0, 15, 5, 32, 7, 32, 2, 18, 8,  7, 4, 17, 3, 48, 1, 52, 6, 39, 
    7, 64, 0, 26, 6, 74, 3, 41, 8,  3, 4, 11, 1,  3, 2, 63, 5, 79, 
    3, 93, 5, 65, 4, 71, 1, 46, 6, 74, 2, 91, 8, 72, 0, 85, 7, 82, 
    0, 27, 1,  2, 2,  6, 3, 26, 6, 99, 8, 80, 4, 11, 7, 70, 5, 95, 
    4, 14, 2, 36, 3,  5, 8, 46, 5, 62, 6, 81, 1, 65, 0, 34, 7, 80, 
    8, 29, 6, 57, 7, 68, 2, 32, 5, 83, 4,  7, 0, 85, 3, 97, 1,  5
  };
  const int q6329[] = {
    9, 9, // Number of jobs and machines
    4, 97, 3, 88, 7, 97, 8, 75, 1, 91, 2,  5, 5, 80, 0, 48, 6, 31, 
    6, 97, 1, 98, 5, 31, 7, 42, 3,  5, 0, 94, 8, 91, 4, 31, 2, 37, 
    8, 58, 5, 75, 7, 97, 0, 83, 1, 65, 2, 95, 3, 67, 4, 44, 6, 30, 
    2,  8, 1, 80, 3, 70, 5, 50, 8, 77, 0, 86, 4, 96, 6, 78, 7,  4, 
    3, 61, 6, 88, 5,  3, 4,  5, 2, 19, 1, 97, 7, 22, 0, 28, 8, 43, 
    4, 92, 3, 51, 1, 99, 6, 60, 7, 42, 8, 26, 5, 20, 0, 69, 2, 44, 
    6,  9, 1, 49, 8, 92, 7, 22, 3, 13, 0, 69, 5, 53, 4, 23, 2, 52, 
    4, 34, 6, 83, 5,  8, 8,  2, 7, 45, 0, 20, 3, 72, 1, 46, 2, 18, 
    7, 95, 1, 63, 8, 57, 5, 90, 0, 26, 4, 40, 6, 98, 3, 92, 2, 56
  };
  const int q6330[] = {
    9, 9, // Number of jobs and machines
    8, 10, 4, 66, 1, 33, 2, 20, 0, 73, 5, 55, 3, 28, 6, 76, 7, 28, 
    8, 51, 1, 11, 7, 97, 6, 72, 3, 59, 2, 74, 0, 64, 5, 58, 4, 60, 
    0, 81, 1, 23, 7, 68, 3, 61, 5, 62, 8, 73, 2, 86, 6, 87, 4, 95, 
    2, 87, 6,  8, 7, 23, 4, 44, 1, 80, 5, 42, 0, 59, 8, 85, 3, 96, 
    3, 15, 2, 17, 4, 12, 8, 66, 0, 86, 5, 99, 1,  4, 6, 96, 7, 66, 
    2, 68, 7, 31, 8, 72, 3, 48, 1, 41, 0, 37, 4, 68, 6,  6, 5, 50, 
    1, 93, 3, 84, 8, 74, 6, 83, 7, 66, 4, 42, 0, 75, 5, 12, 2, 92, 
    7, 69, 5, 56, 6, 22, 1, 76, 3, 88, 4, 60, 0, 31, 2, 99, 8, 77, 
    2, 95, 0, 59, 4, 88, 8, 87, 3, 34, 1, 77, 5, 15, 7, 83, 6, 97
  };
  const int q6331[] = {
    9, 9, // Number of jobs and machines
    8, 68, 6, 27, 7, 70, 1, 89, 2, 33, 3, 48, 4, 82, 5, 49, 0, 93, 
    8, 18, 7, 31, 3, 87, 5, 92, 2, 12, 6, 44, 1, 82, 4, 22, 0, 19, 
    5, 75, 7, 92, 6, 61, 0, 38, 3, 90, 8, 59, 1, 27, 2, 80, 4, 47, 
    7, 45, 8, 72, 4, 24, 2, 14, 0, 59, 1, 59, 6, 78, 5, 78, 3, 68, 
    3, 52, 8, 12, 6, 44, 7, 21, 1, 60, 2, 45, 5, 24, 4, 13, 0, 26, 
    8, 29, 7, 52, 1, 37, 6, 52, 4, 99, 0, 42, 3, 95, 5, 18, 2, 38, 
    3, 87, 5, 35, 0, 12, 8, 28, 2, 61, 4, 12, 1, 86, 7, 61, 6, 94, 
    4, 60, 1, 40, 0, 55, 2, 87, 5, 11, 3, 19, 7, 82, 6, 65, 8, 79, 
    7, 67, 3, 10, 0, 94, 4, 11, 1, 84, 5, 65, 8, 63, 6, 35, 2, 30
  };
  const int q6332[] = {
    9, 9, // Number of jobs and machines
    5, 19, 7, 31, 0, 11, 2,  9, 3, 31, 4, 81, 6, 37, 1, 89, 8, 95, 
    5, 82, 3, 27, 0, 95, 2, 88, 6, 74, 7, 97, 4, 52, 1, 98, 8, 67, 
    1, 39, 6, 52, 4, 67, 3, 32, 7, 59, 5, 61, 8, 54, 2, 12, 0, 69, 
    7, 12, 2, 64, 0, 14, 1, 16, 5, 65, 6, 48, 4, 42, 3, 60, 8, 18, 
    8, 17, 1,  4, 3, 59, 4, 96, 0, 17, 5, 74, 2, 63, 6, 23, 7, 68, 
    3, 17, 5, 94, 6, 42, 2,  2, 1, 92, 8, 74, 0,  1, 7, 71, 4, 77, 
    5, 32, 1, 27, 3, 95, 2, 75, 6, 49, 0, 41, 7, 85, 8, 21, 4, 93, 
    0, 94, 3, 63, 7, 30, 5, 71, 1, 82, 4,  9, 2, 80, 6, 59, 8, 20, 
    3, 72, 2, 67, 7, 99, 0, 73, 6, 78, 4, 67, 8, 71, 5, 96, 1, 11
  };
  const int q6333[] = {
    9, 9, // Number of jobs and machines
    4, 61, 2, 35, 6, 52, 8, 83, 0, 75, 1, 39, 7, 53, 5, 30, 3, 50, 
    1, 42, 8, 91, 2, 91, 6, 39, 5, 52, 4, 84, 7, 99, 3, 13, 0, 45, 
    2, 52, 8, 85, 5, 87, 1, 49, 0, 35, 3, 34, 4, 40, 7, 39, 6, 75, 
    7, 86, 0, 32, 8, 20, 3, 86, 4, 18, 6, 39, 1, 19, 2, 87, 5, 82, 
    4, 54, 1, 46, 8, 70, 7, 82, 6, 77, 0, 66, 2, 27, 5, 82, 3, 65, 
    8, 59, 1,  2, 3, 54, 4, 58, 0, 29, 2, 44, 7,  1, 6, 90, 5,  7, 
    5, 46, 0, 57, 1, 82, 2, 86, 8, 71, 4, 33, 6, 36, 3, 19, 7, 72, 
    3, 12, 7, 44, 4, 51, 2,  1, 5, 28, 6, 79, 1, 21, 0, 41, 8, 91, 
    3,  7, 0,  5, 6, 76, 7, 51, 4, 10, 2, 28, 5, 21, 1, 58, 8, 12
  };
  const int q6334[] = {
    9, 9, // Number of jobs and machines
    8, 27, 7,  9, 4, 90, 5, 11, 6,  7, 3, 90, 1, 48, 2, 16, 0, 80, 
    1, 96, 0, 39, 4, 45, 6, 18, 7, 25, 5, 80, 2, 75, 3, 96, 8, 43, 
    1, 26, 6, 72, 8, 59, 4, 28, 5, 24, 7, 15, 0, 50, 2, 35, 3, 19, 
    2, 32, 3, 39, 6,  1, 7, 78, 4,  5, 1, 68, 8, 65, 5, 34, 0, 18, 
    3, 23, 2, 29, 8, 42, 4, 76, 6, 90, 0,  3, 7,  9, 1, 58, 5, 28, 
    6, 24, 1, 33, 0, 49, 8,  6, 7, 70, 4,  1, 2, 40, 3,  4, 5, 79, 
    4, 56, 2, 37, 5, 46, 8, 39, 1,  9, 6, 25, 7, 20, 3, 25, 0, 42, 
    0, 21, 7, 69, 4,  5, 3, 61, 8, 76, 2, 50, 5, 40, 1,  1, 6, 18, 
    0, 56, 5, 66, 1, 40, 8, 33, 2, 37, 4, 75, 6, 21, 7, 75, 3, 19
  };
  const int q6335[] = {
    9, 9, // Number of jobs and machines
    7, 56, 4, 61, 3,  1, 1, 85, 0, 43, 2, 58, 8, 28, 5, 93, 6, 43, 
    2, 26, 8,  4, 1, 15, 0, 52, 5, 86, 6, 95, 3, 30, 7, 82, 4, 42, 
    4, 40, 1, 62, 3, 52, 6, 25, 5, 33, 2, 25, 0, 32, 7,  8, 8, 41, 
    5, 13, 2, 17, 4,  6, 6, 85, 0, 92, 1, 95, 3, 61, 8, 29, 7, 99, 
    2, 56, 7,  9, 8, 95, 6,  5, 0, 94, 5, 85, 3, 71, 4,  4, 1, 71, 
    6, 28, 8, 55, 7, 40, 4, 93, 0, 53, 3, 51, 5, 52, 2,  8, 1, 46, 
    4, 83, 6, 46, 2, 65, 5, 21, 7, 16, 0, 25, 3, 42, 1, 10, 8, 36, 
    4, 33, 5, 32, 0, 58, 1, 38, 8, 21, 7, 37, 2, 84, 3, 97, 6,  8, 
    2, 63, 4, 40, 5, 20, 0, 69, 7, 33, 1, 72, 6, 88, 3,  6, 8, 93
  };
  const int q6336[] = {
    9, 9, // Number of jobs and machines
    8, 78, 3, 69, 2,  8, 1, 61, 5, 27, 0, 60, 7, 50, 4, 76, 6, 12, 
    2, 77, 5, 59, 4, 53, 3, 25, 6, 74, 0, 11, 7, 30, 8,  8, 1, 51, 
    1, 27, 5, 87, 7, 47, 2, 35, 0, 56, 3, 16, 8,  8, 6, 98, 4, 93, 
    6, 31, 7, 81, 5, 22, 3, 74, 4, 52, 2, 58, 1, 63, 0, 61, 8, 69, 
    3, 83, 1, 90, 4,  7, 2, 96, 0,  3, 8, 16, 6, 15, 5, 38, 7, 87, 
    6, 57, 4, 89, 3, 45, 8, 87, 0, 48, 2, 20, 5, 16, 1, 57, 7, 55, 
    6, 47, 8, 94, 7, 75, 4,  4, 2, 98, 0, 36, 3, 15, 1, 63, 5, 74, 
    1, 85, 4, 50, 2, 46, 6, 69, 0, 83, 3, 80, 7,  5, 8, 23, 5,  3, 
    1,  1, 7, 30, 4, 21, 6, 22, 3, 50, 0, 27, 5,  5, 8, 10, 2, 54
  };
  const int q6337[] = {
    9, 9, // Number of jobs and machines
    7, 84, 4, 96, 2, 34, 0, 62, 3, 57, 8, 54, 1, 27, 5, 44, 6, 92, 
    4, 63, 8, 31, 3, 60, 0, 88, 2, 48, 1, 96, 7, 83, 5, 96, 6, 38, 
    8, 63, 3, 87, 0, 31, 6, 95, 1, 90, 7, 96, 2, 65, 4, 85, 5, 50, 
    7, 32, 6, 26, 4, 94, 2, 14, 1, 37, 0, 96, 5, 28, 3, 40, 8, 93, 
    6,  4, 7, 68, 4, 24, 1, 82, 8, 60, 3,  9, 0, 78, 5, 60, 2, 68, 
    7, 43, 0, 19, 3, 59, 1, 75, 6, 16, 5,  5, 4, 69, 8, 85, 2, 97, 
    1, 70, 5, 25, 4, 63, 3, 91, 0, 12, 8, 99, 2, 90, 7, 20, 6, 47, 
    8, 18, 7, 91, 2, 46, 4, 94, 6, 67, 1, 68, 3, 83, 0, 91, 5, 58, 
    6, 72, 8, 10, 2, 39, 7,  8, 4, 12, 1, 93, 0, 72, 5, 40, 3, 96
  };
  const int q6338[] = {
    9, 9, // Number of jobs and machines
    5, 47, 4, 77, 6, 90, 1, 98, 2, 37, 3, 81, 7, 55, 0, 74, 8, 86, 
    8, 26, 1, 45, 6, 13, 3, 89, 0, 20, 5, 62, 4, 77, 2, 16, 7, 68, 
    5,  6, 4, 98, 8, 25, 0, 89, 6, 81, 2, 40, 1, 90, 7, 45, 3, 87, 
    2, 44, 6, 95, 7, 43, 4, 98, 8, 21, 3,  7, 5, 56, 1, 37, 0, 83, 
    4, 21, 5, 92, 3, 32, 8, 66, 0, 28, 6, 55, 2,  6, 7, 67, 1, 20, 
    1,  8, 6, 13, 7, 12, 4, 21, 3, 78, 0, 15, 8, 72, 5, 13, 2, 54, 
    1, 13, 5, 16, 0, 41, 4, 76, 3, 53, 7, 11, 8, 71, 2, 64, 6, 18, 
    4, 15, 5, 53, 2, 98, 8, 57, 1, 26, 6, 95, 3, 85, 0, 53, 7, 90, 
    8, 41, 2, 23, 6, 70, 4, 81, 3, 46, 1, 33, 5, 85, 0, 42, 7, 31
  };
  const int q6339[] = {
    9, 9, // Number of jobs and machines
    3, 95, 5, 48, 8, 44, 1, 97, 7, 68, 6, 76, 2, 25, 4, 27, 0, 20, 
    2, 14, 5, 44, 3, 32, 8, 91, 7, 21, 0,  5, 1, 13, 4, 83, 6, 21, 
    1, 28, 7, 11, 3,  8, 4, 86, 2, 43, 8, 60, 5, 30, 0, 14, 6, 15, 
    0, 72, 2, 67, 8, 27, 1, 66, 4, 64, 5, 98, 3, 41, 7, 72, 6, 30, 
    4,  1, 8, 91, 1, 20, 6, 77, 3, 54, 2, 31, 7, 92, 0, 81, 5, 26, 
    5,  6, 3,  1, 2, 32, 8, 80, 6, 43, 1, 77, 7, 12, 4, 21, 0, 18, 
    2, 27, 3, 42, 4, 12, 8, 65, 0, 48, 5, 97, 7, 96, 1, 46, 6, 39, 
    6, 33, 2, 87, 8, 89, 4, 67, 0, 38, 3, 70, 5, 57, 7, 18, 1, 27, 
    6, 70, 4, 44, 1, 54, 0, 59, 5, 31, 2, 11, 7, 56, 3, 77, 8, 55
  };
  const int q6340[] = {
    9, 9, // Number of jobs and machines
    8, 65, 5, 81, 1, 25, 7, 54, 0, 41, 2, 16, 3, 15, 4, 67, 6, 71, 
    1, 43, 4, 24, 7, 75, 5, 23, 3, 58, 6, 41, 2, 56, 8, 40, 0, 18, 
    0, 49, 1, 17, 5, 30, 7, 95, 3, 25, 8, 30, 2, 42, 6, 74, 4, 66, 
    7, 82, 1, 53, 8, 67, 3, 75, 4, 11, 6, 44, 2, 87, 5,  5, 0,  1, 
    2, 30, 5, 50, 3, 84, 1, 45, 8, 58, 6, 90, 4, 92, 0, 57, 7, 53, 
    2, 17, 3, 29, 0, 45, 7, 25, 4, 63, 6, 77, 8,  6, 5, 61, 1, 94, 
    7, 28, 3,  5, 4, 53, 0, 67, 8, 60, 5, 23, 6, 80, 1, 88, 2, 41, 
    4, 40, 1, 18, 0, 24, 2,  9, 6, 61, 3, 66, 5, 50, 7, 64, 8, 76, 
    8, 84, 7, 31, 4, 71, 5, 13, 3, 87, 1, 25, 2, 91, 0,  5, 6, 77
  };
  const int q6341[] = {
    9, 9, // Number of jobs and machines
    3, 71, 6, 14, 0, 31, 8, 64, 7, 56, 1, 17, 5, 59, 2,  8, 4, 73, 
    0, 68, 7, 85, 6, 77, 2, 80, 1, 97, 4, 92, 3, 99, 8, 45, 5, 75, 
    0, 71, 6, 10, 3, 69, 8, 11, 1, 93, 5, 96, 7, 78, 4, 89, 2, 13, 
    7, 13, 1, 96, 6, 81, 0, 44, 8, 98, 3, 95, 2, 72, 4, 51, 5, 20, 
    3, 66, 7, 14, 4, 86, 6, 71, 5, 35, 2, 63, 0, 36, 1, 59, 8, 33, 
    7, 20, 3, 94, 5, 94, 2,  1, 0, 74, 6, 47, 1, 65, 8, 47, 4, 98, 
    4, 30, 6, 69, 7, 50, 3, 45, 8, 91, 2, 33, 1, 63, 5, 56, 0, 89, 
    2, 25, 5, 76, 6, 52, 7, 61, 1, 85, 4, 90, 8, 54, 0, 81, 3, 22, 
    8, 65, 3, 51, 4, 88, 0, 28, 1, 52, 7, 70, 2, 70, 6, 96, 5, 64
  };
  const int q6342[] = {
    9, 9, // Number of jobs and machines
    0, 32, 2,  6, 8, 26, 4, 27, 6, 51, 3, 97, 5, 75, 7, 24, 1, 15, 
    1, 16, 8, 26, 7, 73, 3, 52, 4, 62, 5, 74, 6, 92, 2, 69, 0,  7, 
    1, 15, 0, 41, 6, 13, 3,  5, 4, 85, 7, 55, 8, 85, 2, 51, 5, 19, 
    6, 80, 0, 40, 4,  2, 5,  2, 7, 35, 1, 55, 2, 15, 8, 27, 3, 33, 
    2, 15, 8, 46, 1, 66, 3, 31, 5, 62, 4, 12, 7, 46, 6, 93, 0, 32, 
    7, 44, 8,  1, 2,  7, 6, 68, 3, 77, 1, 44, 5, 49, 4, 56, 0, 98, 
    3, 65, 2, 64, 0, 17, 6, 60, 4, 78, 1, 56, 7, 28, 5, 19, 8, 80, 
    8, 56, 5, 78, 6, 36, 7, 12, 3, 13, 1, 61, 4, 52, 0, 73, 2, 34, 
    2, 70, 1, 50, 6, 76, 4, 68, 5, 34, 8, 24, 3, 10, 0, 30, 7, 85
  };
  const int q6343[] = {
    9, 9, // Number of jobs and machines
    2,  2, 3, 31, 7, 62, 0,  2, 6, 62, 4, 72, 8, 57, 5, 70, 1, 82, 
    6, 76, 8, 45, 1, 67, 2, 25, 4,  7, 7, 25, 3, 31, 5, 68, 0, 99, 
    1, 92, 4, 29, 5, 72, 6,  9, 2, 35, 7, 52, 3, 24, 8, 32, 0,  2, 
    3,  6, 1, 47, 0, 81, 8, 33, 6, 32, 4, 66, 2, 18, 5, 24, 7, 35, 
    5, 49, 7, 22, 2, 61, 3, 29, 6, 77, 8, 23, 0, 65, 1, 67, 4, 24, 
    5, 16, 8, 37, 1, 85, 4, 88, 6, 29, 2, 37, 7, 58, 3, 82, 0, 94, 
    4, 78, 5, 30, 8, 78, 2, 41, 6, 13, 0, 70, 1, 42, 3, 45, 7, 75, 
    1, 97, 4, 95, 7, 97, 8, 96, 2, 55, 3, 10, 5, 40, 0, 63, 6, 69, 
    5, 43, 6, 46, 1, 11, 2, 30, 4, 80, 3, 56, 0, 88, 7, 65, 8, 62
  };
  const int q6344[] = {
    9, 9, // Number of jobs and machines
    3, 41, 6, 10, 1, 50, 8, 37, 5, 10, 2, 86, 7, 65, 0, 58, 4, 95, 
    2, 98, 8, 66, 3, 10, 1, 78, 4, 98, 0, 37, 6, 34, 5, 71, 7, 30, 
    0,  9, 6,  6, 1, 66, 8, 63, 3, 87, 4, 79, 5, 47, 7,  8, 2, 72, 
    4, 38, 0, 61, 2, 55, 3, 60, 6, 95, 1, 52, 7, 97, 5, 23, 8, 16, 
    8, 42, 2, 48, 4, 25, 1, 70, 5, 13, 3, 51, 7, 89, 0, 20, 6, 73, 
    7, 88, 2, 17, 6, 23, 0, 32, 8, 22, 3, 91, 4, 57, 5, 99, 1, 75, 
    6, 73, 3, 11, 0, 76, 5, 11, 7,  1, 4, 94, 8, 18, 2, 90, 1, 63, 
    2,  6, 7, 50, 5, 31, 4, 46, 6, 49, 8, 84, 3, 66, 0, 26, 1, 78, 
    7, 48, 2,  4, 1, 20, 0, 62, 6, 44, 8, 69, 5, 54, 3, 70, 4, 15
  };
  const int q6345[] = {
    9, 9, // Number of jobs and machines
    3, 40, 4, 66, 8, 96, 1, 33, 5, 50, 7, 32, 0, 83, 6, 26, 2, 74, 
    3, 91, 8, 29, 7, 25, 2, 17, 0, 90, 4, 20, 1, 40, 6, 88, 5, 11, 
    4, 16, 5, 51, 1, 73, 0, 34, 7, 70, 6, 76, 2, 73, 3, 30, 8, 93, 
    1, 72, 2, 80, 7, 19, 0,  9, 6, 16, 8, 32, 3, 18, 4, 30, 5, 48, 
    1, 33, 4, 15, 6, 69, 2, 19, 8, 97, 7, 71, 5, 77, 3, 81, 0, 89, 
    0,  2, 3, 17, 8, 98, 6, 29, 2, 22, 4,  4, 7, 98, 5, 32, 1, 33, 
    7, 85, 4, 15, 6, 92, 8, 26, 1, 57, 3, 71, 0, 85, 2, 94, 5, 17, 
    5, 36, 6, 26, 2, 99, 4, 64, 0, 23, 8, 38, 3, 71, 1, 48, 7, 83, 
    1, 68, 8, 83, 0, 81, 4, 61, 7, 27, 2, 62, 3, 92, 5, 46, 6,  7
  };
  const int q6346[] = {
    9, 9, // Number of jobs and machines
    6, 84, 1, 56, 4, 23, 8, 30, 2, 30, 0, 80, 5,  2, 3,  1, 7, 65, 
    0, 70, 1, 27, 3, 69, 6, 44, 7, 37, 8, 76, 4, 45, 5, 41, 2, 68, 
    4, 50, 5, 11, 7, 41, 6, 86, 8, 59, 1, 75, 0, 32, 2, 20, 3, 87, 
    2, 79, 1, 87, 7, 17, 4, 56, 6, 83, 3,  5, 0, 84, 8, 65, 5, 67, 
    5, 49, 0, 92, 1, 78, 6, 82, 2, 11, 3, 28, 8, 83, 4, 48, 7, 37, 
    3, 50, 6, 26, 0, 28, 8, 57, 1, 74, 2, 50, 7, 30, 5, 46, 4, 79, 
    1, 98, 4, 84, 7, 30, 5, 86, 2, 18, 6, 37, 0, 94, 3, 89, 8, 43, 
    3, 21, 8, 21, 4, 49, 1, 11, 6, 39, 2, 86, 5,  8, 7, 91, 0, 74, 
    3, 72, 5, 71, 0, 20, 4, 44, 1,  1, 8, 87, 2, 25, 6, 97, 7,  2
  };
  const int q6347[] = {
    9, 9, // Number of jobs and machines
    6, 73, 7, 60, 1, 35, 8, 25, 3, 91, 2, 32, 5, 19, 0, 71, 4, 54, 
    3, 84, 0, 62, 1,  3, 4, 52, 5, 37, 8, 33, 6, 75, 2, 86, 7, 25, 
    2, 89, 4, 41, 3, 10, 0, 17, 1, 68, 8, 68, 7, 75, 5, 30, 6, 62, 
    4, 53, 0, 76, 6, 51, 1, 27, 7, 38, 3, 45, 2, 97, 8, 93, 5, 54, 
    8, 20, 0, 89, 3, 79, 5,  3, 2, 76, 1, 55, 4, 21, 7,  7, 6, 35, 
    1, 67, 0, 25, 6, 59, 8, 40, 5,  9, 2, 84, 7, 72, 4, 93, 3, 80, 
    8, 15, 2, 35, 6,  1, 4, 96, 1, 96, 3, 12, 0, 39, 5, 26, 7,  6, 
    2, 97, 7, 89, 3, 15, 1, 55, 8, 66, 4, 53, 0, 16, 6, 40, 5, 81, 
    6, 12, 1, 15, 3, 28, 0, 34, 5, 27, 2, 96, 7,  2, 4, 15, 8, 85
  };
  const int q6348[] = {
    9, 9, // Number of jobs and machines
    0, 74, 8, 88, 1, 24, 5, 46, 3, 84, 6, 24, 2, 21, 4, 40, 7,  4, 
    2, 67, 7, 13, 8, 73, 4, 91, 6, 49, 1, 23, 5, 19, 3, 13, 0, 80, 
    1, 33, 3, 62, 4,  3, 0,  2, 5, 75, 8, 60, 7, 14, 2, 58, 6, 14, 
    3, 75, 5, 27, 6, 76, 4, 89, 7, 58, 8, 14, 2, 42, 1, 52, 0, 58, 
    1, 47, 6, 56, 0, 70, 8,  5, 7, 63, 4, 97, 5, 87, 3,  1, 2, 37, 
    3, 97, 8, 71, 1, 34, 0,  9, 5, 62, 6, 86, 4, 47, 2, 39, 7, 51, 
    2, 12, 0, 46, 8, 50, 6,  8, 7, 76, 4, 65, 1, 48, 3, 96, 5, 32, 
    1,  7, 0, 53, 7, 75, 6, 77, 8, 52, 3,  1, 2, 64, 4,  7, 5,  5, 
    5, 19, 8, 86, 1, 46, 2, 43, 3, 59, 4, 36, 6, 21, 0, 32, 7, 60
  };
  const int q6349[] = {
    9, 9, // Number of jobs and machines
    7, 79, 8, 77, 1, 12, 3, 52, 5, 72, 2, 15, 6, 32, 4,  4, 0, 81, 
    5,  4, 4, 82, 8, 41, 1, 52, 7, 87, 6, 65, 2, 21, 0, 30, 3, 19, 
    6, 98, 4, 57, 1, 28, 8, 24, 7, 63, 5, 47, 0, 56, 2, 82, 3, 53, 
    8, 77, 1, 62, 0, 25, 7, 78, 5, 29, 2, 64, 6, 72, 4, 48, 3, 59, 
    3,  7, 6, 17, 4, 12, 7, 69, 0, 29, 2, 25, 1, 22, 5,  1, 8, 75, 
    0, 58, 7, 52, 8, 13, 5, 44, 6, 21, 2, 47, 4, 86, 3, 39, 1, 42, 
    2, 32, 5, 61, 4, 20, 8, 76, 3, 70, 1, 71, 7, 53, 6, 93, 0, 96, 
    1, 25, 3, 34, 4, 54, 8, 87, 0,  5, 6, 23, 5, 85, 7, 67, 2, 14, 
    3, 27, 5, 91, 0,  4, 2, 87, 6, 46, 1, 79, 8, 94, 7, 71, 4, 49
  };
  const int q6350[] = {
    9, 9, // Number of jobs and machines
    1, 73, 8, 74, 5, 51, 4, 75, 6, 13, 2, 88, 7, 73, 3,  9, 0, 18, 
    7, 23, 5, 84, 6, 73, 1, 84, 0,  6, 8, 50, 4, 45, 2, 18, 3, 19, 
    2, 86, 5, 27, 4, 25, 8, 66, 3, 58, 0, 13, 7, 32, 1, 60, 6, 30, 
    1, 94, 2, 85, 5, 22, 4, 18, 7, 75, 0, 88, 6, 53, 3, 76, 8, 41, 
    0, 86, 8,  7, 6, 41, 2, 76, 5, 45, 4, 79, 7, 84, 1, 82, 3, 19, 
    0, 40, 6, 68, 7, 92, 1, 78, 2, 60, 8, 46, 4,  5, 3, 57, 5, 83, 
    8, 28, 2, 73, 0, 35, 6, 16, 5, 34, 3,  5, 1, 78, 4, 30, 7, 88, 
    1, 72, 5, 37, 2, 41, 8, 63, 4, 29, 7, 26, 6, 32, 3, 75, 0, 64, 
    2, 38, 1, 38, 6, 71, 4, 22, 5, 86, 8, 13, 7, 69, 0, 46, 3, 62
  };
  const int q6351[] = {
    9, 9, // Number of jobs and machines
    8, 69, 5, 21, 1,  5, 0, 65, 2, 98, 7, 35, 3,  5, 6, 49, 4, 70, 
    0, 15, 4,  4, 3, 45, 2, 22, 8, 37, 1, 78, 5, 44, 7, 41, 6, 80, 
    7,  5, 6, 65, 3, 43, 2, 48, 8, 82, 0, 66, 4, 93, 1, 55, 5, 46, 
    5, 76, 4, 21, 7, 62, 2, 68, 8, 44, 3, 63, 0, 85, 6, 72, 1, 88, 
    2, 92, 8, 72, 3, 89, 1, 33, 6, 37, 5, 57, 0, 83, 7, 22, 4, 41, 
    2,  1, 1, 93, 5,  1, 7, 16, 3, 16, 0, 24, 4, 97, 8, 69, 6, 84, 
    8, 70, 3, 19, 2, 92, 5, 51, 0, 19, 1, 55, 6, 31, 4, 66, 7, 99, 
    6, 68, 3, 93, 8, 79, 1, 60, 5, 58, 4, 76, 0, 95, 7, 40, 2, 93, 
    7, 57, 2, 46, 6, 40, 4, 86, 1, 88, 3, 19, 8, 57, 0, 85, 5, 12
  };
  const int q6352[] = {
    9, 9, // Number of jobs and machines
    8, 87, 7, 87, 5, 22, 3, 13, 2, 82, 0, 81, 4, 82, 1, 16, 6, 42, 
    7, 14, 6, 88, 4, 90, 1, 76, 8, 86, 5, 99, 3,  4, 0, 74, 2, 25, 
    0,  6, 7, 98, 3, 27, 5, 60, 4, 71, 2, 66, 8, 47, 6, 48, 1, 28, 
    8, 46, 2, 13, 3, 88, 5, 39, 4, 34, 7, 25, 1, 65, 0, 91, 6, 56, 
    8, 61, 4, 18, 6, 34, 2, 27, 3, 88, 7, 40, 1, 27, 5,  1, 0, 32, 
    5, 79, 7, 12, 2, 62, 0, 82, 8, 31, 4, 80, 1, 76, 6, 18, 3, 23, 
    7, 88, 1, 36, 8, 63, 2, 48, 3, 41, 4, 76, 0, 58, 5, 83, 6, 27, 
    4, 96, 8, 25, 2, 68, 0,  2, 5, 19, 3, 22, 1, 79, 6, 88, 7, 44, 
    0, 63, 3, 23, 2, 85, 6, 93, 1, 84, 4, 87, 5, 34, 8, 72, 7, 26
  };
  const int q6353[] = {
    9, 9, // Number of jobs and machines
    8, 95, 1, 76, 4, 41, 6, 82, 0, 76, 3, 14, 2, 87, 5, 40, 7, 17, 
    0, 46, 4, 25, 3, 80, 7,  1, 6, 86, 5, 65, 8, 87, 1, 54, 2, 64, 
    3, 49, 6,  5, 2, 94, 8, 42, 4, 76, 7, 97, 1, 26, 5,  5, 0,  1, 
    4, 70, 0, 56, 1, 94, 2, 17, 6, 57, 8, 77, 3, 38, 5, 11, 7,  5, 
    8, 61, 3, 95, 0, 52, 1,  5, 5, 66, 6, 52, 4, 16, 2, 52, 7, 63, 
    0, 48, 5, 85, 1, 94, 8, 10, 6, 24, 7, 11, 2, 40, 4, 16, 3, 25, 
    1, 20, 0, 60, 8, 56, 4,  3, 3, 65, 5, 98, 6, 15, 7, 42, 2, 18, 
    4, 62, 6, 65, 5, 19, 2, 33, 8, 43, 7, 14, 0, 34, 3, 99, 1, 41, 
    2, 89, 1, 48, 3, 99, 0, 21, 5, 58, 4, 36, 6, 77, 7, 44, 8, 41
  };
  const int q6354[] = {
    9, 9, // Number of jobs and machines
    8, 83, 5,  4, 7, 54, 2, 52, 0, 52, 4, 26, 1, 60, 6, 62, 3, 58, 
    5, 50, 3, 25, 6,  5, 2, 39, 7, 72, 1, 45, 0, 42, 4, 18, 8,  4, 
    5, 19, 7, 11, 4, 38, 0, 38, 6, 31, 1, 24, 3, 56, 2, 15, 8, 74, 
    3, 26, 4, 53, 0, 32, 8, 46, 1, 12, 6, 12, 2, 13, 5, 68, 7, 59, 
    1, 92, 4, 82, 2, 29, 3, 32, 6, 68, 5, 80, 0, 82, 7, 19, 8, 66, 
    6,  2, 3, 86, 2, 17, 7, 46, 8, 20, 4, 88, 0, 64, 5, 80, 1, 32, 
    7, 53, 8, 72, 5, 90, 0, 26, 6, 87, 3, 78, 4, 87, 1, 92, 2, 10, 
    0, 69, 4, 79, 7, 33, 6, 18, 5, 55, 8, 90, 1, 47, 3, 13, 2, 44, 
    8,  7, 2, 43, 6,  4, 1, 35, 5, 85, 7, 76, 4, 41, 3, 29, 0, 34
  };
  const int q6355[] = {
    9, 9, // Number of jobs and machines
    1, 43, 6, 79, 8, 60, 2, 57, 5, 85, 3, 23, 0,  5, 4, 60, 7, 98, 
    3, 19, 0, 15, 7, 77, 8, 97, 5, 41, 6, 10, 2, 91, 1, 83, 4, 23, 
    7, 53, 0, 95, 8, 48, 6, 86, 5,  2, 2, 61, 3, 13, 1, 80, 4, 95, 
    8, 93, 4, 84, 6, 40, 7, 72, 5, 41, 2, 61, 0, 28, 1, 42, 3, 87, 
    1, 34, 6, 47, 5,  8, 4,  4, 2, 90, 3, 27, 8, 69, 7, 99, 0, 59, 
    1, 17, 3, 15, 8, 27, 2, 79, 5, 68, 4, 12, 7,  2, 0, 82, 6, 92, 
    3, 23, 6, 35, 1, 51, 2, 26, 5,  3, 4,  3, 7, 86, 0, 62, 8, 69, 
    3, 38, 6, 70, 5, 79, 2, 79, 1, 96, 4, 58, 0, 46, 8, 96, 7, 75, 
    2, 26, 4, 56, 8, 40, 0,  7, 6, 30, 1, 27, 3, 56, 7, 46, 5, 68
  };
  const int q6356[] = {
    9, 9, // Number of jobs and machines
    7, 80, 4, 88, 1, 74, 6, 12, 2, 50, 8, 89, 3, 50, 5,  7, 0, 96, 
    4, 14, 5,  6, 2, 46, 1, 13, 8, 85, 3, 66, 0, 32, 6, 77, 7, 95, 
    0, 84, 6, 54, 1, 47, 4, 64, 3, 14, 2, 47, 8, 55, 7, 86, 5,  3, 
    8, 85, 1, 75, 0,  5, 6, 83, 2, 16, 5, 34, 7, 45, 4, 70, 3, 89, 
    8, 58, 5, 33, 6, 36, 3, 70, 2, 85, 4, 78, 1, 21, 7, 92, 0, 27, 
    5, 73, 6, 12, 8, 75, 2, 42, 0, 21, 1, 15, 7,  5, 4, 98, 3, 43, 
    2, 35, 7, 69, 1, 53, 3, 26, 8, 42, 6,  9, 5,  3, 0,  5, 4, 73, 
    2, 71, 4, 66, 7,  5, 1, 53, 0, 69, 5,  9, 3, 70, 6, 13, 8, 63, 
    1, 27, 0, 63, 7, 15, 8, 31, 3, 99, 6, 65, 4, 78, 2, 70, 5, 52
  };
  const int q6357[] = {
    9, 9, // Number of jobs and machines
    4, 38, 3, 55, 0, 13, 8,  8, 5, 46, 7, 63, 1, 56, 2,  5, 6, 38, 
    7, 27, 6, 23, 3, 47, 0, 49, 1, 27, 5, 74, 8, 68, 4, 16, 2, 88, 
    8, 28, 5, 76, 2, 45, 6,  1, 0,  6, 4, 62, 1, 30, 3, 11, 7, 36, 
    6, 73, 1, 86, 5, 47, 8, 89, 7, 13, 3, 87, 4, 24, 2, 97, 0, 55, 
    2, 50, 7, 61, 1, 26, 5,  1, 8, 62, 6, 98, 3, 86, 4, 68, 0, 43, 
    2, 36, 3, 96, 7, 50, 8, 52, 0, 85, 5, 11, 6, 41, 4, 55, 1, 96, 
    1, 18, 5, 87, 7,  6, 3, 27, 4, 27, 2, 64, 6, 68, 8, 64, 0, 73, 
    1, 50, 5, 79, 7, 14, 0, 69, 3, 99, 8, 21, 6, 14, 4, 13, 2, 29, 
    3, 18, 7, 44, 2, 67, 5, 80, 1, 41, 8, 47, 4, 79, 6, 68, 0, 47
  };
  const int q6358[] = {
    9, 9, // Number of jobs and machines
    5, 96, 0, 41, 3, 78, 2, 28, 4, 16, 6, 76, 7, 10, 1, 61, 8, 95, 
    4, 25, 3, 94, 1, 87, 6, 37, 0, 41, 5,  1, 8,  8, 2, 42, 7, 41, 
    4, 13, 7, 43, 8, 50, 1, 75, 6, 25, 3, 12, 0, 11, 5, 26, 2, 21, 
    3, 12, 1, 56, 4, 52, 2,  7, 0, 67, 5, 90, 6, 73, 7, 29, 8, 51, 
    6, 28, 0, 57, 8,  1, 3, 53, 2,  6, 5, 96, 1, 89, 4, 43, 7, 88, 
    4, 11, 3, 42, 7, 10, 1, 35, 0, 37, 2, 95, 5, 54, 8, 64, 6, 69, 
    4, 79, 0, 27, 6,  3, 3, 77, 5, 76, 1, 74, 2, 97, 8, 41, 7, 56, 
    4,  5, 3, 93, 0, 90, 8, 64, 5, 92, 7, 99, 2, 54, 1, 23, 6, 58, 
    1, 86, 7, 62, 3, 67, 5, 38, 8, 62, 6, 95, 2, 19, 4, 57, 0, 11
  };
  const int q6359[] = {
    9, 9, // Number of jobs and machines
    6, 18, 4, 86, 7, 28, 3, 24, 5, 10, 2,  1, 8, 26, 1, 68, 0, 91, 
    1, 56, 4, 30, 3, 90, 0, 26, 6, 31, 8, 46, 2, 69, 7, 24, 5, 61, 
    1, 90, 0, 92, 4, 99, 7, 16, 6, 75, 5, 15, 3, 86, 2, 68, 8, 75, 
    6, 67, 8, 54, 5, 38, 0, 75, 2, 43, 7, 55, 3, 81, 1, 27, 4, 84, 
    2, 24, 6, 17, 8,  4, 3, 59, 1,  5, 7, 47, 5, 24, 4, 80, 0, 24, 
    8, 63, 6, 24, 4, 38, 7, 33, 0,  2, 2, 78, 1, 39, 3, 21, 5, 28, 
    8, 25, 1, 67, 2, 14, 5, 55, 4, 13, 6, 42, 7, 20, 3, 65, 0, 58, 
    5, 51, 0, 51, 4, 18, 6, 81, 1, 69, 8, 74, 2, 92, 7, 40, 3, 84, 
    8, 22, 3, 15, 4,  9, 5, 22, 2, 49, 6, 31, 7, 90, 0, 55, 1, 44
  };
  const int q6360[] = {
    9, 9, // Number of jobs and machines
    2, 91, 6, 95, 8, 73, 5, 88, 7, 37, 3, 84, 4, 94, 0,  5, 1,  5, 
    6, 73, 2, 81, 5,  8, 3, 47, 4, 56, 0, 65, 8, 25, 7, 94, 1, 45, 
    4, 18, 3, 24, 1, 52, 6, 89, 2, 25, 7, 26, 5, 10, 0, 24, 8, 55, 
    2, 27, 3, 80, 0, 60, 1, 68, 5, 64, 7, 97, 4, 73, 8,  7, 6, 35, 
    0, 54, 4, 83, 2, 62, 1, 80, 8, 39, 7, 52, 3, 16, 5, 14, 6, 75, 
    5, 13, 8, 59, 6, 44, 2, 77, 0, 63, 4, 46, 1, 28, 7, 28, 3, 81, 
    2, 87, 8, 22, 0, 90, 1, 96, 7, 18, 4, 16, 5, 69, 6, 56, 3, 13, 
    7, 80, 8, 89, 4, 69, 5, 15, 1, 85, 3, 79, 0, 99, 6, 47, 2, 81, 
    6, 44, 8, 41, 5, 58, 4, 71, 7, 49, 1, 33, 0, 62, 2, 39, 3, 11
  };
  const int q6361[] = {
    9, 9, // Number of jobs and machines
    1, 41, 7, 75, 6, 55, 5, 13, 0, 57, 8, 46, 2, 83, 4, 43, 3, 82, 
    8, 23, 1, 44, 0, 85, 5, 34, 7, 99, 4, 40, 2, 44, 3, 13, 6, 78, 
    8, 72, 0, 57, 4, 95, 3, 31, 1, 37, 6, 24, 5, 86, 2,  7, 7, 20, 
    7, 54, 5,  1, 1, 58, 3, 15, 6, 49, 8, 19, 4, 65, 2, 45, 0, 19, 
    2,  3, 4, 32, 1, 30, 7, 19, 3, 52, 8, 57, 0, 10, 5, 37, 6, 79, 
    6, 40, 2, 41, 7, 65, 3, 73, 0, 83, 1, 25, 5,  4, 8, 63, 4,  4, 
    4, 25, 2, 13, 8, 86, 5, 35, 3,  7, 6, 59, 7, 34, 0, 79, 1, 22, 
    0, 30, 6, 82, 3, 47, 2, 26, 8, 85, 1, 49, 7, 53, 4, 11, 5, 76, 
    1, 44, 6, 75, 2, 25, 3,  1, 8, 50, 0, 96, 4, 81, 5, 90, 7, 36
  };
  const int q6362[] = {
    9, 9, // Number of jobs and machines
    6, 95, 5, 56, 1, 55, 2, 18, 3, 27, 8, 46, 4, 18, 7, 90, 0, 53, 
    7, 39, 5,  7, 2, 75, 8, 77, 4, 42, 0, 86, 6, 38, 1, 35, 3, 84, 
    3, 96, 2, 33, 6, 36, 7,  1, 4, 75, 5, 53, 1, 52, 0, 50, 8, 95, 
    0, 50, 4,  9, 2, 84, 1, 69, 5, 23, 6, 32, 3,  6, 7, 30, 8, 93, 
    2, 84, 8, 32, 4, 38, 0, 64, 6, 76, 7, 27, 5, 24, 1,  2, 3,  9, 
    2, 68, 1,  6, 8, 94, 0, 26, 3,  2, 7, 75, 5, 63, 4, 13, 6, 99, 
    6, 89, 2,  2, 0, 73, 1, 98, 3, 78, 7, 65, 4, 10, 5, 85, 8, 14, 
    8, 47, 4, 75, 0, 15, 6, 83, 2, 37, 3, 76, 5, 63, 1,  3, 7, 26, 
    3, 36, 4, 66, 7, 79, 2, 78, 6, 81, 5, 42, 8, 95, 0, 52, 1, 65
  };
  const int q6363[] = {
    9, 9, // Number of jobs and machines
    5,  2, 1,  7, 8, 77, 4, 32, 0, 16, 6, 95, 2, 64, 7, 34, 3, 60, 
    4,  7, 8, 82, 5, 56, 3,  5, 7, 32, 2, 70, 0, 67, 6, 73, 1, 60, 
    7, 20, 1, 97, 0, 96, 4, 10, 8, 65, 3, 82, 5, 53, 6, 12, 2, 11, 
    0, 22, 3, 10, 6, 63, 7, 54, 2, 71, 1,  5, 8, 77, 4, 12, 5, 91, 
    0, 33, 7, 45, 8, 44, 5, 63, 3, 32, 4, 44, 2, 85, 6, 86, 1, 54, 
    4, 96, 8, 93, 2, 68, 6, 17, 3, 43, 7, 49, 0, 35, 1, 48, 5,  1, 
    6,  4, 8, 18, 4, 77, 2, 51, 3, 53, 7, 69, 5, 12, 0, 44, 1, 72, 
    0, 78, 2, 58, 6, 69, 7, 36, 8, 57, 4, 43, 5, 98, 3, 15, 1, 15, 
    7, 76, 4, 45, 2, 10, 1, 97, 5, 67, 8, 85, 3, 82, 6,  9, 0, 33
  };
  const int q6364[] = {
    9, 9, // Number of jobs and machines
    7, 74, 0, 49, 1, 98, 3, 76, 5, 13, 8, 63, 2, 45, 4, 43, 6,  7, 
    3, 20, 5, 16, 1, 65, 0, 13, 2, 93, 8, 93, 7, 57, 6, 91, 4, 21, 
    3, 41, 1, 56, 2, 19, 5, 84, 7,  5, 6, 63, 8, 14, 4, 80, 0, 23, 
    1, 10, 2, 67, 3, 77, 0, 60, 7, 96, 4, 26, 6, 25, 8, 21, 5, 65, 
    0, 26, 3, 49, 7, 22, 5, 45, 8, 93, 6, 30, 4, 39, 1, 22, 2,  3, 
    4, 19, 2, 39, 8, 92, 6, 77, 7,  3, 5, 22, 1, 13, 3, 87, 0, 77, 
    4, 82, 8, 68, 2, 87, 6, 38, 0, 73, 7,  3, 1, 46, 5, 69, 3, 82, 
    6, 62, 2, 96, 5, 86, 7, 62, 4, 73, 0, 66, 8, 56, 1, 94, 3, 79, 
    3, 52, 0, 44, 8, 63, 2, 83, 7, 46, 6, 98, 4, 42, 5,  4, 1, 90
  };
  const int q6365[] = {
    9, 9, // Number of jobs and machines
    7, 12, 1, 28, 3, 71, 4, 28, 5, 95, 0, 33, 6, 47, 8, 74, 2,  8, 
    2, 82, 5, 67, 0, 28, 3, 94, 8, 80, 7, 43, 6,  5, 1, 89, 4, 38, 
    6, 35, 3, 41, 0, 34, 7, 36, 8, 42, 4, 47, 1, 93, 2, 60, 5, 24, 
    3, 14, 4, 91, 1, 19, 5, 45, 0,  1, 8, 34, 6, 58, 7, 59, 2, 37, 
    1, 75, 6, 24, 8, 57, 5, 66, 2, 86, 7, 27, 0, 23, 4, 43, 3, 65, 
    6, 40, 7, 44, 5, 41, 3,  2, 2, 92, 1, 84, 4, 56, 8, 74, 0,  9, 
    6, 38, 7, 35, 5,  9, 1, 55, 4, 94, 2, 93, 8, 15, 3, 53, 0, 98, 
    8, 24, 6, 96, 4, 80, 7, 19, 1, 15, 0, 46, 2,  9, 5, 27, 3,  8, 
    5, 45, 4, 12, 2, 36, 8,  7, 3, 19, 1,  2, 6, 34, 0, 76, 7, 47
  };
  const int q6366[] = {
    9, 9, // Number of jobs and machines
    0, 22, 2, 72, 6,  8, 5, 34, 8, 24, 7, 18, 3, 35, 4, 75, 1, 32, 
    1, 75, 7, 20, 6, 85, 0, 25, 5, 97, 2, 69, 8, 64, 4, 68, 3, 35, 
    4, 13, 1, 84, 5, 60, 7, 28, 8,  8, 3, 47, 0, 70, 6,  8, 2, 96, 
    1, 60, 0, 76, 2, 39, 5, 81, 7, 32, 3, 75, 6, 68, 4, 37, 8, 64, 
    4, 90, 7, 80, 8, 76, 1, 90, 2, 93, 0, 12, 5, 18, 3, 78, 6, 69, 
    6, 25, 7, 69, 1, 95, 0, 87, 3, 37, 5, 85, 8, 81, 4, 44, 2,  9, 
    7, 61, 0, 34, 5, 86, 6, 45, 8, 48, 4, 72, 1, 61, 3, 69, 2, 42, 
    3, 61, 6, 27, 4, 63, 7, 36, 0, 46, 8, 24, 2, 12, 1, 67, 5, 48, 
    6, 34, 0, 10, 7, 70, 4, 16, 1, 19, 2, 87, 8, 72, 3, 77, 5, 13
  };
  const int q6367[] = {
    9, 9, // Number of jobs and machines
    0,  5, 4, 87, 2, 47, 8, 66, 5, 72, 6,  6, 7, 64, 3,  6, 1, 83, 
    7, 34, 1, 66, 3, 40, 2, 82, 4, 49, 0, 15, 8, 93, 5, 79, 6, 60, 
    4, 86, 0, 43, 8, 92, 1, 89, 3, 96, 7, 94, 6, 35, 5, 83, 2,  2, 
    4, 67, 3, 19, 2, 82, 7, 50, 8, 78, 5, 35, 6,  6, 1, 76, 0, 98, 
    7, 73, 3,  7, 0, 47, 5, 26, 1, 69, 8, 90, 6, 91, 4, 39, 2, 73, 
    8, 67, 4, 95, 5, 46, 3, 28, 0,  2, 6, 31, 1, 73, 2, 56, 7, 56, 
    1, 70, 6,  9, 5, 66, 3, 85, 0, 53, 8, 68, 7, 25, 4, 44, 2,  7, 
    4, 14, 3, 92, 6, 61, 0, 57, 5, 65, 8, 68, 1,  2, 2, 41, 7, 94, 
    7, 74, 5, 99, 6, 42, 0, 26, 1, 78, 2,  7, 4, 15, 3, 89, 8, 37
  };
  const int q6368[] = {
    9, 9, // Number of jobs and machines
    1, 57, 0, 94, 4, 26, 5, 36, 6, 71, 2, 63, 3, 90, 7, 44, 8, 16, 
    7, 94, 0, 12, 1, 87, 3, 14, 5, 63, 2, 81, 4, 15, 6, 74, 8, 87, 
    1, 74, 0, 46, 3, 41, 8, 19, 5, 89, 4, 43, 6, 10, 7, 63, 2, 92, 
    7, 12, 1, 49, 6, 59, 2, 84, 5, 54, 3, 65, 8, 63, 0, 13, 4, 49, 
    7, 69, 5, 12, 4, 47, 6, 49, 0, 55, 8, 78, 2, 31, 3, 22, 1, 39, 
    5, 41, 1, 41, 3, 65, 2, 45, 8, 68, 0, 56, 4, 48, 7, 60, 6, 85, 
    1, 71, 2, 48, 5, 81, 0, 47, 3, 39, 8, 49, 6, 56, 4, 65, 7, 91, 
    1, 68, 7, 40, 5, 98, 6, 79, 4, 32, 0, 53, 8, 51, 3, 98, 2, 70, 
    5, 67, 7, 19, 1, 34, 8, 99, 2, 38, 4, 29, 3, 43, 0,  7, 6, 52
  };
  const int q6369[] = {
    9, 9, // Number of jobs and machines
    3, 65, 1, 91, 5, 31, 6, 87, 7, 14, 0, 94, 4, 36, 2, 22, 8, 30, 
    5, 31, 0, 62, 1, 37, 6, 28, 4, 62, 8, 95, 7,  1, 2, 57, 3, 75, 
    3, 15, 7, 88, 5,  8, 4, 71, 2, 53, 0, 48, 8, 80, 1, 68, 6, 51, 
    7, 12, 3, 85, 8, 42, 0, 38, 6, 17, 5, 29, 2, 34, 4, 53, 1, 84, 
    0, 29, 4, 37, 7,  6, 6, 81, 8, 23, 1,  5, 2, 51, 5, 61, 3, 35, 
    7, 30, 8, 18, 3, 85, 5, 89, 0, 24, 4, 57, 1, 89, 6, 19, 2, 44, 
    0, 82, 3, 71, 7, 72, 8, 10, 5, 19, 6, 31, 4, 92, 2, 90, 1, 71, 
    8,  2, 1,  4, 6,  4, 3, 87, 7,  3, 5, 34, 4, 16, 2, 69, 0, 55, 
    3, 56, 2, 97, 0, 65, 4, 51, 1, 14, 5, 74, 6, 21, 8, 41, 7, 41
  };
  const int q6370[] = {
    9, 9, // Number of jobs and machines
    1, 48, 5, 67, 7, 22, 0, 77, 2, 42, 3, 49, 4, 70, 8, 14, 6, 32, 
    2, 10, 8, 18, 3, 85, 4, 97, 6, 78, 1, 25, 7, 96, 0, 82, 5, 79, 
    2, 45, 1,  1, 6, 12, 7, 52, 5, 55, 8, 41, 0, 25, 4, 11, 3,  8, 
    8, 59, 3, 42, 2, 37, 5, 16, 1, 38, 0, 98, 6, 59, 7, 87, 4, 10, 
    5, 42, 8, 12, 0,  3, 4, 20, 6, 58, 7, 82, 2, 28, 3, 53, 1, 39, 
    7, 93, 2, 68, 8, 19, 6, 23, 1, 73, 3, 58, 0, 66, 5, 52, 4, 94, 
    6, 33, 4,  7, 7,  1, 2, 30, 5, 83, 8, 50, 0, 92, 3, 45, 1, 78, 
    8, 71, 2, 99, 4, 72, 0,  4, 5, 92, 1, 63, 6, 75, 7, 73, 3, 95, 
    0, 84, 6, 10, 5, 81, 7, 79, 8, 95, 2,  7, 4, 70, 1, 36, 3, 80
  };
  const int q6371[] = {
    9, 9, // Number of jobs and machines
    8, 76, 1, 26, 7, 94, 5, 78, 6, 68, 4, 98, 3, 99, 0, 63, 2, 62, 
    0, 11, 4, 89, 1, 81, 5, 62, 2, 76, 7, 31, 8, 75, 6, 77, 3, 83, 
    3, 52, 8, 23, 1, 90, 7, 57, 4, 80, 2, 19, 5, 92, 0, 35, 6, 60, 
    8,  5, 1, 17, 0, 76, 2, 17, 5, 41, 7, 18, 6, 74, 3, 57, 4, 63, 
    8, 24, 7, 52, 5, 90, 1, 31, 4, 29, 0, 16, 6, 22, 3, 42, 2, 99, 
    6, 39, 2, 84, 4, 75, 8, 30, 5, 32, 0,  5, 3, 39, 7, 14, 1, 48, 
    1, 51, 6, 57, 4, 14, 5, 20, 8, 56, 2, 55, 3,  4, 0, 77, 7, 62, 
    0,  7, 1, 80, 5, 73, 3, 51, 7,  7, 4, 40, 6, 77, 2, 66, 8, 52, 
    6, 89, 2, 82, 7, 41, 4, 22, 3, 88, 5,  8, 8,  6, 0, 99, 1, 86
  };
  const int q6372[] = {
    9, 9, // Number of jobs and machines
    5, 75, 8, 87, 1, 46, 7, 91, 0, 28, 4, 12, 6,  4, 2, 31, 3, 11, 
    4, 79, 3, 95, 7,  3, 8, 46, 6, 34, 1, 78, 0, 45, 2, 83, 5, 14, 
    3, 38, 5, 80, 0, 93, 1, 27, 6, 34, 4, 34, 2,  7, 8, 77, 7, 34, 
    7, 84, 4, 44, 8, 15, 0, 69, 3, 93, 1, 10, 5, 79, 6, 88, 2, 81, 
    3, 24, 1, 22, 5, 85, 0, 57, 7, 32, 6, 78, 4, 53, 8, 62, 2, 30, 
    2, 85, 1, 12, 0, 27, 6, 35, 3, 77, 5, 89, 8, 20, 4,  2, 7, 67, 
    8, 42, 1, 46, 4, 12, 2, 89, 7, 82, 6, 17, 5, 87, 0, 49, 3, 13, 
    4, 69, 3, 85, 5, 99, 6, 21, 2, 10, 0, 29, 8, 16, 1, 13, 7, 26, 
    5, 70, 8, 25, 4, 26, 0, 60, 6, 50, 3, 35, 2, 38, 7, 32, 1,  4
  };
  const int q6373[] = {
    9, 9, // Number of jobs and machines
    1, 39, 6, 80, 5, 69, 3,  7, 2, 99, 7,  9, 8, 77, 4, 16, 0, 14, 
    7, 10, 2, 24, 4, 92, 3, 48, 1, 14, 0, 99, 5, 96, 6, 15, 8, 90, 
    5, 94, 7, 44, 4, 19, 0, 65, 8, 87, 3, 24, 2, 85, 6, 48, 1, 60, 
    2, 57, 1, 65, 7, 83, 5, 30, 3, 83, 4, 26, 6,  2, 8, 10, 0, 65, 
    8, 28, 5, 33, 1, 77, 2, 60, 7, 90, 0, 24, 3, 55, 4, 67, 6, 43, 
    8, 60, 4, 69, 0, 34, 1, 11, 5, 26, 6, 32, 2, 34, 3, 15, 7, 43, 
    2, 91, 4, 37, 8, 26, 0, 52, 3, 26, 6, 61, 1, 90, 7, 55, 5, 36, 
    8, 33, 3, 36, 4, 70, 1, 51, 7, 15, 2, 12, 0,  6, 5, 60, 6, 20, 
    3, 53, 0, 85, 4, 99, 8, 43, 6, 63, 2, 28, 1, 64, 5,  9, 7, 78
  };
  const int q6374[] = {
    9, 9, // Number of jobs and machines
    4, 92, 5, 76, 6, 65, 3, 77, 2,  1, 8, 94, 1, 97, 7, 31, 0, 53, 
    0, 68, 2, 44, 3, 67, 8, 29, 6, 28, 7, 29, 1, 88, 5, 34, 4, 90, 
    7, 79, 4,  7, 2, 47, 8, 20, 3, 32, 6, 98, 0, 59, 1,  9, 5, 80, 
    2, 61, 1, 88, 4, 85, 0, 21, 7, 69, 6, 94, 3, 61, 8, 33, 5, 58, 
    1, 69, 6, 67, 5, 29, 4, 72, 8,  2, 7, 78, 0, 14, 2, 63, 3, 75, 
    0, 79, 2, 78, 6, 43, 7, 60, 5, 49, 1, 40, 3, 15, 8, 57, 4, 84, 
    3, 66, 0, 23, 8, 62, 7,  5, 1, 62, 5, 13, 2,  8, 6, 76, 4, 30, 
    3, 77, 6, 46, 0, 46, 7, 44, 5, 57, 4, 75, 2, 65, 1, 53, 8, 54, 
    2, 79, 8, 76, 5, 39, 6, 98, 4, 79, 7, 50, 1, 51, 0,  7, 3, 13
  };
  const int q6375[] = {
    9, 9, // Number of jobs and machines
    6, 18, 2, 25, 4, 11, 3, 70, 1, 62, 7, 74, 0, 83, 5, 40, 8,  7, 
    7, 51, 1, 37, 0, 61, 2, 32, 8, 14, 6, 12, 5, 70, 3, 33, 4, 83, 
    6, 42, 1, 31, 0, 65, 7, 67, 5, 63, 3, 45, 8, 91, 4, 53, 2, 98, 
    2, 83, 3,  8, 6, 12, 4, 42, 5, 69, 1,  4, 8, 62, 7, 39, 0, 29, 
    6, 56, 0, 56, 5, 15, 8, 65, 3, 88, 7, 79, 4, 79, 1, 57, 2, 92, 
    6, 69, 5,  9, 4, 82, 3, 64, 1, 34, 0, 89, 2,  3, 8, 69, 7, 47, 
    4,  4, 1, 97, 5, 45, 2, 55, 7, 17, 8, 99, 0, 90, 3, 83, 6, 28, 
    3, 30, 5, 23, 8, 57, 1, 25, 6, 35, 7, 22, 0, 98, 4, 17, 2, 10, 
    8, 29, 5, 76, 7, 65, 0,  5, 1, 72, 2, 75, 4, 89, 3,  7, 6, 43
  };
  const int q6376[] = {
    9, 9, // Number of jobs and machines
    4, 39, 2, 56, 0, 39, 5, 66, 1, 93, 3, 85, 7, 59, 8, 55, 6, 45, 
    8, 39, 2, 54, 4, 22, 0, 24, 6, 59, 7, 84, 3, 30, 1, 54, 5, 68, 
    5, 28, 3, 30, 7, 90, 6, 70, 4,  5, 0,  8, 2, 33, 1, 54, 8, 56, 
    3, 12, 6, 56, 2, 52, 1, 75, 0, 11, 7, 95, 4, 64, 8,  9, 5, 12, 
    6, 18, 4, 33, 1, 89, 8, 17, 3, 96, 7, 28, 2, 69, 5, 32, 0,  5, 
    5, 83, 3, 98, 1, 58, 6,  5, 8, 46, 7, 29, 4, 83, 0, 42, 2, 75, 
    7, 69, 3, 19, 8, 64, 2, 94, 1, 43, 4, 29, 0, 63, 5, 16, 6, 70, 
    7, 55, 8, 93, 6, 24, 3, 96, 5, 10, 2, 71, 0, 17, 4, 28, 1, 54, 
    2, 19, 3, 20, 6, 55, 5,  6, 4, 99, 7, 19, 8, 60, 0, 49, 1,  4
  };
  const int q6377[] = {
    9, 9, // Number of jobs and machines
    3, 72, 2, 47, 8, 29, 7,  2, 0, 82, 6, 25, 4, 42, 1,  2, 5,  1, 
    4, 77, 8, 20, 1, 56, 6, 74, 3, 25, 5, 11, 0, 25, 7,  2, 2, 32, 
    5, 61, 6, 90, 3, 13, 8, 51, 1, 22, 0, 72, 2, 72, 7,  1, 4, 96, 
    2, 59, 6, 58, 3, 64, 5,  8, 4, 11, 1, 61, 0, 14, 8, 16, 7, 47, 
    2, 39, 8, 89, 5, 47, 6, 66, 4, 72, 7, 65, 1,  6, 0, 94, 3, 55, 
    7, 73, 1,  1, 3, 97, 6,  7, 0, 64, 2, 14, 5, 54, 4, 57, 8, 61, 
    3, 91, 2,  5, 7, 40, 4, 10, 1, 99, 6, 67, 8, 31, 5, 76, 0, 10, 
    1, 90, 2, 86, 3, 19, 0, 59, 8, 20, 4, 24, 5, 94, 6, 33, 7, 79, 
    0, 65, 7, 98, 2, 69, 5, 23, 4, 25, 6, 51, 3, 10, 1, 48, 8, 58
  };
  const int q6378[] = {
    9, 9, // Number of jobs and machines
    4, 64, 5, 45, 2, 31, 1, 81, 8, 65, 6, 95, 3, 74, 7, 53, 0, 21, 
    1, 71, 4, 24, 2, 96, 5, 85, 7, 81, 6, 23, 8,  5, 3, 54, 0, 47, 
    6, 14, 7, 93, 4, 33, 0, 12, 8, 39, 2, 31, 5, 48, 3, 33, 1, 76, 
    4, 30, 1, 38, 0, 86, 6, 40, 2, 39, 8, 53, 5, 37, 3, 49, 7, 40, 
    0, 58, 1,  5, 2, 23, 7, 90, 3, 88, 5, 77, 8, 44, 6,  7, 4, 63, 
    7, 38, 2, 80, 0, 89, 6, 25, 5,  9, 8, 38, 4, 84, 3, 12, 1, 10, 
    3, 71, 7,  5, 8, 67, 0, 87, 1, 60, 6, 20, 2, 61, 4, 70, 5, 67, 
    0, 16, 3, 80, 2, 52, 6, 26, 8, 46, 4, 47, 5, 98, 7, 53, 1, 15, 
    5, 38, 2, 59, 6, 28, 3, 67, 8, 35, 4, 77, 7, 57, 1, 85, 0,  1
  };
  const int q6379[] = {
    9, 9, // Number of jobs and machines
    7, 81, 4, 61, 3, 82, 5, 37, 2, 17, 8, 94, 1, 89, 0, 50, 6,  4, 
    6, 23, 8, 37, 5, 63, 7, 33, 4, 59, 2, 35, 1, 47, 0, 67, 3, 47, 
    5, 66, 1, 42, 4, 56, 3, 63, 2, 97, 6, 22, 7, 12, 8, 30, 0, 18, 
    5, 95, 1, 71, 6, 16, 0, 86, 2,  6, 3, 44, 7, 91, 8, 65, 4, 88, 
    4, 76, 7, 50, 0, 30, 5, 29, 6, 10, 2, 71, 3, 99, 1, 16, 8, 66, 
    6,  6, 3, 24, 5, 86, 8, 34, 2, 72, 0, 31, 7, 10, 4, 78, 1, 99, 
    4, 81, 5, 59, 0,  9, 2,  5, 1, 61, 6, 53, 3, 75, 7, 49, 8, 62, 
    2, 58, 6,  1, 3, 55, 1, 53, 7, 95, 5, 92, 8, 79, 0, 45, 4,  1, 
    6, 75, 2, 91, 0,  9, 8, 64, 5, 28, 4, 92, 7,  9, 3, 70, 1,  3
  };
  const int q6380[] = {
    9, 9, // Number of jobs and machines
    7, 91, 2, 94, 8,  1, 4, 65, 5, 61, 3, 83, 6, 46, 0, 48, 1, 53, 
    7, 81, 3, 53, 2, 41, 6, 84, 8, 77, 1, 33, 0, 30, 4, 12, 5, 13, 
    3,  6, 4, 23, 2, 99, 5, 68, 7, 29, 6, 90, 8, 65, 1, 84, 0, 73, 
    6, 99, 4, 50, 7, 25, 5, 56, 1, 30, 2, 14, 8, 91, 3, 19, 0, 30, 
    2, 55, 6, 40, 1, 61, 7, 93, 5, 38, 8, 46, 3, 29, 4, 20, 0, 16, 
    3, 74, 7, 62, 1, 75, 0, 21, 5, 46, 4, 15, 2, 17, 8, 48, 6, 13, 
    1, 20, 2, 46, 7, 23, 8, 81, 4, 12, 5, 72, 3, 92, 0, 10, 6, 16, 
    0, 95, 6, 98, 8, 54, 5, 91, 4,  2, 1, 79, 3, 66, 2, 35, 7, 78, 
    3, 52, 4, 79, 6, 45, 0, 90, 1, 37, 5,  4, 2, 32, 7, 13, 8, 19
  };
  const int q6381[] = {
    9, 9, // Number of jobs and machines
    0, 44, 8, 87, 7, 11, 3, 92, 2, 75, 4, 44, 5, 66, 6, 24, 1, 93, 
    4, 92, 2, 61, 7, 36, 1, 73, 8, 28, 0, 44, 3, 92, 5, 61, 6, 69, 
    3, 50, 4, 49, 6, 14, 8,  7, 1, 88, 0, 48, 5, 57, 7, 24, 2, 65, 
    4, 47, 1, 30, 8, 39, 3, 62, 6, 34, 7, 98, 0, 90, 2, 70, 5, 43, 
    6, 55, 0, 98, 1, 76, 8, 62, 5, 64, 2, 15, 3, 46, 7, 61, 4, 96, 
    1, 28, 8, 47, 4, 68, 5, 81, 2, 71, 6, 84, 7,  8, 0,  4, 3, 48, 
    2, 80, 8, 28, 6, 83, 3, 29, 0, 92, 5, 59, 1, 69, 4, 43, 7, 28, 
    8, 25, 4, 33, 3, 24, 1, 80, 0, 53, 6, 21, 7,  2, 5, 47, 2, 66, 
    2, 10, 4, 69, 7, 93, 0, 59, 3,  9, 5, 25, 1, 72, 6, 45, 8, 48
  };
  const int q6382[] = {
    9, 9, // Number of jobs and machines
    5, 10, 0, 19, 3, 22, 1, 75, 2, 61, 7, 73, 6, 72, 4, 57, 8, 73, 
    8, 34, 1, 72, 3, 58, 4, 67, 6, 30, 0, 47, 5, 88, 2, 50, 7, 27, 
    1, 43, 7, 58, 3, 30, 5, 14, 0, 16, 6, 50, 8, 65, 2, 25, 4, 43, 
    1,  1, 2, 86, 0, 26, 7, 36, 4, 17, 8, 14, 3, 99, 5, 98, 6, 81, 
    6, 70, 1, 65, 4, 98, 7, 20, 3, 47, 8, 53, 5, 28, 2, 53, 0, 59, 
    2, 28, 3, 16, 1, 96, 0, 17, 5,  9, 8, 70, 4, 92, 7, 12, 6, 54, 
    8, 49, 7, 22, 3, 98, 2, 77, 4, 90, 1,  4, 5, 32, 6, 90, 0, 95, 
    8, 70, 0, 59, 6, 92, 2, 84, 4, 62, 1, 60, 5,  7, 7,  5, 3, 28, 
    7, 21, 8,  1, 3, 12, 6, 57, 4, 42, 1,  9, 2, 68, 0, 42, 5, 39
  };
  const int q6383[] = {
    9, 9, // Number of jobs and machines
    0, 78, 2, 27, 4, 68, 7, 41, 5, 65, 3,  8, 8, 78, 1, 77, 6, 59, 
    8, 18, 4, 71, 2, 51, 3, 96, 5, 22, 1, 76, 0,  7, 6, 86, 7, 38, 
    7, 19, 6, 27, 0, 46, 8, 22, 4, 78, 2, 32, 3, 96, 1, 61, 5, 31, 
    0,  4, 3, 63, 4, 25, 5, 44, 8, 45, 1,  4, 2, 94, 6, 72, 7, 50, 
    6, 56, 3, 80, 2, 22, 5, 61, 4, 55, 7, 73, 0, 64, 8, 25, 1, 69, 
    4, 18, 6, 49, 8, 13, 2, 17, 5, 10, 3, 12, 7, 56, 0, 91, 1, 77, 
    0, 58, 4, 58, 5, 98, 3, 84, 7, 80, 6, 91, 2, 41, 8, 34, 1, 18, 
    3, 61, 1, 78, 0, 11, 7, 95, 4, 24, 2, 32, 5, 68, 6, 94, 8, 17, 
    0, 30, 5, 48, 8, 39, 7, 12, 3, 86, 2, 42, 6, 50, 1, 85, 4, 73
  };
  const int q6384[] = {
    9, 9, // Number of jobs and machines
    1, 55, 6, 58, 8, 56, 4, 59, 5,  9, 0,  3, 7,  9, 2, 97, 3, 47, 
    7, 99, 5,  3, 4, 62, 2, 44, 8, 37, 1, 41, 6, 22, 0, 44, 3, 57, 
    2, 74, 8, 36, 5, 89, 3, 73, 7, 89, 6, 93, 0, 42, 4, 40, 1, 74, 
    4, 20, 0, 69, 6, 20, 8,  4, 7, 92, 5, 70, 2, 66, 3, 82, 1, 26, 
    6, 61, 8, 64, 1, 28, 2, 56, 7, 77, 0, 73, 3, 37, 4, 37, 5, 43, 
    4, 69, 5, 24, 8, 74, 0, 22, 3, 55, 2, 43, 1,  1, 6, 11, 7, 22, 
    3, 26, 1, 10, 7, 58, 8, 63, 0, 26, 4, 95, 5, 96, 2, 83, 6, 84, 
    5, 33, 8, 51, 6, 89, 0, 61, 7, 94, 2, 55, 1, 44, 3, 19, 4,  1, 
    3, 67, 7, 79, 1, 89, 5, 24, 2, 49, 8, 86, 6, 50, 4, 73, 0, 42
  };
  const int q6385[] = {
    9, 9, // Number of jobs and machines
    4, 79, 1, 54, 0,  6, 8, 70, 2, 46, 6, 80, 5, 35, 3, 38, 7, 83, 
    1, 28, 4, 87, 8,  4, 3, 36, 2, 75, 5, 99, 6, 12, 7, 75, 0, 20, 
    8, 17, 1,  4, 2, 79, 4, 64, 7, 76, 3,  3, 0, 97, 5, 27, 6, 40, 
    5, 10, 4, 25, 7, 79, 0, 51, 3, 11, 8, 51, 2,  5, 6, 92, 1, 32, 
    0, 79, 2,  3, 8, 47, 7, 41, 3, 28, 1, 20, 6, 95, 5, 74, 4, 58, 
    6, 22, 1, 23, 5, 86, 3, 50, 8, 29, 0, 69, 2, 42, 4, 81, 7, 99, 
    5, 58, 4, 42, 7,  9, 6, 92, 1, 95, 2, 79, 3, 49, 8, 41, 0, 62, 
    5, 17, 7, 51, 6, 76, 3, 25, 0,  4, 1, 62, 4, 26, 8, 15, 2, 70, 
    1, 59, 2, 29, 6, 37, 7, 13, 3, 69, 0, 76, 4, 58, 5, 91, 8, 83
  };
  const int q6386[] = {
    9, 9, // Number of jobs and machines
    1, 76, 7, 32, 0,  6, 2, 84, 4, 89, 6, 99, 8, 59, 3, 56, 5, 82, 
    4,  3, 1, 64, 2, 91, 0, 72, 6, 93, 7, 93, 5, 72, 3, 39, 8, 66, 
    4, 31, 7, 31, 2, 50, 8,  8, 3, 31, 1, 86, 0, 10, 6, 85, 5, 97, 
    8,  9, 4, 44, 6, 53, 5, 40, 7, 14, 0, 40, 3, 13, 1, 29, 2, 31, 
    6, 79, 5, 58, 4, 25, 1, 98, 8,  3, 0,  7, 2, 19, 7, 21, 3, 89, 
    5, 26, 3, 35, 6, 56, 7, 53, 0,  5, 4, 32, 8, 76, 2,  7, 1, 58, 
    2, 89, 8, 45, 7, 62, 0, 12, 4,  4, 3,  4, 5, 14, 6, 39, 1, 97, 
    3, 94, 7, 98, 5,  4, 6, 44, 1, 26, 2, 26, 0, 34, 4, 32, 8, 72, 
    3, 65, 1,  6, 4, 92, 0, 57, 5, 45, 2, 62, 8, 71, 7, 82, 6, 75
  };
  const int q6387[] = {
    9, 9, // Number of jobs and machines
    1, 74, 2, 65, 3, 47, 4, 85, 0,  9, 5, 85, 7, 59, 6, 22, 8, 55, 
    2, 55, 4, 68, 0, 45, 7, 11, 6, 54, 5, 11, 1, 13, 3, 67, 8, 70, 
    6, 93, 2, 33, 5, 92, 4, 44, 0, 17, 8, 81, 1, 53, 7, 40, 3, 84, 
    0, 94, 4, 93, 1, 43, 6, 88, 2, 12, 5, 71, 8, 52, 3, 46, 7,  7, 
    0, 25, 5, 87, 2, 57, 4, 50, 1, 86, 3,  5, 8, 22, 6, 38, 7, 74, 
    2, 29, 5, 88, 1, 93, 0, 59, 3, 13, 7, 90, 8, 31, 6, 75, 4, 69, 
    3, 16, 5, 71, 7, 73, 1, 37, 8, 20, 2, 32, 4, 50, 6, 62, 0, 52, 
    5, 43, 6, 36, 8, 44, 0, 20, 2, 48, 3, 70, 1, 79, 7, 91, 4, 71, 
    2, 35, 7, 81, 8, 90, 1,  7, 0, 95, 6, 60, 4, 69, 5, 38, 3, 96
  };
  const int q6388[] = {
    9, 9, // Number of jobs and machines
    0,  7, 2, 47, 8, 65, 5, 83, 4,  1, 1, 95, 3, 27, 6, 48, 7, 70, 
    1, 79, 7, 88, 3, 57, 4, 92, 5, 44, 8, 73, 6, 28, 0, 42, 2, 89, 
    0, 34, 7, 71, 8, 94, 2, 66, 1, 81, 6, 15, 5,  9, 4, 60, 3, 81, 
    2, 31, 0, 81, 3, 80, 7, 23, 1, 70, 6,  7, 5, 40, 8, 21, 4, 96, 
    8, 57, 0, 25, 5, 29, 6, 80, 4, 64, 1, 68, 2, 55, 7, 81, 3, 14, 
    6, 67, 1, 87, 4, 59, 8, 62, 5, 56, 0, 44, 3, 71, 2, 68, 7, 63, 
    8, 64, 2, 89, 0, 22, 3, 87, 5, 71, 6, 36, 7, 57, 1, 22, 4, 85, 
    2, 11, 3, 63, 6, 25, 7, 55, 0, 74, 4,  4, 8, 66, 5, 71, 1, 67, 
    8, 70, 1, 48, 4, 89, 2, 12, 5, 10, 3, 79, 6, 23, 0, 87, 7, 17
  };
  const int q6389[] = {
    9, 9, // Number of jobs and machines
    7, 54, 2, 67, 1, 28, 8, 70, 0, 51, 4, 39, 3, 48, 5, 20, 6, 15, 
    2, 45, 5, 45, 1, 20, 4, 17, 3,  5, 6, 63, 8, 48, 7,  6, 0, 89, 
    6, 25, 4, 42, 8, 44, 2, 51, 5, 32, 7,  8, 3,  1, 0, 33, 1, 52, 
    3, 41, 7, 79, 2, 64, 4, 85, 8, 86, 1, 62, 5, 21, 6, 86, 0, 67, 
    1, 37, 3, 86, 0, 34, 2, 17, 6,  2, 7, 31, 5, 74, 8,  6, 4, 86, 
    6, 26, 8, 24, 7, 82, 5, 46, 1, 54, 4, 44, 3, 57, 2, 82, 0, 72, 
    5,  1, 0, 33, 4,  4, 8, 85, 6, 37, 3, 22, 1, 14, 2, 44, 7, 64, 
    6, 63, 4, 71, 3, 38, 5, 58, 2, 53, 1, 89, 8, 26, 0, 23, 7, 89, 
    1, 54, 2, 39, 8,  3, 5, 79, 0, 60, 7, 25, 3, 89, 6, 14, 4, 19
  };
  const int q6390[] = {
    9, 9, // Number of jobs and machines
    5, 56, 1, 88, 8, 61, 2, 17, 3,  4, 6, 59, 0,  1, 7, 99, 4, 89, 
    8, 74, 0, 16, 3, 19, 4, 40, 5,  1, 6, 71, 2,  7, 1,  1, 7, 71, 
    3, 31, 8, 51, 4, 32, 1, 94, 2, 88, 0, 50, 5, 30, 6, 13, 7, 67, 
    4, 66, 2, 79, 8, 86, 1, 64, 7, 72, 5, 10, 3, 57, 6, 24, 0, 31, 
    8, 31, 1, 16, 6, 41, 5,  5, 3, 44, 4, 82, 7, 76, 0, 88, 2,  7, 
    8, 64, 0, 75, 5, 79, 4, 47, 1, 82, 2, 97, 7, 40, 3, 36, 6, 87, 
    0, 37, 7, 81, 2,  6, 6, 28, 3, 84, 4, 75, 8, 83, 1, 79, 5, 14, 
    7, 44, 2, 33, 6, 99, 5, 77, 3, 63, 4, 22, 0, 21, 8, 10, 1, 27, 
    0, 64, 8, 78, 2, 23, 5, 76, 1, 57, 4, 99, 7, 73, 3, 92, 6, 18
  };
  const int q6391[] = {
    9, 9, // Number of jobs and machines
    0, 47, 2, 64, 8, 58, 1, 42, 3, 71, 4, 39, 7, 55, 6, 30, 5, 72, 
    7, 76, 5, 97, 6, 69, 1, 97, 0, 17, 3, 23, 4, 85, 8,  2, 2, 67, 
    8, 70, 6, 44, 1, 15, 7, 87, 2, 71, 3, 49, 0, 26, 4,  9, 5, 29, 
    6, 10, 1, 22, 5,  3, 3, 31, 2, 63, 7, 22, 4, 47, 8, 10, 0, 46, 
    1, 69, 0, 82, 7, 37, 4, 98, 8, 23, 2, 16, 5, 80, 3, 28, 6, 44, 
    4, 99, 3, 36, 6, 43, 8,  6, 7, 13, 5,  6, 0,  7, 1, 87, 2, 57, 
    8, 13, 5, 98, 7,  5, 3, 40, 2, 81, 6,  1, 1, 43, 0, 27, 4, 26, 
    4, 52, 3, 27, 0, 93, 1, 75, 6, 34, 8, 21, 7,  6, 2,  6, 5, 91, 
    4, 42, 5, 83, 3, 70, 2, 33, 6,  5, 7, 68, 1, 10, 8, 70, 0, 40
  };
  const int q6392[] = {
    9, 9, // Number of jobs and machines
    1, 15, 5, 99, 4, 81, 8, 62, 7, 53, 3, 37, 6, 71, 2, 12, 0, 43, 
    3, 18, 6,  2, 5, 93, 1, 30, 2, 32, 8, 74, 4, 19, 7, 65, 0, 40, 
    1, 17, 6, 54, 4, 52, 2,  9, 5, 32, 0,  3, 8,  4, 3, 29, 7,  2, 
    4, 27, 8, 17, 7, 57, 2, 15, 1, 30, 3, 21, 6, 39, 0, 60, 5, 61, 
    8, 60, 2, 82, 7, 82, 5, 76, 3, 47, 6, 58, 0,  1, 1, 74, 4, 96, 
    2, 51, 0, 85, 7, 41, 3, 12, 4, 40, 1, 62, 6, 77, 5, 24, 8, 44, 
    8, 66, 3, 92, 1, 92, 4, 50, 5, 23, 7, 23, 0, 21, 2, 83, 6, 19, 
    1, 99, 4, 98, 8, 83, 3, 29, 2, 65, 6, 20, 0, 68, 5, 71, 7, 73, 
    5, 45, 3, 22, 4, 73, 6, 84, 0, 75, 1, 69, 8, 45, 7, 25, 2, 31
  };
  const int q6393[] = {
    9, 9, // Number of jobs and machines
    4, 35, 7, 15, 6, 64, 3, 39, 1, 44, 2, 57, 0, 51, 8, 40, 5, 47, 
    3, 66, 8, 52, 5,  1, 4, 98, 7, 50, 6, 20, 2, 77, 0, 51, 1, 17, 
    0, 39, 6, 67, 4, 68, 3, 94, 2, 17, 1, 34, 5, 40, 8, 98, 7, 81, 
    0, 60, 2, 10, 1, 65, 8, 84, 5, 21, 7, 47, 3, 41, 6, 41, 4,  4, 
    3,  6, 2, 89, 8, 67, 4, 71, 5, 58, 7, 83, 6, 27, 0, 31, 1, 10, 
    4, 34, 6, 61, 3, 23, 8, 39, 2, 94, 0,  7, 7, 98, 1, 19, 5, 86, 
    2, 40, 1, 36, 6, 20, 7, 18, 8, 27, 5, 37, 4, 74, 3, 14, 0, 12, 
    1, 76, 5, 72, 8, 44, 3, 54, 4,  3, 2, 22, 6, 98, 7, 94, 0, 49, 
    4, 59, 2,  9, 7, 98, 5, 59, 0,  7, 6, 96, 3, 55, 1,  7, 8, 32
  };
  const int q6394[] = {
    9, 9, // Number of jobs and machines
    5, 89, 7, 32, 0, 49, 1, 28, 3, 38, 6, 35, 8, 51, 4, 51, 2, 89, 
    8, 78, 5, 17, 4, 19, 7, 70, 3, 55, 2, 87, 0, 17, 1, 37, 6, 20, 
    8, 83, 4, 71, 1, 58, 0, 64, 2, 98, 5, 14, 7, 11, 6, 40, 3, 12, 
    5, 86, 7, 32, 4, 56, 2, 15, 8, 44, 1, 49, 3, 65, 6, 34, 0, 72, 
    4, 69, 0, 13, 7,  5, 1, 64, 3, 85, 8, 38, 6, 36, 5, 43, 2, 76, 
    3, 41, 6, 21, 4, 64, 5, 91, 1, 42, 8, 24, 0, 44, 2, 92, 7, 32, 
    5, 91, 4, 24, 6, 28, 3,  8, 7, 37, 2, 25, 0, 53, 1, 79, 8,  3, 
    6, 33, 8, 12, 4, 90, 2,  9, 5, 55, 0, 43, 3,  8, 1, 46, 7, 74, 
    5, 15, 6, 14, 3, 97, 8, 79, 1, 50, 7, 13, 4, 93, 2, 16, 0, 55
  };
  const int q6395[] = {
    9, 9, // Number of jobs and machines
    6, 33, 3, 39, 2, 21, 1, 73, 5, 99, 4,  4, 0, 17, 7, 88, 8, 10, 
    1, 35, 5, 34, 7, 22, 3, 84, 0, 25, 6, 25, 2, 69, 8, 16, 4, 12, 
    7, 57, 0, 17, 6, 85, 4, 39, 5,  5, 1, 46, 3, 97, 2, 46, 8, 73, 
    4, 52, 6, 32, 5, 78, 1, 98, 2, 24, 8,  3, 3, 30, 0, 27, 7, 42, 
    2, 97, 4,  7, 6, 83, 1, 25, 8, 95, 5,  7, 0, 48, 3, 47, 7, 25, 
    2, 50, 6, 99, 8, 11, 3, 42, 1, 81, 4, 35, 7, 15, 0, 71, 5, 54, 
    1, 40, 6, 31, 5, 81, 2, 44, 4, 13, 0, 31, 3, 34, 7, 89, 8, 17, 
    8, 47, 3, 70, 4, 24, 5, 77, 0, 49, 7, 99, 2, 64, 6, 68, 1, 87, 
    5, 55, 0, 42, 3, 88, 6, 37, 8,  8, 2,  6, 1, 29, 7, 22, 4, 96
  };
  const int q6396[] = {
    9, 9, // Number of jobs and machines
    7, 24, 3, 40, 0, 77, 4, 69, 5, 16, 6, 39, 8, 33, 1, 47, 2, 54, 
    8,  4, 0, 43, 4, 46, 2, 43, 6, 56, 1, 67, 3, 66, 5, 73, 7, 26, 
    1, 75, 4, 67, 3, 15, 5, 41, 0, 65, 6, 52, 2,  4, 8, 47, 7,  9, 
    4, 61, 6, 53, 1, 30, 8,  3, 0, 32, 5, 54, 7, 67, 2, 47, 3, 60, 
    5, 55, 4, 16, 8, 42, 7, 48, 0, 11, 3, 40, 1, 51, 6, 54, 2, 97, 
    5, 22, 6, 79, 2, 22, 0, 34, 1, 58, 7, 17, 3, 73, 8, 83, 4, 70, 
    0, 82, 2, 73, 8, 43, 3, 84, 6, 52, 4, 36, 7, 51, 1, 73, 5, 79, 
    0, 74, 5, 93, 8, 32, 4, 70, 1, 53, 3, 49, 2, 97, 6, 47, 7, 24, 
    7, 88, 6, 68, 2, 35, 0, 85, 8, 95, 4,  5, 3, 64, 5, 26, 1, 93
  };
  const int q6397[] = {
    9, 9, // Number of jobs and machines
    0, 68, 3, 75, 5, 53, 6, 93, 1, 98, 4, 43, 8, 36, 7, 80, 2, 98, 
    7, 39, 8, 36, 3, 73, 6, 89, 5, 54, 1, 81, 2, 41, 0, 34, 4, 72, 
    2, 61, 0, 98, 6, 88, 3, 55, 7, 35, 5, 16, 8, 29, 1, 45, 4, 50, 
    3, 89, 0, 87, 5, 40, 6, 93, 7, 48, 4, 30, 2,  4, 8, 24, 1, 31, 
    3, 59, 2, 68, 1, 43, 0, 78, 8, 66, 4, 24, 5, 76, 6, 59, 7, 30, 
    2, 69, 1,  9, 8, 98, 3, 71, 4, 47, 6, 44, 5, 97, 7, 49, 0, 55, 
    6, 95, 5, 93, 8, 18, 2, 76, 1, 66, 7, 56, 0, 76, 4, 30, 3, 84, 
    2, 38, 8, 97, 3,  9, 1, 15, 0, 46, 5, 95, 6, 65, 4, 33, 7, 69, 
    2, 87, 1, 59, 7, 94, 0, 27, 4, 39, 8,  5, 6, 78, 3, 84, 5, 28
  };
  const int q6398[] = {
    9, 9, // Number of jobs and machines
    6, 94, 7, 29, 3, 99, 0, 33, 1, 74, 5, 84, 2, 51, 8,  9, 4, 13, 
    3, 52, 1, 60, 2,  6, 0,  4, 7,  8, 4, 75, 8, 96, 5, 90, 6, 97, 
    1, 65, 2, 36, 8, 73, 3, 49, 6, 35, 5, 83, 4, 71, 0, 73, 7, 78, 
    3,  5, 8, 83, 7, 18, 4, 76, 0, 82, 1, 57, 5, 61, 6, 22, 2, 33, 
    6, 53, 5, 82, 1, 26, 7, 70, 4, 71, 8, 16, 0, 66, 3, 96, 2, 44, 
    8, 57, 1, 96, 3, 42, 6, 64, 7, 99, 2, 26, 0, 32, 5, 89, 4, 59, 
    4, 40, 5, 19, 7, 24, 2, 15, 6, 73, 8, 82, 1,  2, 3,  4, 0, 32, 
    1, 16, 3, 46, 5, 32, 8,  7, 0, 84, 4, 39, 6, 66, 7, 72, 2, 31, 
    4,  5, 7, 56, 2, 58, 5, 67, 3, 86, 1, 47, 6, 78, 0, 11, 8, 67
  };
  const int q6399[] = {
    9, 9, // Number of jobs and machines
    0,  2, 8, 70, 6, 11, 5,  8, 3, 12, 7, 92, 4, 27, 1, 87, 2, 97, 
    8, 20, 5,  1, 3, 19, 6, 79, 1, 10, 7, 60, 0, 22, 2,  9, 4, 26, 
    6, 54, 7, 30, 2, 41, 4, 86, 5, 96, 1, 35, 3, 17, 8, 83, 0, 21, 
    7, 22, 8, 34, 4, 94, 6, 80, 3, 94, 1, 70, 5, 18, 2, 87, 0, 74, 
    1, 34, 6, 43, 5, 52, 2,  6, 0, 67, 3, 46, 7, 47, 8, 52, 4, 46, 
    2, 97, 5, 20, 3,  8, 7, 11, 0, 10, 1, 72, 4, 64, 8, 96, 6, 26, 
    8, 47, 0, 83, 2, 32, 3,  2, 6, 41, 5, 41, 4, 22, 7, 61, 1, 90, 
    8, 83, 0, 55, 7, 76, 2, 75, 5, 32, 1,  1, 4, 70, 6, 86, 3, 91, 
    6, 79, 3, 18, 7, 39, 0, 11, 8, 14, 1, 61, 4,  7, 2, 46, 5,  9
  };
  const int q6400[] = {
    9, 9, // Number of jobs and machines
    3, 90, 5, 96, 8, 47, 4, 25, 1,  7, 7, 14, 0, 22, 6, 34, 2, 31, 
    8, 55, 0, 41, 3, 39, 2, 79, 6, 90, 1, 94, 4, 66, 5, 85, 7, 73, 
    2, 65, 0, 42, 1, 75, 4, 69, 6, 10, 5, 61, 3, 15, 7, 14, 8, 81, 
    0, 76, 5, 28, 1, 86, 8, 47, 2, 74, 7, 49, 3, 15, 6, 73, 4, 39, 
    6, 10, 5, 33, 4,  3, 0, 29, 2, 71, 8, 67, 3, 80, 1, 85, 7, 67, 
    3, 76, 7, 56, 8, 43, 2, 20, 5, 41, 0, 72, 6, 11, 1, 14, 4, 64, 
    5, 29, 0, 53, 4, 32, 6, 11, 8, 34, 1, 69, 3, 77, 7, 60, 2, 48, 
    5, 21, 0, 74, 3, 68, 1, 62, 6, 23, 2, 86, 4,  7, 7, 66, 8,  5, 
    7, 44, 2, 27, 1, 31, 4, 95, 5, 60, 0, 77, 6, 83, 8, 91, 3, 90
  };
  const int q6401[] = {
    9, 9, // Number of jobs and machines
    4, 86, 3, 68, 2, 40, 6,  5, 1, 77, 8, 52, 0, 93, 7, 83, 5, 72, 
    5, 84, 8, 69, 3, 50, 0, 10, 2, 79, 4, 87, 6, 68, 7, 63, 1, 58, 
    5, 50, 2, 18, 0, 95, 3, 28, 1,  7, 4, 50, 7, 45, 8, 60, 6, 18, 
    7, 40, 3, 32, 1, 14, 2, 60, 5, 83, 6, 62, 4, 89, 0, 54, 8, 68, 
    3, 45, 0, 15, 6, 56, 8, 29, 7, 31, 1, 25, 5, 27, 4,  2, 2, 73, 
    8, 54, 6, 81, 3, 59, 0, 99, 7, 83, 4, 21, 5, 47, 2, 15, 1, 25, 
    3, 84, 1, 19, 2, 35, 8, 37, 4, 27, 7, 58, 6, 70, 0, 50, 5, 35, 
    6, 81, 5, 21, 0, 30, 4, 21, 2, 84, 1, 52, 3, 33, 7, 75, 8, 84, 
    1, 67, 8, 75, 4,  1, 6,  7, 0, 85, 7, 72, 2, 47, 5, 50, 3, 88
  };
  const int q6402[] = {
    9, 9, // Number of jobs and machines
    5, 84, 3, 17, 0, 41, 7, 61, 8, 54, 4, 16, 2, 29, 6, 86, 1, 70, 
    8, 45, 2, 49, 1, 62, 6, 97, 5, 50, 4, 98, 0, 84, 7, 61, 3, 32, 
    2, 99, 0, 99, 1,  9, 6, 44, 3, 84, 5, 84, 8,  6, 7, 13, 4, 77, 
    2, 51, 0, 61, 5, 35, 6, 71, 4, 36, 1, 28, 7, 18, 8, 24, 3, 70, 
    8, 74, 5, 91, 3, 27, 0, 38, 2, 40, 7, 54, 6,  6, 4, 68, 1, 50, 
    2,  1, 5, 47, 8, 35, 4, 58, 3, 49, 1, 83, 7, 37, 0, 14, 6, 49, 
    5, 33, 7, 67, 8, 73, 4, 31, 3,  1, 6, 49, 0, 61, 1, 85, 2, 94, 
    8, 71, 3, 79, 4, 38, 5, 99, 1, 64, 6, 38, 7, 28, 0, 60, 2, 67, 
    0, 39, 1, 55, 5, 40, 2, 21, 4, 38, 8, 68, 3, 36, 6, 90, 7, 80
  };
  const int q6403[] = {
    9, 9, // Number of jobs and machines
    8, 34, 3, 27, 5, 77, 7,  1, 2, 15, 6, 45, 4, 33, 1, 13, 0, 77, 
    5, 19, 2, 57, 8, 23, 0,  7, 7,  7, 3, 83, 1, 92, 6, 33, 4, 55, 
    4, 61, 5, 94, 0, 74, 8, 43, 7, 58, 3, 56, 1, 96, 2, 22, 6, 50, 
    4, 53, 2, 53, 0, 16, 3,  2, 7, 54, 1, 68, 8, 49, 5, 72, 6, 55, 
    5, 62, 7,  5, 2, 53, 8, 31, 4, 34, 1, 42, 0, 11, 3, 15, 6, 47, 
    5, 18, 3, 72, 8, 71, 4, 57, 2, 36, 7, 34, 0, 21, 1, 73, 6, 73, 
    8, 41, 1, 71, 4, 46, 2, 22, 6, 90, 7,  6, 0, 31, 5, 93, 3, 23, 
    7, 20, 8, 92, 3, 45, 6, 16, 5, 12, 0, 89, 2, 97, 1, 46, 4,  1, 
    2, 54, 7, 28, 6, 19, 0, 55, 3, 82, 1, 70, 5, 12, 8, 82, 4, 30
  };
  const int q6404[] = {
    9, 9, // Number of jobs and machines
    6, 62, 5, 12, 2, 31, 7, 53, 0, 82, 1,  2, 3, 25, 4, 88, 8, 14, 
    7, 59, 4, 40, 0, 69, 6, 82, 3, 75, 8, 16, 1, 82, 2, 70, 5, 91, 
    4, 81, 7, 98, 2, 10, 6, 90, 5,  9, 3, 47, 1, 23, 8, 11, 0, 46, 
    1, 58, 8, 26, 5, 67, 0,  7, 2, 41, 7, 66, 3, 60, 6, 57, 4, 30, 
    5, 49, 4, 10, 8, 51, 1, 37, 6, 11, 2, 34, 3, 68, 7, 28, 0, 77, 
    7, 56, 5, 57, 6, 41, 2, 20, 8, 87, 1, 18, 3, 51, 4, 50, 0, 82, 
    5, 29, 7, 91, 3, 85, 6, 13, 2, 55, 0, 38, 1,  4, 4, 10, 8, 86, 
    2, 21, 7,  5, 1, 43, 8, 96, 3, 71, 5, 55, 4, 75, 6, 23, 0, 83, 
    1, 26, 5, 34, 7, 37, 6, 39, 8, 74, 2, 95, 3, 17, 4, 63, 0, 72
  };
  const int q6405[] = {
    9, 9, // Number of jobs and machines
    0, 49, 2, 29, 3, 15, 8, 74, 1, 64, 5, 25, 4, 16, 6, 21, 7, 58, 
    0, 16, 8, 70, 4, 19, 1,  8, 3, 30, 7, 17, 6, 53, 2, 97, 5, 14, 
    1, 91, 8, 41, 3, 51, 5, 54, 6, 31, 2, 73, 0, 47, 7, 40, 4, 53, 
    3, 83, 1, 76, 7, 83, 8, 86, 0, 44, 4, 74, 6, 60, 2, 15, 5, 16, 
    3, 20, 0, 83, 6, 52, 2, 33, 1, 47, 8, 45, 7,  5, 5, 42, 4, 94, 
    3, 84, 8,  1, 7, 48, 1, 39, 0, 41, 2, 65, 5, 37, 6, 83, 4, 16, 
    4, 39, 1, 78, 7, 71, 2, 29, 6, 77, 8, 49, 3, 70, 0,  6, 5, 10, 
    1, 45, 2, 19, 8, 69, 0, 56, 3, 85, 5, 71, 6, 65, 4, 92, 7, 26, 
    2, 14, 0,  5, 7, 66, 8, 16, 5, 60, 3, 20, 1,  3, 4,  3, 6, 37
  };
  const int q6406[] = {
    9, 9, // Number of jobs and machines
    3, 21, 0, 78, 8, 98, 1, 16, 5, 80, 2, 34, 7, 63, 6, 27, 4, 97, 
    4, 92, 3, 28, 5,  8, 8, 24, 0, 69, 6, 50, 1, 28, 2, 25, 7, 13, 
    8, 27, 4,  4, 3, 94, 5, 33, 0, 80, 7, 63, 6,  5, 2, 17, 1, 73, 
    6, 89, 4, 59, 7,  1, 5,  4, 3, 21, 0, 94, 1, 68, 2, 63, 8, 93, 
    0, 86, 5, 21, 2, 43, 3, 23, 8, 10, 1, 76, 7, 69, 4, 27, 6, 12, 
    2, 37, 5, 24, 4, 30, 0, 20, 1, 69, 3, 49, 6, 13, 8, 98, 7, 90, 
    3, 42, 6, 43, 7, 33, 8,  3, 5, 10, 1, 48, 0, 40, 2, 70, 4, 36, 
    0, 53, 4, 76, 2, 59, 8, 35, 7, 13, 1, 69, 6, 53, 5, 62, 3, 86, 
    5, 70, 8, 33, 2, 19, 0, 59, 6, 29, 4, 69, 1,  9, 7, 96, 3, 95
  };
  const int q6407[] = {
    9, 9, // Number of jobs and machines
    2, 67, 1, 52, 6,  7, 0, 12, 8, 13, 7, 77, 5, 65, 4, 86, 3,  9, 
    8, 19, 3, 91, 6, 28, 1, 39, 5, 59, 4,  8, 0,  4, 7, 63, 2,  9, 
    4, 64, 7, 12, 6, 57, 8, 37, 1, 52, 5, 58, 0, 52, 2, 91, 3, 41, 
    1, 69, 6, 35, 2, 74, 7,  1, 4, 11, 3, 92, 0, 80, 8, 61, 5, 67, 
    4,  4, 3, 95, 2, 83, 8, 10, 5, 64, 6, 31, 0, 43, 1, 61, 7, 68, 
    4, 53, 6, 48, 3, 66, 8, 31, 0, 16, 5, 94, 2, 38, 7, 19, 1, 53, 
    5, 65, 6, 48, 8, 17, 7, 50, 0, 48, 1, 16, 4,  3, 3, 17, 2, 39, 
    5, 31, 8, 64, 2, 26, 1, 34, 6, 94, 0, 21, 3, 68, 7, 83, 4, 23, 
    7, 13, 0, 15, 8, 60, 6, 20, 2, 15, 1,  5, 4, 33, 3, 88, 5, 26
  };
  const int q6408[] = {
    9, 9, // Number of jobs and machines
    6, 19, 1, 48, 5, 84, 4, 61, 0, 27, 8, 48, 2, 43, 7, 92, 3, 19, 
    7, 65, 2, 19, 1, 15, 3, 16, 6, 22, 0, 83, 5, 33, 4, 18, 8,  6, 
    6, 19, 4, 87, 7, 64, 1, 81, 0, 90, 2, 11, 5, 49, 8, 59, 3, 93, 
    3, 32, 2, 40, 5, 84, 4, 77, 1, 44, 0, 64, 7, 75, 6, 22, 8, 53, 
    0, 51, 4, 61, 3,  2, 7, 94, 2, 35, 6, 81, 5, 88, 1, 73, 8, 76, 
    0, 22, 4, 36, 2, 60, 3, 54, 8, 29, 6, 11, 5, 45, 7, 48, 1, 87, 
    6, 69, 5, 91, 8,  2, 4, 53, 2, 31, 0, 86, 7, 23, 3, 16, 1, 76, 
    3, 72, 7, 36, 6, 38, 8, 73, 1, 19, 5, 11, 4, 46, 2, 21, 0,  8, 
    6, 62, 8, 47, 7, 69, 1, 12, 4, 37, 5, 17, 3, 66, 2, 44, 0, 78
  };
  const int q6409[] = {
    9, 9, // Number of jobs and machines
    4, 43, 3, 19, 6, 40, 8, 23, 7, 28, 1, 64, 2, 36, 0, 40, 5, 42, 
    3,  3, 6,  1, 2, 26, 5, 16, 4, 66, 8, 54, 1, 38, 0, 97, 7, 81, 
    1,  6, 7, 46, 6, 91, 0, 50, 4, 51, 3, 61, 5, 86, 8, 12, 2, 24, 
    6, 26, 3, 51, 0, 34, 5,  1, 1, 27, 7, 31, 4, 89, 8, 90, 2, 34, 
    0, 22, 6, 76, 8, 92, 5, 90, 3, 32, 1,  4, 2, 56, 4, 47, 7, 12, 
    6, 90, 4, 54, 0, 31, 7, 34, 1, 13, 3,  2, 5, 36, 2,  1, 8, 55, 
    4, 25, 0, 85, 1, 63, 5, 44, 3, 72, 2, 32, 6, 30, 7, 35, 8, 33, 
    7, 23, 6, 13, 5, 55, 2, 12, 4, 75, 3, 88, 0, 12, 8,  5, 1, 38, 
    5, 54, 4, 15, 6,  5, 8, 10, 3, 69, 2, 11, 1, 39, 0, 60, 7, 38
  };
  const int q6410[] = {
    9, 9, // Number of jobs and machines
    4, 29, 8, 59, 6, 94, 3, 21, 5, 33, 0,  4, 2, 33, 1, 82, 7, 99, 
    7, 36, 3, 56, 2, 14, 6, 44, 8, 35, 4, 13, 1, 65, 5, 10, 0, 47, 
    5, 86, 2, 45, 1, 36, 3, 65, 7, 50, 8, 75, 6, 32, 0, 87, 4, 83, 
    5, 40, 4, 54, 8,  9, 1, 75, 0, 81, 7, 24, 6, 89, 2, 42, 3, 37, 
    5, 79, 1, 67, 2,  8, 6, 48, 3,  4, 7, 95, 4, 59, 0, 19, 8, 51, 
    6, 61, 8,  9, 0, 75, 2, 91, 7, 20, 1, 66, 3, 10, 5, 50, 4, 30, 
    1, 16, 7, 23, 2,  7, 3, 90, 6, 79, 8, 79, 0,  4, 4, 94, 5, 92, 
    3, 30, 2, 75, 0, 71, 1, 78, 7, 82, 4, 97, 8, 15, 5, 12, 6,  2, 
    1, 12, 0,  2, 8, 54, 7, 14, 4, 88, 5, 45, 6, 48, 3, 47, 2,  6
  };
  const int q6411[] = {
    9, 9, // Number of jobs and machines
    3, 68, 7, 84, 2, 97, 8, 48, 4, 90, 6, 88, 1, 32, 5, 13, 0, 85, 
    3, 15, 8, 51, 0, 31, 5, 28, 2, 56, 1, 27, 7, 74, 6, 31, 4, 30, 
    8, 65, 7, 58, 6, 77, 3, 91, 1, 56, 4, 88, 2, 78, 0, 99, 5, 56, 
    0,  9, 4, 73, 2, 29, 6, 11, 3, 35, 5, 18, 8, 26, 7, 36, 1, 88, 
    8, 62, 3, 10, 4,  4, 5, 90, 7, 54, 6, 20, 0, 29, 2,  7, 1, 65, 
    0,  2, 6, 21, 3, 40, 1, 67, 5, 87, 4, 41, 2, 38, 8, 62, 7, 26, 
    6,  7, 7, 41, 1, 67, 4, 89, 3, 80, 5, 71, 2, 82, 0, 77, 8, 68, 
    6, 10, 7,  4, 2, 85, 8, 79, 1, 26, 0, 72, 5, 84, 3, 87, 4, 59, 
    7, 85, 3,  1, 6, 29, 4, 50, 2, 12, 0, 47, 1, 33, 5, 14, 8, 45
  };
  const int q6412[] = {
    9, 9, // Number of jobs and machines
    1, 89, 8, 53, 0, 77, 4, 20, 6, 42, 3, 11, 2,  3, 5, 10, 7, 87, 
    6,  7, 7, 49, 1,  3, 4, 26, 2, 86, 5, 13, 8, 24, 0, 72, 3, 91, 
    2, 59, 5, 71, 8, 32, 1, 40, 0, 52, 7, 60, 3, 48, 4, 98, 6, 61, 
    4, 21, 7, 74, 2, 57, 1, 78, 3,  8, 6, 80, 5, 79, 0, 75, 8, 76, 
    8, 62, 2, 80, 6, 18, 5, 78, 4,  8, 7, 99, 3,  3, 1, 60, 0, 58, 
    7, 46, 5, 90, 2, 76, 0,  8, 1, 89, 8, 17, 4, 93, 6, 73, 3, 48, 
    0, 39, 5, 27, 7, 27, 1, 45, 2, 51, 6, 44, 3, 74, 8, 61, 4, 79, 
    1, 85, 2, 61, 5, 48, 8,  9, 7, 58, 4, 40, 3, 97, 6, 20, 0, 18, 
    7, 81, 8, 64, 5, 33, 6, 96, 4, 32, 0, 79, 3, 65, 1, 91, 2, 79
  };
  const int q6413[] = {
    9, 9, // Number of jobs and machines
    5, 78, 4, 15, 2, 61, 6,  1, 3, 15, 7, 68, 8, 80, 0, 89, 1, 68, 
    4, 98, 1, 11, 3, 27, 7,  4, 6, 56, 0, 34, 2, 35, 5, 41, 8, 56, 
    8, 74, 1, 27, 0, 58, 2,  2, 6, 58, 7,  3, 4, 72, 3, 18, 5,  8, 
    3, 93, 0, 98, 1, 51, 4,  8, 6, 63, 2, 53, 5, 18, 7, 18, 8, 79, 
    4, 68, 0, 79, 5,  6, 6, 87, 7, 75, 2, 77, 3, 11, 8, 51, 1, 88, 
    8, 19, 6, 69, 5, 38, 7, 28, 2, 89, 1, 36, 0, 48, 3, 34, 4, 63, 
    0, 76, 3, 99, 2, 28, 5, 76, 1, 20, 7, 11, 4, 70, 6, 43, 8, 21, 
    0, 58, 6, 90, 1, 24, 2, 17, 3, 89, 4, 55, 7, 39, 8, 58, 5, 46, 
    0, 11, 5, 66, 4, 16, 1, 43, 6, 10, 2, 60, 8, 65, 3, 76, 7, 85
  };
  const int q6414[] = {
    9, 9, // Number of jobs and machines
    6, 33, 2, 83, 4, 16, 3, 36, 8, 34, 0, 30, 7, 64, 1, 76, 5, 93, 
    0, 47, 5, 70, 4,  4, 7, 36, 3, 91, 6, 75, 1, 71, 8, 10, 2,  1, 
    2, 98, 0, 38, 3, 79, 8, 91, 6, 13, 5, 72, 4, 55, 1, 10, 7, 83, 
    8, 44, 4, 93, 3, 87, 1, 45, 0, 68, 5, 99, 7,  4, 2, 59, 6, 63, 
    5, 12, 1,  7, 7, 55, 0,  1, 8, 57, 2, 58, 3, 41, 6, 25, 4, 81, 
    5, 96, 1, 77, 2, 65, 8, 95, 4, 65, 6, 17, 7, 85, 0, 73, 3, 65, 
    6, 36, 0, 51, 2, 11, 7, 44, 4, 94, 8, 12, 1, 53, 3, 84, 5, 97, 
    8, 37, 3, 27, 5, 44, 1, 96, 0, 73, 7, 48, 4, 16, 6, 31, 2, 33, 
    4, 32, 1, 80, 3, 87, 7, 70, 8, 57, 2, 96, 5, 18, 0, 61, 6, 78
  };
  const int q6415[] = {
    9, 9, // Number of jobs and machines
    8,  6, 1, 16, 6, 77, 3, 62, 4, 15, 7,  3, 5, 39, 2, 93, 0, 62, 
    2, 90, 3, 50, 4, 77, 1, 14, 6, 49, 5, 24, 7, 65, 8, 51, 0, 80, 
    8, 19, 4, 62, 3, 86, 0, 82, 2, 45, 7, 28, 6, 39, 5,  3, 1, 68, 
    4, 23, 3, 73, 2, 29, 6,  2, 0, 86, 5, 48, 7, 64, 8, 93, 1, 89, 
    6, 69, 0, 95, 7, 20, 1, 61, 3, 13, 2, 71, 5, 32, 8, 46, 4, 73, 
    0, 10, 7, 54, 6, 98, 2, 14, 3, 35, 5, 40, 4, 71, 8, 46, 1,  7, 
    0, 30, 1, 82, 8,  2, 2, 56, 7, 52, 6, 37, 3, 55, 4, 99, 5, 86, 
    7, 97, 5,  6, 8, 69, 1, 35, 3, 31, 4,  6, 2, 30, 6,  6, 0, 74, 
    4,  5, 3, 27, 0, 83, 2, 76, 5, 24, 7, 56, 1, 25, 8, 99, 6, 50
  };
  const int q6416[] = {
    9, 9, // Number of jobs and machines
    5, 37, 6, 70, 7, 43, 1, 78, 4, 78, 2,  8, 8, 49, 0, 37, 3, 95, 
    1, 91, 2, 17, 6, 68, 5, 56, 0, 53, 3, 54, 4, 13, 7, 68, 8, 57, 
    0, 82, 8, 46, 7, 79, 2, 96, 5, 45, 4, 47, 1, 19, 6, 11, 3, 55, 
    4, 97, 8, 55, 3, 51, 6, 83, 7, 72, 0,  2, 1,  4, 2, 21, 5, 53, 
    3,  7, 2,  6, 1, 74, 6, 35, 7, 57, 0, 11, 8, 56, 4, 28, 5, 82, 
    7, 54, 0, 80, 6, 30, 3, 54, 2, 99, 1, 34, 4, 96, 5, 76, 8, 95, 
    4, 70, 8, 81, 5, 15, 3, 45, 6,  1, 7, 77, 2, 29, 0,  1, 1, 67, 
    6,  1, 2, 76, 8, 24, 7, 68, 5, 65, 3, 75, 4, 40, 1, 94, 0, 99, 
    7,  2, 5, 94, 3, 79, 1,  2, 6,  5, 4, 65, 0,  8, 8, 99, 2, 37
  };
  const int q6417[] = {
    9, 9, // Number of jobs and machines
    8, 56, 7, 59, 0, 37, 3, 96, 6, 50, 4,  4, 5, 36, 2, 22, 1, 97, 
    1, 51, 5,  6, 2, 96, 8, 99, 4, 32, 7, 42, 0, 40, 3, 84, 6, 77, 
    7, 44, 5, 70, 4, 97, 8, 30, 3,  9, 0, 60, 1, 14, 2,  1, 6, 95, 
    4, 17, 6, 40, 0, 75, 1, 80, 7, 97, 8, 51, 2, 66, 5, 99, 3, 13, 
    0,  1, 5, 90, 7, 40, 2, 55, 6, 51, 3, 25, 8, 75, 1, 10, 4, 11, 
    6, 14, 7, 16, 5, 86, 8, 61, 1, 52, 0, 77, 3,  9, 4, 47, 2, 40, 
    1, 90, 6, 91, 7,  5, 2, 97, 5, 27, 8, 54, 4, 58, 0, 49, 3, 69, 
    4, 79, 8, 38, 0, 25, 7, 19, 6, 58, 5, 56, 2, 96, 3, 22, 1, 65, 
    3, 52, 5, 73, 2, 72, 1, 96, 6, 34, 7,  5, 0, 66, 8, 26, 4, 91
  };
  const int q6418[] = {
    9, 9, // Number of jobs and machines
    6, 76, 5, 59, 8, 77, 0, 71, 3, 94, 1, 96, 2, 24, 7, 59, 4, 17, 
    6, 88, 8, 84, 3, 60, 1, 47, 0, 38, 2, 58, 7, 50, 5, 51, 4, 16, 
    5, 36, 8, 67, 0, 82, 3,  6, 7, 55, 4, 36, 1, 42, 2, 65, 6, 11, 
    2, 77, 1, 11, 4, 59, 0,  2, 6, 77, 5, 27, 8, 80, 7, 47, 3, 21, 
    5, 28, 3, 60, 8, 93, 1,  5, 6, 12, 4, 87, 2, 23, 7, 88, 0, 14, 
    8, 86, 3, 80, 7, 99, 2, 82, 4, 71, 1,  4, 6, 90, 0, 95, 5,  3, 
    7, 96, 6, 46, 2, 73, 8, 88, 3, 88, 1, 17, 5, 46, 0, 59, 4, 73, 
    4, 74, 3,  5, 8, 73, 6, 20, 2,  1, 5, 89, 0, 11, 7, 52, 1, 76, 
    4, 50, 6, 22, 1,  6, 5, 38, 8,  8, 3, 90, 0, 41, 7, 50, 2, 25
  };
  const int q6419[] = {
    9, 9, // Number of jobs and machines
    1, 16, 6, 41, 7, 38, 5, 44, 4, 69, 3, 12, 2, 48, 0, 52, 8, 96, 
    3, 45, 8, 88, 2, 73, 0, 15, 7, 12, 6, 56, 1, 52, 4,  7, 5, 92, 
    4, 18, 5, 46, 0, 62, 2, 40, 7,  2, 8, 95, 6, 35, 1, 10, 3, 97, 
    7, 23, 6, 55, 5, 13, 4, 26, 3, 68, 1,  8, 0, 21, 2, 17, 8, 49, 
    6, 10, 7, 46, 5, 29, 0, 78, 4,  5, 2, 72, 3, 85, 1, 38, 8, 92, 
    3,  9, 0,  4, 6, 25, 1, 69, 2, 72, 7, 81, 4, 68, 8, 81, 5, 90, 
    2, 47, 7, 28, 3, 45, 0, 18, 4, 59, 6, 25, 5, 86, 1, 71, 8, 12, 
    8, 65, 4, 22, 3, 77, 7, 51, 1, 68, 2, 10, 0, 99, 5, 42, 6, 66, 
    3, 89, 0, 10, 2, 83, 5, 75, 8, 56, 4, 94, 7, 95, 1, 47, 6, 29
  };
  const int q6420[] = {
    9, 9, // Number of jobs and machines
    1, 87, 2, 64, 8, 83, 4, 97, 7,  5, 5, 91, 6, 62, 0, 63, 3, 13, 
    8, 27, 0, 48, 7, 68, 4, 26, 2, 59, 5, 19, 1, 15, 3,  1, 6, 43, 
    2, 78, 4, 91, 8, 62, 7, 64, 3, 54, 0, 20, 5, 12, 6, 74, 1, 97, 
    7, 62, 6, 23, 5, 79, 1, 51, 4, 77, 8, 46, 3, 67, 0, 44, 2, 64, 
    4, 49, 0, 31, 2, 37, 5, 38, 3, 29, 1, 49, 7, 75, 6, 14, 8, 90, 
    4, 29, 3, 73, 6, 36, 7, 79, 2, 18, 0, 15, 1,  7, 5, 69, 8, 90, 
    4, 88, 1, 66, 5, 47, 2, 34, 6, 12, 3, 24, 8, 48, 0, 23, 7, 67, 
    2, 77, 8, 38, 3, 23, 0, 75, 6, 55, 5, 23, 1, 86, 7, 26, 4, 19, 
    7, 96, 0, 34, 2, 98, 3, 49, 8, 15, 4,  3, 5, 40, 1, 32, 6, 40
  };
  const int q6421[] = {
    9, 9, // Number of jobs and machines
    8, 70, 4, 43, 3, 42, 0, 99, 5, 31, 7, 25, 6, 90, 2, 77, 1, 29, 
    2, 95, 0, 99, 6, 22, 7, 95, 1, 42, 8, 93, 5, 99, 4, 53, 3, 41, 
    2, 27, 4, 70, 1, 70, 6, 94, 8, 94, 5, 68, 7, 18, 0, 48, 3, 16, 
    8, 61, 5, 79, 3, 30, 1, 68, 4,  1, 2, 24, 6, 91, 0, 74, 7, 15, 
    8, 97, 7, 30, 2, 45, 5, 71, 6, 15, 3, 91, 0, 38, 4, 20, 1, 33, 
    6, 72, 8, 78, 4, 61, 3, 37, 7, 35, 5, 46, 0, 63, 1, 37, 2, 48, 
    1, 24, 7, 65, 6, 17, 0, 99, 2, 16, 5, 85, 8, 66, 4, 15, 3, 11, 
    3, 38, 0, 23, 5, 73, 8, 11, 2, 48, 4, 91, 6, 18, 7, 36, 1, 79, 
    2, 37, 3, 27, 7, 36, 0, 68, 5, 80, 6, 60, 1, 72, 4, 73, 8, 24
  };
  const int q6422[] = {
    9, 9, // Number of jobs and machines
    4, 35, 6, 37, 3, 62, 0, 20, 7, 62, 5, 42, 1,  1, 8, 17, 2, 41, 
    1, 49, 8, 53, 0, 79, 5, 69, 3, 81, 4, 89, 7,  8, 2, 97, 6,  3, 
    1, 59, 4, 10, 6, 97, 7, 59, 0, 12, 2,  9, 5, 85, 8, 68, 3, 16, 
    2, 64, 5, 39, 8, 71, 6, 37, 1, 78, 4, 56, 3, 58, 0, 48, 7, 80, 
    3, 71, 0, 82, 2, 72, 5, 17, 6, 89, 4, 67, 7, 24, 8, 16, 1,  9, 
    6, 97, 1, 22, 3, 52, 8, 31, 0, 70, 5, 25, 2, 52, 7, 39, 4, 48, 
    4, 21, 5, 97, 6, 10, 3, 33, 2, 36, 1, 62, 0, 28, 8, 39, 7, 48, 
    0, 88, 5, 84, 4, 81, 8, 32, 6, 78, 7, 87, 3, 18, 2, 39, 1, 99, 
    1, 70, 3, 11, 2, 17, 7, 22, 8, 52, 6, 72, 4, 94, 5, 22, 0,  3
  };
  const int q6423[] = {
    9, 9, // Number of jobs and machines
    8, 88, 5, 67, 6, 86, 2, 92, 1,  4, 7, 17, 4, 97, 3, 78, 0, 30, 
    3, 87, 2, 46, 6, 78, 1, 89, 7, 36, 0, 72, 4,  4, 8, 31, 5, 51, 
    4, 79, 2, 77, 0, 48, 6, 13, 3, 82, 8, 24, 1, 10, 5, 58, 7, 19, 
    7, 71, 4, 83, 5, 17, 6, 78, 2, 80, 0, 43, 3, 70, 8, 19, 1,  2, 
    3, 16, 1, 76, 5, 72, 4, 36, 2, 12, 0, 76, 8, 17, 7, 76, 6, 33, 
    8, 22, 1, 81, 3,  2, 0, 49, 4, 17, 7, 27, 6, 36, 5, 81, 2, 58, 
    1, 52, 2, 81, 4, 69, 7, 57, 8, 60, 3, 59, 6, 40, 0, 18, 5, 76, 
    5, 11, 8, 58, 6, 46, 0, 68, 1, 41, 2, 68, 4, 83, 3,  8, 7, 57, 
    3, 45, 2, 64, 6, 42, 8, 29, 0, 48, 4, 57, 1,  5, 7, 40, 5, 66
  };
  const int q6424[] = {
    9, 9, // Number of jobs and machines
    0, 69, 1, 85, 2, 33, 7, 68, 8, 95, 3, 10, 4,  4, 5, 68, 6, 12, 
    2, 13, 5, 99, 0, 39, 1, 63, 7, 86, 4, 30, 3, 35, 6,  4, 8, 71, 
    8, 15, 4, 61, 3, 65, 7, 96, 0, 15, 5, 73, 6,  7, 2, 45, 1, 79, 
    4, 48, 8, 81, 2, 79, 5, 68, 0, 57, 6, 30, 1, 38, 3, 78, 7, 54, 
    6, 45, 4, 82, 2, 64, 7, 70, 5, 92, 3, 57, 8, 34, 0, 70, 1, 63, 
    2, 63, 8, 94, 7, 51, 1,  9, 0, 84, 6, 92, 5, 47, 3, 29, 4, 51, 
    0, 21, 5,  1, 8, 90, 2, 30, 4, 57, 1,  9, 3, 61, 7, 37, 6, 65, 
    7, 58, 0, 12, 6, 84, 2, 43, 5, 31, 4,  4, 1, 34, 8, 31, 3, 65, 
    0,  3, 2, 12, 7, 14, 1,  3, 4, 89, 5, 30, 3, 14, 6, 47, 8, 31
  };
  const int q6425[] = {
    9, 9, // Number of jobs and machines
    8, 82, 3, 74, 1, 73, 2, 22, 0, 31, 4, 35, 7, 63, 6, 39, 5, 34, 
    1, 82, 8, 89, 0, 74, 4, 50, 6, 53, 3, 24, 7, 74, 2,  9, 5,  7, 
    6, 60, 3, 25, 4, 53, 7, 66, 1, 14, 0, 33, 8, 75, 2, 67, 5, 51, 
    0, 34, 3,  4, 2, 56, 8, 36, 5, 47, 7, 73, 1, 87, 6, 17, 4, 33, 
    7, 79, 5, 14, 2, 39, 1, 26, 4, 18, 8, 20, 0, 87, 6, 54, 3, 13, 
    5, 31, 3, 76, 2, 55, 8, 71, 7,  6, 1, 27, 4, 41, 6, 94, 0, 73, 
    5,  2, 3, 36, 1, 57, 6, 32, 4, 41, 0, 20, 2, 91, 7, 27, 8, 25, 
    0, 78, 6, 60, 7, 53, 5, 89, 1, 73, 3, 34, 2, 82, 4, 69, 8, 76, 
    4, 96, 5, 12, 7, 45, 2, 76, 3, 51, 8,  6, 1, 82, 6, 37, 0, 86
  };
  const int q6426[] = {
    9, 9, // Number of jobs and machines
    8, 60, 1, 70, 2, 32, 6,  8, 0, 76, 4, 61, 3, 90, 7, 20, 5, 86, 
    7, 73, 3, 31, 8, 59, 6, 17, 0, 23, 4, 81, 1, 29, 5,  1, 2, 38, 
    2, 24, 0, 51, 1, 12, 6, 76, 8, 63, 4, 38, 7, 95, 3, 45, 5, 62, 
    2, 14, 3, 63, 8, 79, 6, 69, 4, 55, 0,  1, 1, 16, 5, 27, 7, 87, 
    1, 48, 7,  7, 2, 99, 6, 38, 3, 78, 8, 68, 4,  5, 0, 77, 5, 74, 
    5, 63, 6, 56, 3,  5, 4, 34, 8, 43, 2, 23, 7, 24, 1, 22, 0, 43, 
    8, 78, 7, 26, 5, 57, 2, 44, 3, 19, 6, 20, 4, 32, 0, 49, 1, 91, 
    4, 41, 1, 67, 5, 88, 3, 50, 0, 49, 7, 28, 2, 91, 6,  3, 8, 76, 
    0, 25, 1, 11, 3, 49, 8, 48, 4, 86, 5, 54, 6, 58, 2, 82, 7, 17
  };
  const int q6427[] = {
    9, 9, // Number of jobs and machines
    5, 65, 0, 50, 1, 70, 2, 21, 8, 13, 6, 53, 3, 29, 7, 26, 4, 70, 
    7, 60, 0, 17, 4, 40, 5, 17, 6, 61, 3, 44, 8, 82, 2, 99, 1, 22, 
    2, 90, 5, 78, 8, 88, 6, 74, 7, 77, 1, 58, 0, 70, 4, 45, 3, 90, 
    1, 82, 5, 61, 8, 45, 4,  8, 0, 50, 7, 65, 6, 72, 2, 42, 3, 58, 
    4, 30, 2, 14, 3, 25, 8, 22, 6, 31, 5,  7, 1, 95, 7, 57, 0, 86, 
    6, 61, 2, 16, 5, 38, 7, 80, 3, 94, 1, 15, 8, 71, 4, 31, 0, 23, 
    7, 70, 1, 28, 8, 29, 5, 38, 6, 73, 4, 34, 0, 32, 3, 61, 2,  6, 
    7, 49, 3,  8, 0, 97, 4, 15, 8, 59, 5, 33, 1, 25, 2, 54, 6, 38, 
    4, 36, 2, 51, 5, 31, 7,  4, 3, 16, 1, 34, 8, 14, 0, 48, 6, 83
  };
  const int q6428[] = {
    9, 9, // Number of jobs and machines
    3,  3, 5, 51, 4, 36, 6, 51, 0, 41, 8, 14, 7, 53, 1, 41, 2, 26, 
    3, 91, 4, 38, 8, 99, 5, 97, 6, 32, 7, 56, 0, 78, 1, 67, 2, 99, 
    0, 54, 7, 31, 3,  9, 1, 75, 5, 30, 4, 84, 8, 92, 6, 68, 2, 40, 
    2, 80, 0, 36, 3, 20, 7, 83, 6, 93, 5, 46, 8, 14, 4, 96, 1, 63, 
    8, 37, 1, 89, 6,  6, 0, 48, 3,  6, 2, 97, 5, 44, 7, 88, 4, 65, 
    8, 55, 2, 25, 4, 29, 6, 64, 0, 48, 1, 60, 3, 86, 5, 28, 7, 64, 
    4, 81, 3, 64, 0, 42, 5, 72, 2, 80, 8, 76, 6, 92, 1, 80, 7, 94, 
    8, 29, 5, 64, 3, 98, 0, 78, 4, 99, 6, 82, 2,  9, 7, 21, 1, 39, 
    0, 23, 1,  4, 7, 38, 5, 94, 8, 76, 6, 18, 2, 20, 3, 58, 4,  8
  };
  const int q6429[] = {
    9, 9, // Number of jobs and machines
    0, 60, 2, 70, 8, 72, 6,  8, 7, 13, 1, 56, 5, 58, 3, 28, 4, 62, 
    4, 66, 5,  9, 6, 70, 3, 36, 2, 88, 7, 24, 8, 97, 1, 45, 0, 41, 
    4, 81, 2, 82, 3, 54, 1, 38, 8, 26, 7, 99, 5, 39, 0, 17, 6, 29, 
    6,  2, 5,  5, 2, 66, 0, 82, 4, 64, 1,  7, 8, 97, 3, 29, 7, 26, 
    2, 79, 8, 57, 1, 55, 7, 77, 6, 86, 4, 10, 5, 75, 0, 26, 3, 97, 
    8, 94, 2, 20, 3,  8, 0, 95, 6, 52, 4, 85, 1, 79, 5, 62, 7, 55, 
    4, 31, 7,  7, 3, 52, 2, 36, 8, 59, 1, 25, 5, 92, 0, 52, 6, 99, 
    1, 19, 2, 44, 3, 76, 7, 56, 4, 65, 8,  5, 0, 14, 6, 90, 5, 16, 
    5, 35, 4,  3, 0, 50, 6, 79, 2, 52, 7, 48, 3, 64, 1, 31, 8, 89
  };
  const int q6430[] = {
    9, 9, // Number of jobs and machines
    8, 76, 3, 91, 2, 68, 4, 24, 7,  2, 5, 93, 0,  7, 1, 37, 6, 28, 
    5, 31, 1, 60, 7, 59, 0, 18, 6, 92, 4, 69, 8, 55, 3, 63, 2, 39, 
    0, 97, 5, 67, 3,  9, 4, 47, 2, 15, 1, 47, 6, 34, 8, 95, 7, 77, 
    2, 90, 1, 30, 5, 73, 4, 45, 3, 42, 8, 95, 0, 68, 6, 66, 7, 40, 
    8, 99, 0, 23, 3, 98, 5, 63, 1, 22, 6, 72, 2, 87, 4, 98, 7, 89, 
    4, 73, 6, 16, 7, 77, 0, 85, 3, 98, 1, 48, 2, 95, 5, 34, 8, 78, 
    1, 64, 8,  6, 3, 36, 2, 60, 7, 53, 0, 52, 5, 38, 4, 45, 6, 85, 
    7, 35, 5, 71, 2, 94, 4, 87, 6, 12, 3, 28, 0, 10, 8, 99, 1, 24, 
    4, 73, 5, 78, 8, 68, 7, 30, 2, 32, 1, 20, 0, 16, 6, 79, 3, 82
  };
  const int q6431[] = {
    9, 9, // Number of jobs and machines
    6, 33, 4, 30, 0, 85, 1, 68, 3, 95, 8, 15, 7, 71, 2, 35, 5,  4, 
    7, 95, 1, 48, 8, 52, 6, 34, 4, 29, 0, 61, 5, 82, 3, 51, 2, 17, 
    1, 10, 5, 11, 0, 71, 3, 50, 7, 62, 4, 94, 2, 98, 6, 29, 8, 68, 
    7, 18, 2, 11, 1, 75, 3, 56, 5, 87, 6, 42, 4, 43, 0, 14, 8, 36, 
    3, 52, 7, 42, 6, 64, 5, 70, 0, 18, 1, 15, 2, 49, 4, 70, 8,  9, 
    0,  5, 6, 66, 1, 36, 2, 98, 8, 45, 5,  9, 3, 56, 4, 31, 7, 29, 
    2, 89, 7, 94, 6, 13, 1, 74, 0, 46, 5, 96, 8,  9, 4,  6, 3, 54, 
    7, 99, 6, 31, 1, 16, 3,  5, 8, 17, 0, 75, 4, 90, 5, 45, 2, 81, 
    6, 19, 0, 57, 3, 73, 7, 46, 2, 27, 5, 14, 4, 77, 1, 88, 8, 18
  };
  const int q6432[] = {
    9, 9, // Number of jobs and machines
    1, 30, 4, 45, 3, 34, 7, 84, 2, 17, 6, 44, 5, 94, 0, 40, 8, 68, 
    2,  7, 8, 97, 6, 20, 7, 21, 5, 37, 1,  6, 4, 45, 3, 69, 0, 76, 
    0, 93, 1, 73, 3, 72, 5, 73, 6, 32, 4, 85, 2, 93, 7, 64, 8, 41, 
    6, 75, 3, 67, 8, 16, 7, 64, 0, 38, 1, 33, 2, 21, 4, 27, 5, 22, 
    1, 37, 2, 47, 7, 38, 5, 34, 0, 61, 3, 30, 6, 85, 4, 47, 8, 57, 
    4, 52, 6, 96, 3, 84, 0, 43, 8, 69, 2, 62, 5, 43, 7,  1, 1, 92, 
    1, 69, 8, 71, 2, 25, 0, 45, 4, 49, 7, 48, 5, 43, 6, 49, 3, 66, 
    2,  4, 8, 22, 6, 47, 4, 80, 3, 66, 5, 29, 0,  8, 1, 82, 7, 56, 
    1, 62, 4, 82, 8, 46, 3, 10, 5, 51, 2, 51, 6, 34, 0, 45, 7,  8
  };
  const int q6433[] = {
    9, 9, // Number of jobs and machines
    4,  2, 7, 56, 0, 23, 3, 11, 8, 11, 1, 32, 6,  7, 2, 73, 5, 20, 
    6, 47, 8, 51, 2, 47, 1, 74, 3,  6, 5, 92, 7, 41, 0, 19, 4, 18, 
    3, 16, 2, 23, 1, 26, 0, 16, 4, 15, 6, 71, 7, 87, 8,  4, 5, 50, 
    2,  8, 0, 31, 8, 84, 4, 50, 7, 19, 1, 41, 3, 64, 6, 71, 5, 43, 
    5, 69, 7, 15, 0, 70, 3, 74, 4, 84, 1,  2, 8,  5, 2, 31, 6, 71, 
    8, 76, 7, 63, 4, 45, 5,  2, 3, 20, 6, 28, 0, 69, 1, 56, 2, 65, 
    5, 45, 2,  2, 7, 39, 6, 45, 3, 41, 1, 68, 8, 66, 0, 43, 4,  2, 
    0, 16, 3, 51, 6, 91, 1, 74, 5, 41, 2, 19, 7, 67, 4, 82, 8, 81, 
    2, 83, 4,  6, 8, 87, 7, 28, 3, 92, 5,  9, 1, 23, 0, 97, 6, 74
  };
  const int q6434[] = {
    9, 9, // Number of jobs and machines
    5, 17, 1, 68, 4, 12, 2,  3, 8, 91, 0, 36, 3, 93, 7, 41, 6, 39, 
    1, 37, 8, 89, 5, 24, 0, 72, 6, 30, 2, 76, 4, 51, 7, 38, 3, 62, 
    8,  4, 3, 97, 0, 56, 7, 26, 2, 47, 1, 55, 4, 90, 5, 97, 6, 31, 
    6, 70, 5, 15, 2, 73, 1, 44, 7, 69, 4, 58, 0, 98, 3, 29, 8, 47, 
    8, 80, 7, 16, 0, 72, 4, 85, 3, 32, 5, 54, 1, 35, 2, 48, 6, 96, 
    5, 13, 7, 96, 1, 28, 2, 20, 6, 81, 0, 31, 8, 55, 4,  4, 3,  4, 
    8,  9, 7, 92, 5, 41, 6, 53, 0, 29, 4, 66, 2, 22, 1, 47, 3, 98, 
    0, 78, 6, 15, 2, 21, 7, 44, 8, 79, 4, 24, 3, 88, 5, 76, 1, 70, 
    2, 59, 8, 82, 3, 65, 1, 52, 5,  3, 6, 94, 4, 14, 0, 76, 7, 46
  };
  const int q6435[] = {
    9, 9, // Number of jobs and machines
    0, 97, 3, 98, 7, 73, 2, 25, 5, 53, 8,  1, 1, 49, 4, 39, 6,  2, 
    1, 38, 8, 55, 2,  4, 3, 91, 7, 14, 6, 55, 5, 91, 4, 65, 0, 39, 
    2, 32, 5, 61, 4,  3, 3, 90, 1, 34, 0, 75, 8,  6, 7, 92, 6, 95, 
    6, 36, 1, 52, 8, 60, 4,  4, 7, 80, 0, 71, 2, 41, 5, 31, 3, 70, 
    1, 45, 6, 51, 8, 13, 7, 87, 2, 40, 4, 87, 5, 74, 3, 54, 0, 78, 
    7, 27, 4, 38, 1, 96, 0, 37, 3, 51, 8,  5, 5, 70, 2, 96, 6, 23, 
    4, 61, 7, 48, 0, 56, 8, 96, 6, 68, 1, 38, 2, 67, 3, 48, 5, 50, 
    2, 26, 3, 95, 7, 73, 0, 14, 6, 96, 8, 51, 1, 31, 5, 96, 4, 79, 
    8, 44, 0, 85, 1, 66, 2, 47, 3, 73, 4, 66, 7, 77, 6, 49, 5, 51
  };
  const int q6436[] = {
    9, 9, // Number of jobs and machines
    8, 69, 5,  1, 2, 31, 3, 64, 1, 87, 0, 26, 6, 57, 4, 22, 7,  1, 
    3,  3, 5,  2, 0, 92, 8, 57, 1,  2, 6, 59, 2, 84, 4, 71, 7, 22, 
    6, 92, 4, 21, 1, 57, 2, 84, 0, 97, 8, 68, 7, 82, 5, 37, 3, 73, 
    4, 48, 3, 20, 2, 69, 5, 97, 8,  4, 0, 42, 7, 25, 1, 64, 6, 89, 
    0, 80, 4, 71, 6, 52, 1, 55, 2, 79, 3, 71, 7, 22, 5, 54, 8, 59, 
    4,  1, 6, 24, 2, 20, 8, 90, 1, 76, 0, 75, 7, 64, 5, 49, 3, 21, 
    6, 45, 0, 37, 3, 91, 2, 68, 7, 11, 5, 67, 8, 11, 4, 32, 1, 95, 
    5, 32, 2, 57, 4, 45, 6, 87, 3, 41, 8, 11, 1, 96, 0, 66, 7,  1, 
    0,  8, 2, 10, 4, 80, 6, 62, 1, 75, 3, 13, 8, 38, 5, 35, 7, 92
  };
  const int q6437[] = {
    9, 9, // Number of jobs and machines
    2, 65, 5, 80, 8, 88, 0, 42, 3, 72, 4, 22, 6, 91, 1,  7, 7, 13, 
    2, 39, 8, 82, 3, 21, 5, 18, 7, 57, 0, 81, 1, 95, 6, 88, 4,  9, 
    5, 67, 8, 91, 7, 59, 6, 22, 3, 57, 1, 81, 2, 42, 4, 67, 0, 50, 
    1, 61, 6,  3, 3, 51, 0, 20, 7, 66, 2, 65, 4, 93, 8, 23, 5, 44, 
    2, 34, 7,  5, 0, 90, 1, 29, 3, 80, 4, 65, 6, 23, 5, 34, 8, 59, 
    8, 23, 1, 61, 5, 50, 6, 37, 4, 88, 0, 17, 7, 73, 3, 31, 2, 97, 
    4, 98, 0, 66, 3, 55, 8, 85, 7, 28, 5, 71, 1,  9, 2, 23, 6, 17, 
    2, 58, 1, 41, 0, 27, 7, 66, 8, 74, 5, 47, 6, 15, 4, 74, 3, 37, 
    6, 93, 0, 19, 3, 85, 2, 81, 8, 88, 1, 50, 4, 66, 5, 98, 7, 36
  };
  const int q6438[] = {
    9, 9, // Number of jobs and machines
    5, 83, 3, 43, 1, 92, 8, 20, 2, 89, 4, 71, 0, 61, 6, 55, 7, 55, 
    4, 36, 6, 47, 2, 65, 7,  8, 8, 48, 5, 49, 1, 61, 0, 46, 3, 61, 
    2, 67, 0, 72, 5, 27, 1, 28, 6, 41, 7, 48, 4, 78, 8, 52, 3, 31, 
    5, 83, 1, 62, 3, 83, 7, 56, 6, 70, 4, 29, 2, 50, 0, 48, 8, 85, 
    0, 62, 3, 28, 4, 90, 2, 94, 5, 11, 6, 96, 7, 18, 1, 78, 8,  5, 
    2, 98, 7, 41, 0, 75, 4, 30, 3, 61, 6, 85, 1, 30, 5, 39, 8, 66, 
    8, 71, 3, 27, 4, 43, 5, 51, 2, 22, 1, 98, 0, 71, 6, 69, 7, 78, 
    0, 74, 2, 79, 3, 46, 1, 71, 7, 69, 8, 25, 5, 49, 6, 59, 4, 62, 
    8, 43, 3, 66, 5, 91, 2, 40, 6, 12, 7, 55, 0, 67, 1, 14, 4, 65
  };
  const int q6439[] = {
    9, 9, // Number of jobs and machines
    8, 62, 2, 67, 7, 27, 0, 75, 5, 57, 3, 53, 1,  1, 4, 29, 6, 14, 
    8, 95, 7, 93, 4,  1, 6, 41, 5, 63, 3, 76, 2, 96, 0, 60, 1, 10, 
    6, 19, 8, 92, 4,  5, 0, 78, 3, 24, 5, 21, 7, 78, 1, 62, 2,  2, 
    1, 14, 8,  4, 0, 19, 2, 52, 6,  9, 3, 40, 7, 96, 4, 65, 5,  5, 
    3, 39, 1, 13, 6, 85, 5, 79, 8, 30, 4, 20, 7, 35, 2, 93, 0, 38, 
    0, 73, 8, 18, 4, 22, 6, 18, 2, 26, 1, 16, 3, 58, 7, 64, 5, 25, 
    6, 56, 1, 54, 3, 91, 4, 62, 2, 58, 0, 78, 7, 86, 5,  7, 8, 67, 
    7, 96, 3, 30, 6, 16, 0, 72, 1, 56, 8, 56, 5, 67, 2, 53, 4, 43, 
    0, 26, 3, 38, 5, 65, 1, 75, 7, 55, 4, 66, 2, 12, 6, 67, 8, 80
  };
  const int q6440[] = {
    9, 9, // Number of jobs and machines
    3, 82, 8, 32, 5, 65, 7, 86, 2, 42, 6, 37, 1, 32, 4, 27, 0, 93, 
    0, 45, 6, 58, 4, 12, 3, 82, 5, 27, 7, 95, 8, 15, 1, 20, 2, 51, 
    4, 50, 7, 92, 0, 61, 3, 38, 2, 97, 8, 22, 6, 42, 1, 31, 5, 43, 
    0, 86, 1, 97, 6, 33, 5, 84, 3, 82, 2, 38, 8, 92, 4, 30, 7, 97, 
    7, 61, 1, 22, 8, 51, 3, 35, 4, 18, 2, 89, 5, 68, 6, 54, 0, 19, 
    8, 52, 7, 50, 5, 37, 1, 18, 0, 79, 3, 74, 2, 64, 6, 10, 4,  5, 
    2, 87, 5, 71, 6, 59, 0, 38, 3, 46, 1, 50, 7, 12, 4, 35, 8,  1, 
    5, 53, 1, 37, 7, 86, 8, 13, 3, 26, 6, 94, 2, 40, 0, 36, 4, 55, 
    1, 74, 8, 35, 3, 99, 5, 32, 7, 29, 2, 62, 0, 89, 6, 89, 4, 92
  };
  const int q6441[] = {
    9, 9, // Number of jobs and machines
    4, 87, 5, 71, 2, 28, 3, 36, 6,  3, 7, 54, 0, 59, 8, 82, 1, 36, 
    1, 38, 4, 18, 2, 68, 7,  1, 6, 32, 0, 17, 5, 80, 8, 62, 3, 17, 
    8, 86, 1, 91, 4, 67, 0, 86, 6, 68, 3,  2, 5, 57, 2, 69, 7, 12, 
    7,  9, 2, 50, 3, 55, 1, 97, 5, 29, 8,  2, 4, 67, 0, 53, 6, 61, 
    2, 18, 5, 13, 0, 86, 4,  4, 1, 97, 7,  3, 6,  5, 8, 70, 3, 55, 
    0,  6, 4, 58, 3, 64, 8, 19, 7, 29, 6, 47, 5, 61, 2,  4, 1, 38, 
    2, 40, 3,  4, 7, 86, 8, 43, 6, 48, 1, 58, 4,  9, 5, 12, 0, 17, 
    0, 71, 8, 31, 2, 11, 5,  4, 4, 67, 3, 67, 6, 77, 1, 95, 7, 75, 
    8,  4, 7, 22, 6, 70, 3, 98, 0, 19, 5, 70, 4, 89, 2, 89, 1, 96
  };
  const int q6442[] = {
    9, 9, // Number of jobs and machines
    0,  3, 4,  2, 2, 95, 8, 47, 5,  1, 7, 63, 6, 50, 3, 15, 1, 21, 
    4, 70, 0, 58, 7, 20, 6, 38, 2,  1, 5,  9, 3,  8, 8, 69, 1, 55, 
    8, 64, 0, 72, 4, 97, 2, 42, 5, 14, 1, 37, 6, 61, 3, 20, 7, 20, 
    1,  1, 2, 40, 8, 93, 3, 32, 5, 20, 4, 45, 6, 60, 0, 75, 7, 20, 
    1, 35, 5, 49, 6, 35, 0, 36, 7, 39, 8, 92, 3, 83, 4, 60, 2, 14, 
    8, 88, 0,  9, 2, 31, 5, 13, 6, 84, 4, 18, 7, 53, 1,  5, 3, 34, 
    5, 94, 3, 45, 8, 71, 0, 86, 4, 27, 6, 56, 2, 24, 7, 57, 1, 24, 
    6, 41, 7, 33, 1, 87, 5, 77, 8,  1, 0, 63, 4, 58, 3, 33, 2, 31, 
    1, 32, 0, 35, 8, 38, 3, 75, 2, 79, 5, 98, 6, 71, 7,  5, 4, 61
  };
  const int q6443[] = {
    9, 9, // Number of jobs and machines
    3, 91, 2, 66, 1, 64, 4, 20, 6, 24, 7, 43, 5, 13, 8, 32, 0, 90, 
    1, 43, 5,  4, 0, 36, 3, 63, 2, 16, 7, 77, 4, 50, 6, 93, 8, 58, 
    5, 81, 6, 65, 3, 16, 4, 59, 0, 60, 1, 10, 2, 49, 7,  2, 8, 99, 
    5, 21, 8, 50, 6,  1, 4, 65, 7, 98, 3, 17, 0, 82, 1, 43, 2, 94, 
    8, 18, 2, 61, 6, 26, 5, 79, 7, 11, 4, 93, 0, 13, 3, 25, 1,  4, 
    1, 59, 4, 69, 7, 28, 3, 60, 6, 89, 0, 46, 5, 37, 2, 46, 8, 13, 
    7, 11, 6, 38, 1, 74, 4, 88, 0, 62, 2, 15, 3,  8, 8, 85, 5, 48, 
    4, 57, 3, 21, 2, 16, 5, 78, 7,  4, 8, 86, 0, 81, 1, 38, 6, 44, 
    8,  6, 4, 69, 7, 70, 3, 88, 0, 51, 1, 13, 5, 96, 6,  8, 2, 43
  };
  const int q6444[] = {
    9, 9, // Number of jobs and machines
    5, 73, 1, 62, 3, 18, 6, 19, 8, 72, 2, 28, 4, 94, 7, 68, 0, 60, 
    1, 56, 5, 89, 3,  4, 6, 87, 0, 68, 7, 52, 4, 16, 8, 70, 2, 73, 
    8, 72, 2, 40, 4, 67, 6, 61, 5, 88, 7, 18, 3, 29, 1,  5, 0, 88, 
    2, 41, 4, 24, 6, 40, 8, 24, 1, 36, 0, 97, 7, 48, 5, 44, 3, 39, 
    7, 13, 3, 17, 5, 50, 2, 58, 1, 44, 0, 37, 4, 59, 8, 49, 6, 88, 
    1, 19, 2, 11, 0, 44, 4, 36, 3, 20, 7, 90, 8, 24, 5, 51, 6, 87, 
    1, 25, 6, 62, 2, 46, 4, 82, 0, 77, 5, 14, 3, 60, 8,  9, 7, 73, 
    1, 49, 3, 89, 5, 45, 0, 48, 4, 94, 2, 28, 6, 63, 7,  2, 8, 83, 
    1, 71, 7, 69, 4, 46, 0, 65, 2, 96, 8, 76, 3, 25, 6, 13, 5, 58
  };
  const int q6445[] = {
    9, 9, // Number of jobs and machines
    3, 16, 5, 70, 1, 88, 8, 63, 7,  7, 4, 21, 0, 84, 6, 81, 2, 54, 
    8, 99, 6, 28, 0, 89, 5, 63, 7, 86, 4, 30, 3, 54, 2, 25, 1, 10, 
    8, 99, 7, 75, 0, 77, 3, 19, 4,  8, 1, 46, 5, 51, 2, 46, 6, 30, 
    7, 66, 4, 41, 1, 26, 5, 13, 0, 90, 8, 32, 2, 72, 6, 78, 3, 36, 
    1, 97, 3, 46, 2, 16, 5, 40, 7, 29, 4, 51, 8, 19, 6, 71, 0, 11, 
    3,  6, 4, 32, 8, 93, 0, 80, 6, 66, 1, 22, 7, 27, 5, 25, 2, 82, 
    2, 57, 8, 36, 4, 61, 0, 74, 6, 96, 5, 29, 7, 61, 1, 73, 3, 32, 
    2, 87, 0, 95, 4,  7, 7, 91, 5, 13, 1, 53, 3, 67, 8, 65, 6, 16, 
    7,  8, 5, 95, 2, 89, 4, 54, 3, 28, 8, 28, 0, 84, 6, 52, 1, 21
  };
  const int q6446[] = {
    9, 9, // Number of jobs and machines
    5, 67, 2,  9, 4, 78, 7, 59, 1, 89, 3, 88, 0, 24, 8, 83, 6, 24, 
    3,  2, 0, 12, 4, 19, 1, 35, 5, 33, 7, 97, 8,  3, 2, 96, 6, 14, 
    3, 13, 8, 77, 4,  6, 7, 44, 2, 51, 1, 55, 6, 63, 0, 69, 5, 98, 
    7, 96, 0, 11, 6, 20, 3, 86, 2, 46, 4, 75, 5, 48, 1,  8, 8, 88, 
    6, 27, 2,  6, 7,  6, 5, 45, 0, 61, 1, 69, 3, 72, 8,  5, 4, 19, 
    6, 44, 0, 25, 2, 99, 5, 28, 8, 34, 3, 13, 4, 79, 7, 34, 1, 79, 
    8, 38, 5, 12, 1, 30, 6, 84, 3, 68, 4, 40, 2, 92, 0, 85, 7, 11, 
    3,  7, 6, 89, 0, 27, 5, 11, 7, 11, 1, 15, 4, 65, 2, 71, 8, 89, 
    1, 94, 6, 78, 7, 43, 2, 71, 8, 40, 0, 95, 3, 53, 5, 52, 4, 83
  };
  const int q6447[] = {
    9, 9, // Number of jobs and machines
    7, 86, 0, 82, 6, 98, 2, 11, 3, 18, 1, 57, 5, 42, 8, 55, 4, 53, 
    6, 82, 1, 66, 0, 92, 2, 36, 7, 88, 4, 16, 5,  7, 8, 42, 3, 86, 
    7, 20, 8, 95, 2, 16, 1, 45, 4,  8, 3, 73, 6, 38, 0, 95, 5, 32, 
    8, 61, 3, 62, 6, 86, 1, 72, 2, 80, 7, 39, 5, 20, 4, 56, 0,  2, 
    1, 44, 8, 27, 3, 98, 6, 22, 0, 44, 2, 96, 4, 14, 7, 97, 5, 71, 
    0, 75, 3, 53, 7, 94, 1, 50, 8, 26, 2, 38, 6, 96, 4, 44, 5, 52, 
    3, 91, 8, 81, 2, 98, 4, 79, 0, 98, 5, 22, 7, 52, 6, 39, 1, 46, 
    1, 12, 8, 38, 4, 14, 2, 44, 3, 85, 7,  1, 6, 95, 0, 75, 5, 59, 
    7, 89, 0, 95, 4, 45, 3, 88, 6, 37, 2, 26, 8, 13, 5, 64, 1, 95
  };
  const int q6448[] = {
    9, 9, // Number of jobs and machines
    1, 75, 3, 51, 8, 37, 0, 50, 2, 19, 5, 19, 4, 32, 6,  2, 7, 43, 
    1, 88, 6, 68, 2, 93, 4, 97, 5, 14, 0,  2, 7, 91, 3, 43, 8, 58, 
    6, 10, 2, 52, 3, 99, 4, 54, 0, 11, 7, 82, 1, 35, 5, 59, 8, 74, 
    5, 63, 2, 58, 3,  6, 6, 86, 0, 86, 8, 44, 1, 31, 4, 20, 7, 44, 
    8, 57, 5, 38, 3,  3, 6, 42, 4, 84, 7, 80, 1, 48, 0, 45, 2, 46, 
    4, 78, 5, 39, 3, 50, 0, 82, 7, 17, 2, 39, 6, 42, 8, 92, 1, 59, 
    5, 51, 6, 98, 8, 56, 0, 65, 3, 19, 7, 54, 4, 38, 1, 52, 2, 97, 
    0, 26, 2, 95, 4, 37, 3, 94, 7, 92, 6, 73, 5, 32, 8, 61, 1, 31, 
    8,  9, 0, 15, 6, 86, 7, 33, 2, 11, 4, 87, 1, 81, 5, 41, 3, 26
  };
  const int q6449[] = {
    9, 9, // Number of jobs and machines
    2, 84, 8, 15, 5, 45, 3, 54, 4, 68, 7,  6, 6,  8, 0, 66, 1, 95, 
    3, 89, 0, 12, 5, 10, 2, 30, 8, 52, 6,  8, 4, 82, 1,  6, 7,  7, 
    5, 77, 4, 60, 7, 12, 2,  2, 8, 40, 6, 74, 0, 66, 3, 58, 1, 10, 
    0, 26, 2, 24, 3, 42, 7, 38, 6, 54, 1, 90, 4,  8, 8, 74, 5, 60, 
    3, 54, 6, 70, 1, 81, 2, 64, 5, 65, 0, 99, 7, 59, 8, 77, 4, 58, 
    4, 26, 2, 40, 6, 37, 5,  7, 8, 40, 1, 28, 7, 62, 0, 57, 3, 24, 
    8, 63, 3,  3, 1, 14, 6, 57, 2, 83, 5, 76, 7, 25, 4, 32, 0, 16, 
    0, 19, 7, 80, 5, 68, 2, 24, 4, 14, 3, 58, 8, 63, 1, 41, 6, 88, 
    7, 73, 6, 58, 1,  5, 8, 88, 2, 69, 0, 14, 5, 20, 3, 93, 4, 78
  };
  const int q6450[] = {
    9, 9, // Number of jobs and machines
    2, 87, 4, 29, 5, 67, 6,  4, 0, 32, 7, 13, 3, 93, 1, 85, 8, 32, 
    8, 59, 7, 52, 1, 52, 0, 96, 2, 76, 3, 53, 6, 87, 5, 40, 4, 51, 
    7, 78, 1, 95, 5, 59, 3, 38, 6,  5, 8, 27, 0, 81, 2, 95, 4, 66, 
    3, 68, 1, 10, 2, 78, 6, 30, 8, 43, 5, 40, 4, 84, 7, 62, 0, 70, 
    2, 42, 5, 27, 7, 54, 6, 48, 8, 41, 4, 69, 3, 12, 1, 31, 0, 95, 
    1, 68, 5, 22, 4, 54, 2, 26, 3, 60, 0, 34, 6, 24, 7, 23, 8, 24, 
    8, 59, 6, 34, 0, 82, 2, 40, 3, 77, 5, 93, 1, 81, 4, 76, 7, 99, 
    8, 10, 1, 14, 5, 97, 0, 59, 2, 46, 6, 69, 7, 64, 3, 71, 4,  3, 
    2, 92, 1, 21, 7, 63, 3, 80, 0, 23, 6, 90, 5, 64, 4, 95, 8, 51
  };
  const int q6451[] = {
    9, 9, // Number of jobs and machines
    7, 59, 3, 67, 5, 50, 4, 51, 2, 91, 6, 84, 0, 50, 1,  8, 8, 20, 
    8, 54, 0, 24, 3, 74, 5, 14, 6,  7, 7, 40, 1, 15, 4, 71, 2, 49, 
    2, 28, 1, 67, 4, 94, 5,  1, 3, 68, 0, 32, 8, 82, 6, 11, 7, 35, 
    5, 71, 3, 47, 6, 89, 7, 41, 0, 65, 2,  5, 8, 19, 1, 88, 4, 17, 
    0, 15, 4, 28, 7, 91, 2, 80, 5, 90, 3, 33, 6, 70, 1, 48, 8, 11, 
    0, 40, 5, 23, 6, 10, 4,  5, 2, 60, 8, 77, 7, 80, 3, 16, 1, 56, 
    5, 87, 7, 47, 3, 55, 4, 42, 2, 73, 8, 34, 1,  2, 6, 43, 0, 14, 
    4, 59, 1, 67, 6, 63, 3, 87, 5, 20, 2, 27, 0, 38, 7, 44, 8, 69, 
    6,  3, 8, 41, 0, 49, 3, 99, 1,  6, 7, 98, 4, 93, 5, 12, 2, 87
  };
  const int q6452[] = {
    9, 9, // Number of jobs and machines
    7, 50, 1, 52, 3, 98, 8, 47, 5, 37, 6, 49, 4, 23, 0, 88, 2, 67, 
    5, 45, 6, 96, 2,  7, 4, 51, 0,  1, 1, 15, 8, 77, 7, 85, 3,  1, 
    5, 12, 7, 17, 3,  5, 4, 82, 1, 71, 6, 72, 2, 49, 8, 20, 0, 91, 
    2, 64, 1, 10, 4, 83, 0, 25, 5, 87, 8, 95, 6, 31, 3, 59, 7, 43, 
    3, 67, 5, 69, 8, 82, 6, 86, 7, 57, 1, 51, 2, 66, 4, 45, 0, 26, 
    1, 53, 7, 46, 8, 22, 4, 85, 2, 14, 3, 57, 0, 93, 5, 64, 6, 78, 
    7, 54, 6, 94, 4, 34, 0, 41, 2,  6, 1, 88, 5, 38, 8, 74, 3, 63, 
    2, 57, 7, 98, 3, 73, 4, 12, 5, 94, 1, 15, 8, 78, 0, 42, 6, 35, 
    4, 31, 7, 40, 3, 19, 6, 13, 8, 93, 0, 67, 5, 67, 2,  5, 1, 80
  };
  const int q6453[] = {
    9, 9, // Number of jobs and machines
    3, 35, 8, 78, 0, 74, 5, 34, 1, 91, 4,  5, 6, 47, 2, 41, 7, 74, 
    4,  6, 6, 33, 2, 43, 1, 73, 8, 76, 3, 61, 5, 56, 0, 65, 7, 88, 
    5, 85, 6, 68, 3,  6, 4, 59, 7, 32, 0, 80, 8, 17, 2, 27, 1, 26, 
    4,  5, 1, 91, 8,  5, 6, 65, 0, 20, 2, 20, 5,  7, 7, 69, 3, 83, 
    7, 64, 3, 56, 6, 97, 8, 52, 1, 93, 2, 76, 4, 20, 5,  1, 0, 17, 
    3, 69, 0, 63, 5, 53, 6, 67, 2, 87, 7, 23, 1, 26, 8, 48, 4, 74, 
    5, 92, 4, 71, 8, 11, 1,  8, 3, 10, 0, 72, 7, 52, 2, 16, 6, 36, 
    6, 54, 1, 10, 3,  2, 4, 71, 0,  5, 5, 59, 7,  7, 8, 66, 2, 20, 
    3, 95, 4, 13, 7, 86, 6, 23, 5, 63, 2, 78, 0, 33, 1, 28, 8, 26
  };
  const int q6454[] = {
    9, 9, // Number of jobs and machines
    5, 76, 1, 30, 2, 44, 4, 70, 6, 40, 0, 38, 3, 26, 7, 37, 8, 68, 
    4, 27, 1, 22, 0, 35, 8, 48, 6, 10, 2, 28, 3, 75, 5, 87, 7, 59, 
    4, 31, 1, 35, 0,  4, 7, 71, 6, 72, 5,  3, 3, 90, 8, 60, 2, 61, 
    2, 86, 0, 68, 6, 44, 7, 23, 4, 73, 3, 55, 1, 91, 5, 32, 8, 88, 
    7, 44, 0, 62, 5, 35, 4,  9, 1, 94, 3, 59, 8, 28, 6, 29, 2, 21, 
    7, 99, 4, 35, 5,  6, 8, 58, 1, 94, 0, 99, 2, 35, 3, 46, 6, 78, 
    0,  8, 8, 87, 5,  3, 6, 92, 1, 72, 4,  5, 3, 79, 7, 91, 2,  8, 
    2, 28, 5, 30, 7, 50, 8, 91, 6, 49, 1, 45, 4, 29, 0, 65, 3, 31, 
    1, 31, 6, 21, 3, 78, 7, 54, 0, 76, 5,  3, 8, 98, 4, 41, 2, 29
  };
  const int q6455[] = {
    9, 9, // Number of jobs and machines
    3, 79, 5, 98, 7, 18, 4, 14, 2, 75, 1, 44, 6, 52, 0, 10, 8, 51, 
    4, 10, 8,  2, 6, 50, 2, 10, 3, 55, 5,  1, 1, 39, 0, 79, 7, 45, 
    2, 74, 1, 80, 5, 10, 8, 80, 7, 12, 6, 92, 4, 95, 0, 92, 3, 40, 
    2, 81, 8, 76, 3, 16, 0, 18, 6, 37, 5,  4, 1, 46, 7, 60, 4, 14, 
    2, 10, 6, 31, 4, 11, 3,  2, 0, 67, 8,  8, 5, 89, 1, 65, 7, 76, 
    3, 52, 6, 68, 5, 18, 7, 44, 8, 79, 1, 27, 4, 52, 2, 28, 0, 59, 
    6, 23, 2, 61, 1, 38, 8,  3, 0, 76, 5, 65, 4,  3, 3, 60, 7, 61, 
    3, 53, 0, 39, 8, 31, 4, 68, 5, 76, 6, 33, 7, 87, 1, 20, 2, 35, 
    6,  8, 1, 20, 4, 69, 7, 55, 0, 40, 2, 40, 8, 60, 5, 67, 3, 21
  };
  const int q6456[] = {
    9, 9, // Number of jobs and machines
    7, 16, 5,  2, 0, 72, 8,  7, 2, 80, 3, 50, 4, 72, 1, 62, 6, 29, 
    0,  9, 8, 63, 4, 29, 6, 82, 1, 56, 7, 29, 2, 42, 3, 50, 5, 12, 
    4, 87, 3,  3, 2, 28, 6, 66, 0, 62, 1, 50, 5, 50, 8, 90, 7, 92, 
    4,  7, 3, 63, 5, 38, 1, 16, 0, 68, 8, 80, 6, 23, 7, 25, 2, 68, 
    7, 49, 1, 38, 0, 70, 2, 51, 8, 58, 6, 16, 5, 24, 4,  2, 3, 45, 
    6, 63, 1, 25, 0, 13, 8, 86, 2, 90, 7, 38, 5, 91, 3, 58, 4,  9, 
    2, 74, 7, 85, 3, 21, 8, 84, 0, 56, 5, 86, 6,  7, 4,  8, 1,  8, 
    4,  3, 3, 97, 7, 55, 2, 33, 5, 88, 1, 34, 6, 53, 0, 38, 8, 58, 
    5, 48, 7,  3, 2,  7, 6, 14, 8, 64, 0, 96, 3, 46, 4,  2, 1, 37
  };
  const int q6457[] = {
    9, 9, // Number of jobs and machines
    6, 13, 2, 89, 1, 76, 3, 46, 5, 26, 0,  3, 8, 63, 4, 17, 7, 31, 
    2, 79, 1, 50, 8, 37, 3, 86, 6, 71, 0, 62, 5, 27, 7, 38, 4, 29, 
    1, 85, 3, 47, 5, 85, 0, 68, 2, 30, 7, 85, 4, 71, 8, 51, 6, 11, 
    8, 23, 3, 64, 7, 71, 6, 76, 1, 83, 5, 24, 0, 39, 4,  5, 2,  6, 
    4, 79, 1, 71, 6, 34, 3, 54, 8, 69, 7, 64, 2, 97, 0, 91, 5, 15, 
    8, 58, 4, 33, 7, 24, 3, 54, 1, 91, 0, 60, 5, 76, 6,  8, 2, 44, 
    0, 40, 4, 68, 6, 38, 7, 63, 8, 69, 3,  7, 1, 67, 5, 63, 2, 55, 
    0, 28, 1, 60, 6,  6, 4, 48, 3, 68, 7, 50, 5, 82, 8, 43, 2, 63, 
    1, 38, 4, 36, 2,  2, 0, 64, 8, 45, 3, 42, 7, 81, 6, 47, 5, 43
  };
  const int q6458[] = {
    9, 9, // Number of jobs and machines
    2, 34, 5, 46, 1, 88, 6,  6, 7, 82, 8, 49, 0, 88, 4, 84, 3, 50, 
    3, 23, 0, 12, 7, 58, 6, 87, 2, 13, 4, 27, 1,  9, 8, 41, 5, 82, 
    6, 61, 5, 19, 2, 72, 3, 92, 0, 34, 4, 67, 1, 38, 7,  7, 8, 84, 
    0, 61, 5, 35, 6, 69, 3, 86, 1, 28, 2, 16, 7, 69, 8, 74, 4, 19, 
    7, 29, 8, 68, 4, 99, 3, 16, 0, 61, 2, 87, 5, 96, 1, 59, 6, 12, 
    3, 73, 1,  6, 0, 52, 7, 21, 6, 38, 2, 11, 8, 89, 5, 82, 4, 73, 
    4, 64, 3, 67, 8, 57, 7, 77, 2,  5, 0,  9, 5, 14, 1, 18, 6, 19, 
    3, 79, 0, 67, 4, 86, 7, 24, 8, 26, 5, 85, 6, 69, 1, 53, 2, 11, 
    7, 65, 2, 49, 8, 14, 6, 57, 1, 34, 4, 24, 3, 76, 0, 22, 5,  4
  };
  const int q6459[] = {
    9, 9, // Number of jobs and machines
    0, 31, 6, 84, 5, 93, 8, 21, 7, 47, 3, 21, 4, 95, 1, 94, 2,  2, 
    8, 60, 4, 84, 1, 70, 0, 30, 3, 52, 5, 91, 6, 74, 2, 70, 7, 53, 
    0, 93, 1, 55, 3, 40, 4, 64, 7, 56, 8, 80, 6, 30, 2, 31, 5, 76, 
    3, 59, 8,  8, 7, 56, 5,  6, 1, 62, 4,  5, 0, 37, 6, 46, 2, 12, 
    5,  1, 0, 80, 7, 68, 2,  4, 6, 92, 4, 74, 8, 63, 1, 85, 3, 36, 
    0, 65, 3, 36, 2, 69, 1, 27, 6, 35, 5, 18, 4, 40, 7, 77, 8, 13, 
    4, 37, 8, 73, 7, 78, 0, 73, 1, 88, 3, 38, 6, 83, 5, 31, 2, 97, 
    0, 98, 8,  5, 7, 98, 6, 85, 3, 67, 2, 56, 1,  8, 4, 51, 5, 46, 
    4, 49, 7, 63, 6,  8, 8, 86, 3, 83, 5, 88, 1, 36, 0, 30, 2, 39
  };
  const int q6460[] = {
    9, 9, // Number of jobs and machines
    8, 74, 0, 10, 4, 29, 2, 17, 3, 57, 1, 41, 5, 92, 7, 23, 6, 17, 
    3, 17, 5,  6, 7, 82, 8, 47, 1, 47, 4, 86, 2, 68, 6, 91, 0, 42, 
    2, 33, 4, 67, 8, 31, 0, 50, 6, 57, 5, 21, 3, 58, 1, 21, 7, 40, 
    4, 64, 1, 83, 2, 23, 8, 95, 5, 66, 6, 44, 7, 59, 3,  1, 0, 96, 
    3, 51, 0, 89, 5, 90, 7, 78, 6,  9, 8, 14, 1, 59, 4, 31, 2, 65, 
    2, 10, 4, 60, 6, 86, 8, 60, 1, 61, 7, 91, 0, 70, 3, 72, 5, 29, 
    5, 56, 2, 42, 3, 40, 7, 39, 8, 91, 6, 29, 1, 28, 0, 11, 4, 71, 
    8, 54, 1, 32, 2, 37, 3, 15, 4, 74, 0, 72, 7, 75, 5, 56, 6, 92, 
    7, 24, 6, 10, 4, 95, 1, 40, 2, 82, 8, 88, 3, 14, 5, 74, 0, 76
  };
  const int q6461[] = {
    9, 9, // Number of jobs and machines
    0, 82, 8, 97, 1, 89, 2, 20, 7, 39, 5, 96, 3, 80, 4, 28, 6, 52, 
    3, 98, 6, 46, 5, 90, 0, 96, 7, 37, 2, 15, 8, 90, 4, 62, 1, 46, 
    3, 74, 6, 64, 8, 18, 5,  6, 0, 92, 1, 56, 7,  7, 4, 36, 2, 43, 
    3, 55, 0, 61, 2, 36, 7, 78, 1, 40, 4, 25, 5, 48, 6,  1, 8, 86, 
    3, 47, 5, 75, 6, 69, 1, 13, 4, 95, 8, 16, 0, 64, 7, 37, 2, 77, 
    4, 22, 0, 90, 8, 98, 2, 51, 3, 69, 5, 52, 6, 86, 7, 82, 1, 99, 
    2, 31, 6, 22, 4, 66, 3, 65, 8, 24, 1, 85, 0, 15, 7, 61, 5, 37, 
    3, 82, 2,  5, 7, 65, 6, 60, 0, 50, 1, 35, 8,  7, 4,  1, 5, 81, 
    8, 33, 5, 97, 3, 36, 7, 36, 1, 65, 6, 89, 0, 82, 4, 48, 2, 78
  };
  const int q6462[] = {
    9, 9, // Number of jobs and machines
    6, 97, 1, 45, 2, 66, 7, 33, 0, 63, 5, 86, 8, 24, 4, 58, 3, 32, 
    8, 68, 4, 87, 0, 47, 3, 80, 1,  1, 6, 13, 2, 28, 5, 44, 7, 56, 
    3, 50, 2, 54, 8, 40, 4, 16, 6, 25, 1, 65, 5,  7, 0, 42, 7,  3, 
    6, 23, 8,  7, 7, 15, 5,  7, 2, 55, 3, 57, 4,  7, 0, 65, 1, 88, 
    1, 96, 4, 40, 8, 65, 0, 83, 6, 38, 3, 19, 2, 32, 7, 45, 5, 65, 
    2, 94, 5, 82, 8, 23, 7, 92, 1, 45, 6, 27, 0, 97, 3, 72, 4, 12, 
    5, 29, 7, 19, 4, 33, 0, 39, 2, 47, 1, 91, 6, 45, 8, 53, 3, 38, 
    3, 39, 0, 62, 6, 31, 4, 82, 7, 76, 1, 18, 5, 88, 8, 76, 2, 82, 
    7, 45, 5, 31, 6, 75, 0, 79, 3, 94, 8, 97, 2, 70, 4, 91, 1, 57
  };
  const int q6463[] = {
    9, 9, // Number of jobs and machines
    0, 30, 2, 42, 8, 32, 6, 47, 1, 20, 7, 53, 3, 83, 4, 80, 5, 61, 
    4, 30, 0, 21, 6, 72, 3, 16, 8, 59, 7, 39, 2, 20, 1, 22, 5, 98, 
    1, 43, 6, 31, 4, 75, 5, 40, 2, 28, 8, 24, 7, 42, 3, 25, 0, 49, 
    3, 55, 1, 66, 2, 72, 7, 45, 0, 83, 6, 12, 4, 99, 5, 42, 8, 97, 
    4, 65, 2, 27, 8, 95, 3, 39, 5, 31, 6, 65, 0,  4, 7, 82, 1,  3, 
    6, 12, 7, 58, 4, 56, 3, 73, 1, 83, 5,  7, 8, 97, 2, 83, 0, 34, 
    7, 45, 8, 26, 4, 81, 3, 19, 0, 18, 5, 75, 6, 80, 2, 89, 1, 73, 
    0, 46, 1, 41, 2, 35, 8, 58, 4,  5, 7, 41, 6, 65, 5,  6, 3, 36, 
    7, 31, 6,  9, 2, 21, 3, 26, 4, 99, 8,  6, 0, 35, 1, 40, 5, 15
  };
  const int q6464[] = {
    9, 9, // Number of jobs and machines
    0, 59, 3, 72, 1, 45, 4, 86, 5, 80, 8, 25, 7, 18, 6, 16, 2,  3, 
    8, 53, 5, 84, 0, 21, 2, 92, 4, 53, 1, 71, 6, 88, 3, 76, 7, 64, 
    6, 71, 7, 60, 4, 93, 1, 92, 0, 59, 2, 74, 8, 11, 5,  3, 3, 58, 
    3, 24, 8,  2, 1,  9, 4, 65, 0, 33, 5, 94, 7, 38, 6, 69, 2, 20, 
    8, 83, 7, 54, 0, 55, 1, 46, 2, 97, 5, 62, 3, 12, 4, 13, 6, 91, 
    5, 53, 7, 76, 1, 28, 0, 26, 6, 32, 3, 81, 2, 77, 4, 93, 8, 18, 
    8,  4, 4, 98, 0, 56, 2, 76, 5, 55, 7, 57, 3, 36, 6, 49, 1, 24, 
    1, 23, 3, 28, 4, 11, 2, 31, 7, 61, 0,  1, 6, 10, 8, 72, 5, 80, 
    8, 11, 6, 34, 5, 19, 3, 38, 0,  9, 7, 78, 2, 58, 4,  5, 1, 27
  };
  const int q6465[] = {
    9, 9, // Number of jobs and machines
    3, 11, 0, 25, 2, 81, 8, 71, 1, 25, 6, 12, 4, 28, 5, 26, 7, 69, 
    1, 22, 6, 34, 8, 65, 4, 85, 5, 42, 2, 34, 3, 28, 0, 27, 7, 25, 
    4, 84, 3, 84, 7, 45, 2, 33, 6, 25, 5, 16, 0, 59, 1, 56, 8, 63, 
    4, 77, 6, 49, 0, 35, 2, 29, 7, 68, 1, 59, 8, 25, 3,  9, 5, 18, 
    7, 61, 0, 21, 4, 47, 1, 74, 6, 72, 5, 98, 3, 31, 2, 48, 8, 47, 
    2, 41, 5, 22, 7, 17, 0, 41, 3, 43, 6, 16, 1, 90, 8, 16, 4, 58, 
    4, 40, 7, 54, 3, 74, 8, 74, 1,  3, 6, 55, 2, 24, 0, 75, 5, 52, 
    0, 65, 6, 82, 2, 48, 4, 50, 8, 44, 5, 21, 3, 39, 1,  6, 7, 98, 
    5, 17, 4, 84, 8, 46, 2, 56, 1, 15, 6, 11, 3, 54, 7, 48, 0, 24
  };
  const int q6466[] = {
    9, 9, // Number of jobs and machines
    8, 12, 3, 85, 7, 95, 5, 45, 6, 45, 1, 70, 2, 18, 4, 19, 0, 20, 
    1, 21, 8, 13, 2, 47, 4, 35, 7, 16, 3, 68, 0, 12, 5, 29, 6, 90, 
    2, 99, 8,  9, 1, 22, 6, 56, 3,  4, 5,  4, 7, 93, 0, 86, 4, 85, 
    8, 73, 5,  2, 3, 57, 2, 24, 0, 39, 4, 26, 7, 97, 1,  7, 6, 10, 
    5, 65, 1, 84, 8, 58, 4, 16, 7, 13, 0, 81, 6, 22, 3, 37, 2, 14, 
    5, 66, 1, 94, 0, 85, 4, 91, 8, 62, 2, 55, 6, 67, 3, 17, 7, 74, 
    0, 67, 4, 68, 3,  9, 1, 97, 8, 22, 7, 40, 6, 99, 2, 46, 5, 98, 
    6, 79, 1, 74, 5, 41, 2, 76, 8, 81, 4,  6, 0, 30, 7, 29, 3, 83, 
    6, 86, 3, 62, 5, 95, 7, 27, 0,  9, 4, 88, 1, 13, 2, 99, 8, 61
  };
  const int q6467[] = {
    9, 9, // Number of jobs and machines
    5, 40, 2, 36, 1, 97, 8, 31, 0, 70, 6, 14, 3, 26, 7, 63, 4, 69, 
    1, 55, 0, 90, 3, 21, 7, 61, 8, 94, 6, 68, 5, 98, 4,  4, 2, 59, 
    4,  6, 5, 92, 1, 66, 7, 42, 2, 48, 6, 10, 0, 36, 3, 59, 8, 69, 
    0, 12, 3, 66, 8, 17, 5, 50, 6, 60, 2, 19, 7, 29, 1, 11, 4, 83, 
    8, 34, 7, 15, 5, 67, 1, 22, 3, 21, 0, 61, 2, 13, 4,  5, 6,  3, 
    0, 95, 2,  9, 7, 87, 8, 83, 1, 96, 4,  7, 5, 57, 6, 35, 3, 67, 
    5, 85, 1, 41, 3, 98, 6, 34, 4, 32, 2, 44, 7, 94, 0,  2, 8, 60, 
    8, 77, 5, 66, 3, 97, 7, 39, 0, 90, 1, 43, 4, 49, 6, 24, 2, 71, 
    0, 42, 2,  4, 4, 95, 5,  3, 3, 21, 6, 22, 1, 16, 8, 12, 7, 47
  };
  const int q6468[] = {
    9, 9, // Number of jobs and machines
    4, 66, 2, 76, 3, 52, 8, 61, 0, 61, 5, 11, 1, 11, 7, 54, 6, 96, 
    6, 23, 1, 54, 4, 39, 2, 94, 5, 45, 0,  5, 7, 39, 3, 76, 8, 55, 
    8, 25, 0, 78, 5, 38, 6, 54, 3, 60, 2, 26, 1,  2, 4,  7, 7, 52, 
    7, 53, 0, 24, 5, 74, 3, 15, 2, 89, 4, 63, 1, 76, 6, 23, 8, 24, 
    8, 79, 7, 91, 0, 41, 4, 16, 1, 12, 6, 14, 3, 75, 2, 18, 5, 76, 
    2, 58, 1, 60, 6, 66, 7, 81, 8, 94, 5, 98, 3, 96, 4, 89, 0, 72, 
    5,  6, 7, 80, 1, 55, 6, 49, 0, 69, 3, 52, 2, 95, 4, 23, 8, 93, 
    4, 26, 0, 23, 5, 56, 6, 36, 3, 51, 8, 17, 2, 54, 1, 93, 7, 30, 
    3,  6, 5,  9, 1, 33, 7, 88, 0, 75, 6, 92, 4, 53, 8, 70, 2, 43
  };
  const int q6469[] = {
    9, 9, // Number of jobs and machines
    3,  7, 8, 95, 5, 28, 6, 14, 4, 95, 2, 10, 1, 26, 0, 93, 7,  1, 
    3, 40, 7, 83, 6, 43, 5, 46, 0, 85, 4, 78, 1, 95, 8, 66, 2, 61, 
    3, 96, 1, 33, 8, 88, 0, 79, 5, 34, 2, 22, 4, 25, 6, 74, 7, 92, 
    2,  1, 7,  1, 1, 72, 0,  9, 8, 85, 3, 10, 6,  2, 5, 49, 4, 99, 
    7,  1, 5, 49, 6, 47, 8, 44, 4, 24, 0, 21, 1, 55, 2, 50, 3, 43, 
    5, 34, 0, 18, 6, 67, 3, 30, 7, 43, 4, 44, 2, 79, 1, 74, 8, 63, 
    4, 40, 1,  6, 7, 90, 0, 44, 8,  5, 5, 77, 3, 73, 6, 89, 2, 41, 
    8, 94, 4,  3, 1, 47, 0, 55, 6, 94, 5, 66, 7, 98, 2, 93, 3, 24, 
    5, 27, 8, 43, 4, 45, 0, 64, 7, 59, 2, 34, 1, 17, 6, 23, 3, 33
  };
  const int q6470[] = {
    9, 9, // Number of jobs and machines
    6,  5, 0, 98, 2, 13, 7,  3, 1, 89, 3, 97, 4, 23, 8, 17, 5, 41, 
    3, 27, 4, 26, 0, 86, 7, 20, 8, 62, 6, 13, 1, 90, 5,  8, 2, 42, 
    1, 11, 0, 36, 8, 61, 5,  7, 4, 51, 6, 78, 3, 17, 7, 28, 2, 46, 
    3, 13, 2, 27, 6, 94, 7, 77, 8, 54, 4, 76, 0, 11, 1, 16, 5, 65, 
    0, 71, 2, 82, 3, 13, 7, 19, 8, 99, 1, 97, 6, 19, 5, 95, 4, 69, 
    6, 55, 0, 70, 4, 10, 1, 15, 2, 40, 8, 10, 7,  4, 3,  5, 5, 71, 
    2, 76, 7, 57, 6, 83, 5, 86, 3, 42, 0, 62, 1,  2, 8,  1, 4, 89, 
    6, 68, 4, 14, 7, 68, 5, 80, 8, 77, 3,  6, 1, 44, 2, 45, 0, 81, 
    8, 47, 4, 81, 2, 30, 7, 52, 0, 54, 3, 38, 6, 67, 5, 31, 1, 43
  };
  const int q6471[] = {
    9, 9, // Number of jobs and machines
    5,  8, 1, 26, 8, 76, 0, 36, 6, 33, 4, 49, 3, 60, 2, 74, 7, 84, 
    7, 62, 4,  9, 8, 84, 3, 74, 2,  7, 6, 77, 5, 42, 0,  8, 1, 79, 
    2, 71, 4, 86, 6,  2, 3, 26, 8, 99, 5, 45, 7, 94, 1, 94, 0, 99, 
    4, 53, 3, 69, 2, 90, 0, 76, 5, 94, 8, 56, 7, 30, 6, 42, 1, 57, 
    8, 38, 0, 50, 6, 23, 5, 67, 1, 74, 4, 49, 3, 84, 7, 75, 2,  7, 
    3, 49, 0, 74, 8, 51, 7, 40, 2, 48, 1, 94, 4, 66, 6, 52, 5, 73, 
    3, 55, 1, 32, 0, 74, 6, 75, 7, 53, 5, 87, 8, 94, 4,  2, 2, 71, 
    5, 39, 3, 54, 7,  4, 1, 57, 0, 21, 4, 21, 8,  4, 2, 19, 6, 10, 
    2, 97, 0, 55, 7, 94, 6, 24, 4, 29, 8, 37, 5, 56, 1, 39, 3, 37
  };
  const int q6472[] = {
    9, 9, // Number of jobs and machines
    1, 41, 8, 72, 5, 62, 3,  9, 4, 93, 0, 82, 7, 18, 2, 70, 6, 42, 
    0, 55, 2, 13, 3, 94, 7,  6, 5, 23, 4, 54, 1, 14, 6, 92, 8, 79, 
    3, 77, 5, 45, 0,  9, 6, 67, 4, 70, 1,  1, 7, 55, 8, 99, 2, 64, 
    8, 22, 0, 33, 6, 50, 3, 33, 7, 62, 2, 91, 5, 58, 1,  7, 4, 44, 
    1,  8, 2, 83, 3, 49, 6, 20, 7, 95, 4, 24, 0,  9, 5, 25, 8, 37, 
    8, 26, 1, 81, 4, 91, 2, 31, 3, 52, 0,  8, 6, 37, 7, 38, 5, 79, 
    4, 87, 7, 24, 0, 52, 2, 30, 5, 12, 1, 25, 6,  8, 8, 51, 3, 54, 
    5, 66, 8, 67, 3, 69, 7, 55, 0, 21, 2, 68, 1, 11, 4, 85, 6, 21, 
    8, 42, 0, 25, 1, 13, 7,  2, 4, 69, 6, 11, 3, 85, 5, 29, 2, 80
  };
  const int q6473[] = {
    9, 9, // Number of jobs and machines
    6, 29, 4,  5, 8, 76, 3,  3, 2, 12, 0, 21, 7, 10, 1, 95, 5,  4, 
    2, 12, 8, 98, 3, 70, 4, 55, 1, 97, 0, 51, 5, 66, 6,  3, 7, 49, 
    2, 36, 8, 38, 5, 65, 4, 99, 6, 79, 7, 42, 0,  9, 1, 90, 3, 76, 
    2, 90, 0, 83, 4, 67, 8, 72, 6, 50, 1, 42, 5, 27, 3, 67, 7, 60, 
    1, 18, 0, 19, 8, 20, 5, 18, 3, 63, 6, 17, 7, 49, 4, 89, 2, 53, 
    3, 84, 6, 39, 0,  6, 8, 92, 5, 54, 4, 80, 7, 51, 2, 79, 1, 37, 
    5, 64, 8, 44, 2, 83, 4, 91, 0, 35, 7, 75, 6, 99, 3, 92, 1, 90, 
    2, 75, 3,  3, 6,  7, 5, 19, 0, 24, 4, 12, 1, 57, 8, 11, 7, 38, 
    1, 76, 4,  8, 7, 90, 2, 45, 3, 76, 6, 34, 0, 84, 5, 16, 8, 51
  };
  const int q6474[] = {
    9, 9, // Number of jobs and machines
    6,  4, 3, 74, 8, 11, 0, 59, 4, 15, 2, 69, 1, 59, 5, 71, 7, 36, 
    1, 63, 7, 65, 2, 51, 0, 23, 8, 41, 6, 67, 5, 60, 4, 70, 3, 64, 
    4, 23, 1, 30, 8,  3, 2, 71, 0, 40, 7, 49, 3, 35, 5, 98, 6, 90, 
    2, 37, 5, 59, 3, 18, 4, 95, 0,  8, 6, 10, 1, 99, 8, 73, 7,  2, 
    1, 82, 6, 87, 5, 65, 0, 13, 7, 67, 8, 80, 4, 53, 2, 73, 3,  1, 
    2, 78, 3, 74, 0, 17, 7, 79, 1, 97, 6, 86, 5,  8, 8, 38, 4, 50, 
    1, 23, 8, 85, 0, 57, 4, 79, 7,  2, 2, 90, 3,  9, 5, 40, 6, 16, 
    8, 66, 3, 73, 0, 91, 5, 28, 4, 92, 1, 63, 2, 36, 6, 65, 7, 28, 
    2, 31, 4, 66, 1, 74, 5, 38, 3, 43, 6, 69, 0, 25, 8, 23, 7, 61
  };
  const int q6475[] = {
    9, 9, // Number of jobs and machines
    2, 76, 6, 12, 0,  9, 5, 33, 7, 34, 8, 17, 3, 45, 4, 63, 1, 55, 
    6, 71, 1, 21, 3, 67, 5, 98, 8, 98, 2,  3, 4, 81, 7, 50, 0, 47, 
    2, 26, 0, 58, 1, 76, 6, 10, 5, 97, 8, 63, 3, 81, 4, 38, 7, 62, 
    3, 87, 2, 99, 5, 89, 6, 78, 7, 72, 0, 36, 1, 58, 8, 93, 4, 97, 
    2, 78, 4, 20, 8, 84, 5, 73, 3, 74, 1, 13, 0, 43, 6, 22, 7, 85, 
    5, 90, 0, 44, 7, 37, 1, 53, 8, 34, 3, 52, 4, 60, 2, 54, 6, 33, 
    3, 40, 4,  2, 0, 73, 8, 96, 7, 67, 6, 50, 2,  3, 5, 11, 1, 95, 
    8, 20, 5, 68, 4, 60, 7, 54, 3, 83, 2,  9, 1,  1, 6, 70, 0, 98, 
    4, 16, 6, 86, 8, 26, 2, 25, 5, 19, 1, 91, 3, 35, 7, 86, 0, 52
  };
  const int q6476[] = {
    9, 9, // Number of jobs and machines
    8, 46, 0, 79, 4, 43, 5, 80, 2, 29, 3, 29, 6, 26, 7, 80, 1, 25, 
    0, 47, 3, 15, 2, 13, 1, 72, 7, 41, 6, 34, 8, 24, 4, 56, 5, 17, 
    4, 31, 8, 71, 5, 12, 0, 35, 2, 90, 6, 69, 3, 62, 7, 38, 1, 27, 
    0, 90, 5, 51, 6, 54, 2, 87, 1, 84, 7, 11, 3, 58, 4, 43, 8,  7, 
    5,  4, 2, 98, 0, 87, 1, 12, 8, 94, 3, 88, 7,  6, 6, 79, 4, 21, 
    1, 33, 7,  2, 5, 57, 6, 47, 0, 92, 4, 72, 8, 84, 3, 37, 2,  4, 
    8, 92, 1, 37, 4, 69, 6, 46, 0,  9, 2, 53, 3, 32, 5, 83, 7, 71, 
    7, 78, 6, 97, 8, 29, 3, 55, 2, 95, 5, 15, 4, 51, 1, 45, 0, 59, 
    6, 31, 1, 91, 7, 65, 3, 51, 4, 27, 2, 74, 8, 63, 5, 33, 0, 44
  };
  const int q6477[] = {
    9, 9, // Number of jobs and machines
    2,  5, 5,  2, 0, 56, 1, 79, 3, 53, 7, 16, 4, 26, 6, 46, 8, 67, 
    1, 55, 0, 87, 3,  2, 6, 28, 4, 57, 5, 24, 2, 16, 8, 57, 7, 41, 
    3, 32, 6, 29, 8, 79, 5, 41, 0, 55, 7,  6, 4, 13, 2,  3, 1,  9, 
    4, 21, 3, 17, 0, 78, 1, 45, 7, 51, 2,  4, 5,  6, 6, 50, 8, 68, 
    0, 62, 3, 20, 1, 78, 7, 42, 5, 36, 2, 93, 6, 27, 8, 23, 4, 63, 
    6,  1, 5,  2, 7, 58, 2, 32, 1, 33, 3, 14, 8, 65, 0, 97, 4, 54, 
    2, 39, 3, 53, 6, 47, 8, 28, 0, 51, 4, 82, 7, 28, 1, 87, 5, 38, 
    4, 82, 7, 30, 0, 90, 8, 57, 5, 57, 6, 62, 2, 26, 3,  9, 1, 90, 
    6, 40, 5, 14, 7, 78, 3,  9, 4, 84, 8, 71, 1, 20, 2, 60, 0, 51
  };
  const int q6478[] = {
    9, 9, // Number of jobs and machines
    6, 93, 4, 95, 7, 96, 0, 82, 2, 25, 3, 12, 5, 12, 1, 53, 8, 85, 
    7, 81, 4, 59, 2, 94, 1, 40, 5, 29, 3, 43, 6, 47, 8, 30, 0, 78, 
    4, 39, 3, 59, 7, 74, 8, 91, 1, 84, 2, 88, 5,  6, 0, 96, 6, 81, 
    4, 21, 8, 26, 5, 82, 1, 95, 6, 76, 3, 86, 2, 27, 7, 83, 0, 42, 
    8, 75, 3, 44, 4,  1, 0, 32, 5, 36, 7, 80, 2, 88, 1,  2, 6, 98, 
    6, 70, 2, 73, 7, 59, 3, 55, 0, 67, 1, 26, 4, 22, 5,  6, 8, 17, 
    0, 17, 7, 94, 4, 65, 2, 82, 3, 70, 8, 86, 5, 67, 1, 36, 6, 48, 
    8, 19, 4, 27, 0, 48, 7, 83, 2, 69, 5, 59, 3, 55, 1, 11, 6, 48, 
    7, 68, 4, 75, 0, 68, 2, 41, 3,  4, 8, 37, 5, 62, 6, 99, 1, 99
  };
  const int q6479[] = {
    9, 9, // Number of jobs and machines
    7, 59, 2, 73, 6, 14, 8, 85, 4, 82, 3, 41, 5, 88, 0, 83, 1, 52, 
    0, 55, 7, 98, 2, 68, 5, 43, 8, 79, 6, 50, 4, 22, 1, 57, 3, 24, 
    8, 44, 2, 80, 3, 99, 1, 75, 6,  7, 0, 64, 5, 73, 4, 76, 7, 61, 
    5, 86, 6, 19, 4, 27, 1, 51, 0, 56, 3, 58, 8, 91, 7,  9, 2, 74, 
    3, 99, 7, 43, 4, 14, 0, 75, 2, 84, 6, 80, 5, 80, 1, 88, 8, 90, 
    2, 62, 5, 50, 3, 11, 0, 16, 7, 50, 4, 88, 8, 17, 1, 28, 6, 86, 
    3, 98, 7, 33, 1, 60, 8, 70, 4, 85, 5, 34, 6, 72, 2,  5, 0, 90, 
    4, 55, 6, 64, 2, 80, 1, 16, 7, 31, 0,  9, 8, 93, 5, 62, 3, 49, 
    0, 72, 8, 24, 6,  6, 5, 47, 4, 72, 2, 94, 1,  8, 3, 77, 7, 25
  };
  const int q6480[] = {
    9, 9, // Number of jobs and machines
    8, 69, 2, 75, 1, 14, 7, 99, 0, 17, 4, 68, 5, 83, 6, 73, 3, 49, 
    1, 19, 7, 74, 4, 90, 0, 91, 3, 87, 6, 18, 2, 67, 5, 58, 8, 94, 
    8,  5, 7, 27, 2, 38, 4, 98, 6, 60, 1, 82, 0, 28, 3, 31, 5, 51, 
    8, 93, 7, 57, 3, 30, 5, 68, 0, 66, 6, 80, 1, 88, 4,  9, 2,  1, 
    7, 41, 8, 18, 0, 56, 6, 93, 4, 20, 1, 74, 5, 78, 2, 58, 3, 49, 
    8, 61, 7, 67, 1,  8, 4, 63, 5, 12, 6, 76, 3, 27, 2, 39, 0, 77, 
    1,  2, 7, 57, 3, 94, 6, 52, 2,  5, 5,  3, 4, 10, 0, 77, 8, 49, 
    4, 83, 3, 11, 0, 27, 6, 24, 1, 50, 8, 79, 5, 15, 2,  2, 7, 51, 
    7, 48, 3, 59, 5, 64, 6, 27, 0, 54, 1, 57, 2, 49, 4, 42, 8, 73
  };
  const int q6481[] = {
    9, 9, // Number of jobs and machines
    3, 97, 5, 39, 6, 19, 1,  7, 0, 24, 8, 10, 4, 98, 2, 80, 7, 84, 
    2, 19, 8, 72, 5, 25, 0, 43, 6, 99, 4,  8, 3, 25, 1, 20, 7, 82, 
    6, 39, 5, 17, 0, 68, 7, 79, 1, 81, 8, 81, 3, 30, 2, 11, 4, 35, 
    2, 55, 4, 49, 1, 20, 3, 39, 8, 29, 7, 43, 6, 11, 5, 74, 0, 91, 
    5, 47, 8, 45, 0, 42, 6, 14, 2, 32, 4, 68, 7, 10, 1, 63, 3, 23, 
    5,  6, 3, 80, 1, 31, 8, 32, 7,  1, 6,  3, 2, 19, 4, 79, 0, 11, 
    0, 48, 2,  2, 7,  7, 6, 48, 3, 72, 4, 50, 8, 79, 5, 31, 1, 78, 
    0, 49, 5, 23, 3, 28, 7, 93, 8, 77, 2, 23, 6, 16, 1, 65, 4, 85, 
    6, 38, 4, 94, 5, 40, 1, 14, 3, 39, 7, 18, 0, 82, 2,  2, 8, 65
  };
  const int q6482[] = {
    9, 9, // Number of jobs and machines
    7,  8, 0, 72, 3, 11, 8, 27, 1, 67, 4, 63, 5, 45, 2, 85, 6, 43, 
    1, 25, 7, 43, 4, 44, 3, 26, 2, 50, 8, 43, 6, 78, 5, 80, 0,  2, 
    2, 30, 0, 54, 5, 82, 6, 66, 3, 52, 4, 19, 7,  3, 8, 86, 1, 82, 
    2, 25, 5, 84, 7, 44, 1, 91, 4, 32, 0, 80, 8, 34, 3, 55, 6, 54, 
    0,  9, 4, 77, 3, 26, 8, 82, 6, 41, 5, 33, 1, 25, 2, 93, 7, 49, 
    6, 95, 1, 57, 8, 83, 0,  5, 5, 18, 3, 79, 2, 95, 4, 72, 7, 76, 
    3, 46, 8, 85, 0, 79, 1, 11, 2, 75, 7, 71, 6, 46, 4, 19, 5, 45, 
    3, 47, 5, 53, 4, 28, 6, 35, 2, 61, 0, 70, 7, 14, 1, 16, 8, 11, 
    6, 74, 8, 62, 4, 43, 5, 49, 1, 48, 0, 21, 7, 25, 3, 44, 2, 30
  };
  const int q6483[] = {
    9, 9, // Number of jobs and machines
    5, 33, 4, 62, 2, 98, 8,  5, 1, 12, 0, 53, 6, 59, 3, 70, 7, 68, 
    6, 85, 8, 87, 0, 81, 5, 71, 7, 31, 3, 69, 4, 41, 2, 19, 1, 91, 
    4, 23, 7,  2, 0, 27, 2, 85, 1, 54, 8, 15, 3, 50, 6, 97, 5, 39, 
    4, 71, 1, 97, 6, 87, 3, 32, 0, 70, 8, 77, 5, 12, 7, 24, 2,  2, 
    7, 71, 4, 60, 3, 76, 2, 61, 1, 75, 5,  3, 6, 13, 0, 45, 8,  2, 
    8, 51, 2, 64, 5, 30, 3,  9, 6, 86, 7, 79, 0, 31, 4, 16, 1, 60, 
    3, 33, 5, 53, 8, 87, 4,  6, 7, 77, 0, 37, 2, 93, 6, 57, 1, 11, 
    2, 18, 1,  1, 7, 10, 8, 98, 5, 62, 0, 95, 4, 40, 3, 67, 6, 27, 
    3, 42, 8,  7, 6, 37, 0, 57, 2, 12, 5,  7, 4, 90, 1, 52, 7, 84
  };
  const int q6484[] = {
    9, 9, // Number of jobs and machines
    0, 86, 4, 38, 3, 52, 6, 28, 5, 18, 1, 16, 8, 94, 2,  1, 7, 78, 
    7, 77, 2, 76, 0, 66, 8, 71, 3,  9, 4, 52, 5, 82, 6, 23, 1, 53, 
    8, 42, 7, 31, 3, 98, 0, 15, 1, 46, 6, 76, 5, 48, 4, 53, 2, 16, 
    1, 17, 5, 52, 6, 88, 4, 74, 0, 60, 2, 93, 7, 36, 3, 52, 8,  3, 
    7, 50, 4, 60, 8, 94, 0, 57, 1, 44, 2, 81, 5, 90, 6, 46, 3, 98, 
    8, 20, 7, 90, 5,  2, 4, 91, 1, 14, 2, 74, 3, 29, 6, 14, 0, 50, 
    2, 56, 8, 85, 7, 99, 6, 87, 3, 22, 1,  8, 0,  3, 4, 54, 5, 49, 
    8, 20, 0, 22, 3, 48, 4, 27, 1, 99, 5, 46, 7, 12, 2, 87, 6, 70, 
    7, 71, 5, 64, 4, 89, 2, 80, 6, 41, 3, 74, 8, 40, 1, 53, 0, 25
  };
  const int q6485[] = {
    9, 9, // Number of jobs and machines
    1, 92, 5, 51, 7, 54, 8, 46, 6, 68, 4, 53, 2, 19, 3, 39, 0, 51, 
    5, 15, 0, 49, 8, 34, 1, 28, 6, 44, 4, 63, 7, 63, 2, 29, 3, 36, 
    2, 63, 7, 38, 4,  6, 8, 85, 6, 90, 0, 36, 1, 72, 5, 81, 3, 54, 
    5, 42, 4, 92, 1, 54, 3, 64, 0, 16, 6, 29, 2, 98, 7, 50, 8, 48, 
    1, 42, 5, 64, 8, 23, 0, 27, 7, 26, 4, 79, 2, 66, 3, 46, 6, 57, 
    5, 23, 3, 16, 2, 58, 7, 40, 0, 52, 4,  2, 1, 19, 6, 92, 8, 36, 
    8, 30, 7, 43, 2,  5, 6, 45, 3, 51, 4,  2, 1, 98, 0, 10, 5, 34, 
    1, 67, 3, 81, 0, 47, 7, 38, 2, 83, 4, 96, 6, 42, 8,  1, 5, 10, 
    6, 12, 3, 57, 4, 40, 2, 63, 0, 43, 5, 13, 8, 62, 1, 33, 7, 49
  };
  const int q6486[] = {
    9, 9, // Number of jobs and machines
    7, 75, 4, 51, 0, 84, 6, 51, 3, 56, 5, 35, 2, 11, 8, 73, 1, 34, 
    2, 36, 7, 43, 8, 35, 1, 70, 4, 49, 0, 66, 6, 95, 3, 98, 5, 86, 
    3, 58, 8, 45, 7, 34, 6, 15, 0, 31, 2, 63, 4, 41, 5, 89, 1, 70, 
    3, 88, 4, 10, 6, 90, 0, 77, 7, 48, 1, 68, 2, 41, 5, 33, 8, 50, 
    5, 38, 7, 73, 8, 89, 2, 31, 1, 87, 4, 98, 0,  1, 6, 63, 3, 27, 
    1, 85, 4, 29, 2, 13, 6, 28, 7, 58, 0, 29, 3, 62, 8, 97, 5, 63, 
    1, 90, 4, 29, 3, 50, 6,  9, 2, 67, 8, 58, 7, 45, 5, 10, 0, 14, 
    1, 45, 4, 44, 5, 76, 3, 94, 6, 99, 0, 41, 8, 69, 2, 63, 7,  3, 
    1,  8, 0, 52, 2, 38, 3, 66, 4, 94, 8, 69, 6, 47, 7, 18, 5, 18
  };
  const int q6487[] = {
    9, 9, // Number of jobs and machines
    2, 18, 1, 19, 0, 19, 7, 64, 6, 20, 5, 28, 4, 10, 3, 62, 8, 14, 
    4, 35, 7, 75, 3, 47, 5, 79, 8, 50, 0, 54, 6, 48, 1, 12, 2, 90, 
    0, 27, 5, 60, 6, 61, 4, 58, 1, 89, 7, 57, 8, 25, 2, 35, 3, 39, 
    7, 25, 5, 30, 6, 51, 1, 91, 8, 93, 4, 38, 2, 19, 3, 99, 0, 74, 
    7, 30, 4, 75, 5, 35, 6, 72, 3, 98, 8, 58, 0,  2, 1, 89, 2, 99, 
    7, 35, 0, 78, 5, 90, 6,  4, 4, 48, 2,  5, 8, 48, 1, 41, 3, 47, 
    8, 55, 0, 15, 7, 77, 6, 80, 2,  8, 1, 47, 5, 16, 3, 67, 4, 40, 
    1, 24, 0, 24, 8, 25, 4, 75, 7, 85, 6, 31, 3, 91, 2, 91, 5, 58, 
    6, 99, 5, 43, 0, 98, 8, 76, 1, 91, 2, 23, 7, 32, 3, 17, 4, 43
  };
  const int q6488[] = {
    9, 9, // Number of jobs and machines
    0, 53, 4, 91, 2, 21, 1, 58, 8, 11, 3, 85, 7, 57, 6, 28, 5,  4, 
    2, 85, 1, 50, 7, 23, 5, 17, 0, 77, 8, 78, 4, 18, 3,  7, 6, 81, 
    0, 57, 7, 48, 2, 44, 4, 75, 6, 31, 8,  4, 1, 33, 5, 75, 3, 23, 
    7, 31, 1, 77, 0,  1, 6, 85, 3, 85, 5, 68, 8, 39, 4, 26, 2, 75, 
    1, 57, 7, 58, 6, 86, 0, 74, 3, 42, 2, 32, 4, 95, 5, 87, 8, 74, 
    1, 94, 3, 45, 8, 40, 4, 95, 7, 28, 5, 47, 2, 80, 0, 62, 6, 28, 
    0, 89, 3, 60, 2, 11, 6, 44, 8, 63, 7, 61, 4, 82, 1, 60, 5, 51, 
    8, 15, 7, 73, 3, 74, 5, 53, 6, 98, 0, 43, 2, 36, 4, 26, 1, 64, 
    4, 60, 6, 49, 2,  6, 7, 60, 8, 19, 3, 16, 0, 10, 5,  7, 1, 33
  };
  const int q6489[] = {
    9, 9, // Number of jobs and machines
    8, 93, 2, 46, 1, 97, 7, 64, 5, 38, 3, 24, 0, 38, 4, 25, 6, 36, 
    1, 86, 8, 19, 4, 14, 6, 29, 7, 70, 3, 81, 0, 17, 2, 17, 5, 44, 
    6, 70, 4, 80, 5, 80, 8, 16, 0, 59, 1, 67, 2, 34, 7, 60, 3, 97, 
    0, 78, 8, 35, 6, 47, 5, 69, 7, 19, 2, 28, 4, 92, 3, 88, 1, 46, 
    5, 42, 0, 71, 2,  9, 1, 51, 6, 21, 4, 89, 3, 67, 7, 24, 8, 29, 
    1, 15, 8, 68, 4, 45, 0, 97, 6, 14, 2, 16, 7, 23, 3, 81, 5, 57, 
    3, 61, 7, 59, 6, 35, 0, 62, 1, 97, 4, 90, 8, 98, 5, 89, 2, 84, 
    5, 98, 4, 13, 3, 52, 7, 59, 6, 87, 2, 38, 8, 46, 1, 61, 0, 80, 
    3, 64, 6, 42, 0, 51, 1,  5, 4, 98, 7, 24, 5, 45, 2, 70, 8, 80
  };
  const int q6490[] = {
    9, 9, // Number of jobs and machines
    5, 71, 1, 19, 6, 39, 8, 34, 2, 56, 7, 78, 0, 21, 3, 36, 4,  8, 
    6, 43, 7, 92, 0, 56, 5, 65, 8, 81, 2, 77, 4, 63, 3, 54, 1,  3, 
    8,  2, 6, 45, 7, 93, 4, 56, 0, 96, 5, 92, 2,  7, 3, 64, 1, 41, 
    4, 38, 7, 12, 2, 57, 8, 80, 5, 58, 0, 35, 3, 24, 6, 50, 1, 93, 
    4, 52, 2, 12, 1, 77, 3, 16, 8, 46, 7, 52, 5, 39, 6, 72, 0, 49, 
    2, 96, 8, 88, 6,  5, 5, 82, 7, 76, 4, 98, 0,  2, 3, 69, 1, 43, 
    6, 19, 8, 18, 5, 21, 2, 66, 7, 19, 0, 79, 4,  8, 3, 15, 1, 85, 
    0, 80, 8, 18, 1, 36, 3, 46, 2, 89, 5, 73, 6, 58, 4,  7, 7, 84, 
    4, 92, 8, 58, 3,  4, 1, 80, 7, 18, 2, 29, 0, 93, 5, 17, 6, 80
  };
  const int q6491[] = {
    9, 9, // Number of jobs and machines
    7,  3, 1, 42, 3, 83, 0, 24, 2, 92, 8, 89, 4, 73, 5, 48, 6, 39, 
    1, 79, 3, 30, 8, 19, 6, 31, 2, 67, 4, 45, 7, 97, 0, 98, 5, 87, 
    7, 69, 0, 87, 1, 56, 8, 84, 3, 61, 5, 50, 4, 47, 2, 88, 6, 14, 
    8, 87, 4, 45, 6, 10, 7, 61, 0, 49, 1, 77, 3, 10, 5, 60, 2,  4, 
    4, 57, 7, 79, 2, 41, 5, 52, 6, 90, 0, 65, 3, 42, 8, 87, 1, 57, 
    7, 54, 5, 83, 1, 51, 8, 27, 3, 33, 4, 93, 6, 59, 0, 50, 2, 57, 
    4, 20, 8, 75, 6, 35, 0, 53, 2, 35, 1, 35, 3, 93, 5, 82, 7, 76, 
    7, 58, 6, 68, 2, 62, 1, 14, 0, 69, 4, 44, 8, 31, 3, 53, 5, 32, 
    0, 17, 4, 82, 1, 98, 2, 91, 6, 65, 3, 54, 5, 20, 8, 75, 7, 20
  };
  const int q6492[] = {
    9, 9, // Number of jobs and machines
    3, 46, 5, 72, 1, 93, 7, 55, 8,  2, 0, 94, 2, 76, 4, 87, 6, 60, 
    5, 63, 4, 93, 0, 57, 7, 95, 8, 19, 3, 33, 1, 42, 6, 89, 2, 70, 
    7, 97, 6, 78, 3, 92, 5, 75, 4, 60, 1, 45, 0, 86, 8, 73, 2, 78, 
    5, 46, 3, 99, 6, 33, 1, 37, 7, 12, 0,  6, 2, 19, 4, 69, 8, 80, 
    1, 39, 4,  6, 7, 57, 0,  3, 3, 19, 6, 41, 5, 82, 2, 51, 8,  8, 
    7, 91, 6, 46, 3, 32, 0, 60, 8, 99, 1, 76, 4, 72, 2, 16, 5, 22, 
    7, 60, 8, 99, 6,  6, 0, 57, 3, 49, 1, 68, 5, 35, 2, 78, 4, 78, 
    3, 30, 2,  7, 7, 23, 0, 22, 6, 97, 8, 13, 5, 74, 4, 43, 1, 67, 
    5, 42, 8, 56, 4, 37, 7, 69, 3, 39, 1, 85, 6, 12, 0, 94, 2, 39
  };
  const int q6493[] = {
    9, 9, // Number of jobs and machines
    0, 94, 3, 42, 7, 28, 6, 79, 4,  9, 2, 26, 1, 97, 8, 70, 5, 84, 
    2, 56, 7, 15, 8, 52, 6, 89, 4,  7, 0, 55, 5, 75, 3,  2, 1, 82, 
    6, 84, 1, 57, 0, 69, 5, 13, 7, 37, 4, 68, 3, 46, 2, 24, 8, 98, 
    6, 32, 4, 57, 2, 90, 1, 91, 0, 67, 8, 71, 7, 36, 5, 44, 3, 24, 
    8, 97, 6, 81, 5, 24, 4, 30, 1, 44, 0, 72, 7, 47, 3, 97, 2, 86, 
    1, 81, 3, 20, 5, 94, 7, 91, 8, 55, 2, 30, 0, 99, 4, 56, 6, 72, 
    2, 27, 4, 13, 5, 66, 3,  1, 1, 69, 6, 20, 0, 58, 7, 46, 8, 84, 
    0, 74, 1, 80, 7,  7, 3, 24, 5, 86, 4, 67, 8, 62, 2, 40, 6, 49, 
    0, 82, 6, 89, 2,  8, 5,  9, 1, 50, 7,  9, 3, 78, 4, 68, 8, 50
  };
  const int q6494[] = {
    9, 9, // Number of jobs and machines
    2, 37, 7, 52, 6, 11, 0, 61, 8, 88, 1, 29, 3, 62, 5,  9, 4, 76, 
    1, 61, 3, 64, 0, 20, 6, 36, 4, 68, 2, 18, 5, 29, 7, 85, 8, 37, 
    7, 52, 3, 49, 2, 67, 8, 85, 1, 32, 6, 71, 5, 47, 0,  6, 4, 96, 
    4, 28, 3, 44, 8, 84, 1, 34, 2, 17, 6, 82, 5, 95, 7, 37, 0,  3, 
    1,  6, 3, 24, 4, 85, 5, 56, 7, 76, 2, 55, 6, 14, 0, 52, 8, 67, 
    6,  3, 2, 38, 4, 86, 7, 35, 3, 17, 0, 29, 5, 49, 1, 63, 8, 95, 
    6,  3, 3, 27, 2, 79, 5, 15, 0, 93, 4, 41, 7, 89, 8, 35, 1, 99, 
    8, 63, 6, 80, 4, 55, 3,  1, 5, 42, 1, 31, 2, 61, 0, 76, 7, 87, 
    3, 85, 6,  4, 8, 22, 5, 25, 4, 98, 2, 60, 1, 36, 0, 83, 7, 37
  };
  const int q6495[] = {
    9, 9, // Number of jobs and machines
    6, 16, 4, 67, 0, 91, 3, 60, 1, 39, 2, 10, 7, 78, 8,  9, 5, 96, 
    3, 53, 4, 26, 5, 93, 2,  7, 6, 18, 0, 91, 7, 86, 8, 36, 1, 87, 
    8, 72, 1, 71, 3, 87, 7, 44, 5, 77, 4, 14, 6, 31, 2, 61, 0, 33, 
    1, 90, 0, 10, 8, 88, 6, 83, 7, 65, 5, 95, 3, 81, 4, 93, 2, 74, 
    7, 13, 2, 43, 5, 83, 1, 40, 8, 97, 0, 62, 4, 66, 6, 86, 3, 81, 
    2, 37, 1, 95, 5, 68, 0, 14, 8, 98, 3, 73, 4, 76, 7, 51, 6, 40, 
    6, 45, 7, 76, 1, 84, 5, 55, 8, 46, 3, 35, 4,  3, 2, 29, 0, 39, 
    7, 26, 4, 98, 0, 16, 6, 37, 3, 39, 5, 66, 8, 29, 2, 23, 1, 88, 
    4, 46, 7, 30, 5, 80, 2, 13, 1, 59, 8, 70, 6, 48, 0, 99, 3, 60
  };
  const int q6496[] = {
    9, 9, // Number of jobs and machines
    6, 44, 2, 87, 1, 30, 5, 74, 7, 40, 4, 79, 0,  4, 8, 24, 3, 70, 
    6, 42, 0, 46, 4, 61, 2, 74, 1, 19, 5, 84, 8, 47, 3, 52, 7,  7, 
    7, 96, 8, 86, 5,  8, 1, 51, 0,  1, 4, 27, 3, 22, 6, 36, 2, 29, 
    3, 72, 0, 37, 4, 19, 2, 57, 6,  1, 1, 91, 7, 45, 8, 45, 5,  1, 
    2, 86, 7, 30, 1, 62, 8, 49, 3, 42, 6,  7, 5, 61, 4, 85, 0, 46, 
    3, 77, 2, 44, 7, 97, 6,  9, 5, 71, 8, 21, 4, 68, 1, 94, 0, 83, 
    3, 11, 8, 42, 5, 31, 6, 16, 1,  2, 0, 97, 7, 81, 2, 81, 4, 56, 
    5, 72, 2,  4, 7, 90, 4,  6, 8, 23, 3, 49, 6, 85, 1,  2, 0, 22, 
    8, 61, 7, 48, 4, 95, 5, 24, 6, 94, 1, 81, 2, 50, 3, 43, 0, 71
  };
  const int q6497[] = {
    9, 9, // Number of jobs and machines
    4, 80, 7, 33, 1, 54, 2, 67, 0, 30, 3, 36, 5, 63, 6, 11, 8, 93, 
    1, 50, 7,  6, 2, 57, 3, 42, 4, 31, 6, 29, 0, 84, 5, 61, 8,  9, 
    1, 48, 2, 27, 5, 45, 4, 99, 3, 44, 8, 13, 0, 99, 7, 37, 6, 68, 
    2, 15, 1, 72, 4,  9, 5, 76, 3, 38, 8, 66, 7, 87, 6, 71, 0, 35, 
    1, 66, 8, 58, 7, 39, 5, 94, 0, 64, 4, 57, 2,  9, 6, 50, 3, 99, 
    2, 19, 6, 82, 0, 34, 1, 97, 5, 26, 8, 30, 7, 21, 4, 53, 3, 75, 
    6, 49, 8, 50, 0, 25, 1, 68, 7, 92, 5,  7, 3, 36, 4, 99, 2, 75, 
    4, 11, 7, 55, 2, 62, 5, 17, 6, 31, 8, 40, 3, 33, 1, 81, 0, 54, 
    2, 10, 4,  8, 7, 29, 0, 80, 5, 88, 3, 11, 6, 51, 8, 85, 1, 57
  };
  const int q6498[] = {
    9, 9, // Number of jobs and machines
    0, 38, 8, 38, 3, 49, 4, 54, 6, 77, 1, 25, 2,  1, 5, 14, 7, 68, 
    7, 92, 3, 58, 5,  6, 1, 32, 4, 71, 2, 69, 8, 89, 6, 27, 0, 96, 
    6, 90, 7, 85, 4, 22, 3, 50, 2, 87, 0, 16, 1, 32, 8, 57, 5, 46, 
    4, 66, 7, 32, 2, 47, 8, 36, 1, 65, 5, 28, 3, 99, 0,  7, 6, 70, 
    8, 45, 1, 17, 6, 90, 5, 27, 7, 72, 4, 12, 2, 14, 3, 51, 0, 78, 
    3, 62, 2, 30, 4, 43, 5,  6, 6,  3, 0, 95, 1, 95, 8,  2, 7, 38, 
    4, 85, 6, 73, 5, 47, 8, 77, 0, 90, 3, 16, 1, 45, 2,  7, 7, 96, 
    2, 73, 7, 51, 3, 93, 5, 72, 0, 22, 8, 64, 1, 14, 4, 42, 6, 62, 
    8, 30, 7, 70, 6, 84, 4, 66, 2,  2, 5, 97, 0, 34, 1,  8, 3,  1
  };
  const int q6499[] = {
    9, 9, // Number of jobs and machines
    0, 43, 2, 36, 8,  6, 4, 69, 3, 35, 7, 91, 6,  9, 5,  2, 1, 78, 
    4, 38, 0, 39, 8, 60, 2, 44, 6, 44, 7, 64, 5, 39, 3, 63, 1, 16, 
    1, 45, 4,  6, 6, 50, 3,  4, 8, 72, 7, 85, 5, 65, 2, 10, 0, 41, 
    0, 15, 4, 76, 8, 76, 6, 37, 7,  7, 1, 70, 3, 54, 5, 71, 2, 87, 
    1, 92, 8, 27, 2, 72, 4, 86, 7, 44, 0, 33, 3,  6, 5, 59, 6, 42, 
    5, 90, 0, 23, 6, 34, 2,  4, 3, 32, 4, 91, 1, 86, 8,  6, 7, 47, 
    0, 69, 1, 41, 6, 90, 5,  6, 7, 38, 2, 30, 3, 32, 4, 51, 8, 62, 
    7, 63, 6, 64, 2, 82, 4, 50, 8, 21, 1, 12, 3, 27, 5, 17, 0,  5, 
    8, 38, 7, 14, 1, 49, 3, 22, 0, 90, 2,  3, 5, 58, 6, 96, 4, 98
  };
  const int q6500[] = {
    9, 9, // Number of jobs and machines
    3, 60, 8, 87, 5, 11, 2, 20, 0,  3, 1, 30, 6, 21, 7, 47, 4, 50, 
    6, 82, 8, 93, 2, 29, 5, 20, 0, 54, 4, 71, 3, 19, 7, 44, 1, 38, 
    8,  2, 5, 46, 7, 62, 3, 54, 1, 91, 2, 48, 6, 44, 4, 28, 0, 32, 
    5, 80, 1,  6, 7, 83, 8, 29, 4, 29, 2, 20, 0, 51, 3, 40, 6, 66, 
    7, 56, 8, 23, 5, 52, 1, 59, 2, 98, 0, 51, 6, 69, 4, 10, 3, 99, 
    4, 97, 8, 67, 0, 69, 7, 20, 1, 60, 6, 22, 3, 12, 5, 60, 2, 74, 
    0, 67, 8, 30, 7,  2, 1, 52, 3,  3, 2, 63, 5, 72, 4, 27, 6,  8, 
    5, 87, 8, 65, 7, 26, 3, 83, 2, 77, 4, 92, 0, 14, 1,  9, 6, 82, 
    0, 64, 6, 10, 8, 94, 3, 93, 4,  4, 7, 38, 5, 65, 1, 31, 2, 57
  };
  const int q6501[] = {
    9, 9, // Number of jobs and machines
    8, 60, 5, 81, 2, 43, 7,  1, 3, 92, 1, 49, 0, 68, 4, 21, 6, 53, 
    5, 21, 4, 13, 3, 11, 1, 41, 8, 97, 0, 91, 6, 28, 7, 59, 2, 60, 
    3, 63, 7, 63, 5, 10, 1, 43, 6, 19, 0,  9, 8, 63, 4, 44, 2, 55, 
    3, 15, 2, 84, 1, 84, 0,  3, 6,  6, 4,  5, 7, 87, 8, 17, 5, 66, 
    7, 26, 4, 98, 8, 38, 1, 93, 0, 24, 6, 18, 2, 41, 5, 22, 3,  8, 
    2, 82, 7, 27, 6, 12, 8, 44, 5,  2, 1, 67, 4, 11, 3, 26, 0, 65, 
    8, 66, 0, 99, 1, 73, 4, 50, 3, 25, 6,  5, 5,  7, 2, 16, 7, 18, 
    8, 29, 0, 97, 3, 52, 2,  2, 4, 29, 5, 37, 1, 45, 6, 77, 7, 36, 
    6, 40, 3, 41, 8,  1, 5, 57, 1, 51, 4, 38, 0, 51, 7, 68, 2, 55
  };
  const int q6502[] = {
    9, 9, // Number of jobs and machines
    8, 14, 7, 29, 5, 66, 0,  7, 3, 10, 4, 10, 6, 23, 1, 40, 2, 76, 
    1, 27, 8, 84, 0, 72, 4, 96, 2, 67, 5, 39, 7, 11, 6, 25, 3, 30, 
    5, 34, 8, 80, 4, 78, 0, 30, 3, 87, 6, 57, 1, 18, 7, 99, 2, 47, 
    8, 83, 7, 34, 3, 23, 6, 20, 0, 62, 1,  5, 4, 12, 2, 25, 5,  6, 
    6, 96, 7, 22, 3, 34, 1, 72, 4, 71, 5,  5, 2, 20, 0, 33, 8, 65, 
    0, 30, 5, 51, 7, 90, 3, 17, 6, 86, 8, 43, 2, 28, 4, 77, 1, 30, 
    6, 95, 0, 89, 4, 55, 1, 65, 8, 73, 7, 49, 5, 26, 3, 54, 2, 37, 
    1, 83, 8, 89, 6, 22, 3, 64, 4, 10, 7, 22, 5, 96, 0, 37, 2, 51, 
    6, 94, 8, 74, 0,  9, 2, 46, 5, 75, 3, 74, 7, 93, 1, 28, 4, 22
  };
  const int q6503[] = {
    9, 9, // Number of jobs and machines
    8, 55, 1, 56, 7, 55, 5,  2, 3, 85, 2, 42, 4, 69, 6, 74, 0, 21, 
    8, 53, 2, 39, 3, 41, 1, 26, 0, 63, 4, 25, 6, 94, 5, 80, 7, 92, 
    8,  7, 2, 51, 1, 20, 0, 42, 7, 22, 3,  9, 5, 16, 4, 23, 6, 37, 
    3, 48, 5, 43, 7, 78, 4, 33, 0, 65, 2, 87, 6, 60, 8, 19, 1, 14, 
    1, 87, 7, 89, 4, 36, 3, 63, 5, 61, 6, 80, 0, 90, 2, 19, 8, 54, 
    1, 75, 0,  7, 2, 13, 8, 64, 4,  8, 3, 58, 7, 62, 6, 60, 5,  1, 
    0, 38, 1, 46, 4, 92, 5, 31, 2, 97, 7, 14, 8, 52, 3, 63, 6, 98, 
    1, 64, 5, 91, 6, 79, 8, 24, 2, 64, 3, 39, 0, 14, 4, 20, 7, 87, 
    7, 89, 3, 67, 0, 56, 6,  9, 5, 73, 1, 13, 8, 75, 2, 32, 4, 76
  };
  const int q6504[] = {
    9, 9, // Number of jobs and machines
    8, 47, 0, 25, 2, 45, 1, 25, 5, 57, 3, 81, 6, 83, 7,  5, 4, 99, 
    0, 69, 5, 62, 6, 53, 7, 35, 3, 22, 1, 84, 8, 26, 2, 55, 4, 43, 
    7, 75, 1,  8, 5, 92, 0, 32, 3, 78, 2, 10, 4, 80, 6, 72, 8, 89, 
    3, 43, 0, 78, 7, 95, 6, 62, 1, 71, 5, 26, 8, 86, 2, 84, 4, 93, 
    4, 75, 0, 41, 6, 67, 7, 41, 8, 29, 5, 42, 1, 83, 2, 33, 3, 98, 
    7, 60, 4, 16, 0, 69, 6, 52, 1, 68, 2, 31, 8, 41, 5, 63, 3, 65, 
    5,  3, 0, 45, 7, 20, 8, 14, 2, 72, 3, 55, 1, 79, 6, 19, 4, 52, 
    3, 83, 6, 28, 2, 66, 0, 89, 7, 66, 1, 99, 4, 57, 5, 81, 8, 12, 
    3, 87, 4, 34, 2, 19, 1, 10, 5, 91, 6, 62, 7, 38, 0, 71, 8, 21
  };
  const int q6505[] = {
    9, 9, // Number of jobs and machines
    1, 67, 6, 31, 7, 38, 3, 46, 5, 90, 0, 79, 4, 13, 2, 51, 8, 73, 
    6, 15, 7, 98, 3, 56, 5, 20, 2, 13, 0, 59, 8, 70, 1, 55, 4, 96, 
    4, 67, 5,  4, 1, 25, 3, 74, 8, 89, 0, 16, 2, 75, 6, 14, 7, 78, 
    2, 13, 5,  8, 4, 28, 8, 67, 0, 81, 3, 90, 7, 28, 6, 21, 1, 16, 
    8, 70, 6,  9, 4, 63, 2, 83, 5,  7, 7, 35, 3, 83, 0, 47, 1, 48, 
    6, 72, 1, 74, 5, 14, 8, 23, 4, 16, 2, 30, 0, 24, 3, 27, 7, 60, 
    6, 98, 2, 65, 1, 81, 3, 81, 4,  8, 7,  9, 0, 99, 5, 78, 8, 37, 
    1, 79, 3, 70, 6, 61, 8, 33, 2, 37, 4, 72, 5, 16, 0, 53, 7, 51, 
    5, 20, 6, 83, 3, 77, 7, 30, 8, 81, 0, 45, 1, 34, 2, 99, 4, 29
  };
  const int q6506[] = {
    9, 9, // Number of jobs and machines
    8, 32, 6, 61, 4,  7, 0, 79, 2, 63, 5, 85, 7, 64, 1,  1, 3, 45, 
    5, 28, 7, 52, 4, 78, 1,  5, 0, 18, 2, 20, 3, 73, 8, 89, 6, 91, 
    8, 30, 2, 44, 3, 14, 7, 82, 1, 74, 4, 71, 0, 75, 6, 73, 5, 57, 
    2, 18, 1, 99, 4, 20, 3, 15, 8, 33, 7, 37, 5, 76, 6, 54, 0, 75, 
    8, 58, 5, 86, 4, 75, 7, 87, 6, 81, 0, 44, 2, 76, 3, 29, 1, 64, 
    0, 48, 3, 52, 1,  2, 5, 66, 4, 90, 2, 12, 6, 33, 7, 46, 8,  9, 
    5, 80, 8, 41, 6, 63, 7, 30, 4, 12, 0, 23, 1, 39, 3, 14, 2, 81, 
    6, 24, 4, 13, 0, 75, 8, 42, 3, 45, 1, 34, 7,  9, 5, 41, 2, 40, 
    6, 24, 8, 67, 1, 87, 0, 16, 2, 78, 3, 42, 4, 58, 5, 74, 7, 19
  };
  const int q6507[] = {
    9, 9, // Number of jobs and machines
    0, 55, 7, 86, 6, 98, 2, 54, 8, 10, 4, 41, 1, 48, 5, 72, 3, 77, 
    6, 73, 8, 92, 2, 54, 3, 16, 4, 77, 0, 45, 1, 76, 5,  7, 7, 70, 
    8, 64, 6, 10, 7,  3, 2, 35, 3, 66, 5, 96, 1, 45, 4, 45, 0, 82, 
    1, 68, 4, 27, 8, 80, 2, 13, 3, 86, 7, 39, 0, 62, 5, 32, 6, 40, 
    5, 91, 6, 11, 2, 60, 4, 49, 7, 67, 8, 42, 1, 51, 3,  1, 0, 98, 
    8, 26, 2, 47, 1, 70, 3, 97, 6, 38, 5, 82, 4, 54, 0, 38, 7,  8, 
    7, 60, 2,  1, 5, 58, 1, 40, 8, 84, 4, 71, 0, 32, 6, 31, 3, 36, 
    5, 51, 4, 66, 2, 98, 6, 25, 0, 76, 8, 98, 1, 79, 7, 19, 3, 14, 
    5, 47, 2,  8, 7, 57, 3, 55, 1,  5, 8,  1, 4, 51, 0,  3, 6, 63
  };
  const int q6508[] = {
    9, 9, // Number of jobs and machines
    1,  1, 7, 32, 2, 38, 6, 21, 5, 28, 0, 19, 3, 87, 8, 11, 4, 51, 
    4, 44, 7, 98, 3,  1, 5, 24, 0, 11, 8, 68, 6, 67, 1, 12, 2, 41, 
    3, 62, 2, 97, 0, 39, 8, 63, 6, 12, 4,  6, 5, 23, 7, 77, 1, 43, 
    6, 58, 2, 64, 7, 26, 4, 50, 5, 65, 3, 28, 8, 83, 1, 77, 0, 75, 
    5, 82, 4,  3, 0, 18, 2, 28, 6,  4, 1, 10, 8, 12, 7,  3, 3, 32, 
    3, 65, 4,  1, 7, 21, 0, 56, 1, 27, 8, 67, 2, 84, 6, 75, 5, 19, 
    1, 36, 2, 23, 4, 87, 5, 88, 8, 31, 7, 99, 6, 58, 3,  7, 0, 31, 
    6, 75, 2, 60, 3, 82, 0, 93, 5, 66, 7, 31, 1, 31, 4, 17, 8, 59, 
    5, 57, 7, 26, 2, 81, 8, 43, 3,  1, 0, 78, 6, 13, 1, 14, 4,  4
  };
  const int q6509[] = {
    9, 9, // Number of jobs and machines
    6, 29, 0, 51, 3, 22, 5, 32, 7, 51, 8, 87, 1, 85, 2, 81, 4, 88, 
    7,  4, 4, 29, 1, 18, 0, 52, 5,  5, 8, 69, 6, 52, 3, 40, 2, 13, 
    5, 15, 1, 89, 3, 76, 8, 12, 0, 35, 7, 31, 2, 19, 6, 94, 4, 72, 
    6, 41, 8, 55, 1, 80, 0, 33, 2,  5, 4, 76, 3, 52, 7, 61, 5, 73, 
    7, 98, 4, 91, 1,  7, 8, 66, 0, 29, 6, 19, 2, 28, 5, 66, 3, 99, 
    4, 62, 1, 31, 8, 52, 6, 35, 5, 77, 2, 29, 7, 99, 3, 73, 0, 21, 
    5, 14, 7, 67, 4, 17, 3, 39, 8, 69, 0,  2, 2, 46, 6, 78, 1, 49, 
    6, 66, 3, 85, 1, 31, 5, 50, 2, 24, 8, 19, 4, 68, 7, 38, 0, 69, 
    8, 72, 0, 92, 5, 60, 7, 36, 1, 52, 4, 40, 3, 19, 2, 94, 6, 40
  };
  const int q6510[] = {
    9, 9, // Number of jobs and machines
    3, 12, 6, 12, 4, 30, 8, 35, 7, 93, 0, 60, 2, 87, 1, 34, 5, 85, 
    4, 15, 5, 34, 7, 64, 8, 60, 6, 60, 1,  2, 3, 21, 0, 63, 2, 35, 
    0, 93, 5, 98, 3, 78, 8, 55, 4, 75, 1, 93, 7, 58, 2, 42, 6, 73, 
    6, 77, 7, 34, 8, 54, 5, 26, 4, 42, 1, 53, 0, 77, 3, 33, 2, 66, 
    0, 84, 1, 50, 3,  5, 4, 96, 6, 76, 2,  7, 5, 77, 8, 46, 7, 30, 
    2, 66, 4, 50, 8, 42, 6, 15, 3, 99, 7, 87, 1, 35, 5, 22, 0,  1, 
    3, 83, 6, 80, 0, 26, 1, 11, 5, 73, 8, 93, 4, 55, 7, 50, 2, 92, 
    6, 50, 8, 13, 3, 29, 0, 71, 4, 81, 2, 85, 1, 33, 5, 75, 7, 32, 
    8, 95, 1, 37, 4, 27, 3, 70, 7, 55, 0, 35, 5, 61, 2, 82, 6, 19
  };
  const int q6511[] = {
    9, 9, // Number of jobs and machines
    0, 17, 8, 75, 6, 46, 5, 70, 7, 76, 1, 16, 4, 53, 3, 82, 2, 20, 
    7,  2, 0, 75, 8, 12, 6, 31, 1, 11, 4, 24, 5, 68, 3, 89, 2, 19, 
    7, 45, 1, 86, 3, 23, 8, 55, 5, 86, 6,  5, 2, 84, 4, 91, 0, 73, 
    4, 35, 5, 25, 6, 73, 0, 47, 7, 55, 3, 41, 8, 43, 2, 39, 1, 78, 
    8, 89, 3, 74, 4, 92, 6, 91, 0, 25, 2, 61, 5, 88, 7, 75, 1, 48, 
    4, 76, 3, 90, 2,  9, 7,  7, 6, 46, 0, 25, 1, 21, 8, 55, 5, 81, 
    5, 17, 7, 15, 6, 61, 0, 15, 3, 84, 8, 65, 1, 34, 2, 11, 4, 29, 
    3, 81, 4, 98, 0, 43, 6, 17, 1, 65, 8, 60, 5, 29, 2, 57, 7, 12, 
    2, 67, 3, 59, 6, 40, 5, 50, 8, 79, 7, 16, 1, 29, 0, 75, 4, 17
  };
  const int q6512[] = {
    9, 9, // Number of jobs and machines
    5, 54, 2,  4, 3, 99, 4, 95, 7, 35, 6, 84, 1, 72, 0, 19, 8, 30, 
    6, 94, 8, 39, 5, 34, 1, 39, 7, 81, 0, 16, 4, 41, 2, 64, 3, 87, 
    5, 75, 3, 56, 0, 68, 4, 67, 1, 62, 7, 82, 2, 29, 6, 10, 8, 60, 
    8, 66, 4, 65, 0, 25, 2, 16, 5, 39, 7, 91, 3, 68, 6, 69, 1, 61, 
    1, 85, 7, 64, 5, 52, 2, 34, 4, 71, 8, 77, 0, 38, 3,  5, 6, 58, 
    1, 13, 7, 15, 3, 66, 6, 16, 2, 48, 8, 84, 0, 41, 5, 34, 4, 89, 
    4, 99, 7, 38, 6, 17, 0, 50, 8, 69, 1,  6, 2,  4, 5, 65, 3, 55, 
    4, 47, 6, 15, 1, 52, 8, 58, 3, 66, 7, 77, 0, 85, 5, 12, 2, 10, 
    4,  8, 0, 85, 2, 21, 7, 40, 5, 66, 1, 26, 8, 89, 3,  5, 6,  6
  };
  const int q6513[] = {
    9, 9, // Number of jobs and machines
    4, 79, 8, 89, 6, 43, 5,  9, 2, 34, 3, 30, 0, 19, 1, 86, 7, 52, 
    8,  9, 7, 40, 6, 65, 3, 62, 5, 71, 1, 11, 4, 19, 0, 95, 2, 63, 
    1,  2, 7, 56, 4, 80, 2, 23, 3, 48, 0, 80, 8, 85, 5, 37, 6, 49, 
    3,  7, 4, 42, 0,  2, 8, 99, 2, 45, 6, 43, 7, 50, 1, 48, 5, 32, 
    7, 37, 4, 82, 1, 67, 6, 72, 2, 94, 8, 91, 5, 80, 0,  3, 3, 22, 
    6, 98, 1, 84, 7, 45, 8, 29, 4, 39, 3, 94, 0, 95, 2, 73, 5, 12, 
    1, 87, 6, 64, 7, 58, 5, 86, 3, 26, 2, 31, 4, 28, 0, 70, 8, 36, 
    2, 16, 4, 75, 8, 37, 0,  7, 7, 63, 3, 12, 1, 50, 5, 75, 6, 17, 
    8, 63, 3, 69, 6, 77, 1, 84, 4, 84, 5, 64, 2, 85, 0, 81, 7, 30
  };
  const int q6514[] = {
    9, 9, // Number of jobs and machines
    8,  4, 5, 82, 1, 87, 4, 40, 3, 85, 0, 68, 6,  9, 2, 61, 7, 67, 
    7, 98, 5, 21, 4, 83, 2, 11, 0, 64, 8, 50, 3, 42, 1, 18, 6, 36, 
    6, 19, 5, 30, 8, 60, 3, 90, 0,  8, 2, 69, 1, 95, 4, 46, 7, 60, 
    1, 18, 4, 68, 8, 36, 2, 47, 6, 90, 0, 88, 7, 37, 5, 13, 3, 83, 
    6, 88, 4, 28, 1, 77, 2, 74, 3, 28, 0, 17, 7, 53, 8, 83, 5,  4, 
    0, 22, 7, 99, 6,  9, 8, 56, 3, 29, 4,  1, 1, 15, 5,  3, 2, 98, 
    4, 10, 2, 81, 5, 82, 6, 54, 0, 89, 8, 74, 3, 56, 1, 28, 7,  7, 
    1, 57, 2,  5, 5, 77, 8, 84, 3, 22, 0, 31, 7, 93, 4, 35, 6, 52, 
    4, 82, 1,  2, 3, 79, 6, 17, 5, 60, 8, 65, 0, 42, 2, 36, 7, 30
  };
  const int q6515[] = {
    9, 9, // Number of jobs and machines
    7, 89, 5, 99, 4,  2, 1, 37, 0, 24, 8, 35, 2,  1, 3, 82, 6, 98, 
    8, 36, 0, 11, 5, 37, 3, 56, 6, 56, 1, 64, 2, 99, 7, 79, 4, 42, 
    3, 81, 1, 65, 8, 39, 2, 82, 6, 83, 5, 55, 4, 84, 7,  5, 0, 91, 
    7, 46, 1, 43, 8, 38, 2, 53, 4, 40, 3,  2, 5,  7, 6, 92, 0, 90, 
    4, 44, 0,  1, 7, 30, 8, 29, 1, 23, 3, 79, 6, 50, 2, 63, 5, 69, 
    7, 56, 0, 37, 2, 14, 3, 95, 5, 28, 1, 75, 8, 29, 6, 94, 4, 62, 
    7,  3, 1, 72, 3, 55, 4, 44, 5, 97, 0, 59, 2, 64, 8, 72, 6, 66, 
    4, 82, 3, 85, 5,  3, 0, 86, 2, 90, 7, 47, 6, 14, 1, 16, 8, 67, 
    8, 89, 5, 58, 7,  9, 2, 64, 1, 96, 6, 93, 0, 89, 3, 43, 4, 52
  };
  const int q6516[] = {
    9, 9, // Number of jobs and machines
    6,  8, 7,  6, 5, 67, 2, 87, 0,  4, 8, 96, 1, 15, 3, 17, 4, 70, 
    6, 34, 0, 27, 7, 75, 5, 16, 3, 48, 4,  9, 1, 24, 2, 33, 8, 16, 
    7, 83, 3, 40, 2, 15, 6, 17, 8, 65, 4, 40, 1, 69, 5, 40, 0, 97, 
    0, 44, 1, 25, 2, 19, 7, 49, 5, 73, 4, 97, 8, 40, 3, 91, 6, 57, 
    6, 12, 2, 25, 7, 85, 5, 95, 1, 65, 3, 65, 4, 83, 0,  9, 8, 48, 
    8, 16, 1, 51, 3,  2, 6,  7, 2, 90, 4,  5, 5, 97, 0, 90, 7, 34, 
    6, 46, 8,  8, 0, 28, 5, 68, 2, 54, 3, 95, 1, 77, 4, 65, 7, 41, 
    7, 68, 6, 82, 4,  4, 0, 10, 3, 95, 2, 76, 1, 76, 8, 61, 5, 14, 
    3, 34, 6, 75, 1, 97, 5, 95, 2, 30, 0, 70, 7, 53, 4, 96, 8, 60
  };
  const int q6517[] = {
    9, 9, // Number of jobs and machines
    1, 97, 6, 66, 2, 42, 4,  4, 7, 13, 3, 54, 0, 39, 5, 55, 8, 10, 
    3, 26, 5, 69, 6, 71, 2, 82, 1, 14, 4, 92, 8, 69, 7, 18, 0, 90, 
    3, 75, 2, 20, 5, 92, 0,  6, 6, 97, 4, 42, 7, 68, 1, 17, 8, 65, 
    5, 46, 4, 34, 1, 89, 3, 11, 2, 42, 6, 85, 7, 82, 0, 46, 8, 64, 
    6, 40, 0, 57, 7, 99, 5, 32, 8, 96, 2, 42, 1, 99, 4, 15, 3, 58, 
    3, 63, 6, 24, 2, 51, 1, 99, 4, 87, 0, 50, 7, 60, 8, 91, 5, 47, 
    1, 41, 5,  1, 2, 99, 6, 25, 8, 94, 4, 25, 0, 76, 3, 93, 7, 35, 
    1, 89, 7, 35, 4, 72, 6, 61, 0, 86, 2, 20, 8, 32, 3, 69, 5, 67, 
    1, 20, 7, 14, 3, 92, 6, 40, 5, 63, 0, 77, 4, 61, 8, 59, 2, 65
  };
  const int q6518[] = {
    9, 9, // Number of jobs and machines
    8, 35, 6,  4, 2, 28, 7, 54, 3, 83, 1, 12, 4, 85, 0, 59, 5, 87, 
    6, 18, 7, 73, 4, 86, 0, 49, 2, 33, 5, 33, 8, 57, 3,  3, 1, 82, 
    3, 10, 4,  8, 7, 26, 5,  8, 8, 73, 1, 54, 2, 43, 6, 53, 0,  2, 
    4, 97, 0, 79, 5, 24, 7, 18, 2, 32, 1, 29, 8, 57, 6,  8, 3, 31, 
    0, 53, 1, 92, 4, 27, 8, 24, 6, 56, 5, 47, 7, 57, 2, 74, 3, 64, 
    8, 33, 4, 26, 3, 75, 1, 98, 6, 54, 5, 61, 0, 34, 2, 24, 7, 78, 
    0, 65, 5, 96, 2, 17, 6, 69, 7,  1, 3, 51, 8, 81, 1,  8, 4, 12, 
    7, 29, 8, 45, 3,  2, 4, 40, 1, 37, 0, 84, 6, 70, 5, 65, 2, 18, 
    4, 60, 2, 99, 7, 70, 6, 76, 3, 50, 1,  1, 0, 60, 5, 92, 8,  4
  };
  const int q6519[] = {
    9, 9, // Number of jobs and machines
    3, 16, 7, 10, 5, 96, 4, 18, 0, 19, 2, 22, 1, 10, 8, 88, 6, 95, 
    8, 84, 1, 35, 0, 43, 2, 25, 4, 47, 6, 20, 5, 39, 3, 78, 7,  9, 
    7, 86, 5, 77, 0, 69, 2, 50, 8,  8, 1, 62, 3, 95, 6, 96, 4,  1, 
    0, 80, 6, 54, 2, 59, 1, 43, 8, 18, 4, 24, 3, 55, 5, 29, 7, 65, 
    7, 89, 3, 42, 1, 28, 2, 76, 4, 50, 5, 35, 8, 45, 6, 73, 0, 69, 
    7, 12, 2, 19, 0, 44, 1, 39, 5, 65, 3, 44, 4, 39, 8, 29, 6, 51, 
    0, 99, 7, 59, 1, 29, 4, 95, 2, 58, 8, 25, 5, 95, 6, 81, 3, 81, 
    2,  5, 5, 93, 8, 82, 7, 15, 0, 13, 1, 15, 3, 37, 4, 54, 6, 41, 
    5, 32, 2, 76, 3,  7, 8, 89, 1, 60, 0, 57, 6, 33, 4, 47, 7, 45
  };
  const int q6520[] = {
    9, 9, // Number of jobs and machines
    2, 11, 0, 44, 7, 15, 5, 88, 8,  7, 6, 86, 4, 12, 3, 58, 1, 50, 
    8, 31, 2, 38, 3, 67, 6, 70, 7, 57, 0, 89, 4, 84, 5, 62, 1, 81, 
    2, 30, 8, 50, 6, 12, 3, 27, 0, 21, 1, 19, 7, 66, 4,  1, 5, 72, 
    7, 93, 5, 20, 4, 14, 3, 86, 1,  4, 0, 35, 8, 12, 2, 78, 6, 16, 
    3, 47, 7, 49, 2, 81, 8, 53, 5, 61, 6, 12, 0, 44, 1, 63, 4, 59, 
    1, 18, 0,  5, 6, 10, 5,  5, 3, 94, 2, 93, 7, 12, 8, 81, 4, 53, 
    0, 25, 8, 76, 7, 70, 6,  7, 2, 49, 4, 42, 3, 44, 5, 98, 1,  6, 
    5, 54, 3,  1, 4, 73, 7, 67, 1, 32, 6, 40, 8, 96, 0, 66, 2, 57, 
    4, 59, 7, 60, 2, 19, 0,  2, 1, 82, 6, 25, 5, 52, 8, 69, 3,  3
  };
  const int q6521[] = {
    9, 9, // Number of jobs and machines
    8, 13, 5,  9, 0, 28, 6, 33, 4, 86, 7, 58, 2, 56, 1, 60, 3, 84, 
    6, 62, 0, 52, 5, 76, 1, 43, 7, 29, 8, 61, 2, 45, 3, 58, 4, 33, 
    2, 73, 3, 33, 8, 48, 5, 34, 7,  9, 1, 34, 6, 57, 0, 63, 4, 75, 
    1,  5, 8, 97, 0, 22, 6, 44, 4, 63, 5, 50, 3, 81, 7,  1, 2, 71, 
    6, 32, 5, 34, 8,  8, 0, 62, 4, 52, 1, 66, 3, 36, 7, 97, 2, 51, 
    3,  7, 6, 16, 2, 92, 0, 53, 7,  3, 1, 38, 4, 69, 5,  6, 8, 92, 
    1, 90, 2, 14, 5, 93, 3, 74, 7, 19, 6, 13, 8,  2, 0, 40, 4, 90, 
    4,  7, 3, 50, 2, 74, 7, 42, 1, 99, 8, 32, 6, 12, 5, 58, 0, 53, 
    5, 40, 7, 51, 4, 54, 6, 91, 8, 97, 3, 82, 0, 43, 2, 21, 1, 16
  };
  const int q6522[] = {
    9, 9, // Number of jobs and machines
    4,  4, 3, 90, 5,  7, 7, 13, 8, 89, 6, 22, 2, 35, 1, 93, 0, 56, 
    3, 67, 2, 35, 1, 35, 5, 20, 4, 79, 0, 18, 6, 73, 8, 59, 7,  9, 
    2,  1, 3, 70, 6, 81, 4, 43, 0, 69, 5, 89, 1, 16, 7,  4, 8, 32, 
    3, 35, 1, 40, 2, 26, 0, 24, 5, 11, 8, 23, 6, 74, 7, 56, 4, 11, 
    2, 32, 8, 54, 4, 22, 3, 30, 0, 11, 7, 96, 6,  5, 5, 23, 1, 51, 
    8, 38, 4,  9, 5, 49, 6, 29, 0, 10, 3, 98, 7, 33, 2, 48, 1, 75, 
    7, 94, 0, 46, 3, 82, 6, 43, 4, 68, 5, 15, 2, 75, 8, 50, 1,  3, 
    1,  9, 4, 31, 6, 52, 2,  4, 7, 58, 8, 86, 5, 66, 0, 25, 3, 41, 
    0, 78, 3,  5, 8, 93, 2, 53, 1, 38, 6, 68, 5, 10, 4, 58, 7,  1
  };
  const int q6523[] = {
    9, 9, // Number of jobs and machines
    5, 22, 3, 21, 6, 69, 2,  2, 4, 13, 0, 78, 7, 29, 1, 48, 8, 38, 
    6, 14, 0, 32, 4, 26, 3,  4, 7, 16, 8, 76, 1,  6, 5, 10, 2, 56, 
    4, 41, 5, 33, 7, 40, 6, 35, 1, 14, 0, 86, 8, 18, 2, 24, 3, 15, 
    6, 57, 2, 71, 4, 79, 0, 36, 5, 87, 8, 61, 7, 41, 1, 10, 3, 78, 
    5, 76, 3, 13, 8, 91, 1, 79, 2, 23, 4, 27, 6, 58, 0, 77, 7, 77, 
    4, 80, 5, 41, 2,  4, 1, 72, 7, 49, 6,  7, 8, 50, 3, 13, 0, 73, 
    6, 55, 8, 58, 5, 11, 4, 13, 0, 70, 2, 55, 1,  1, 7,  4, 3, 81, 
    5, 80, 8, 24, 7,  8, 2, 86, 4, 87, 1, 94, 0, 60, 6, 85, 3, 58, 
    8, 77, 3, 58, 7, 40, 5, 35, 4, 69, 1, 20, 2, 18, 0, 16, 6, 74
  };
  const int q6524[] = {
    9, 9, // Number of jobs and machines
    8, 53, 1, 36, 6, 17, 3, 84, 7, 56, 4, 93, 0, 19, 2, 85, 5,  6, 
    2, 65, 8, 57, 4, 94, 0, 78, 3, 14, 1, 66, 7, 24, 6, 69, 5, 96, 
    3, 22, 8, 23, 5, 18, 1, 66, 7, 63, 4, 56, 2, 58, 0, 44, 6, 17, 
    7, 80, 8, 70, 3, 19, 6, 20, 2, 99, 4, 84, 0, 62, 1, 68, 5, 79, 
    3, 99, 1, 94, 8, 10, 7, 29, 0, 19, 4, 23, 5, 23, 6, 79, 2, 73, 
    7, 78, 1, 83, 8, 76, 6, 34, 2, 49, 3, 62, 5, 26, 0, 93, 4, 30, 
    8, 93, 0, 59, 7, 50, 5, 98, 2, 98, 4, 70, 1, 46, 6, 73, 3, 85, 
    7, 61, 8, 39, 3, 79, 4, 90, 6, 23, 1, 49, 0, 31, 5, 68, 2, 77, 
    8, 93, 3, 97, 4, 77, 1,  8, 5, 66, 2, 23, 0, 59, 7,  5, 6, 11
  };
  const int q6525[] = {
    9, 9, // Number of jobs and machines
    6, 73, 2, 28, 7,  3, 4, 12, 5, 81, 3, 50, 8, 49, 0, 44, 1,  1, 
    4, 32, 0, 45, 1, 32, 5, 36, 6, 22, 8,  2, 2, 76, 7, 53, 3, 28, 
    5, 44, 7, 22, 3, 61, 8, 83, 4, 95, 2, 18, 0, 69, 1, 76, 6, 71, 
    5, 75, 2, 14, 4, 39, 6, 29, 0, 91, 8, 43, 3, 77, 7, 26, 1, 49, 
    2, 99, 1, 45, 0, 81, 5, 56, 3, 27, 6, 58, 8, 93, 4,  8, 7, 42, 
    0, 10, 6, 62, 2, 81, 8, 55, 7, 76, 5, 58, 4, 36, 3, 91, 1, 49, 
    0, 25, 7, 98, 3, 98, 8, 64, 4, 54, 6, 99, 5, 76, 2, 51, 1, 59, 
    6, 88, 2,  9, 4,  8, 8, 77, 5, 72, 3, 42, 7, 45, 0, 85, 1,  7, 
    1, 96, 6, 86, 7, 53, 3, 83, 2, 65, 8,  7, 4, 74, 5, 99, 0, 57
  };
  const int q6526[] = {
    9, 9, // Number of jobs and machines
    4, 74, 0, 76, 6,  4, 5, 41, 7, 49, 3, 49, 2,  1, 1, 45, 8, 65, 
    2,  7, 8, 25, 7, 66, 0, 28, 1, 86, 6, 30, 3, 47, 5, 13, 4, 46, 
    0, 64, 2, 46, 4,  9, 6, 39, 7, 26, 3, 63, 5, 44, 8, 38, 1,  5, 
    3, 22, 4, 17, 6, 30, 2, 85, 1,  2, 0, 74, 7, 12, 8, 28, 5, 64, 
    4, 43, 6, 30, 3, 87, 5, 48, 7, 90, 0, 78, 1, 93, 2, 30, 8, 80, 
    4, 89, 0, 52, 1, 47, 8, 87, 3, 77, 6, 67, 7,  9, 5, 64, 2,  5, 
    2,  2, 0, 26, 6, 66, 7,  9, 4, 25, 8, 13, 1,  9, 3, 62, 5, 22, 
    7, 62, 5, 98, 3, 83, 0, 53, 2, 96, 4, 79, 1, 67, 8, 23, 6, 50, 
    2, 29, 0, 75, 8, 80, 4, 41, 3, 95, 5, 92, 1, 79, 7, 90, 6, 63
  };
  const int q6527[] = {
    9, 9, // Number of jobs and machines
    2, 65, 8, 61, 1, 17, 4, 99, 5, 80, 6, 40, 3, 43, 7, 99, 0, 21, 
    8, 93, 6, 66, 7, 76, 4, 93, 5, 20, 1, 81, 0, 24, 3, 52, 2, 99, 
    2, 88, 8,  4, 4, 41, 0, 83, 7,  4, 5, 62, 3, 99, 1, 22, 6, 69, 
    2, 14, 4, 80, 1, 25, 6, 64, 5,  4, 7, 77, 0, 60, 3, 28, 8, 36, 
    3, 92, 4, 43, 8, 16, 7, 91, 2, 67, 6, 87, 5, 65, 0, 83, 1,  5, 
    8, 87, 2,  6, 4, 56, 0, 90, 3, 61, 5, 77, 6,  6, 7, 14, 1, 36, 
    6, 41, 0, 14, 7, 95, 8, 32, 1, 19, 5, 44, 2, 61, 3, 33, 4, 82, 
    8, 96, 1,  3, 2, 15, 3, 33, 6, 10, 0,  2, 5, 77, 7,  8, 4, 99, 
    3, 82, 4, 93, 1, 28, 8,  1, 6, 86, 2, 25, 7, 81, 5,  1, 0, 52
  };
  const int q6528[] = {
    9, 9, // Number of jobs and machines
    6, 99, 8, 65, 4, 91, 7, 74, 0, 62, 1, 11, 3, 99, 5, 34, 2, 42, 
    7, 58, 4, 49, 5, 20, 2, 52, 3, 88, 1, 99, 8, 34, 6, 85, 0, 39, 
    1, 39, 4, 28, 7, 69, 8, 27, 2, 21, 0, 66, 6, 70, 3, 61, 5, 98, 
    1, 71, 7, 46, 5, 14, 8, 24, 6, 90, 0,  9, 2, 10, 4, 41, 3, 29, 
    5, 19, 3, 46, 0, 49, 4,  2, 2, 45, 1, 17, 6, 43, 7, 59, 8, 97, 
    7, 23, 6, 46, 1, 25, 8, 41, 0,  9, 2, 31, 3,  3, 4, 44, 5, 95, 
    0, 41, 8, 77, 1, 63, 2, 54, 3, 76, 6, 65, 4, 27, 7, 26, 5, 83, 
    3,  6, 6, 76, 4, 38, 1, 74, 8, 82, 5, 32, 2, 41, 0, 39, 7, 72, 
    8, 65, 1, 25, 3, 42, 7, 51, 2, 78, 4, 11, 0,  5, 5, 21, 6, 42
  };
  const int q6529[] = {
    9, 9, // Number of jobs and machines
    3, 94, 4, 36, 8,  7, 2, 72, 5, 57, 1, 24, 6, 77, 7,  7, 0, 71, 
    4, 49, 7, 77, 8, 45, 3, 68, 2, 23, 5, 68, 1, 36, 0, 13, 6, 15, 
    1, 75, 7, 72, 2, 45, 8, 43, 5, 65, 6, 76, 4, 68, 3, 10, 0, 42, 
    1,  1, 7, 13, 8, 43, 6, 97, 5, 33, 0, 15, 2, 95, 4, 51, 3, 59, 
    6, 60, 0,  1, 2, 21, 4, 18, 8, 70, 7, 45, 3, 14, 1,  6, 5, 20, 
    0, 22, 5, 33, 6, 88, 2,  1, 1,  8, 8, 35, 7, 83, 3, 70, 4, 13, 
    7, 74, 4, 21, 5, 37, 8, 48, 6, 74, 1, 33, 3,  5, 0, 48, 2, 79, 
    1, 47, 8, 20, 4, 88, 0, 24, 6, 21, 7, 96, 3, 55, 2, 91, 5, 31, 
    4, 51, 0, 96, 2, 33, 6, 89, 8, 16, 7, 68, 5,  3, 3, 36, 1, 39
  };
  const int q6530[] = {
    9, 9, // Number of jobs and machines
    8, 41, 3, 53, 4, 32, 7, 32, 5, 82, 0, 90, 1, 21, 6, 86, 2, 25, 
    0,  8, 3, 78, 8, 46, 5, 72, 2, 94, 1, 16, 7, 31, 4, 51, 6, 14, 
    4, 97, 7, 62, 2, 89, 5, 37, 6,  9, 0, 75, 8, 17, 3, 44, 1, 97, 
    7, 21, 8, 78, 5, 71, 3, 47, 6, 51, 4,  6, 2, 79, 1, 35, 0, 57, 
    8,  8, 3, 62, 0, 22, 2, 57, 1, 90, 5, 38, 6, 14, 7, 40, 4, 69, 
    6, 89, 0, 40, 8, 66, 3,  3, 7, 10, 5, 26, 2,  9, 1, 65, 4, 81, 
    5, 62, 4, 48, 2, 48, 1, 39, 8, 35, 3, 86, 0, 47, 7, 19, 6, 75, 
    2, 94, 7, 54, 6, 93, 4, 35, 0, 19, 3,  9, 8, 42, 5, 87, 1, 89, 
    1, 63, 5, 98, 2, 95, 4, 49, 8, 66, 0, 16, 6, 42, 7, 37, 3, 85
  };
  const int q6531[] = {
    9, 9, // Number of jobs and machines
    0, 78, 1, 52, 2, 94, 8, 58, 5, 44, 6, 64, 4, 75, 3, 18, 7, 12, 
    5, 49, 1, 28, 7, 63, 2, 97, 0, 82, 3, 12, 8, 84, 4, 33, 6, 31, 
    4, 72, 8, 26, 2, 43, 5, 25, 7, 67, 3, 76, 1, 99, 6, 86, 0, 51, 
    8,  4, 6, 79, 2, 56, 4, 72, 1, 88, 7, 76, 3, 16, 5, 50, 0, 65, 
    6,  4, 3, 48, 7, 13, 4, 78, 5,  9, 8, 52, 1, 64, 2, 35, 0, 81, 
    7, 16, 0, 40, 5, 31, 6,  8, 4, 66, 1, 34, 2, 40, 8, 63, 3, 27, 
    4, 80, 6, 71, 5, 54, 2, 60, 3, 81, 0,  2, 7, 39, 8, 38, 1, 82, 
    4, 50, 1, 26, 2, 46, 6, 80, 3, 38, 8, 87, 7, 15, 5, 98, 0, 61, 
    2, 31, 7, 21, 5,  6, 6,  5, 0, 21, 3, 26, 8, 52, 4, 92, 1, 98
  };
  const int q6532[] = {
    9, 9, // Number of jobs and machines
    5, 74, 4, 67, 2, 24, 3, 11, 6, 39, 1,  8, 8, 15, 7, 57, 0, 70, 
    3, 33, 5,  1, 7, 16, 6, 85, 2, 41, 1, 78, 4, 60, 0, 15, 8,  3, 
    5, 33, 3,  1, 2,  5, 1, 55, 0, 80, 4, 22, 8, 39, 6, 90, 7, 99, 
    5, 84, 3, 86, 4, 60, 0, 71, 6, 99, 1, 19, 7, 14, 8, 60, 2, 62, 
    0, 69, 8,  5, 6, 21, 2, 77, 3, 33, 7, 18, 5, 26, 4, 52, 1, 34, 
    5,  6, 0, 23, 4, 82, 3, 47, 7, 67, 1, 53, 2, 79, 6, 45, 8, 54, 
    5, 32, 8, 90, 6, 28, 2, 10, 4, 89, 3, 34, 1, 48, 0, 86, 7, 26, 
    7, 49, 5, 75, 8, 20, 4, 33, 3,  3, 2, 30, 6, 44, 1, 18, 0, 27, 
    3, 17, 4, 14, 1, 69, 2, 74, 6, 54, 7, 96, 0, 76, 8, 77, 5, 79
  };
  const int q6533[] = {
    9, 9, // Number of jobs and machines
    7, 64, 4, 68, 3, 41, 6, 49, 2,  7, 0, 96, 5, 90, 1, 71, 8, 38, 
    8, 22, 4, 75, 1, 45, 3, 22, 0, 43, 6, 74, 2, 27, 7, 22, 5, 51, 
    4, 10, 2, 48, 7,  1, 3, 91, 1, 26, 8, 80, 0, 73, 5, 21, 6,  7, 
    6, 57, 2, 81, 1,  6, 7, 90, 4, 30, 3, 81, 8, 39, 5, 55, 0, 22, 
    1, 90, 4, 14, 3, 77, 0, 55, 8, 52, 2, 45, 5, 46, 7, 73, 6, 80, 
    4, 92, 5, 32, 7, 81, 8,  8, 2, 33, 0, 78, 3, 88, 6, 33, 1, 71, 
    1, 63, 3, 14, 7, 76, 4, 14, 0, 16, 2, 11, 6, 71, 5, 30, 8, 19, 
    4, 44, 6, 54, 3, 59, 8, 98, 0, 61, 7, 20, 1, 13, 2, 83, 5, 17, 
    7, 89, 5, 94, 4, 92, 6, 87, 1, 29, 8,  2, 3, 26, 2, 83, 0, 65
  };
  const int q6534[] = {
    9, 9, // Number of jobs and machines
    5, 54, 0, 81, 8, 18, 7, 26, 6, 66, 2, 73, 4, 47, 1, 27, 3, 87, 
    6, 91, 8, 14, 5, 93, 7, 80, 4, 81, 2, 65, 1, 75, 0, 89, 3, 22, 
    4, 64, 8, 19, 2, 42, 5, 96, 6, 14, 1, 60, 0, 16, 3, 35, 7, 48, 
    7, 42, 0, 44, 2, 70, 4, 48, 8, 37, 1, 69, 5, 64, 6, 56, 3, 25, 
    5, 24, 1, 72, 7, 98, 3, 46, 2, 56, 8, 69, 6, 50, 4, 24, 0, 99, 
    8, 48, 2, 37, 0, 38, 4, 43, 3, 87, 6, 32, 1, 48, 7, 87, 5, 72, 
    5, 81, 7, 85, 0,  2, 4, 30, 6, 74, 2, 32, 1, 68, 3,  5, 8, 84, 
    3, 18, 5,  9, 8, 65, 6, 97, 7, 57, 2, 96, 1, 58, 0,  2, 4, 55, 
    5, 86, 0, 93, 8, 41, 1, 93, 7, 35, 6, 66, 3, 41, 4, 32, 2,  7
  };
  const int q6535[] = {
    9, 9, // Number of jobs and machines
    5,  4, 3, 87, 2, 52, 8, 31, 6, 85, 7, 60, 4, 49, 1, 27, 0, 32, 
    2, 43, 8, 66, 7, 76, 5,  1, 1, 10, 3,  8, 0, 50, 4, 76, 6, 93, 
    7, 53, 6, 68, 4, 97, 0, 76, 5, 92, 2, 15, 1, 92, 3, 93, 8, 98, 
    6, 15, 0, 77, 7, 93, 5, 76, 4, 81, 8, 62, 3, 71, 2, 70, 1, 88, 
    3, 71, 0, 15, 2, 50, 4, 13, 7, 32, 8, 96, 5, 14, 6, 50, 1, 91, 
    6, 71, 7, 84, 1, 65, 8, 48, 2, 95, 3, 17, 0, 30, 4, 56, 5, 87, 
    6, 78, 2, 73, 8,  6, 5, 78, 1, 16, 7, 16, 4, 53, 0, 62, 3, 87, 
    1, 96, 2,  1, 0, 91, 7, 44, 4, 63, 8, 33, 5, 11, 6, 35, 3, 48, 
    8, 90, 5,  3, 6, 97, 3, 98, 1, 19, 4,  2, 2, 29, 7, 85, 0, 40
  };
  const int q6536[] = {
    9, 9, // Number of jobs and machines
    7, 58, 6, 24, 4, 57, 0, 56, 1, 12, 2, 27, 5, 21, 3, 96, 8, 64, 
    6, 69, 3, 87, 1,  2, 7,  8, 0, 35, 2, 37, 5, 17, 8, 77, 4, 74, 
    0, 42, 4, 72, 3, 57, 7, 44, 8, 73, 6, 98, 5,  2, 1, 67, 2, 20, 
    2, 95, 7, 62, 6, 61, 1, 33, 4, 77, 0, 39, 5, 89, 3, 20, 8,  9, 
    4, 30, 8, 40, 5, 99, 1, 73, 6, 42, 7, 83, 3, 18, 2, 11, 0, 10, 
    1, 90, 3, 71, 8, 91, 7, 32, 5, 49, 2, 25, 0, 58, 6, 17, 4, 64, 
    0, 77, 1, 36, 7, 82, 5, 97, 6, 18, 8, 50, 2, 18, 4, 33, 3,  2, 
    2, 16, 3,  6, 7, 74, 6, 94, 8, 18, 5, 76, 4, 34, 1, 76, 0, 89, 
    7,  2, 6, 28, 5, 16, 3, 34, 2, 26, 1, 92, 8, 37, 4, 60, 0, 15
  };
  const int q6537[] = {
    9, 9, // Number of jobs and machines
    6, 72, 1,  4, 8, 67, 2, 80, 3, 51, 0, 47, 7, 85, 4, 74, 5, 10, 
    6, 80, 3, 26, 7, 77, 4, 73, 0, 37, 5, 23, 8,  2, 2, 51, 1, 85, 
    7, 60, 8, 93, 5, 44, 0, 57, 2,  7, 6, 70, 4, 96, 3, 78, 1, 38, 
    3, 41, 8, 37, 5, 15, 2, 39, 1, 16, 0, 97, 4, 83, 7, 32, 6, 37, 
    4, 47, 6, 14, 7, 81, 1,  1, 2, 82, 8, 69, 0, 26, 5, 11, 3, 56, 
    1, 92, 5,  1, 2,  7, 8, 21, 3, 15, 7, 20, 4, 73, 0, 84, 6, 28, 
    5, 46, 8,  5, 6, 14, 4,  7, 0, 24, 3, 88, 1, 62, 2, 22, 7, 16, 
    2, 57, 1, 91, 6, 31, 5, 32, 8, 64, 0, 25, 3, 88, 7, 15, 4, 11, 
    3, 81, 5, 36, 4,  1, 1, 95, 6, 92, 8,  8, 7, 67, 0,  7, 2,  6
  };
  const int q6538[] = {
    9, 9, // Number of jobs and machines
    2, 94, 5, 87, 8, 21, 6, 30, 3, 79, 1, 93, 4, 64, 7, 71, 0, 13, 
    2, 98, 7, 29, 0, 12, 8, 17, 5, 49, 3, 11, 1, 98, 6, 87, 4, 89, 
    6, 33, 0, 11, 2, 18, 5, 40, 8, 63, 3, 19, 1, 68, 4, 11, 7, 76, 
    4, 53, 6, 65, 3, 31, 0, 23, 5,  7, 1, 59, 8, 69, 2, 94, 7, 99, 
    3, 66, 7, 54, 1,  5, 2, 37, 5, 76, 6, 93, 8, 63, 4, 37, 0,  7, 
    2, 25, 6,  4, 3, 89, 0, 83, 7, 70, 5, 62, 1, 36, 8, 97, 4, 85, 
    5, 72, 6, 36, 2, 29, 8, 59, 4, 10, 0, 18, 1, 19, 7, 41, 3, 31, 
    7, 94, 5, 93, 6, 60, 3, 32, 2, 45, 4, 36, 1, 34, 8, 76, 0, 32, 
    7, 80, 4, 50, 8, 66, 5,  2, 2, 42, 6,  9, 0, 94, 3, 40, 1, 35
  };
  const int q6539[] = {
    9, 9, // Number of jobs and machines
    2, 81, 5, 65, 1, 57, 8, 63, 7, 42, 4, 13, 3, 88, 6, 98, 0, 22, 
    3, 18, 7, 83, 0, 42, 4, 59, 8, 93, 5, 61, 6, 83, 2, 78, 1, 96, 
    1, 21, 2, 16, 3, 28, 6, 13, 8, 83, 7, 16, 0, 74, 5, 33, 4, 43, 
    4, 96, 1,  8, 8,  5, 5, 46, 7, 78, 0, 90, 6, 43, 3, 97, 2, 45, 
    2, 86, 5, 32, 3, 24, 8, 34, 0, 58, 7, 77, 4,  7, 6, 41, 1, 26, 
    4, 44, 3, 17, 2, 58, 8, 98, 5, 88, 0,  8, 6, 87, 1, 41, 7, 33, 
    5, 47, 3, 56, 1, 72, 8, 13, 4, 53, 2, 49, 7, 58, 6, 57, 0, 71, 
    1, 75, 2, 42, 8, 16, 4,  8, 7, 76, 0, 31, 5, 89, 3, 67, 6, 99, 
    2, 34, 1, 72, 7, 52, 0, 86, 5, 85, 4, 62, 6,  8, 8, 43, 3, 59
  };
  const int q6540[] = {
    9, 9, // Number of jobs and machines
    1, 49, 2, 33, 7,  9, 3, 22, 4, 14, 8, 51, 0, 89, 5,  1, 6, 42, 
    2, 91, 0, 50, 5, 15, 1,  5, 6, 78, 3, 91, 8, 95, 7, 85, 4,  1, 
    2, 35, 7, 85, 6, 38, 3,  4, 4, 32, 1, 82, 5, 46, 0,  4, 8, 22, 
    0, 41, 4, 58, 8,  2, 7, 97, 2, 35, 5, 34, 1, 38, 6,  9, 3, 71, 
    2, 64, 4,  7, 6, 64, 5, 25, 8,  3, 0, 25, 3, 21, 7,  5, 1, 49, 
    6, 55, 8,  9, 5, 19, 0, 12, 2, 22, 7, 81, 3, 90, 1, 67, 4, 78, 
    8, 37, 7, 66, 5, 92, 3, 69, 0, 90, 6, 24, 1,  2, 4, 41, 2, 90, 
    7, 67, 5, 54, 2, 18, 0,  2, 4, 23, 8, 90, 1, 21, 6, 55, 3, 29, 
    4, 12, 8, 82, 7, 44, 3, 43, 5, 16, 0, 92, 2, 95, 1, 13, 6,  4
  };
  const int q6541[] = {
    9, 9, // Number of jobs and machines
    2, 26, 4, 83, 1, 27, 5, 50, 3,  5, 0, 53, 7, 10, 8, 42, 6, 39, 
    3, 25, 8, 33, 6, 29, 0, 97, 7,  9, 4, 63, 1, 53, 2, 65, 5, 35, 
    5, 57, 2, 32, 1, 49, 6, 78, 0, 11, 8, 83, 3, 84, 7, 56, 4, 38, 
    4, 91, 3, 36, 7, 79, 0, 30, 8, 81, 5, 12, 1, 18, 2, 43, 6, 47, 
    1, 22, 2, 50, 3, 70, 7, 74, 0, 39, 5, 18, 8, 28, 4, 41, 6, 63, 
    7, 21, 5, 13, 2, 45, 6,  9, 8,  9, 0, 80, 3, 99, 1, 92, 4,  2, 
    2, 34, 8, 33, 6, 90, 7, 77, 5, 19, 4, 14, 1, 57, 0, 10, 3, 47, 
    5, 35, 3, 98, 4, 63, 2, 89, 8, 46, 6, 35, 0,  3, 1, 68, 7, 75, 
    1, 31, 4, 38, 7, 19, 3, 63, 2, 69, 8, 97, 5, 99, 0, 34, 6, 73
  };
  const int q6542[] = {
    9, 9, // Number of jobs and machines
    3, 30, 6, 80, 8, 54, 7, 66, 5, 23, 0,  1, 1, 48, 4, 60, 2, 55, 
    0, 16, 1, 87, 7, 28, 3, 94, 2, 63, 6, 59, 8, 91, 4, 26, 5, 75, 
    6, 98, 0, 83, 2, 37, 3,  4, 1, 61, 7, 32, 4, 21, 8, 31, 5,  6, 
    7,  9, 6, 51, 8, 75, 2, 91, 0, 62, 4, 46, 5, 83, 3, 71, 1, 96, 
    6, 10, 3, 78, 2, 15, 0, 18, 7, 30, 1, 37, 5, 47, 8,  5, 4, 94, 
    4, 28, 6, 56, 3,  2, 2, 97, 7,  5, 5, 37, 8, 17, 0, 20, 1, 93, 
    2, 39, 3, 35, 7, 89, 1, 61, 6, 51, 5, 28, 4, 43, 0, 75, 8, 68, 
    4, 77, 0, 43, 1, 14, 6,  1, 2, 45, 8, 35, 3, 60, 7, 66, 5,  8, 
    0, 73, 2, 82, 6, 73, 7, 23, 1, 22, 4, 94, 3, 54, 8,  8, 5, 12
  };
  const int q6543[] = {
    9, 9, // Number of jobs and machines
    4, 49, 2, 57, 0, 35, 6, 72, 5, 21, 1, 32, 8,  5, 3, 62, 7, 32, 
    2, 75, 6, 59, 5, 56, 0, 24, 1, 21, 8, 17, 4, 27, 7, 52, 3, 32, 
    5, 20, 4, 96, 2, 66, 7, 49, 0, 59, 8, 67, 6, 55, 3, 58, 1, 53, 
    4, 98, 0, 70, 5, 26, 6, 49, 1, 50, 2, 16, 3, 98, 7, 74, 8, 57, 
    1, 55, 3, 52, 6, 18, 4, 92, 7, 76, 0,  4, 8, 46, 2, 95, 5, 74, 
    8, 26, 5, 57, 2, 42, 6, 94, 4, 65, 0, 40, 1, 52, 3, 58, 7, 57, 
    0, 12, 1, 53, 6, 93, 7, 66, 5, 70, 2, 55, 8, 82, 4, 93, 3, 77, 
    4, 82, 6, 89, 0, 51, 8, 35, 1, 67, 2, 63, 3, 91, 7, 38, 5, 87, 
    2, 30, 1, 27, 8, 74, 3,  1, 4, 49, 5, 58, 0, 22, 7,  4, 6, 41
  };
  const int q6544[] = {
    9, 9, // Number of jobs and machines
    2, 66, 7, 21, 8, 86, 4, 41, 5, 58, 3, 27, 1,  9, 6, 32, 0, 65, 
    6, 80, 7, 90, 8,  6, 5, 71, 2, 70, 1, 39, 3, 43, 4, 88, 0, 23, 
    4, 45, 1, 39, 8, 66, 6, 74, 3, 79, 2,  6, 7, 83, 0, 91, 5, 27, 
    1, 66, 0, 96, 2, 22, 4,  6, 6, 86, 7, 12, 8, 36, 3, 39, 5, 59, 
    2, 44, 0, 97, 8,  4, 6, 55, 4, 16, 1, 22, 5, 22, 7, 47, 3,  2, 
    6, 63, 8, 33, 5, 69, 1, 38, 2, 56, 3, 10, 0, 89, 4, 54, 7, 75, 
    3, 86, 1,  8, 5, 36, 0, 27, 7, 63, 2, 52, 6, 82, 4, 66, 8,  4, 
    0, 53, 3, 52, 7, 52, 1,  6, 6, 59, 5, 82, 8, 90, 4, 37, 2,  9, 
    5, 46, 7, 68, 6, 66, 1, 77, 8, 10, 4, 56, 0,  5, 2, 99, 3, 22
  };
  const int q6545[] = {
    9, 9, // Number of jobs and machines
    2, 11, 1, 82, 6, 93, 7,  1, 3, 50, 4, 35, 8, 58, 5,  8, 0, 34, 
    0, 22, 8, 41, 7, 85, 2, 31, 5, 23, 1, 24, 4, 72, 6, 54, 3, 94, 
    5,  6, 2,  8, 3, 80, 6, 50, 7, 64, 8, 46, 4, 73, 1, 82, 0, 61, 
    0, 78, 8, 94, 7, 69, 1, 95, 6, 97, 3, 80, 2, 23, 4, 27, 5, 98, 
    6, 78, 4,  8, 8, 33, 2, 15, 0, 85, 1, 98, 7, 19, 5, 20, 3, 63, 
    5, 23, 0, 99, 4, 48, 8, 13, 1, 98, 6, 46, 2, 82, 3,  5, 7, 44, 
    8, 92, 7, 70, 0, 75, 6, 33, 4, 93, 2, 70, 5, 76, 1, 25, 3, 51, 
    6, 16, 4, 99, 3, 96, 2, 57, 7, 52, 5, 90, 8, 15, 1, 63, 0, 30, 
    4, 99, 3, 31, 2, 53, 8, 61, 5, 20, 7, 96, 6, 78, 1, 91, 0, 94
  };
  const int q6546[] = {
    9, 9, // Number of jobs and machines
    0, 75, 3, 30, 4, 16, 1, 91, 7, 24, 8, 54, 2, 77, 5, 66, 6, 39, 
    1,  7, 4, 24, 8, 86, 6, 69, 3, 81, 7, 87, 0, 10, 2, 61, 5, 87, 
    2, 48, 7, 31, 8,  9, 1, 28, 0, 75, 3, 27, 6, 29, 5, 68, 4, 41, 
    1,  7, 8, 43, 0,  2, 2, 74, 3, 47, 5, 56, 7, 73, 4, 99, 6, 67, 
    8, 58, 3, 11, 7, 91, 6,  5, 0, 88, 4, 43, 5, 49, 1, 40, 2, 37, 
    6, 15, 7, 72, 1, 72, 2, 77, 4, 54, 0, 85, 8,  3, 3, 20, 5,  3, 
    1, 81, 3, 98, 7, 18, 8, 28, 4, 64, 0, 28, 2, 38, 6, 31, 5, 76, 
    7, 36, 6, 10, 1, 64, 0, 30, 8,  5, 5, 20, 2, 27, 3, 10, 4, 88, 
    2, 41, 5, 56, 3, 58, 0, 79, 4, 63, 1, 28, 8, 14, 7, 23, 6, 49
  };
  const int q6547[] = {
    9, 9, // Number of jobs and machines
    2, 79, 7, 75, 6, 66, 3, 77, 8, 44, 5, 18, 0, 98, 4, 72, 1, 28, 
    4, 69, 7,  5, 0, 61, 3, 75, 1, 60, 2, 93, 5, 49, 8,  2, 6, 30, 
    2, 65, 7, 58, 3, 90, 0, 76, 1, 27, 8, 43, 5, 86, 4, 45, 6, 42, 
    6, 78, 8, 91, 1, 72, 2, 53, 3, 92, 5, 19, 0, 69, 4, 13, 7, 63, 
    6, 12, 4, 10, 7,  4, 0, 91, 2, 40, 5, 59, 1, 34, 3, 97, 8, 13, 
    2,  3, 4, 80, 7, 46, 3, 10, 0, 74, 1, 57, 6, 29, 8, 11, 5, 20, 
    5, 93, 3,  2, 8, 31, 1, 10, 0, 52, 6, 43, 2, 44, 7,  7, 4, 12, 
    5, 78, 1, 58, 6, 69, 8, 15, 4, 43, 7, 50, 0, 35, 2, 41, 3, 32, 
    3, 87, 0, 24, 6, 86, 1, 18, 8, 77, 5, 64, 7, 32, 4, 38, 2, 62
  };
  const int q6548[] = {
    9, 9, // Number of jobs and machines
    6, 13, 2, 11, 4, 42, 3, 19, 7, 39, 5, 59, 1, 25, 8, 57, 0, 25, 
    1, 23, 2, 64, 3,  2, 6, 81, 8, 27, 5, 94, 7, 27, 0, 36, 4, 36, 
    3, 61, 8, 35, 1, 16, 7, 27, 6, 19, 5, 49, 4, 13, 2, 36, 0, 13, 
    5, 16, 6, 19, 7, 86, 1, 76, 8, 17, 3, 75, 2, 39, 4, 16, 0, 27, 
    4, 55, 0, 55, 6, 58, 5, 21, 7, 74, 3, 27, 2, 72, 8, 24, 1,  5, 
    7, 28, 2, 57, 4, 89, 8, 28, 5, 54, 1, 43, 0, 71, 6, 43, 3, 36, 
    8, 87, 1, 13, 6, 46, 5, 26, 7, 67, 4, 89, 0, 13, 2, 80, 3, 55, 
    8, 76, 3, 37, 0, 35, 5, 64, 4, 62, 6, 20, 1, 58, 7, 91, 2, 52, 
    7,  5, 1,  3, 6, 49, 2, 16, 0, 25, 3, 25, 5, 97, 4, 55, 8, 49
  };
  const int q6549[] = {
    9, 9, // Number of jobs and machines
    3, 49, 8, 96, 4, 27, 1,  2, 6, 57, 2, 44, 7, 11, 0, 18, 5, 63, 
    5, 15, 1, 37, 7, 18, 2, 37, 0,  3, 4, 71, 6, 59, 3,  3, 8, 56, 
    6, 97, 2, 15, 1, 53, 8, 87, 4, 28, 3, 87, 5, 12, 7, 73, 0, 89, 
    3, 83, 0, 41, 8, 25, 6, 44, 7, 68, 1, 41, 2, 58, 4, 41, 5, 46, 
    6, 54, 3,  3, 0, 13, 7, 58, 1, 66, 4, 20, 2, 78, 5, 30, 8, 11, 
    2, 55, 7, 50, 6, 80, 5, 35, 8, 71, 0, 80, 4, 17, 1, 21, 3, 58, 
    2, 52, 8, 41, 5,  1, 1, 64, 6, 50, 7, 60, 4, 50, 3,  5, 0, 33, 
    5, 46, 8, 38, 6,  4, 4, 89, 3, 77, 2, 12, 1, 52, 0, 22, 7, 11, 
    6, 94, 3, 36, 8, 21, 0, 74, 1, 92, 2, 73, 4, 60, 5,  6, 7, 34
  };
  const int q6550[] = {
    9, 9, // Number of jobs and machines
    1, 95, 5, 18, 4, 77, 2, 25, 7, 55, 6, 11, 3, 35, 8, 73, 0, 49, 
    3,  9, 7, 26, 6,  7, 4, 10, 5, 65, 1, 73, 2, 41, 8, 97, 0, 13, 
    6, 12, 1, 33, 4, 14, 7, 89, 5, 46, 2, 41, 8, 44, 0,  4, 3, 44, 
    2, 79, 0, 62, 7, 47, 8, 55, 6, 76, 5, 91, 3, 21, 4, 89, 1, 46, 
    0, 92, 3, 19, 5, 31, 6, 42, 7,  8, 8, 11, 1, 54, 2, 77, 4, 24, 
    3, 68, 4, 23, 1, 21, 8, 27, 6, 96, 2, 33, 7, 55, 0, 71, 5, 28, 
    6, 76, 3, 19, 7, 64, 4, 45, 8, 61, 5, 27, 2, 79, 1, 81, 0, 85, 
    7, 55, 5, 41, 1,  1, 2, 49, 3, 46, 0, 86, 6, 59, 4, 47, 8, 41, 
    6, 52, 5, 98, 1, 35, 3, 82, 8, 62, 7, 63, 0, 64, 2, 34, 4, 40
  };
  const int q6551[] = {
    9, 9, // Number of jobs and machines
    7, 16, 3, 23, 0, 69, 5, 15, 1,  9, 8, 52, 2, 31, 6, 63, 4, 23, 
    5, 26, 1, 36, 3, 47, 8, 55, 6,  3, 7, 57, 0, 58, 2, 39, 4, 72, 
    5, 14, 0, 82, 2, 83, 6, 42, 7, 23, 8, 43, 4,  8, 1, 72, 3, 22, 
    3, 19, 1, 27, 0, 89, 2,  7, 7, 82, 6, 99, 4, 51, 5, 89, 8, 95, 
    5, 60, 8, 74, 3, 16, 2, 88, 6, 42, 7, 44, 0, 59, 4, 62, 1, 92, 
    6, 27, 8, 61, 1, 33, 4, 55, 3, 80, 2, 92, 7, 98, 5, 26, 0, 57, 
    1, 76, 5,  2, 7, 30, 8, 61, 2, 22, 6, 87, 4, 21, 3, 28, 0, 74, 
    6, 79, 0, 32, 4, 41, 3, 80, 2, 60, 1, 48, 5, 49, 7, 21, 8, 25, 
    2, 77, 3, 82, 6, 30, 4, 59, 5, 27, 8, 16, 0, 96, 7, 10, 1,  2
  };
  const int q6552[] = {
    9, 9, // Number of jobs and machines
    7, 81, 0, 58, 2, 27, 5, 29, 4, 16, 3, 79, 8, 56, 1, 91, 6, 12, 
    3, 56, 6, 15, 5, 78, 0, 63, 8, 61, 4, 69, 2, 42, 1,  2, 7, 50, 
    6, 94, 3, 62, 8, 93, 5, 59, 4, 91, 1, 36, 7, 96, 0, 76, 2, 36, 
    4, 79, 0, 13, 2, 37, 7, 69, 8, 67, 5, 35, 1, 96, 6, 50, 3, 64, 
    0, 19, 3, 10, 1, 49, 5, 24, 8, 39, 7, 54, 4, 33, 2, 85, 6, 93, 
    3, 77, 1, 39, 2, 94, 5, 52, 0, 79, 4, 15, 6, 21, 8, 13, 7,  4, 
    1,  4, 6, 48, 7, 88, 0, 71, 3, 78, 4, 78, 8, 88, 2, 31, 5,  5, 
    2, 12, 5, 24, 7, 94, 6, 20, 4, 76, 3, 92, 0, 54, 8, 34, 1, 25, 
    4, 96, 0, 30, 6, 64, 1, 12, 5, 32, 8, 85, 3, 79, 7, 26, 2, 13
  };
  const int q6553[] = {
    9, 9, // Number of jobs and machines
    6, 43, 8, 70, 1, 66, 3, 97, 4, 94, 0, 41, 5, 80, 7, 90, 2,  6, 
    7, 29, 2, 78, 0, 58, 6, 70, 8, 87, 4, 85, 5, 31, 3, 71, 1, 53, 
    5, 30, 8, 53, 7, 51, 4, 64, 0,  9, 6,  2, 1, 78, 3, 26, 2, 82, 
    0, 79, 2, 33, 7, 98, 6, 37, 3, 70, 1, 11, 4, 34, 8, 23, 5, 62, 
    1, 29, 7, 79, 5,  3, 4, 65, 2, 70, 6, 54, 3, 74, 0, 76, 8, 75, 
    3, 28, 1, 37, 6, 11, 5, 65, 7, 48, 8,  7, 0, 18, 4, 41, 2,  6, 
    8, 55, 3, 90, 4, 75, 6, 53, 1, 61, 5, 62, 7,  5, 0, 25, 2, 38, 
    2, 48, 7, 91, 4, 14, 6, 37, 0, 23, 5, 77, 1, 29, 3, 13, 8, 14, 
    3, 99, 6, 89, 0, 75, 5, 95, 7, 26, 1, 15, 2, 64, 4, 52, 8, 51
  };
  const int q6554[] = {
    9, 9, // Number of jobs and machines
    0,  2, 8, 87, 6, 56, 1, 36, 7, 49, 5, 65, 4, 38, 2, 62, 3, 47, 
    1, 93, 6, 11, 3, 48, 0, 91, 7, 30, 8, 42, 5, 36, 4, 16, 2, 51, 
    4, 73, 8, 99, 1, 42, 0, 21, 6, 25, 5, 96, 3, 32, 2, 13, 7, 96, 
    8, 13, 3, 11, 0, 25, 2, 57, 6, 39, 4, 26, 1, 44, 7, 76, 5, 44, 
    7, 14, 5, 72, 0, 47, 2, 91, 6, 66, 1, 99, 3, 76, 4,  3, 8, 97, 
    5, 49, 4, 66, 1, 19, 6,  6, 8, 16, 7, 35, 2, 47, 0, 43, 3, 54, 
    8, 95, 4, 66, 6, 52, 1, 58, 7, 18, 3, 51, 2, 17, 5,  3, 0, 47, 
    5, 41, 0, 35, 3, 32, 7, 35, 8, 59, 6, 95, 1, 80, 4, 58, 2,  8, 
    6, 73, 0, 51, 4, 41, 3, 27, 5, 13, 1, 16, 7, 82, 2, 14, 8, 74
  };
  const int q6555[] = {
    9, 9, // Number of jobs and machines
    1, 20, 0, 19, 5, 29, 4, 69, 2, 59, 6, 64, 3, 96, 7, 73, 8, 40, 
    5, 81, 4, 42, 3, 56, 1, 28, 8, 76, 0, 58, 6, 83, 7, 33, 2,  9, 
    7,  9, 5, 17, 8, 89, 2, 57, 4, 76, 1, 23, 3, 57, 0, 80, 6, 55, 
    5, 73, 7, 46, 0, 64, 2, 11, 3, 11, 6, 70, 1, 49, 8, 43, 4, 82, 
    1,  6, 2, 94, 3, 70, 4, 83, 6, 68, 0, 61, 7, 63, 8, 14, 5, 52, 
    7, 45, 5, 61, 0, 12, 3, 78, 8, 15, 2, 62, 4, 49, 1, 62, 6, 50, 
    0, 78, 2, 13, 8, 65, 5, 32, 4, 21, 6, 35, 7, 36, 3, 45, 1, 92, 
    8, 65, 0, 71, 4, 91, 2, 98, 5, 36, 1, 73, 3, 24, 6, 89, 7, 55, 
    5, 24, 6, 95, 0, 22, 1, 86, 7, 26, 2, 56, 4, 26, 8, 61, 3, 37
  };
  const int q6556[] = {
    9, 9, // Number of jobs and machines
    7, 34, 0, 42, 5, 57, 8, 85, 6, 88, 4, 32, 2, 87, 3,  8, 1,  3, 
    0, 14, 4, 37, 7,  5, 2, 60, 6,  9, 1, 99, 3, 75, 5, 80, 8, 54, 
    8,  6, 7, 62, 2, 63, 1, 24, 4, 28, 0, 21, 3, 55, 5, 28, 6, 36, 
    5, 65, 1, 33, 7, 23, 0, 62, 4, 33, 8, 16, 3, 21, 6, 69, 2, 72, 
    0, 90, 2, 82, 1, 23, 3, 96, 7, 38, 5, 39, 6, 44, 4, 56, 8, 21, 
    4, 31, 7, 12, 2,  9, 1,  3, 6, 64, 3, 75, 8, 50, 5, 77, 0, 90, 
    0, 18, 3, 86, 7, 64, 6, 54, 5, 79, 2, 32, 1, 72, 8, 40, 4,  3, 
    7, 86, 5, 93, 3, 39, 2, 42, 1, 55, 4, 52, 8, 19, 6, 85, 0, 68, 
    8, 36, 3, 59, 5, 72, 4, 86, 6,  4, 1,  1, 7, 86, 0, 53, 2, 90
  };
  const int q6557[] = {
    9, 9, // Number of jobs and machines
    6, 56, 5, 39, 3,  4, 4, 52, 8, 84, 0, 28, 1, 49, 2, 24, 7, 28, 
    8, 31, 6, 11, 3, 94, 1, 43, 4, 24, 7, 20, 0, 78, 2,  4, 5, 73, 
    1, 24, 5, 18, 2, 98, 7, 18, 3, 13, 0, 58, 6, 19, 8, 41, 4, 18, 
    7, 65, 2,  9, 5, 98, 6, 70, 1, 59, 0,  7, 4, 36, 3, 12, 8, 42, 
    6, 65, 1, 91, 4, 14, 8, 76, 0, 73, 7, 45, 2, 51, 3, 89, 5, 77, 
    1, 44, 0, 16, 6, 66, 4,  9, 2, 37, 8, 64, 5, 51, 3, 78, 7, 57, 
    4, 94, 0, 81, 2, 63, 6, 82, 7,  6, 5, 48, 8, 78, 3, 70, 1, 23, 
    4, 63, 3, 21, 6, 26, 8, 70, 1, 47, 2, 21, 0, 59, 7, 52, 5, 33, 
    0, 70, 3, 39, 5, 67, 6, 67, 2, 18, 4, 58, 7, 93, 8, 53, 1, 24
  };
  const int q6558[] = {
    9, 9, // Number of jobs and machines
    3, 91, 6, 99, 1, 99, 5, 95, 4, 76, 2, 88, 7, 55, 8, 76, 0,  9, 
    4, 63, 5, 92, 1,  7, 2, 77, 6, 89, 8, 38, 7, 37, 0, 75, 3, 96, 
    8, 39, 2, 59, 1, 44, 7, 59, 0, 18, 6, 88, 3, 81, 4, 51, 5, 17, 
    8, 66, 2, 58, 4, 74, 3, 45, 6,  7, 5, 36, 7, 22, 0, 84, 1, 31, 
    1, 42, 4, 16, 0, 28, 7, 82, 8, 60, 6, 42, 2, 44, 3, 66, 5, 85, 
    3, 98, 2, 11, 4, 56, 5, 94, 0, 22, 1, 17, 7, 83, 6, 81, 8, 64, 
    2, 71, 0, 83, 3, 40, 6,  4, 1, 91, 7, 23, 4, 36, 5, 90, 8, 33, 
    0, 94, 3, 83, 5, 82, 4, 74, 8,  2, 2, 49, 1, 93, 7, 18, 6, 96, 
    7, 47, 8, 78, 6, 60, 0, 96, 3,  7, 2, 56, 1,  9, 5, 97, 4, 84
  };
  const int q6559[] = {
    9, 9, // Number of jobs and machines
    0, 90, 6, 48, 5, 10, 4, 93, 8, 73, 7, 35, 2, 95, 1, 38, 3, 12, 
    1, 64, 5, 14, 4, 73, 8, 91, 2, 27, 0, 32, 6, 20, 3, 73, 7, 88, 
    1, 31, 7, 60, 0, 43, 5, 84, 2, 69, 8, 44, 3, 22, 4, 61, 6, 17, 
    2, 61, 7, 58, 0, 69, 1, 67, 6, 47, 4, 45, 8, 54, 3, 33, 5, 34, 
    0, 93, 7, 70, 5, 94, 8, 42, 1, 73, 6, 74, 2, 12, 3, 87, 4, 32, 
    6, 64, 0, 14, 7, 96, 4, 62, 2, 42, 3, 75, 5, 36, 1, 59, 8, 11, 
    4,  4, 5, 35, 8, 74, 0, 72, 2, 59, 1,  4, 3, 25, 7, 83, 6, 89, 
    3, 18, 7, 94, 8, 25, 6, 51, 0, 87, 4, 46, 2, 60, 1,  1, 5, 14, 
    8, 68, 5, 74, 0, 51, 6, 61, 3, 92, 2, 76, 4, 30, 7, 98, 1, 60
  };
  const int q6560[] = {
    9, 9, // Number of jobs and machines
    0,  7, 5, 96, 4, 97, 3,  4, 7, 22, 1, 50, 6, 52, 8, 72, 2, 71, 
    8, 35, 7, 94, 6, 39, 4, 14, 3, 40, 0, 42, 2, 79, 5,  2, 1, 77, 
    8, 14, 5, 83, 2, 42, 4, 80, 1, 27, 3, 46, 7, 74, 6, 41, 0, 38, 
    3, 81, 8, 74, 1, 47, 6, 78, 4, 58, 5, 24, 0, 59, 7, 89, 2, 22, 
    0, 99, 8, 11, 1, 81, 4, 61, 7, 15, 3, 14, 2, 41, 5, 77, 6,  9, 
    8,  8, 3, 24, 7, 56, 2, 36, 0, 57, 1, 23, 5, 23, 6, 52, 4, 80, 
    6, 67, 5, 83, 4,  2, 3, 69, 7, 40, 0, 12, 1, 24, 8, 96, 2, 35, 
    7, 79, 1, 39, 8, 69, 6, 33, 5, 23, 2, 37, 0, 29, 3, 27, 4, 75, 
    6, 59, 4, 94, 8, 79, 5, 92, 2, 11, 7, 46, 0, 78, 3, 90, 1, 43
  };
  const int q6561[] = {
    9, 9, // Number of jobs and machines
    4, 19, 0, 82, 5, 96, 6, 86, 2, 45, 3, 81, 7,  8, 1, 33, 8, 68, 
    3, 41, 1, 84, 6, 86, 2, 47, 4, 32, 0, 94, 8, 45, 7, 40, 5, 98, 
    8, 34, 5, 25, 3, 87, 4, 57, 0,  9, 1, 41, 2, 55, 7, 22, 6, 78, 
    4, 72, 6, 55, 0, 87, 3, 80, 8, 20, 2,  9, 7, 90, 1, 52, 5, 79, 
    4, 35, 8, 16, 3, 61, 6, 11, 2, 65, 7, 81, 5, 31, 1, 99, 0, 57, 
    0, 66, 6, 77, 5, 14, 8, 23, 3, 84, 7,  1, 1, 10, 4, 42, 2,  2, 
    2, 35, 8, 36, 5, 40, 1, 71, 7, 33, 0, 62, 3, 91, 4, 26, 6, 97, 
    5, 48, 0, 32, 7,  1, 2, 27, 3, 40, 6, 21, 1, 17, 8, 63, 4, 43, 
    5, 57, 7, 59, 0, 50, 6, 86, 4,  6, 2, 50, 8, 15, 3, 28, 1, 53
  };
  const int q6562[] = {
    9, 9, // Number of jobs and machines
    4,  4, 0, 64, 8, 53, 7, 49, 2,  9, 1, 88, 5, 24, 3, 50, 6,  5, 
    8, 90, 4, 35, 1,  4, 0,  3, 3, 40, 7, 50, 6, 32, 2, 48, 5, 96, 
    3, 58, 4, 22, 7, 75, 1, 95, 2, 25, 6, 17, 8, 27, 5, 81, 0, 55, 
    5, 47, 3, 63, 2, 36, 8, 77, 1, 31, 0, 99, 6, 44, 4, 96, 7, 39, 
    3, 72, 4, 52, 5, 51, 6, 11, 1, 77, 8, 33, 0,  8, 7, 82, 2, 98, 
    2, 31, 1, 42, 6, 92, 5, 63, 8, 79, 0, 53, 4, 83, 7, 66, 3, 59, 
    3, 22, 2, 58, 0, 29, 4, 61, 6, 56, 7, 22, 5, 16, 8, 17, 1, 13, 
    5, 48, 1, 89, 2, 67, 7, 88, 6, 59, 4, 90, 3, 30, 0, 35, 8,  1, 
    2, 48, 8, 18, 5,  9, 1, 31, 6, 14, 7, 35, 0, 31, 4,  3, 3, 84
  };
  const int q6563[] = {
    9, 9, // Number of jobs and machines
    1, 53, 6, 51, 0, 52, 7,  6, 2, 34, 8, 69, 3,  5, 4, 37, 5, 63, 
    4, 70, 3, 45, 8, 32, 1, 54, 0, 71, 2, 33, 6, 66, 5, 64, 7, 85, 
    4, 76, 5, 87, 3, 19, 7, 15, 8, 83, 0, 53, 1, 55, 2, 65, 6, 91, 
    3, 18, 8, 24, 6, 70, 2, 32, 7, 95, 5, 37, 4, 38, 1, 84, 0, 47, 
    1, 25, 0, 22, 2,  4, 4, 66, 7, 34, 3,  2, 6, 10, 5, 23, 8, 89, 
    7, 48, 6, 74, 0, 20, 5, 33, 3, 42, 4, 44, 1, 40, 8, 51, 2, 13, 
    5, 16, 1, 91, 0, 71, 6, 42, 2, 33, 8, 51, 7, 89, 3,  6, 4, 46, 
    6, 63, 3, 97, 7, 25, 0,  3, 8, 36, 2, 58, 5, 11, 4, 23, 1, 71, 
    6, 55, 1, 14, 5, 46, 0, 71, 7, 18, 8, 26, 4, 78, 2, 29, 3, 45
  };
  const int q6564[] = {
    9, 9, // Number of jobs and machines
    1, 66, 3, 30, 5, 79, 7, 78, 0, 78, 4, 39, 6,  6, 8, 28, 2, 97, 
    7, 22, 8, 27, 1, 23, 2, 84, 4, 84, 3, 31, 0, 85, 6, 42, 5, 73, 
    0, 51, 4, 48, 2, 91, 1, 53, 5,  5, 6, 41, 3, 96, 8, 83, 7, 91, 
    7, 64, 6, 42, 5, 12, 1, 98, 3, 44, 8, 30, 4, 22, 2, 48, 0, 67, 
    7, 17, 3, 96, 8, 50, 4, 44, 2, 31, 1, 88, 5, 13, 6,  7, 0, 32, 
    4, 26, 6,  3, 1, 55, 2, 16, 8, 78, 7, 81, 0, 43, 3, 92, 5, 46, 
    8, 93, 1, 63, 0, 77, 4, 18, 7, 33, 2, 12, 6, 67, 3, 24, 5, 21, 
    6, 10, 5, 48, 4, 36, 0, 37, 7, 39, 3,  8, 1, 18, 8, 49, 2, 16, 
    6, 82, 4,  5, 1, 32, 5, 84, 2, 11, 3, 76, 0,  2, 7, 31, 8, 64
  };
  const int q6565[] = {
    9, 9, // Number of jobs and machines
    7, 74, 6, 35, 3, 15, 8, 35, 2, 49, 1, 39, 5, 79, 4, 89, 0, 13, 
    6, 14, 1, 42, 3, 92, 7, 52, 2, 74, 5, 72, 8, 70, 4, 17, 0, 33, 
    0, 15, 4, 89, 8, 60, 3, 32, 7, 65, 5, 24, 6, 63, 2, 53, 1, 25, 
    2, 19, 5, 36, 4, 81, 8, 62, 1, 40, 6, 23, 3, 12, 0, 38, 7, 79, 
    4, 44, 6, 85, 7,  4, 2, 96, 3, 42, 8, 29, 0, 39, 5, 17, 1, 25, 
    8, 59, 1,  8, 5, 77, 0, 69, 4, 82, 2, 75, 6, 90, 7, 22, 3, 42, 
    7, 36, 8, 53, 2, 56, 3, 37, 1, 55, 5, 11, 6, 54, 0, 11, 4,  5, 
    8, 34, 7, 23, 4, 18, 1, 76, 3,  5, 0, 37, 5, 26, 6, 82, 2, 86, 
    1, 68, 8, 43, 2, 57, 6, 91, 4, 21, 3, 69, 7, 97, 0, 21, 5, 80
  };
  const int q6566[] = {
    9, 9, // Number of jobs and machines
    8, 29, 1, 73, 2, 98, 3, 81, 4, 79, 0, 72, 7, 42, 6, 37, 5, 80, 
    6,  8, 7, 52, 4, 33, 3, 38, 8, 64, 1, 92, 5, 13, 2, 74, 0, 81, 
    8, 11, 6, 27, 3,  1, 7, 73, 5, 76, 4,  4, 1, 89, 0, 64, 2, 25, 
    5,  8, 2, 83, 0,  9, 3, 23, 4, 36, 7, 77, 1, 28, 8, 92, 6, 95, 
    8, 46, 4, 99, 1, 60, 0,  1, 2, 84, 6, 36, 7, 19, 3, 93, 5, 15, 
    6, 62, 8, 40, 1, 50, 5, 57, 0, 58, 7, 32, 2, 70, 3, 10, 4, 29, 
    7, 96, 4, 58, 2,  5, 5,  3, 6, 13, 0, 62, 1,  1, 3, 45, 8, 96, 
    3, 49, 4, 41, 2, 79, 8,  8, 0, 39, 1, 29, 6, 97, 7, 91, 5, 93, 
    2, 88, 3, 83, 1, 12, 8, 92, 0, 53, 5, 68, 4, 38, 7,  3, 6,  5
  };
  const int q6567[] = {
    9, 9, // Number of jobs and machines
    6, 43, 3, 61, 8, 41, 7, 72, 1, 23, 0, 27, 4, 63, 5, 68, 2, 68, 
    5, 45, 6, 53, 7, 60, 0, 54, 2, 44, 3, 62, 4, 31, 8, 37, 1, 82, 
    1,  7, 7, 91, 5, 56, 4, 13, 8, 96, 6, 33, 0, 65, 2,  4, 3, 41, 
    5, 48, 2,  2, 0, 26, 3, 81, 8, 13, 7, 95, 6, 32, 1, 78, 4, 56, 
    5, 51, 4, 85, 6, 75, 1, 35, 8, 28, 3, 25, 7, 82, 0, 61, 2,  8, 
    0, 37, 1, 63, 7, 56, 3, 47, 5, 78, 6, 36, 8, 78, 2, 26, 4, 50, 
    2, 94, 3, 56, 1, 64, 0, 14, 4, 68, 5, 74, 6, 52, 7, 33, 8,  9, 
    8,  5, 6, 54, 5, 51, 0, 52, 2, 54, 3, 17, 1, 15, 4, 72, 7, 17, 
    0, 60, 3, 37, 7, 46, 5, 10, 4, 89, 6, 88, 2, 14, 1,  7, 8, 37
  };
  const int q6568[] = {
    9, 9, // Number of jobs and machines
    5, 47, 8, 85, 3, 99, 4, 81, 7, 95, 6, 40, 1, 12, 2, 33, 0, 22, 
    3, 33, 5, 11, 1, 85, 6, 37, 8, 47, 7, 40, 4, 33, 0, 51, 2,  2, 
    3, 56, 7, 61, 2, 91, 6, 47, 1,  5, 4, 97, 0, 34, 5, 69, 8, 74, 
    2,  6, 5, 38, 4, 95, 8, 90, 3, 71, 6, 51, 1, 99, 7, 30, 0,  2, 
    8, 64, 3,  3, 6, 64, 1, 47, 4, 13, 5, 54, 7, 14, 0, 57, 2, 37, 
    6, 38, 3, 84, 5, 28, 2, 92, 1, 72, 0, 79, 4, 95, 8, 10, 7, 20, 
    4, 33, 1,  2, 2, 33, 7, 62, 5, 48, 0, 27, 3, 35, 6, 54, 8, 67, 
    3, 81, 4, 57, 0, 41, 8, 48, 1,  6, 6,  8, 2, 45, 7, 84, 5, 99, 
    6, 85, 4, 95, 2, 41, 7, 29, 8, 26, 1, 46, 5, 80, 0, 18, 3, 89
  };
  const int q6569[] = {
    9, 9, // Number of jobs and machines
    1, 14, 5, 81, 8, 35, 0, 21, 2, 66, 6, 37, 3, 99, 7, 12, 4, 92, 
    7, 27, 5, 69, 4, 73, 6, 77, 8,  4, 0, 96, 3, 59, 2,  8, 1, 77, 
    0, 38, 4, 92, 3, 22, 7, 17, 5, 53, 8, 91, 6, 20, 1, 14, 2, 87, 
    1,  4, 2, 33, 6, 73, 0, 82, 7, 33, 5, 16, 4, 26, 8, 68, 3, 74, 
    2, 61, 0, 69, 5, 41, 3, 38, 7, 89, 8, 58, 1, 38, 6, 64, 4, 97, 
    7, 32, 0, 44, 8, 57, 3, 22, 5, 32, 4, 27, 2, 42, 6, 15, 1,  5, 
    6, 72, 7, 15, 4,  7, 5, 65, 2, 39, 1, 74, 3, 95, 0,  9, 8, 96, 
    5, 48, 2, 18, 3, 82, 8, 45, 7, 25, 4, 84, 1, 37, 6, 25, 0, 79, 
    6, 95, 7, 59, 3, 52, 4, 37, 5, 84, 1, 70, 8, 94, 0, 66, 2, 71
  };
  const int q6570[] = {
    9, 9, // Number of jobs and machines
    5, 23, 6, 54, 0,  1, 8, 73, 3, 78, 1, 80, 2, 53, 4, 12, 7, 11, 
    5, 27, 1, 41, 0, 77, 2, 46, 3, 26, 6, 96, 8,  6, 7, 82, 4, 82, 
    6, 47, 0, 98, 5, 96, 4, 70, 8, 12, 3, 74, 1, 45, 2, 93, 7, 78, 
    6, 21, 3, 71, 7, 12, 1, 76, 4, 53, 8, 82, 5, 43, 0,  4, 2, 99, 
    8, 43, 2, 21, 4, 73, 7, 22, 3, 14, 5,  4, 1, 56, 0,  4, 6, 18, 
    2, 62, 6, 81, 7, 94, 8, 91, 1, 71, 0, 37, 5, 71, 3, 65, 4, 54, 
    0, 50, 5, 67, 4, 23, 3, 31, 6, 26, 1, 80, 8, 90, 2, 28, 7,  3, 
    5, 34, 6, 50, 3, 74, 1, 75, 8, 54, 0, 23, 2, 63, 7, 73, 4, 11, 
    3, 42, 1, 99, 7, 69, 2, 17, 6, 25, 4, 71, 8, 46, 5, 58, 0, 24
  };
  const int q6571[] = {
    9, 9, // Number of jobs and machines
    5, 99, 2, 11, 7, 62, 4,  3, 8,  6, 0, 82, 3, 45, 1, 87, 6, 59, 
    4, 31, 6, 96, 8, 53, 3,  8, 1, 37, 2, 21, 5, 13, 0, 81, 7, 86, 
    0, 60, 1, 73, 3, 19, 5, 21, 8, 99, 7, 48, 2, 21, 6, 83, 4, 31, 
    5, 69, 2, 15, 7, 50, 0, 64, 4,  2, 3, 53, 1, 54, 6, 12, 8, 24, 
    2, 14, 0, 35, 4, 83, 8, 82, 5, 98, 1,  4, 7, 80, 3,  8, 6, 48, 
    2, 54, 3,  2, 7, 59, 4, 19, 1, 80, 8, 16, 0, 50, 6, 11, 5,  9, 
    8, 42, 3, 34, 4, 72, 2, 60, 1, 85, 0, 83, 6, 64, 5, 11, 7, 93, 
    1, 76, 3, 26, 4, 37, 6, 26, 0, 38, 2, 61, 7, 50, 5, 70, 8, 97, 
    2, 10, 5, 91, 8, 18, 0, 17, 7, 78, 4, 93, 3, 30, 1, 77, 6, 62
  };
  const int q6572[] = {
    9, 9, // Number of jobs and machines
    4, 45, 2, 90, 8, 58, 7, 79, 0, 85, 3, 69, 1, 45, 5, 47, 6, 29, 
    6, 31, 0,  4, 4, 31, 1, 42, 2, 30, 8,  6, 5, 31, 7, 39, 3, 83, 
    7, 57, 1, 48, 8, 72, 0, 66, 4, 42, 5, 41, 6, 26, 3, 86, 2, 11, 
    6, 38, 8, 27, 4, 37, 0, 54, 3, 37, 1, 14, 2, 40, 7, 50, 5, 11, 
    1, 92, 2, 36, 4, 13, 5, 34, 8, 47, 3, 59, 7, 95, 0, 74, 6, 56, 
    5, 18, 0, 67, 4, 49, 2, 84, 1, 21, 7, 47, 3, 54, 8, 69, 6, 94, 
    6,  5, 2, 98, 3,  4, 1, 22, 8, 99, 5, 96, 4, 50, 7, 25, 0, 32, 
    2, 82, 8, 95, 1, 88, 0, 29, 5, 17, 6, 95, 4, 60, 3, 41, 7, 43, 
    0, 53, 6,  8, 7, 62, 1, 57, 2, 24, 3, 66, 5, 65, 8, 30, 4, 58
  };
  const int q6573[] = {
    9, 9, // Number of jobs and machines
    0, 24, 6, 22, 7,  8, 4, 81, 1,  4, 8, 82, 5, 55, 2, 90, 3, 80, 
    0, 40, 8, 50, 3, 64, 6, 36, 2, 89, 7, 69, 1,  9, 4, 70, 5, 83, 
    6, 53, 8, 22, 1, 89, 2, 19, 0, 81, 5, 26, 3, 29, 7, 84, 4, 98, 
    3,  6, 0, 79, 6, 50, 5, 35, 2, 34, 8, 97, 1, 51, 4, 64, 7, 73, 
    7, 86, 0, 23, 1, 13, 2, 46, 5, 98, 6, 80, 8, 61, 3, 22, 4, 85, 
    2, 39, 4, 96, 3, 42, 6, 35, 0, 14, 5, 46, 1, 89, 8, 33, 7, 60, 
    2, 13, 7, 46, 6, 16, 5, 17, 8,  8, 1, 75, 3, 85, 0, 73, 4, 43, 
    2, 91, 6, 93, 1, 89, 0, 68, 3, 25, 4, 84, 7, 43, 8, 44, 5, 88, 
    3, 77, 5, 79, 8, 76, 7, 21, 6, 70, 0, 65, 4, 71, 2, 40, 1, 82
  };
  const int q6574[] = {
    9, 9, // Number of jobs and machines
    5, 60, 2, 13, 8, 28, 7, 36, 3, 26, 0, 83, 6, 77, 1, 88, 4, 75, 
    5, 18, 8, 25, 3, 44, 2, 81, 7, 33, 1, 47, 0, 72, 4, 81, 6, 53, 
    2, 14, 5, 73, 0, 18, 6, 98, 1,  6, 4, 10, 8, 74, 7, 97, 3, 51, 
    5, 93, 3, 72, 7, 14, 8, 76, 2,  2, 4, 22, 1, 87, 6,  2, 0, 24, 
    6, 33, 2, 52, 3, 24, 1, 32, 0,  5, 5, 22, 4,  4, 8, 16, 7, 15, 
    3, 58, 6, 83, 2, 59, 7, 73, 1, 71, 0, 95, 4, 41, 5, 35, 8, 54, 
    6, 44, 0, 51, 1, 14, 3, 37, 4, 15, 5, 85, 8, 95, 7, 67, 2, 56, 
    4, 28, 6, 18, 5, 98, 7, 79, 1, 49, 8,  9, 2, 59, 3, 67, 0, 75, 
    2, 31, 1, 97, 5, 12, 4, 59, 8, 62, 3, 60, 0, 52, 7, 95, 6, 30
  };
  const int q6575[] = {
    9, 9, // Number of jobs and machines
    7,  4, 1, 56, 8, 38, 6,  5, 0, 89, 4, 57, 3, 84, 5, 71, 2, 84, 
    0, 71, 3, 25, 8, 53, 6, 19, 2, 69, 1, 14, 4, 39, 7, 97, 5,  9, 
    4, 92, 1, 34, 6, 31, 8, 20, 5, 50, 3, 29, 7, 86, 0, 65, 2,  8, 
    0, 45, 8, 41, 2, 66, 7, 13, 4, 68, 6, 65, 5, 60, 3, 75, 1, 62, 
    2, 57, 5,  5, 4, 79, 7, 50, 6, 28, 3, 19, 1,  5, 8, 29, 0, 40, 
    5, 26, 8, 77, 0, 37, 1, 19, 3, 29, 7, 42, 6, 20, 4, 79, 2,  9, 
    7, 12, 1, 51, 5, 46, 6, 55, 2, 80, 8, 78, 4,  5, 3, 75, 0, 21, 
    1,  9, 2, 59, 7, 49, 0, 48, 3, 14, 6, 58, 4, 13, 8, 23, 5, 51, 
    8, 40, 0, 83, 2, 93, 1, 34, 5, 89, 6, 23, 7, 19, 4, 52, 3, 96
  };
  const int q6576[] = {
    9, 9, // Number of jobs and machines
    4, 48, 0, 31, 6, 80, 5, 23, 7, 30, 8, 18, 2, 56, 3, 79, 1, 39, 
    4, 49, 3, 41, 2, 38, 8, 15, 6, 79, 1, 76, 5, 50, 0, 66, 7, 70, 
    0,  2, 5,  9, 6,  4, 2, 95, 7, 77, 8, 80, 1, 43, 4, 83, 3, 62, 
    0, 67, 5, 76, 3, 93, 7, 33, 2, 81, 4, 58, 8, 14, 1, 61, 6, 72, 
    4, 62, 0, 59, 2, 39, 7, 36, 6, 43, 8, 11, 5, 88, 3, 50, 1, 43, 
    6, 46, 3, 58, 5, 13, 8, 52, 1, 60, 0, 34, 2, 42, 4, 19, 7, 94, 
    5, 53, 3, 72, 0, 23, 2,  4, 8,  8, 4, 33, 7, 96, 1, 34, 6,  5, 
    2, 18, 1, 45, 3, 65, 5, 17, 7, 27, 6, 82, 0, 38, 8, 88, 4, 47, 
    2, 59, 1,  2, 3, 27, 6, 93, 7, 70, 4, 49, 0, 97, 5, 29, 8, 96
  };
  const int q6577[] = {
    9, 9, // Number of jobs and machines
    8, 77, 1,  3, 6, 45, 2, 63, 3, 74, 7, 68, 5, 58, 4, 53, 0, 86, 
    6, 99, 4, 18, 2, 18, 7, 48, 3, 58, 0, 18, 5, 46, 8, 45, 1, 53, 
    6,  3, 0, 30, 7, 86, 5, 59, 8, 39, 1, 64, 3, 80, 4, 59, 2, 43, 
    7, 68, 1, 25, 6, 72, 2, 14, 5, 89, 8, 11, 3, 69, 4, 25, 0, 53, 
    1,  8, 2,  4, 4, 56, 3, 97, 6, 64, 8, 77, 5, 85, 7, 70, 0, 69, 
    4, 24, 8, 37, 5, 13, 2, 99, 3, 60, 1, 23, 6, 56, 0, 66, 7, 17, 
    7, 34, 0, 57, 8, 73, 5, 86, 1, 71, 6, 12, 2, 13, 4, 16, 3, 17, 
    8, 31, 7,  2, 0, 53, 1, 63, 4, 22, 6, 20, 5, 29, 3, 98, 2, 61, 
    1, 57, 4, 13, 6, 16, 3, 58, 0, 84, 7, 63, 5,  9, 8, 84, 2, 52
  };
  const int q6578[] = {
    9, 9, // Number of jobs and machines
    8, 15, 7, 65, 6, 52, 5, 55, 1, 67, 3, 74, 0, 79, 4, 23, 2, 82, 
    7, 40, 3, 78, 6, 91, 8, 13, 1, 52, 0, 77, 5, 76, 4, 81, 2, 91, 
    8, 34, 2, 91, 7, 22, 0, 56, 1, 66, 6, 98, 5, 97, 4, 54, 3, 46, 
    3, 72, 5,  4, 6, 73, 0, 92, 8, 99, 7, 17, 1, 53, 4, 14, 2, 59, 
    3, 33, 8, 43, 6, 87, 1, 55, 0, 46, 2, 62, 4, 61, 5, 43, 7, 74, 
    5, 76, 4,  5, 6,  7, 3, 41, 0, 13, 1, 32, 7, 60, 8, 50, 2, 42, 
    6, 84, 1, 94, 8, 89, 3, 71, 2, 90, 7, 47, 5, 34, 0,  2, 4, 81, 
    4, 20, 1, 24, 2, 69, 6, 31, 3, 78, 7, 25, 5,  8, 0, 11, 8, 79, 
    8, 27, 6, 77, 3, 10, 0, 91, 2, 43, 7, 30, 1, 21, 4, 23, 5, 43
  };
  const int q6579[] = {
    9, 9, // Number of jobs and machines
    4, 37, 1, 43, 2, 30, 8, 61, 3, 81, 6, 32, 7, 23, 5,  8, 0, 37, 
    5, 57, 8, 24, 0, 76, 1, 13, 3, 16, 4,  2, 6, 85, 2, 55, 7, 91, 
    7, 99, 5, 32, 3, 72, 4,  5, 8, 67, 1, 96, 0, 55, 2, 12, 6, 46, 
    4, 45, 3, 40, 1, 24, 5, 90, 7, 10, 0, 65, 6, 88, 8, 13, 2, 64, 
    8, 28, 4, 49, 1, 13, 5, 62, 0, 48, 2, 56, 6, 83, 7, 87, 3, 42, 
    1, 51, 8, 40, 3, 12, 4, 78, 0, 76, 6, 32, 7, 86, 5, 55, 2, 98, 
    0, 51, 6, 18, 4, 51, 8, 82, 1, 85, 2,  4, 3, 36, 7, 42, 5, 12, 
    8, 90, 1, 48, 7, 99, 2,  9, 6, 25, 4, 57, 5, 43, 0, 73, 3, 98, 
    0, 48, 5, 98, 1, 41, 3, 89, 2, 32, 6, 28, 7, 93, 8, 34, 4, 48
  };
  const int q6580[] = {
    9, 9, // Number of jobs and machines
    1, 58, 6,  5, 7, 92, 2, 10, 3, 55, 5, 77, 4, 71, 8, 91, 0, 16, 
    6, 51, 4, 59, 3, 79, 5, 24, 2, 22, 8, 34, 7, 80, 1, 52, 0, 81, 
    4, 76, 2, 22, 5, 38, 8, 26, 3, 29, 6, 81, 0, 39, 7, 69, 1, 17, 
    2, 26, 6, 31, 0, 36, 1, 38, 4, 95, 5, 95, 8, 68, 7, 31, 3, 92, 
    6, 13, 4,  9, 8, 68, 3, 79, 5, 75, 1, 68, 0, 72, 2, 14, 7, 27, 
    3, 34, 2, 56, 1, 72, 0, 75, 8, 39, 6, 19, 7, 56, 4, 57, 5, 85, 
    0, 42, 8, 50, 6, 36, 2,  4, 1, 33, 7, 11, 4, 25, 3,  5, 5, 19, 
    2, 45, 5, 63, 4,  1, 6, 63, 1, 84, 0, 20, 8, 17, 3, 19, 7, 22, 
    2, 93, 8, 27, 4, 67, 0, 19, 3, 40, 6, 46, 7, 27, 1, 33, 5, 98
  };
  const int q6581[] = {
    9, 9, // Number of jobs and machines
    8, 74, 2, 41, 0, 96, 5, 68, 6, 59, 3, 47, 4, 96, 7, 85, 1,  7, 
    5, 66, 8, 86, 3, 63, 2, 80, 7, 64, 6, 10, 1, 75, 4,  7, 0, 29, 
    8, 94, 1, 45, 7, 86, 6, 87, 5,  5, 0, 37, 3, 81, 4, 51, 2, 47, 
    2, 93, 4, 99, 3, 63, 5, 67, 8, 66, 6, 78, 0, 68, 7, 94, 1, 35, 
    7, 52, 3, 92, 2, 22, 0,  8, 5, 87, 6, 47, 1, 10, 8, 90, 4,  4, 
    0, 19, 5, 68, 1, 17, 6, 92, 4, 38, 2, 33, 3, 22, 8,  1, 7, 17, 
    4, 16, 6, 84, 0, 19, 8, 42, 7, 11, 3, 58, 2, 28, 5, 94, 1, 74, 
    3, 95, 5, 67, 0, 74, 4, 62, 2, 14, 8, 48, 7, 79, 6, 42, 1, 34, 
    4, 76, 2, 48, 8, 32, 5, 90, 7, 69, 6, 54, 3, 49, 0, 41, 1, 50
  };
  const int q6582[] = {
    9, 9, // Number of jobs and machines
    3, 97, 8, 19, 1, 97, 6, 33, 0, 98, 7, 89, 4, 17, 5,  5, 2, 85, 
    8, 20, 0, 99, 1, 43, 7, 57, 3, 91, 2, 20, 4, 20, 5, 18, 6, 71, 
    6, 81, 3, 65, 2, 78, 8, 11, 7, 14, 0, 40, 4, 32, 1, 14, 5, 74, 
    8, 49, 1, 42, 0, 34, 7, 42, 6, 39, 2, 59, 4, 69, 5, 24, 3, 72, 
    0, 25, 1, 48, 7, 71, 4, 66, 3, 44, 5, 39, 2, 15, 8, 89, 6, 53, 
    7,  6, 1, 81, 0, 34, 2, 91, 5, 21, 3, 29, 4, 74, 6, 68, 8, 87, 
    0, 18, 8,  6, 3, 59, 6, 18, 5, 12, 4, 68, 7, 19, 2, 56, 1, 15, 
    2, 92, 5, 53, 4, 22, 0, 49, 7, 47, 6, 84, 1, 92, 8, 86, 3, 47, 
    3, 39, 8, 56, 1, 95, 2, 30, 6, 98, 4,  8, 0, 99, 7,  1, 5, 34
  };
  const int q6583[] = {
    9, 9, // Number of jobs and machines
    1, 15, 4, 41, 0, 58, 2,  4, 3, 66, 6, 71, 7, 27, 8, 73, 5, 13, 
    2, 69, 5, 68, 8, 82, 7, 35, 1, 20, 3, 16, 0,  1, 6,  8, 4, 15, 
    7, 23, 6, 40, 8, 95, 1, 38, 4, 23, 5, 45, 2, 36, 0,  1, 3, 86, 
    3, 68, 4, 62, 2, 74, 1, 20, 5, 29, 0, 48, 6, 52, 8, 39, 7, 26, 
    6, 83, 8, 16, 7, 34, 0,  4, 5, 15, 3, 45, 4,  9, 2, 72, 1, 95, 
    0, 62, 6, 98, 4, 48, 2, 67, 8, 49, 7, 22, 1, 44, 5, 86, 3, 19, 
    8, 54, 3, 10, 4, 69, 0, 36, 1, 64, 7, 91, 2, 10, 5, 87, 6, 55, 
    2, 47, 0, 70, 6, 60, 3, 52, 4, 19, 5,  1, 8, 79, 7, 87, 1, 59, 
    1, 99, 0, 34, 5, 10, 4, 90, 3, 89, 8, 38, 2, 33, 7, 81, 6, 62
  };
  const int q6584[] = {
    9, 9, // Number of jobs and machines
    0, 72, 8, 13, 1, 54, 4, 23, 7, 56, 6, 98, 5,  5, 2, 47, 3,  5, 
    7, 57, 6, 82, 8, 90, 1, 60, 5, 84, 2, 75, 0, 17, 3, 44, 4, 39, 
    8, 85, 3, 46, 7, 42, 4, 68, 0, 57, 2, 19, 1,  1, 6, 56, 5, 46, 
    5, 27, 1, 18, 6, 73, 8, 50, 4, 87, 0, 61, 3, 75, 2, 69, 7, 62, 
    0, 21, 1,  4, 6, 76, 4, 79, 8, 65, 3, 75, 5,  3, 2, 22, 7, 30, 
    0, 88, 1, 56, 4, 81, 3, 81, 6, 65, 8, 82, 2, 68, 7,  3, 5, 73, 
    3, 36, 6, 34, 8, 42, 4, 40, 2, 70, 0, 89, 5, 68, 7, 89, 1, 61, 
    0, 76, 3, 59, 1, 34, 2, 67, 8, 67, 5,  3, 4,  7, 7, 18, 6, 12, 
    8, 50, 7,  7, 5, 99, 0, 49, 6, 22, 3, 38, 2, 15, 4, 43, 1, 25
  };
  const int q6585[] = {
    9, 9, // Number of jobs and machines
    3, 73, 5, 29, 2, 50, 4, 59, 6, 75, 7, 61, 1, 57, 8, 54, 0, 75, 
    5, 30, 4, 47, 8, 11, 3, 30, 0, 46, 2, 38, 1, 75, 7, 71, 6, 53, 
    2, 19, 7, 69, 8,  5, 5, 82, 4, 62, 0, 75, 3, 99, 6, 41, 1, 84, 
    3, 93, 6, 63, 8,  6, 5, 77, 4, 42, 0, 40, 2, 35, 7, 81, 1, 31, 
    8, 30, 1, 34, 3, 11, 5, 16, 7, 31, 2, 64, 0, 40, 4, 20, 6, 76, 
    2, 53, 7, 97, 8, 46, 0, 44, 1, 59, 3, 67, 5, 15, 6, 12, 4,  1, 
    6, 85, 0, 88, 4, 93, 7, 74, 5,  1, 3, 56, 1, 94, 2, 86, 8, 89, 
    6, 29, 3, 65, 2, 75, 0, 10, 1, 47, 5, 28, 8, 37, 7, 93, 4, 47, 
    8, 42, 0, 40, 1, 21, 4, 13, 2,  4, 6, 71, 7, 25, 3, 70, 5, 80
  };
  const int q6586[] = {
    9, 9, // Number of jobs and machines
    1, 90, 5, 76, 4, 49, 7, 54, 0, 45, 3,  6, 6, 16, 2, 47, 8, 96, 
    6,  5, 5, 66, 2, 89, 1, 10, 8,  9, 0, 32, 7, 88, 3, 90, 4, 95, 
    3, 75, 4, 23, 0, 21, 5, 92, 8, 38, 7, 34, 6, 68, 2, 87, 1, 15, 
    3, 57, 0, 98, 4, 31, 6, 14, 1, 33, 5, 67, 2, 67, 8, 74, 7, 55, 
    2, 74, 1, 54, 7, 52, 8, 37, 6, 10, 0, 12, 4, 59, 5, 90, 3, 65, 
    0,  9, 1, 52, 3, 52, 8, 70, 6, 58, 2, 26, 5,  3, 7, 41, 4, 41, 
    2, 18, 8,  4, 1, 45, 6, 89, 5, 46, 4, 97, 0, 69, 7, 56, 3, 27, 
    4, 55, 2, 11, 0, 15, 6, 35, 8, 37, 7, 62, 3, 42, 5,  3, 1,  1, 
    6, 15, 7, 99, 8, 30, 1, 72, 3, 51, 4, 58, 0, 94, 5, 90, 2, 85
  };
  const int q6587[] = {
    9, 9, // Number of jobs and machines
    3, 13, 8, 62, 7, 92, 1, 53, 5, 90, 4, 51, 0, 45, 6,  5, 2, 94, 
    1, 64, 2,  9, 6,  7, 4, 62, 5, 81, 8, 29, 3, 69, 0, 63, 7, 51, 
    5, 95, 2, 24, 8, 92, 7, 70, 4, 42, 6, 38, 0, 43, 3, 79, 1, 77, 
    3, 44, 0, 11, 5, 23, 2, 24, 8,  3, 7,  5, 4, 85, 6, 95, 1,  2, 
    6, 42, 8, 76, 3, 67, 5, 47, 2, 72, 4, 37, 1, 36, 0, 40, 7, 24, 
    0, 99, 7, 51, 4, 24, 2, 32, 6, 95, 8, 56, 3, 11, 1, 59, 5, 17, 
    2, 47, 7, 73, 1, 23, 6, 52, 0, 29, 8, 27, 4, 65, 3, 56, 5, 26, 
    7, 20, 8, 68, 5, 53, 1, 79, 2, 12, 4, 69, 3, 75, 0, 36, 6, 22, 
    0, 75, 3, 33, 7, 94, 6,  8, 4, 29, 5, 18, 1, 28, 2,  7, 8, 60
  };
  const int q6588[] = {
    9, 9, // Number of jobs and machines
    5, 16, 0, 37, 4, 59, 2, 37, 7, 10, 1, 60, 8, 61, 6, 80, 3, 19, 
    0, 36, 4, 21, 8, 37, 2, 72, 6, 45, 3, 94, 5, 79, 1, 29, 7, 72, 
    5, 73, 6, 89, 8,  8, 0, 22, 1, 35, 7, 75, 2, 93, 3, 90, 4, 36, 
    4, 34, 1, 46, 0, 90, 2, 24, 8, 12, 3, 91, 5, 77, 7, 75, 6, 34, 
    2, 68, 3, 98, 7, 16, 0,  8, 4, 29, 8, 35, 1, 32, 5, 48, 6,  2, 
    2, 46, 4, 22, 3, 89, 8, 57, 7, 32, 6, 92, 0, 68, 5, 92, 1, 42, 
    3, 10, 8, 21, 5, 22, 7, 30, 6, 71, 0, 13, 1,  5, 2, 55, 4, 35, 
    6, 24, 7, 61, 1, 48, 3, 30, 0, 44, 4, 15, 8, 30, 5, 60, 2, 85, 
    6, 86, 2, 85, 0,  7, 7, 47, 4,  2, 3, 80, 8, 67, 1, 44, 5, 29
  };
  const int q6589[] = {
    9, 9, // Number of jobs and machines
    3, 97, 7, 87, 5, 62, 2, 67, 1, 85, 0, 11, 6, 60, 4, 83, 8, 79, 
    0, 37, 2, 10, 1, 91, 3, 46, 7, 22, 5, 16, 8, 39, 4, 14, 6, 66, 
    1, 53, 7, 99, 0, 66, 4, 23, 8, 21, 3, 97, 2, 73, 5, 32, 6, 24, 
    4, 62, 3, 95, 0, 35, 5, 19, 1, 37, 7, 69, 6, 63, 2, 98, 8, 83, 
    2, 83, 3, 23, 0, 27, 4, 90, 8, 78, 5, 33, 7, 20, 1, 62, 6, 62, 
    8, 68, 3, 53, 0, 16, 7, 53, 6, 24, 1, 79, 4, 46, 5, 10, 2, 67, 
    0, 44, 3, 11, 5,  4, 8, 82, 4,  4, 1, 82, 7, 93, 2,  9, 6, 19, 
    5,  7, 4, 78, 1,  2, 0, 48, 8,  3, 6, 45, 2, 30, 3, 50, 7, 75, 
    6,  6, 5, 18, 0, 96, 4, 99, 8, 76, 1, 90, 2,  6, 3, 91, 7, 31
  };
  const int q6590[] = {
    9, 9, // Number of jobs and machines
    4, 87, 0, 86, 5, 83, 3,  2, 8,  5, 1, 66, 6, 53, 2,  2, 7, 48, 
    6, 42, 7, 67, 2, 82, 4, 57, 1, 85, 3, 17, 0, 11, 8, 33, 5, 41, 
    6,  1, 1, 19, 5, 25, 2, 89, 4, 44, 3, 87, 8, 52, 0, 92, 7,  4, 
    5, 67, 3,  5, 8, 18, 6, 80, 0, 45, 1, 17, 7, 29, 2, 29, 4, 56, 
    3, 63, 6, 14, 8, 51, 2,  9, 7, 31, 5,  7, 1, 98, 0, 83, 4, 27, 
    3, 50, 7,  7, 5, 23, 2, 84, 8, 40, 0, 51, 4, 96, 6, 73, 1, 57, 
    7,  8, 4, 51, 2,  8, 3, 99, 0, 95, 6, 84, 1, 74, 8, 79, 5, 58, 
    1, 18, 7, 50, 3, 76, 4, 42, 2, 58, 5, 40, 8, 21, 0, 65, 6, 79, 
    6, 58, 2, 65, 7, 77, 1,  8, 0, 47, 4, 66, 3, 31, 5, 74, 8, 57
  };
  const int q6591[] = {
    9, 9, // Number of jobs and machines
    8, 82, 1, 17, 3, 13, 7, 33, 5, 88, 6, 91, 4,  8, 2, 16, 0,  7, 
    0, 99, 4, 51, 3, 37, 7, 38, 8, 61, 2,  8, 1, 19, 5, 85, 6, 84, 
    0, 32, 4, 80, 8, 35, 3, 96, 6, 49, 1, 34, 7, 44, 5, 62, 2, 37, 
    3, 98, 7, 21, 5, 97, 8, 13, 1, 58, 2, 43, 0, 84, 4, 39, 6, 80, 
    0, 71, 7, 51, 8,  3, 1, 89, 4, 19, 3,  7, 6, 49, 5,  8, 2, 37, 
    2, 92, 0, 17, 8, 76, 6, 85, 1, 24, 5, 83, 3, 71, 4, 27, 7, 68, 
    1, 70, 0, 39, 3,  8, 4, 28, 7, 92, 8, 40, 6, 39, 2, 31, 5, 48, 
    5, 56, 0, 89, 8, 57, 6, 26, 2, 84, 4, 81, 3, 59, 1, 73, 7, 54, 
    0, 12, 1, 15, 5, 49, 4, 47, 8, 95, 2, 27, 7, 47, 6, 42, 3, 97
  };
  const int q6592[] = {
    9, 9, // Number of jobs and machines
    4, 52, 3, 48, 7, 11, 8, 88, 2,  9, 6, 60, 0, 32, 5,  7, 1, 17, 
    3, 77, 2, 11, 8, 74, 5, 48, 7, 45, 6, 20, 0, 60, 4,  3, 1, 41, 
    5, 55, 0, 70, 1, 60, 6,  8, 7, 99, 8, 37, 2, 11, 3, 96, 4, 23, 
    8, 43, 3, 18, 5, 50, 0, 21, 7, 46, 6, 63, 4, 26, 1, 14, 2, 48, 
    7, 36, 3, 50, 6, 97, 1, 79, 5, 59, 2, 98, 8, 98, 0, 93, 4, 37, 
    8,  6, 2, 65, 6, 76, 0, 76, 7, 15, 5, 50, 1, 86, 3, 58, 4, 59, 
    6, 62, 3,  9, 4, 69, 7, 16, 5,  3, 1, 69, 8, 77, 2,  2, 0, 39, 
    1, 82, 7, 39, 3,  1, 0, 62, 6, 51, 2, 19, 8, 21, 5, 35, 4, 67, 
    0, 15, 5, 27, 1, 93, 8, 32, 3, 52, 4, 46, 7, 51, 2, 51, 6, 79
  };
  const int q6593[] = {
    9, 9, // Number of jobs and machines
    0, 92, 1, 58, 6, 67, 3, 58, 2, 47, 4, 77, 5, 74, 8, 26, 7, 46, 
    0, 94, 1, 89, 8,  5, 5, 88, 3, 47, 4,  6, 2, 79, 7, 34, 6, 21, 
    0, 19, 7, 38, 2, 67, 3, 69, 4,  4, 5, 94, 1, 39, 8, 61, 6, 79, 
    7, 27, 5, 78, 0, 39, 4, 35, 3, 56, 6, 64, 2, 58, 1, 74, 8, 37, 
    8, 47, 2,  6, 7, 11, 5, 36, 4, 75, 1, 60, 0, 96, 6,  8, 3, 78, 
    0, 27, 8, 26, 5, 33, 4, 54, 3, 40, 7, 48, 1, 28, 6,  9, 2, 18, 
    0, 16, 8, 80, 1, 12, 6, 13, 4, 15, 2, 85, 7, 31, 3, 10, 5, 90, 
    8, 92, 5, 45, 1, 80, 7, 51, 0, 37, 4, 55, 3,  3, 6, 22, 2, 15, 
    4, 47, 0, 34, 2, 33, 7, 95, 3, 22, 8, 92, 5, 41, 6, 29, 1, 18
  };
  const int q6594[] = {
    9, 9, // Number of jobs and machines
    6, 87, 5, 75, 4, 17, 7, 77, 1, 36, 3, 45, 0, 42, 8, 29, 2, 44, 
    2, 90, 7, 43, 0,  9, 5, 71, 4, 30, 8, 18, 1, 11, 6, 79, 3,  2, 
    5, 70, 6, 75, 0, 30, 8, 11, 2, 37, 3, 28, 1,  6, 7, 92, 4,  7, 
    5, 95, 0, 99, 7,  4, 2, 36, 4, 98, 6, 36, 3, 66, 1, 40, 8, 22, 
    5, 64, 3, 33, 7, 43, 6, 93, 1, 60, 0, 52, 4, 95, 2, 59, 8, 96, 
    7, 88, 4,  4, 5, 26, 2, 96, 1, 35, 0, 52, 3, 60, 8, 90, 6, 68, 
    4, 17, 8, 12, 5, 83, 1, 79, 6,  4, 3, 85, 0, 85, 2, 23, 7, 50, 
    6, 36, 4, 44, 3, 73, 8, 59, 0, 83, 5, 13, 7, 54, 2, 33, 1, 62, 
    6, 50, 3, 95, 7, 65, 4, 21, 8, 79, 1, 51, 0, 83, 2, 41, 5, 34
  };
  const int q6595[] = {
    9, 9, // Number of jobs and machines
    1, 24, 0, 23, 8, 94, 3, 28, 4, 79, 2, 92, 6, 92, 7, 92, 5, 65, 
    7, 57, 4, 43, 8,  9, 3, 14, 5, 61, 6, 44, 1,  8, 2, 31, 0, 18, 
    1, 93, 7, 48, 8, 71, 4, 47, 5, 61, 2, 63, 6, 33, 3, 45, 0, 42, 
    1, 58, 0, 69, 6, 68, 7, 63, 4,  6, 5, 20, 3,  5, 8, 26, 2, 40, 
    1, 50, 8, 15, 7, 49, 6, 71, 0, 14, 3, 19, 4, 22, 2, 93, 5, 47, 
    7, 23, 8,  1, 5, 12, 2, 58, 6, 70, 0, 89, 3, 88, 4, 13, 1, 54, 
    2, 81, 1, 18, 4, 63, 8, 68, 5, 25, 6, 29, 3, 91, 7, 13, 0, 57, 
    8,  6, 3, 45, 5, 82, 7, 27, 0, 11, 6, 44, 4, 35, 2, 53, 1, 59, 
    6, 85, 0, 63, 8, 34, 1, 25, 4,  4, 7, 19, 3, 53, 5,  7, 2,  6
  };
  const int q6596[] = {
    9, 9, // Number of jobs and machines
    1, 77, 0, 68, 2, 44, 6, 63, 7, 80, 8, 91, 4, 92, 3, 33, 5, 21, 
    8, 58, 0, 53, 1, 94, 7, 81, 5, 82, 2, 45, 6, 92, 4, 91, 3, 40, 
    7, 42, 5, 42, 3, 79, 2, 24, 1, 80, 6, 81, 0, 98, 8, 94, 4, 59, 
    0, 16, 1, 81, 2, 90, 5, 49, 7, 58, 8, 30, 4, 84, 3,  9, 6, 32, 
    2,  5, 7, 21, 4, 91, 5, 91, 1, 55, 8, 18, 3, 64, 0, 67, 6, 30, 
    1, 11, 4, 37, 2, 16, 3, 18, 6, 42, 0, 37, 5, 28, 8, 28, 7, 95, 
    0, 13, 5,  8, 2, 10, 7, 89, 6, 12, 1, 18, 3, 20, 8, 82, 4, 19, 
    6, 38, 8, 46, 1,  2, 4, 90, 5, 95, 7, 70, 0,  7, 3, 81, 2, 59, 
    8, 97, 0, 59, 2, 25, 3, 93, 7, 50, 5, 15, 1,  7, 6, 31, 4, 43
  };
  const int q6597[] = {
    9, 9, // Number of jobs and machines
    2, 22, 5, 82, 1, 80, 4, 32, 6, 93, 0, 64, 3, 89, 8, 37, 7, 89, 
    6, 38, 4, 60, 3, 38, 1, 85, 2, 34, 0, 59, 5, 37, 8, 52, 7, 79, 
    0, 76, 3, 91, 1, 51, 7,  7, 6, 67, 5, 30, 4, 38, 8, 61, 2, 49, 
    2, 96, 3, 74, 8, 58, 1, 91, 0,  7, 6, 75, 4, 39, 5, 66, 7, 86, 
    2, 48, 1, 69, 5, 66, 6, 93, 7, 74, 3, 88, 0, 76, 8, 92, 4, 32, 
    7, 46, 3, 27, 2,  6, 4, 37, 8, 16, 5, 97, 6, 15, 1, 53, 0, 24, 
    5, 24, 1, 56, 3, 51, 6, 83, 8, 89, 2, 54, 0, 83, 4, 81, 7, 61, 
    3, 80, 4, 99, 7, 67, 1, 18, 0, 94, 6, 83, 2, 14, 5, 34, 8,  7, 
    5, 67, 2, 42, 6, 46, 0, 38, 3, 39, 4, 72, 7, 34, 1, 25, 8, 98
  };
  const int q6598[] = {
    9, 9, // Number of jobs and machines
    2, 12, 4, 99, 5,  2, 6,  1, 1, 52, 3, 54, 8,  1, 7, 60, 0, 38, 
    8, 61, 6, 53, 0, 30, 7, 83, 4, 83, 1, 62, 2,  7, 3, 46, 5, 30, 
    0, 73, 5,  9, 7, 47, 6, 93, 3, 76, 4, 55, 2, 72, 1, 22, 8, 77, 
    0, 86, 1, 90, 4, 70, 8,  8, 3, 77, 6, 18, 7, 75, 2, 29, 5, 83, 
    3, 91, 8, 36, 1, 15, 7, 73, 0, 64, 6, 73, 2, 53, 5, 90, 4, 15, 
    8, 39, 2, 85, 5, 11, 0, 92, 6, 48, 4, 36, 7, 59, 3, 58, 1, 26, 
    6, 79, 3, 58, 0, 54, 4, 67, 1, 16, 7, 56, 5, 38, 2, 41, 8, 62, 
    1, 70, 2, 63, 3, 49, 0, 99, 4, 12, 8,  2, 6, 73, 5, 68, 7, 35, 
    6, 93, 8, 99, 1, 23, 5, 34, 3, 16, 4, 29, 7, 60, 0, 10, 2, 83
  };
  const int q6599[] = {
    9, 9, // Number of jobs and machines
    6, 44, 1, 29, 0, 49, 2, 95, 8, 68, 4, 71, 7,  8, 3, 35, 5, 76, 
    4, 79, 8, 94, 1, 49, 3,  9, 5, 63, 0, 55, 6, 83, 7, 39, 2, 32, 
    1,  4, 4, 13, 7, 59, 3,  8, 0, 48, 8, 54, 5, 11, 6, 45, 2, 24, 
    1, 77, 2, 86, 0, 77, 6, 92, 8, 71, 4, 45, 7, 65, 3, 99, 5, 94, 
    3, 77, 6, 56, 4, 39, 2, 74, 7, 40, 5, 98, 8, 22, 0, 91, 1,  6, 
    0, 34, 1, 47, 2,  1, 7, 90, 3, 54, 8, 29, 4, 28, 6, 12, 5, 34, 
    8, 75, 2, 45, 3, 18, 6, 39, 7,  5, 0, 42, 4, 32, 1, 94, 5, 64, 
    4, 80, 2, 58, 0, 13, 1, 62, 3,  3, 8, 90, 7, 84, 5, 58, 6, 10, 
    5,  5, 8, 33, 2, 90, 7, 14, 0, 95, 3, 63, 1, 95, 6, 58, 4, 24
  };
  const int q6600[] = {
    9, 9, // Number of jobs and machines
    8, 10, 6, 97, 0, 16, 5, 47, 2, 73, 1, 62, 7, 14, 3, 24, 4, 98, 
    6, 32, 8, 19, 1, 80, 7,  2, 2, 22, 4, 61, 0, 72, 3, 81, 5, 84, 
    4, 47, 7, 43, 5, 55, 8,  9, 0,  2, 3, 39, 6, 81, 1, 99, 2, 35, 
    8, 60, 0, 80, 2, 40, 6,  3, 3, 58, 1, 88, 4, 53, 7, 12, 5, 91, 
    6, 42, 0, 99, 4, 92, 3, 81, 8, 46, 2, 82, 1, 75, 5, 43, 7, 25, 
    2, 43, 6, 91, 7, 72, 4, 48, 5, 28, 3, 17, 0, 20, 1, 76, 8, 74, 
    4, 25, 7, 75, 3, 34, 2, 92, 0, 40, 5, 92, 8, 91, 6, 76, 1, 46, 
    3, 19, 0, 93, 5, 45, 4, 95, 8, 74, 1, 91, 7, 62, 2,  1, 6, 11, 
    4, 44, 0, 16, 1, 66, 8, 76, 6, 20, 2, 48, 5, 87, 3, 36, 7, 19
  };
  const int q6601[] = {
    9, 9, // Number of jobs and machines
    6, 50, 1, 49, 5, 37, 3, 81, 7, 96, 2, 96, 8, 74, 0,  2, 4,  9, 
    8,  8, 4, 97, 0, 17, 5,  8, 7,  7, 1, 10, 6, 22, 2, 47, 3, 58, 
    6, 74, 8, 37, 1, 94, 3, 46, 4, 97, 2, 68, 5, 42, 0, 92, 7, 76, 
    1,  3, 0, 30, 3, 68, 2,  9, 6, 27, 4,  6, 8, 37, 7,  2, 5, 27, 
    8, 97, 0, 39, 1, 37, 6,  2, 3, 22, 7, 54, 4, 50, 5, 96, 2, 30, 
    8, 10, 6, 83, 7,  5, 5, 60, 4, 29, 2, 38, 1, 57, 0, 81, 3, 39, 
    6, 83, 1, 81, 8, 26, 0, 59, 2, 31, 7, 21, 5, 21, 4, 61, 3,  7, 
    8, 35, 6,  2, 3, 71, 4,  3, 1, 17, 0, 28, 7, 64, 2, 95, 5, 81, 
    4, 17, 1, 53, 0, 59, 5, 21, 2, 84, 7, 37, 6,  5, 3,  8, 8, 79
  };
  const int q6602[] = {
    9, 9, // Number of jobs and machines
    2, 96, 0, 55, 7, 56, 3, 43, 4, 13, 8, 23, 6, 12, 5, 18, 1, 35, 
    4,  7, 8, 38, 3, 28, 6, 61, 5, 37, 0, 79, 2, 96, 7, 66, 1, 46, 
    0, 73, 8, 87, 7, 65, 5,  6, 4,  9, 2, 59, 1,  6, 6, 29, 3, 59, 
    8, 15, 2, 63, 0, 58, 3,  8, 4, 47, 7, 55, 1, 82, 5, 44, 6, 10, 
    8, 44, 7, 30, 4, 92, 2, 89, 0, 48, 1,  2, 3, 88, 6, 99, 5,  6, 
    8, 37, 6, 14, 0, 30, 2, 65, 5, 52, 3, 86, 4, 64, 7, 65, 1, 35, 
    1, 85, 2, 61, 5,  3, 0, 48, 7,  7, 8, 29, 4, 84, 6, 72, 3, 22, 
    7, 25, 1, 12, 6, 94, 2, 99, 8, 49, 5, 19, 3,  6, 4, 62, 0, 79, 
    0, 37, 8, 43, 5, 85, 1, 32, 3, 12, 6, 59, 7, 33, 2, 59, 4, 85
  };
  const int q6603[] = {
    9, 9, // Number of jobs and machines
    1, 91, 5,  8, 4, 63, 3,  5, 0, 65, 7, 23, 2, 80, 8, 50, 6, 40, 
    2, 46, 6, 75, 5, 88, 0,  1, 1, 48, 7, 85, 3, 73, 8, 69, 4, 15, 
    3, 87, 1, 89, 7, 93, 2, 68, 4, 73, 6,  4, 5,  7, 8, 81, 0, 77, 
    0, 54, 3, 16, 1, 37, 7, 76, 5, 56, 8, 48, 2, 89, 4, 20, 6, 70, 
    3, 30, 6, 29, 2, 60, 0, 40, 8, 99, 4, 85, 1, 67, 5, 25, 7, 28, 
    8, 33, 7, 29, 6, 16, 0, 68, 4, 20, 2, 59, 3, 90, 1, 79, 5, 93, 
    0, 16, 8, 85, 1, 89, 6, 76, 3, 81, 7, 28, 5, 39, 4, 15, 2, 84, 
    2,  8, 3, 54, 5, 79, 1, 61, 8, 22, 6, 94, 4, 12, 7,  7, 0, 27, 
    6,  3, 5, 25, 3, 42, 2, 61, 1, 71, 0, 64, 8,  9, 7, 50, 4,  3
  };
  const int q6604[] = {
    9, 9, // Number of jobs and machines
    2, 12, 1, 54, 3, 34, 6, 81, 7, 96, 8, 68, 0, 80, 5, 83, 4, 26, 
    5, 91, 7, 65, 3, 61, 0, 25, 6,  7, 1, 86, 8, 34, 2, 88, 4, 80, 
    0, 44, 7, 79, 6, 22, 1, 32, 8, 22, 3, 84, 2, 13, 4, 63, 5, 15, 
    3, 51, 0,  4, 5, 21, 7, 87, 8, 69, 2, 81, 1, 94, 6, 93, 4, 95, 
    5, 50, 1, 43, 8, 76, 2, 86, 3,  8, 7, 50, 4, 67, 6, 90, 0, 79, 
    5, 70, 4, 44, 7, 95, 1, 46, 8,  4, 2, 50, 3, 40, 6, 58, 0, 84, 
    2, 50, 4, 55, 5, 21, 8, 23, 7, 99, 0, 26, 3, 51, 1, 60, 6, 61, 
    7, 41, 6, 97, 2, 77, 0, 86, 1, 21, 5, 34, 8, 32, 4, 22, 3, 45, 
    0, 44, 4, 90, 1, 55, 8, 62, 6, 98, 5, 53, 2, 45, 3, 63, 7, 73
  };
  const int q6605[] = {
    9, 9, // Number of jobs and machines
    0, 18, 3, 75, 6, 81, 5, 81, 4, 65, 8, 75, 7, 32, 1, 57, 2, 83, 
    5, 13, 6, 34, 2,  4, 7, 56, 4, 39, 0, 11, 3, 75, 1,  2, 8,  6, 
    0, 95, 2, 27, 8, 75, 4, 65, 7, 26, 6, 76, 5, 57, 1, 22, 3, 90, 
    7, 17, 5,  7, 4, 41, 1, 45, 0, 51, 6, 50, 3, 44, 2, 48, 8, 25, 
    7, 93, 1, 38, 8, 58, 5, 18, 2, 97, 4, 66, 3, 11, 6, 82, 0, 53, 
    6, 44, 0, 96, 5, 46, 2, 81, 8, 57, 4, 39, 3, 15, 7, 24, 1, 81, 
    1, 91, 2, 49, 4, 41, 0, 87, 6, 80, 3, 61, 8, 16, 7, 17, 5, 52, 
    5, 49, 4, 85, 2, 18, 1, 32, 0, 63, 7, 33, 6, 15, 8,  5, 3, 62, 
    0, 58, 2, 87, 6, 16, 8, 21, 3, 81, 4, 95, 1, 33, 7, 63, 5, 65
  };
  const int q6606[] = {
    9, 9, // Number of jobs and machines
    5, 76, 4, 89, 7, 79, 2, 57, 8,  5, 0, 94, 6, 98, 3, 76, 1,  3, 
    3, 71, 7, 11, 1, 88, 0, 76, 4,  5, 5, 92, 2, 41, 8, 88, 6,  3, 
    8, 69, 2, 66, 7, 96, 1, 58, 0, 86, 4, 76, 3, 76, 5, 71, 6,  4, 
    0, 33, 7, 59, 8,  7, 6, 66, 5, 85, 4,  7, 1, 17, 3, 46, 2, 13, 
    1,  3, 8, 91, 6,  6, 7, 64, 2, 90, 0, 84, 5, 68, 3, 75, 4, 81, 
    3, 49, 5, 60, 4, 52, 0, 55, 8, 24, 2, 63, 1, 14, 6, 72, 7, 17, 
    5,  1, 6, 10, 3, 19, 2, 31, 4,  3, 7, 42, 1, 74, 8, 55, 0, 50, 
    4,  7, 2, 64, 0, 24, 1, 54, 5, 84, 7,  4, 8, 19, 3, 74, 6, 55, 
    1, 24, 4, 98, 8, 68, 0, 61, 5, 34, 2, 98, 7,  5, 6, 86, 3, 61
  };
  const int q6607[] = {
    9, 9, // Number of jobs and machines
    6, 72, 8, 59, 2, 74, 1, 10, 4, 79, 7, 48, 5, 10, 3, 96, 0, 37, 
    3, 71, 8, 73, 4, 68, 5, 83, 2, 68, 1, 79, 7, 36, 6, 23, 0,  6, 
    2, 32, 0, 34, 1, 28, 6, 99, 4, 49, 5, 75, 3,  2, 7, 28, 8, 53, 
    5, 41, 2, 70, 7, 33, 3, 59, 6, 40, 1, 79, 4, 82, 8, 63, 0, 95, 
    4, 48, 3, 34, 1, 37, 7, 66, 8, 61, 2, 91, 6, 11, 5, 98, 0, 77, 
    2, 25, 3, 28, 4, 84, 1, 65, 6, 86, 5,  5, 8, 20, 7,  7, 0, 17, 
    5,  1, 1, 89, 4, 87, 6, 27, 2, 23, 7, 97, 3, 36, 8, 76, 0, 32, 
    2, 71, 6, 85, 3, 74, 7, 74, 1, 79, 8, 85, 4, 35, 5,  6, 0, 10, 
    4, 53, 5, 33, 1, 50, 7, 90, 2, 12, 6, 66, 8, 50, 3,  3, 0,  7
  };
  const int q6608[] = {
    9, 9, // Number of jobs and machines
    3, 61, 5, 39, 8, 34, 1, 79, 6, 54, 7, 52, 4, 22, 2,  4, 0, 51, 
    7, 54, 0, 80, 5,  2, 1, 39, 8, 85, 4, 86, 6, 37, 3, 23, 2, 64, 
    7, 50, 2, 42, 8, 58, 1, 51, 4, 66, 6, 52, 3, 83, 5, 49, 0, 75, 
    6, 93, 7, 60, 3, 72, 2, 28, 1, 27, 0, 36, 8, 43, 5, 68, 4, 89, 
    7, 14, 1, 64, 8, 91, 3, 61, 6, 62, 5, 46, 4, 88, 2, 45, 0, 72, 
    2, 75, 3, 23, 4, 64, 7, 12, 0, 87, 5, 77, 8, 41, 6, 35, 1, 22, 
    1, 57, 2, 49, 6, 35, 3, 70, 7, 82, 0, 95, 4, 49, 5, 74, 8, 25, 
    4, 94, 1, 46, 0,  3, 6, 50, 3, 14, 5, 96, 7, 26, 8, 39, 2, 55, 
    7, 12, 1, 49, 5, 93, 8, 46, 0, 21, 3, 98, 6, 23, 2, 15, 4, 23
  };
  const int q6609[] = {
    9, 9, // Number of jobs and machines
    1, 35, 7, 53, 2, 18, 6, 69, 3, 62, 0, 14, 8, 42, 5, 77, 4, 27, 
    7, 98, 5,  2, 1, 83, 2, 45, 4, 48, 6, 51, 3, 65, 0, 21, 8, 23, 
    5, 21, 7, 67, 4, 79, 8, 74, 2, 86, 6, 21, 1, 53, 0, 27, 3, 30, 
    6, 99, 8, 28, 2, 59, 3, 26, 1, 16, 5, 37, 0, 87, 4, 86, 7, 83, 
    1, 55, 7, 60, 8, 92, 3, 22, 4,  9, 2, 45, 6, 96, 5, 34, 0, 27, 
    6, 58, 5, 21, 7, 50, 4, 28, 3,  6, 0, 41, 8, 38, 2, 18, 1, 78, 
    2, 70, 1, 51, 6, 73, 3, 47, 5,  3, 4, 71, 8, 35, 0, 13, 7, 40, 
    2, 74, 4, 60, 7, 50, 0, 69, 1, 53, 3,  6, 6, 68, 5, 89, 8, 54, 
    7, 18, 0, 13, 2, 52, 8, 50, 4,  7, 5, 92, 6, 84, 3, 90, 1, 68
  };
  const int q6610[] = {
    9, 9, // Number of jobs and machines
    2, 57, 7, 48, 4, 89, 0, 36, 6,  3, 8,  7, 5, 29, 3, 71, 1, 35, 
    2, 49, 3, 89, 0, 23, 1, 26, 4, 28, 5, 43, 6, 25, 7, 81, 8, 70, 
    5, 67, 0, 75, 7, 75, 8, 85, 3, 77, 2, 15, 6, 48, 1, 34, 4, 41, 
    4, 91, 3, 21, 0, 60, 2, 66, 7, 15, 1, 88, 5, 75, 6, 17, 8, 63, 
    8, 41, 6, 38, 3, 87, 7, 24, 0, 52, 5, 78, 2, 84, 4, 47, 1, 80, 
    0, 72, 6, 66, 7, 94, 1,  2, 8, 15, 3, 38, 4, 17, 5, 97, 2, 19, 
    5, 97, 8, 83, 7, 73, 3, 97, 6,  9, 4, 72, 1, 43, 2, 97, 0, 42, 
    4, 84, 7,  2, 6, 85, 0, 34, 1, 65, 2, 63, 3, 62, 8, 43, 5, 80, 
    6, 84, 1, 94, 2, 67, 8,  7, 0, 23, 5, 37, 3, 49, 4, 95, 7, 79
  };
  const int q6611[] = {
    9, 9, // Number of jobs and machines
    8, 84, 6, 35, 4, 11, 0, 43, 7, 61, 1, 44, 2, 13, 5,  6, 3, 20, 
    0, 96, 3,  9, 8,  9, 7,  8, 5, 32, 1, 28, 2, 59, 6, 15, 4, 58, 
    5, 24, 7, 23, 8, 90, 4, 72, 1, 30, 6, 23, 0, 99, 2, 79, 3, 46, 
    0,  3, 6, 50, 2, 56, 4, 34, 8, 88, 3, 75, 7, 10, 5, 99, 1, 14, 
    3, 87, 6, 73, 2, 95, 5, 96, 4, 19, 7, 98, 8,  6, 1, 99, 0, 35, 
    0, 33, 5, 26, 3, 44, 6, 51, 8, 46, 1, 61, 2, 26, 4,  6, 7, 78, 
    2, 70, 4, 95, 5, 32, 0, 21, 8, 18, 3, 69, 1,  7, 7, 78, 6, 35, 
    4, 26, 0, 36, 8, 86, 7,  7, 5, 94, 6,  6, 2, 62, 1, 13, 3, 82, 
    5, 20, 7, 95, 4, 31, 0, 76, 2,  8, 6, 80, 1, 47, 8, 71, 3, 80
  };
  const int q6612[] = {
    9, 9, // Number of jobs and machines
    5, 47, 6, 38, 0,  7, 2, 41, 8, 84, 4, 51, 3, 73, 1, 28, 7, 67, 
    5, 67, 1,  3, 3, 11, 4, 39, 2, 20, 7, 20, 6, 43, 8, 36, 0, 27, 
    5, 23, 7, 97, 0, 31, 4, 53, 2, 73, 8, 46, 1, 94, 6, 15, 3, 46, 
    1, 93, 2, 19, 8, 26, 5, 42, 0, 18, 3, 75, 4, 16, 7, 10, 6, 94, 
    7, 17, 5,  5, 3, 71, 6, 24, 0, 21, 1, 82, 2, 37, 8, 87, 4, 31, 
    3, 16, 1, 57, 7, 39, 2, 13, 0, 29, 8, 14, 4, 66, 5, 34, 6, 19, 
    3, 63, 5, 14, 8, 54, 2, 71, 4, 77, 0, 40, 6, 75, 1, 65, 7, 58, 
    7,  2, 2, 70, 8, 16, 6, 75, 4, 99, 3,  2, 1, 24, 5, 86, 0, 19, 
    6, 89, 5, 24, 1, 29, 0, 31, 4, 26, 3, 81, 7, 89, 8,  5, 2, 39
  };
  const int q6613[] = {
    9, 9, // Number of jobs and machines
    3,  8, 6, 64, 0, 79, 4, 53, 7, 44, 2, 84, 1, 87, 5, 83, 8, 30, 
    4, 80, 0, 30, 6, 11, 3,  3, 2, 80, 1, 38, 7, 86, 5, 74, 8, 89, 
    5, 89, 3,  2, 8, 24, 2, 30, 7, 40, 1, 50, 0, 15, 6, 44, 4, 52, 
    2, 11, 6, 60, 7, 12, 1,  8, 8, 38, 3, 22, 0, 72, 5, 17, 4, 92, 
    1, 50, 2, 69, 4, 92, 8, 91, 0, 37, 7,  1, 6, 31, 5, 97, 3, 26, 
    6, 53, 5, 56, 7, 51, 2, 49, 4, 61, 0, 47, 1, 16, 3, 50, 8, 13, 
    6, 10, 3,  6, 5, 80, 4, 10, 8, 10, 1,  6, 2,  8, 0, 89, 7, 84, 
    1, 44, 7, 33, 4, 90, 0,  3, 2, 66, 6, 99, 5, 37, 3, 88, 8, 96, 
    0, 38, 4, 60, 8, 80, 6, 22, 7, 69, 5, 88, 3, 52, 1, 33, 2, 74
  };
  const int q6614[] = {
    9, 9, // Number of jobs and machines
    5, 47, 6, 39, 7, 23, 8,  3, 3, 11, 2, 92, 4,  8, 0, 57, 1, 62, 
    8, 63, 3, 49, 6, 71, 1, 85, 5, 65, 7, 74, 4, 17, 2, 11, 0, 52, 
    1, 78, 3, 33, 7, 18, 8, 93, 6, 48, 2, 17, 4,  6, 5, 88, 0, 71, 
    8, 77, 7, 50, 4, 26, 5, 59, 6, 69, 3, 49, 1,  7, 0, 36, 2, 16, 
    8, 45, 4, 79, 5, 15, 0, 50, 6, 64, 2, 91, 7, 13, 1, 91, 3, 87, 
    3, 97, 7, 93, 6, 74, 5, 11, 4, 10, 0, 25, 8, 74, 1, 92, 2,  9, 
    4, 53, 2, 10, 6, 71, 7, 79, 3, 51, 5, 61, 1, 25, 8, 82, 0,  6, 
    8, 32, 3, 46, 4, 84, 1, 24, 7, 98, 0, 42, 5, 43, 2, 36, 6, 19, 
    4, 59, 5, 89, 6, 40, 7, 48, 2, 60, 1, 19, 0, 52, 3, 99, 8,  3
  };
  const int q6615[] = {
    9, 9, // Number of jobs and machines
    0, 79, 5, 94, 2, 71, 4, 27, 1, 92, 7,  1, 3, 22, 6, 28, 8, 73, 
    5, 30, 0, 45, 8, 61, 1, 33, 7, 68, 2, 49, 4, 96, 6, 19, 3, 42, 
    8, 31, 5, 89, 6,  7, 1, 43, 4, 39, 7, 90, 2, 54, 3, 83, 0, 64, 
    2, 28, 0, 20, 8,  7, 1, 49, 3, 51, 4, 25, 6, 72, 7, 73, 5, 23, 
    3, 98, 0, 12, 6, 65, 5, 54, 1, 14, 4, 89, 8,  4, 2, 92, 7, 41, 
    0, 34, 7, 59, 2, 53, 3, 28, 8, 47, 6, 79, 4, 89, 5,  8, 1, 62, 
    7, 31, 1, 17, 5, 74, 8, 45, 3, 42, 6, 13, 4, 85, 2, 64, 0, 46, 
    4, 69, 2, 76, 8,  1, 0, 68, 7, 44, 5, 12, 6, 69, 1, 96, 3, 70, 
    6, 20, 2, 43, 1, 17, 4, 82, 8, 44, 3, 32, 0, 21, 7, 71, 5, 46
  };
  const int q6616[] = {
    9, 9, // Number of jobs and machines
    2,  5, 6, 40, 7, 44, 5, 96, 0, 18, 4, 10, 3, 89, 8, 51, 1, 39, 
    3, 54, 4, 24, 8, 71, 1, 13, 2, 25, 6, 66, 0, 23, 7, 80, 5, 22, 
    2, 63, 6, 46, 4, 19, 3, 67, 8, 28, 5,  2, 1, 89, 0, 34, 7, 59, 
    3, 64, 8, 42, 6, 46, 4, 72, 5, 56, 2, 50, 7, 63, 1, 88, 0, 98, 
    6, 68, 7, 42, 0, 28, 4, 90, 2, 89, 1, 40, 3, 38, 5, 40, 8, 57, 
    2, 72, 6, 44, 0, 26, 1, 77, 4, 80, 3, 49, 7, 94, 8,  8, 5,  5, 
    3, 47, 5,  5, 4, 69, 2, 30, 7, 68, 0, 20, 6, 69, 1, 85, 8,  2, 
    4, 68, 0, 56, 2, 26, 6, 49, 7, 73, 1,  4, 5,  5, 8, 32, 3, 95, 
    4, 71, 1,  8, 2, 23, 5, 96, 0, 86, 3, 35, 8, 71, 7, 17, 6, 19
  };
  const int q6617[] = {
    9, 9, // Number of jobs and machines
    5, 56, 3,  7, 6, 87, 4, 76, 0, 87, 1,  9, 7,  2, 2, 78, 8, 18, 
    7, 23, 4, 52, 0, 52, 5, 22, 3, 77, 2, 24, 8, 91, 6, 93, 1,  7, 
    1, 73, 5, 49, 6, 11, 2, 90, 4, 26, 7, 24, 8, 19, 3, 28, 0, 54, 
    8, 60, 2, 26, 4, 35, 6,  2, 1, 23, 7, 15, 5, 96, 3, 27, 0, 75, 
    5, 19, 7, 96, 0, 97, 3, 22, 2, 84, 1, 67, 8, 60, 4,  4, 6, 19, 
    6, 40, 5, 88, 4, 46, 3, 60, 8, 20, 0, 41, 1, 56, 7, 43, 2,  1, 
    2, 70, 8, 87, 5, 54, 1, 26, 4, 20, 6, 36, 7, 78, 0, 34, 3, 13, 
    2, 51, 0, 94, 7, 98, 4,  2, 6, 53, 3, 80, 1, 27, 8,  4, 5, 95, 
    6, 84, 4, 11, 7, 62, 1, 34, 8, 99, 2, 59, 3, 46, 0, 79, 5, 30
  };
  const int q6618[] = {
    9, 9, // Number of jobs and machines
    1,  2, 4, 84, 0, 48, 3, 28, 2, 13, 5, 10, 7, 51, 8, 26, 6, 22, 
    5, 63, 6, 62, 1, 40, 0, 78, 2, 52, 3, 87, 8, 61, 4, 53, 7, 70, 
    5, 95, 8, 21, 4,  9, 3, 81, 2, 19, 7, 56, 6, 81, 1, 33, 0,  7, 
    4,  5, 3, 28, 1, 76, 7, 79, 2, 82, 0, 15, 6, 40, 5, 59, 8, 79, 
    2, 33, 3, 77, 4, 10, 5, 84, 6, 85, 8, 86, 0, 43, 7,  6, 1, 73, 
    0, 95, 8, 16, 7, 62, 4,  4, 3, 87, 1, 82, 6, 97, 2, 85, 5,  9, 
    4, 91, 2, 89, 0, 64, 6, 34, 7, 57, 3, 84, 5, 18, 8, 64, 1, 40, 
    5,  1, 1, 27, 7, 80, 4, 43, 8, 80, 2, 88, 0, 85, 6, 86, 3, 38, 
    2, 26, 1,  3, 4, 69, 8, 73, 5, 10, 0, 51, 6, 31, 3, 39, 7, 74
  };
  const int q6619[] = {
    9, 9, // Number of jobs and machines
    3, 27, 8, 30, 2, 93, 5, 37, 0,  9, 7, 74, 6, 92, 1, 97, 4, 79, 
    1, 32, 5, 14, 6, 94, 2, 34, 8, 73, 0, 33, 3,  1, 4, 50, 7, 19, 
    0, 39, 8, 37, 6, 45, 4,  7, 7, 87, 2, 43, 3, 57, 5, 89, 1, 54, 
    5, 50, 2, 29, 6,  5, 7, 56, 1, 69, 4, 47, 3, 45, 8, 73, 0, 40, 
    8, 41, 1, 13, 2, 38, 7, 89, 5, 53, 3, 21, 0, 45, 4, 62, 6, 53, 
    4, 34, 3, 14, 8, 87, 1,  7, 5,  8, 0, 71, 7, 34, 2, 13, 6, 57, 
    0, 53, 6, 86, 2, 56, 5, 12, 4, 40, 1,  2, 8,  6, 7, 99, 3, 10, 
    0, 83, 4, 65, 1,  8, 2, 10, 5, 14, 6, 27, 3, 75, 7, 69, 8, 90, 
    8, 36, 4, 71, 1, 36, 2, 59, 7, 68, 5, 45, 6, 86, 0, 19, 3, 84
  };
  const int q6620[] = {
    9, 9, // Number of jobs and machines
    1, 24, 8, 56, 5, 33, 7, 37, 0, 82, 6, 98, 4, 26, 2, 53, 3, 77, 
    1, 73, 5, 61, 0, 12, 3, 24, 8,  5, 4, 95, 2, 59, 7, 74, 6, 10, 
    2, 54, 3,  3, 5,  5, 1, 58, 6, 65, 4, 76, 8, 77, 7, 51, 0,  1, 
    2, 10, 0, 45, 6, 46, 5, 18, 3, 15, 4, 90, 8, 38, 1, 57, 7, 51, 
    2, 58, 4, 16, 8, 53, 3, 90, 5,  9, 6, 37, 0, 29, 1,  9, 7, 17, 
    0, 79, 5, 39, 4, 23, 6, 33, 3, 16, 7, 82, 8, 55, 1, 38, 2, 82, 
    2, 80, 6, 72, 7, 47, 8, 75, 1, 51, 5, 40, 0, 61, 3, 89, 4, 87, 
    0, 35, 3, 89, 6, 37, 1, 73, 8, 43, 2, 17, 4, 33, 5, 60, 7,  2, 
    5, 32, 2, 43, 7,  1, 6, 32, 1, 81, 4,  9, 0,  6, 8, 17, 3, 29
  };
  const int q6621[] = {
    9, 9, // Number of jobs and machines
    5, 85, 0, 10, 2, 30, 3, 63, 7, 21, 1, 34, 4, 26, 8, 92, 6,  6, 
    0, 83, 3, 33, 7, 51, 4, 51, 1, 77, 8, 25, 2, 93, 5, 37, 6, 50, 
    3, 64, 4,  9, 0,  7, 6, 45, 1, 17, 8, 34, 2, 46, 7, 57, 5, 82, 
    1, 52, 8, 14, 6,  2, 2, 25, 7, 54, 4, 44, 5, 81, 0, 37, 3, 33, 
    2, 30, 3, 73, 7, 88, 8, 41, 1, 53, 4, 84, 0, 34, 5, 70, 6, 65, 
    6, 34, 5, 70, 8, 74, 1, 65, 0, 42, 3, 82, 2, 49, 4, 56, 7, 83, 
    5, 14, 3,  1, 4, 19, 1,  5, 2,  2, 0,  5, 7, 43, 6, 66, 8, 42, 
    4, 69, 0, 20, 7, 43, 6, 63, 3,  8, 5,  9, 2,  8, 1,  1, 8, 46, 
    7, 66, 2, 42, 1, 44, 4, 25, 5, 83, 3, 61, 6, 75, 8, 17, 0, 80
  };
  const int q6622[] = {
    9, 9, // Number of jobs and machines
    0, 92, 5, 76, 2, 72, 1, 14, 6, 69, 3, 83, 4, 42, 8, 84, 7, 37, 
    5, 84, 4, 95, 7,  6, 0, 85, 1, 58, 8, 53, 2, 97, 3, 31, 6,  5, 
    5, 48, 8, 45, 0, 32, 2, 16, 1, 15, 3, 19, 4, 56, 7, 80, 6,  9, 
    4,  5, 8,  7, 5, 79, 3, 36, 0, 83, 6, 36, 1, 74, 2, 36, 7, 51, 
    1, 92, 7, 18, 2, 98, 4,  8, 3, 41, 6, 12, 0, 52, 5, 56, 8, 53, 
    0,  5, 2, 80, 6, 55, 3, 31, 8, 57, 7, 92, 5, 89, 4, 48, 1, 92, 
    3, 78, 0, 42, 2, 96, 5, 12, 1, 25, 6, 50, 7, 84, 4, 28, 8, 23, 
    3, 61, 1, 79, 0, 68, 2,  9, 7, 56, 8, 16, 5, 10, 6, 99, 4, 28, 
    7, 93, 2,  4, 6, 70, 3,  3, 8, 85, 1, 56, 0, 97, 5, 69, 4, 89
  };
  const int q6623[] = {
    9, 9, // Number of jobs and machines
    2, 52, 1, 70, 5, 12, 0, 82, 7,  3, 4, 17, 3, 42, 8, 48, 6, 43, 
    7, 27, 3, 56, 4, 43, 0, 67, 2, 89, 6, 38, 8, 48, 5, 91, 1, 25, 
    8,  1, 2,  6, 0, 28, 7, 25, 5, 15, 6, 23, 3, 49, 4, 98, 1,  7, 
    3,  2, 1,  6, 7, 80, 5, 19, 0, 60, 4, 57, 6, 25, 8, 20, 2,  1, 
    4, 31, 7, 26, 3, 94, 1,  4, 8, 20, 2, 88, 0, 22, 6, 64, 5, 54, 
    1, 87, 4, 93, 2, 32, 8, 60, 5,  1, 6, 82, 0, 90, 3, 77, 7, 69, 
    4, 92, 1, 51, 3, 22, 8, 29, 7, 80, 2, 22, 6, 13, 5, 11, 0, 11, 
    6, 84, 5, 77, 3, 84, 1, 27, 0,  7, 7, 77, 4, 57, 8, 96, 2, 19, 
    6, 33, 4,  5, 2, 70, 8, 78, 7, 55, 1, 63, 3, 48, 0, 59, 5, 58
  };
  const int q6624[] = {
    9, 9, // Number of jobs and machines
    6, 27, 1, 92, 8, 44, 3, 55, 2, 95, 4, 84, 0, 79, 7,  9, 5, 86, 
    8, 78, 4, 88, 2, 66, 6, 60, 5, 89, 0, 70, 3, 63, 7, 92, 1, 48, 
    3, 33, 0, 68, 1, 16, 6, 30, 5, 27, 7, 17, 2, 38, 4, 94, 8, 54, 
    0,  4, 4, 73, 6, 47, 1, 11, 2, 84, 5, 92, 8, 48, 3, 25, 7, 99, 
    6, 90, 3, 82, 0, 86, 5, 18, 2, 89, 8, 79, 7, 30, 4, 58, 1, 51, 
    5, 37, 1, 45, 7, 45, 3, 24, 0, 84, 8, 61, 2, 88, 4, 32, 6, 33, 
    3, 88, 2, 12, 6, 96, 5, 58, 1, 82, 4, 64, 0, 12, 8, 99, 7, 28, 
    7, 90, 2, 57, 3, 78, 8, 79, 4, 98, 1, 72, 6, 85, 5, 19, 0, 89, 
    4, 75, 6, 49, 3, 35, 0, 91, 2, 54, 5,  5, 8, 41, 7, 38, 1, 53
  };
  const int q6625[] = {
    9, 9, // Number of jobs and machines
    3, 96, 8, 57, 6,  3, 2, 82, 4, 70, 1, 30, 0,  4, 7, 56, 5, 84, 
    1, 98, 4, 53, 7, 18, 0, 12, 6, 61, 8, 31, 2, 24, 3, 73, 5, 15, 
    5, 90, 6,  1, 1, 72, 3, 38, 2, 68, 7, 77, 4, 49, 8,  3, 0, 33, 
    1, 60, 0, 95, 8, 38, 6, 83, 2, 97, 5, 48, 4,  9, 7, 67, 3, 18, 
    1, 58, 2, 60, 0, 41, 7, 98, 5, 14, 3, 47, 4, 23, 8, 74, 6, 36, 
    3, 67, 7, 37, 6, 38, 0,  8, 4, 29, 8, 10, 5,  5, 2, 70, 1, 65, 
    4,  4, 6, 64, 8, 35, 7, 36, 3, 45, 1, 66, 5, 93, 0, 30, 2, 30, 
    0, 68, 8, 87, 5, 57, 1, 77, 4, 21, 7, 35, 2, 72, 6, 24, 3, 80, 
    8, 32, 1, 24, 7, 96, 5, 14, 0, 49, 6, 77, 4, 10, 3, 57, 2,  6
  };
  const int q6626[] = {
    9, 9, // Number of jobs and machines
    4, 83, 8, 22, 5, 31, 6, 82, 0, 95, 1, 87, 2,  8, 7,  8, 3, 33, 
    8, 17, 7, 34, 1, 91, 0,  4, 5, 51, 4, 95, 3, 90, 6, 75, 2, 76, 
    7, 95, 2, 29, 0, 56, 3,  5, 4, 92, 6, 38, 5, 54, 8, 13, 1, 29, 
    0,  1, 6, 85, 1, 16, 4, 75, 7,  4, 8, 87, 5, 49, 3, 66, 2, 31, 
    6,  7, 4, 28, 1, 13, 7, 45, 8, 19, 2, 68, 0, 74, 3, 45, 5, 15, 
    5,  1, 2, 51, 8, 85, 0, 77, 6, 74, 1, 89, 4, 80, 7, 89, 3, 55, 
    4, 85, 5, 87, 7, 25, 3, 86, 0, 58, 6,  1, 1, 34, 2, 69, 8, 13, 
    3, 39, 8, 18, 0, 92, 2, 43, 4, 65, 5, 21, 1, 31, 6, 87, 7,  5, 
    3, 50, 6, 80, 7, 26, 8, 77, 2, 25, 1,  6, 4, 35, 0, 76, 5, 78
  };
  const int q6627[] = {
    9, 9, // Number of jobs and machines
    1, 13, 6, 95, 5, 15, 0, 78, 7, 59, 2, 48, 4, 33, 3, 73, 8, 74, 
    0, 57, 6, 57, 4, 18, 2, 73, 8, 39, 7, 56, 5, 76, 1, 79, 3, 55, 
    6, 88, 3, 19, 4,  8, 7, 23, 2, 34, 5, 22, 0, 68, 8, 97, 1, 67, 
    1, 15, 3, 73, 7,  2, 6, 91, 2,  9, 4, 83, 0, 64, 5, 99, 8, 12, 
    0, 83, 1, 77, 2, 67, 8, 80, 7, 78, 5, 31, 6, 44, 3,  7, 4, 63, 
    7, 45, 8, 89, 2, 24, 3, 21, 0, 57, 1, 69, 5, 96, 4, 54, 6, 29, 
    6, 41, 2, 82, 8, 97, 3, 31, 7, 79, 1, 78, 0, 36, 4, 77, 5, 20, 
    6, 39, 8, 64, 5, 46, 2, 60, 7, 66, 4, 68, 3, 82, 0, 66, 1, 97, 
    2, 93, 6, 83, 1, 99, 5,  1, 3, 21, 4,  3, 0, 46, 7, 76, 8, 95
  };
  const int q6628[] = {
    9, 9, // Number of jobs and machines
    1, 28, 5, 38, 7, 87, 6, 36, 8, 61, 4, 42, 3, 34, 2, 79, 0, 37, 
    3, 88, 7, 79, 2, 89, 0, 28, 8, 58, 4, 77, 5, 20, 1, 81, 6, 21, 
    2, 64, 5, 61, 4, 67, 3, 88, 7, 57, 8, 79, 1, 83, 6, 17, 0, 71, 
    7,  3, 8, 39, 4, 30, 5, 42, 2, 79, 1, 11, 6, 57, 3,  1, 0, 70, 
    3, 32, 8, 50, 6, 16, 0, 77, 5, 36, 4, 37, 1, 67, 7, 72, 2, 90, 
    0, 87, 3, 83, 2, 79, 5, 26, 8, 65, 1, 53, 4, 82, 6, 69, 7, 48, 
    2, 85, 6, 87, 1, 29, 5, 31, 3, 97, 7, 58, 8, 60, 0, 62, 4, 27, 
    8, 53, 7, 90, 3, 41, 4,  7, 2, 84, 0, 45, 6, 43, 5, 80, 1, 57, 
    4, 13, 5, 61, 7, 22, 0, 28, 8, 86, 2, 73, 6,  7, 3, 33, 1,  9
  };
  const int q6629[] = {
    9, 9, // Number of jobs and machines
    5, 27, 8, 29, 6, 49, 1, 54, 0, 74, 2, 85, 3, 48, 7, 85, 4, 40, 
    8, 29, 4, 59, 1, 76, 7, 71, 6, 31, 3, 17, 0, 35, 2, 11, 5, 88, 
    0, 39, 4, 93, 2, 65, 8, 86, 1, 24, 6, 44, 7, 85, 5,  7, 3, 80, 
    6,  4, 8, 24, 4, 49, 7, 80, 0, 85, 5, 87, 2, 65, 1, 85, 3, 25, 
    8, 63, 5, 42, 3, 43, 6, 29, 1, 31, 7, 96, 0, 29, 4, 17, 2, 96, 
    4, 15, 6, 21, 8, 33, 2, 10, 0, 36, 1,  5, 5, 93, 7, 53, 3, 21, 
    3, 72, 1, 36, 2, 71, 5, 82, 6, 12, 0, 50, 4, 55, 7, 23, 8,  2, 
    2, 98, 5, 56, 7, 66, 8,  9, 1, 74, 0, 64, 3, 68, 6,  1, 4, 60, 
    1, 87, 2, 40, 4, 52, 8, 98, 7, 95, 0, 46, 6,  3, 3, 94, 5, 78
  };
  const int q6630[] = {
    9, 9, // Number of jobs and machines
    3, 65, 6, 99, 2, 96, 0, 88, 5, 68, 1, 57, 7, 76, 4, 31, 8, 42, 
    1, 60, 2, 36, 3, 90, 5, 61, 4,  3, 7, 65, 8, 68, 0, 34, 6, 45, 
    7, 63, 1, 37, 8, 34, 0, 23, 2, 97, 5, 93, 3, 42, 4, 63, 6, 56, 
    5, 91, 3, 83, 2, 86, 0, 58, 8, 13, 4, 27, 1, 42, 6, 71, 7, 29, 
    7,  4, 4, 59, 3, 34, 5, 42, 8, 85, 0, 17, 1, 67, 6, 48, 2, 10, 
    7, 14, 0, 94, 2, 45, 8,  4, 5, 97, 1, 24, 3, 70, 4, 44, 6, 81, 
    7, 36, 5, 57, 8, 56, 3, 81, 2, 94, 6, 56, 1, 69, 0, 45, 4, 48, 
    1, 28, 7, 28, 0, 57, 6, 22, 3, 56, 8, 95, 4, 69, 5, 89, 2, 42, 
    0, 73, 3, 36, 2, 67, 1, 15, 7, 60, 4, 68, 6, 94, 8, 15, 5, 98
  };
  const int q6631[] = {
    9, 9, // Number of jobs and machines
    1, 60, 0, 10, 2, 91, 8, 78, 3, 13, 5, 80, 7, 38, 4, 13, 6, 37, 
    6, 77, 8, 68, 0, 74, 1, 69, 2,  9, 4, 67, 7,  7, 5, 25, 3, 96, 
    1, 11, 7, 57, 0, 83, 2, 64, 6, 14, 3, 78, 5, 35, 8, 35, 4, 65, 
    2, 66, 7, 38, 1, 18, 0, 90, 3, 29, 5, 83, 4, 64, 6, 41, 8, 19, 
    7, 79, 0,  8, 5, 82, 6, 77, 4, 48, 2, 57, 8, 62, 3, 71, 1, 45, 
    5, 84, 4, 56, 6, 34, 3, 83, 8, 82, 2, 75, 7, 56, 1, 66, 0, 69, 
    5, 56, 1, 95, 6, 31, 3, 64, 2, 18, 0, 35, 7, 22, 8, 78, 4, 89, 
    4, 72, 6, 18, 0, 88, 5,  8, 1, 89, 3, 75, 7, 54, 2, 55, 8, 80, 
    1, 12, 4,  8, 7,  9, 5, 52, 6, 78, 2, 63, 3, 86, 8, 95, 0, 42
  };
  const int q6632[] = {
    9, 9, // Number of jobs and machines
    7, 90, 5, 40, 4, 93, 1, 28, 0, 85, 2, 30, 3, 89, 8, 44, 6, 86, 
    6, 19, 3, 95, 4, 14, 5, 60, 8, 60, 1, 19, 0, 88, 2, 82, 7, 75, 
    0, 90, 8,  5, 5, 40, 6,  6, 3, 93, 1, 18, 4, 30, 7, 18, 2, 86, 
    8, 83, 0,  7, 2, 29, 6, 36, 7, 35, 1, 28, 4, 93, 3, 29, 5, 29, 
    2, 11, 5, 68, 8, 60, 0, 54, 1, 54, 6, 19, 7, 34, 4,  4, 3, 33, 
    6, 15, 0, 47, 4,  8, 1,  5, 3,  5, 7, 13, 8, 34, 2, 37, 5, 60, 
    6, 93, 3, 23, 8, 40, 4, 10, 7, 50, 1, 87, 2, 48, 5, 23, 0, 80, 
    8, 13, 2, 42, 6, 26, 3, 27, 1, 30, 4,  9, 5, 96, 0, 35, 7, 86, 
    3, 69, 5, 29, 6, 30, 0, 48, 8, 69, 7, 86, 4, 47, 1, 17, 2, 54
  };
  const int q6633[] = {
    9, 9, // Number of jobs and machines
    0,  4, 4, 80, 2, 45, 1, 11, 5, 10, 3,  1, 7, 78, 6, 96, 8, 18, 
    7, 91, 0, 91, 8, 19, 3, 70, 5, 66, 6, 95, 1, 74, 4,  8, 2, 12, 
    3, 22, 1,  1, 5, 34, 4, 47, 0, 45, 2,  4, 8, 24, 7, 62, 6, 64, 
    3,  6, 0, 98, 2, 34, 4, 11, 8,  1, 1,  9, 6, 50, 5, 39, 7, 32, 
    0, 74, 8, 85, 4, 10, 2, 81, 3, 16, 7, 57, 1, 38, 6, 64, 5, 53, 
    4,  5, 6,  5, 0, 87, 5, 84, 8, 51, 1, 32, 3, 56, 7, 42, 2, 35, 
    0, 81, 2, 37, 4, 22, 5, 69, 8, 13, 6,  7, 7, 16, 1, 92, 3,  1, 
    1, 39, 8, 34, 7, 15, 6, 23, 5, 68, 2, 17, 4, 38, 0, 19, 3, 17, 
    6, 46, 0, 55, 7, 64, 8, 69, 2, 28, 3, 66, 4, 96, 5, 23, 1, 38
  };
  const int q6634[] = {
    9, 9, // Number of jobs and machines
    7, 97, 4, 71, 5, 73, 6,  3, 8, 30, 0, 79, 3, 90, 2, 51, 1,  3, 
    6,  7, 1, 38, 2, 35, 5, 74, 3, 81, 0, 63, 8, 50, 7, 37, 4, 68, 
    2, 69, 0, 19, 7, 56, 5, 91, 8, 94, 1, 52, 3, 92, 6, 29, 4, 60, 
    0, 31, 2, 82, 6, 42, 8, 12, 7, 97, 3, 70, 1, 73, 5, 71, 4, 86, 
    0,  4, 3, 36, 4, 67, 1,  3, 2, 65, 7, 94, 8, 22, 6, 97, 5, 56, 
    6, 86, 8, 95, 2, 35, 4, 27, 5, 12, 3, 37, 1, 98, 7, 67, 0, 22, 
    4,  1, 7, 22, 2, 44, 1, 59, 6, 50, 0, 31, 5, 23, 8,  9, 3, 87, 
    3, 26, 6, 37, 4, 99, 7, 43, 5, 94, 1, 21, 0, 37, 2, 30, 8, 19, 
    6, 93, 0, 30, 8, 90, 3, 99, 7, 87, 2, 58, 5,  9, 4, 97, 1, 34
  };
  const int q6635[] = {
    9, 9, // Number of jobs and machines
    1, 71, 2,  9, 7,  6, 6,  1, 8, 45, 5, 49, 4, 81, 3, 84, 0, 96, 
    2, 41, 8, 76, 4, 60, 5, 60, 0, 16, 6, 62, 3,  8, 7, 40, 1, 73, 
    0,  9, 3, 65, 4, 92, 7,  4, 8, 38, 1, 39, 2, 50, 5, 13, 6, 33, 
    7, 13, 1, 10, 0, 82, 2, 37, 4, 86, 6, 81, 3, 24, 8, 62, 5,  4, 
    1, 63, 0, 53, 4, 40, 6, 85, 7, 14, 3, 78, 5, 80, 2, 95, 8,  7, 
    7, 89, 0, 84, 1, 44, 4, 86, 5, 86, 3, 66, 2, 51, 6, 27, 8, 84, 
    5, 30, 6, 88, 7, 54, 1,  9, 2, 30, 4, 94, 8, 39, 0, 40, 3, 16, 
    8,  4, 3, 44, 4, 16, 5, 86, 6, 38, 1, 91, 7,  1, 2, 38, 0, 41, 
    5, 50, 7, 88, 8, 31, 6, 70, 3, 35, 0, 24, 1, 27, 4, 60, 2, 33
  };
  const int q6636[] = {
    9, 9, // Number of jobs and machines
    8, 34, 6, 52, 0, 48, 3, 84, 1, 89, 7, 88, 4, 16, 2, 30, 5, 79, 
    2, 57, 0, 10, 1, 66, 6, 14, 4, 73, 5, 66, 8, 56, 7, 68, 3, 21, 
    3, 13, 1, 30, 0, 54, 7, 89, 4, 60, 8, 85, 2, 58, 5, 99, 6, 50, 
    5, 55, 4,  2, 6, 42, 1, 43, 2, 40, 8, 32, 7, 22, 3, 48, 0, 47, 
    3, 78, 0, 10, 4, 10, 8, 38, 7, 47, 5,  9, 6, 71, 2, 70, 1, 99, 
    5, 82, 6, 69, 1, 85, 4, 16, 3, 61, 8, 11, 2, 16, 7, 50, 0, 63, 
    6, 12, 3, 94, 8,  9, 0, 29, 1, 77, 5,  2, 2, 24, 4, 66, 7,  5, 
    5, 55, 4, 64, 2, 31, 3,  5, 7, 12, 6,  2, 1, 29, 0, 59, 8, 62, 
    0, 82, 8, 60, 3, 18, 2, 41, 4, 58, 5, 43, 1, 11, 7, 28, 6, 45
  };
  const int q6637[] = {
    9, 9, // Number of jobs and machines
    3, 24, 1, 14, 2, 35, 4, 22, 0,  8, 6, 44, 5, 53, 7,  7, 8, 86, 
    8, 81, 7, 13, 6, 44, 1, 11, 2, 23, 0, 59, 3, 98, 4, 38, 5, 71, 
    2, 26, 1, 67, 3, 37, 6, 46, 7, 20, 5, 16, 4, 31, 8, 84, 0, 79, 
    0, 10, 2, 13, 6, 57, 8, 86, 7,  1, 1, 58, 4, 63, 3, 69, 5,  6, 
    5, 35, 1, 73, 7, 21, 8, 44, 4, 95, 6, 85, 0, 12, 3, 33, 2, 91, 
    2, 78, 5,  5, 8, 60, 4, 47, 7, 44, 1, 49, 0,  5, 3, 99, 6, 89, 
    8, 75, 3, 59, 7, 84, 2, 28, 0, 55, 1, 21, 5, 98, 6, 50, 4, 72, 
    1, 47, 8,  4, 2, 92, 5, 39, 6, 76, 4, 16, 0, 94, 7, 55, 3, 45, 
    8, 76, 4, 60, 2, 38, 7, 75, 1, 59, 5, 32, 3, 28, 6, 85, 0, 90
  };
  const int q6638[] = {
    9, 9, // Number of jobs and machines
    8, 72, 7, 92, 0, 76, 2, 86, 5, 91, 4, 90, 6, 21, 3, 93, 1, 43, 
    0, 43, 2,  6, 3, 47, 4,  1, 6, 95, 8, 13, 5, 95, 1, 95, 7, 32, 
    8, 44, 2,  4, 7, 23, 3, 40, 6,  6, 0, 40, 4, 47, 1, 79, 5, 77, 
    1, 52, 5, 27, 7, 80, 0, 42, 8, 30, 3, 77, 6, 16, 4, 87, 2, 51, 
    3, 86, 2, 17, 5,  3, 4, 72, 0, 18, 1, 93, 8, 51, 6, 62, 7, 69, 
    6, 57, 1, 97, 0, 82, 7, 66, 5,  6, 3, 33, 2, 88, 4, 32, 8, 61, 
    3, 24, 5, 21, 1, 52, 4, 89, 6, 32, 0, 35, 8, 46, 7, 11, 2, 47, 
    3, 14, 0, 90, 1, 60, 4, 89, 8, 28, 5, 98, 6,  4, 2, 65, 7,  1, 
    5,  9, 4, 31, 0, 12, 7, 50, 6, 54, 3, 83, 1, 91, 8, 19, 2, 27
  };
  const int q6639[] = {
    9, 9, // Number of jobs and machines
    3, 33, 1, 49, 4, 18, 2, 27, 0, 51, 6, 26, 8, 74, 5, 74, 7, 70, 
    3, 50, 6, 81, 4, 35, 2, 37, 1,  9, 5, 11, 0, 29, 8, 98, 7, 60, 
    6, 26, 4, 91, 5, 61, 0, 71, 2, 78, 8, 37, 1, 10, 7, 38, 3, 81, 
    8, 75, 6, 26, 5, 14, 4, 44, 0, 42, 1, 36, 7, 18, 2, 99, 3, 57, 
    3, 80, 8, 71, 0, 24, 5, 11, 1, 66, 2, 83, 7, 40, 4, 66, 6, 11, 
    4, 74, 5, 33, 0, 60, 1, 94, 2, 54, 3, 23, 8, 30, 7, 22, 6, 87, 
    1, 88, 0, 23, 5,  4, 2, 48, 7, 55, 6, 80, 4, 96, 3, 66, 8, 76, 
    6, 90, 7, 13, 4, 15, 1, 43, 8, 62, 3,  7, 0, 55, 2, 19, 5, 26, 
    1, 44, 6, 56, 0,  1, 7, 70, 8, 29, 4, 37, 5, 14, 2, 32, 3, 80
  };
  const int q6640[] = {
    9, 9, // Number of jobs and machines
    4, 25, 2, 40, 6, 79, 7, 54, 0,  6, 3, 82, 5, 52, 8, 93, 1, 52, 
    5, 98, 7, 73, 2, 71, 0, 64, 8, 13, 4, 21, 1, 84, 6, 22, 3, 13, 
    2, 37, 8, 73, 6, 64, 4, 55, 7, 37, 1, 57, 0, 44, 3, 30, 5, 93, 
    5, 18, 3, 47, 2, 54, 1, 62, 8, 19, 7, 35, 4, 97, 6, 94, 0, 32, 
    3, 83, 2, 55, 6, 61, 0, 10, 8, 69, 1, 67, 5, 43, 7, 82, 4, 20, 
    6, 13, 7, 98, 0, 27, 2, 94, 5, 22, 1,  8, 4, 88, 8, 51, 3, 49, 
    5, 46, 0, 78, 6, 70, 8, 96, 2, 15, 4, 48, 1, 34, 7, 96, 3, 11, 
    0, 57, 7, 29, 1, 47, 2,  8, 6, 69, 3, 49, 5, 81, 8, 45, 4, 34, 
    0, 80, 3, 97, 5, 44, 4, 37, 2, 67, 1, 62, 7, 64, 8, 18, 6, 74
  };
  const int q6641[] = {
    9, 9, // Number of jobs and machines
    4,  2, 0, 88, 3, 67, 6, 72, 2, 11, 1, 85, 5,  1, 7, 93, 8, 25, 
    5, 36, 0, 70, 2, 85, 8, 94, 3, 18, 1,  6, 6, 49, 7, 95, 4, 72, 
    5, 66, 8, 56, 3, 35, 1, 67, 0, 17, 7, 60, 4, 55, 2, 61, 6, 96, 
    1, 10, 4, 20, 6, 96, 0, 79, 5, 53, 8, 92, 2, 34, 7, 76, 3, 85, 
    3, 47, 0, 49, 8, 29, 4, 68, 5, 36, 1, 67, 2, 27, 6, 26, 7, 40, 
    2, 68, 3, 70, 8, 90, 6, 40, 7, 72, 5, 15, 1, 79, 0, 32, 4, 96, 
    3, 65, 0, 67, 8, 23, 6, 76, 7, 38, 4, 61, 1, 95, 5, 48, 2, 77, 
    8, 62, 6, 76, 4, 21, 1, 13, 3, 94, 0, 84, 5, 81, 7, 12, 2, 36, 
    8,  2, 2, 43, 1,  8, 4, 34, 6, 76, 0, 10, 7, 26, 3, 75, 5, 96
  };
  const int q6642[] = {
    9, 9, // Number of jobs and machines
    0, 74, 5, 35, 3, 10, 4, 26, 7, 81, 2, 23, 8, 24, 1, 86, 6, 36, 
    7, 69, 4, 71, 8, 60, 1, 73, 5, 25, 3, 86, 0, 68, 6,  3, 2, 63, 
    4, 21, 2, 47, 1,  8, 8, 16, 7, 25, 5, 14, 0, 59, 6, 96, 3,  7, 
    0, 45, 4, 33, 3, 54, 7, 45, 5, 95, 8, 59, 6, 20, 1, 27, 2, 63, 
    2, 13, 7, 78, 0, 56, 5, 39, 4, 79, 3, 87, 6, 43, 8, 80, 1, 79, 
    6, 58, 0,  3, 4, 55, 7, 57, 5, 54, 8, 14, 2, 34, 3, 32, 1,  7, 
    6, 48, 0, 79, 3, 97, 5, 23, 2, 51, 8, 16, 1, 32, 4, 10, 7, 95, 
    8, 34, 5, 75, 7, 72, 1, 70, 6, 65, 2, 93, 0, 14, 3, 65, 4, 62, 
    7, 76, 4, 13, 6, 51, 2, 89, 3, 40, 5, 93, 1, 10, 0, 49, 8,  5
  };
  const int q6643[] = {
    9, 9, // Number of jobs and machines
    8, 78, 2, 39, 5, 20, 7, 59, 1, 99, 3, 16, 4, 24, 6, 11, 0,  5, 
    3, 61, 7, 88, 2, 36, 4, 48, 5, 52, 0, 26, 8, 53, 6, 92, 1, 87, 
    8, 74, 4, 58, 6,  7, 5, 33, 2, 33, 0, 77, 7, 47, 3, 25, 1, 30, 
    8, 75, 3,  8, 2,  6, 5, 87, 0, 84, 4,  1, 6, 86, 7, 79, 1, 63, 
    4, 89, 7, 82, 0,  3, 6, 86, 8,  6, 2, 50, 3, 79, 5, 10, 1, 98, 
    1, 24, 6, 13, 0, 34, 5, 62, 8, 77, 3, 47, 4, 81, 7, 66, 2, 41, 
    3, 21, 4, 14, 2, 13, 0, 38, 6, 46, 8, 38, 5, 54, 7,  2, 1, 50, 
    8, 93, 2,  3, 7, 84, 5, 54, 1, 28, 6, 48, 4, 78, 3, 72, 0, 14, 
    8, 24, 0, 98, 6, 58, 3, 73, 4, 49, 2, 98, 1,  7, 7, 49, 5, 33
  };
  const int q6644[] = {
    9, 9, // Number of jobs and machines
    0, 63, 1, 99, 5, 40, 8, 74, 3, 17, 2,  4, 4, 65, 6, 87, 7, 31, 
    8, 69, 3, 19, 4, 85, 0, 36, 1,  3, 5, 39, 7, 12, 2, 25, 6, 59, 
    8,  5, 1, 79, 7, 28, 6, 71, 3, 91, 0, 52, 2, 74, 4, 19, 5, 80, 
    1, 98, 4, 96, 3, 21, 5,  8, 7, 19, 6, 81, 0, 10, 2, 10, 8, 62, 
    2, 64, 8, 97, 1, 82, 0, 46, 5, 65, 3, 54, 4, 80, 6, 81, 7, 59, 
    6,  9, 2, 12, 3, 73, 1, 27, 0, 45, 5, 21, 8, 57, 4, 94, 7, 59, 
    3, 10, 2, 98, 7, 84, 8, 68, 5,  3, 4, 13, 6, 21, 0, 24, 1, 66, 
    0, 90, 7, 68, 2, 66, 4, 12, 6, 94, 5,  4, 8, 46, 1, 57, 3, 23, 
    2, 46, 3, 84, 8, 85, 0, 56, 5, 54, 7, 47, 4, 37, 6, 26, 1, 83
  };
  const int q6645[] = {
    9, 9, // Number of jobs and machines
    1, 93, 0, 13, 6, 32, 8, 25, 2, 72, 5, 74, 7, 75, 4, 30, 3, 28, 
    4, 70, 7, 43, 5, 44, 2, 49, 3, 48, 8, 68, 0, 47, 1, 85, 6, 61, 
    8,  9, 0, 65, 2, 35, 5, 27, 7, 24, 6, 41, 3,  1, 4,  2, 1, 77, 
    1, 59, 4, 58, 7, 31, 2, 85, 5, 99, 3, 21, 0, 45, 6,  1, 8,  8, 
    8, 10, 7, 29, 5, 63, 0, 13, 6, 78, 3, 13, 2, 75, 1, 24, 4, 28, 
    5, 52, 4, 40, 7, 40, 8, 80, 3, 22, 6, 26, 0, 83, 2, 32, 1, 74, 
    2, 21, 8, 37, 6, 70, 1, 20, 0, 87, 3, 55, 7, 22, 5, 32, 4, 99, 
    1, 61, 3, 23, 4, 64, 6, 68, 8, 87, 2, 90, 0, 63, 5, 12, 7, 11, 
    4, 71, 2, 78, 8, 28, 0, 23, 7, 61, 3, 10, 6, 24, 1, 73, 5, 28
  };
  const int q6646[] = {
    9, 9, // Number of jobs and machines
    6,  3, 0, 91, 7, 39, 8, 64, 1, 12, 2,  8, 3, 96, 5, 93, 4, 98, 
    5,  9, 1, 48, 3,  3, 4, 41, 8, 21, 6, 38, 7,  6, 0,  2, 2, 91, 
    6, 80, 1,  7, 8, 12, 7, 13, 4, 68, 3, 94, 5, 12, 0, 57, 2, 22, 
    0, 51, 6, 90, 1, 74, 7, 12, 3, 16, 2, 37, 5, 84, 8, 72, 4, 77, 
    4, 91, 8, 59, 5, 13, 2, 42, 6, 23, 7, 90, 3, 72, 0, 87, 1, 51, 
    5, 94, 4, 44, 7, 29, 2, 21, 6, 53, 3, 57, 1, 75, 0, 53, 8, 87, 
    2, 71, 8, 32, 6, 32, 0, 89, 1, 33, 4,  2, 7, 48, 5, 37, 3, 98, 
    7, 55, 8, 32, 4, 27, 0, 65, 2, 48, 1, 22, 6, 59, 3, 44, 5, 32, 
    1, 65, 2, 10, 7, 90, 3,  3, 6, 72, 0, 37, 5,  5, 8, 93, 4, 14
  };
  const int q6647[] = {
    9, 9, // Number of jobs and machines
    2,  5, 5, 97, 3, 43, 1, 26, 8, 80, 0, 98, 7,  9, 6,  4, 4, 80, 
    8, 62, 7, 53, 1,  2, 2, 28, 0, 65, 6, 35, 5,  2, 4, 60, 3, 10, 
    5,  4, 3,  6, 7, 44, 0,  4, 8, 81, 2, 84, 4, 94, 1, 75, 6, 41, 
    6, 83, 5, 61, 0, 24, 8, 47, 3, 19, 2, 70, 1, 97, 7, 56, 4, 66, 
    4, 93, 8, 48, 2, 39, 5, 37, 0, 97, 6, 71, 1, 10, 7, 56, 3, 13, 
    2, 18, 4, 17, 7,  9, 6, 36, 5, 51, 3, 38, 8, 89, 0, 35, 1, 63, 
    6, 80, 8, 40, 0, 92, 3, 47, 1, 72, 5, 93, 4, 94, 7, 20, 2, 31, 
    2, 21, 6, 88, 1, 81, 7, 25, 4, 83, 3, 40, 8, 39, 0, 34, 5, 57, 
    8,  8, 7, 94, 0, 92, 1, 72, 4, 18, 3, 82, 5, 90, 2, 63, 6, 31
  };
  const int q6648[] = {
    9, 9, // Number of jobs and machines
    2, 12, 7, 94, 8, 69, 5, 79, 6, 50, 0, 21, 3,  5, 1, 76, 4, 33, 
    3,  8, 4, 44, 1, 34, 6, 78, 5, 17, 2,  8, 0,  8, 8, 83, 7, 52, 
    1, 71, 2, 80, 6, 55, 3, 25, 8, 21, 4, 87, 5, 93, 0, 79, 7,  7, 
    8, 74, 2, 30, 4, 96, 1, 58, 3, 47, 0, 50, 7, 30, 5, 91, 6,  2, 
    7, 57, 0, 78, 6, 22, 2, 72, 5, 17, 4, 14, 1, 59, 8, 18, 3, 75, 
    6, 21, 2, 75, 3, 95, 0, 99, 8, 77, 1, 46, 4, 17, 7,  1, 5, 60, 
    6, 94, 7, 11, 0, 10, 4, 17, 2, 99, 1, 87, 3, 82, 5, 54, 8, 46, 
    2, 30, 5,  9, 7, 55, 0, 60, 8, 99, 1,  4, 3, 80, 6, 64, 4, 15, 
    2, 91, 8, 76, 5, 85, 3, 11, 6, 55, 4, 27, 1, 26, 7, 11, 0, 77
  };
  const int q6649[] = {
    9, 9, // Number of jobs and machines
    0, 57, 8, 15, 2,  5, 7, 43, 3, 15, 4, 99, 1, 48, 6,  5, 5, 85, 
    5, 99, 7, 49, 8, 19, 2,  6, 0, 86, 4, 98, 6, 87, 1, 36, 3, 10, 
    0, 58, 6, 20, 7, 91, 3, 84, 1, 85, 5, 80, 2, 82, 8, 91, 4, 48, 
    5, 77, 7,  7, 2, 47, 3, 11, 6, 68, 0, 94, 1, 71, 8,  5, 4, 24, 
    1, 86, 3, 88, 0, 85, 4, 78, 8, 88, 5, 56, 7, 70, 6, 76, 2, 52, 
    4, 27, 6,  4, 7,  2, 0, 28, 1, 95, 5, 93, 8,  7, 3, 49, 2, 16, 
    1, 88, 6, 32, 8, 51, 3, 30, 0, 11, 2, 53, 5, 33, 4, 65, 7, 71, 
    6, 99, 0, 78, 2, 19, 4, 31, 1, 49, 7, 43, 8, 33, 5,  6, 3, 84, 
    6, 54, 4, 39, 7,  6, 8, 24, 3, 96, 2, 69, 1, 89, 0, 41, 5, 34
  };
  const int q6650[] = {
    9, 9, // Number of jobs and machines
    8, 99, 6,  4, 3, 54, 0, 56, 1, 60, 4,  9, 7, 51, 2, 99, 5, 47, 
    0, 14, 5, 13, 7, 49, 2, 30, 1, 26, 4, 99, 8, 26, 6, 86, 3, 94, 
    8, 59, 4,  6, 3, 20, 7, 15, 5, 43, 6, 20, 2,  6, 1, 36, 0, 70, 
    6, 18, 3, 49, 4, 76, 5, 19, 2,  6, 0, 94, 7, 52, 8, 10, 1, 68, 
    3,  6, 8, 33, 1, 56, 0, 60, 2, 31, 5, 55, 4, 58, 7, 30, 6, 80, 
    5, 92, 6, 26, 8, 42, 2, 52, 3, 88, 7, 13, 1, 49, 4,  6, 0, 43, 
    4, 50, 6,  4, 0, 32, 2, 35, 1, 38, 7, 89, 5, 37, 3, 34, 8, 28, 
    2, 32, 7, 98, 0, 66, 6, 79, 5, 56, 4, 55, 8, 69, 3, 84, 1, 66, 
    0, 45, 5,  5, 4, 50, 1, 93, 8, 10, 2, 96, 6, 98, 7, 31, 3, 22
  };
  const int q6651[] = {
    9, 9, // Number of jobs and machines
    6, 77, 3, 35, 2, 95, 4, 46, 7, 31, 1, 25, 8, 33, 0, 38, 5, 93, 
    2, 13, 7, 29, 3, 46, 8,  3, 5, 45, 4, 45, 1, 41, 0, 17, 6, 32, 
    7, 99, 4, 12, 0, 47, 2, 61, 1, 93, 8, 33, 6,  6, 5, 14, 3, 21, 
    8, 86, 7, 19, 3, 24, 1, 43, 5, 66, 6, 42, 0, 63, 2, 19, 4, 15, 
    5, 43, 7, 46, 3,  4, 1, 45, 6, 67, 4, 48, 2, 69, 0, 60, 8, 73, 
    1, 68, 7, 81, 3, 40, 5, 70, 2, 84, 8, 88, 0, 49, 4, 81, 6, 13, 
    7, 18, 3, 66, 6, 80, 5, 77, 8, 89, 0, 74, 1, 52, 2, 36, 4, 54, 
    5, 65, 4, 23, 1, 81, 8, 77, 7, 74, 2, 74, 0,  5, 3, 74, 6, 21, 
    5, 99, 8, 84, 4, 83, 1, 53, 0, 82, 7, 13, 2,  6, 3, 25, 6, 91
  };
  const int q6652[] = {
    9, 9, // Number of jobs and machines
    4,  3, 2, 62, 7, 29, 5, 50, 6, 79, 1, 17, 3, 90, 0, 64, 8, 79, 
    2, 57, 3, 66, 5, 55, 0, 53, 1, 17, 4, 32, 8, 15, 6, 82, 7, 99, 
    7, 54, 5, 82, 8, 91, 4, 69, 2,  9, 1, 76, 6, 80, 3, 74, 0, 71, 
    7,  3, 8, 59, 0, 98, 3, 47, 2, 83, 4, 38, 1, 70, 6, 79, 5, 41, 
    8, 37, 7, 42, 2, 78, 3, 39, 6, 78, 4, 14, 1, 71, 5, 16, 0, 72, 
    8, 24, 5, 24, 3, 33, 0, 51, 4, 76, 2, 70, 7, 40, 1, 22, 6, 74, 
    2,  5, 8, 39, 1, 28, 3,  5, 5, 58, 0, 58, 7, 56, 6, 79, 4, 22, 
    3, 15, 5, 32, 8, 84, 4,  8, 6, 17, 1, 95, 7, 30, 0, 43, 2, 83, 
    0, 82, 7, 47, 1, 87, 5, 41, 8, 14, 6, 45, 3, 71, 4, 29, 2, 87
  };
  const int q6653[] = {
    9, 9, // Number of jobs and machines
    7,  6, 0, 90, 4, 77, 2, 87, 1, 77, 6, 64, 8, 17, 5, 10, 3, 41, 
    3, 92, 5, 21, 8, 51, 2, 26, 0, 25, 4, 90, 7, 91, 6, 19, 1,  8, 
    6, 55, 4, 32, 1, 36, 2, 89, 7, 70, 3, 65, 5, 53, 8, 89, 0, 84, 
    0, 62, 6, 59, 4, 63, 2, 65, 8, 51, 1, 30, 5, 21, 7, 15, 3, 43, 
    0, 92, 3, 59, 2, 45, 7, 62, 1, 37, 6, 91, 4, 35, 5, 87, 8, 51, 
    2, 96, 4, 93, 0, 17, 1, 88, 7,  7, 6, 55, 3, 63, 8,  8, 5, 98, 
    2, 40, 3, 21, 5, 47, 4, 10, 0, 91, 6, 95, 1, 11, 7, 86, 8, 70, 
    5, 43, 8, 72, 0, 83, 4, 64, 6, 73, 3, 73, 1, 77, 7, 93, 2, 31, 
    5,  6, 4, 25, 6, 69, 1, 24, 0, 67, 2, 50, 7, 68, 3,  1, 8, 86
  };
  const int q6654[] = {
    9, 9, // Number of jobs and machines
    2, 45, 1, 45, 6, 55, 7, 45, 4, 32, 3, 45, 0, 95, 5, 87, 8, 69, 
    8, 19, 0, 48, 5,  4, 1, 27, 6, 69, 7, 86, 4, 80, 2,  7, 3, 78, 
    0, 42, 4, 25, 8, 87, 6, 26, 2, 93, 3, 47, 7, 50, 5, 24, 1, 44, 
    1, 71, 7, 37, 2,  3, 3, 34, 6, 51, 8, 27, 5, 87, 4, 11, 0, 90, 
    3, 86, 8, 82, 5, 28, 0, 47, 6,  9, 1,  5, 7, 94, 4, 74, 2, 19, 
    0, 36, 2, 69, 3, 67, 5, 57, 1, 56, 7, 22, 4, 76, 6, 57, 8, 49, 
    5, 87, 3, 35, 6, 25, 4, 78, 7,  2, 1, 89, 8, 36, 0, 33, 2, 49, 
    2, 79, 7, 21, 3, 74, 4, 93, 5, 18, 0, 25, 8, 20, 1, 88, 6,  4, 
    5, 49, 6, 70, 8, 79, 1, 88, 0, 67, 2, 69, 4, 30, 3, 45, 7, 83
  };
  const int q6655[] = {
    9, 9, // Number of jobs and machines
    8, 51, 7, 87, 3,  8, 5,  3, 6, 45, 2, 63, 4, 41, 0, 57, 1, 69, 
    0, 78, 3, 67, 5, 85, 2, 14, 7, 85, 6, 63, 8, 23, 4, 33, 1, 75, 
    6, 15, 7, 14, 2, 90, 3, 46, 1, 94, 4, 88, 5, 70, 0, 58, 8, 22, 
    5, 62, 3, 76, 1, 23, 2, 31, 8, 86, 7, 36, 6, 46, 0, 34, 4, 61, 
    0, 64, 6,  5, 5,  7, 8, 41, 2, 46, 7, 76, 4, 57, 3,  4, 1, 84, 
    8,  4, 1, 61, 2, 72, 4, 56, 3, 48, 5,  5, 6, 31, 7, 72, 0, 39, 
    0, 91, 2, 92, 8, 23, 3, 71, 5, 66, 1, 56, 6, 59, 4, 74, 7, 10, 
    1, 38, 8, 73, 2, 30, 6, 86, 4, 21, 7, 41, 0, 35, 3, 43, 5, 65, 
    0, 77, 5, 35, 1, 37, 3, 52, 6, 50, 7, 88, 4, 96, 8,  9, 2, 58
  };
  const int q6656[] = {
    9, 9, // Number of jobs and machines
    3, 96, 7, 66, 0, 80, 2, 67, 8, 39, 5, 33, 4, 57, 1, 97, 6, 47, 
    0, 70, 8, 33, 2,  2, 4, 84, 5, 93, 1, 96, 3, 77, 6, 48, 7, 38, 
    1, 56, 7, 31, 4, 74, 5, 56, 2, 13, 0, 51, 6, 34, 3, 60, 8, 61, 
    5, 81, 8, 70, 1, 32, 3, 96, 6, 69, 2, 76, 0, 38, 7, 87, 4,  6, 
    1, 79, 8, 74, 5, 29, 2, 13, 7,  4, 0, 33, 6, 50, 3, 75, 4, 63, 
    2, 56, 6,  5, 8, 47, 7, 35, 3, 36, 5, 78, 0, 70, 4, 13, 1, 65, 
    2, 62, 7, 29, 5, 11, 0, 25, 3, 66, 8, 93, 6, 90, 4,  9, 1, 52, 
    4, 97, 1, 27, 8, 61, 3, 21, 7, 42, 5,  9, 2, 26, 6, 78, 0, 46, 
    2,  2, 8, 30, 4, 49, 6, 44, 1, 55, 7, 80, 5, 54, 3, 99, 0, 63
  };
  const int q6657[] = {
    9, 9, // Number of jobs and machines
    5, 86, 6, 24, 4,  4, 0, 39, 8, 91, 3, 61, 2, 48, 7, 29, 1, 46, 
    4, 38, 2, 93, 7, 63, 1, 32, 6, 91, 8, 17, 3,  8, 0, 81, 5, 78, 
    5,  3, 0, 53, 4, 74, 8, 44, 2, 64, 3,  7, 6,  7, 7, 91, 1, 78, 
    1, 74, 2, 19, 5, 34, 3, 99, 0, 83, 7, 53, 4, 22, 6, 72, 8, 37, 
    0, 17, 2, 75, 5, 21, 1,  7, 7, 15, 4, 97, 8, 16, 6, 26, 3, 85, 
    4, 65, 7, 75, 3, 89, 6, 32, 8, 67, 2, 61, 1, 35, 5, 32, 0, 76, 
    6, 49, 4, 99, 8, 98, 3, 31, 7,  5, 0, 61, 5, 25, 1, 88, 2, 15, 
    0, 21, 4, 61, 3,  4, 8, 74, 7, 78, 6, 13, 5, 41, 1, 12, 2, 57, 
    5, 45, 1, 14, 2, 37, 7, 66, 3, 53, 4, 37, 8, 22, 6, 59, 0, 74
  };
  const int q6658[] = {
    9, 9, // Number of jobs and machines
    7, 58, 1, 41, 2,  1, 3, 66, 4, 15, 0, 34, 8, 17, 6, 93, 5, 33, 
    6, 66, 5, 17, 3, 23, 4, 49, 0, 65, 1, 52, 8, 45, 7, 15, 2, 63, 
    7, 79, 4, 32, 2, 36, 8, 51, 5, 68, 0,  1, 3, 89, 1, 58, 6,  2, 
    4, 72, 5, 87, 0, 31, 1, 98, 8, 37, 6, 48, 2, 53, 7, 25, 3, 50, 
    4, 21, 2,  5, 3, 70, 5, 35, 1, 21, 8, 87, 0, 81, 6, 87, 7,  2, 
    5, 33, 8, 75, 6,  3, 0, 45, 3, 99, 4, 10, 2, 74, 1, 66, 7, 18, 
    0, 95, 1,  8, 5, 50, 3,  1, 4, 77, 7, 70, 2, 15, 6, 70, 8, 19, 
    6, 78, 7, 10, 1,  3, 4, 25, 8, 79, 0, 35, 5, 63, 3, 25, 2, 18, 
    6, 81, 7,  1, 0, 77, 1, 60, 4,  2, 8, 43, 3, 56, 2, 24, 5, 41
  };
  const int q6659[] = {
    9, 9, // Number of jobs and machines
    8, 75, 5, 82, 0, 61, 7, 91, 6, 81, 2, 11, 1, 64, 3, 36, 4, 14, 
    4, 88, 6, 87, 5,  5, 1, 93, 8, 24, 2, 26, 7, 37, 0, 55, 3, 82, 
    3, 33, 5, 13, 6, 54, 8, 25, 2, 92, 0, 61, 1, 11, 4, 65, 7, 68, 
    7, 77, 8, 98, 4, 30, 2, 96, 5, 22, 3, 88, 1, 80, 6, 98, 0,  3, 
    2,  2, 7, 86, 5, 79, 4, 49, 1, 98, 0, 58, 6, 65, 3, 55, 8, 91, 
    5, 15, 8, 11, 7, 93, 3, 20, 2, 97, 0, 64, 6, 83, 1,  8, 4, 90, 
    1, 53, 3, 92, 4,  1, 8,  7, 5, 75, 2, 17, 0, 72, 7, 33, 6, 45, 
    2, 85, 0, 84, 5, 86, 7, 94, 3, 37, 6, 34, 4, 75, 8, 49, 1, 24, 
    3, 97, 1, 27, 0, 49, 7, 41, 6, 39, 4,  2, 2, 15, 5, 58, 8, 86
  };
  const int q6660[] = {
    9, 9, // Number of jobs and machines
    8, 88, 0, 90, 4, 73, 1, 77, 3, 33, 2, 48, 7,  7, 6, 85, 5, 34, 
    2, 21, 5, 64, 6, 39, 3, 23, 1, 79, 0, 28, 8,  2, 7, 33, 4, 93, 
    1, 95, 2, 79, 5, 37, 3, 44, 4,  2, 8, 87, 6, 39, 7, 73, 0, 38, 
    4, 63, 8, 10, 2, 11, 0,  2, 3, 93, 1, 27, 6, 89, 5,  6, 7, 44, 
    7, 54, 5, 75, 8, 49, 1, 36, 6, 61, 4, 24, 3, 15, 2, 20, 0, 17, 
    8, 56, 2, 72, 5, 30, 7, 90, 1, 46, 6, 24, 4, 83, 3, 42, 0, 95, 
    3, 52, 5, 68, 0, 96, 6, 38, 8, 67, 7, 47, 1, 19, 2, 79, 4, 67, 
    1,  5, 4, 75, 0, 39, 7,  3, 3, 34, 8, 30, 6, 25, 5,  8, 2, 98, 
    7, 43, 2, 87, 3, 86, 1, 49, 5, 22, 6, 10, 4, 96, 8, 86, 0, 99
  };
  const int q6661[] = {
    9, 9, // Number of jobs and machines
    8, 88, 5, 52, 0,  1, 1, 87, 4, 72, 2, 15, 3, 10, 7, 25, 6, 34, 
    7, 72, 6,  7, 2, 94, 0, 44, 5, 63, 4, 30, 3, 90, 1, 50, 8, 28, 
    8, 84, 5, 81, 6, 25, 1, 18, 2, 98, 0, 33, 3, 26, 4, 47, 7, 81, 
    3, 46, 5, 56, 8, 56, 2, 90, 6, 74, 0, 21, 1,  1, 4, 11, 7,  1, 
    1, 58, 0, 99, 8, 72, 3, 82, 5, 72, 7, 47, 2,  9, 4,  9, 6, 81, 
    0, 36, 2, 53, 3, 73, 1, 23, 5, 92, 7, 98, 4, 92, 6, 21, 8, 96, 
    7, 91, 1, 21, 8,  4, 0, 37, 5, 57, 4, 96, 3, 18, 6,  5, 2, 96, 
    1, 88, 2, 46, 3, 74, 6,  9, 0, 35, 5, 44, 7, 80, 4, 34, 8, 25, 
    6, 99, 0, 10, 7, 82, 4,  7, 5, 58, 1, 21, 3, 96, 8, 45, 2, 64
  };
  const int q6662[] = {
    9, 9, // Number of jobs and machines
    7, 69, 1, 59, 2, 56, 8, 70, 5, 42, 6, 36, 0, 58, 4, 71, 3, 99, 
    8, 39, 0, 72, 6,  6, 1, 26, 3, 52, 2, 19, 5, 80, 4, 97, 7,  8, 
    5, 99, 0, 29, 2, 89, 3, 32, 8, 74, 6, 97, 4, 69, 1, 59, 7, 97, 
    0, 76, 1, 70, 5, 60, 8, 40, 7, 91, 2, 85, 6, 15, 4, 42, 3, 77, 
    4, 10, 1, 52, 0, 69, 2, 19, 7, 29, 5, 74, 8, 83, 6, 63, 3, 61, 
    5, 29, 2,  9, 0, 23, 8, 59, 3, 40, 7, 60, 1, 54, 4, 67, 6, 72, 
    4, 16, 6, 23, 5,  8, 0, 37, 2, 88, 3, 50, 7, 55, 8, 28, 1, 43, 
    3,  1, 7, 92, 2, 11, 4, 22, 8, 99, 1, 57, 0, 20, 5, 22, 6, 91, 
    1, 95, 3, 80, 7, 20, 4, 40, 2, 63, 6, 45, 5, 95, 0, 83, 8,  5
  };
  const int q6663[] = {
    9, 9, // Number of jobs and machines
    6, 37, 2, 12, 5, 56, 3, 37, 7, 85, 1, 11, 4,  7, 8, 98, 0, 26, 
    1, 91, 0, 54, 5, 81, 3, 71, 7, 76, 4, 90, 6, 22, 8, 63, 2, 70, 
    8,  3, 0, 70, 1, 92, 5, 57, 6,  5, 3, 43, 2, 91, 7, 56, 4, 93, 
    3, 73, 6, 67, 0, 95, 1, 51, 5, 64, 4, 66, 8, 16, 7, 77, 2, 22, 
    6, 75, 4,  8, 3, 90, 8, 43, 1, 66, 2, 49, 0,  2, 5, 70, 7, 46, 
    0, 60, 2, 31, 7, 23, 6, 58, 8, 98, 5, 62, 4,  2, 1, 51, 3, 79, 
    5, 53, 2, 95, 1, 42, 6, 72, 8, 90, 3, 25, 4, 18, 7, 87, 0, 59, 
    4,  8, 3, 51, 0, 88, 5, 17, 6, 95, 2, 20, 7, 63, 1, 68, 8, 60, 
    8, 12, 6, 43, 5, 28, 7, 88, 0, 30, 3, 65, 2, 92, 4, 46, 1,  1
  };
  const int q6664[] = {
    9, 9, // Number of jobs and machines
    6, 35, 4, 83, 5, 13, 1, 54, 8,  6, 0,  8, 7,  7, 3, 43, 2, 72, 
    4, 91, 0, 29, 2, 46, 5, 41, 3, 17, 7, 76, 8, 50, 6, 81, 1, 71, 
    0, 83, 5, 74, 2,  6, 7, 94, 3, 83, 4,  7, 6, 48, 8, 18, 1, 34, 
    7, 87, 0,  3, 8, 90, 4, 23, 6, 32, 3, 21, 1, 85, 2, 74, 5, 46, 
    0,  9, 7, 15, 8, 64, 1, 40, 4,  2, 3, 62, 2, 10, 6,  7, 5, 30, 
    3, 37, 5,  8, 6, 27, 0, 13, 1, 23, 2, 43, 8, 57, 4, 22, 7, 10, 
    6, 69, 1, 54, 2, 75, 0, 46, 5, 58, 3, 85, 4, 50, 8, 95, 7, 37, 
    1, 95, 6,  1, 3, 51, 8, 40, 5,  4, 4,  7, 7, 21, 2,  7, 0, 87, 
    7, 65, 0, 74, 5, 61, 4, 92, 6, 97, 8, 37, 2, 83, 1, 74, 3, 80
  };
  const int q6665[] = {
    9, 9, // Number of jobs and machines
    8, 57, 3,  2, 2, 17, 6, 37, 0, 92, 5, 99, 1, 28, 4, 74, 7,  5, 
    2, 34, 5, 29, 4, 30, 3, 26, 0, 34, 8, 72, 1, 94, 7, 16, 6,  6, 
    1, 37, 6, 55, 2,  3, 7, 78, 8, 72, 0, 36, 3, 32, 5, 82, 4, 29, 
    1,  8, 2, 62, 3, 87, 0, 16, 8, 37, 6, 25, 5, 22, 4, 81, 7, 94, 
    2, 98, 5, 59, 1, 32, 3, 87, 4,  2, 8, 68, 0, 73, 7, 78, 6, 83, 
    4, 73, 3, 29, 8,  5, 6,  6, 5, 17, 7, 56, 1, 67, 2, 18, 0, 92, 
    6, 19, 7, 26, 2, 24, 0, 47, 4, 83, 1, 29, 3, 84, 8, 21, 5, 95, 
    4, 98, 8, 85, 3, 88, 0, 80, 7, 76, 2, 24, 6, 71, 1, 78, 5, 10, 
    1, 60, 4, 61, 6, 22, 7, 58, 5, 40, 8, 40, 0, 98, 3, 52, 2, 34
  };
  const int q6666[] = {
    9, 9, // Number of jobs and machines
    3, 32, 6, 99, 5, 17, 8, 91, 4, 14, 2, 40, 1, 38, 0, 10, 7, 80, 
    0, 11, 5, 97, 7, 49, 4, 79, 2, 82, 3, 59, 6, 92, 1, 74, 8, 69, 
    8, 45, 6, 19, 5, 67, 4, 83, 3,  8, 0, 44, 7, 73, 1,  7, 2, 26, 
    5, 36, 0, 67, 1, 15, 8, 68, 2, 53, 7, 63, 6, 28, 3, 90, 4, 52, 
    4, 29, 5, 97, 1, 60, 3, 56, 8, 75, 0, 32, 2, 72, 7, 31, 6, 81, 
    8, 27, 4, 53, 1, 64, 5, 61, 2, 31, 3, 94, 6, 95, 7, 47, 0, 30, 
    1, 97, 4, 91, 7, 94, 2, 10, 0, 75, 8, 42, 6, 81, 5, 50, 3, 95, 
    5, 71, 1, 60, 2, 32, 6, 54, 0, 19, 3, 27, 4, 14, 7, 84, 8, 25, 
    6, 50, 2, 29, 4, 40, 7, 22, 5, 92, 0, 75, 8, 27, 1, 17, 3, 49
  };
  const int q6667[] = {
    9, 9, // Number of jobs and machines
    6, 48, 2, 22, 7, 18, 0, 48, 4, 62, 3, 19, 5,  9, 8, 71, 1, 91, 
    4, 57, 2, 49, 7, 40, 5, 83, 8,  4, 6, 83, 1, 77, 3, 73, 0, 46, 
    0, 92, 2, 35, 5, 21, 7, 93, 4, 97, 1, 56, 6, 98, 8, 29, 3, 10, 
    4, 39, 5, 64, 3, 29, 1, 15, 0, 10, 7, 10, 2,  1, 8, 15, 6, 31, 
    7, 92, 0, 29, 2, 40, 5, 48, 3, 28, 6,  6, 8, 13, 4, 33, 1, 24, 
    0, 37, 7, 82, 2,  2, 8, 78, 3, 11, 4,  6, 1,  6, 5, 97, 6, 94, 
    7, 71, 1, 29, 5, 86, 0, 63, 4, 58, 6, 49, 2, 75, 8, 78, 3,  1, 
    1, 20, 5, 17, 2, 17, 0, 17, 3, 44, 6, 94, 7, 91, 8, 44, 4, 39, 
    0, 54, 5, 31, 1, 27, 3, 40, 2,  8, 8, 14, 6, 26, 7, 80, 4, 46
  };
  const int q6668[] = {
    9, 9, // Number of jobs and machines
    0, 89, 6, 32, 5, 83, 7, 37, 4,  6, 8, 53, 3,  8, 2, 20, 1, 14, 
    5, 88, 1, 41, 7, 26, 4, 99, 3, 63, 0, 32, 6, 35, 2, 27, 8, 22, 
    3, 96, 5, 42, 4, 19, 8, 53, 6, 54, 2, 33, 1, 31, 7, 95, 0, 75, 
    7, 46, 1,  8, 0, 92, 8, 53, 6, 76, 2, 93, 4, 53, 3, 48, 5, 82, 
    3, 10, 1,  2, 0, 17, 8, 14, 2, 65, 5, 44, 4, 40, 6, 16, 7, 12, 
    8, 98, 7, 94, 3, 59, 0, 34, 2,  4, 5, 69, 1, 78, 6, 28, 4, 76, 
    2, 81, 4, 88, 3, 10, 8, 56, 7, 79, 0, 78, 6, 61, 5, 77, 1, 55, 
    7, 72, 8, 18, 0, 73, 6, 55, 3, 66, 1, 57, 5, 26, 2, 23, 4, 66, 
    7, 36, 2,  6, 5, 36, 0, 94, 8, 54, 4, 52, 3, 60, 6, 49, 1, 22
  };
  const int q6669[] = {
    9, 9, // Number of jobs and machines
    8, 30, 3, 91, 1, 96, 7, 88, 4, 47, 5, 67, 0, 74, 6,  1, 2, 38, 
    5, 39, 3, 51, 6,  3, 1, 17, 0, 32, 4, 94, 7, 66, 2, 64, 8, 91, 
    8, 81, 4, 67, 3, 26, 6, 48, 1, 95, 0,  7, 7, 97, 5, 54, 2, 81, 
    6, 36, 3, 85, 1, 15, 7, 21, 4, 85, 2, 66, 0, 99, 5, 53, 8, 53, 
    2, 17, 3, 83, 6,  9, 4, 97, 0, 98, 5, 48, 7, 11, 1, 32, 8, 92, 
    3,  6, 7, 17, 2, 30, 1, 33, 6, 33, 5, 82, 8, 71, 4, 36, 0, 55, 
    5, 84, 0, 70, 3, 93, 4, 31, 6, 92, 2, 18, 1, 36, 8, 17, 7, 54, 
    0, 73, 1, 24, 8, 28, 4,  5, 7, 86, 3, 91, 2, 29, 5, 23, 6, 57, 
    2, 41, 6, 76, 4, 86, 7, 45, 0, 89, 1, 40, 3, 24, 5, 47, 8, 56
  };
  const int q6670[] = {
    9, 9, // Number of jobs and machines
    0, 62, 6, 27, 8, 96, 5, 53, 3, 33, 1, 93, 7, 44, 2,  9, 4, 45, 
    2, 80, 1, 89, 4, 98, 6, 51, 5, 27, 0, 89, 8, 97, 3, 11, 7, 31, 
    1, 34, 4, 32, 7, 80, 5, 67, 8, 73, 6, 36, 3, 92, 0, 27, 2, 64, 
    5, 33, 2, 75, 6, 88, 7, 48, 1, 91, 0, 92, 8, 85, 3, 47, 4, 94, 
    4, 22, 5, 23, 6, 25, 0, 24, 8, 34, 1,  7, 2, 45, 7, 99, 3, 23, 
    0, 66, 1, 57, 2, 35, 8, 75, 5,  7, 3, 36, 7, 22, 6, 24, 4, 46, 
    5, 15, 8,  5, 0, 44, 4,  7, 3, 73, 6, 25, 7, 30, 2, 48, 1,  8, 
    2, 92, 3,  8, 0, 73, 6, 12, 1, 91, 8, 26, 7, 73, 4, 10, 5, 59, 
    8, 82, 0, 13, 4, 61, 1, 52, 6, 19, 7, 96, 5, 24, 3, 24, 2, 57
  };
  const int q6671[] = {
    9, 9, // Number of jobs and machines
    4, 58, 7, 26, 6, 49, 5,  8, 0, 66, 2, 66, 1, 38, 3, 28, 8, 25, 
    8, 62, 4, 57, 1, 43, 6, 49, 0, 95, 2, 14, 5, 17, 3, 53, 7, 43, 
    6, 19, 8, 85, 4, 52, 7, 99, 2, 65, 5, 24, 1, 37, 0, 52, 3, 78, 
    6, 11, 2, 58, 3, 15, 4, 67, 5, 28, 1, 32, 8, 23, 7, 55, 0,  3, 
    6, 80, 4, 67, 1, 19, 3, 72, 8, 98, 0, 13, 2, 13, 5, 31, 7, 51, 
    7, 97, 3, 59, 8, 42, 5, 61, 2, 73, 4, 37, 6, 68, 0, 81, 1, 43, 
    8, 90, 6, 56, 0, 40, 4, 98, 7, 68, 2, 93, 5, 76, 3, 40, 1, 93, 
    6, 70, 8, 52, 0, 72, 2, 32, 3, 95, 7, 32, 4, 47, 1, 53, 5, 55, 
    8, 75, 0, 96, 7, 43, 2, 86, 6, 97, 1, 69, 3, 39, 4, 34, 5, 34
  };
  const int q6672[] = {
    9, 9, // Number of jobs and machines
    5, 50, 4, 13, 3, 10, 6,  6, 2, 87, 0, 26, 1, 94, 8, 36, 7, 80, 
    6, 71, 8, 24, 2, 41, 3, 66, 4, 95, 1, 54, 0, 17, 5, 15, 7, 22, 
    1, 68, 6, 75, 3, 95, 0, 84, 5, 14, 7, 68, 4, 29, 2, 52, 8, 36, 
    3,  2, 7, 64, 6, 27, 4, 38, 0, 87, 8, 99, 2, 47, 5, 61, 1, 76, 
    8, 98, 7, 62, 6,  9, 4, 98, 0, 80, 3, 49, 5, 60, 2, 26, 1, 23, 
    6, 52, 0, 24, 8,  6, 5, 59, 3, 91, 1, 48, 2,  5, 4,  6, 7, 61, 
    7, 78, 8, 16, 3, 63, 0, 20, 2, 67, 6, 47, 4, 60, 1, 74, 5, 61, 
    8, 30, 2, 90, 3, 91, 6, 57, 7, 77, 1,  7, 5,  2, 0, 67, 4, 60, 
    0, 78, 3,  4, 7, 99, 6, 98, 8, 65, 4, 67, 2, 49, 1, 90, 5, 88
  };
  const int q6673[] = {
    9, 9, // Number of jobs and machines
    8, 27, 5, 66, 1, 73, 2, 28, 7, 56, 6, 63, 4, 58, 0,  8, 3, 59, 
    4, 74, 7, 45, 1, 24, 0, 20, 2, 41, 6, 60, 8,  4, 5, 19, 3, 63, 
    4, 42, 2, 65, 6, 56, 8, 15, 1, 15, 3, 75, 0, 50, 5, 58, 7, 86, 
    5, 65, 1, 71, 2, 47, 6, 79, 4, 90, 3, 47, 8, 15, 7,  5, 0, 55, 
    8, 37, 3, 29, 6, 50, 5, 90, 2, 90, 4, 52, 0, 95, 1,  8, 7, 18, 
    3, 10, 4, 77, 7, 72, 1, 41, 0, 61, 5, 37, 6, 89, 8, 26, 2, 16, 
    7, 38, 1, 57, 2, 53, 5, 35, 8, 42, 6, 43, 0, 18, 4, 13, 3, 83, 
    7, 72, 2, 97, 0, 93, 8, 69, 3, 41, 6, 43, 5, 47, 4, 22, 1, 30, 
    2, 15, 0, 44, 6, 14, 7, 13, 8, 12, 5, 83, 4,  2, 3, 68, 1, 54
  };
  const int q6674[] = {
    9, 9, // Number of jobs and machines
    8, 18, 4, 15, 2, 25, 1, 42, 0, 50, 7, 25, 3, 65, 5, 79, 6,  2, 
    0, 60, 3, 53, 4, 46, 5, 82, 7, 13, 8, 92, 2, 58, 6, 67, 1, 82, 
    1,  7, 5, 82, 8, 66, 7, 76, 4, 86, 6, 39, 2, 11, 3, 15, 0, 49, 
    5, 63, 6, 82, 7, 35, 3, 70, 8, 40, 4, 24, 1, 73, 0, 57, 2,  8, 
    2,  9, 3, 15, 0, 99, 8, 41, 6, 92, 5, 14, 4, 65, 7, 87, 1, 99, 
    6, 48, 8, 37, 0, 37, 5, 46, 1,  4, 3, 59, 7, 91, 4,  6, 2,  2, 
    0, 84, 6, 74, 8, 47, 1, 84, 3, 72, 2, 64, 5,  7, 7, 91, 4,  3, 
    2, 17, 0, 15, 3, 77, 1, 13, 7, 77, 5,  9, 8, 46, 4, 95, 6, 94, 
    8, 65, 4, 77, 3, 67, 0, 87, 2, 13, 5, 65, 6, 86, 7, 10, 1, 87
  };
  const int q6675[] = {
    9, 9, // Number of jobs and machines
    2, 16, 4,  6, 7, 37, 1, 82, 5, 16, 3, 75, 0, 73, 6, 97, 8, 56, 
    0,  9, 2, 69, 5, 48, 6, 72, 1, 83, 4, 86, 3, 47, 7, 69, 8, 21, 
    1, 66, 6, 31, 8, 41, 0, 50, 2, 46, 7, 75, 5, 60, 4, 87, 3, 65, 
    2, 86, 0, 80, 1, 28, 6, 89, 3, 75, 7, 98, 4, 12, 5, 15, 8, 56, 
    3, 61, 8, 66, 5, 68, 7, 58, 2, 32, 1,  4, 6, 35, 0,  6, 4, 91, 
    5,  6, 3, 47, 6, 53, 1, 24, 4, 93, 0, 73, 2, 78, 8, 16, 7, 60, 
    2, 73, 4, 51, 6, 88, 0, 82, 3, 32, 7, 67, 8,  6, 1, 94, 5, 52, 
    6, 44, 0, 21, 5, 90, 4, 90, 3,  4, 7, 53, 2, 75, 1, 64, 8, 68, 
    0, 87, 8, 45, 1, 85, 7, 79, 6, 51, 2, 31, 4, 81, 5, 28, 3, 98
  };
  const int q6676[] = {
    9, 9, // Number of jobs and machines
    8, 21, 0, 27, 6, 26, 2, 51, 3, 51, 4, 10, 1, 27, 5, 32, 7, 71, 
    4, 23, 0, 62, 6, 20, 7, 49, 1, 13, 2, 81, 8, 31, 3, 29, 5, 53, 
    6, 72, 2,  8, 1, 48, 5, 61, 3, 28, 8, 55, 7, 50, 0, 77, 4,  9, 
    5, 46, 2, 95, 8, 94, 6, 51, 7, 57, 4, 35, 1, 27, 3, 81, 0,  5, 
    4, 80, 5, 63, 3, 15, 6,  7, 7,  8, 1, 32, 8,  8, 0, 68, 2, 96, 
    3, 90, 2, 26, 5, 34, 7, 25, 4, 24, 1, 76, 8, 74, 6, 17, 0, 82, 
    3,  1, 7, 72, 0, 28, 5, 97, 2, 14, 4, 82, 1, 99, 6, 78, 8, 21, 
    3, 36, 2, 38, 8, 25, 5, 17, 4, 81, 0, 76, 6, 38, 1, 86, 7, 55, 
    8, 59, 6, 26, 2, 93, 3, 41, 0, 69, 4, 16, 1, 32, 7, 85, 5, 87
  };
  const int q6677[] = {
    9, 9, // Number of jobs and machines
    8, 30, 7, 56, 2, 51, 6, 38, 3, 37, 4,  5, 5, 87, 1, 91, 0, 60, 
    0, 17, 8, 20, 1, 49, 7, 93, 5, 60, 2, 78, 3, 93, 6, 43, 4, 70, 
    4, 24, 8, 86, 5, 53, 1, 46, 3, 25, 7, 85, 2, 21, 6,  9, 0, 82, 
    5, 29, 2, 23, 1,  3, 6, 42, 7, 37, 0, 30, 4, 10, 8, 66, 3, 46, 
    3, 57, 2,  6, 5, 25, 0, 59, 4, 77, 1, 64, 7, 16, 8, 51, 6, 37, 
    1, 75, 6, 68, 4, 90, 8, 26, 2, 26, 3, 72, 7,  1, 5, 44, 0, 41, 
    1,  7, 6,  1, 0, 80, 7, 16, 8, 49, 3, 84, 2, 87, 4,  1, 5, 32, 
    6, 83, 8, 18, 1,  7, 4, 81, 0, 84, 3, 30, 5, 48, 7,  7, 2, 32, 
    7, 80, 4, 90, 1, 81, 3, 94, 2, 51, 5, 41, 0, 89, 6, 37, 8, 95
  };
  const int q6678[] = {
    9, 9, // Number of jobs and machines
    3, 10, 8, 29, 2, 82, 7, 40, 5, 95, 1, 31, 4, 59, 6, 98, 0, 11, 
    6, 30, 0,  4, 3, 49, 8, 93, 7, 36, 1,  5, 2, 69, 4, 16, 5, 26, 
    2, 73, 1, 54, 0, 67, 5, 70, 4, 62, 7, 17, 6, 21, 8, 84, 3, 21, 
    7, 61, 3, 92, 0, 42, 6, 98, 1,  9, 5, 15, 4, 19, 2, 87, 8, 62, 
    0, 20, 1, 30, 8, 38, 7, 69, 5, 31, 4, 38, 2, 46, 3,  4, 6, 82, 
    3, 10, 7, 86, 2, 83, 4, 12, 6, 25, 5, 91, 1, 47, 8, 13, 0, 61, 
    3, 25, 7, 63, 6, 44, 4, 46, 1, 99, 0, 58, 8, 13, 2, 87, 5, 69, 
    5, 25, 2, 28, 8, 84, 6, 84, 3, 69, 4, 89, 7, 21, 1, 52, 0, 68, 
    0, 23, 5, 30, 8, 54, 1, 26, 2, 60, 6, 44, 7, 57, 3, 43, 4, 43
  };
  const int q6679[] = {
    9, 9, // Number of jobs and machines
    5,  3, 4, 73, 8, 88, 6, 53, 0, 34, 1, 26, 2, 65, 3, 62, 7, 37, 
    1, 33, 7, 37, 0, 19, 2, 57, 5, 64, 4, 90, 6, 72, 8, 99, 3, 36, 
    8, 95, 2, 63, 1, 64, 7, 29, 3, 35, 4, 97, 6, 56, 0, 53, 5, 64, 
    8, 45, 4, 21, 2, 87, 7, 21, 1, 56, 0, 77, 3, 32, 6, 62, 5, 30, 
    4, 90, 6, 78, 0, 56, 3, 11, 5, 25, 8, 42, 7, 90, 1, 65, 2, 90, 
    6, 87, 2, 79, 1, 54, 8, 14, 3, 28, 5, 65, 0, 76, 4, 68, 7, 69, 
    0, 79, 2, 45, 7, 80, 1, 82, 3, 52, 5,  2, 6, 28, 4, 53, 8, 56, 
    0,  9, 8, 30, 1, 86, 7, 76, 3, 64, 2, 68, 6, 88, 4, 40, 5, 23, 
    5, 78, 3, 35, 7, 71, 8, 74, 6, 55, 1, 62, 0, 91, 2, 30, 4, 40
  };
  const int q6680[] = {
    9, 9, // Number of jobs and machines
    5, 54, 8, 68, 3, 36, 0, 15, 6, 39, 4, 24, 1, 11, 7, 59, 2, 79, 
    7, 32, 6, 21, 1, 44, 3, 62, 2, 95, 8, 13, 5, 61, 4, 55, 0, 20, 
    7, 26, 2, 51, 5, 66, 1, 99, 8, 62, 4, 10, 6,  5, 3,  6, 0, 11, 
    0,  7, 7, 22, 6, 43, 4, 91, 3, 41, 1, 54, 2, 88, 5, 83, 8, 88, 
    3, 98, 2, 34, 1, 20, 6, 85, 4, 27, 5, 63, 0, 93, 8, 87, 7, 42, 
    5, 18, 2, 99, 6, 66, 1, 18, 7, 65, 4, 59, 8, 10, 0, 90, 3, 41, 
    0, 66, 5, 75, 2, 12, 8, 20, 4, 89, 3, 31, 1, 24, 7, 40, 6, 65, 
    7, 18, 3,  6, 4, 68, 0, 21, 8, 55, 1, 54, 6, 26, 5, 39, 2, 19, 
    1, 64, 0, 96, 4, 84, 6, 79, 8, 33, 2, 28, 7, 28, 5, 13, 3, 53
  };
  const int q6681[] = {
    9, 9, // Number of jobs and machines
    3, 59, 6, 14, 2, 35, 0, 58, 7, 67, 1,  9, 5, 69, 4, 79, 8, 94, 
    7, 17, 2, 23, 3, 32, 6,  5, 0, 94, 4, 94, 5, 52, 1, 66, 8,  9, 
    0, 91, 4, 84, 2, 45, 1, 77, 7, 29, 5, 86, 6,  6, 8, 55, 3, 14, 
    8, 33, 7, 26, 3, 16, 5, 46, 1, 45, 4, 28, 6, 65, 0, 14, 2, 94, 
    4, 92, 5, 24, 7, 13, 0, 79, 6, 64, 1, 60, 8, 48, 2, 73, 3, 80, 
    7, 77, 8, 23, 5, 78, 3, 69, 2, 89, 4, 59, 6, 30, 1, 52, 0, 97, 
    8, 18, 2, 49, 6, 36, 4, 73, 7, 80, 1, 11, 5,  4, 3, 34, 0, 27, 
    3, 35, 2, 96, 5, 59, 7, 83, 1, 58, 0, 36, 8,  2, 6, 38, 4, 21, 
    6, 73, 5,  4, 4, 21, 2, 87, 0, 65, 8, 50, 1, 59, 3, 40, 7, 67
  };
  const int q6682[] = {
    9, 9, // Number of jobs and machines
    0, 94, 6, 89, 3, 19, 5, 60, 8, 74, 1, 48, 4, 12, 2, 78, 7, 62, 
    8, 92, 6, 59, 7,  5, 0, 18, 1, 79, 2, 41, 3, 99, 5, 89, 4, 57, 
    0, 35, 3, 20, 4, 83, 2, 26, 1, 19, 7, 37, 8, 84, 6, 68, 5, 13, 
    7, 28, 1, 27, 6, 12, 3, 11, 4, 20, 8, 22, 5, 68, 2, 88, 0, 63, 
    1, 89, 0, 31, 8, 94, 2, 95, 3, 96, 7, 49, 6, 52, 5, 91, 4, 63, 
    4,  2, 3, 90, 1, 73, 7,  1, 5, 75, 2, 56, 8, 23, 0, 70, 6, 43, 
    1, 84, 2,  2, 0, 58, 5,  2, 4, 74, 7, 44, 6, 64, 8, 13, 3, 91, 
    5, 75, 7, 38, 0, 24, 3, 53, 1, 36, 2, 64, 6, 97, 8, 25, 4,  1, 
    4, 14, 3, 37, 1, 26, 2, 53, 8, 37, 0, 22, 5, 85, 7, 67, 6, 11
  };
  const int q6683[] = {
    9, 9, // Number of jobs and machines
    5, 71, 6, 61, 0, 95, 2, 76, 3, 32, 7, 78, 1, 42, 8, 33, 4, 52, 
    6, 61, 8, 81, 1, 65, 3, 61, 2, 24, 4, 82, 7, 48, 5, 48, 0, 14, 
    8, 66, 1, 31, 2, 34, 5, 86, 0, 53, 6, 33, 7, 11, 3, 88, 4, 65, 
    4, 96, 0,  5, 6, 25, 5, 99, 1, 16, 7, 92, 2, 76, 3, 85, 8, 65, 
    7, 51, 0, 40, 5, 16, 8, 77, 4, 42, 6, 40, 1, 70, 3, 85, 2, 26, 
    5, 63, 8, 67, 1, 58, 2, 78, 6, 69, 7, 61, 4, 79, 3, 98, 0, 12, 
    2, 19, 6, 69, 1, 55, 5, 31, 3, 25, 8, 14, 4, 23, 7, 84, 0, 15, 
    6, 93, 4, 83, 3, 21, 8, 48, 7, 78, 2, 65, 0, 33, 5, 20, 1, 77, 
    7, 24, 5, 62, 0, 38, 2, 97, 6, 21, 4, 53, 3, 38, 8, 97, 1, 59
  };
  const int q6684[] = {
    9, 9, // Number of jobs and machines
    8, 78, 0, 13, 7, 18, 1, 37, 2, 64, 4, 31, 6, 90, 5, 57, 3, 31, 
    0, 19, 1, 46, 7, 42, 3, 90, 8, 49, 2,  3, 5,  3, 6, 73, 4, 53, 
    0, 67, 2, 21, 6, 79, 8, 34, 3, 16, 1,  6, 5, 44, 4, 12, 7, 29, 
    6, 57, 8,  2, 5, 88, 0, 29, 7,  9, 2, 53, 4,  9, 1, 62, 3, 46, 
    8, 13, 4, 46, 1, 65, 0, 56, 6,  4, 3, 48, 2, 78, 7, 31, 5, 65, 
    2, 17, 1, 12, 5, 85, 6, 69, 8, 38, 4, 80, 7, 83, 0, 96, 3, 48, 
    5, 33, 0, 14, 3, 11, 2, 83, 1,  1, 7,  7, 4, 64, 6, 91, 8, 78, 
    3,  6, 7, 29, 4,  9, 8, 39, 2, 30, 1, 14, 5, 94, 0, 96, 6, 25, 
    1, 97, 5, 88, 8, 77, 6, 78, 3, 27, 2, 34, 7, 34, 4, 35, 0, 93
  };
  const int q6685[] = {
    9, 9, // Number of jobs and machines
    0, 89, 1, 55, 4, 67, 2, 13, 8, 47, 6, 32, 5, 53, 7,  5, 3, 90, 
    0,  5, 6, 32, 2, 16, 1, 83, 8,  2, 4, 24, 5, 53, 3, 70, 7, 74, 
    7, 74, 6, 11, 5, 72, 1, 81, 3, 92, 0, 79, 4, 39, 2, 27, 8, 49, 
    6, 39, 7,  8, 0, 48, 2, 69, 1, 44, 5, 23, 4, 86, 8, 41, 3, 12, 
    1, 67, 5, 73, 8, 25, 7, 92, 3, 50, 6,  3, 2,  9, 4, 88, 0, 27, 
    5, 50, 7, 39, 0,  2, 1, 36, 8, 74, 6, 48, 2, 64, 4, 11, 3, 54, 
    5, 35, 8, 53, 2, 14, 0, 50, 6, 36, 3, 20, 7, 58, 1, 37, 4, 47, 
    0, 65, 4, 45, 7, 55, 3, 71, 2, 61, 5, 40, 6, 26, 8, 82, 1, 29, 
    5, 61, 6, 65, 4, 12, 8, 18, 3, 52, 1,  6, 7, 14, 2, 64, 0, 44
  };
  const int q6686[] = {
    9, 9, // Number of jobs and machines
    1,  5, 4, 42, 3, 18, 5, 98, 8, 94, 7, 63, 6, 15, 0, 37, 2,  4, 
    5, 51, 8, 35, 3,  1, 6,  1, 2, 61, 0, 77, 7, 80, 1, 43, 4, 42, 
    2, 69, 0, 65, 3, 45, 8,  9, 7, 45, 1,  8, 4, 53, 5, 83, 6, 95, 
    5, 16, 2, 28, 0, 26, 1, 47, 3, 40, 4, 48, 7, 80, 8,  6, 6, 18, 
    5, 38, 6, 32, 0, 93, 1, 31, 8, 67, 4, 14, 2, 37, 3, 41, 7, 22, 
    1, 80, 3, 44, 0, 21, 7, 56, 4, 50, 6, 65, 8, 12, 5, 65, 2, 14, 
    4, 66, 0, 21, 3, 40, 5, 98, 8, 86, 7, 21, 6, 71, 1, 94, 2, 16, 
    8, 37, 4, 99, 7, 42, 3, 79, 1, 15, 0, 17, 6, 58, 2, 32, 5, 51, 
    0, 66, 1, 45, 6, 68, 3,  8, 2, 64, 7, 45, 8, 20, 4, 88, 5, 45
  };
  const int q6687[] = {
    9, 9, // Number of jobs and machines
    7, 98, 1, 97, 6, 17, 2, 55, 8, 87, 3, 20, 0,  3, 5, 83, 4, 87, 
    5, 77, 4, 22, 1, 57, 7, 29, 6, 87, 3, 68, 2, 12, 0, 32, 8, 15, 
    3, 68, 8, 15, 5, 76, 6,  2, 7, 45, 0, 76, 2, 94, 4, 15, 1, 12, 
    0, 85, 4, 69, 7, 12, 8,  3, 5, 78, 2, 34, 6, 62, 1, 21, 3, 44, 
    0,  4, 5,  7, 1, 84, 4, 83, 2, 17, 7, 11, 3, 32, 6, 57, 8,  8, 
    8, 62, 2, 68, 0,  5, 7, 64, 1, 75, 6, 45, 3, 84, 5, 60, 4, 45, 
    6, 27, 8, 15, 0, 23, 2, 61, 5, 22, 1, 13, 3, 85, 7,  5, 4, 73, 
    4, 20, 5,  6, 8, 84, 6, 18, 7, 17, 3,  3, 0, 99, 1, 65, 2, 55, 
    4, 39, 8,  9, 5, 29, 3, 15, 0, 90, 6, 27, 2,  5, 7, 11, 1,  1
  };
  const int q6688[] = {
    9, 9, // Number of jobs and machines
    7, 73, 5,  7, 6, 53, 4,  6, 3, 17, 1, 51, 2, 45, 0, 82, 8, 17, 
    6, 33, 1, 67, 0, 26, 4, 51, 5, 82, 7, 57, 3, 20, 2, 41, 8, 63, 
    0, 71, 2, 59, 7, 69, 6,  4, 8, 70, 3, 71, 4, 75, 5, 74, 1, 46, 
    0, 83, 5, 63, 6, 83, 1, 76, 2,  1, 8, 65, 4, 28, 3, 74, 7, 77, 
    4, 19, 2, 95, 8,  6, 0, 83, 6,  8, 1,  2, 7, 96, 5, 42, 3, 24, 
    5, 64, 0, 35, 2, 91, 7, 67, 3, 34, 4, 52, 1, 36, 6, 44, 8, 11, 
    5, 99, 3, 51, 0, 71, 1,  1, 7, 49, 2, 73, 8, 14, 6, 89, 4,  8, 
    4, 24, 6,  6, 5, 62, 3, 96, 0, 31, 8, 50, 7, 88, 1, 97, 2, 22, 
    6, 83, 4, 19, 3, 82, 5, 77, 2, 42, 1, 98, 7, 46, 0,  1, 8, 51
  };
  const int q6689[] = {
    9, 9, // Number of jobs and machines
    8, 52, 3, 86, 2, 77, 1, 19, 0,  1, 4, 56, 7, 10, 5, 53, 6,  5, 
    8, 77, 7, 64, 0, 21, 2,  1, 5, 21, 6, 65, 4, 46, 1, 80, 3, 50, 
    0, 36, 7, 30, 8, 64, 6,  9, 2, 59, 1, 73, 4, 80, 5, 62, 3, 62, 
    5, 83, 0,  1, 6, 31, 3, 51, 8, 22, 1, 40, 7, 26, 2, 39, 4, 68, 
    3,  9, 2, 20, 7, 41, 5, 18, 1, 65, 0, 14, 6, 93, 4,  3, 8, 51, 
    3,  9, 5, 78, 1, 95, 4, 17, 7,  4, 2, 17, 6, 11, 8, 58, 0, 92, 
    0, 33, 7, 50, 5, 25, 3, 16, 2, 62, 8, 78, 1, 69, 6, 61, 4, 31, 
    5, 57, 6, 53, 3, 34, 0, 13, 1, 77, 8, 30, 2, 25, 7, 84, 4, 58, 
    8, 37, 5, 38, 0, 65, 6, 96, 2, 82, 7,  9, 1, 61, 3, 87, 4, 63
  };
  const int q6690[] = {
    9, 9, // Number of jobs and machines
    5, 69, 4, 28, 2, 48, 7, 69, 3, 26, 1, 65, 6, 80, 0, 31, 8, 65, 
    6,  5, 5, 59, 3, 81, 0, 31, 4, 22, 8, 23, 7, 59, 1, 75, 2, 61, 
    8, 50, 7, 13, 5, 19, 1, 99, 0, 58, 3, 76, 4, 37, 6, 37, 2, 67, 
    6, 63, 7, 66, 4, 95, 3, 53, 1, 75, 0, 12, 8, 69, 2, 56, 5, 87, 
    1, 85, 0, 30, 6, 84, 4, 13, 7, 21, 3, 94, 5, 93, 8, 98, 2, 72, 
    2, 52, 4, 83, 5, 96, 6, 60, 0, 95, 3, 17, 7, 88, 1, 24, 8, 85, 
    3, 75, 2, 65, 4, 89, 6,  6, 1, 34, 7, 23, 0, 42, 5, 95, 8, 29, 
    1, 60, 3, 61, 7, 51, 6, 60, 0, 96, 5, 43, 4, 82, 2, 41, 8, 86, 
    5, 59, 8, 54, 3, 88, 2,  3, 7,  7, 4, 89, 0, 80, 6, 70, 1, 75
  };
  const int q6691[] = {
    9, 9, // Number of jobs and machines
    7, 19, 1, 45, 3, 78, 5, 22, 6, 63, 4, 26, 8, 30, 2, 69, 0, 18, 
    0, 16, 4, 81, 8, 58, 2, 41, 6, 38, 1, 27, 5, 29, 3, 10, 7, 39, 
    1, 23, 8, 22, 6, 33, 3, 59, 4, 50, 2, 43, 0, 14, 7, 14, 5, 26, 
    3, 17, 8, 16, 5, 72, 6, 48, 1, 23, 4, 18, 2, 61, 7, 69, 0, 54, 
    0, 58, 1, 66, 3,  6, 2, 98, 5, 69, 8, 70, 4, 92, 7, 47, 6, 55, 
    3, 28, 7,  7, 0, 69, 5, 14, 2, 88, 4, 18, 6, 13, 1, 70, 8,  7, 
    0, 78, 4,  9, 7, 52, 3, 69, 1, 54, 6, 46, 2, 84, 5, 75, 8, 99, 
    3,  5, 0,  6, 4, 35, 1, 18, 5, 43, 7, 70, 8, 18, 6, 56, 2, 47, 
    6, 42, 8, 97, 0, 40, 4, 84, 2, 47, 1, 88, 5, 69, 7, 87, 3, 32
  };
  const int q6692[] = {
    9, 9, // Number of jobs and machines
    4, 72, 6, 51, 7, 23, 1, 63, 0, 58, 3, 41, 5,  2, 8, 41, 2, 83, 
    8, 21, 0, 74, 6, 39, 2,  1, 3, 50, 7, 88, 1, 34, 4, 94, 5, 25, 
    8, 35, 2, 14, 1, 24, 6, 46, 7, 51, 3, 66, 5, 38, 0, 84, 4, 88, 
    2, 24, 1, 94, 4,  6, 6, 95, 8, 56, 0, 39, 7, 33, 3, 27, 5, 87, 
    8, 26, 4, 11, 1, 51, 2,  2, 5, 45, 6, 37, 3, 58, 0, 97, 7, 95, 
    5, 25, 2, 22, 8,  9, 3, 48, 6, 35, 0, 64, 7, 40, 1, 64, 4,  4, 
    3, 41, 4, 50, 7, 53, 5, 48, 0, 66, 8, 97, 1,  2, 2, 62, 6, 20, 
    1, 67, 6, 26, 0, 50, 3, 70, 4, 82, 7, 30, 8, 24, 2, 97, 5, 11, 
    6, 37, 5, 57, 4, 31, 1, 22, 2, 55, 7, 85, 3, 73, 8,  4, 0,  2
  };
  const int q6693[] = {
    9, 9, // Number of jobs and machines
    6, 53, 1, 62, 3, 69, 0, 57, 5, 45, 4, 90, 8, 62, 2, 77, 7, 21, 
    1, 90, 0, 24, 6,  1, 8, 30, 3, 89, 2, 51, 5, 20, 7, 66, 4, 58, 
    8, 63, 5, 85, 4, 41, 0, 49, 3, 81, 1, 20, 6, 50, 2, 19, 7, 88, 
    5, 57, 2, 74, 1, 97, 8, 48, 6, 40, 4, 20, 7, 97, 3, 96, 0, 66, 
    4, 22, 8, 38, 7, 32, 1,  6, 0, 86, 2, 66, 5, 52, 3, 19, 6, 34, 
    0, 61, 2, 78, 4, 36, 7, 21, 3, 16, 8, 10, 6, 26, 5,  8, 1, 80, 
    0, 86, 7, 36, 5,  4, 8, 48, 1, 42, 2, 70, 6, 90, 3, 43, 4, 74, 
    4,  3, 2, 34, 3, 46, 6, 10, 8, 23, 7, 20, 1, 63, 0, 20, 5, 54, 
    3, 82, 7, 98, 6, 70, 4, 91, 1, 88, 5, 62, 0, 45, 2, 20, 8,  6
  };
  const int q6694[] = {
    9, 9, // Number of jobs and machines
    7, 19, 5, 35, 3, 64, 8, 81, 4, 32, 1, 85, 6, 87, 2, 29, 0, 69, 
    8, 73, 5, 41, 2, 74, 0, 66, 3, 53, 7,  6, 4, 68, 6, 10, 1, 63, 
    2,  6, 7, 25, 0,  8, 6, 85, 4, 93, 5, 49, 8, 47, 3, 43, 1, 74, 
    8, 19, 7, 59, 4, 76, 0, 80, 3, 56, 5, 97, 6,  4, 1, 68, 2, 34, 
    8,  9, 5, 68, 4, 64, 0, 50, 7, 58, 6, 42, 3, 10, 2, 58, 1, 70, 
    0, 63, 2, 27, 5, 68, 8, 89, 3, 85, 1,  1, 4, 16, 6,  7, 7, 13, 
    1, 18, 0, 21, 6, 98, 4, 40, 3, 74, 7, 10, 5, 32, 2, 48, 8, 25, 
    7, 92, 2, 51, 1, 61, 6, 47, 8, 54, 0,  2, 4, 42, 3, 79, 5, 43, 
    5, 83, 7, 25, 2, 68, 4, 16, 0, 14, 3, 72, 1, 16, 8, 87, 6, 60
  };
  const int q6695[] = {
    9, 9, // Number of jobs and machines
    8,  9, 5, 97, 2, 39, 6, 21, 1, 21, 0, 54, 4, 70, 7, 48, 3, 80, 
    7, 68, 3, 74, 5, 40, 8, 47, 1, 25, 2, 27, 0, 36, 6, 54, 4, 86, 
    8, 15, 2, 47, 6, 17, 5, 82, 4, 46, 3, 48, 1, 40, 0,  5, 7, 68, 
    6, 73, 8, 57, 7, 12, 0, 40, 2, 22, 4, 28, 1, 52, 3, 90, 5, 44, 
    8, 84, 0, 55, 5, 10, 4, 60, 2, 90, 6, 63, 3, 16, 7, 90, 1, 24, 
    2, 99, 1, 40, 4, 89, 3, 70, 6, 36, 5, 67, 7, 21, 8, 31, 0, 94, 
    7, 48, 8, 56, 2, 54, 4, 36, 5, 53, 6, 71, 0, 39, 3, 15, 1, 59, 
    4, 65, 2, 54, 8, 12, 1, 40, 6,  9, 0, 54, 3, 26, 5, 95, 7, 29, 
    5, 54, 8,  9, 2, 76, 7,  7, 6,  4, 3, 94, 1, 81, 4, 98, 0, 32
  };
  const int q6696[] = {
    9, 9, // Number of jobs and machines
    2, 98, 8, 65, 4, 26, 7, 52, 1, 18, 6, 54, 5, 95, 3,  6, 0, 84, 
    3, 99, 1, 37, 2, 75, 4, 78, 0, 63, 6, 63, 8,  5, 5, 31, 7, 52, 
    0, 47, 4,  3, 3, 34, 2, 34, 6, 91, 5, 78, 7, 86, 8, 24, 1, 83, 
    5, 18, 2, 81, 4, 79, 7, 38, 1, 67, 8, 96, 3, 77, 0, 63, 6, 16, 
    2, 74, 1, 11, 4, 17, 6, 56, 0, 41, 8, 30, 3, 23, 7, 78, 5,  1, 
    2, 53, 0, 74, 1,  5, 5, 60, 6, 47, 8,  7, 7, 27, 4, 96, 3, 18, 
    4, 57, 8, 54, 2,  8, 5, 54, 1, 63, 3, 63, 0, 39, 7, 57, 6,  2, 
    5, 53, 0, 72, 3, 97, 2, 59, 8, 87, 6, 77, 7, 59, 4, 73, 1, 95, 
    5, 39, 7, 54, 0, 54, 4, 89, 2, 98, 1, 34, 3, 35, 6, 50, 8, 35
  };
  const int q6697[] = {
    9, 9, // Number of jobs and machines
    8, 96, 3, 77, 0, 42, 4, 81, 5, 12, 1,  3, 7, 91, 6, 94, 2, 12, 
    7, 37, 0, 16, 5, 86, 4, 46, 6, 60, 8, 90, 3, 75, 2, 52, 1, 10, 
    6, 38, 5, 91, 2, 54, 1, 99, 0, 91, 8, 90, 3, 96, 4, 93, 7, 26, 
    8, 91, 7, 79, 6, 49, 3, 30, 1, 33, 5, 57, 4, 37, 0, 87, 2, 45, 
    8,  2, 1, 34, 5,  4, 6, 72, 7, 78, 2,  6, 4, 60, 0, 10, 3, 98, 
    5, 16, 4,  3, 6, 72, 1, 94, 2, 81, 7, 19, 8, 50, 0, 96, 3, 71, 
    5, 53, 1, 21, 7, 91, 4, 90, 8, 97, 3,  6, 2, 10, 6, 61, 0,  6, 
    4, 58, 5, 76, 8,  5, 0, 59, 1, 69, 3, 97, 7, 60, 2, 49, 6, 27, 
    5, 31, 3, 11, 7, 33, 6, 41, 8, 77, 2, 34, 4, 56, 0, 90, 1, 87
  };
  const int q6698[] = {
    9, 9, // Number of jobs and machines
    8, 80, 5, 16, 0, 41, 4, 48, 3,  6, 2, 79, 7, 15, 1, 90, 6, 55, 
    6, 87, 5, 21, 0, 89, 4, 85, 8, 57, 7, 61, 2,  6, 3, 14, 1, 71, 
    4, 86, 7, 59, 5, 86, 8, 31, 1, 16, 2, 36, 3, 31, 6,  4, 0, 40, 
    8, 19, 4, 70, 7, 31, 3,  8, 6, 38, 2,  1, 5, 74, 0, 47, 1, 66, 
    8, 93, 3, 34, 7, 18, 2, 80, 0, 14, 1, 76, 6, 91, 5, 49, 4, 93, 
    6, 14, 5, 43, 2, 74, 7, 55, 3,  5, 4, 46, 1, 32, 0, 19, 8, 32, 
    4, 22, 5, 52, 3, 25, 6, 21, 0,  3, 1, 91, 7, 65, 8, 84, 2, 85, 
    5, 92, 3, 32, 0, 74, 4, 58, 7, 54, 6, 73, 2, 60, 1, 49, 8, 66, 
    1, 93, 4, 75, 6, 51, 7, 71, 3, 46, 2, 42, 8, 52, 0, 82, 5,  9
  };
  const int q6699[] = {
    9, 9, // Number of jobs and machines
    8, 96, 0, 47, 6, 94, 4, 86, 7, 81, 5, 79, 2, 54, 3, 85, 1, 64, 
    6, 11, 4, 31, 3, 43, 7, 88, 5, 46, 8,  4, 2, 90, 0, 74, 1, 56, 
    4, 99, 1, 28, 8, 56, 0, 13, 2, 77, 6, 77, 7, 64, 3, 13, 5, 78, 
    4, 39, 1, 51, 0, 80, 2, 73, 6, 61, 8,  5, 5, 16, 3, 84, 7, 84, 
    5, 89, 1, 40, 0,  3, 4, 87, 8, 93, 2, 16, 3, 23, 6, 39, 7, 59, 
    6, 97, 3, 36, 4, 73, 8, 30, 2, 35, 5, 79, 7, 74, 1, 49, 0, 30, 
    4, 44, 2, 61, 3,  1, 5, 73, 8, 17, 0, 34, 6, 30, 7, 50, 1, 34, 
    5, 15, 1, 55, 7, 12, 0, 55, 6, 57, 4, 89, 3, 20, 2, 93, 8, 46, 
    8, 67, 3, 85, 0, 38, 2, 51, 4, 41, 7, 94, 5, 85, 1,  7, 6, 19
  };
  const int q6700[] = {
    9, 9, // Number of jobs and machines
    8, 69, 6, 66, 1, 33, 5, 58, 7, 49, 2, 31, 4, 90, 0, 34, 3, 60, 
    1, 54, 3, 41, 0, 42, 4, 99, 6, 74, 2, 41, 5, 74, 7, 45, 8, 16, 
    0, 36, 5, 66, 7, 50, 1, 81, 6, 47, 2, 14, 8, 29, 4,  6, 3, 93, 
    6, 49, 2, 35, 0, 65, 5, 96, 8, 72, 3, 33, 1, 96, 4, 24, 7, 68, 
    3, 75, 4, 32, 6, 77, 8, 13, 2, 35, 5, 69, 1, 94, 0, 23, 7, 40, 
    3, 24, 6, 68, 4, 62, 8, 73, 5, 61, 1, 15, 7, 63, 2, 17, 0, 14, 
    6, 85, 5, 74, 2, 28, 8, 79, 1, 91, 7,  8, 0, 93, 4, 23, 3, 81, 
    2, 37, 7, 68, 0, 38, 5, 72, 3, 79, 6, 17, 4, 92, 8, 36, 1,  5, 
    2, 88, 0, 77, 3, 80, 1, 54, 6, 81, 5, 89, 7, 14, 4, 19, 8, 60
  };
  const int q6701[] = {
    9, 9, // Number of jobs and machines
    8, 33, 2,  8, 7, 97, 3, 24, 6, 62, 0, 10, 5, 41, 1, 19, 4, 99, 
    8, 51, 6, 77, 3, 58, 7, 90, 5, 93, 1, 70, 0, 91, 2, 23, 4, 28, 
    5,  6, 8, 40, 0, 56, 2, 87, 1,  8, 7, 37, 3, 82, 4, 78, 6, 46, 
    3, 32, 1, 82, 2, 80, 8, 34, 6, 72, 0,  3, 5, 49, 4, 54, 7, 78, 
    7,  7, 6, 70, 0, 13, 8, 93, 4, 98, 2, 85, 1, 51, 3, 99, 5,  8, 
    7, 61, 3, 19, 8, 74, 1, 69, 4, 33, 5, 42, 6, 96, 0, 24, 2, 23, 
    8, 33, 7, 28, 5, 59, 4, 56, 3, 68, 0, 54, 6, 98, 2, 35, 1, 74, 
    7, 71, 4, 24, 8, 31, 5, 79, 0, 94, 1, 62, 2, 84, 6,  7, 3, 12, 
    7, 22, 0, 52, 5, 67, 1,  1, 3, 83, 6, 95, 4, 42, 2, 95, 8, 53
  };
  const int q6702[] = {
    9, 9, // Number of jobs and machines
    3, 40, 0, 84, 1, 72, 8,  8, 4, 24, 2, 68, 5, 96, 7, 81, 6, 16, 
    7, 74, 6, 60, 1, 87, 0, 50, 8, 55, 4,  1, 5, 37, 2, 78, 3, 71, 
    8, 25, 5, 75, 3, 54, 4, 67, 7, 75, 0, 66, 1, 26, 6, 76, 2, 72, 
    1, 15, 8, 28, 3, 19, 7, 70, 4, 48, 5, 55, 2, 44, 6, 18, 0, 42, 
    1, 14, 8, 52, 2, 25, 4, 52, 7, 82, 3, 77, 5, 51, 0, 60, 6, 45, 
    6, 14, 5, 23, 1,  3, 0, 39, 7, 23, 2, 24, 8, 44, 3,  3, 4, 82, 
    7, 79, 5, 95, 1, 36, 2, 77, 4, 83, 8,  7, 6, 75, 0, 50, 3, 42, 
    6, 61, 3, 39, 7, 81, 1, 74, 2, 65, 8, 93, 5, 17, 4, 94, 0, 87, 
    5,  5, 1, 73, 0, 34, 3, 87, 6, 25, 4, 74, 8, 38, 7, 67, 2, 36
  };
  const int q6703[] = {
    9, 9, // Number of jobs and machines
    4, 38, 0, 84, 3, 39, 6, 93, 8, 84, 2, 48, 7, 18, 1, 63, 5, 12, 
    4,  5, 8, 90, 2, 10, 5, 50, 7, 61, 0, 50, 6, 55, 3, 55, 1, 46, 
    7, 81, 3, 21, 5, 52, 6, 22, 1, 38, 2,  2, 4, 35, 8, 36, 0,  5, 
    7,  1, 2, 71, 6, 39, 8, 88, 4, 33, 1,  7, 5, 13, 3, 82, 0, 22, 
    8, 24, 5,  1, 7, 26, 4, 75, 1, 13, 3, 23, 2, 34, 0, 67, 6, 68, 
    3, 87, 5, 47, 8, 47, 0, 40, 1, 47, 2, 35, 4, 95, 7,  8, 6, 91, 
    8, 93, 2, 51, 0, 87, 4, 54, 5, 14, 7, 34, 3, 58, 6, 81, 1, 88, 
    1, 95, 5, 81, 6, 47, 2, 48, 3, 79, 7, 76, 4, 66, 0, 65, 8, 76, 
    6, 57, 1, 50, 0, 63, 4, 57, 5, 63, 8, 80, 2, 51, 3, 50, 7, 85
  };
  const int q6704[] = {
    9, 9, // Number of jobs and machines
    8, 66, 4, 11, 2, 61, 6, 42, 3, 41, 0, 32, 1, 85, 7, 95, 5, 74, 
    1, 84, 4, 70, 8, 15, 0, 56, 5, 68, 3, 61, 2, 74, 7, 53, 6, 53, 
    8, 86, 0, 33, 3, 75, 2, 58, 1, 52, 5, 66, 4, 97, 6, 95, 7, 49, 
    8, 89, 4, 74, 0, 13, 1, 57, 3, 29, 2, 21, 5, 12, 6, 65, 7, 96, 
    5,  2, 7, 56, 8, 26, 2, 13, 1, 59, 6, 84, 0, 17, 4, 60, 3, 64, 
    6, 29, 5, 91, 4,  4, 3, 97, 2, 98, 8, 52, 7, 46, 1, 61, 0, 14, 
    6,  3, 8, 14, 2, 79, 1, 75, 5,  6, 7, 89, 4, 98, 3, 20, 0, 78, 
    6, 73, 1, 94, 7, 97, 3, 11, 5, 26, 0,  6, 2, 36, 4, 17, 8, 97, 
    5, 64, 0, 18, 3, 14, 2, 72, 8, 23, 4, 49, 1, 94, 7, 81, 6, 96
  };
  const int q6705[] = {
    9, 9, // Number of jobs and machines
    2, 34, 5, 48, 6,  1, 3, 15, 4, 17, 0, 42, 1, 71, 8, 57, 7, 31, 
    2, 40, 8, 30, 7, 86, 3, 39, 6, 25, 1, 13, 0, 31, 5, 49, 4, 30, 
    8, 81, 1, 25, 0, 31, 3, 44, 5,  6, 7, 96, 4, 34, 6, 24, 2, 65, 
    0, 63, 5, 61, 4, 46, 3,  8, 7,  9, 6, 33, 1,  8, 8, 17, 2, 75, 
    7, 65, 2, 14, 8, 24, 3, 50, 4,  3, 1, 28, 6, 18, 0, 36, 5, 44, 
    3, 36, 6, 43, 2, 50, 4, 32, 0, 57, 7,  8, 8, 29, 5, 96, 1, 29, 
    7, 73, 2, 23, 1, 99, 5, 75, 8, 57, 6, 11, 0, 17, 4, 71, 3, 43, 
    4,  5, 7, 26, 8, 32, 0, 13, 5, 87, 3, 87, 1, 84, 2, 41, 6, 85, 
    1, 89, 6, 26, 8, 81, 5, 18, 4, 49, 3,  8, 2, 72, 7, 93, 0, 23
  };
  const int q6706[] = {
    9, 9, // Number of jobs and machines
    8, 66, 0, 15, 5, 15, 1,  6, 6, 54, 7, 45, 3, 52, 2, 79, 4, 18, 
    4, 44, 1,  2, 2, 71, 7,  1, 5, 80, 8, 62, 6, 80, 3, 94, 0, 31, 
    6, 42, 2, 87, 8, 28, 1, 17, 3, 48, 5, 67, 7, 84, 4, 53, 0, 94, 
    8, 18, 7, 32, 5, 99, 6, 60, 4, 57, 2, 40, 1, 38, 0, 99, 3, 12, 
    5, 78, 4, 13, 3, 10, 8, 62, 2, 47, 1, 71, 0, 80, 6, 17, 7, 13, 
    6, 28, 1, 60, 7, 93, 3, 28, 0, 60, 2, 46, 5, 96, 8, 87, 4, 59, 
    7, 35, 1,  2, 2, 91, 5, 62, 0, 39, 4,  5, 8, 29, 3, 94, 6, 38, 
    4, 72, 2,  1, 7, 87, 1, 13, 8, 39, 6, 37, 3, 65, 0, 15, 5,  1, 
    3, 21, 2, 33, 6, 19, 4, 93, 0,  1, 5, 93, 7, 82, 1, 52, 8, 93
  };
  const int q6707[] = {
    9, 9, // Number of jobs and machines
    8, 68, 0, 99, 2, 12, 5, 47, 4, 94, 3, 74, 6, 57, 7, 58, 1, 14, 
    3, 19, 8, 16, 7, 26, 5, 90, 6, 57, 2, 91, 1, 91, 4, 36, 0, 59, 
    0, 95, 2, 85, 6, 51, 8, 48, 7, 22, 3, 86, 4, 98, 5, 36, 1, 26, 
    2, 13, 3, 63, 4, 56, 0, 71, 6, 14, 8, 39, 5, 82, 1, 75, 7, 52, 
    8, 17, 3,  8, 7, 42, 1, 36, 6, 38, 0, 98, 5, 44, 4, 95, 2, 19, 
    8, 81, 1, 68, 4, 90, 2, 33, 5, 99, 7, 61, 6, 15, 3, 26, 0, 64, 
    4, 13, 1, 68, 6, 34, 5,  2, 0, 85, 2, 46, 7, 23, 3, 91, 8, 86, 
    0, 36, 3, 94, 4, 23, 5,  4, 1, 82, 6, 17, 7, 16, 2, 62, 8, 27, 
    3, 58, 0, 51, 4, 63, 6,  3, 2, 95, 7, 17, 8, 88, 1, 94, 5, 74
  };
  const int q6708[] = {
    9, 9, // Number of jobs and machines
    3, 82, 6, 41, 2, 20, 4, 32, 7, 73, 0, 13, 1, 94, 5, 76, 8, 35, 
    8, 16, 6, 48, 3, 95, 1, 64, 0, 36, 7, 17, 5,  9, 4, 21, 2, 22, 
    8, 93, 0,  8, 6,  9, 1, 98, 3, 73, 7, 47, 5, 14, 4, 73, 2, 25, 
    5, 39, 4,  5, 6, 12, 0,  8, 2, 29, 7, 28, 3, 19, 1, 37, 8, 70, 
    3, 92, 6, 34, 2, 76, 8, 54, 5, 47, 0, 41, 7, 47, 4,  7, 1, 97, 
    3, 23, 2, 54, 4, 18, 7, 79, 8, 78, 0, 69, 5,  8, 1, 11, 6, 43, 
    3, 51, 7, 60, 8, 63, 6, 68, 2, 15, 4, 18, 0, 54, 1, 27, 5, 44, 
    2, 50, 7, 27, 5, 82, 4, 72, 8, 58, 0, 91, 3,  8, 1, 65, 6,  2, 
    4, 17, 5, 33, 3, 55, 7, 23, 8, 79, 2, 50, 1,  2, 0, 84, 6, 57
  };
  const int q6709[] = {
    9, 9, // Number of jobs and machines
    2, 56, 7, 79, 3, 39, 0, 63, 8, 71, 6,  6, 1, 38, 4, 40, 5, 29, 
    2, 33, 3, 95, 0, 82, 4, 42, 6, 26, 7, 71, 1, 72, 5,  3, 8,  2, 
    5, 33, 1, 70, 8,  6, 3,  8, 6, 59, 2, 62, 7, 40, 0, 12, 4, 21, 
    8, 37, 7, 89, 0, 25, 3, 38, 6, 35, 2, 88, 5, 69, 1, 99, 4, 51, 
    2, 26, 4, 15, 1, 57, 5, 16, 0, 90, 8, 46, 7, 20, 3, 36, 6, 44, 
    0, 91, 8, 37, 3,  4, 6, 84, 7, 84, 1, 60, 5,  4, 2, 32, 4,  3, 
    1, 63, 0, 51, 8, 84, 3, 47, 2, 95, 7, 23, 6, 87, 5,  1, 4, 20, 
    0, 71, 5, 95, 4, 69, 1, 18, 3, 93, 6, 80, 7, 73, 8, 96, 2, 90, 
    4, 31, 0, 87, 8, 42, 3, 86, 2, 43, 6, 33, 5, 97, 7, 59, 1, 83
  };
  const int q6710[] = {
    9, 9, // Number of jobs and machines
    2, 38, 4, 99, 6, 17, 1, 25, 7,  3, 5, 19, 8, 56, 3, 34, 0, 64, 
    8, 37, 6, 45, 3, 50, 5, 75, 0, 19, 1, 36, 7, 61, 2,  8, 4,  2, 
    3, 62, 2, 74, 6, 58, 0, 12, 1, 32, 4, 39, 8, 45, 5, 96, 7, 41, 
    8, 15, 6, 13, 3, 72, 7, 19, 1, 65, 5, 84, 2, 35, 4, 61, 0, 20, 
    2, 49, 8, 82, 4, 82, 5, 17, 1, 38, 6, 19, 3, 86, 0, 10, 7, 93, 
    6, 55, 0, 62, 4, 22, 5, 14, 2, 29, 8,  3, 1, 17, 7, 59, 3, 30, 
    2, 95, 1, 37, 7, 12, 5, 64, 8, 52, 6, 44, 4, 76, 0, 19, 3, 21, 
    7, 17, 5, 88, 0, 11, 4, 35, 8, 73, 2, 86, 1, 79, 6, 88, 3,  9, 
    3, 50, 0, 32, 5,  7, 4, 23, 1, 94, 6, 11, 8, 65, 2, 78, 7, 92
  };
  const int q6711[] = {
    9, 9, // Number of jobs and machines
    2, 89, 0,  5, 7, 52, 1, 93, 6,  7, 3, 22, 5, 13, 8, 76, 4, 17, 
    5, 74, 8, 67, 3, 22, 1, 71, 2,  3, 4, 72, 7, 82, 0, 90, 6, 35, 
    2, 52, 4, 48, 7, 90, 6, 16, 1, 48, 0, 80, 8, 75, 5, 38, 3,  5, 
    3, 48, 1, 86, 6, 81, 0, 97, 7, 37, 5, 37, 8,  2, 4, 76, 2, 75, 
    5, 41, 2, 15, 7, 67, 4, 12, 0, 31, 6, 98, 1, 94, 8, 53, 3, 26, 
    3, 60, 8,  6, 0, 42, 1,  8, 4,  4, 2,  7, 6, 74, 7, 18, 5, 16, 
    5, 84, 1, 10, 2, 74, 6, 97, 7, 28, 3, 50, 4, 18, 8, 90, 0, 49, 
    3, 81, 1, 57, 8, 57, 4,  1, 6, 13, 0, 71, 2, 68, 5, 40, 7, 99, 
    3, 61, 0, 66, 4,  6, 5, 98, 2, 97, 1, 87, 8, 96, 7, 33, 6, 50
  };
  const int q6712[] = {
    9, 9, // Number of jobs and machines
    8, 19, 0, 84, 6, 63, 1, 29, 7, 14, 4, 70, 5, 52, 2, 51, 3, 61, 
    2, 19, 8, 77, 0, 44, 3, 99, 7, 21, 5, 78, 1, 56, 4, 62, 6, 59, 
    1, 97, 4, 82, 7, 31, 8, 35, 6, 51, 5, 50, 2, 18, 3, 60, 0, 21, 
    2, 34, 0,  8, 5, 43, 8,  1, 6, 78, 1, 21, 7, 12, 4, 33, 3, 95, 
    6, 44, 4, 54, 0, 53, 8, 39, 5, 47, 2, 44, 7, 14, 1, 26, 3, 25, 
    7, 86, 6, 17, 4, 38, 5, 17, 1, 98, 0, 36, 3, 83, 2, 96, 8, 45, 
    6, 66, 0, 93, 1, 12, 4, 39, 2, 75, 3, 96, 7, 13, 8, 75, 5, 53, 
    6, 31, 8, 72, 3, 99, 0, 28, 1, 44, 7,  9, 4, 45, 2, 76, 5, 75, 
    4, 13, 6, 90, 7, 76, 5, 83, 8,  2, 0, 57, 1, 12, 3, 65, 2, 54
  };
  const int q6713[] = {
    9, 9, // Number of jobs and machines
    3, 99, 1, 73, 5, 42, 8, 79, 0, 35, 7, 14, 6, 22, 4, 87, 2, 68, 
    8, 62, 0,  5, 3, 23, 5, 57, 7, 41, 1, 41, 2, 50, 6, 18, 4, 66, 
    7, 39, 1, 83, 5,  9, 0, 85, 3, 16, 6, 61, 2, 12, 4, 78, 8, 71, 
    2, 27, 6, 33, 3, 22, 5, 43, 0, 74, 4,  3, 1, 47, 8,  9, 7, 69, 
    7, 15, 5, 47, 1, 24, 2, 78, 0, 86, 4, 30, 3, 77, 6, 50, 8, 50, 
    7, 63, 3, 92, 1, 11, 6, 27, 2, 10, 0, 38, 4, 18, 8, 87, 5, 84, 
    4, 29, 0, 38, 6, 60, 7, 52, 5, 80, 1, 54, 2, 48, 3, 67, 8, 34, 
    1, 40, 2, 24, 3, 79, 6, 35, 5, 42, 7, 29, 0, 52, 4,  9, 8, 44, 
    2, 57, 3, 50, 5, 81, 4, 31, 6, 90, 8, 85, 1, 55, 7, 10, 0, 49
  };
  const int q6714[] = {
    9, 9, // Number of jobs and machines
    6, 28, 0, 53, 4, 25, 3, 71, 8, 54, 7, 39, 1,  8, 2, 94, 5, 54, 
    5,  3, 7, 57, 2, 68, 0, 76, 1, 12, 4, 82, 6, 90, 3, 79, 8, 30, 
    2, 91, 3, 34, 7, 75, 4, 63, 5, 29, 0, 86, 1, 29, 8, 92, 6, 78, 
    5, 64, 6, 73, 2, 60, 0, 49, 8, 67, 7, 95, 3, 57, 1, 56, 4, 15, 
    4, 69, 2,  4, 6, 62, 1, 98, 5, 87, 8, 19, 0, 70, 7, 51, 3,  5, 
    0, 86, 3, 29, 6, 89, 2, 35, 7, 35, 5, 48, 1, 85, 8, 27, 4, 33, 
    0, 83, 1, 98, 2, 19, 5, 84, 4, 41, 7, 29, 6, 87, 3,  9, 8, 67, 
    6, 60, 4, 46, 2, 67, 7, 74, 3,  1, 1, 18, 8,  8, 0,  7, 5, 26, 
    7, 20, 6, 42, 8, 60, 1, 39, 4, 66, 0, 59, 2, 36, 5, 14, 3, 73
  };
  const int q6715[] = {
    9, 9, // Number of jobs and machines
    6, 11, 3, 48, 2, 22, 0, 71, 8, 89, 1, 40, 4, 12, 7, 88, 5, 43, 
    1, 28, 2, 31, 3, 30, 5, 76, 6, 23, 7, 95, 4, 85, 0, 91, 8, 67, 
    8,  5, 5, 86, 0,  6, 4, 38, 2, 29, 6, 67, 7, 67, 1, 13, 3, 92, 
    8, 70, 3, 15, 6, 46, 1, 45, 7, 84, 0, 14, 4, 20, 2, 92, 5, 71, 
    7, 43, 5, 88, 1, 27, 2, 84, 0, 46, 4, 32, 6, 31, 3, 21, 8, 39, 
    7, 45, 5, 77, 2, 52, 1, 21, 4, 74, 6, 53, 8,  2, 0, 79, 3, 54, 
    1, 83, 3, 15, 4, 25, 5, 59, 7, 40, 2, 28, 0, 94, 8, 33, 6, 62, 
    8, 26, 4, 97, 0, 91, 2, 16, 1, 31, 7, 66, 5, 58, 3, 51, 6, 38, 
    8, 35, 0, 73, 7,  6, 5, 41, 3, 77, 1, 76, 2, 49, 4, 89, 6, 52
  };
  const int q6716[] = {
    9, 9, // Number of jobs and machines
    1, 57, 5, 12, 0, 70, 6, 77, 7, 48, 8, 16, 4, 71, 3, 29, 2, 42, 
    2, 83, 8, 33, 6, 62, 5, 51, 0,  3, 3, 79, 4, 60, 7,  5, 1, 80, 
    0, 85, 4, 74, 1, 36, 2, 95, 8, 97, 5, 56, 7, 80, 3,  7, 6, 41, 
    2, 35, 0, 31, 8, 61, 1, 98, 5, 30, 4,  1, 3, 73, 6, 27, 7, 45, 
    3, 97, 7, 55, 6, 49, 1, 71, 0, 32, 4, 54, 8, 59, 5, 63, 2, 41, 
    6, 40, 0, 86, 1, 36, 7, 59, 8, 79, 5, 24, 4, 94, 3, 46, 2, 78, 
    4, 55, 0, 28, 3, 25, 2, 45, 1, 11, 5, 17, 8,  4, 6, 66, 7, 81, 
    1, 57, 8, 57, 2, 20, 6, 16, 3, 99, 4, 88, 7, 69, 0, 90, 5, 47, 
    7, 97, 1, 52, 6,  2, 4, 67, 2, 81, 0, 32, 8, 70, 5, 74, 3, 86
  };
  const int q6717[] = {
    9, 9, // Number of jobs and machines
    0,  5, 4, 60, 1, 71, 2,  6, 8, 59, 3, 72, 6, 50, 5, 28, 7, 54, 
    5, 93, 3, 57, 2, 38, 8, 83, 0, 67, 6, 44, 4,  9, 7, 72, 1, 43, 
    5, 58, 8, 43, 7, 22, 2,  5, 3, 17, 1, 22, 4, 41, 0, 79, 6, 78, 
    6, 84, 2, 57, 0, 87, 5, 98, 3,  7, 1, 50, 7, 22, 8, 85, 4, 51, 
    7, 31, 0, 60, 1, 40, 2, 47, 3, 56, 6, 24, 8, 10, 5, 11, 4, 54, 
    0, 54, 4, 94, 3, 69, 2,  4, 5, 71, 7, 16, 1, 38, 6, 39, 8,  1, 
    8, 74, 6, 11, 0, 61, 3, 32, 1, 25, 2, 57, 4, 82, 7, 96, 5, 51, 
    8, 29, 7, 10, 2,  8, 1, 34, 4, 47, 5,  6, 3,  7, 6, 25, 0, 85, 
    6, 74, 5, 34, 1, 52, 7, 94, 8, 64, 0, 92, 4, 25, 2, 32, 3, 53
  };
  const int q6718[] = {
    9, 9, // Number of jobs and machines
    8, 66, 7,  7, 6, 42, 5, 53, 4, 42, 0, 78, 3, 67, 2, 66, 1, 78, 
    1, 57, 4,  7, 3, 40, 7, 15, 8, 12, 6, 64, 0, 15, 2, 62, 5, 66, 
    1, 25, 5, 94, 2, 61, 3, 63, 6, 74, 4, 99, 0, 80, 8, 40, 7, 11, 
    5, 11, 7, 67, 3,  8, 6, 79, 1, 49, 2, 10, 4,  5, 8, 30, 0, 39, 
    0, 75, 2, 98, 3, 92, 4, 88, 5, 17, 1, 31, 6, 54, 8, 13, 7, 82, 
    3, 47, 2, 32, 5, 84, 8, 82, 0, 26, 4, 50, 7, 75, 6, 34, 1, 73, 
    4, 11, 3, 80, 2,  2, 5, 88, 6, 88, 0, 90, 1, 65, 8, 55, 7, 18, 
    2, 33, 7, 98, 1, 82, 5, 68, 4,  5, 0, 41, 8, 18, 6, 38, 3, 31, 
    4, 63, 6, 46, 8, 98, 5, 92, 0, 55, 3, 51, 2,  3, 7, 84, 1, 54
  };
  const int q6719[] = {
    9, 9, // Number of jobs and machines
    5, 86, 2, 32, 8, 50, 7, 72, 1, 17, 3, 58, 6, 12, 4, 25, 0, 96, 
    1, 65, 0, 10, 3, 49, 4, 34, 2, 10, 8, 45, 7, 39, 6, 31, 5, 55, 
    8, 75, 2, 21, 3, 73, 6, 54, 5, 18, 7, 19, 4, 66, 0, 54, 1, 50, 
    6, 77, 1, 99, 0, 85, 3, 15, 7, 90, 4,  4, 5, 92, 8, 52, 2, 77, 
    5, 16, 3, 81, 7, 78, 8, 12, 0, 62, 1,  1, 4, 29, 2, 75, 6, 59, 
    1, 81, 6, 59, 0,  2, 2, 67, 5, 99, 8, 51, 4, 47, 3, 52, 7, 30, 
    2, 68, 7,  5, 4, 87, 0, 25, 5,  2, 8, 73, 3, 23, 1, 73, 6,  7, 
    6, 49, 8, 32, 3,  5, 7, 63, 0, 84, 4, 43, 2, 21, 5, 77, 1, 82, 
    1, 17, 0, 31, 2, 96, 8, 37, 7,  1, 4, 51, 6, 13, 5, 22, 3, 36
  };
  const int q6720[] = {
    9, 9, // Number of jobs and machines
    8, 21, 7, 44, 1, 22, 3, 95, 6, 22, 0, 79, 4, 58, 2, 86, 5, 91, 
    1,  8, 5, 80, 3, 89, 4, 60, 2, 42, 8, 66, 0, 15, 6, 53, 7, 50, 
    3, 35, 6, 90, 4, 61, 8, 20, 1, 98, 0, 35, 7, 70, 2, 41, 5, 45, 
    6,  8, 7, 86, 8, 29, 5, 10, 1, 57, 0, 94, 3, 45, 4,  9, 2, 18, 
    7, 37, 1,  4, 3, 73, 2, 54, 8, 72, 0, 59, 6, 80, 5, 39, 4, 39, 
    4, 75, 0, 89, 7, 80, 8, 34, 2,  3, 5, 57, 1, 46, 3, 66, 6, 22, 
    0, 40, 8, 88, 5, 38, 7, 71, 4, 49, 1, 14, 6, 17, 2, 33, 3, 29, 
    6, 75, 3, 42, 8, 42, 4, 88, 7, 89, 0, 33, 5, 23, 1, 86, 2, 50, 
    8, 73, 7, 24, 4, 93, 5,  3, 6, 72, 0, 35, 3, 13, 1, 68, 2, 25
  };
  const int q6721[] = {
    9, 9, // Number of jobs and machines
    5, 24, 4, 48, 7, 13, 1, 41, 6, 56, 2, 24, 0, 30, 8, 68, 3,  7, 
    8, 93, 2, 90, 6, 45, 5, 73, 3, 75, 0, 78, 1, 71, 4, 12, 7, 63, 
    7, 12, 6, 52, 0,  2, 3, 82, 1, 38, 4, 10, 5, 99, 2, 60, 8, 36, 
    0, 23, 6, 18, 1, 71, 7, 60, 3,  3, 8, 50, 2,  4, 4, 60, 5, 59, 
    3, 97, 4, 80, 8, 17, 1, 57, 7, 33, 6, 55, 0,  1, 2,  3, 5, 84, 
    0, 34, 4, 56, 1, 20, 6,  8, 3, 60, 8, 47, 2, 75, 7, 63, 5, 75, 
    4, 55, 2, 36, 5, 96, 3, 74, 7, 36, 1, 30, 0, 70, 8,  8, 6,  5, 
    6, 88, 7, 27, 1, 53, 3, 76, 2, 79, 5, 30, 8, 52, 4, 23, 0, 86, 
    0, 41, 5, 68, 1, 32, 3, 47, 7, 72, 8, 82, 6, 70, 2, 20, 4, 65
  };
  const int q6722[] = {
    9, 9, // Number of jobs and machines
    5, 25, 0, 80, 3, 91, 4, 49, 1, 62, 7, 34, 6, 98, 8,  9, 2, 25, 
    5, 37, 6, 76, 1, 78, 2, 87, 8, 23, 3, 56, 0, 93, 4, 16, 7, 92, 
    6, 35, 1,  6, 7,  9, 3, 60, 2, 53, 5,  2, 0,  3, 8, 76, 4, 85, 
    0, 64, 2, 89, 5, 53, 8, 17, 3, 55, 4,  2, 6, 59, 7, 77, 1, 49, 
    5, 59, 7, 62, 8, 90, 0, 24, 4, 83, 2, 33, 1,  3, 3, 50, 6, 49, 
    3, 12, 1, 51, 0, 47, 8, 91, 4, 68, 7, 79, 6,  2, 5, 70, 2, 68, 
    4, 55, 6, 30, 5, 79, 8, 46, 3, 84, 2,  7, 0, 81, 1, 27, 7,  7, 
    3, 84, 5, 26, 7, 36, 8, 96, 6, 10, 0, 24, 2, 93, 4, 93, 1, 13, 
    6, 85, 4, 63, 0, 68, 8, 39, 7, 37, 2,  8, 5, 81, 3, 78, 1, 40
  };
  const int q6723[] = {
    9, 9, // Number of jobs and machines
    6, 94, 0, 18, 2, 16, 1, 41, 3, 86, 4, 86, 8, 88, 7, 18, 5, 72, 
    5, 39, 7, 95, 8, 65, 1, 28, 3, 48, 6, 35, 0, 26, 2, 97, 4, 78, 
    1, 94, 0, 44, 2, 31, 6, 38, 4, 93, 5, 74, 7, 43, 8, 12, 3,  9, 
    1, 60, 0,  1, 4,  4, 6, 10, 8, 66, 3, 20, 5, 41, 2,  4, 7, 47, 
    8, 89, 3, 49, 7, 51, 4, 92, 2, 60, 5, 58, 0, 75, 6, 50, 1, 40, 
    2, 75, 3,  1, 6, 83, 1, 63, 4, 45, 0, 34, 5, 12, 7, 69, 8, 28, 
    1, 37, 6, 98, 2, 79, 0,  6, 5, 64, 4, 42, 7, 40, 3, 96, 8, 76, 
    7, 40, 5, 68, 2, 34, 8, 53, 6, 26, 1, 32, 3, 52, 0, 71, 4,  9, 
    6, 56, 7, 33, 5,  9, 3, 43, 1, 80, 0, 77, 8, 16, 4, 16, 2, 51
  };
  const int q6724[] = {
    9, 9, // Number of jobs and machines
    0, 70, 2, 46, 6, 74, 1, 34, 5, 78, 8, 15, 7, 80, 4, 42, 3,  4, 
    2,  4, 1, 57, 3, 51, 7, 36, 8, 61, 6, 74, 5, 76, 4, 44, 0, 62, 
    6, 67, 7, 90, 2, 26, 1, 71, 4, 88, 3, 27, 8, 37, 5, 91, 0,  1, 
    0, 67, 5, 29, 2, 42, 3, 63, 6, 62, 8, 74, 4, 89, 1, 49, 7, 34, 
    7, 58, 1, 59, 6, 94, 4, 38, 8, 82, 2, 15, 0, 22, 5, 89, 3, 35, 
    2, 15, 8, 60, 6, 44, 4, 58, 7, 38, 3, 39, 1, 92, 0, 80, 5, 10, 
    1, 90, 3, 92, 7, 14, 2, 85, 6, 30, 8, 15, 4, 67, 5, 95, 0, 76, 
    0, 29, 7, 82, 2, 88, 1, 73, 6, 58, 5, 84, 4, 47, 3, 98, 8, 52, 
    6, 19, 1, 54, 8, 97, 2,  1, 7, 27, 0, 42, 3, 48, 5, 89, 4, 74
  };
  const int q6725[] = {
    9, 9, // Number of jobs and machines
    2, 27, 4, 52, 3, 17, 0, 81, 1, 88, 8, 82, 6, 15, 5, 32, 7, 70, 
    8, 51, 7, 44, 4,  2, 1, 11, 6, 38, 0, 44, 5, 51, 2, 33, 3, 74, 
    1,  8, 6, 24, 3,  1, 4, 64, 8, 82, 2, 25, 0, 65, 5, 83, 7, 34, 
    8, 50, 0, 28, 7, 97, 5, 15, 6, 65, 3, 38, 1, 32, 4, 87, 2, 36, 
    0, 46, 1, 77, 5, 63, 7, 75, 2, 18, 4, 38, 6, 89, 8, 93, 3, 40, 
    5, 70, 4, 11, 3, 15, 7, 86, 8, 24, 6, 14, 1, 25, 2, 22, 0, 95, 
    7, 56, 4, 31, 1, 92, 0, 90, 5, 73, 6, 53, 3,  7, 2, 18, 8, 57, 
    2, 34, 3, 55, 7, 34, 1,  6, 6, 19, 5, 99, 4, 56, 8, 61, 0, 63, 
    3, 94, 0, 17, 5, 54, 6, 22, 4, 70, 8, 46, 7, 76, 1, 50, 2, 11
  };
  const int q6726[] = {
    9, 9, // Number of jobs and machines
    3, 63, 1, 59, 7, 85, 2, 58, 4, 71, 0, 26, 5,  9, 6, 35, 8, 47, 
    2, 11, 5, 73, 3, 58, 0, 63, 8, 95, 1, 42, 4, 85, 7, 53, 6, 63, 
    5, 58, 4, 47, 1, 12, 2,  2, 6, 98, 7, 27, 0, 54, 3, 18, 8, 41, 
    1, 33, 2, 16, 8, 86, 7,  1, 3, 97, 0, 18, 6, 49, 4, 46, 5, 78, 
    4, 60, 3, 73, 1, 17, 0, 55, 6, 23, 7,  6, 8,  1, 5, 79, 2, 31, 
    8, 82, 1, 89, 4, 13, 5, 95, 6, 82, 3, 25, 2,  2, 7, 64, 0, 41, 
    6, 98, 0, 76, 8,  7, 2, 74, 5, 67, 1, 71, 7, 87, 3, 94, 4, 48, 
    3, 72, 1,  6, 0, 25, 8, 54, 5, 46, 6, 91, 2, 52, 4, 22, 7,  8, 
    8, 81, 3, 15, 1, 96, 4, 52, 6, 63, 5, 61, 0,  1, 7, 89, 2, 82
  };
  const int q6727[] = {
    9, 9, // Number of jobs and machines
    0, 32, 6, 50, 3, 67, 5, 68, 4, 85, 7, 68, 8, 34, 2, 95, 1, 42, 
    0, 14, 5, 66, 1,  3, 4,  1, 3,  7, 8, 66, 2, 13, 7, 26, 6, 31, 
    2,  6, 7, 99, 3, 91, 1, 47, 8, 36, 5, 21, 4, 13, 0, 82, 6, 98, 
    4, 10, 5, 16, 7, 57, 0, 93, 8, 61, 2, 73, 3,  5, 1, 86, 6, 42, 
    0, 80, 1,  7, 3, 53, 6, 90, 7, 82, 4, 52, 2, 70, 8, 99, 5, 24, 
    1, 64, 4, 84, 0,  8, 5,  2, 8, 42, 6, 53, 3, 65, 7, 38, 2, 12, 
    5, 28, 6, 27, 4, 29, 0, 43, 2, 53, 8,  7, 1, 43, 3, 38, 7, 76, 
    8, 53, 1, 52, 0, 20, 6, 42, 3, 83, 2, 14, 7, 10, 5, 79, 4, 70, 
    3, 19, 7, 21, 1, 78, 6, 26, 0, 47, 4, 34, 5,  9, 2, 14, 8, 14
  };
  const int q6728[] = {
    9, 9, // Number of jobs and machines
    8, 52, 3, 68, 5, 14, 1, 42, 4, 69, 6,  6, 7, 71, 0, 55, 2, 15, 
    1, 26, 7,  4, 8, 82, 3, 75, 4, 69, 5, 40, 6, 90, 0, 21, 2, 26, 
    3, 37, 7, 33, 8, 83, 4, 47, 5,  7, 1, 40, 0, 72, 2, 33, 6, 98, 
    3, 66, 5, 70, 0, 13, 4,  5, 6, 81, 8, 96, 7, 40, 2, 72, 1, 20, 
    1, 91, 4, 89, 2, 91, 5, 11, 6, 23, 8, 17, 3, 94, 7, 71, 0, 98, 
    1, 43, 4, 88, 3,  8, 0,  4, 2, 41, 8, 76, 6, 20, 7,  7, 5, 16, 
    5, 26, 4, 58, 8,  9, 3, 47, 0, 22, 7, 97, 2, 40, 1, 78, 6, 89, 
    1, 89, 8, 86, 0, 14, 6, 88, 5, 98, 3, 35, 2, 15, 7, 66, 4,  7, 
    5, 24, 0, 13, 2,  7, 8, 74, 7, 72, 1, 44, 3, 38, 6, 55, 4,  7
  };
  const int q6729[] = {
    9, 9, // Number of jobs and machines
    6, 45, 7, 20, 2, 70, 0, 95, 5, 99, 3, 29, 4, 66, 8, 43, 1, 28, 
    7, 56, 6, 79, 5, 65, 0, 17, 2, 67, 3, 79, 8, 69, 4, 33, 1,  3, 
    0, 47, 2, 31, 4, 36, 5, 38, 8, 22, 3, 16, 1, 35, 7, 44, 6, 96, 
    8, 97, 0, 18, 6, 18, 3,  9, 1, 46, 2,  8, 5, 20, 4, 77, 7, 54, 
    0, 80, 6, 85, 7, 31, 5, 88, 4, 33, 3, 46, 1, 85, 2, 84, 8, 97, 
    6, 65, 7, 65, 1, 61, 0, 82, 8,  5, 5, 72, 3, 35, 2, 19, 4, 70, 
    6, 39, 7, 10, 3, 14, 0, 32, 4, 15, 8,  5, 2, 69, 1, 36, 5, 90, 
    4,  6, 7, 83, 5, 73, 8, 25, 0, 30, 1, 85, 3, 27, 2, 30, 6, 19, 
    4, 62, 1, 58, 6, 24, 7,  8, 8, 90, 0, 54, 3, 27, 2, 47, 5, 76
  };
  const int q6730[] = {
    9, 9, // Number of jobs and machines
    1, 95, 6, 62, 7, 94, 4, 79, 5, 81, 3, 98, 0, 37, 2, 38, 8, 83, 
    3, 12, 8, 20, 4, 67, 0, 75, 7, 20, 2, 68, 5, 19, 6, 59, 1, 95, 
    8, 93, 5, 92, 3, 15, 1, 55, 2, 62, 4, 78, 7, 75, 6, 18, 0, 62, 
    1, 88, 6, 32, 7, 53, 3, 90, 0, 94, 5, 92, 4, 80, 2, 69, 8, 32, 
    2, 26, 4, 27, 7, 85, 6, 26, 5, 89, 1, 81, 3, 20, 8, 83, 0, 46, 
    6,  7, 7, 20, 5, 56, 1, 25, 3, 19, 4, 10, 0, 32, 2, 72, 8, 51, 
    7, 36, 5, 71, 1, 11, 2, 92, 0, 60, 4, 75, 3, 90, 6, 91, 8, 61, 
    5, 28, 8, 27, 7, 39, 2, 40, 6, 31, 1, 86, 3, 51, 4, 43, 0, 18, 
    5, 44, 0, 44, 1,  7, 6, 55, 2, 83, 3, 61, 7, 43, 4, 76, 8,  8
  };
  const int q6731[] = {
    9, 9, // Number of jobs and machines
    5, 63, 3,  4, 2, 24, 6, 13, 1, 90, 7, 48, 0, 62, 4, 56, 8, 25, 
    8, 37, 4, 95, 6, 92, 7, 52, 1, 33, 0, 33, 2, 77, 3, 10, 5, 13, 
    2, 95, 5, 92, 1,  5, 6,  8, 4,  4, 8, 64, 3, 58, 7, 44, 0, 17, 
    8, 48, 0, 88, 6, 56, 1, 81, 5, 59, 4,  4, 2, 86, 3, 36, 7, 47, 
    3, 85, 7, 29, 4, 63, 1,  7, 8, 87, 0, 94, 6, 98, 2, 58, 5, 99, 
    3, 56, 5,  4, 0, 27, 2, 85, 4, 21, 6, 74, 1, 87, 8, 41, 7, 51, 
    4, 88, 8, 44, 7, 25, 1,  2, 3, 25, 5, 54, 0, 84, 6, 43, 2, 29, 
    4,  1, 1, 60, 6, 36, 2, 98, 0, 44, 5, 37, 3, 56, 8, 84, 7, 57, 
    3, 39, 7, 39, 6,  9, 5, 67, 8, 53, 1, 83, 0, 78, 4, 74, 2, 81
  };
  const int q6732[] = {
    9, 9, // Number of jobs and machines
    0, 23, 2, 97, 7, 78, 5, 78, 6, 37, 4, 65, 1, 99, 8, 14, 3, 37, 
    3, 19, 0, 97, 6, 94, 1, 85, 7, 29, 8, 73, 4, 66, 5, 56, 2, 68, 
    3, 94, 4, 21, 2, 95, 6, 95, 0, 35, 7, 33, 5, 48, 8, 13, 1, 16, 
    3, 98, 0, 89, 6, 35, 1, 40, 5, 10, 4, 70, 2,  6, 8, 69, 7, 40, 
    2, 14, 6, 17, 5, 24, 8, 49, 3, 95, 1, 75, 0, 53, 4, 27, 7, 17, 
    7, 67, 3, 56, 1, 41, 2, 74, 6, 12, 8, 78, 0, 37, 5, 80, 4, 24, 
    0, 12, 2, 85, 5, 12, 7, 58, 4, 26, 3, 21, 6, 65, 8, 15, 1, 91, 
    7, 28, 0,  4, 8, 79, 4, 16, 5, 82, 6, 85, 1, 22, 3, 92, 2,  4, 
    7, 77, 6, 98, 1, 70, 3, 14, 2, 65, 5,  2, 8, 91, 4, 77, 0, 88
  };
  const int q6733[] = {
    9, 9, // Number of jobs and machines
    5, 98, 3, 63, 6,  2, 8, 67, 7, 81, 0, 75, 2, 59, 1, 57, 4, 89, 
    8, 59, 6, 10, 1, 28, 2, 30, 5, 49, 4, 89, 3, 68, 0, 43, 7, 62, 
    0, 65, 1, 64, 3, 76, 6, 62, 8, 18, 4, 53, 5, 17, 7, 50, 2, 31, 
    4, 23, 5, 84, 7, 50, 6, 58, 1, 76, 0, 84, 8, 71, 3, 29, 2, 53, 
    1, 76, 8, 88, 5, 83, 0, 46, 4, 89, 7, 97, 2, 18, 3, 10, 6, 12, 
    6, 36, 2, 36, 5, 49, 0, 99, 3, 77, 7, 54, 8, 76, 4, 68, 1, 28, 
    6, 55, 1, 19, 3, 61, 2, 15, 8,  4, 5, 63, 7, 31, 4, 70, 0, 25, 
    0, 95, 2, 73, 7, 64, 3, 83, 4, 96, 1, 87, 6, 73, 8,  5, 5, 59, 
    4, 88, 0, 41, 3, 10, 1, 71, 2, 69, 8,  1, 7, 27, 5, 18, 6,  5
  };
  const int q6734[] = {
    9, 9, // Number of jobs and machines
    0, 70, 5, 62, 8, 29, 4,  8, 7, 29, 2,  3, 3, 39, 6, 46, 1, 26, 
    4, 63, 5, 99, 2, 22, 7, 87, 1, 14, 8, 26, 3, 52, 0, 79, 6, 29, 
    7, 80, 3, 91, 5, 18, 6, 48, 1, 23, 4, 54, 2, 55, 0, 57, 8, 86, 
    8, 71, 7,  3, 2, 11, 0, 84, 5, 90, 6, 15, 4, 17, 1, 63, 3, 27, 
    1,  3, 2, 31, 7, 39, 3, 79, 5, 67, 8, 41, 6, 67, 0, 77, 4, 36, 
    8, 57, 7, 22, 0, 53, 3,  1, 4, 88, 5, 60, 1, 32, 6, 42, 2, 29, 
    8, 36, 7,  7, 6, 40, 3, 99, 5, 68, 2, 93, 1, 45, 0, 36, 4, 82, 
    6, 56, 3, 70, 8, 77, 2, 70, 4, 72, 7,  7, 5, 45, 1, 86, 0, 92, 
    0, 23, 2, 46, 6, 73, 3, 24, 7, 54, 1, 47, 4, 55, 8, 88, 5, 29
  };
  const int q6735[] = {
    9, 9, // Number of jobs and machines
    4, 86, 3, 90, 7, 69, 5, 98, 2, 40, 8, 87, 1, 19, 0, 39, 6, 56, 
    1, 15, 2, 36, 8, 98, 0, 69, 7, 32, 3, 47, 4,  5, 5, 37, 6, 54, 
    7, 66, 2, 83, 5, 27, 4, 74, 6, 71, 1, 78, 0, 56, 8, 60, 3, 84, 
    5, 54, 8, 86, 7, 63, 0, 87, 1, 53, 2, 87, 6, 54, 4, 23, 3, 56, 
    2,  7, 7,  8, 6, 76, 0, 18, 5, 52, 4, 68, 1, 49, 3, 21, 8, 49, 
    5,  1, 3, 21, 4, 17, 6, 62, 8, 38, 1, 66, 7, 72, 0, 63, 2, 99, 
    1, 30, 6, 56, 5, 77, 2, 38, 3, 31, 8, 31, 4,  9, 0, 35, 7, 48, 
    5, 46, 8,  9, 6,  9, 3, 19, 7, 39, 2, 35, 1, 51, 4, 69, 0, 43, 
    8, 32, 5, 70, 7, 19, 6, 74, 3, 92, 4, 74, 0, 61, 1, 56, 2, 61
  };
  const int q6736[] = {
    9, 9, // Number of jobs and machines
    6, 12, 3, 77, 8, 68, 1, 17, 4, 49, 7, 73, 0, 15, 5, 95, 2, 38, 
    0, 47, 3, 98, 5, 81, 8, 58, 2, 41, 4, 43, 6, 28, 7, 40, 1, 54, 
    3,  6, 1, 17, 4, 86, 7, 74, 6, 84, 8, 36, 2, 10, 0, 37, 5, 72, 
    0, 53, 7, 75, 6, 78, 1, 52, 2, 65, 5, 31, 8, 20, 4,  3, 3,  2, 
    8, 68, 5, 81, 0, 54, 1,  3, 2, 71, 3, 68, 4, 89, 7, 26, 6, 99, 
    0, 45, 1,  9, 2, 23, 5, 67, 8, 74, 4, 55, 7, 46, 6, 91, 3, 34, 
    3, 24, 5, 80, 0, 74, 8, 65, 1, 53, 2, 45, 7, 34, 6, 46, 4, 26, 
    8, 38, 0, 72, 3, 85, 6, 32, 2,  4, 4, 26, 1, 22, 7, 27, 5, 87, 
    4, 88, 6, 47, 3, 42, 5, 29, 7, 84, 1, 28, 8, 34, 0, 20, 2, 94
  };
  const int q6737[] = {
    9, 9, // Number of jobs and machines
    7, 31, 2, 69, 5, 29, 6, 32, 8, 67, 0, 59, 1, 14, 3, 58, 4, 16, 
    7,  3, 0, 73, 1, 88, 6, 10, 4, 49, 5, 30, 2, 92, 3, 29, 8, 46, 
    3, 88, 0, 69, 2, 22, 8, 48, 1, 31, 5, 23, 4, 61, 7, 23, 6, 65, 
    4, 70, 2, 68, 1, 84, 3, 52, 8, 71, 0, 36, 5, 99, 6,  4, 7, 21, 
    8, 62, 2, 67, 1, 32, 6, 62, 7, 59, 0, 86, 5, 11, 4, 12, 3, 48, 
    7, 32, 3, 31, 1, 75, 0, 65, 4, 55, 6, 68, 2, 18, 5, 34, 8, 80, 
    0, 70, 4, 80, 8, 18, 7,  6, 5, 51, 6, 33, 2, 10, 3, 63, 1, 75, 
    5, 15, 0, 68, 1, 24, 3, 58, 6, 99, 8, 75, 2, 51, 4, 18, 7, 58, 
    4, 70, 1, 97, 6, 44, 8, 58, 7, 71, 3, 21, 5, 16, 2, 49, 0, 23
  };
  const int q6738[] = {
    9, 9, // Number of jobs and machines
    2, 53, 8, 53, 5, 81, 3, 38, 6, 19, 0, 26, 4, 45, 7, 44, 1, 52, 
    3, 87, 1, 10, 6, 50, 7, 24, 2, 86, 8,  2, 4, 40, 0, 37, 5, 19, 
    3, 60, 8, 83, 6, 14, 0, 93, 1, 54, 5, 11, 2, 51, 7, 29, 4, 41, 
    2,  9, 6,  6, 3, 57, 4, 59, 7, 75, 1, 19, 5, 23, 8, 32, 0, 56, 
    6, 14, 2, 61, 7, 86, 0, 28, 1, 65, 5, 83, 8, 76, 3, 61, 4, 91, 
    6, 47, 4, 41, 2, 27, 3, 35, 0, 61, 8, 13, 1, 72, 5, 23, 7,  5, 
    0, 96, 4, 17, 2, 58, 1, 56, 6, 29, 3, 65, 8,  6, 5, 73, 7, 12, 
    7, 24, 3,  9, 8, 34, 1, 65, 6, 78, 2, 66, 5, 33, 4, 83, 0, 11, 
    0,  8, 3,  7, 6, 19, 7, 81, 2, 63, 8,  8, 4, 17, 5, 54, 1, 72
  };
  const int q6739[] = {
    9, 9, // Number of jobs and machines
    0,  3, 3, 16, 6, 35, 2, 16, 4, 29, 1, 79, 5, 78, 8, 79, 7, 88, 
    2,  8, 6, 14, 8, 51, 0, 52, 4, 58, 5,  5, 3, 84, 7, 30, 1, 12, 
    1, 17, 0, 19, 2, 47, 8, 85, 6, 35, 7, 59, 3, 17, 4, 59, 5, 93, 
    8, 51, 1, 17, 3, 70, 0, 31, 6,  1, 7, 67, 5, 28, 2, 84, 4,  7, 
    7, 58, 8, 57, 2,  6, 4, 32, 6, 17, 5, 96, 3, 35, 0, 19, 1, 21, 
    3, 50, 2, 72, 0, 96, 4, 24, 7, 59, 6, 65, 8, 51, 1, 14, 5,  1, 
    7, 85, 3, 24, 1, 14, 6, 31, 4, 34, 5, 95, 0, 16, 2, 49, 8, 94, 
    3, 24, 5, 48, 6, 74, 7, 69, 1,  8, 4,  1, 2, 60, 8, 68, 0,  9, 
    7, 48, 1, 39, 2, 34, 6, 99, 4, 89, 0,  2, 8, 20, 3, 77, 5,  4
  };
  const int q6740[] = {
    9, 9, // Number of jobs and machines
    0, 91, 4, 13, 3, 85, 2, 34, 5, 44, 7, 46, 6, 53, 1, 13, 8, 91, 
    1, 15, 0, 59, 8, 97, 7, 12, 6, 39, 2, 20, 4, 72, 3, 73, 5, 81, 
    5, 89, 3, 52, 4, 76, 2, 48, 6, 60, 0, 53, 1, 25, 7, 54, 8, 41, 
    5, 90, 1, 92, 8, 77, 6, 58, 2, 61, 4, 35, 3, 24, 7, 49, 0, 53, 
    1, 49, 5, 74, 7, 60, 3, 25, 4, 91, 0, 84, 6, 23, 8, 92, 2, 69, 
    7, 54, 0,  6, 5, 41, 3,  3, 2, 56, 8, 56, 4, 86, 1, 38, 6, 77, 
    5, 67, 8,  6, 2,  3, 0, 73, 6, 70, 3, 19, 7, 13, 4, 61, 1, 86, 
    6, 55, 3, 16, 7, 83, 8, 76, 4, 52, 0, 52, 1, 77, 2, 37, 5, 89, 
    2, 27, 1, 80, 6, 97, 7, 30, 8, 15, 0, 37, 4, 81, 3, 61, 5, 12
  };
  const int q6741[] = {
    9, 9, // Number of jobs and machines
    1, 70, 0, 45, 3, 89, 4, 27, 7, 36, 5,  1, 2, 89, 6, 53, 8, 32, 
    8, 37, 6,  5, 4,  6, 7, 82, 5, 80, 0, 73, 1, 60, 3, 52, 2, 30, 
    1,  6, 8, 69, 7,  7, 0, 21, 6, 94, 4, 17, 5, 27, 2, 51, 3, 29, 
    1, 51, 5, 65, 7, 31, 6, 68, 0,  8, 2, 94, 8, 45, 4, 85, 3, 98, 
    1, 24, 7, 54, 2, 59, 6, 27, 3, 84, 8, 99, 4, 73, 0, 17, 5, 68, 
    6, 30, 7, 55, 3, 13, 5, 66, 8, 82, 1, 70, 4, 87, 0, 28, 2, 41, 
    6, 30, 0, 49, 7, 47, 1, 26, 2, 97, 5, 77, 8, 22, 3, 60, 4, 31, 
    2, 53, 0, 77, 5,  5, 7, 68, 4, 51, 8, 15, 3, 37, 1, 77, 6, 26, 
    4, 25, 2, 61, 0,  2, 5, 58, 7, 80, 3, 45, 1, 40, 6, 28, 8, 63
  };
  const int q6742[] = {
    9, 9, // Number of jobs and machines
    4, 42, 3, 73, 2, 43, 1, 86, 6, 83, 0, 63, 8, 39, 5, 85, 7, 96, 
    6, 91, 4, 95, 2, 76, 3, 41, 8,  5, 0, 94, 1, 85, 7, 34, 5, 29, 
    3, 87, 8,  4, 2, 64, 1, 48, 5, 55, 7, 34, 0, 72, 4, 86, 6, 62, 
    0, 18, 8, 91, 6, 70, 5, 65, 4, 34, 3, 36, 2, 43, 1, 93, 7, 90, 
    7, 77, 3, 43, 0, 68, 2, 65, 6, 11, 1, 47, 5, 33, 4, 44, 8, 76, 
    1, 69, 0, 32, 7, 29, 6, 47, 3, 50, 2, 20, 5, 88, 8,  7, 4, 26, 
    2,  9, 4, 13, 1, 53, 7, 89, 3, 59, 6, 79, 0, 37, 8, 61, 5, 13, 
    8, 68, 4, 41, 7, 47, 2, 80, 6, 52, 0, 55, 1, 43, 3, 45, 5, 49, 
    1, 90, 2, 91, 5, 59, 0, 94, 6, 90, 3, 88, 8, 43, 4, 82, 7, 22
  };
  const int q6743[] = {
    9, 9, // Number of jobs and machines
    4, 64, 7, 11, 8, 29, 6,  3, 2,  8, 0, 73, 5, 51, 1, 27, 3, 13, 
    1, 28, 8, 31, 5, 76, 4, 48, 0, 36, 7, 17, 3, 81, 2, 20, 6,  3, 
    6, 96, 5, 65, 2, 36, 1, 95, 3, 36, 0, 73, 7, 12, 4, 55, 8, 26, 
    3, 33, 6, 90, 0,  5, 4,  2, 8, 58, 7, 55, 5,  4, 2, 32, 1, 14, 
    6, 31, 5, 94, 0, 78, 2, 59, 4, 94, 7, 53, 3, 95, 8, 66, 1, 77, 
    1, 82, 7, 83, 2,  2, 5, 33, 8, 49, 4, 93, 3, 99, 0, 58, 6, 75, 
    5, 36, 7,  2, 0, 88, 8,  7, 1, 36, 3, 33, 4, 25, 2, 61, 6, 83, 
    0, 74, 5, 99, 3, 88, 1, 30, 7,  7, 6, 69, 8, 33, 2, 59, 4, 82, 
    6,  9, 1, 54, 7, 22, 3, 61, 2, 39, 4, 92, 0, 22, 8, 88, 5, 48
  };
  const int q6744[] = {
    9, 9, // Number of jobs and machines
    8, 61, 5,  5, 6, 60, 2, 79, 7, 41, 4,  5, 1,  4, 3, 24, 0, 46, 
    6, 88, 8, 75, 3, 49, 5,  6, 4, 59, 0, 57, 1, 54, 2, 29, 7, 73, 
    1, 37, 6, 43, 8, 22, 7, 74, 0, 39, 2, 42, 4, 81, 3, 50, 5, 55, 
    7, 51, 6, 86, 2, 20, 0, 41, 5, 54, 1,  1, 3, 52, 8, 78, 4, 53, 
    0, 52, 3, 72, 4, 58, 7, 91, 6, 96, 2, 56, 8, 78, 1, 86, 5, 68, 
    3, 74, 2, 14, 8, 72, 6, 75, 1, 37, 5, 38, 4, 72, 7, 27, 0, 75, 
    6,  9, 5, 77, 0, 67, 8, 52, 1, 63, 7, 92, 3,  4, 4, 67, 2, 64, 
    2, 78, 1, 11, 3, 16, 8, 89, 5, 38, 4, 60, 0, 49, 7, 96, 6, 41, 
    8, 46, 7, 50, 3, 39, 2,  6, 4, 36, 5,  3, 6, 15, 1, 94, 0, 70
  };
  const int q6745[] = {
    9, 9, // Number of jobs and machines
    3, 53, 4, 26, 5, 58, 6, 27, 1,  8, 2, 28, 8, 23, 0, 55, 7, 84, 
    5, 44, 0, 79, 8, 58, 7, 90, 2, 36, 6, 80, 4, 33, 3, 20, 1, 57, 
    5, 56, 4, 17, 6,  4, 8, 17, 0, 98, 1, 54, 2, 20, 7, 14, 3, 14, 
    1, 21, 6, 47, 8, 98, 7,  3, 5, 17, 3, 15, 4, 85, 2, 92, 0, 77, 
    3, 55, 5, 67, 2, 41, 8, 80, 6, 99, 1, 54, 7, 23, 0, 17, 4, 52, 
    6, 26, 3, 11, 1, 46, 5,  9, 8, 32, 7, 90, 0, 29, 4, 22, 2,  5, 
    4, 49, 6, 64, 8, 76, 7, 29, 2, 95, 1, 33, 5, 73, 3, 25, 0, 22, 
    5, 38, 4, 14, 7, 82, 8, 28, 6, 56, 2, 67, 0, 88, 3,  6, 1, 28, 
    7, 54, 3, 95, 4, 61, 0,  6, 2, 60, 8, 84, 1, 46, 6, 58, 5, 94
  };
  const int q6746[] = {
    9, 9, // Number of jobs and machines
    8, 69, 3, 79, 1, 81, 4, 73, 6, 96, 0, 80, 2, 51, 5, 96, 7, 65, 
    3, 76, 1, 12, 6, 21, 5, 44, 4, 20, 0, 42, 2, 15, 7,  2, 8,  4, 
    2, 60, 5, 11, 6, 69, 8, 90, 1, 17, 3, 10, 4, 80, 7, 54, 0, 91, 
    1, 97, 0, 76, 5, 42, 8, 63, 6, 75, 4, 56, 7, 99, 2,  4, 3, 87, 
    7, 33, 4, 29, 1, 18, 6, 19, 2, 94, 0, 74, 3, 76, 8,  4, 5, 47, 
    6, 29, 0, 49, 2, 91, 4, 99, 7, 36, 3, 65, 8, 48, 5, 66, 1, 17, 
    0, 11, 3, 38, 2, 80, 8, 99, 1, 58, 7, 75, 5,  6, 6, 18, 4, 27, 
    5, 11, 6, 11, 7, 10, 0, 83, 3, 18, 2, 27, 1, 84, 4, 25, 8, 82, 
    1, 23, 4, 21, 3, 29, 8, 96, 2, 44, 5,  6, 0, 27, 7, 89, 6, 30
  };
  const int q6747[] = {
    9, 9, // Number of jobs and machines
    4, 42, 0, 61, 2, 37, 1, 79, 3, 97, 5, 57, 7, 77, 8, 37, 6, 40, 
    6, 14, 3, 59, 4, 26, 8, 32, 7, 93, 0, 84, 5, 51, 1, 18, 2, 11, 
    8, 26, 2, 12, 3, 98, 0, 24, 7, 25, 6, 70, 1, 81, 5, 81, 4, 64, 
    5, 53, 4, 28, 2, 84, 3, 44, 1, 27, 0,  9, 8, 71, 6, 49, 7, 26, 
    0, 57, 6, 32, 5, 54, 7, 73, 1, 53, 2,  1, 3, 44, 4, 53, 8, 41, 
    5, 90, 0, 13, 8, 94, 1,  3, 3, 81, 4, 94, 2, 26, 7, 65, 6, 96, 
    4,  5, 7, 70, 6,  9, 5, 58, 0, 36, 2, 36, 8,  2, 3, 52, 1, 81, 
    5, 29, 6, 65, 8, 18, 1, 61, 2, 73, 4, 11, 0, 23, 3, 99, 7, 42, 
    7, 43, 5, 26, 2, 63, 1, 88, 3, 48, 0, 36, 4, 70, 8, 85, 6, 71
  };
  const int q6748[] = {
    9, 9, // Number of jobs and machines
    7, 17, 3, 37, 6, 64, 0, 67, 5, 45, 2, 15, 1, 72, 8, 90, 4, 48, 
    2, 64, 8, 71, 7,  6, 4, 83, 1, 90, 3, 38, 6, 41, 0,  7, 5, 41, 
    1, 34, 0, 19, 2, 68, 3, 18, 4, 12, 7, 10, 5, 83, 6, 92, 8,  5, 
    7, 30, 3, 96, 2,  4, 5, 87, 0, 35, 1, 48, 8, 26, 4, 87, 6, 48, 
    1, 19, 3, 58, 5,  6, 0, 38, 8, 48, 2, 90, 6, 23, 4, 98, 7, 67, 
    1, 90, 6,  4, 0, 14, 5, 54, 8, 38, 4, 66, 3, 11, 2, 45, 7, 50, 
    6, 14, 3, 60, 0, 51, 5, 15, 2,  3, 4, 80, 1,  8, 8, 41, 7,  2, 
    1, 31, 3, 61, 4, 30, 5, 18, 8, 20, 2,  7, 6, 82, 7, 89, 0,  1, 
    0, 66, 5, 43, 8, 42, 4, 70, 6, 47, 3, 46, 2, 93, 1, 65, 7, 80
  };
  const int q6749[] = {
    9, 9, // Number of jobs and machines
    1, 96, 5, 48, 4, 17, 2, 36, 6, 37, 7, 84, 0,  3, 3, 13, 8, 27, 
    1, 26, 2, 84, 4, 73, 8, 18, 0, 18, 6, 32, 7, 68, 3, 22, 5, 82, 
    4, 53, 0, 36, 2, 74, 6, 17, 7, 67, 8, 16, 3, 24, 5, 51, 1, 91, 
    6, 39, 0, 76, 3, 20, 4, 81, 5, 33, 7, 81, 1, 98, 8, 65, 2, 52, 
    6,  3, 2, 81, 5, 96, 7, 58, 4, 76, 0, 12, 1, 55, 8, 30, 3, 76, 
    4, 61, 2,  3, 5, 12, 1,  4, 8, 64, 7, 52, 3, 57, 0, 32, 6,  7, 
    3, 97, 8, 28, 2, 16, 1, 63, 5, 59, 0, 78, 4, 45, 7, 74, 6, 96, 
    4, 25, 2, 93, 6, 31, 7, 23, 8,  5, 1, 31, 5, 10, 3, 35, 0, 47, 
    7, 82, 2, 42, 4, 12, 8, 97, 5, 40, 3, 69, 6, 60, 0, 81, 1, 88
  };
  const int q6750[] = {
    9, 9, // Number of jobs and machines
    2, 41, 0, 43, 1,  6, 8, 42, 5, 68, 4, 16, 6, 89, 3, 44, 7, 73, 
    1, 82, 6, 31, 4, 42, 0, 78, 8, 86, 7,  8, 3, 96, 2, 34, 5, 63, 
    2, 93, 1, 79, 4, 44, 3, 94, 7, 45, 0,  8, 8, 15, 5, 19, 6,  9, 
    6, 64, 7, 62, 2, 80, 5, 41, 1, 64, 4,  3, 0, 56, 3, 24, 8, 34, 
    1, 83, 8,  7, 6, 17, 5, 27, 4, 34, 2, 90, 0, 43, 7, 18, 3, 70, 
    6, 49, 8, 36, 1, 70, 2, 58, 7, 75, 4, 68, 3, 73, 5, 84, 0, 86, 
    8, 26, 7, 61, 0, 46, 4, 23, 2, 73, 5, 50, 3, 50, 1,  1, 6, 47, 
    5, 10, 7, 12, 4, 75, 8, 82, 6, 25, 0,  2, 1, 77, 2, 96, 3, 83, 
    5, 12, 0, 16, 4, 92, 6, 76, 8, 12, 3, 78, 2,  2, 7, 38, 1, 25
  };
  const int q6751[] = {
    9, 9, // Number of jobs and machines
    1, 70, 3, 68, 6, 74, 7, 32, 4, 52, 8,  4, 2, 41, 5, 79, 0, 69, 
    3, 13, 4, 51, 6, 96, 1, 44, 5, 46, 2,  3, 0, 45, 7, 60, 8, 77, 
    6, 90, 1, 73, 8, 57, 7, 41, 2, 66, 5, 77, 3, 18, 4, 27, 0, 44, 
    0, 93, 2, 30, 7, 36, 8, 81, 1, 31, 5,  8, 4, 26, 3, 27, 6, 19, 
    8, 54, 6,  7, 2, 59, 4, 19, 1, 63, 3, 47, 0, 86, 7, 22, 5, 34, 
    4,  4, 5, 26, 0, 16, 8, 77, 2,  4, 7, 23, 3,  7, 1, 70, 6, 79, 
    8, 71, 2, 72, 1, 52, 4, 71, 7, 86, 5, 17, 3,  6, 6, 13, 0, 26, 
    7, 76, 3, 71, 2, 34, 1, 73, 8, 23, 4, 63, 6, 32, 0, 42, 5,  9, 
    1, 81, 6, 81, 7, 51, 2, 87, 8, 59, 4, 85, 3, 68, 5, 33, 0, 40
  };
  const int q6752[] = {
    9, 9, // Number of jobs and machines
    5, 52, 2, 58, 7, 99, 1, 26, 3, 32, 0,  6, 8, 43, 4, 69, 6, 48, 
    3,  6, 1, 59, 4, 65, 8, 27, 2, 26, 7, 48, 6, 89, 5, 30, 0,  5, 
    0, 57, 4, 32, 5, 71, 7, 48, 6, 91, 3, 24, 1, 67, 8, 75, 2, 67, 
    8, 77, 5, 87, 1,  1, 2, 92, 7, 52, 4, 55, 6, 64, 3,  2, 0, 96, 
    3, 94, 2,  6, 7, 39, 5,  9, 6, 84, 4, 75, 0, 54, 1, 64, 8, 38, 
    1, 13, 2, 43, 5, 91, 4, 27, 0, 93, 6, 70, 7,  5, 8, 36, 3, 26, 
    5, 60, 0, 91, 4, 72, 3,  1, 7, 34, 6, 58, 8, 10, 2, 77, 1, 51, 
    8, 70, 2, 78, 1,  2, 6, 63, 4, 16, 3, 51, 5,  7, 0, 20, 7, 87, 
    2, 30, 8, 44, 5, 86, 4, 92, 0, 69, 3, 49, 6, 80, 1, 79, 7, 16
  };
  const int q6753[] = {
    9, 9, // Number of jobs and machines
    6, 59, 7, 18, 0, 83, 8, 11, 2, 18, 4, 15, 5, 73, 3, 75, 1, 65, 
    4, 10, 1, 21, 0, 96, 3, 42, 5, 56, 7, 88, 8, 16, 2,  9, 6, 44, 
    3, 13, 6, 76, 5, 55, 0, 55, 8, 33, 4,  9, 1, 18, 2, 85, 7, 25, 
    7, 80, 0, 99, 5, 97, 2, 13, 1, 19, 8, 24, 3, 73, 6, 56, 4, 80, 
    6, 32, 4, 91, 5, 66, 7, 90, 8, 49, 2, 36, 0, 68, 1, 80, 3, 49, 
    8, 54, 5, 87, 1, 11, 2, 88, 6, 98, 0, 70, 7, 55, 3, 49, 4, 95, 
    5, 99, 1, 77, 6, 99, 0, 74, 2, 69, 3, 29, 4,  3, 7, 77, 8, 39, 
    8, 69, 1, 99, 3, 56, 4, 57, 2,  4, 0, 56, 5, 96, 6, 28, 7, 81, 
    3, 50, 1, 92, 8, 56, 2, 38, 5, 15, 6, 68, 7, 51, 0, 70, 4, 53
  };
  const int q6754[] = {
    9, 9, // Number of jobs and machines
    6, 18, 7, 76, 1, 82, 4, 22, 2, 31, 5,  1, 0,  3, 3, 90, 8, 97, 
    1, 55, 2, 17, 5, 61, 4, 42, 8, 48, 7,  8, 3, 38, 0, 98, 6, 34, 
    3,  2, 7, 20, 8,  5, 0, 92, 5, 16, 2, 11, 1, 71, 4, 95, 6, 23, 
    5, 56, 6, 77, 1, 97, 2, 70, 0, 47, 3, 58, 4, 96, 8, 96, 7, 98, 
    1, 42, 3, 21, 5, 67, 8, 32, 0, 67, 7, 25, 4,  1, 2, 84, 6, 43, 
    4, 24, 8, 77, 1, 61, 6, 79, 3, 21, 0, 98, 2, 87, 5, 79, 7, 82, 
    5, 55, 6,  1, 2, 33, 8, 22, 4, 41, 7, 94, 3, 33, 0, 41, 1, 34, 
    8, 16, 6, 79, 7, 75, 5, 16, 2, 50, 3, 37, 4, 89, 0,  6, 1,  1, 
    7, 69, 1, 53, 6, 20, 2, 57, 0, 57, 3, 22, 5,  1, 8, 26, 4,  7
  };
  const int q6755[] = {
    9, 9, // Number of jobs and machines
    0, 25, 3, 43, 6,  7, 8, 76, 5, 35, 7,  5, 1, 86, 4, 81, 2, 33, 
    1,  4, 5, 75, 3, 55, 7, 14, 8, 20, 0, 37, 4, 28, 2, 92, 6, 44, 
    4,  1, 5, 46, 6,  8, 2, 61, 7, 50, 3, 28, 8, 23, 1, 39, 0, 68, 
    2, 74, 6, 57, 5, 90, 1, 76, 8, 92, 7,  8, 3, 39, 4,  4, 0, 15, 
    1, 48, 4, 80, 8, 43, 7, 96, 0, 92, 6, 41, 3, 83, 2, 29, 5, 11, 
    5, 20, 3, 44, 6, 50, 4, 68, 1, 49, 7, 87, 8, 67, 2, 84, 0, 52, 
    8, 52, 1, 87, 4, 99, 2, 95, 6, 58, 5, 48, 7, 24, 3, 13, 0, 83, 
    2, 51, 6, 10, 0, 63, 1, 30, 5, 31, 8,  6, 7, 31, 4, 15, 3, 89, 
    1, 10, 8, 44, 3, 32, 6, 89, 4, 68, 0, 58, 7, 81, 2, 96, 5, 20
  };
  const int q6756[] = {
    9, 9, // Number of jobs and machines
    3, 33, 5, 32, 7, 86, 4,  5, 8, 35, 6, 80, 2, 76, 0, 51, 1, 86, 
    1, 72, 7, 49, 5, 35, 8, 60, 2, 16, 4, 94, 3,  6, 6, 57, 0, 76, 
    5, 41, 7, 62, 4,  5, 1, 90, 6, 38, 2, 81, 8, 22, 3, 28, 0, 33, 
    5,  2, 2, 32, 3, 92, 0, 75, 7, 17, 1, 47, 8, 14, 4, 88, 6, 22, 
    4, 38, 2, 95, 5, 87, 7, 58, 8, 16, 3, 62, 1, 79, 6, 13, 0, 99, 
    5, 41, 0, 37, 6, 34, 1, 77, 8, 47, 4, 19, 2,  7, 7, 31, 3, 72, 
    4, 76, 1, 63, 0, 88, 6, 48, 7, 88, 2,  3, 5,  6, 8, 40, 3, 81, 
    1, 50, 6, 67, 4, 28, 5, 77, 8, 65, 3,  5, 0, 88, 2,  5, 7, 81, 
    8, 16, 3, 56, 1, 93, 4, 55, 0, 84, 6, 45, 2, 74, 7, 42, 5, 77
  };
  const int q6757[] = {
    9, 9, // Number of jobs and machines
    1,  4, 8, 15, 3, 16, 0,  7, 4, 27, 5, 39, 6, 75, 2, 25, 7, 80, 
    7, 59, 1, 15, 2, 49, 6, 55, 3, 64, 8, 18, 5, 98, 4,  7, 0, 30, 
    6, 82, 0, 58, 3, 35, 2, 57, 1, 38, 8, 39, 7, 80, 4, 58, 5, 73, 
    4, 28, 8,  8, 5,  2, 3, 72, 7, 28, 2, 96, 0, 49, 1, 17, 6, 68, 
    3, 57, 5, 35, 7, 25, 6, 26, 2, 49, 0, 76, 8, 84, 4, 50, 1, 54, 
    2, 94, 3, 38, 6, 44, 7, 76, 8, 19, 4, 98, 5, 59, 1, 48, 0, 92, 
    4, 59, 1,  4, 3, 55, 2, 40, 5, 68, 6,  6, 7, 67, 0,  1, 8, 56, 
    1, 37, 0, 36, 6, 95, 7, 19, 2, 13, 5, 86, 4, 98, 8, 65, 3, 87, 
    4, 69, 3, 52, 6, 78, 0, 36, 8, 84, 5,  7, 7, 31, 1, 37, 2, 79
  };
  const int q6758[] = {
    9, 9, // Number of jobs and machines
    7, 84, 3, 78, 6, 81, 4, 52, 1, 80, 2, 86, 5, 91, 8, 26, 0, 42, 
    8, 81, 5, 92, 3, 12, 4, 28, 6, 78, 2, 89, 7, 80, 0, 94, 1, 93, 
    7, 57, 0, 34, 3, 48, 6, 34, 4, 25, 1, 36, 5, 58, 8, 82, 2, 49, 
    3, 22, 6,  2, 2, 15, 8, 73, 1, 42, 5, 32, 7, 95, 0, 25, 4, 65, 
    3, 63, 5,  9, 4, 67, 0, 89, 7, 62, 8, 80, 6, 94, 2, 16, 1, 21, 
    8, 30, 6, 85, 0, 27, 2, 34, 4,  3, 5,  3, 3, 48, 7, 93, 1,  9, 
    5, 50, 4, 86, 3, 16, 7, 31, 8, 30, 1, 85, 6, 12, 0, 54, 2, 98, 
    7, 33, 4, 50, 5, 62, 2, 91, 8, 69, 1, 77, 0, 57, 3,  2, 6, 17, 
    5, 77, 1, 57, 7, 85, 3, 37, 0,  3, 6, 24, 4, 11, 8, 25, 2, 19
  };
  const int q6759[] = {
    9, 9, // Number of jobs and machines
    2, 58, 0, 41, 6, 86, 4,  8, 7,  6, 1,  5, 5,  5, 8, 73, 3, 19, 
    6, 43, 4, 78, 7, 73, 2, 56, 1,  9, 5, 65, 0, 39, 3,  4, 8, 29, 
    3, 90, 7, 92, 8, 33, 0, 72, 5, 11, 2, 74, 1, 46, 4, 34, 6,  5, 
    7, 70, 1, 64, 4, 10, 8, 34, 3, 45, 5, 97, 2, 29, 0, 36, 6, 73, 
    2, 52, 7, 21, 1, 48, 3, 36, 8, 91, 4,  7, 6, 67, 0, 93, 5, 45, 
    4, 19, 6, 43, 7, 48, 5, 63, 1, 91, 8, 21, 2, 34, 3,  7, 0, 18, 
    2, 79, 6, 88, 4, 86, 5,  5, 0, 62, 1,  4, 8, 66, 3, 54, 7, 24, 
    2,  2, 0, 65, 8, 42, 3, 23, 5, 12, 7, 78, 1, 46, 6, 86, 4, 58, 
    5, 85, 0, 28, 3,  9, 2, 16, 4, 56, 7, 95, 6, 92, 8, 50, 1, 21
  };
  const int q6760[] = {
    9, 9, // Number of jobs and machines
    1, 24, 6, 67, 8, 95, 3, 96, 4, 49, 0, 93, 2,  5, 5, 35, 7, 76, 
    3, 10, 1,  7, 8, 83, 6, 48, 2, 93, 7, 81, 5, 75, 4, 19, 0, 77, 
    5, 20, 6, 96, 7, 35, 0, 62, 8, 48, 1, 19, 2, 73, 4, 18, 3, 76, 
    7, 16, 8, 58, 1,  1, 6, 60, 2, 64, 4, 22, 0, 89, 3,  2, 5, 96, 
    8, 25, 5, 34, 4, 18, 0,  3, 3, 44, 2, 19, 6, 95, 1, 24, 7, 62, 
    3, 57, 2, 49, 5, 12, 4, 31, 1, 35, 7, 69, 8, 84, 6, 79, 0,  8, 
    1, 30, 5, 46, 3, 64, 0, 32, 7, 59, 6, 94, 2, 16, 8, 36, 4, 72, 
    7, 28, 0, 78, 2, 21, 1, 69, 8, 62, 6, 57, 3, 75, 5, 69, 4, 48, 
    1, 98, 7, 96, 2, 26, 4, 97, 5, 62, 3, 18, 0, 24, 8, 69, 6, 81
  };
  const int q6761[] = {
    9, 9, // Number of jobs and machines
    0, 72, 6, 84, 2, 51, 3, 94, 1, 59, 4, 71, 7, 19, 5,  9, 8,  1, 
    5, 27, 2, 41, 8, 21, 6, 91, 4, 72, 0, 75, 7, 20, 1, 73, 3, 92, 
    8, 86, 3, 66, 7, 54, 0, 92, 1, 93, 2, 13, 4,  4, 5, 24, 6, 62, 
    3, 27, 7, 34, 0, 54, 2, 80, 1, 61, 6, 49, 8, 59, 5, 34, 4, 83, 
    1, 45, 6, 58, 4,  8, 5, 95, 0, 82, 7, 66, 8, 13, 2, 55, 3,  7, 
    3, 52, 0, 72, 6,  1, 7,  1, 5, 99, 4, 30, 1, 24, 2, 96, 8, 97, 
    6, 43, 0, 58, 1, 98, 5, 76, 3, 21, 2, 87, 7, 87, 4, 98, 8, 44, 
    5, 52, 0, 42, 1, 76, 7, 80, 8, 49, 6, 18, 4, 13, 3, 66, 2, 48, 
    3, 44, 2, 10, 1, 80, 8, 89, 4, 73, 0, 93, 5, 52, 6, 22, 7, 42
  };
  const int q6762[] = {
    9, 9, // Number of jobs and machines
    7, 86, 2, 52, 8, 52, 3, 99, 4, 89, 0, 96, 5, 65, 6, 22, 1, 58, 
    6, 53, 8, 70, 7, 26, 2,  8, 3, 12, 1, 62, 0, 60, 5, 73, 4, 25, 
    3,  5, 8, 21, 2, 82, 7, 14, 1, 48, 0, 36, 4, 68, 6, 93, 5, 86, 
    3, 21, 1, 51, 6, 97, 7, 51, 4, 62, 5, 83, 2, 91, 0, 52, 8, 81, 
    1, 97, 7, 67, 6, 28, 2, 26, 4, 79, 8, 53, 0, 43, 5, 32, 3, 33, 
    0, 47, 5, 94, 3, 32, 7, 85, 2, 72, 8, 44, 1, 24, 6, 73, 4, 85, 
    5, 70, 0, 91, 3, 56, 4, 38, 6, 87, 8, 97, 7, 85, 1,  7, 2, 62, 
    4, 81, 6, 59, 8, 16, 5, 53, 0, 79, 2, 90, 1, 40, 7, 21, 3, 97, 
    0, 46, 7, 13, 4, 33, 2, 22, 6, 17, 5, 41, 3, 69, 1, 55, 8, 73
  };
  const int q6763[] = {
    9, 9, // Number of jobs and machines
    4, 55, 1, 51, 3, 21, 0, 46, 5, 70, 8, 42, 7, 63, 2, 12, 6, 69, 
    6,  1, 7, 81, 4, 90, 1, 92, 0, 86, 5, 82, 8, 47, 2, 90, 3, 76, 
    7, 35, 2, 54, 5,  9, 6, 93, 0, 82, 4, 65, 1,  1, 3, 93, 8, 16, 
    3, 26, 4, 63, 0, 10, 1, 91, 8, 52, 2, 42, 7, 99, 5, 59, 6, 18, 
    7, 87, 6, 58, 2, 63, 4, 14, 1, 26, 5, 56, 0, 94, 8, 23, 3, 41, 
    0,  3, 7, 46, 6, 72, 2,  8, 8,  5, 3, 31, 1, 78, 5,  2, 4,  8, 
    2, 88, 3, 20, 4, 16, 0, 75, 1, 97, 8, 49, 7, 35, 5, 46, 6, 34, 
    2, 25, 5, 35, 7, 15, 6, 50, 0, 34, 1, 43, 3, 85, 4, 92, 8, 86, 
    0, 80, 2, 80, 1, 52, 6, 77, 8, 85, 5, 28, 4, 53, 7, 47, 3, 66
  };
  const int q6764[] = {
    9, 9, // Number of jobs and machines
    7, 75, 0, 82, 8, 20, 3,  1, 2, 86, 4, 46, 5, 12, 6, 54, 1,  7, 
    0, 52, 3, 72, 7, 23, 4,  7, 2, 39, 5, 73, 1, 36, 6, 78, 8, 25, 
    0, 80, 2, 42, 1, 57, 4, 49, 3,  6, 8, 30, 6, 36, 7, 93, 5, 33, 
    8, 31, 2,  3, 5, 80, 1, 42, 3, 16, 4, 42, 7, 95, 6, 14, 0, 15, 
    8, 16, 0, 44, 3, 22, 2, 71, 5, 95, 1, 48, 6, 13, 7, 92, 4, 50, 
    4, 82, 2, 75, 6, 25, 8,  3, 0, 52, 5, 44, 3, 68, 1,  5, 7, 83, 
    0, 74, 7, 28, 6, 57, 1, 94, 3, 27, 2, 33, 4, 66, 8, 48, 5, 10, 
    2, 93, 4, 26, 0, 21, 1, 96, 5, 23, 7, 74, 8, 92, 3, 29, 6, 71, 
    5, 34, 7, 78, 1, 56, 2, 64, 4, 11, 8, 86, 3, 43, 6, 13, 0,  3
  };
  const int q6765[] = {
    9, 9, // Number of jobs and machines
    2,  3, 6, 52, 4, 75, 3, 47, 5, 63, 1, 11, 7,  3, 0, 59, 8, 38, 
    7, 28, 3, 77, 2, 48, 1, 35, 5, 40, 0, 90, 4, 11, 8, 16, 6, 18, 
    3, 85, 4, 37, 2, 38, 8, 86, 1, 44, 6, 12, 5, 26, 7, 22, 0,  1, 
    6, 85, 2,  7, 4,  4, 1, 96, 0,  5, 3, 66, 7, 28, 5, 89, 8, 12, 
    7, 98, 5, 97, 8, 76, 3, 65, 4, 18, 0, 73, 2, 41, 6, 85, 1, 61, 
    6, 23, 8, 40, 1, 77, 3, 30, 4,  4, 5, 27, 7,  5, 2,  6, 0, 19, 
    7, 93, 6, 68, 1, 96, 5, 75, 4, 66, 0, 46, 3, 59, 2, 30, 8, 44, 
    4, 26, 0, 47, 6, 13, 2, 58, 8, 98, 7, 41, 3, 39, 5, 76, 1, 20, 
    5, 69, 8, 38, 4, 11, 2, 45, 0, 77, 3,  6, 1, 53, 7, 46, 6, 95
  };
  const int q6766[] = {
    9, 9, // Number of jobs and machines
    6, 89, 3, 96, 4, 10, 8,  9, 1, 14, 0, 51, 2, 88, 7, 80, 5, 40, 
    0, 20, 6, 86, 8, 51, 7, 71, 4, 74, 3, 57, 2, 73, 5, 90, 1, 20, 
    3, 22, 2, 20, 8, 72, 5, 33, 4, 52, 0, 64, 6, 96, 1, 54, 7, 95, 
    0,  2, 7, 14, 1, 64, 3, 37, 2, 22, 8, 54, 6, 64, 4, 29, 5,  4, 
    3, 49, 8,  9, 2, 58, 0, 59, 5, 92, 7, 26, 4, 81, 1, 65, 6, 22, 
    7, 32, 5, 82, 6, 49, 3, 65, 2,  1, 1, 22, 8, 69, 4, 52, 0, 78, 
    5, 40, 1, 77, 6,  8, 2, 77, 8, 20, 4, 77, 0, 49, 7, 55, 3, 14, 
    3, 98, 4, 27, 7, 82, 6, 91, 0, 71, 1,  7, 5, 55, 2, 32, 8, 38, 
    1, 56, 3, 22, 2, 12, 7, 31, 8, 70, 4, 67, 0, 97, 5, 42, 6, 70
  };
  const int q6767[] = {
    9, 9, // Number of jobs and machines
    2, 37, 0, 94, 1, 28, 3, 14, 6, 73, 8, 24, 4, 89, 5, 86, 7, 55, 
    1, 45, 6, 41, 7, 64, 2,  5, 4, 89, 5,  4, 3, 56, 8, 98, 0, 43, 
    6, 58, 8, 46, 0, 27, 4, 21, 3, 44, 1, 38, 2, 21, 5, 81, 7, 90, 
    6, 39, 3, 89, 4, 64, 8, 12, 2, 63, 5, 78, 7, 14, 1, 70, 0, 89, 
    5, 34, 4, 50, 6, 46, 3, 81, 1, 88, 2, 31, 0, 34, 7,  9, 8, 77, 
    0, 38, 7, 13, 8,  7, 6,  2, 3, 11, 4, 78, 5, 97, 1, 60, 2, 79, 
    8, 73, 0, 90, 3, 93, 5,  5, 2, 69, 6, 31, 7, 53, 1, 22, 4, 11, 
    2, 41, 6, 91, 8, 85, 7, 11, 1,  4, 5, 34, 0, 81, 4, 88, 3,  5, 
    3, 81, 5, 79, 2, 62, 1,  7, 4, 99, 6, 32, 0,  8, 7,  3, 8, 74
  };
  const int q6768[] = {
    9, 9, // Number of jobs and machines
    4, 45, 6, 52, 2, 27, 7, 85, 1, 73, 0,  3, 8, 79, 5, 10, 3, 45, 
    4, 78, 7, 99, 5, 17, 1, 56, 8, 99, 6, 77, 0, 95, 2,  2, 3, 63, 
    3, 19, 5, 95, 1, 18, 2,  8, 4, 56, 6, 56, 0, 80, 8, 89, 7, 41, 
    1, 47, 6, 64, 3, 65, 2,  7, 7, 66, 4,  5, 0, 24, 5, 26, 8, 48, 
    1, 66, 8, 88, 4, 77, 3,  5, 6, 66, 2, 98, 5, 20, 7, 47, 0, 21, 
    5, 54, 3, 77, 1,  8, 6, 58, 0, 77, 4, 19, 2, 61, 7, 34, 8, 69, 
    6, 45, 4, 57, 8, 18, 0, 80, 7, 29, 2, 90, 5, 92, 3, 92, 1, 42, 
    6,  7, 4, 45, 8, 42, 0, 82, 5, 40, 1, 62, 2, 61, 3, 72, 7, 72, 
    7, 63, 2,  2, 6, 53, 8, 71, 3, 26, 4, 25, 1, 90, 5, 67, 0, 14
  };
  const int q6769[] = {
    9, 9, // Number of jobs and machines
    5, 87, 2, 43, 1, 75, 8, 48, 0,  3, 7, 61, 3, 69, 6, 42, 4, 18, 
    3, 24, 1, 37, 0,  9, 6, 46, 2, 17, 7, 96, 4, 35, 5, 19, 8, 28, 
    3, 43, 8, 80, 2, 41, 1, 80, 7, 77, 4, 40, 5, 55, 0, 27, 6, 91, 
    7, 43, 4, 85, 6, 18, 2, 56, 8, 44, 5, 52, 0, 82, 1, 38, 3, 92, 
    4, 45, 0, 91, 5, 42, 2, 13, 8, 36, 7, 72, 6, 54, 3, 51, 1, 81, 
    5, 29, 0, 27, 8, 28, 4, 54, 2, 13, 1, 54, 3, 58, 7, 64, 6, 38, 
    2, 74, 1, 96, 5, 29, 4, 71, 8, 43, 3, 43, 0, 66, 7, 22, 6,  3, 
    3, 46, 5, 15, 4, 90, 6, 59, 7,  3, 8, 13, 0, 54, 2, 86, 1, 72, 
    4, 44, 6, 66, 8, 17, 5, 86, 1, 20, 2, 95, 3, 21, 7, 98, 0, 43
  };
  const int q6770[] = {
    9, 9, // Number of jobs and machines
    4, 15, 6, 48, 5, 68, 8, 51, 0,  8, 2,  6, 3, 91, 7, 10, 1,  6, 
    6, 81, 8, 31, 7, 49, 0, 97, 2, 97, 4, 40, 5, 67, 3, 11, 1, 77, 
    8, 67, 6, 50, 1, 99, 2, 61, 7,  7, 0, 51, 5,  8, 3, 18, 4, 21, 
    5, 58, 6,  2, 2, 29, 4, 14, 3, 93, 7, 82, 8, 93, 0, 68, 1, 10, 
    3, 68, 0, 10, 8, 53, 5, 13, 4, 90, 7, 94, 1,  5, 6, 13, 2, 60, 
    2, 82, 8, 46, 3, 10, 1, 21, 7, 89, 6, 58, 0, 85, 5, 71, 4, 45, 
    4, 64, 7, 69, 5,  8, 3, 15, 1, 17, 2, 34, 6, 85, 8, 34, 0, 95, 
    3, 56, 1, 31, 6, 37, 0, 21, 2, 24, 4, 50, 8, 43, 5, 84, 7, 77, 
    1, 47, 4,  2, 0, 21, 6, 71, 8, 70, 7, 50, 5, 86, 2, 83, 3, 78
  };
  const int q6771[] = {
    9, 9, // Number of jobs and machines
    3, 74, 8, 29, 5, 18, 4, 60, 2, 83, 7, 36, 0, 79, 6, 66, 1, 16, 
    4, 31, 3, 72, 8, 87, 2, 67, 5, 25, 1, 15, 6, 13, 0, 47, 7, 72, 
    2, 83, 7, 93, 8, 86, 3, 20, 0, 78, 1, 41, 5, 48, 4, 10, 6, 71, 
    0, 79, 2, 98, 7, 33, 6, 93, 5, 44, 1,  2, 8, 37, 4, 34, 3, 86, 
    1, 76, 7, 47, 8, 29, 5, 39, 2, 77, 3, 81, 6, 79, 0,  7, 4, 75, 
    8, 29, 1, 72, 2, 65, 3, 46, 6, 31, 5, 32, 4, 39, 7, 32, 0, 56, 
    2, 68, 3, 57, 7, 43, 5, 60, 8, 20, 0, 92, 1, 58, 4, 63, 6, 59, 
    6, 76, 7, 15, 5, 66, 2, 67, 4, 22, 1, 59, 8, 16, 3, 11, 0, 97, 
    1, 35, 2, 17, 3, 76, 8, 30, 6, 96, 5, 24, 7, 29, 4, 51, 0, 49
  };
  const int q6772[] = {
    9, 9, // Number of jobs and machines
    6, 37, 8, 94, 1, 28, 7, 29, 5, 45, 0, 34, 3, 67, 2, 42, 4, 22, 
    7,  6, 6, 78, 8, 58, 4, 19, 5, 26, 0, 88, 2, 49, 1, 67, 3, 43, 
    1, 25, 2, 89, 0,  1, 7, 71, 4, 76, 3, 84, 6,  3, 5,  1, 8, 66, 
    0, 84, 5, 21, 4, 73, 2, 28, 3, 18, 7,  2, 1, 26, 8, 13, 6, 70, 
    2, 49, 8, 12, 7, 16, 5, 60, 4, 38, 6, 35, 1, 24, 0, 98, 3,  2, 
    4, 46, 2, 47, 8, 61, 6, 99, 0, 32, 3, 93, 7, 87, 5, 35, 1, 54, 
    4, 67, 2, 60, 3, 25, 7, 87, 0, 57, 1, 26, 8, 20, 6, 15, 5, 66, 
    2, 51, 4, 86, 1, 37, 3, 79, 8, 35, 6, 94, 7, 38, 0, 58, 5, 18, 
    5, 55, 0, 39, 4, 97, 2, 39, 8, 44, 7,  6, 6, 80, 1, 12, 3, 65
  };
  const int q6773[] = {
    9, 9, // Number of jobs and machines
    8, 82, 0, 41, 5,  7, 3, 42, 7, 80, 1, 11, 2, 20, 6,  3, 4, 63, 
    2, 27, 0, 99, 6, 48, 8, 55, 4, 10, 1, 45, 7, 43, 5,  8, 3,  3, 
    5, 21, 8, 13, 3, 99, 7, 68, 6, 57, 2, 52, 0, 63, 1, 10, 4, 13, 
    7, 24, 8, 65, 0, 86, 1, 74, 5, 43, 4, 57, 2, 58, 3, 58, 6, 26, 
    7, 23, 8, 73, 4, 66, 1, 70, 6, 44, 0, 78, 2, 50, 3, 58, 5, 21, 
    2, 29, 1,  8, 6, 40, 8, 17, 0, 32, 5, 38, 4, 87, 3, 58, 7, 27, 
    3, 78, 1, 43, 0, 18, 5, 31, 4,  8, 6, 16, 8,  7, 7,  6, 2, 70, 
    6, 20, 5, 64, 1, 10, 0, 92, 2, 65, 3, 25, 4, 53, 8, 66, 7, 83, 
    7, 92, 5,  7, 6, 35, 0, 52, 3, 18, 8, 19, 4, 41, 1, 88, 2, 44
  };
  const int q6774[] = {
    9, 9, // Number of jobs and machines
    3,  7, 1, 42, 0, 95, 4, 98, 7,  7, 5,  5, 8, 69, 2, 52, 6, 48, 
    3, 18, 5, 99, 2, 50, 1, 66, 4, 67, 7, 65, 0, 27, 6,  9, 8, 29, 
    1, 96, 6, 87, 8, 39, 3, 20, 5, 73, 7, 92, 0, 38, 4, 80, 2, 58, 
    8, 33, 2, 51, 3, 92, 1, 83, 4, 29, 7, 28, 5, 39, 6, 38, 0, 85, 
    2, 76, 4, 82, 3, 89, 0, 13, 6,  5, 1, 24, 7, 56, 8, 87, 5, 18, 
    3, 38, 0, 13, 6, 16, 4, 71, 8, 11, 7, 35, 5, 47, 1, 26, 2, 90, 
    7, 71, 1, 70, 2, 15, 3, 10, 5, 73, 6, 97, 0, 39, 4, 30, 8, 18, 
    0,  1, 4, 82, 7, 41, 2, 64, 8, 18, 3,  8, 5, 25, 6, 72, 1, 40, 
    3, 98, 1, 52, 0, 79, 7, 61, 2, 23, 4, 14, 5, 64, 6, 16, 8, 50
  };
  const int q6775[] = {
    9, 9, // Number of jobs and machines
    0, 13, 1, 95, 5, 13, 6, 34, 2, 90, 3, 60, 8, 23, 7, 42, 4, 58, 
    5, 32, 3, 93, 4, 44, 6,  1, 1,  8, 2, 86, 8, 18, 7, 91, 0, 95, 
    6, 34, 0, 17, 1, 59, 3, 25, 7, 95, 5, 33, 4, 38, 2, 70, 8, 31, 
    7, 52, 6, 26, 4, 88, 1, 36, 8, 52, 0, 11, 5, 81, 3, 77, 2, 53, 
    1, 92, 0, 32, 3, 74, 2, 70, 8, 84, 5, 18, 6, 20, 7, 30, 4,  8, 
    1, 83, 4, 23, 5, 86, 8, 14, 2, 92, 0, 83, 6, 63, 3, 73, 7,  3, 
    3, 60, 6, 56, 5, 70, 0, 58, 8, 52, 2, 31, 4, 91, 7, 67, 1, 14, 
    6, 60, 2, 41, 4, 67, 8, 59, 3, 81, 1, 84, 7, 94, 0, 12, 5, 65, 
    7,  3, 6, 52, 3, 46, 4, 14, 8,  5, 5, 55, 1, 98, 2, 24, 0, 88
  };
  const int q6776[] = {
    9, 9, // Number of jobs and machines
    8, 22, 1, 23, 5, 12, 4, 70, 2, 96, 3, 12, 6, 75, 7, 70, 0, 60, 
    3, 83, 1, 35, 0, 31, 4, 67, 6, 12, 7, 91, 8, 11, 5, 12, 2, 72, 
    3, 43, 1, 33, 8, 12, 7, 64, 5, 23, 2, 91, 4, 53, 6, 81, 0, 40, 
    7, 54, 6, 21, 8, 15, 4, 29, 5, 84, 0, 27, 1, 38, 2,  5, 3, 95, 
    0, 37, 1, 46, 2,  6, 6, 47, 5, 57, 8, 28, 7, 18, 3, 61, 4, 26, 
    3,  1, 2,  6, 7, 52, 6, 43, 1, 33, 5, 71, 8, 38, 4, 82, 0, 54, 
    4, 33, 0, 84, 5, 20, 6, 75, 3, 50, 7, 91, 8, 25, 2, 37, 1, 43, 
    0, 41, 8, 27, 3, 75, 1, 63, 2, 63, 7, 75, 4, 32, 6, 90, 5, 66, 
    4, 56, 7, 85, 8, 67, 3, 39, 1, 76, 6, 60, 0, 85, 2, 72, 5,  1
  };
  const int q6777[] = {
    9, 9, // Number of jobs and machines
    6, 55, 5, 84, 4, 51, 7, 58, 0,  3, 8, 14, 3, 92, 1, 19, 2, 92, 
    8, 62, 7, 71, 1, 97, 2, 34, 6, 61, 4, 26, 0, 34, 3, 23, 5, 43, 
    5, 95, 4, 88, 8, 16, 2, 81, 7, 58, 6, 30, 0, 54, 3, 18, 1, 23, 
    1, 78, 2, 79, 3, 46, 4, 27, 6, 73, 7, 25, 0, 28, 5, 57, 8, 67, 
    6, 66, 2, 86, 4, 78, 7, 46, 0, 31, 3, 68, 5, 54, 1, 30, 8, 24, 
    8, 59, 1, 49, 7, 77, 0, 31, 4, 88, 5, 75, 3, 37, 2, 36, 6, 53, 
    3, 32, 5, 96, 2, 86, 7, 12, 6, 91, 4,  9, 8,  2, 0, 82, 1, 87, 
    1, 68, 8, 32, 6, 85, 5, 10, 7, 35, 3, 89, 0,  1, 2, 78, 4, 78, 
    7, 40, 5, 72, 2, 79, 1, 36, 6, 46, 8, 26, 3, 92, 0, 11, 4, 48
  };
  const int q6778[] = {
    9, 9, // Number of jobs and machines
    1, 48, 3, 18, 8, 53, 2,  5, 5, 25, 7, 15, 4, 38, 0,  9, 6, 98, 
    6, 54, 1, 43, 7, 98, 4, 52, 5, 87, 8, 18, 0, 56, 2, 23, 3,  8, 
    2, 53, 1, 30, 6, 34, 0, 87, 8, 31, 3, 32, 5, 44, 4, 95, 7, 22, 
    0, 94, 5, 84, 3, 37, 2,  7, 6, 54, 8,  9, 4, 57, 1, 23, 7, 75, 
    0, 38, 5, 86, 8, 73, 1, 96, 6, 28, 7, 87, 3, 40, 4, 81, 2,  7, 
    8, 20, 5, 58, 3, 78, 7, 50, 4, 56, 2, 85, 6, 71, 1, 13, 0, 53, 
    7,  3, 5, 84, 8, 76, 3, 25, 1, 67, 0, 86, 2, 38, 6, 18, 4, 86, 
    2, 90, 5, 30, 0, 50, 3, 30, 1, 37, 4, 40, 7, 77, 8, 75, 6,  2, 
    0, 53, 3, 68, 7,  1, 1,  8, 6, 95, 8, 82, 5, 28, 2, 13, 4, 91
  };
  const int q6779[] = {
    9, 9, // Number of jobs and machines
    0, 79, 8, 68, 4, 30, 6, 66, 7, 87, 1, 84, 2, 97, 3,  7, 5, 48, 
    2, 63, 6, 61, 8, 46, 7, 14, 0, 77, 1, 85, 3, 17, 5, 53, 4, 39, 
    5, 37, 2,  4, 0, 37, 1, 52, 7, 11, 6, 74, 8, 21, 3, 61, 4, 54, 
    0, 69, 6, 77, 1,  9, 2, 64, 3, 92, 4, 95, 7, 58, 5, 39, 8, 51, 
    6, 58, 1, 59, 5, 49, 0, 60, 3, 81, 4, 34, 2, 13, 7, 89, 8, 33, 
    8, 18, 5, 87, 6, 88, 2, 90, 4, 47, 7, 43, 3, 16, 0, 13, 1, 40, 
    4, 34, 7, 49, 2, 48, 0, 44, 5, 33, 8, 69, 6, 68, 1, 40, 3, 22, 
    4, 63, 0, 43, 8, 10, 2,  4, 6, 64, 7, 17, 3, 98, 1, 74, 5, 56, 
    0, 67, 6, 41, 1, 58, 2, 27, 5, 96, 8,  6, 3, 98, 4, 69, 7, 96
  };
  const int q6780[] = {
    9, 9, // Number of jobs and machines
    5, 80, 8, 14, 1, 73, 3, 30, 6, 23, 7,  1, 2, 70, 4, 35, 0, 40, 
    1, 42, 3, 72, 0, 61, 4, 25, 8, 28, 5, 69, 2,  9, 7, 22, 6, 50, 
    6, 39, 3, 74, 4, 50, 2, 73, 7, 55, 0, 82, 5,  4, 1, 34, 8, 22, 
    8, 91, 2, 30, 6, 33, 0, 77, 5, 55, 7, 78, 4, 61, 3, 33, 1, 91, 
    4, 97, 8, 57, 5, 26, 1, 21, 6, 62, 7, 38, 2, 13, 0, 19, 3, 76, 
    0, 65, 4, 81, 8, 79, 5, 60, 1, 61, 6, 54, 2, 85, 7, 11, 3, 93, 
    8, 21, 6, 43, 7, 35, 0, 42, 4,  7, 5, 73, 3, 11, 2,  6, 1, 68, 
    8, 86, 4, 76, 6, 42, 0, 31, 5, 94, 2, 52, 7,  2, 3, 62, 1, 22, 
    5, 98, 4, 65, 6, 97, 3,  7, 8, 28, 7, 84, 0, 92, 1, 22, 2, 81
  };
  const int q6781[] = {
    9, 9, // Number of jobs and machines
    2, 61, 8, 67, 7, 24, 3, 51, 4, 58, 0, 74, 5, 32, 6, 88, 1,  6, 
    3, 52, 7, 38, 0, 80, 5, 32, 6, 25, 2, 38, 8, 64, 1,  6, 4, 19, 
    3, 45, 8, 40, 7, 64, 6, 55, 2, 94, 0, 46, 5, 69, 1, 89, 4, 99, 
    6,  8, 8,  9, 1, 67, 3,  9, 7, 69, 5, 40, 4, 31, 0, 43, 2, 90, 
    1, 58, 4, 67, 6, 51, 5, 72, 2, 23, 0, 47, 3, 13, 8, 95, 7, 83, 
    2, 13, 4, 30, 3, 28, 1, 63, 6, 27, 0,  2, 8, 18, 5, 71, 7, 26, 
    3, 76, 2, 61, 6, 56, 4, 14, 0, 99, 8, 81, 5,  3, 7, 60, 1, 67, 
    4, 33, 2, 92, 3, 13, 7, 84, 6, 51, 1, 79, 5, 69, 0, 70, 8, 23, 
    4,  6, 0, 92, 5, 23, 8, 61, 3, 81, 6, 22, 1, 58, 7, 74, 2, 48
  };
  const int q6782[] = {
    9, 9, // Number of jobs and machines
    1, 76, 7, 85, 4, 63, 0,  1, 8, 74, 3,  6, 5, 29, 6, 78, 2, 55, 
    8,  2, 0, 20, 5,  5, 4, 64, 2, 28, 1, 11, 6, 96, 7,  5, 3, 27, 
    7, 74, 2, 83, 3, 46, 4, 12, 8, 68, 6, 91, 0, 85, 1, 75, 5, 51, 
    8, 31, 5, 23, 7, 18, 6, 59, 2, 25, 3,  2, 0, 62, 1,  2, 4, 61, 
    3, 56, 2, 12, 7, 32, 5, 20, 6,  7, 0, 36, 4, 29, 8, 72, 1, 40, 
    8, 65, 3, 90, 5, 82, 1, 66, 2, 46, 0, 20, 4,  1, 6, 41, 7,  5, 
    0, 61, 7, 92, 2, 38, 5, 98, 8, 79, 4, 52, 1, 94, 6, 41, 3, 75, 
    2, 46, 3, 99, 6, 47, 8, 93, 4, 79, 0, 29, 5, 27, 7, 55, 1, 92, 
    1, 63, 3, 34, 8, 60, 7, 12, 2, 32, 0, 72, 5, 82, 6, 58, 4, 37
  };
  const int q6783[] = {
    9, 9, // Number of jobs and machines
    7, 88, 4, 27, 1, 98, 6, 49, 8, 59, 2, 97, 0, 27, 5, 80, 3, 62, 
    0, 91, 7,  2, 6, 41, 2, 62, 1, 23, 8, 36, 3, 73, 5,  3, 4, 83, 
    4, 28, 3, 44, 1, 72, 2, 33, 5, 43, 0, 54, 7, 35, 8, 44, 6, 24, 
    8, 47, 1, 60, 5, 65, 7, 15, 2, 81, 4, 34, 0,  1, 6,  9, 3, 79, 
    2, 77, 0, 72, 6, 92, 3, 28, 4, 33, 8, 26, 1, 12, 7, 84, 5, 84, 
    4, 29, 1, 85, 0, 66, 5, 43, 2,  6, 3, 10, 7,  8, 8, 66, 6,  7, 
    0, 13, 7, 71, 4, 71, 6, 84, 2, 66, 5, 82, 1, 72, 8, 98, 3, 36, 
    1, 36, 7, 28, 2, 81, 6, 45, 4, 23, 0, 99, 3, 13, 5, 72, 8, 14, 
    0, 68, 8,  8, 7, 64, 5, 69, 1, 37, 4, 55, 3, 99, 2, 28, 6,  8
  };
  const int q6784[] = {
    9, 9, // Number of jobs and machines
    3, 21, 8, 28, 5, 30, 4, 96, 1, 39, 6, 74, 2, 60, 0, 66, 7, 20, 
    4, 95, 6, 63, 3, 70, 5, 82, 8, 50, 7, 62, 0, 91, 1, 58, 2, 77, 
    2, 39, 1, 35, 8,  4, 6, 46, 7, 67, 3, 41, 4, 27, 0,  5, 5, 87, 
    5, 85, 7, 56, 8, 28, 2, 90, 3, 16, 0, 60, 1, 20, 4,  1, 6, 84, 
    8, 40, 0, 52, 1, 84, 7, 50, 5, 54, 6,  3, 3, 13, 4, 80, 2, 31, 
    1, 66, 7, 81, 0, 85, 5, 74, 8,  5, 2, 93, 3, 21, 6, 74, 4, 51, 
    2, 34, 4, 15, 7, 73, 1, 31, 0, 92, 6, 18, 5, 34, 8, 59, 3, 74, 
    2, 73, 0, 17, 3, 41, 6, 73, 7, 62, 4, 80, 1, 83, 8, 85, 5, 91, 
    3, 29, 4, 66, 6, 55, 5, 35, 1,  1, 0,  4, 7, 68, 8, 47, 2, 19
  };
  const int q6785[] = {
    9, 9, // Number of jobs and machines
    7,  3, 0, 44, 2, 23, 6, 26, 4, 67, 3, 63, 8, 44, 5, 19, 1, 41, 
    3,  7, 2,  9, 8, 21, 1, 47, 5, 49, 4, 76, 0, 52, 6, 93, 7, 56, 
    1, 32, 3, 37, 8, 19, 0, 87, 7, 56, 5, 34, 4, 32, 6, 18, 2, 62, 
    0, 27, 7, 63, 6, 83, 8, 36, 5, 91, 1, 80, 2, 73, 4, 24, 3, 28, 
    6, 50, 8, 28, 0,  1, 5, 34, 7, 80, 2, 25, 1, 62, 4, 38, 3, 69, 
    8, 14, 0, 78, 3, 28, 6, 52, 4, 11, 7, 35, 2, 13, 5, 70, 1, 92, 
    4, 28, 0, 10, 6, 66, 2,  8, 1, 43, 3, 55, 5, 94, 8, 53, 7, 21, 
    5, 81, 4, 77, 1, 49, 7, 37, 6, 88, 3, 47, 0,  2, 2, 82, 8, 77, 
    7, 99, 6, 64, 0,  1, 5, 82, 2, 26, 1,  2, 8, 56, 4, 43, 3, 51
  };
  const int q6786[] = {
    9, 9, // Number of jobs and machines
    4, 28, 6, 26, 3, 23, 5, 73, 0, 67, 7, 71, 8, 42, 1, 12, 2,  4, 
    7, 90, 1, 84, 3,  3, 8, 86, 2, 13, 5, 45, 4,  1, 6, 66, 0, 41, 
    6, 75, 7, 47, 3, 95, 4, 20, 5, 40, 0, 36, 2, 67, 8, 10, 1, 99, 
    5, 36, 7, 38, 3, 36, 8,  4, 4, 44, 6, 95, 2,  5, 0, 46, 1, 88, 
    1, 89, 7, 27, 0, 16, 5, 16, 4,  4, 3, 65, 2,  6, 8, 13, 6, 20, 
    6, 80, 7, 69, 2, 53, 4, 59, 5, 23, 0, 54, 8, 70, 3, 63, 1, 26, 
    6, 62, 0, 73, 4, 76, 2, 80, 1, 83, 7, 41, 5, 58, 8, 75, 3, 12, 
    4, 63, 1, 25, 0, 85, 8, 10, 5, 42, 2, 19, 6, 63, 7, 16, 3, 56, 
    6, 38, 1, 97, 3, 13, 2, 62, 0, 53, 4, 11, 7, 73, 5, 91, 8,  7
  };
  const int q6787[] = {
    9, 9, // Number of jobs and machines
    6, 69, 8,  1, 2, 78, 5, 53, 0, 47, 1, 35, 3, 38, 7, 68, 4, 29, 
    7, 36, 5, 42, 0, 25, 6, 83, 8, 13, 3, 25, 4, 45, 1, 24, 2, 68, 
    2, 42, 4, 13, 6, 84, 3,  7, 7, 76, 1, 25, 0, 31, 8, 25, 5,  6, 
    8, 69, 3, 93, 4, 79, 2, 93, 0, 80, 5, 14, 7, 67, 1, 74, 6, 92, 
    0, 10, 6, 51, 2, 26, 1, 66, 8, 36, 7, 56, 3, 22, 4, 43, 5, 78, 
    7, 49, 2, 86, 0, 42, 5, 79, 4, 71, 3, 61, 1, 54, 8, 94, 6, 88, 
    4, 59, 5, 92, 7, 99, 3, 85, 2, 18, 8, 91, 6, 62, 1, 77, 0, 25, 
    6, 30, 8, 42, 0, 56, 3,  8, 7, 88, 2, 28, 4, 27, 1, 38, 5, 60, 
    2, 12, 1, 30, 0, 90, 7, 39, 8, 61, 4,  4, 3, 87, 5, 60, 6, 27
  };
  const int q6788[] = {
    9, 9, // Number of jobs and machines
    0, 88, 4, 63, 6,  1, 5, 13, 8, 97, 2, 48, 3, 48, 1, 18, 7, 16, 
    3, 92, 8,  6, 6, 52, 5, 46, 4, 85, 7, 92, 0, 49, 2, 93, 1, 38, 
    1, 72, 5, 60, 8, 93, 6, 96, 7, 27, 0, 57, 4, 76, 3, 78, 2, 40, 
    1, 43, 8, 17, 3, 24, 5, 98, 4, 86, 6, 41, 2, 96, 7,  3, 0, 45, 
    2, 42, 5, 26, 0, 75, 1, 22, 8, 71, 3, 40, 7, 20, 4, 35, 6,  8, 
    6, 66, 8, 43, 5, 56, 0, 87, 2, 72, 4, 26, 7, 75, 1, 70, 3, 45, 
    6, 62, 0, 88, 5, 33, 2,  8, 1,  8, 8, 73, 4, 79, 7,  6, 3, 38, 
    7, 39, 3, 25, 0, 77, 8, 84, 5, 14, 2, 88, 4, 33, 6, 87, 1, 81, 
    8, 26, 7, 51, 3, 46, 1, 59, 2, 39, 0, 44, 4, 35, 5, 20, 6, 96
  };
  const int q6789[] = {
    9, 9, // Number of jobs and machines
    3,  1, 5, 10, 0, 26, 4, 93, 6, 10, 2, 39, 1, 58, 8, 30, 7, 97, 
    4, 92, 0, 71, 7, 16, 2, 41, 5,  1, 1, 87, 3, 78, 6, 86, 8, 91, 
    2, 97, 1, 31, 3, 30, 7, 47, 6, 51, 0, 86, 4, 56, 5, 20, 8, 17, 
    7, 33, 8, 36, 6, 26, 5, 50, 2, 68, 1, 13, 3, 47, 0, 25, 4, 21, 
    8, 18, 1, 66, 2, 79, 5, 31, 3, 29, 4, 67, 6, 60, 0, 15, 7, 48, 
    8, 67, 1, 29, 7, 83, 5, 57, 4, 31, 3, 10, 6, 43, 2, 43, 0, 44, 
    4, 70, 0, 52, 7, 42, 8, 22, 3, 11, 1, 54, 2, 38, 6, 37, 5, 35, 
    4, 30, 3, 72, 6, 37, 0, 84, 5, 21, 7, 42, 1, 65, 2, 51, 8, 96, 
    5, 57, 3, 70, 1, 95, 2, 97, 7, 39, 4, 35, 0, 33, 8, 38, 6, 70
  };
  const int q6790[] = {
    9, 9, // Number of jobs and machines
    7, 71, 6, 16, 4, 60, 5, 92, 0, 68, 1, 85, 2, 59, 8, 75, 3, 34, 
    4, 96, 3,  5, 7, 78, 6, 10, 2, 21, 0, 61, 1, 22, 5, 95, 8,  2, 
    1, 40, 7, 41, 6, 64, 2, 82, 0, 64, 8, 87, 5, 80, 4, 66, 3, 73, 
    3, 94, 6, 36, 1, 92, 5, 13, 0, 96, 2, 70, 7, 88, 8, 85, 4, 96, 
    1, 47, 8, 77, 2, 87, 7,  6, 4, 38, 6,  6, 0, 50, 5, 68, 3, 90, 
    5, 34, 4, 89, 2, 21, 8, 63, 7, 20, 0, 33, 6, 56, 3, 79, 1, 21, 
    4,  4, 8, 27, 3, 55, 2, 20, 5, 73, 1, 47, 6, 11, 7, 92, 0, 64, 
    5, 43, 7, 17, 4,  7, 8, 62, 6, 45, 0, 96, 1, 32, 3,  3, 2, 44, 
    2, 66, 7, 22, 1, 52, 4, 63, 5, 59, 0, 44, 8, 12, 3, 88, 6, 23
  };
  const int q6791[] = {
    9, 9, // Number of jobs and machines
    6, 96, 4, 49, 1, 94, 2, 94, 0, 75, 5, 18, 7, 20, 3, 93, 8, 72, 
    8, 46, 4, 32, 1, 94, 0, 84, 7, 15, 5, 65, 6, 97, 3, 17, 2, 27, 
    7, 60, 6, 33, 2, 49, 1, 50, 4, 28, 8, 77, 5, 13, 3, 24, 0, 28, 
    1, 98, 6, 79, 7, 54, 5, 13, 4, 73, 0, 37, 8, 47, 3,  1, 2, 73, 
    2, 24, 7, 55, 5, 80, 1, 92, 0, 13, 3, 39, 4, 93, 8, 58, 6, 63, 
    2, 30, 1, 89, 6, 99, 4,  9, 3, 87, 7, 21, 0, 63, 5, 90, 8, 71, 
    5, 50, 7, 89, 3, 69, 2, 32, 1, 55, 8, 78, 0, 82, 4, 94, 6, 31, 
    4, 88, 1, 96, 8, 44, 3, 90, 0, 28, 2, 36, 7, 41, 5,  3, 6, 27, 
    4, 44, 1,  3, 0, 93, 8, 94, 5, 82, 6, 85, 2, 95, 3, 36, 7, 27
  };
  const int q6792[] = {
    9, 9, // Number of jobs and machines
    1, 28, 0, 68, 2, 52, 4, 31, 8, 63, 3, 46, 6, 65, 7, 76, 5, 82, 
    5,  1, 8, 63, 7, 70, 0, 64, 1, 31, 4, 19, 2, 38, 6, 95, 3, 45, 
    6, 50, 1, 18, 0, 52, 3, 92, 5, 59, 8, 46, 7, 86, 2, 78, 4, 74, 
    8, 74, 2, 58, 1, 43, 4, 58, 6, 99, 0, 58, 5, 82, 3, 81, 7,  7, 
    6, 83, 1, 96, 8, 41, 7, 45, 2, 85, 5, 80, 4, 25, 3, 29, 0, 23, 
    5, 93, 4, 92, 3, 64, 1, 92, 6, 72, 8, 50, 7, 30, 2, 61, 0, 29, 
    2,  9, 0, 84, 6, 11, 8, 52, 5, 52, 7, 61, 4, 21, 3, 78, 1, 73, 
    6, 88, 4, 97, 5, 36, 3, 19, 1, 33, 0, 52, 8, 56, 7,  9, 2, 58, 
    6, 97, 0,  8, 2, 76, 3, 15, 8, 80, 7, 58, 5, 52, 4, 47, 1, 28
  };
  const int q6793[] = {
    9, 9, // Number of jobs and machines
    1, 80, 3,  7, 6, 71, 5, 85, 0, 64, 7, 31, 4, 98, 8,  4, 2,  3, 
    2,  3, 5, 35, 6, 60, 3,  8, 4, 77, 0, 22, 1, 85, 7,  8, 8, 94, 
    7, 81, 2, 80, 5, 24, 1, 13, 0, 47, 8,  5, 6, 99, 3, 78, 4, 51, 
    5, 48, 0, 65, 2, 69, 3, 81, 1, 45, 7, 47, 8,  8, 6, 87, 4, 56, 
    4, 33, 8, 33, 7, 13, 5, 23, 2, 31, 1, 79, 3, 57, 0,  1, 6,  7, 
    3, 13, 6, 47, 8, 43, 4, 60, 2, 78, 5, 75, 1, 94, 0, 88, 7,  2, 
    0, 93, 1, 48, 3, 49, 2, 73, 5, 43, 6, 61, 7, 92, 8, 56, 4, 27, 
    4, 98, 0, 99, 5, 43, 3, 30, 2, 80, 8,  5, 7, 49, 6, 79, 1, 49, 
    4, 46, 0, 13, 7, 63, 3, 98, 5, 64, 6, 61, 8, 78, 2, 19, 1, 97
  };
  const int q6794[] = {
    9, 9, // Number of jobs and machines
    7, 14, 0, 12, 6, 88, 2, 66, 5, 27, 1,  6, 8, 15, 3, 30, 4, 37, 
    2, 86, 6, 29, 7, 60, 1, 33, 3, 26, 4, 18, 8, 88, 0, 80, 5, 75, 
    6, 57, 2, 52, 1, 82, 7, 64, 5, 79, 0, 82, 3, 74, 8, 73, 4, 68, 
    1, 76, 4, 68, 0, 91, 2, 87, 5, 16, 7, 12, 6, 63, 8,  5, 3, 12, 
    0, 19, 3, 49, 1, 49, 2, 93, 4, 50, 8, 53, 7, 74, 6, 26, 5, 28, 
    0, 17, 8,  4, 1, 81, 5, 50, 2, 24, 3, 81, 6, 48, 4, 29, 7, 83, 
    6,  2, 2, 99, 5, 86, 4, 72, 0, 57, 8, 45, 1, 20, 3, 75, 7, 32, 
    4, 37, 6, 55, 7, 57, 5, 36, 3, 71, 1, 67, 2, 77, 0, 91, 8, 50, 
    1, 58, 6, 92, 2, 37, 4,  6, 7, 58, 0, 81, 8, 65, 5, 96, 3, 94
  };
  const int q6795[] = {
    9, 9, // Number of jobs and machines
    2, 73, 4,  2, 8, 89, 3, 77, 5, 86, 1, 62, 7, 82, 6, 30, 0, 32, 
    1, 39, 3, 51, 2, 54, 5, 27, 6, 75, 7, 60, 4, 67, 0, 96, 8, 80, 
    2, 39, 7, 78, 8, 36, 1, 80, 5,  4, 4, 45, 3, 75, 0, 51, 6, 77, 
    8, 36, 7, 61, 6, 77, 1, 64, 2, 40, 4, 45, 3, 51, 5, 70, 0, 69, 
    7, 96, 3, 24, 8, 34, 4, 57, 0, 82, 5, 72, 6, 98, 1, 77, 2, 13, 
    2, 48, 5, 87, 6, 26, 4, 87, 8, 59, 0,  3, 7, 97, 1, 11, 3, 13, 
    5, 89, 2, 90, 1, 41, 8, 36, 7,  7, 3, 98, 4, 20, 6, 15, 0, 14, 
    0, 20, 2, 30, 1, 22, 3, 61, 6, 44, 8,  6, 4, 13, 7, 91, 5, 81, 
    5, 53, 3, 37, 0, 92, 8,  9, 2, 24, 6, 46, 7, 12, 1, 90, 4, 62
  };
  const int q6796[] = {
    9, 9, // Number of jobs and machines
    1, 54, 6, 49, 8, 20, 0, 28, 7, 47, 3, 75, 4, 30, 5,  3, 2, 21, 
    3, 95, 7, 35, 8, 86, 0, 50, 2, 98, 1, 89, 5, 13, 6,  5, 4, 80, 
    2, 87, 4, 60, 3, 70, 8,  6, 6, 53, 7, 23, 1,  6, 5, 93, 0, 16, 
    1, 37, 8, 15, 2, 55, 5, 44, 7, 23, 0, 42, 3, 80, 6, 22, 4,  3, 
    3, 46, 4, 39, 7, 95, 2, 34, 1, 77, 5, 84, 0, 98, 6,  3, 8, 20, 
    3, 97, 6, 71, 2, 48, 8, 33, 1, 92, 7, 94, 0, 63, 4, 55, 5, 89, 
    3, 34, 7, 88, 4, 33, 5, 46, 6, 54, 1,  1, 2,  8, 8, 57, 0, 26, 
    2, 18, 3, 69, 6, 98, 0,  3, 8, 79, 4,  2, 1, 77, 5, 36, 7, 40, 
    8, 37, 7, 91, 0, 74, 5, 98, 1, 86, 4, 36, 2, 10, 6, 93, 3,  6
  };
  const int q6797[] = {
    9, 9, // Number of jobs and machines
    3, 66, 1, 61, 4, 77, 8, 19, 2, 45, 5, 52, 6, 96, 0, 95, 7, 46, 
    4,  1, 0, 58, 8, 39, 6, 47, 7, 36, 2, 91, 1, 51, 3, 51, 5, 50, 
    8, 11, 6, 92, 2, 18, 4,  3, 1, 37, 0, 94, 7, 46, 3,  5, 5, 88, 
    3, 31, 7, 44, 4, 64, 5, 65, 1, 60, 8,  2, 2, 11, 6, 53, 0, 47, 
    3, 40, 6,  3, 8, 95, 7, 79, 2, 42, 0, 53, 4,  9, 1,  1, 5, 64, 
    7, 25, 1, 42, 8, 25, 5, 19, 0, 37, 6,  4, 4, 95, 3, 62, 2, 23, 
    8, 97, 1,  7, 7, 79, 4, 27, 5, 48, 2, 43, 0, 84, 3, 52, 6, 43, 
    2, 67, 6, 40, 1, 34, 7, 65, 5, 75, 4, 51, 8, 86, 3, 84, 0, 78, 
    1, 30, 2, 39, 8, 30, 0,  1, 5, 82, 7, 71, 4, 89, 3, 32, 6, 23
  };
  const int q6798[] = {
    9, 9, // Number of jobs and machines
    0, 24, 3, 38, 2, 70, 8, 63, 7, 71, 6, 33, 5, 29, 4, 98, 1, 44, 
    0,  3, 7,  5, 2, 56, 5, 89, 8, 80, 4, 22, 6, 62, 3, 74, 1,  9, 
    5, 16, 4, 51, 0,  4, 7, 77, 1, 47, 2, 40, 8, 28, 6, 19, 3, 43, 
    8, 86, 7, 60, 4, 91, 6, 31, 0, 23, 2, 46, 5, 58, 1, 41, 3, 63, 
    6, 85, 8, 78, 5, 58, 7, 10, 1, 96, 4, 70, 3, 17, 2, 98, 0, 92, 
    0, 28, 4, 89, 7, 60, 1, 42, 2,  8, 5, 41, 6,  8, 3, 98, 8,  2, 
    2, 71, 5, 88, 6, 12, 8, 61, 1, 79, 7, 51, 4, 60, 0,  9, 3, 93, 
    2,  3, 8, 41, 1,  7, 6, 99, 0, 85, 3, 33, 7, 40, 5, 55, 4, 19, 
    7, 66, 3, 19, 2, 14, 0, 15, 1, 18, 5, 49, 8, 48, 6, 71, 4,  1
  };
  const int q6799[] = {
    9, 9, // Number of jobs and machines
    1, 19, 6, 70, 3, 38, 0, 27, 2, 26, 8, 67, 7, 28, 4, 15, 5, 10, 
    7, 50, 3, 59, 5,  4, 4, 68, 2, 17, 6, 51, 8,  6, 0, 18, 1, 91, 
    3, 65, 8, 73, 2,  1, 6, 70, 7, 13, 4, 66, 0, 96, 5, 45, 1, 98, 
    1, 61, 7, 40, 8, 67, 3, 19, 5, 90, 2, 15, 6,  6, 0, 94, 4, 90, 
    3, 93, 8, 87, 7, 15, 5, 37, 2,  7, 0, 59, 4,  4, 6, 95, 1, 26, 
    0, 39, 7, 41, 2, 82, 1, 48, 5, 76, 6, 85, 3, 63, 4, 77, 8, 32, 
    0, 54, 5, 48, 3, 97, 2, 31, 7, 73, 4, 43, 8, 70, 1, 44, 6, 32, 
    5, 74, 6, 54, 0, 58, 1, 58, 3, 29, 2, 76, 7, 56, 4, 69, 8, 41, 
    4, 53, 2, 16, 1, 72, 3, 98, 6, 87, 0, 50, 5, 24, 7, 69, 8, 12
  };
  const int q6800[] = {
    9, 9, // Number of jobs and machines
    8, 57, 3, 76, 1, 65, 2, 28, 4, 63, 5, 84, 0, 51, 7, 60, 6, 58, 
    8, 63, 4, 15, 1, 18, 6, 78, 5, 50, 3, 33, 2, 49, 0, 10, 7, 10, 
    3, 96, 5, 87, 8, 75, 4, 96, 7, 43, 0, 29, 2, 96, 1, 49, 6, 72, 
    8,  8, 7, 10, 1, 88, 6, 68, 3, 56, 0, 15, 2, 16, 4, 56, 5,  9, 
    0, 47, 8, 65, 7, 87, 1, 14, 3, 17, 4, 65, 5, 55, 6, 56, 2, 76, 
    7, 74, 0, 66, 8, 50, 5, 19, 2, 90, 4,  8, 6, 83, 1, 38, 3, 88, 
    7, 24, 0, 30, 2,  7, 3, 98, 6, 46, 1,  7, 8, 15, 4, 66, 5, 47, 
    0, 64, 2, 43, 5, 91, 8, 62, 7, 12, 4, 28, 6,  3, 1, 12, 3, 46, 
    6, 56, 8, 57, 4, 17, 1, 14, 2, 53, 0, 75, 5, 48, 3, 89, 7, 26
  };
  const int q6801[] = {
    9, 9, // Number of jobs and machines
    0, 55, 7, 30, 4, 27, 3, 76, 8, 68, 2, 12, 1, 88, 6,  8, 5, 31, 
    2, 50, 6, 11, 0, 76, 4, 12, 5, 84, 3, 96, 1,  2, 7,  4, 8,  8, 
    0, 97, 6, 18, 3, 36, 7, 93, 8, 11, 2, 98, 5, 16, 4, 31, 1, 94, 
    1, 76, 6, 60, 0, 54, 7,  9, 5, 61, 3,  3, 4, 51, 2, 40, 8, 43, 
    3,  6, 2, 54, 5, 76, 6, 41, 7, 86, 4, 18, 1, 68, 8, 70, 0, 70, 
    6, 26, 3, 37, 5, 13, 8, 58, 1, 75, 2, 32, 0, 51, 7, 59, 4, 74, 
    7,  9, 1, 49, 4, 52, 6, 39, 0, 11, 5, 26, 3, 39, 8, 43, 2, 94, 
    2, 55, 5, 61, 4, 41, 8, 64, 3, 67, 6,  1, 1,  7, 0, 83, 7, 11, 
    3, 51, 7, 65, 1, 45, 0, 65, 2, 98, 6, 58, 4, 54, 5,  3, 8, 19
  };
  const int q6802[] = {
    9, 9, // Number of jobs and machines
    3, 40, 0, 77, 7, 90, 1, 94, 5,  7, 6, 80, 8, 27, 2, 24, 4, 31, 
    1, 18, 4, 54, 0, 88, 7, 76, 5, 68, 3, 55, 8, 23, 2, 79, 6, 73, 
    4, 87, 3, 90, 2, 66, 6, 31, 7, 41, 0, 29, 5, 70, 1, 87, 8, 30, 
    1, 77, 0, 71, 3, 36, 6,  3, 5, 76, 2, 91, 7,  6, 8, 31, 4,  7, 
    1, 88, 3, 23, 0,  9, 5, 13, 6, 69, 2, 19, 8, 92, 7, 59, 4, 83, 
    6, 49, 1, 71, 7, 80, 4, 12, 3, 70, 2, 22, 0, 10, 5, 48, 8, 39, 
    4, 19, 1, 27, 8, 26, 7, 71, 6, 80, 5, 48, 0, 72, 2, 49, 3, 14, 
    2, 43, 6, 44, 7, 27, 1, 92, 8, 37, 4, 64, 3, 15, 5, 54, 0, 43, 
    7, 92, 4, 31, 6,  9, 5, 72, 3,  5, 8, 26, 0, 28, 1, 47, 2,  5
  };
  const int q6803[] = {
    9, 9, // Number of jobs and machines
    8, 72, 5, 62, 4, 17, 3, 84, 6, 94, 1, 33, 0, 78, 2, 48, 7, 25, 
    2, 57, 8, 17, 5,  8, 4, 21, 7, 39, 6, 56, 1, 49, 0, 80, 3, 59, 
    6, 75, 1,  6, 0, 75, 2, 73, 5, 14, 4, 10, 3, 28, 7, 83, 8, 76, 
    7, 97, 8, 22, 0,  9, 5,  8, 1,  8, 2, 18, 3, 20, 4, 41, 6, 94, 
    3, 58, 7, 12, 2, 20, 5,  2, 6, 34, 1, 12, 0, 67, 8, 90, 4, 90, 
    4, 94, 3, 37, 6, 23, 0, 30, 2, 42, 1, 83, 8, 19, 5,  4, 7, 72, 
    5, 87, 0, 23, 2, 51, 4, 12, 1, 67, 3, 84, 8, 58, 6, 77, 7, 54, 
    7, 97, 4, 92, 1, 91, 5, 71, 2, 31, 6, 22, 0, 57, 3, 22, 8, 23, 
    1, 25, 6, 80, 3, 49, 5, 24, 2, 67, 8, 68, 7, 40, 4, 42, 0, 57
  };
  const int q6804[] = {
    9, 9, // Number of jobs and machines
    7, 86, 5, 31, 1, 51, 2, 80, 4, 45, 3, 60, 8, 90, 6, 37, 0, 52, 
    3, 98, 5, 13, 6, 23, 8,  2, 0, 39, 1, 30, 4, 30, 2, 72, 7, 34, 
    6, 58, 1, 89, 3, 27, 5,  5, 4, 96, 7, 11, 8, 72, 0, 97, 2, 12, 
    1,  3, 0, 54, 3, 40, 6, 30, 4, 18, 2, 70, 8, 88, 5, 94, 7, 74, 
    1, 85, 3, 67, 6, 91, 7, 25, 8, 63, 4,  2, 0, 78, 2, 98, 5, 14, 
    6, 56, 4, 99, 5, 17, 2, 43, 0, 77, 3,  8, 1, 43, 8,  6, 7, 23, 
    2, 82, 5, 44, 7, 10, 0, 24, 4, 80, 8, 19, 1,  4, 3, 41, 6, 30, 
    1, 11, 3, 20, 5, 98, 4, 66, 0, 15, 6, 47, 7, 46, 8, 68, 2, 67, 
    7, 52, 3, 77, 2, 44, 0, 52, 1, 54, 4, 85, 5,  9, 6, 56, 8, 61
  };
  const int q6805[] = {
    9, 9, // Number of jobs and machines
    7, 69, 6, 42, 8, 94, 5, 39, 0, 43, 2, 40, 1, 36, 3,  2, 4, 70, 
    6,  6, 4,  7, 3, 69, 1, 28, 8, 57, 7,  7, 0, 19, 5, 93, 2, 79, 
    5, 67, 6, 30, 2,  1, 8,  3, 7, 77, 3, 76, 4, 12, 1, 43, 0, 69, 
    1, 82, 3, 10, 6,  1, 7, 41, 4,  1, 0, 13, 8, 77, 5, 19, 2, 44, 
    7, 66, 1,  3, 6, 70, 0,  4, 3, 57, 2,  9, 5, 10, 8, 68, 4, 14, 
    6, 12, 4, 33, 7, 10, 5, 82, 3, 81, 2, 46, 8, 55, 1, 49, 0, 53, 
    8, 22, 1,  5, 7,  7, 6, 32, 3, 16, 5, 13, 2, 35, 4, 93, 0, 75, 
    5, 83, 8, 79, 2, 44, 3, 54, 0, 89, 4, 83, 1, 80, 6, 91, 7, 65, 
    6, 52, 4, 94, 0, 62, 1, 37, 7, 83, 3, 48, 5, 74, 8, 47, 2, 88
  };
  const int q6806[] = {
    9, 9, // Number of jobs and machines
    4, 38, 1, 10, 7, 88, 2, 38, 0, 62, 6, 84, 3, 92, 8, 56, 5, 89, 
    5, 31, 4, 33, 1, 41, 7, 50, 0, 97, 2, 51, 3, 74, 8, 46, 6, 74, 
    2, 72, 8, 66, 4, 14, 6, 82, 0, 41, 5, 76, 1, 71, 3, 10, 7, 60, 
    7, 94, 2, 57, 5, 42, 3,  8, 1, 25, 4, 70, 0, 43, 6, 67, 8, 37, 
    2, 81, 4, 36, 0, 54, 5, 82, 8, 83, 1, 24, 6, 20, 7, 16, 3, 47, 
    3, 64, 8, 33, 1, 96, 7, 74, 5, 88, 0, 89, 2, 94, 4, 36, 6, 65, 
    5, 33, 1, 96, 6, 10, 0,  9, 8, 57, 4, 89, 7, 56, 2, 31, 3, 78, 
    7, 89, 4, 93, 0, 80, 8, 24, 6, 70, 3, 70, 1, 63, 2, 49, 5, 13, 
    5,  6, 0, 13, 3, 37, 7, 20, 6, 92, 1, 97, 8, 17, 2, 59, 4, 76
  };
  const int q6807[] = {
    9, 9, // Number of jobs and machines
    3, 20, 1, 44, 0, 74, 4, 86, 5, 97, 7,  8, 8, 51, 6, 55, 2, 10, 
    7, 96, 2, 58, 5, 42, 3, 11, 0, 55, 8, 25, 4, 74, 6,  6, 1, 27, 
    4, 31, 3, 15, 6, 29, 5, 35, 7, 89, 0, 83, 8, 22, 2, 93, 1, 88, 
    5, 93, 0, 81, 3, 54, 1, 80, 2, 58, 4, 38, 8, 33, 6, 64, 7, 14, 
    5, 79, 1,  3, 4, 71, 2, 46, 7, 68, 3, 40, 6, 75, 8, 34, 0, 75, 
    1, 39, 0, 11, 8, 30, 7, 15, 5, 12, 6, 78, 4, 86, 3, 74, 2, 38, 
    2, 59, 5, 83, 7, 74, 1, 81, 3, 11, 4, 61, 0,  3, 8, 34, 6,  7, 
    3,  8, 0, 60, 4, 12, 1, 52, 8, 73, 5, 63, 2, 73, 6, 30, 7, 55, 
    1,  7, 3, 20, 8, 74, 6, 93, 4, 14, 2, 71, 5, 11, 7,  7, 0, 27
  };
  const int q6808[] = {
    9, 9, // Number of jobs and machines
    2, 63, 0, 96, 6, 35, 8, 49, 3, 60, 4, 76, 1, 75, 7, 52, 5, 82, 
    1,  8, 2, 28, 7, 49, 0, 71, 4, 83, 5, 82, 3, 19, 6, 51, 8, 57, 
    2, 12, 0,  8, 3, 20, 8, 41, 6, 92, 7, 43, 1, 67, 5, 17, 4,  1, 
    1, 86, 8, 89, 4, 71, 5, 24, 0, 24, 7, 12, 3, 46, 6, 64, 2, 75, 
    7, 64, 6, 54, 1, 57, 4, 65, 0, 53, 3, 82, 2, 59, 8, 14, 5, 25, 
    7, 17, 1, 91, 6, 28, 8, 28, 0, 77, 3, 54, 5, 94, 2, 93, 4, 68, 
    5, 28, 4, 57, 8, 61, 2, 79, 1, 63, 7, 19, 6, 69, 3, 24, 0, 52, 
    8, 56, 5, 77, 4, 20, 3, 42, 1, 36, 2, 22, 7, 72, 6, 97, 0, 57, 
    3,  9, 7, 54, 4, 65, 8, 70, 2, 66, 0, 83, 1, 21, 6, 30, 5, 35
  };
  const int q6809[] = {
    9, 9, // Number of jobs and machines
    8, 39, 3, 17, 5, 49, 2, 31, 7, 97, 6, 18, 4, 18, 1,  2, 0, 91, 
    1, 18, 7, 88, 0, 39, 6, 44, 5, 97, 3, 28, 2, 64, 4,  3, 8, 33, 
    8, 66, 0, 25, 6, 61, 5, 12, 3,  8, 4, 94, 1, 79, 7, 37, 2, 23, 
    7, 86, 2, 48, 4, 74, 0, 88, 3, 28, 8, 73, 1, 33, 6, 79, 5, 98, 
    3, 71, 6,  2, 5, 81, 4, 87, 0, 31, 2, 16, 1, 28, 8, 19, 7, 94, 
    2, 78, 4, 56, 7, 74, 1, 86, 3, 57, 8, 86, 5, 95, 0, 23, 6,  5, 
    4, 36, 0, 97, 8, 77, 1, 20, 3, 92, 6, 61, 7, 23, 2, 91, 5, 50, 
    5, 81, 8, 48, 2, 47, 6, 49, 7, 68, 4, 46, 3, 53, 0,  1, 1, 97, 
    8, 62, 1,  7, 4,  1, 6, 79, 2, 48, 3, 99, 7,  8, 5, 31, 0, 69
  };
  const int q6810[] = {
    9, 9, // Number of jobs and machines
    6, 90, 8, 82, 3, 21, 5, 38, 1, 36, 7, 63, 0, 76, 2, 77, 4, 92, 
    1, 23, 7, 51, 4, 89, 5, 64, 8, 40, 2, 89, 6, 43, 3, 47, 0, 95, 
    3, 87, 7, 67, 4, 25, 6, 76, 5, 87, 0, 81, 2, 13, 8, 88, 1, 36, 
    4, 44, 0, 35, 1, 99, 7, 41, 3, 75, 5, 66, 6, 45, 8, 62, 2, 75, 
    1, 90, 3, 30, 4, 83, 2, 85, 6, 26, 5, 23, 0, 25, 8, 25, 7,  8, 
    2, 44, 7, 38, 0, 84, 8,  6, 3, 35, 4, 60, 5,  4, 6, 26, 1, 52, 
    6,  2, 5, 48, 4, 77, 0, 21, 1, 59, 2,  9, 3, 55, 8, 32, 7, 41, 
    0,  3, 6, 30, 2, 20, 5, 82, 7, 92, 8, 31, 1, 56, 4,  7, 3, 85, 
    6, 58, 7,  6, 5, 66, 8, 16, 2, 57, 1, 80, 4, 38, 3, 42, 0, 30
  };
  const int q6811[] = {
    9, 9, // Number of jobs and machines
    3, 27, 5, 11, 6, 76, 7, 82, 2, 89, 8, 82, 0, 76, 1, 66, 4, 26, 
    3,  8, 1, 99, 4, 13, 8, 18, 5, 16, 6, 56, 7,  4, 2, 23, 0, 11, 
    0, 40, 1, 28, 4, 83, 2, 79, 6, 33, 3, 48, 5, 68, 7, 20, 8, 21, 
    8, 94, 4, 32, 0, 50, 6, 73, 1, 51, 5, 25, 7, 44, 3, 83, 2, 28, 
    8, 99, 0, 95, 2,  6, 4,  2, 3, 69, 1,  9, 6, 38, 7, 32, 5, 97, 
    0, 63, 5, 51, 3, 37, 6, 32, 2, 71, 8, 30, 7, 30, 1,  5, 4, 53, 
    4, 69, 8, 33, 7, 63, 5, 51, 2, 51, 1, 14, 3, 41, 0, 94, 6,  9, 
    4, 40, 6, 11, 7, 46, 2, 63, 3, 56, 1, 48, 8, 67, 5,  6, 0,  1, 
    4, 59, 7, 17, 8, 50, 1, 96, 5, 32, 6, 94, 2,  3, 3, 27, 0, 62
  };
  const int q6812[] = {
    9, 9, // Number of jobs and machines
    0, 98, 6, 80, 4, 44, 8, 56, 2, 17, 7, 67, 1, 80, 3, 19, 5, 53, 
    6, 67, 7,  9, 3,  2, 5, 49, 1, 11, 2, 93, 0, 41, 4, 26, 8, 67, 
    2, 30, 5, 91, 1, 31, 3, 37, 8,  9, 0,  8, 7, 87, 4, 30, 6, 98, 
    6, 49, 0, 17, 7,  4, 8, 37, 1, 34, 2, 32, 4, 80, 5, 50, 3, 53, 
    3, 68, 1, 68, 7, 24, 4, 95, 8, 76, 2, 50, 5, 93, 6,  7, 0, 59, 
    0, 88, 6, 29, 2, 83, 8, 72, 7, 71, 3, 39, 5, 19, 1, 91, 4, 83, 
    1, 68, 8, 27, 2,  8, 0, 27, 4, 95, 3, 87, 7, 16, 5, 20, 6, 89, 
    3, 71, 7, 60, 6, 11, 8, 53, 5, 21, 4, 87, 1, 13, 2, 64, 0, 67, 
    7,  1, 4,  3, 0, 58, 8, 53, 2, 60, 1, 55, 6, 36, 5,  4, 3,  4
  };
  const int q6813[] = {
    9, 9, // Number of jobs and machines
    8, 12, 6, 22, 0,  6, 1,  4, 5, 35, 3, 59, 4, 24, 2, 57, 7, 66, 
    0, 95, 8, 98, 3, 28, 5, 71, 6, 22, 1, 78, 7, 38, 2, 41, 4, 21, 
    8, 26, 1, 31, 7, 90, 2, 23, 5, 73, 4, 92, 6, 29, 3, 20, 0, 79, 
    7, 92, 4, 86, 8, 77, 2, 58, 0, 83, 1, 84, 6, 20, 3, 70, 5, 39, 
    3, 93, 8, 77, 6, 21, 1, 16, 4, 93, 7, 10, 2, 81, 0, 73, 5, 63, 
    7, 41, 0,  8, 1, 58, 2, 30, 6, 43, 5, 50, 8, 62, 3, 37, 4, 65, 
    4, 39, 7, 81, 8, 81, 2, 57, 3, 95, 6, 88, 0, 90, 1, 30, 5, 14, 
    8,  2, 3, 38, 1, 37, 0,  2, 5, 77, 6, 48, 7, 36, 2,  9, 4, 20, 
    4, 51, 6, 13, 0, 44, 1, 91, 8, 20, 2, 28, 3, 78, 5, 33, 7, 66
  };
  const int q6814[] = {
    9, 9, // Number of jobs and machines
    5, 10, 3, 43, 2, 70, 0, 42, 7, 32, 1, 10, 4, 90, 6, 10, 8, 97, 
    3, 24, 1, 86, 0, 34, 8, 52, 7,  9, 2, 61, 6, 49, 4, 21, 5, 25, 
    8, 86, 3, 73, 0, 12, 4, 27, 1, 47, 6, 73, 7, 44, 5, 89, 2,  6, 
    8, 24, 3, 41, 5, 76, 6, 21, 4, 59, 2, 61, 0, 50, 7,  2, 1, 97, 
    0, 78, 7, 52, 1, 70, 5, 61, 6, 47, 4, 36, 3, 96, 2, 39, 8, 69, 
    1, 36, 7,  8, 5, 41, 8, 90, 3, 26, 6, 60, 4, 56, 2, 85, 0, 97, 
    1, 16, 8, 20, 0, 92, 5, 60, 7, 24, 6, 43, 4, 74, 2, 70, 3, 24, 
    7, 79, 3, 50, 2,  1, 8,  3, 0, 65, 6, 33, 1, 20, 5, 53, 4, 73, 
    2, 51, 7, 99, 6, 34, 5, 16, 1, 42, 8, 11, 3, 93, 4, 16, 0, 61
  };
  const int q6815[] = {
    9, 9, // Number of jobs and machines
    0, 51, 5, 71, 8, 35, 6, 23, 2, 74, 7, 45, 4, 87, 3, 87, 1, 48, 
    5, 93, 1, 19, 0, 10, 3, 63, 2, 58, 7, 95, 8, 38, 4, 48, 6, 57, 
    5, 40, 8, 58, 3, 87, 2, 51, 1, 46, 6, 13, 0, 47, 4,  5, 7, 96, 
    0,  5, 7,  4, 6, 78, 3,  9, 4, 20, 1, 35, 8, 80, 5, 43, 2, 50, 
    1, 39, 2, 84, 6, 22, 4, 10, 0, 10, 8, 83, 5, 68, 3, 78, 7,  6, 
    2, 25, 6, 54, 1,  2, 0, 41, 4, 25, 8, 12, 3, 61, 7, 91, 5, 88, 
    7, 98, 3,  9, 8, 62, 5, 67, 4, 80, 1, 90, 0, 67, 2, 97, 6, 63, 
    5, 21, 4, 48, 3, 44, 7, 60, 8, 61, 1, 46, 6, 50, 2, 76, 0, 91, 
    7, 99, 2,  6, 3, 20, 0, 77, 5, 48, 6, 56, 1, 58, 4, 91, 8, 33
  };
  const int q6816[] = {
    9, 9, // Number of jobs and machines
    3, 58, 6, 98, 0, 84, 2, 58, 8, 85, 1, 16, 7,  3, 5, 85, 4,  1, 
    4, 22, 0, 45, 7, 83, 8, 37, 1,  5, 2, 57, 3,  2, 6,  7, 5, 36, 
    6, 10, 4, 44, 1, 36, 7, 15, 0, 82, 5, 28, 2, 85, 3, 47, 8, 86, 
    0, 43, 3, 80, 8, 17, 4, 62, 1, 88, 2, 67, 7, 76, 5, 76, 6,  1, 
    3,  9, 2, 81, 8, 45, 5, 67, 4, 69, 0, 23, 1,  1, 6, 80, 7,  3, 
    1,  7, 7, 85, 4,  3, 6, 77, 5, 36, 8, 72, 3, 81, 2, 42, 0, 40, 
    2, 16, 6, 36, 7, 26, 8, 84, 0, 64, 5, 43, 3, 10, 1, 82, 4, 44, 
    0, 36, 7, 14, 5, 38, 4, 40, 1, 46, 8,  6, 6, 98, 3, 79, 2, 34, 
    3, 55, 7,  9, 0, 86, 4, 33, 6, 43, 5, 56, 1, 52, 8, 65, 2, 58
  };
  const int q6817[] = {
    9, 9, // Number of jobs and machines
    6, 33, 4, 85, 5, 70, 2, 40, 0, 99, 7,  9, 1, 93, 3, 87, 8,  1, 
    3, 22, 5, 63, 6, 92, 1, 74, 4, 69, 2, 82, 0, 86, 8, 13, 7, 79, 
    1, 29, 3, 88, 6, 71, 4, 15, 8, 59, 2, 90, 5, 83, 0,  2, 7, 58, 
    8, 79, 6, 99, 0, 35, 4, 53, 2, 98, 3, 84, 7,  4, 5,  7, 1, 55, 
    2, 34, 8, 21, 1, 54, 3, 37, 6, 50, 5, 92, 7, 68, 4, 21, 0, 31, 
    2, 71, 5, 49, 6, 84, 4, 90, 7, 22, 1, 13, 0, 99, 8, 12, 3,  7, 
    3, 10, 4, 90, 6, 42, 0, 88, 2, 16, 7, 96, 8,  8, 1, 49, 5,  3, 
    5, 96, 0, 85, 6, 44, 2, 51, 1,  5, 4, 99, 3, 64, 7, 57, 8, 24, 
    2, 32, 1, 96, 4, 85, 7, 50, 3, 90, 0, 35, 8, 93, 5, 60, 6, 89
  };
  const int q6818[] = {
    9, 9, // Number of jobs and machines
    2, 17, 6, 25, 8, 81, 4,  9, 7, 64, 0, 52, 5, 68, 3, 13, 1, 74, 
    4, 67, 0, 26, 1, 91, 6, 95, 2, 65, 3, 25, 8, 57, 5, 12, 7, 65, 
    3,  9, 8, 97, 0, 76, 4, 75, 1, 33, 7, 57, 2, 75, 5, 82, 6, 62, 
    0, 14, 3, 29, 2, 25, 4, 37, 8, 63, 6, 60, 7, 22, 5, 17, 1, 27, 
    1, 49, 6, 89, 7, 92, 2, 14, 0, 83, 4, 72, 8, 14, 5, 48, 3, 89, 
    0, 57, 3, 63, 1, 17, 2, 81, 8, 79, 7, 82, 5, 32, 6, 81, 4, 71, 
    7, 45, 2, 52, 6, 89, 8, 76, 4, 51, 1, 40, 5, 77, 0, 91, 3, 88, 
    2, 10, 0, 10, 5, 54, 6, 76, 1, 35, 8, 46, 7, 12, 4, 99, 3, 37, 
    6, 41, 2, 42, 8, 32, 1,  7, 5, 83, 7, 74, 3, 83, 0, 51, 4, 94
  };
  const int q6819[] = {
    9, 9, // Number of jobs and machines
    8, 95, 3, 87, 7, 38, 4,  7, 5, 39, 0, 55, 2,  8, 1, 26, 6, 44, 
    1, 23, 5, 13, 6, 84, 0, 77, 3, 45, 2, 73, 7, 80, 4, 44, 8, 43, 
    8, 48, 3, 48, 6, 83, 0, 90, 2, 14, 7, 43, 1, 13, 4, 74, 5, 95, 
    0, 47, 2, 93, 4, 93, 8, 92, 7,  1, 5, 86, 6, 14, 3, 30, 1,  1, 
    7, 14, 5, 60, 2,  2, 1, 20, 6, 33, 3, 22, 8, 51, 0, 33, 4, 61, 
    2, 45, 0, 21, 1, 34, 8, 59, 7, 95, 6, 67, 5, 32, 4, 39, 3, 13, 
    3, 14, 0, 28, 6, 64, 5, 36, 1, 89, 2, 52, 8, 78, 7, 91, 4, 77, 
    6, 71, 8, 81, 7, 43, 2, 56, 4, 32, 0, 62, 3, 56, 5, 16, 1, 45, 
    3, 93, 0, 58, 1, 68, 8, 35, 2, 73, 6, 52, 5, 87, 7, 50, 4, 51
  };
  const int q6820[] = {
    9, 9, // Number of jobs and machines
    3, 69, 4, 60, 7, 20, 5, 99, 6, 42, 2, 80, 0, 53, 8, 35, 1, 68, 
    0, 55, 3, 32, 8, 98, 7, 48, 5, 98, 4, 35, 2, 45, 1, 69, 6, 49, 
    2, 94, 4,  3, 7, 10, 6, 44, 3, 26, 1, 92, 0, 28, 5, 96, 8, 43, 
    2, 24, 0, 86, 8, 37, 3, 99, 6, 24, 4, 41, 7, 68, 5, 97, 1, 73, 
    6, 54, 5, 22, 1, 48, 8, 42, 4, 23, 7, 16, 0, 17, 2, 65, 3, 43, 
    1, 94, 5,  2, 7, 95, 2, 69, 8, 93, 6, 41, 3, 88, 0, 53, 4, 75, 
    8, 63, 4, 76, 6, 97, 2, 56, 5, 72, 3, 75, 1, 49, 7,  5, 0, 44, 
    6, 61, 0, 73, 5, 70, 4, 16, 1, 84, 7, 19, 8, 58, 2,  4, 3, 74, 
    5, 41, 3, 39, 0, 87, 8, 13, 6, 26, 2, 65, 1, 30, 4, 97, 7, 41
  };
  const int q6821[] = {
    9, 9, // Number of jobs and machines
    7, 44, 6, 85, 2, 96, 1, 55, 8, 71, 3, 30, 0, 34, 5, 62, 4, 78, 
    7,  4, 1, 86, 6, 54, 5, 81, 8,  1, 4, 12, 2, 59, 3, 40, 0, 74, 
    4, 72, 1, 60, 5,  6, 0,  7, 6, 67, 3, 93, 7, 90, 2, 35, 8, 75, 
    5, 76, 3, 74, 2, 74, 7, 14, 4, 14, 6, 84, 1, 63, 8, 26, 0, 91, 
    1,  5, 2, 39, 6,  6, 3, 39, 7, 41, 8, 58, 4, 38, 5, 93, 0, 58, 
    2, 83, 6, 13, 8, 41, 4, 89, 0, 28, 1, 28, 7, 16, 5,  9, 3, 50, 
    6, 20, 7, 38, 8, 99, 1, 55, 4, 29, 5, 73, 3, 78, 0, 99, 2, 22, 
    7,  5, 0, 67, 8, 84, 1, 90, 2, 29, 5, 89, 3, 13, 4, 42, 6, 74, 
    3, 68, 1, 27, 5, 43, 0, 43, 8, 99, 2,  9, 4, 50, 7, 95, 6,  4
  };
  const int q6822[] = {
    9, 9, // Number of jobs and machines
    6, 72, 5, 80, 1, 12, 2, 30, 8, 15, 7, 22, 4, 26, 3, 62, 0, 65, 
    1, 58, 8, 45, 7, 61, 3, 57, 6, 30, 2, 83, 4, 80, 5, 85, 0, 42, 
    6, 12, 8, 58, 5, 16, 4, 37, 2,  9, 1, 64, 3, 31, 7, 42, 0, 61, 
    8, 80, 0,  2, 2, 24, 7, 22, 5, 29, 6, 51, 1, 58, 3, 12, 4, 57, 
    5,  2, 6, 20, 7, 86, 2, 13, 3, 10, 4, 93, 8, 11, 1, 26, 0, 94, 
    5,  2, 8, 49, 3, 86, 7,  6, 6, 42, 4, 94, 2, 74, 0, 96, 1, 18, 
    3, 10, 4, 35, 0, 60, 5, 53, 8, 15, 7, 57, 1, 16, 6, 52, 2, 37, 
    0, 99, 3,  7, 4, 18, 7, 78, 5, 24, 6, 25, 1, 42, 8, 25, 2, 62, 
    6, 71, 7, 46, 3, 37, 1, 25, 2, 69, 4, 32, 0,  9, 8, 32, 5, 99
  };
  const int q6823[] = {
    9, 9, // Number of jobs and machines
    4, 67, 5, 34, 0, 63, 8,  5, 6, 29, 1, 76, 2, 16, 7, 81, 3, 66, 
    8,  1, 0, 43, 1, 51, 5, 98, 4, 82, 3, 20, 7, 72, 6,  4, 2, 95, 
    7, 31, 1, 34, 8, 34, 3, 76, 5, 23, 2, 45, 6, 75, 0, 91, 4, 42, 
    8,  3, 3, 29, 4, 86, 7, 79, 2, 77, 1, 40, 6, 22, 5, 80, 0, 55, 
    5, 87, 6, 75, 8, 12, 0, 62, 2, 81, 3, 94, 4, 81, 7, 23, 1, 42, 
    4, 34, 3, 65, 5, 22, 0, 35, 2,  2, 7, 67, 8, 59, 6, 41, 1, 29, 
    8, 97, 4, 15, 0, 43, 3, 66, 1, 62, 2,  4, 7, 42, 6, 60, 5, 28, 
    4, 41, 0, 47, 7,  1, 8, 81, 3, 23, 2, 50, 5, 79, 6, 45, 1, 85, 
    4, 66, 0, 60, 8, 59, 7,  1, 6, 18, 2, 59, 5, 35, 1, 38, 3, 36
  };
  const int q6824[] = {
    9, 9, // Number of jobs and machines
    3,  5, 4, 88, 0, 88, 2, 27, 8, 49, 1, 10, 6, 68, 7, 79, 5, 81, 
    8, 57, 1, 86, 7, 34, 0, 82, 6, 89, 2, 41, 4, 25, 5,  5, 3, 99, 
    2, 42, 3, 36, 5, 45, 1,  6, 4, 36, 8, 66, 7,  4, 0, 19, 6, 71, 
    3, 18, 0, 41, 7,  2, 8, 72, 5, 27, 1, 97, 4, 21, 6, 51, 2, 42, 
    8, 15, 3, 28, 7,  7, 2, 41, 1, 33, 5, 72, 0, 53, 6, 30, 4, 22, 
    6, 74, 2, 94, 7, 10, 5, 34, 1, 37, 3, 38, 0, 94, 4, 71, 8, 86, 
    0, 99, 2, 51, 1,  9, 3, 37, 4, 74, 8, 16, 7, 40, 6, 33, 5, 44, 
    8, 14, 7, 75, 0, 87, 4, 75, 2, 84, 5, 85, 6, 61, 3, 38, 1, 17, 
    1,  2, 0, 87, 6, 64, 4, 20, 8, 54, 7, 84, 5,  1, 3, 88, 2, 45
  };
  const int q6825[] = {
    9, 9, // Number of jobs and machines
    0, 71, 6, 92, 4, 64, 5, 26, 1,  6, 7, 76, 3, 57, 8, 36, 2, 75, 
    2, 94, 0, 27, 3, 32, 7,  1, 8, 92, 1, 83, 4, 65, 6, 20, 5, 47, 
    1, 61, 7, 13, 0, 59, 6, 49, 2, 11, 4, 23, 5, 66, 3, 10, 8, 38, 
    2, 42, 3, 87, 0, 78, 1, 49, 6, 45, 7,  6, 5, 81, 4, 23, 8, 26, 
    0, 57, 6, 19, 7, 61, 2, 10, 4, 74, 3, 25, 1, 57, 8, 57, 5, 96, 
    2, 13, 6, 87, 8, 16, 1, 89, 5, 69, 7, 23, 0, 95, 4, 27, 3, 84, 
    3, 16, 4, 60, 2, 81, 5, 82, 0, 58, 7, 42, 6, 95, 8, 27, 1, 11, 
    4, 75, 0, 16, 2, 63, 5, 11, 1, 33, 3, 85, 7, 92, 8, 30, 6, 95, 
    1, 71, 0, 80, 6, 44, 7, 43, 2,  3, 8,  8, 3, 85, 5, 26, 4, 26
  };
  const int q6826[] = {
    9, 9, // Number of jobs and machines
    3, 42, 5, 28, 0, 44, 6, 49, 4, 42, 2, 87, 7, 71, 8, 96, 1,  7, 
    0, 77, 1, 42, 2,  5, 4, 83, 3, 77, 5, 83, 8, 69, 7, 83, 6,  6, 
    4, 23, 2, 47, 6, 55, 7, 11, 3, 99, 0, 32, 5, 52, 1, 56, 8, 62, 
    2, 15, 4, 34, 0,  8, 7, 44, 3, 44, 1, 18, 8, 54, 5, 65, 6, 43, 
    1, 46, 0, 76, 8, 19, 7, 82, 5,  4, 3, 19, 6, 57, 2, 54, 4, 24, 
    4, 70, 3, 75, 1, 12, 5,  5, 2, 57, 7, 29, 0, 82, 8, 20, 6, 83, 
    4, 14, 0, 82, 2, 98, 8, 33, 3, 24, 1, 28, 7, 82, 6, 76, 5, 79, 
    7, 44, 5, 35, 6, 28, 3, 95, 8, 81, 1,  7, 0, 81, 4, 38, 2, 53, 
    2, 28, 5, 89, 6, 12, 0, 78, 1, 63, 7, 31, 3,  7, 8, 72, 4, 70
  };
  const int q6827[] = {
    9, 9, // Number of jobs and machines
    2, 84, 0, 96, 8, 25, 6, 19, 4, 98, 1,  3, 5, 24, 3, 98, 7, 41, 
    4, 62, 2, 88, 6, 86, 0, 55, 7, 24, 8, 50, 5, 16, 1, 32, 3, 24, 
    4, 68, 3, 39, 7, 43, 5, 32, 6, 47, 8, 63, 2, 77, 1, 49, 0, 24, 
    6, 42, 2, 19, 4, 50, 5, 96, 3, 75, 0, 10, 7, 62, 8, 98, 1, 67, 
    3, 81, 1, 93, 8, 70, 0, 25, 5,  9, 7, 54, 4, 86, 2, 57, 6,  6, 
    2, 88, 6, 40, 1, 66, 7, 60, 0, 57, 4, 69, 8, 62, 5, 80, 3, 85, 
    5, 86, 8, 65, 7,  5, 1, 38, 4, 29, 6,  2, 3,  4, 2, 59, 0, 50, 
    3,  2, 2, 65, 8, 25, 6, 98, 4, 72, 0,  2, 1, 34, 5, 82, 7, 35, 
    3, 63, 6, 24, 2, 37, 0, 98, 1, 60, 4, 69, 5, 65, 8, 14, 7, 64
  };
  const int q6828[] = {
    9, 9, // Number of jobs and machines
    5, 65, 7, 24, 1, 62, 2, 61, 4, 41, 0, 83, 8,  3, 6,  6, 3, 11, 
    0, 40, 4, 24, 6, 65, 1, 67, 8, 79, 7, 16, 2, 22, 3, 33, 5, 25, 
    0, 86, 7, 23, 4, 11, 5, 67, 6, 75, 8, 20, 2, 31, 1, 48, 3, 71, 
    4, 68, 0, 89, 8, 75, 6, 19, 7, 13, 3, 37, 1, 97, 5, 29, 2, 31, 
    4, 88, 6, 92, 3, 48, 7,  9, 8,  2, 5, 27, 0, 75, 2, 22, 1, 44, 
    6, 25, 0, 68, 2, 54, 4, 67, 1, 21, 7, 54, 5, 61, 8,  5, 3, 66, 
    1, 67, 2, 26, 7, 91, 6, 17, 0, 50, 8, 61, 5, 64, 3, 94, 4, 54, 
    2,  1, 6, 16, 4, 51, 8, 99, 0, 36, 3, 92, 7, 25, 1, 45, 5, 89, 
    6, 78, 4, 47, 1, 91, 8, 28, 3, 65, 7, 29, 2, 39, 0, 65, 5, 76
  };
  const int q6829[] = {
    9, 9, // Number of jobs and machines
    8, 47, 5, 50, 7, 94, 6, 11, 3,  5, 2, 27, 4, 17, 1, 75, 0,  9, 
    1, 84, 0, 54, 7, 69, 2, 91, 4, 24, 3, 33, 5, 88, 6, 35, 8, 31, 
    0, 13, 4, 12, 5, 21, 6, 70, 2, 13, 1, 52, 8, 65, 7, 49, 3, 52, 
    6, 93, 1, 28, 8, 66, 0, 70, 4, 16, 5, 41, 7,  3, 3, 58, 2, 31, 
    8, 49, 7, 52, 3, 45, 1, 42, 2, 42, 0, 43, 5, 36, 6, 60, 4,  7, 
    5, 47, 8, 66, 4, 69, 7, 72, 0, 16, 6, 49, 2, 15, 3, 90, 1,  8, 
    6, 11, 7, 83, 8, 65, 5, 90, 2, 96, 3, 30, 1,  7, 0, 17, 4,  2, 
    7, 26, 6, 31, 5, 22, 0, 68, 8, 29, 4, 43, 3, 56, 2,  2, 1, 80, 
    5, 28, 2, 95, 4, 15, 7, 63, 6, 57, 8, 65, 1, 89, 3, 27, 0, 46
  };
  const int q6830[] = {
    9, 9, // Number of jobs and machines
    5, 77, 3, 45, 8,  1, 6, 77, 2, 26, 7, 11, 0, 44, 1,  7, 4, 44, 
    3, 39, 7, 69, 8, 48, 2, 54, 1, 54, 5, 41, 6, 40, 4, 43, 0, 33, 
    2, 66, 0, 30, 1, 15, 3,  9, 4, 47, 8, 30, 7, 86, 5,  5, 6, 19, 
    1, 67, 3, 56, 7, 80, 6, 22, 8,  3, 0, 26, 2, 92, 5, 61, 4, 29, 
    1, 52, 7,  4, 5, 16, 8, 72, 3, 78, 0, 23, 6, 35, 4, 57, 2, 94, 
    3, 45, 4, 76, 5, 49, 0, 83, 8, 54, 7, 85, 1, 27, 2, 21, 6, 67, 
    3, 67, 8, 77, 2,  1, 5, 55, 7, 77, 0, 88, 6, 44, 1, 61, 4, 36, 
    7, 28, 5, 96, 1, 71, 8, 33, 6, 82, 3, 16, 0, 95, 2, 37, 4, 70, 
    4, 74, 0, 21, 1, 50, 7, 43, 8, 69, 3, 25, 6, 57, 2,  1, 5, 70
  };
  const int q6831[] = {
    9, 9, // Number of jobs and machines
    6, 92, 5, 77, 0, 38, 1, 37, 8, 60, 4, 14, 3, 16, 2, 22, 7,  3, 
    4, 86, 2, 85, 7, 85, 8, 94, 3, 99, 1, 94, 6, 84, 5, 15, 0, 73, 
    6, 41, 5, 19, 8, 68, 0, 85, 2, 52, 7, 24, 3, 52, 1,  8, 4, 54, 
    7, 87, 4, 52, 1, 17, 8, 49, 5, 50, 3, 95, 0, 86, 2, 45, 6, 15, 
    7, 43, 1,  3, 4, 52, 5, 69, 2, 46, 8, 69, 0, 76, 3, 91, 6, 27, 
    1,  8, 6, 43, 4, 83, 7,  7, 5, 79, 2, 59, 3,  5, 8, 22, 0, 99, 
    5, 72, 8, 77, 0, 73, 2,  9, 1, 49, 4, 84, 3, 29, 7, 86, 6, 50, 
    6, 12, 0, 17, 1, 65, 7, 65, 4, 46, 2, 67, 3, 78, 8, 65, 5, 88, 
    0, 75, 8, 80, 1, 48, 3, 97, 6, 48, 2, 64, 7, 95, 4, 65, 5, 19
  };
  const int q6832[] = {
    9, 9, // Number of jobs and machines
    6, 76, 1, 28, 4, 53, 2, 31, 8, 44, 5, 96, 3, 60, 7, 66, 0, 31, 
    8, 58, 7, 21, 2, 11, 5, 81, 3, 35, 1, 52, 0, 42, 6, 90, 4, 85, 
    4, 46, 0, 83, 2, 69, 6, 92, 3,  1, 7, 52, 1, 60, 5, 21, 8,  2, 
    0, 61, 5, 49, 2, 31, 1, 83, 7, 83, 6, 17, 3, 99, 4, 50, 8, 20, 
    1, 16, 0, 29, 6, 80, 2, 90, 7, 97, 4, 37, 5, 67, 3, 57, 8, 50, 
    5, 44, 8,  7, 4,  9, 3, 25, 6, 66, 0, 16, 1, 85, 2, 36, 7, 72, 
    8, 77, 7, 43, 5, 89, 0,  4, 1, 31, 3, 94, 6, 15, 4, 99, 2, 71, 
    4, 16, 0, 85, 6, 24, 2, 75, 3, 79, 1, 14, 5, 17, 8, 93, 7, 47, 
    8, 33, 6, 18, 2, 45, 4, 94, 1, 36, 5, 20, 3, 85, 0, 78, 7, 75
  };
  const int q6833[] = {
    9, 9, // Number of jobs and machines
    7, 53, 5, 59, 2, 37, 1, 73, 3, 78, 0, 66, 4, 71, 8, 11, 6, 75, 
    4,  7, 8, 84, 5, 49, 0, 38, 7, 96, 2, 43, 6, 64, 3, 25, 1,  7, 
    8, 91, 7, 65, 2, 47, 0, 84, 1, 40, 3, 97, 6, 53, 4, 34, 5, 75, 
    4,  2, 3, 74, 2, 81, 0, 33, 7, 11, 6, 99, 5,  6, 8, 30, 1, 52, 
    4, 69, 2, 35, 1, 29, 0, 17, 8, 48, 3, 95, 6,  3, 5, 73, 7, 27, 
    1, 72, 0, 38, 5, 91, 8, 72, 3, 46, 7, 90, 6, 56, 4, 16, 2, 12, 
    4, 82, 1, 92, 6,  5, 5, 68, 3, 59, 0, 35, 7, 79, 8, 84, 2, 25, 
    7,  4, 5, 10, 1, 21, 8, 23, 4, 85, 2, 80, 6, 43, 0, 47, 3,  7, 
    1, 86, 8, 41, 4, 75, 7, 12, 5, 14, 3, 96, 6, 28, 0, 43, 2, 76
  };
  const int q6834[] = {
    9, 9, // Number of jobs and machines
    2, 52, 7, 91, 1, 13, 8, 11, 3, 10, 5, 22, 4, 30, 6, 57, 0,  4, 
    6, 24, 1, 15, 8, 28, 2, 87, 5, 62, 7, 50, 0, 90, 4, 88, 3,  5, 
    1, 37, 3, 42, 5, 76, 6, 33, 2, 13, 4, 88, 0, 86, 8, 49, 7, 52, 
    3,  6, 6, 26, 1, 10, 4, 80, 0, 25, 7, 87, 2, 40, 8, 83, 5, 42, 
    2, 97, 7, 84, 0,  7, 6, 47, 4, 68, 8, 71, 1, 63, 3, 76, 5, 43, 
    3,  2, 5, 69, 0, 44, 1, 20, 6, 17, 7, 52, 4, 34, 2,  6, 8, 44, 
    0, 86, 5, 73, 3, 54, 2, 38, 4, 44, 6, 15, 7, 77, 8, 62, 1, 37, 
    1, 97, 4, 50, 6, 79, 0, 19, 2, 32, 8, 36, 3, 77, 7,  9, 5, 26, 
    2, 36, 6, 63, 1, 62, 7, 24, 5, 20, 3, 49, 8, 13, 0, 67, 4, 86
  };
  const int q6835[] = {
    9, 9, // Number of jobs and machines
    3, 30, 8, 69, 6, 68, 7, 98, 0, 68, 4, 50, 5, 27, 2, 63, 1, 82, 
    0, 25, 8, 22, 7, 15, 4, 53, 3, 56, 6, 33, 1, 72, 5, 82, 2, 48, 
    2,  1, 8, 90, 5, 15, 3, 88, 6, 81, 7,  5, 1,  5, 4, 63, 0, 46, 
    8, 53, 2, 72, 0, 39, 1, 36, 7, 28, 5, 77, 6, 69, 3, 13, 4, 34, 
    7, 21, 3,  8, 0, 27, 4, 90, 8, 73, 2, 91, 5, 30, 6, 87, 1,  8, 
    6, 89, 1, 86, 8, 45, 5, 13, 0, 93, 4, 21, 3, 38, 2, 76, 7, 37, 
    3, 75, 0, 54, 1, 86, 8, 54, 2, 64, 7, 37, 4, 13, 6,  9, 5,  2, 
    2, 13, 4, 89, 3,  9, 6, 45, 5, 88, 7, 44, 1, 27, 8, 47, 0, 43, 
    4, 52, 8,  6, 7, 59, 2, 96, 5, 36, 6, 79, 3, 52, 1, 14, 0, 25
  };
  const int q6836[] = {
    9, 9, // Number of jobs and machines
    6, 32, 5, 34, 2, 86, 0, 89, 3, 26, 1, 75, 4, 24, 7, 43, 8, 66, 
    2, 77, 4, 46, 8, 23, 7, 91, 1, 79, 5, 53, 6, 36, 0, 17, 3, 52, 
    3, 54, 2, 88, 0, 92, 7, 23, 6, 20, 5, 66, 4, 86, 8, 18, 1, 33, 
    6, 11, 5, 77, 0, 64, 4, 42, 2, 84, 1, 30, 7, 76, 8, 57, 3, 56, 
    4,  6, 6, 11, 3, 67, 8, 25, 5, 11, 2, 71, 1, 66, 0, 26, 7, 55, 
    3, 25, 2, 43, 7, 81, 5, 27, 1, 51, 6,  3, 8, 69, 4, 33, 0,  3, 
    4, 17, 2, 46, 5, 36, 6, 15, 7, 48, 1, 49, 0, 69, 8, 84, 3, 38, 
    4, 29, 1, 74, 3, 71, 7, 37, 8, 66, 5, 25, 6, 30, 0, 85, 2, 19, 
    7, 38, 2, 56, 1, 65, 4, 41, 6, 34, 0,  8, 3, 27, 5, 35, 8, 88
  };
  const int q6837[] = {
    9, 9, // Number of jobs and machines
    7, 59, 0, 90, 1, 95, 5, 70, 6,  5, 8, 31, 4, 44, 2, 94, 3, 47, 
    4, 68, 1, 28, 7, 96, 3, 37, 5,  3, 8, 37, 0, 46, 6, 20, 2, 16, 
    4, 39, 8, 19, 1, 85, 5,  1, 2, 85, 3, 23, 6, 93, 7,  9, 0, 29, 
    5, 23, 2, 27, 6, 13, 1, 39, 0, 43, 3, 45, 7, 17, 4, 51, 8, 33, 
    3, 52, 0, 52, 6, 90, 1,  7, 2, 44, 7, 23, 8, 98, 5, 56, 4, 50, 
    6, 41, 7, 70, 8, 90, 0, 53, 4,  2, 1,  7, 3,  6, 2, 35, 5, 63, 
    8, 81, 1, 30, 5, 45, 2, 53, 4, 37, 3,  9, 6, 98, 0, 29, 7, 77, 
    3, 86, 7, 56, 0, 51, 8, 62, 4, 50, 1, 59, 2, 96, 5, 66, 6, 77, 
    5, 43, 4, 89, 2,  6, 1, 83, 3, 86, 8, 23, 0, 98, 7, 69, 6, 44
  };
  const int q6838[] = {
    9, 9, // Number of jobs and machines
    0, 44, 5, 14, 7, 29, 4, 13, 3, 41, 2, 69, 8, 84, 6, 39, 1, 22, 
    3, 90, 8, 91, 7,  7, 0, 88, 6, 40, 2, 23, 5, 79, 4, 78, 1, 24, 
    2, 65, 3, 92, 7, 60, 6, 37, 1, 65, 5, 23, 0, 77, 4, 52, 8, 17, 
    4, 53, 3, 39, 2,  1, 1, 80, 7, 47, 5, 76, 6, 59, 0, 88, 8, 45, 
    5, 25, 7, 50, 2, 93, 6, 20, 4, 68, 0, 33, 3, 50, 1, 92, 8, 60, 
    2,  2, 1, 34, 6, 15, 8, 97, 0, 28, 7, 11, 4, 25, 3, 24, 5, 22, 
    1, 12, 5, 28, 0, 72, 8,  5, 7, 73, 6, 89, 3, 39, 4, 56, 2, 56, 
    3, 16, 2, 56, 7,  1, 1, 10, 8, 75, 0, 70, 6, 34, 5, 21, 4,  3, 
    2, 30, 1, 68, 4, 80, 5,  2, 3,  1, 0, 57, 8, 85, 6, 97, 7,  3
  };
  const int q6839[] = {
    9, 9, // Number of jobs and machines
    6, 88, 4, 66, 5, 63, 2, 52, 7, 90, 8,  3, 0, 67, 3, 90, 1, 83, 
    4, 52, 3, 59, 5, 56, 2, 27, 1, 53, 6, 87, 0, 24, 7, 30, 8, 68, 
    1, 92, 4, 52, 3, 20, 7, 97, 2, 96, 5, 86, 0, 43, 8, 18, 6, 77, 
    2, 45, 8, 39, 4, 99, 7, 18, 5, 42, 3, 12, 0, 82, 6,  5, 1, 78, 
    6, 32, 0, 60, 7, 29, 4, 34, 1, 99, 8, 26, 3, 10, 5, 24, 2, 26, 
    6, 19, 7, 66, 3, 21, 4, 16, 5, 93, 1, 98, 0, 18, 8, 69, 2, 32, 
    3, 31, 2, 49, 0, 19, 5, 97, 8, 33, 4, 74, 1, 78, 6,  8, 7, 12, 
    7, 10, 3, 90, 1, 61, 6, 47, 0, 20, 5, 42, 4, 90, 8, 37, 2, 81, 
    0, 47, 2, 72, 4, 12, 6, 79, 3, 82, 7, 61, 8, 40, 5, 47, 1, 70
  };
  const int q6840[] = {
    9, 9, // Number of jobs and machines
    3,  5, 5, 91, 6, 11, 8, 44, 2, 27, 4, 96, 7, 15, 0, 95, 1, 76, 
    2, 47, 8, 55, 4, 76, 5,  1, 3, 45, 1, 51, 0, 26, 6, 79, 7, 44, 
    6, 49, 4, 90, 5, 28, 3, 85, 0, 54, 8, 55, 2, 39, 1,  7, 7, 20, 
    5, 62, 6, 26, 2, 91, 8, 57, 3, 87, 1, 46, 0, 90, 4, 66, 7, 26, 
    5,  8, 4,  3, 7, 63, 0, 42, 6, 35, 1,  8, 8, 79, 3, 26, 2, 40, 
    7, 11, 0,  3, 2, 21, 5,  8, 4, 71, 8, 41, 3, 64, 1, 11, 6, 52, 
    5, 69, 2, 28, 0, 55, 7, 26, 3, 59, 1, 48, 6,  9, 4, 74, 8, 22, 
    6,  3, 2, 68, 7, 43, 5, 46, 0, 85, 4, 73, 8, 40, 3, 48, 1, 53, 
    4, 61, 5, 14, 8, 84, 6, 31, 1,  5, 2,  7, 3, 54, 7, 39, 0, 20
  };
  const int q6841[] = {
    9, 9, // Number of jobs and machines
    1, 41, 0, 97, 2, 60, 6, 14, 7, 90, 4, 20, 5, 99, 3, 94, 8, 60, 
    6, 42, 0, 60, 2, 66, 8,  5, 4, 16, 3,  8, 1, 54, 7, 27, 5,  3, 
    5, 20, 6, 16, 7, 23, 1, 15, 3, 64, 0, 38, 2, 31, 8, 73, 4, 78, 
    1, 14, 5,  3, 4, 82, 7, 81, 2, 98, 0, 92, 8, 87, 3, 85, 6, 95, 
    7, 71, 3, 61, 4, 78, 5, 78, 6, 90, 0, 38, 8, 69, 2, 41, 1,  9, 
    8, 40, 6, 36, 2, 32, 0, 87, 3, 52, 5, 29, 4, 68, 1, 66, 7, 43, 
    0, 36, 7, 63, 6, 31, 8, 76, 5, 81, 4,  2, 1, 36, 2, 16, 3, 27, 
    8, 34, 3, 65, 7, 88, 2, 14, 1, 46, 4, 81, 0, 30, 6, 21, 5,  5, 
    4,  9, 2, 71, 8, 87, 1, 68, 5, 24, 7, 59, 6, 53, 0, 76, 3, 84
  };
  const int q6842[] = {
    9, 9, // Number of jobs and machines
    1, 79, 3, 61, 5, 36, 0, 71, 4, 47, 2, 73, 6, 69, 8, 76, 7, 10, 
    0, 97, 3, 69, 7, 46, 6, 74, 8, 11, 5, 63, 1, 52, 4, 75, 2, 46, 
    2, 46, 6, 61, 3,  1, 4, 88, 5, 11, 7, 91, 8, 11, 0, 75, 1, 13, 
    6, 40, 8, 16, 4, 62, 2, 67, 1, 64, 5,  7, 3, 57, 7, 12, 0, 75, 
    6, 92, 2, 25, 5, 49, 1, 75, 3, 37, 4, 60, 0, 35, 7, 93, 8, 83, 
    1, 25, 6,  7, 5,  3, 2, 32, 8,  9, 4, 44, 7, 30, 0,  9, 3, 64, 
    3, 28, 5, 62, 7, 18, 0, 31, 2, 60, 1, 12, 8, 17, 4, 16, 6, 20, 
    0, 54, 3,  1, 7, 20, 8, 48, 1, 46, 6, 28, 5, 44, 2, 50, 4, 12, 
    2, 57, 6,  1, 4, 12, 1, 12, 7, 44, 0,  3, 5, 14, 8,  1, 3, 94
  };
  const int q6843[] = {
    9, 9, // Number of jobs and machines
    3, 99, 8, 45, 0, 56, 2, 61, 4, 68, 6, 14, 5, 47, 7, 68, 1, 91, 
    7,  9, 5, 18, 6, 31, 0, 60, 2, 68, 8, 68, 3, 36, 1, 25, 4, 76, 
    5, 83, 3,  7, 7, 94, 1, 41, 6, 33, 8, 12, 2, 97, 4, 58, 0, 65, 
    6, 44, 4, 30, 3,  3, 0, 81, 1, 57, 7, 49, 2, 75, 8, 85, 5,  8, 
    2, 44, 6, 25, 0,  2, 3, 30, 1, 34, 5, 68, 8, 65, 4,  6, 7, 25, 
    5, 57, 3, 70, 0, 48, 7, 78, 2, 38, 6, 70, 8, 24, 4,  7, 1, 53, 
    7, 48, 8,  4, 3, 11, 4, 88, 1, 62, 6, 17, 0, 87, 5, 44, 2, 10, 
    1, 72, 5, 47, 2, 87, 8, 23, 7,  5, 4, 22, 0, 63, 3, 85, 6, 92, 
    5, 77, 0, 60, 6, 37, 3, 64, 1,  5, 8, 38, 4, 44, 7, 61, 2, 16
  };
  const int q6844[] = {
    9, 9, // Number of jobs and machines
    0, 30, 7, 44, 4, 67, 1, 47, 2, 12, 5, 29, 6, 87, 8, 74, 3, 64, 
    8, 82, 7, 34, 6, 26, 5, 33, 0, 70, 3, 44, 1,  4, 2, 48, 4, 47, 
    7, 32, 1, 51, 6, 11, 8, 87, 4, 35, 5, 90, 2,  9, 3, 15, 0, 96, 
    0, 18, 4, 61, 6, 90, 1,  3, 5,  8, 2, 13, 8, 46, 3, 12, 7,  6, 
    0, 39, 4, 55, 2, 53, 3, 11, 6, 29, 8, 87, 5, 47, 1, 89, 7, 47, 
    4, 13, 8, 32, 3, 48, 1, 86, 7, 55, 2, 18, 0,  8, 5, 13, 6, 31, 
    1, 13, 6, 31, 0,  8, 2, 48, 3,  3, 8, 37, 7, 14, 4, 26, 5, 31, 
    4, 44, 0, 13, 5, 53, 3,  6, 1, 42, 6, 43, 7, 32, 8, 21, 2, 27, 
    3, 93, 4, 45, 0, 66, 1, 69, 8, 93, 2, 32, 5, 90, 6, 63, 7, 98
  };
  const int q6845[] = {
    9, 9, // Number of jobs and machines
    8, 92, 5, 99, 2, 57, 6, 64, 7, 15, 4, 84, 0, 94, 3, 30, 1, 88, 
    2, 65, 4, 32, 3, 15, 6,  4, 0, 89, 5, 90, 1, 78, 7, 94, 8, 64, 
    2, 66, 7, 10, 8,  3, 6, 50, 0, 85, 1, 93, 5, 82, 3, 13, 4, 23, 
    6, 38, 2, 61, 1, 32, 0, 61, 4, 57, 5, 94, 8, 57, 3, 93, 7, 31, 
    7, 69, 1, 38, 3, 90, 4, 63, 0,  8, 6, 87, 5, 28, 8, 10, 2, 83, 
    8, 91, 0, 81, 7,  5, 1, 90, 5,  9, 2, 69, 4, 79, 3, 78, 6, 18, 
    4, 94, 2, 44, 1, 88, 7, 39, 6, 54, 8, 62, 0,  9, 3, 60, 5, 21, 
    2, 38, 5,  2, 1, 87, 8, 63, 6, 25, 7, 84, 3,  3, 4, 28, 0, 45, 
    5, 60, 1, 28, 0, 23, 6, 53, 3, 19, 2, 91, 7, 23, 8, 45, 4, 98
  };
  const int q6846[] = {
    9, 9, // Number of jobs and machines
    7, 65, 4, 95, 2, 77, 0, 29, 8, 70, 1, 13, 3,  7, 5, 64, 6, 71, 
    7, 11, 5, 60, 3, 83, 0, 90, 4, 69, 6, 82, 1,  6, 2, 46, 8, 23, 
    1, 13, 3, 42, 5, 33, 4, 15, 8, 44, 7, 10, 6, 12, 0, 20, 2, 90, 
    5, 69, 4, 22, 7, 87, 2, 84, 3, 18, 6, 56, 1, 37, 0, 62, 8, 42, 
    1, 64, 4, 16, 8, 94, 6, 78, 0, 79, 5, 31, 7, 50, 3, 67, 2, 23, 
    8,  4, 0,  4, 3, 52, 2, 31, 1, 29, 5, 56, 6, 55, 4, 99, 7, 44, 
    6, 94, 3, 51, 1, 63, 0, 35, 2, 62, 8, 94, 4, 35, 7, 75, 5, 74, 
    7, 36, 2, 62, 4, 42, 0, 63, 5, 27, 8, 80, 3, 60, 6, 84, 1,  7, 
    7, 82, 6, 47, 2, 77, 8, 54, 3, 84, 4,  2, 1,  1, 5, 87, 0, 33
  };
  const int q6847[] = {
    9, 9, // Number of jobs and machines
    8, 31, 2, 34, 5, 37, 3, 74, 6, 52, 1, 63, 4, 11, 0, 75, 7, 68, 
    6, 42, 8, 24, 2,  6, 5, 38, 4, 24, 1, 85, 7, 14, 0, 45, 3, 44, 
    3, 66, 6, 27, 2, 84, 5, 69, 7, 68, 4, 29, 8, 14, 0, 63, 1, 24, 
    3, 17, 0,  2, 6, 77, 4, 69, 1, 55, 5, 79, 7, 54, 2, 78, 8, 82, 
    0, 92, 2, 78, 8, 66, 4, 63, 3, 35, 6,  5, 1, 46, 7, 35, 5, 63, 
    7, 10, 5, 55, 6, 37, 1, 23, 3, 23, 4, 75, 8, 52, 2, 31, 0, 91, 
    2, 46, 6, 86, 3, 67, 4, 10, 5, 74, 7, 53, 1, 75, 8, 14, 0, 68, 
    1, 27, 5, 42, 7, 47, 4, 12, 0, 54, 8, 89, 3, 45, 2, 43, 6, 83, 
    1,  4, 8, 98, 7, 62, 0, 95, 2, 81, 5, 41, 4, 68, 3, 24, 6, 29
  };
  const int q6848[] = {
    9, 9, // Number of jobs and machines
    4, 28, 1, 16, 0, 37, 8, 49, 7, 66, 2,  2, 3, 42, 5, 76, 6, 46, 
    6, 91, 7, 62, 3, 33, 5, 27, 4, 97, 8, 15, 0, 66, 2, 18, 1, 56, 
    5, 44, 2, 80, 1, 34, 0, 82, 7, 61, 8, 36, 3, 84, 4, 56, 6, 61, 
    3, 98, 6, 35, 2, 88, 0, 41, 7, 76, 4, 66, 5, 47, 8,  8, 1, 11, 
    2, 32, 6, 42, 5, 19, 4, 74, 8, 15, 1, 59, 3, 56, 7,  8, 0, 32, 
    6, 94, 3, 46, 4, 39, 5, 93, 0, 48, 1, 29, 8, 51, 2, 30, 7, 15, 
    1, 13, 5, 68, 0, 58, 4, 33, 3, 99, 7,  5, 8, 91, 2, 33, 6, 55, 
    2, 57, 6,  5, 3,  6, 5, 98, 7, 31, 1, 87, 4, 72, 0, 80, 8, 66, 
    6, 89, 4,  5, 8, 67, 2, 82, 3, 50, 5, 84, 0, 29, 7, 14, 1, 54
  };
  const int q6849[] = {
    9, 9, // Number of jobs and machines
    2, 22, 1,  4, 5, 23, 8, 18, 4, 10, 7, 63, 6, 51, 0,  3, 3, 45, 
    3, 41, 0, 33, 1, 43, 4, 24, 2, 72, 5, 92, 8,  1, 7, 25, 6, 33, 
    5, 10, 2, 22, 3, 31, 1, 52, 7, 95, 6,  2, 4, 32, 0, 35, 8, 93, 
    0, 84, 7, 17, 6, 68, 2, 78, 3, 42, 4, 55, 8, 44, 1, 55, 5, 69, 
    0, 41, 4,  6, 1, 10, 8, 75, 3, 55, 2, 41, 7, 44, 6, 70, 5, 59, 
    1, 28, 5, 95, 2, 85, 0, 12, 8, 18, 3, 79, 7, 96, 6, 95, 4, 19, 
    1, 39, 3, 14, 6, 98, 5, 33, 2, 20, 7, 89, 0, 77, 8, 15, 4, 16, 
    8, 99, 5, 39, 2, 77, 3, 91, 7, 81, 0, 30, 6, 36, 1, 11, 4,  6, 
    2, 45, 0, 35, 6,  8, 4, 27, 7, 52, 3, 43, 8, 26, 5,  3, 1, 72
  };
  const int q6850[] = {
    9, 9, // Number of jobs and machines
    6, 61, 4, 35, 3, 57, 0, 42, 1, 36, 7, 46, 5, 72, 8, 19, 2, 41, 
    5, 59, 2, 97, 1, 56, 7, 64, 8, 17, 0, 35, 6, 65, 3, 43, 4, 62, 
    2, 42, 3, 11, 7, 73, 6, 95, 5, 36, 4, 93, 1, 91, 8, 30, 0, 15, 
    2, 20, 7, 96, 8, 67, 1, 12, 0, 95, 5, 46, 3, 56, 6, 78, 4, 28, 
    0, 44, 8, 69, 1, 92, 6,  9, 2, 51, 5,  4, 3, 21, 7, 46, 4, 91, 
    8, 84, 6,  3, 0, 87, 4, 16, 3, 50, 7, 58, 5, 48, 2, 95, 1, 19, 
    3, 12, 1, 78, 2, 35, 4, 82, 0, 55, 8,  4, 7, 15, 6, 97, 5, 70, 
    6, 94, 0, 52, 7, 98, 4, 79, 8, 81, 3, 50, 1, 44, 5, 30, 2, 73, 
    8, 52, 6,  2, 0, 20, 7, 99, 3, 79, 4, 38, 2, 79, 5, 85, 1,  3
  };
  const int q6851[] = {
    9, 9, // Number of jobs and machines
    2, 82, 0, 18, 4, 92, 1, 81, 8, 87, 5, 33, 3, 67, 7,  5, 6, 17, 
    7, 15, 3, 55, 5, 35, 8, 81, 6,  8, 4, 91, 2, 13, 0, 13, 1, 88, 
    1, 17, 5, 18, 3, 96, 6, 64, 7, 46, 4, 47, 8, 18, 0, 76, 2, 82, 
    0, 58, 3, 69, 1, 67, 6, 63, 4, 79, 5, 67, 8, 70, 7, 77, 2, 97, 
    1, 67, 2, 80, 6, 12, 7, 52, 0, 75, 4, 19, 8, 98, 3, 78, 5, 71, 
    3, 52, 0,  5, 1, 79, 2, 22, 7, 50, 4, 12, 8, 18, 6, 88, 5, 44, 
    0, 55, 8, 75, 5, 48, 3,  5, 1, 66, 6, 79, 4, 58, 2, 69, 7, 42, 
    7, 39, 8, 65, 1, 54, 3, 49, 6, 13, 0, 34, 5, 92, 2, 21, 4, 85, 
    6, 12, 1, 81, 7, 50, 3, 42, 8, 12, 4, 32, 0, 66, 2, 19, 5, 85
  };
  const int q6852[] = {
    9, 9, // Number of jobs and machines
    2, 51, 5, 46, 4, 62, 0, 75, 8, 98, 3, 15, 1, 63, 6, 29, 7, 68, 
    3, 37, 4, 28, 2, 39, 8, 69, 7, 47, 1, 52, 5, 10, 0, 87, 6,  2, 
    1, 21, 3, 84, 6, 91, 7, 68, 5, 24, 8, 51, 2, 21, 0, 40, 4, 72, 
    6, 69, 5, 92, 4, 23, 8, 81, 7, 47, 2, 28, 0, 50, 1, 29, 3, 28, 
    7, 18, 6, 23, 1, 35, 4,  1, 5, 32, 8, 81, 0, 41, 2, 86, 3, 46, 
    5, 89, 8, 19, 0, 77, 7, 94, 6, 76, 1, 56, 2, 14, 3, 94, 4, 97, 
    6, 18, 4, 80, 8, 64, 0, 33, 1, 78, 2, 86, 5, 89, 3, 72, 7, 75, 
    1, 60, 2, 43, 5, 61, 6, 30, 4, 80, 3, 14, 0, 50, 7, 34, 8,  3, 
    4, 11, 5, 79, 1, 17, 7,  1, 8, 40, 2, 44, 3, 46, 6, 64, 0, 94
  };
  const int q6853[] = {
    9, 9, // Number of jobs and machines
    5, 89, 0, 30, 6, 33, 7, 71, 8, 27, 3, 57, 2, 29, 1, 65, 4, 31, 
    0, 72, 2, 87, 8, 64, 4, 69, 7, 18, 6,  8, 5,  4, 1,  8, 3, 24, 
    1, 61, 8, 63, 5, 19, 2, 29, 3, 36, 0, 25, 6, 42, 4, 55, 7, 47, 
    2, 74, 3, 61, 0, 32, 1, 79, 7, 13, 5, 77, 4, 68, 8, 34, 6, 11, 
    8, 71, 6, 56, 3, 90, 4, 87, 7, 73, 0, 96, 5, 64, 1, 78, 2, 45, 
    3, 59, 0, 65, 6, 94, 2, 83, 4,  2, 7,  8, 8,  9, 5, 43, 1, 74, 
    2, 44, 0, 26, 8, 75, 6, 71, 4, 64, 5, 49, 7, 32, 1, 61, 3, 23, 
    8, 24, 5, 17, 0, 88, 4, 99, 3, 68, 2,  1, 7, 27, 1, 77, 6, 21, 
    6, 90, 0, 11, 2, 59, 4, 76, 8, 61, 3, 72, 1, 55, 7, 25, 5,  3
  };
  const int q6854[] = {
    9, 9, // Number of jobs and machines
    7, 67, 0, 52, 5, 86, 8, 27, 3, 91, 6, 80, 2, 20, 4, 83, 1,  6, 
    2, 89, 0, 93, 6, 68, 3, 43, 1, 86, 4, 75, 8, 97, 5, 72, 7, 86, 
    4, 85, 0, 49, 7, 29, 6, 66, 1, 16, 3, 51, 8,  4, 2, 59, 5, 56, 
    0, 50, 4, 18, 5, 71, 8, 17, 2, 27, 3,  7, 6, 52, 1, 93, 7, 67, 
    4, 44, 2, 52, 6, 80, 5, 40, 0, 74, 8, 47, 1, 11, 7, 20, 3, 43, 
    1, 37, 4, 97, 5, 38, 8, 72, 6, 74, 0, 90, 3, 40, 7, 73, 2, 91, 
    0, 54, 2,  2, 3, 60, 6, 30, 4, 82, 8, 69, 7, 13, 5, 66, 1, 49, 
    0, 26, 4,  8, 7, 59, 8, 15, 3,  9, 6, 78, 5, 20, 2, 76, 1,  9, 
    0,  9, 3, 88, 5, 93, 8, 10, 7, 24, 1, 40, 2, 36, 4, 43, 6, 24
  };
  const int q6855[] = {
    9, 9, // Number of jobs and machines
    5, 15, 2,  9, 1, 18, 4, 16, 0, 14, 8, 11, 7, 77, 3, 17, 6, 15, 
    2,  1, 6, 21, 7, 44, 5, 48, 1, 52, 3, 58, 4, 38, 0, 62, 8, 46, 
    4, 19, 5, 95, 1, 78, 2, 76, 8, 25, 0, 64, 3, 92, 6, 45, 7,  9, 
    5,  6, 2, 17, 4, 24, 1, 71, 3, 80, 7, 26, 6, 33, 8, 36, 0, 93, 
    2, 70, 5, 37, 0, 99, 8, 53, 7, 13, 6, 33, 1, 63, 4, 78, 3, 95, 
    4, 73, 7,  4, 0, 42, 6, 92, 8, 46, 1, 87, 5, 38, 3, 50, 2, 37, 
    3, 66, 5, 41, 4, 36, 7, 88, 0, 64, 8, 64, 1, 22, 6, 78, 2, 84, 
    0, 38, 2, 70, 1, 54, 8, 79, 7, 89, 4, 92, 3, 67, 5, 44, 6, 99, 
    6, 83, 7, 68, 3, 53, 1, 21, 8, 50, 4, 96, 5, 53, 0, 69, 2, 82
  };
  const int q6856[] = {
    9, 9, // Number of jobs and machines
    5, 92, 1,  1, 0, 36, 3, 55, 6, 83, 4, 58, 8, 82, 7, 88, 2, 64, 
    0, 77, 3, 10, 8, 66, 1, 48, 5, 86, 4, 85, 6,  5, 7, 98, 2, 75, 
    8, 74, 5, 32, 2, 20, 4, 21, 3, 66, 0, 99, 1, 58, 7, 24, 6, 34, 
    8, 52, 4, 21, 5, 19, 0, 96, 7, 89, 2, 15, 3, 92, 1, 71, 6, 25, 
    1, 54, 6, 15, 5, 60, 2, 71, 0, 97, 4, 19, 7, 55, 8, 12, 3, 17, 
    3, 53, 2, 88, 8, 66, 7, 80, 5, 65, 4, 41, 0, 98, 1, 46, 6, 68, 
    2, 79, 7, 19, 4, 93, 8, 12, 0, 75, 5, 19, 6, 68, 1, 72, 3,  2, 
    1, 65, 7, 82, 0, 56, 6, 34, 4, 38, 8, 13, 2, 89, 3,  7, 5, 26, 
    4, 22, 7, 87, 1, 83, 0, 89, 2, 78, 5, 82, 3, 43, 8, 75, 6, 13
  };
  const int q6857[] = {
    9, 9, // Number of jobs and machines
    0, 58, 3, 38, 1, 60, 2, 24, 6, 67, 8, 66, 4, 24, 7, 11, 5, 53, 
    1, 69, 3, 71, 5, 75, 4,  6, 2, 68, 8, 69, 6, 69, 7, 63, 0, 28, 
    7, 60, 1, 46, 2,  5, 3, 98, 5, 34, 0, 55, 4, 47, 8,  1, 6, 22, 
    5, 69, 1, 72, 8,  4, 3, 22, 4, 36, 0, 14, 2, 94, 6, 69, 7,  7, 
    1, 15, 3, 72, 6, 59, 4, 37, 8, 18, 0, 24, 7, 95, 5, 39, 2, 45, 
    8, 18, 2, 76, 6,  7, 0, 59, 5, 84, 4, 20, 3, 46, 1, 44, 7, 78, 
    7, 22, 6, 36, 1, 90, 4, 19, 0, 90, 3, 94, 8, 90, 5, 47, 2, 67, 
    4, 37, 2, 99, 3, 87, 6, 59, 8, 77, 1, 75, 7, 13, 5, 24, 0,  6, 
    4, 22, 6, 16, 0, 66, 5, 70, 1, 34, 2, 62, 8,  9, 7, 63, 3, 88
  };
  const int q6858[] = {
    9, 9, // Number of jobs and machines
    0, 74, 2,  8, 1, 93, 7, 87, 3,  5, 4, 98, 5, 81, 6, 49, 8, 16, 
    3, 85, 6, 54, 1, 97, 5, 80, 7, 74, 8, 22, 4, 75, 0,  6, 2, 79, 
    4, 33, 2,  7, 8, 19, 1, 69, 7, 62, 5, 41, 3, 93, 0, 64, 6, 17, 
    0, 18, 8, 75, 2, 92, 5, 38, 4, 92, 6, 82, 3, 71, 7, 39, 1, 24, 
    3, 85, 2, 52, 8, 28, 4, 67, 7, 97, 6, 57, 0, 83, 1, 29, 5, 43, 
    3, 26, 2, 71, 5, 12, 6, 52, 7, 59, 8, 14, 0, 36, 4, 45, 1, 90, 
    3, 12, 4, 29, 5,  4, 8, 94, 2, 23, 6, 22, 1, 83, 0, 44, 7, 19, 
    0, 19, 3, 20, 4, 95, 2, 76, 5, 70, 7, 95, 1, 13, 8, 51, 6, 40, 
    4, 18, 2, 82, 1, 87, 5,  7, 8, 88, 0, 12, 6, 24, 3, 25, 7, 36
  };
  const int q6859[] = {
    9, 9, // Number of jobs and machines
    8, 77, 4, 34, 1, 62, 6, 76, 2,  1, 7, 42, 0,  7, 5, 60, 3, 94, 
    1, 19, 7, 22, 5, 58, 6, 34, 3, 30, 8, 57, 0, 78, 4, 94, 2, 53, 
    1, 51, 2, 42, 3, 84, 4,  9, 6, 23, 7, 71, 8, 15, 0, 11, 5, 15, 
    7, 35, 4, 69, 6, 62, 0, 18, 2, 17, 5, 30, 1, 29, 8, 40, 3, 12, 
    6, 52, 8, 63, 7, 66, 4, 95, 0, 15, 1, 55, 5,  6, 3, 66, 2, 40, 
    7, 93, 5, 40, 4, 19, 3, 71, 6, 21, 8, 88, 1, 61, 2, 99, 0, 77, 
    6, 36, 8, 24, 4,  4, 0, 36, 2, 77, 3,  6, 7, 20, 1, 13, 5, 75, 
    8, 83, 1, 71, 4, 48, 7, 18, 5, 53, 2, 91, 3, 90, 6, 95, 0, 20, 
    7, 80, 8, 54, 0, 62, 2, 56, 5, 30, 3, 30, 4, 77, 6,  7, 1, 96
  };
  const int q6860[] = {
    9, 9, // Number of jobs and machines
    0, 21, 5, 38, 6, 63, 3, 78, 2, 90, 7, 76, 1,  8, 8, 69, 4, 41, 
    8, 89, 2, 62, 7, 70, 3,  9, 4, 74, 0, 70, 5,  8, 6,  8, 1, 34, 
    2, 20, 7, 80, 5, 21, 0, 66, 1, 10, 4, 64, 6, 71, 3, 57, 8, 93, 
    4, 68, 1, 13, 6,  3, 3, 94, 2, 12, 0, 29, 8, 29, 5, 83, 7, 11, 
    3, 70, 5, 70, 6, 17, 7, 63, 1, 61, 0, 10, 2, 61, 8, 36, 4, 37, 
    4, 92, 7, 41, 5,  7, 2, 87, 6, 36, 8, 26, 3, 30, 1, 59, 0, 52, 
    5, 13, 2, 66, 0,  7, 1, 85, 4, 14, 3, 78, 6, 89, 8, 56, 7, 72, 
    3, 57, 7, 80, 6, 60, 4, 99, 0,  5, 5, 26, 8, 22, 2, 33, 1, 58, 
    4, 40, 7,  7, 0, 15, 8, 58, 6, 72, 2, 15, 1, 33, 3, 21, 5, 42
  };
  const int q6861[] = {
    9, 9, // Number of jobs and machines
    0, 77, 6, 83, 3, 83, 4, 29, 7, 49, 1, 36, 8, 94, 5, 71, 2, 13, 
    4, 42, 7, 84, 6, 38, 3, 32, 8, 23, 2, 57, 5, 73, 1, 50, 0, 26, 
    6, 48, 4, 30, 0, 82, 2, 15, 8, 99, 7, 25, 5, 12, 3, 83, 1, 89, 
    2, 23, 3,  9, 7, 60, 1, 45, 0, 41, 8, 47, 5, 14, 4,  8, 6, 74, 
    0, 45, 8, 27, 1, 66, 7, 88, 4, 70, 3, 30, 2, 74, 5, 43, 6, 73, 
    0, 26, 8, 20, 2, 28, 7, 51, 6,  6, 5, 29, 3, 40, 1, 37, 4, 42, 
    4, 68, 2, 64, 7, 26, 1,  6, 8, 51, 0, 79, 5, 72, 6, 84, 3, 18, 
    1, 55, 6,  5, 5, 71, 4, 23, 3, 31, 2, 69, 0, 43, 7,  3, 8, 21, 
    6,  8, 5, 80, 7, 60, 8, 40, 1, 20, 4, 42, 0, 16, 2, 63, 3, 56
  };
  const int q6862[] = {
    9, 9, // Number of jobs and machines
    7, 13, 4, 41, 0, 68, 3, 74, 8, 96, 5, 73, 1, 53, 6, 26, 2, 60, 
    4, 45, 6, 98, 3, 16, 0, 95, 7, 80, 5, 15, 1,  2, 2, 83, 8, 66, 
    6, 73, 1, 16, 4, 44, 2,  8, 0, 82, 7, 92, 5, 56, 3, 72, 8, 63, 
    1, 61, 5, 82, 8, 19, 3, 93, 0, 40, 2, 55, 6, 69, 4, 41, 7, 22, 
    4, 19, 5, 15, 6, 53, 0, 26, 2, 25, 8, 27, 7, 39, 1, 25, 3, 27, 
    0, 73, 6, 72, 1, 61, 2, 20, 7, 56, 4, 16, 3, 37, 8, 12, 5, 67, 
    0, 59, 8, 69, 2, 90, 1, 63, 3, 56, 4, 64, 5,  7, 6, 19, 7, 60, 
    1, 40, 6, 28, 3, 54, 2, 62, 4, 38, 7, 38, 8, 42, 0, 77, 5, 25, 
    1, 33, 0, 13, 7,  6, 2,  2, 3, 63, 6, 72, 4, 26, 8, 45, 5, 35
  };
  const int q6863[] = {
    9, 9, // Number of jobs and machines
    0, 45, 8, 97, 2, 35, 3, 39, 7,  1, 4, 11, 6, 62, 1, 76, 5, 87, 
    1, 66, 0, 37, 4, 31, 6, 12, 2, 57, 8, 82, 3, 87, 7, 30, 5, 14, 
    2, 61, 7, 20, 4, 47, 3, 50, 5, 56, 6,  3, 0, 12, 1, 90, 8, 23, 
    2, 10, 1, 59, 0, 58, 6,  5, 4, 76, 3, 29, 7, 98, 5, 12, 8, 33, 
    5, 30, 8, 91, 0, 47, 7, 32, 4, 43, 2, 71, 6, 16, 1, 64, 3, 51, 
    7, 76, 1,  2, 6, 54, 8, 34, 5,  7, 4,  3, 2, 91, 0, 59, 3, 51, 
    8, 82, 5, 34, 6, 42, 2, 72, 0, 70, 7, 71, 3, 58, 4, 46, 1, 37, 
    1, 12, 8, 50, 3, 19, 6, 43, 0, 28, 2, 41, 5, 28, 7, 76, 4, 19, 
    0, 20, 5, 73, 7, 87, 1, 64, 3,  6, 6, 51, 2, 45, 4, 79, 8, 90
  };
  const int q6864[] = {
    9, 9, // Number of jobs and machines
    1, 56, 7, 91, 4, 96, 3, 93, 5,  5, 6, 45, 0, 77, 8, 74, 2, 43, 
    5,  9, 0, 40, 2, 91, 8, 70, 6, 92, 7, 72, 1, 52, 4, 69, 3, 41, 
    6, 33, 5, 80, 7, 55, 4, 39, 8, 70, 3, 79, 2, 13, 0, 59, 1, 13, 
    2,  7, 8, 68, 5,  4, 3, 29, 0, 63, 7, 10, 4, 77, 1, 58, 6, 16, 
    0, 48, 2, 16, 5, 29, 7, 63, 3, 96, 8, 82, 6, 83, 4, 23, 1, 35, 
    7, 17, 2, 32, 0, 92, 6, 61, 3, 96, 8, 10, 4, 10, 1, 35, 5, 47, 
    5, 45, 0, 83, 7, 68, 2, 47, 6, 22, 3, 98, 1, 16, 8, 29, 4, 66, 
    1, 64, 6, 20, 2, 77, 8, 96, 0, 48, 7, 64, 4, 86, 5, 69, 3, 46, 
    8, 65, 7, 31, 4, 23, 1, 53, 5, 28, 2, 13, 0, 82, 3, 86, 6, 73
  };
  const int q6865[] = {
    9, 9, // Number of jobs and machines
    3, 26, 5, 63, 4, 29, 7, 57, 1, 50, 8, 87, 2, 56, 6, 51, 0, 19, 
    5, 62, 0,  8, 7, 15, 4, 12, 1, 45, 8, 84, 6, 23, 3, 65, 2,  4, 
    4, 49, 7, 41, 0,  7, 5, 32, 1, 62, 3, 54, 8, 39, 2, 18, 6, 94, 
    8, 55, 1, 60, 5, 10, 2, 54, 7, 59, 0, 90, 3, 79, 6, 43, 4, 35, 
    3, 92, 4, 25, 8, 69, 6, 17, 2, 15, 0, 11, 1, 86, 5, 94, 7, 52, 
    1, 24, 0, 66, 4, 92, 8, 60, 5,  2, 3, 62, 7, 84, 6, 86, 2, 46, 
    6, 20, 5, 36, 7, 23, 4, 23, 0, 49, 8, 50, 2, 34, 3, 71, 1, 13, 
    7, 31, 5, 85, 8,  6, 1, 80, 6, 58, 3, 10, 4, 43, 0, 28, 2, 85, 
    5, 11, 8, 36, 2, 19, 7,  2, 3, 50, 6, 96, 0, 10, 1, 39, 4, 45
  };
  const int q6866[] = {
    9, 9, // Number of jobs and machines
    6, 95, 2, 76, 7, 48, 1, 77, 4, 61, 5, 55, 8, 43, 3, 23, 0, 29, 
    2, 11, 5, 98, 4, 23, 7, 76, 8, 95, 0, 13, 1, 67, 3, 24, 6,  7, 
    2, 24, 4, 56, 1, 50, 6, 68, 8, 74, 3, 43, 5, 26, 0, 83, 7, 14, 
    0, 45, 4, 70, 3, 83, 1, 64, 7, 49, 6, 67, 2, 35, 5, 31, 8, 12, 
    3, 21, 0, 18, 4, 76, 2, 18, 5, 85, 1, 96, 6, 65, 7, 29, 8, 57, 
    0, 83, 8, 43, 5, 82, 1,  7, 4, 73, 7, 88, 2, 60, 6, 79, 3, 89, 
    7, 62, 0, 42, 4, 33, 6, 36, 8, 81, 2, 18, 1, 54, 5, 48, 3, 32, 
    7, 60, 4, 86, 1, 10, 3, 99, 5, 52, 2, 10, 8, 66, 0, 97, 6, 25, 
    7, 57, 0, 52, 2, 86, 4, 67, 5, 53, 8, 76, 6, 57, 3, 82, 1, 22
  };
  const int q6867[] = {
    9, 9, // Number of jobs and machines
    2,  5, 3, 40, 5, 31, 4, 32, 1, 87, 0, 73, 7, 17, 8, 62, 6, 58, 
    8, 50, 5, 56, 7, 19, 3, 38, 6, 83, 4, 17, 1, 59, 2, 28, 0, 60, 
    6, 31, 1, 74, 7, 89, 4, 31, 2, 49, 0, 45, 8,  9, 5, 68, 3, 16, 
    1,  1, 4, 67, 7, 25, 6, 78, 8, 71, 2, 29, 3, 96, 5, 16, 0, 20, 
    4,  8, 6, 21, 7, 12, 1, 80, 3, 93, 8, 33, 5, 67, 2, 83, 0,  5, 
    6, 18, 0, 57, 7, 37, 8,  9, 2, 82, 5, 60, 3, 13, 1, 71, 4, 58, 
    8, 50, 1, 23, 3, 20, 4, 34, 6, 65, 7, 28, 5, 33, 2, 82, 0, 76, 
    8, 90, 7, 32, 6, 16, 2, 95, 4,  6, 3, 57, 5, 80, 1, 69, 0, 49, 
    7, 17, 6,  1, 1, 66, 8, 90, 4, 83, 3, 27, 0, 98, 5, 73, 2,  9
  };
  const int q6868[] = {
    9, 9, // Number of jobs and machines
    8, 93, 7, 69, 4, 58, 0, 41, 6, 41, 1, 82, 3, 35, 2, 58, 5, 19, 
    8, 40, 1, 10, 6, 45, 3,  9, 7, 86, 0,  4, 5, 68, 4, 95, 2, 58, 
    3, 71, 8, 26, 7, 39, 1, 69, 6, 36, 5, 84, 2, 65, 0, 35, 4, 19, 
    4, 51, 2, 70, 0,  9, 3, 64, 7, 17, 6, 23, 1, 41, 8, 88, 5, 49, 
    0, 65, 5, 62, 3, 80, 1,  8, 4, 71, 6,  8, 8, 56, 7, 54, 2, 19, 
    7, 25, 6, 84, 8, 62, 2, 90, 4, 71, 0, 56, 3, 59, 5, 81, 1, 40, 
    3, 19, 5, 77, 0, 14, 7, 27, 8, 63, 2, 18, 1, 36, 6, 39, 4,  2, 
    4, 97, 3, 47, 7, 31, 5,  7, 6, 48, 8, 71, 0, 70, 2, 27, 1, 69, 
    7, 34, 2,  4, 6, 41, 1, 58, 4, 31, 8, 22, 5, 96, 0, 91, 3, 74
  };
  const int q6869[] = {
    9, 9, // Number of jobs and machines
    3, 17, 2, 98, 1, 33, 4, 53, 5, 44, 7, 33, 8, 11, 6,  1, 0,  4, 
    3, 42, 6, 71, 0, 30, 7, 61, 8, 54, 2, 47, 1,  9, 4, 79, 5, 32, 
    3, 94, 2, 70, 1, 22, 6, 22, 4, 52, 0, 30, 7, 76, 5, 18, 8, 71, 
    2, 62, 8, 96, 1, 12, 5, 24, 4, 11, 7, 24, 0, 48, 3, 98, 6, 46, 
    1, 87, 3, 97, 2, 48, 5, 40, 6,  9, 8,  6, 7, 72, 0,  6, 4, 19, 
    0, 95, 7, 45, 1, 40, 6, 73, 3, 87, 8, 47, 5, 51, 4,  6, 2, 16, 
    1, 93, 2, 97, 8, 19, 4, 75, 6, 73, 3, 93, 5,  2, 7, 41, 0, 51, 
    2, 10, 8, 44, 6, 49, 0, 43, 3, 65, 5, 71, 4, 70, 7, 82, 1, 57, 
    3, 56, 7, 53, 4, 80, 8, 51, 1, 14, 0, 67, 2, 68, 5,  2, 6, 77
  };
  const int q6870[] = {
    9, 9, // Number of jobs and machines
    0, 70, 1, 63, 2, 11, 7,  1, 5, 11, 8, 71, 6, 84, 4, 55, 3, 48, 
    2, 19, 1, 29, 3, 59, 5, 44, 6, 30, 0,  4, 8, 66, 4, 95, 7, 17, 
    5, 16, 0, 10, 4, 33, 2, 32, 1, 55, 8, 89, 6,  4, 7, 24, 3, 86, 
    1, 38, 6,  6, 3, 28, 8, 49, 5, 37, 4, 37, 2, 61, 7, 98, 0, 95, 
    6,  3, 5, 26, 3, 47, 2, 15, 1, 43, 7, 55, 4, 44, 0, 64, 8, 95, 
    3, 58, 5, 87, 4, 11, 1, 87, 6, 45, 8,  5, 7, 89, 2, 81, 0,  2, 
    4, 81, 7, 78, 0, 82, 5, 14, 1, 31, 6, 62, 8, 84, 2, 60, 3,  5, 
    5, 75, 4, 16, 1, 87, 2, 42, 3, 90, 8, 88, 0, 83, 6,  7, 7, 32, 
    6, 24, 1,  5, 8, 65, 0, 91, 7, 68, 2, 38, 5, 90, 3, 23, 4, 29
  };
  const int q6871[] = {
    9, 9, // Number of jobs and machines
    6, 16, 8, 58, 3,  8, 1, 21, 5, 99, 4, 87, 7, 57, 2, 24, 0, 45, 
    2,  2, 5, 93, 8, 99, 4, 72, 1, 15, 0, 24, 7, 50, 6, 36, 3, 58, 
    6, 64, 5, 65, 3, 72, 1, 57, 4, 60, 8, 82, 7, 56, 0, 29, 2, 14, 
    1, 55, 7, 32, 0, 89, 4, 80, 6, 19, 5, 57, 2, 33, 3, 72, 8, 36, 
    0, 50, 6, 22, 5, 23, 4, 47, 7, 69, 2, 61, 1, 49, 8,  3, 3, 67, 
    1, 60, 6, 91, 2, 48, 4, 46, 8, 70, 5, 69, 7, 42, 0, 65, 3, 36, 
    0, 86, 1, 59, 7, 60, 4,  6, 5, 92, 3, 94, 8, 76, 6, 87, 2, 46, 
    0, 99, 8, 43, 1, 39, 5, 58, 6, 61, 3,  9, 7, 82, 4,  3, 2, 72, 
    0, 10, 4, 74, 1, 78, 5, 73, 2, 48, 6, 26, 3, 12, 7, 51, 8, 35
  };
  const int q6872[] = {
    9, 9, // Number of jobs and machines
    8, 18, 2, 14, 7, 35, 5, 28, 4, 72, 0, 72, 3, 20, 6, 34, 1, 39, 
    5, 48, 6, 45, 4, 98, 0, 87, 1, 58, 3, 27, 2, 19, 8, 30, 7,  3, 
    8, 81, 6, 66, 3, 14, 7, 80, 1, 86, 4, 59, 5,  8, 0,  7, 2,  7, 
    6, 63, 3, 92, 0, 89, 5, 93, 2, 97, 4, 98, 1, 61, 7, 24, 8, 61, 
    8, 86, 0, 38, 7, 84, 6, 86, 4, 99, 2, 86, 1,  4, 3, 16, 5, 90, 
    7, 67, 1, 29, 8, 73, 2, 22, 0, 31, 3, 74, 5, 74, 4, 12, 6, 95, 
    3, 73, 8, 76, 2, 13, 1, 90, 5, 80, 7,  1, 4, 74, 0, 94, 6, 35, 
    3, 55, 5, 25, 8, 10, 6, 11, 2, 28, 4, 67, 0, 86, 7, 64, 1,  7, 
    4, 13, 3, 60, 0, 94, 5, 58, 7, 59, 1, 91, 6, 84, 2, 43, 8, 31
  };
  const int q6873[] = {
    9, 9, // Number of jobs and machines
    1, 51, 6,  8, 3, 70, 5,  4, 7, 36, 0, 92, 2, 37, 8, 45, 4, 62, 
    7,  7, 2, 77, 0, 18, 4, 51, 5,  4, 8, 83, 1, 20, 3, 38, 6, 72, 
    7,  8, 0, 69, 2, 35, 1, 80, 5, 28, 6, 54, 8,  2, 3,  7, 4, 33, 
    8, 41, 2, 62, 6, 15, 5, 71, 4, 78, 7, 60, 0, 36, 1, 91, 3, 29, 
    2, 37, 8, 67, 1, 26, 0, 22, 6,  4, 5, 95, 3, 94, 7, 78, 4, 46, 
    6, 59, 0, 98, 8, 75, 5, 35, 2, 69, 4, 55, 3, 39, 7, 49, 1,  4, 
    2, 69, 5,  2, 1, 59, 8, 23, 3, 58, 4, 34, 7, 60, 6, 56, 0, 87, 
    5, 47, 3,  8, 0, 26, 6, 32, 2, 11, 7, 98, 8, 13, 4, 87, 1, 70, 
    0, 20, 2, 94, 3, 60, 1, 54, 8, 76, 7, 74, 5, 31, 6, 93, 4, 68
  };
  const int q6874[] = {
    9, 9, // Number of jobs and machines
    5, 36, 1, 85, 8, 31, 2,  7, 4,  5, 6, 37, 0, 88, 7, 23, 3, 65, 
    0, 59, 7, 32, 5, 34, 2, 30, 6, 95, 4, 79, 8, 79, 1, 26, 3, 56, 
    5, 42, 7,  8, 0, 29, 4, 46, 6, 99, 3, 11, 2, 57, 8, 52, 1, 25, 
    3, 30, 5, 71, 1, 48, 4,  7, 8,  7, 7, 35, 2, 50, 6, 78, 0, 59, 
    2, 13, 6,  7, 1, 38, 8, 61, 3, 86, 7, 63, 4, 44, 0, 51, 5, 97, 
    4, 72, 5, 80, 2, 66, 3, 42, 6,  7, 0, 75, 7, 77, 1, 27, 8,  6, 
    4, 42, 7, 26, 8, 15, 3, 22, 1, 14, 2,  9, 5, 46, 0, 24, 6, 14, 
    2, 47, 7, 31, 5, 18, 0,  8, 8, 13, 3, 36, 6, 47, 1, 25, 4, 31, 
    4, 25, 3, 42, 6, 79, 1, 98, 8, 19, 0, 10, 7, 85, 2, 12, 5, 13
  };
  const int q6875[] = {
    9, 9, // Number of jobs and machines
    6, 88, 2, 92, 0, 46, 8, 45, 4, 74, 5, 49, 7, 14, 3, 41, 1, 61, 
    8, 43, 0, 91, 2, 46, 4, 33, 1,  7, 7, 89, 3, 58, 6, 11, 5, 43, 
    3, 58, 0, 57, 7, 38, 6, 23, 2, 70, 8, 88, 1,  6, 5, 71, 4, 35, 
    4, 81, 3, 26, 7, 82, 0,  2, 6, 77, 1, 86, 8,  6, 5, 15, 2, 78, 
    6, 11, 7, 64, 5, 25, 3, 68, 1, 52, 8, 56, 2, 43, 0, 77, 4, 96, 
    7, 58, 6, 34, 2, 53, 5, 64, 4, 84, 3, 51, 1, 97, 0, 51, 8, 99, 
    2, 63, 8, 80, 1,  8, 0,  6, 7, 28, 3, 28, 4,  9, 5, 95, 6, 42, 
    5, 13, 1, 76, 4, 82, 8, 97, 7, 77, 2, 26, 3, 65, 6, 82, 0, 13, 
    7, 18, 6, 22, 8, 26, 3, 50, 5, 50, 1, 93, 4, 49, 0, 47, 2, 70
  };
  const int q6876[] = {
    9, 9, // Number of jobs and machines
    5, 79, 0, 67, 1, 89, 4, 36, 3, 37, 6,  5, 2, 50, 7, 48, 8, 79, 
    0, 91, 8, 14, 1, 82, 5, 69, 3, 89, 6, 17, 7, 82, 2, 47, 4, 57, 
    3, 35, 0, 22, 8, 33, 1, 48, 5, 32, 7, 66, 2, 96, 6, 90, 4,  7, 
    1, 27, 6, 34, 2, 77, 3, 15, 7,  1, 8, 82, 0, 16, 5, 95, 4, 84, 
    7, 60, 1, 53, 2,  7, 3, 37, 6, 19, 5, 89, 0, 36, 8, 47, 4, 68, 
    5,  7, 8, 87, 3, 44, 1, 30, 7, 73, 2, 43, 6, 62, 0, 61, 4, 70, 
    1, 92, 0, 95, 7, 45, 4, 65, 8, 88, 6, 13, 5, 96, 2, 24, 3, 52, 
    6, 77, 0, 46, 1, 66, 2, 35, 4, 24, 5, 95, 7, 23, 3, 50, 8, 17, 
    3, 99, 5, 17, 4,  8, 8, 90, 7, 66, 2, 57, 0, 80, 6, 90, 1, 92
  };
  const int q6877[] = {
    9, 9, // Number of jobs and machines
    5, 33, 0,  1, 8, 85, 3, 59, 6, 38, 4, 93, 2, 18, 7, 41, 1,  5, 
    6, 94, 8, 41, 7, 17, 3, 57, 5, 37, 4, 38, 1, 83, 2, 15, 0, 39, 
    6, 29, 8, 20, 3, 56, 5, 31, 4, 77, 0,  2, 2, 84, 1, 73, 7, 81, 
    1, 88, 3, 42, 7, 13, 2,  7, 0, 97, 4, 99, 8, 29, 5, 64, 6, 25, 
    1, 41, 4, 53, 5, 16, 7, 97, 3, 86, 0, 91, 6,  7, 8, 68, 2, 25, 
    8, 56, 6, 33, 5, 89, 0, 20, 3, 88, 2, 86, 1, 31, 4, 61, 7, 94, 
    0, 16, 3, 48, 6, 19, 8,  2, 2, 55, 5, 67, 4, 99, 1, 69, 7, 72, 
    2, 56, 7, 28, 4, 10, 5, 69, 3, 18, 8, 19, 0, 38, 6, 11, 1, 49, 
    4, 64, 1, 99, 3, 31, 2, 25, 8, 22, 7,  3, 5, 32, 0, 27, 6, 36
  };
  const int q6878[] = {
    9, 9, // Number of jobs and machines
    7,  1, 5, 25, 3, 78, 4, 86, 1, 21, 2, 51, 6, 48, 8, 73, 0, 67, 
    3, 15, 8, 42, 4, 48, 6,  7, 7, 60, 1, 80, 0, 28, 2,  4, 5, 11, 
    2, 56, 7, 54, 5,  2, 8, 96, 1, 63, 0, 21, 6, 66, 4, 29, 3, 13, 
    5, 76, 2, 31, 8, 63, 1, 57, 3, 60, 4, 88, 0, 44, 6, 47, 7,  2, 
    0, 29, 6, 86, 1, 80, 3,  8, 4, 90, 8, 31, 7, 91, 2, 89, 5, 38, 
    3, 84, 8, 16, 5, 27, 1, 51, 6, 65, 0, 28, 2, 34, 7, 94, 4, 24, 
    7, 37, 0, 64, 6, 59, 1, 83, 3, 48, 4,  5, 8, 16, 5, 94, 2, 65, 
    0, 35, 5, 21, 1, 38, 2, 48, 8, 60, 6, 50, 4, 83, 3, 35, 7, 84, 
    7, 85, 8, 73, 1, 95, 0, 98, 4, 36, 5,  9, 2, 36, 3, 24, 6, 57
  };
  const int q6879[] = {
    9, 9, // Number of jobs and machines
    4, 77, 1,  4, 3, 82, 6, 62, 8, 25, 0, 22, 5, 60, 2, 36, 7, 81, 
    3, 12, 8, 12, 1, 49, 4,  6, 7, 50, 2, 64, 5, 23, 0, 92, 6, 89, 
    3, 18, 0, 51, 7, 31, 1, 86, 8, 69, 6, 66, 4, 20, 5, 69, 2, 92, 
    8, 30, 7, 24, 2, 46, 1, 22, 4, 89, 3, 50, 5, 93, 6, 97, 0, 63, 
    1,  6, 6, 17, 5, 39, 7, 34, 8, 20, 0, 13, 4, 99, 2, 48, 3, 93, 
    4, 78, 3, 62, 8, 96, 2, 80, 0, 89, 1, 77, 6, 40, 5, 97, 7, 22, 
    2,  7, 4, 13, 7, 92, 1,  8, 8, 71, 6, 68, 3, 40, 5, 88, 0, 98, 
    1, 34, 7, 77, 4, 49, 3, 47, 6, 14, 0, 44, 5, 21, 8, 43, 2, 46, 
    0, 25, 1, 10, 4, 81, 6, 23, 7, 71, 8, 37, 5, 54, 2, 49, 3, 89
  };
  const int q6880[] = {
    9, 9, // Number of jobs and machines
    1, 68, 0, 64, 3, 11, 5, 44, 7, 41, 6, 96, 8, 39, 2, 19, 4, 92, 
    0, 20, 2,  5, 7,  7, 4, 18, 1, 16, 5, 75, 8,  4, 3, 52, 6, 29, 
    8, 75, 3, 95, 6, 14, 4, 67, 5, 83, 1, 56, 7, 66, 0, 45, 2, 61, 
    5, 85, 1, 92, 3, 13, 2, 39, 6, 53, 7, 24, 4, 25, 8, 32, 0, 29, 
    5, 65, 7, 88, 0, 32, 3, 79, 2, 42, 6, 91, 1, 34, 8, 40, 4, 63, 
    7, 79, 2, 35, 3,  3, 1, 92, 0, 73, 6, 44, 8,  6, 5, 15, 4, 42, 
    5, 72, 8,  7, 3, 24, 6, 43, 0, 60, 1, 40, 7, 88, 4, 85, 2, 42, 
    0, 15, 2, 44, 3,  2, 1, 28, 4, 81, 6, 79, 5, 79, 7, 59, 8,  5, 
    7, 40, 6, 69, 0, 56, 5, 99, 2, 51, 1, 49, 3, 71, 8, 65, 4, 54
  };
  const int q6881[] = {
    9, 9, // Number of jobs and machines
    0, 68, 6,  9, 3, 25, 7, 43, 4, 42, 2, 75, 1, 19, 8, 20, 5,  2, 
    8, 94, 4, 50, 2, 11, 6, 38, 7, 98, 0, 63, 5, 84, 1, 37, 3, 15, 
    5, 20, 3, 49, 7, 92, 2, 54, 4, 21, 8, 82, 0, 10, 6, 75, 1, 80, 
    5, 98, 1, 45, 4,  3, 7, 65, 2,  7, 8, 27, 3, 62, 6, 20, 0, 37, 
    4, 13, 6, 21, 2, 56, 0, 41, 1, 83, 8, 97, 5,  8, 3, 55, 7, 37, 
    6, 95, 3, 36, 5, 11, 0,  4, 1, 39, 2, 40, 8, 52, 7, 16, 4, 14, 
    5, 18, 8, 42, 3, 67, 6, 64, 2, 76, 7, 51, 0, 19, 4, 98, 1, 34, 
    0, 49, 7, 45, 6, 24, 5, 86, 1, 59, 4, 11, 2, 75, 8, 17, 3, 56, 
    5, 86, 6, 43, 7, 50, 3, 89, 2, 82, 0, 64, 8, 78, 4, 41, 1, 21
  };
  const int q6882[] = {
    9, 9, // Number of jobs and machines
    4, 11, 3, 92, 1, 71, 6, 11, 2, 81, 0, 80, 8, 33, 7, 46, 5,  8, 
    7, 76, 0, 16, 8, 50, 1, 52, 2, 12, 3, 77, 5, 11, 4, 96, 6, 66, 
    2, 12, 1, 43, 6, 29, 5, 87, 7, 29, 3, 84, 8, 77, 0,  6, 4, 97, 
    8, 54, 7, 14, 5, 58, 4, 98, 0,  6, 3, 25, 6, 54, 1, 48, 2, 62, 
    5, 22, 7, 93, 2, 44, 0, 17, 1, 29, 3, 32, 8, 58, 4, 31, 6, 48, 
    1, 21, 2, 83, 3, 89, 8, 83, 6, 19, 0, 50, 4, 25, 7, 46, 5, 87, 
    2, 99, 3, 96, 0, 88, 6, 96, 1, 30, 5, 67, 4, 95, 7, 23, 8, 87, 
    2, 66, 6, 17, 5, 94, 1, 55, 8, 33, 4, 48, 7, 68, 0, 82, 3, 13, 
    6, 38, 2, 16, 3, 89, 0, 78, 7, 63, 5, 95, 8, 54, 4,  5, 1, 16
  };
  const int q6883[] = {
    9, 9, // Number of jobs and machines
    0, 66, 7,  1, 3, 13, 5, 80, 2, 89, 6, 70, 4, 29, 1, 21, 8, 13, 
    8, 10, 3, 47, 2, 63, 4, 64, 0, 96, 6, 70, 7, 91, 5, 24, 1, 48, 
    8, 59, 1,  5, 7, 85, 6, 93, 4, 19, 3, 84, 2, 68, 0, 91, 5, 61, 
    1, 73, 4, 49, 8, 97, 2, 62, 0, 96, 3,  6, 5, 56, 6, 10, 7, 53, 
    5, 21, 7, 79, 8, 28, 0, 17, 6,  4, 4, 37, 3, 43, 2, 26, 1, 32, 
    6, 14, 0, 31, 7, 29, 4, 22, 2, 82, 8, 87, 1, 43, 5, 46, 3, 22, 
    0, 78, 1,  2, 2, 10, 4, 68, 8, 32, 5,  8, 6, 72, 7, 65, 3,  9, 
    5, 41, 6, 23, 0, 59, 3,  7, 1, 21, 7, 69, 4, 68, 8, 90, 2, 32, 
    0, 12, 1, 33, 3, 72, 7, 64, 4, 74, 6, 12, 8, 17, 2, 35, 5, 28
  };
  const int q6884[] = {
    9, 9, // Number of jobs and machines
    7, 43, 4, 23, 5, 88, 8, 85, 3, 47, 1, 44, 0, 74, 6, 51, 2,  2, 
    3, 52, 7, 99, 2, 93, 0, 73, 4, 45, 8, 83, 5, 39, 1, 71, 6, 96, 
    3, 47, 1, 34, 0, 39, 6, 69, 2, 30, 8, 42, 7, 67, 4, 78, 5, 35, 
    8, 39, 5, 35, 0, 23, 6, 81, 1, 93, 4, 80, 2, 85, 3,  4, 7, 67, 
    6, 82, 3, 85, 1, 77, 8, 11, 5, 62, 4, 62, 0, 46, 7,  4, 2, 97, 
    6, 66, 7, 72, 5, 25, 8, 16, 2, 79, 0, 31, 3,  4, 1, 13, 4, 55, 
    2, 31, 8, 47, 1, 67, 6, 45, 0, 31, 7, 79, 3, 54, 4, 86, 5, 74, 
    8,  1, 0, 65, 3, 29, 2,  9, 5, 35, 7, 50, 1, 89, 6, 25, 4, 98, 
    0, 66, 1, 64, 7, 76, 6,  6, 2, 53, 8, 54, 5, 29, 3, 65, 4, 65
  };
  const int q6885[] = {
    9, 9, // Number of jobs and machines
    0, 81, 8, 62, 1, 81, 6, 29, 2, 26, 7, 65, 5, 18, 3, 57, 4,  5, 
    6, 76, 4, 57, 1, 36, 2, 98, 0, 29, 7, 51, 5,  6, 3, 88, 8, 65, 
    6, 19, 8, 17, 3, 27, 4, 75, 7, 71, 5, 80, 0, 65, 2,  4, 1, 81, 
    8, 20, 0, 55, 7,  5, 4, 25, 3,  4, 2, 48, 6, 98, 5, 78, 1, 59, 
    3, 68, 6, 81, 1, 77, 4, 13, 7, 14, 8, 44, 5, 58, 2, 29, 0, 81, 
    8, 55, 1, 29, 4, 64, 5,  5, 7, 21, 6, 73, 0, 57, 3, 72, 2, 88, 
    7,  3, 6, 11, 8, 85, 2, 35, 5, 77, 1, 42, 0, 33, 3, 96, 4, 63, 
    0, 41, 4, 94, 8, 82, 2, 94, 7, 15, 5,  5, 6, 17, 1, 38, 3, 79, 
    2, 45, 4, 64, 6, 73, 5, 72, 8, 49, 1, 98, 0, 75, 3, 50, 7, 45
  };
  const int q6886[] = {
    9, 9, // Number of jobs and machines
    4,  1, 7, 55, 1, 77, 6, 16, 5, 21, 2, 98, 3, 44, 0, 31, 8, 29, 
    4, 53, 5, 46, 3, 48, 8, 17, 6, 33, 7, 83, 2, 59, 0, 81, 1, 63, 
    2, 49, 7, 43, 1, 79, 3,  9, 8, 76, 6, 94, 0, 44, 5, 28, 4, 60, 
    1,  1, 4, 71, 5, 48, 0, 76, 2, 65, 3, 61, 8, 50, 7, 11, 6, 72, 
    1, 24, 0, 68, 5, 58, 3, 95, 8, 31, 7, 89, 6, 30, 2, 20, 4,  6, 
    3, 26, 8, 73, 6,  9, 2, 78, 5, 11, 1, 14, 7, 31, 0, 50, 4, 49, 
    4, 22, 8, 58, 1, 65, 2, 74, 6, 62, 3,  8, 0, 75, 7, 15, 5, 22, 
    5, 80, 8,  2, 6, 93, 4, 79, 7, 70, 3,  9, 2,  2, 0, 26, 1, 68, 
    0, 99, 2, 34, 3, 91, 6, 25, 4, 23, 8, 59, 5, 34, 1, 76, 7, 46
  };
  const int q6887[] = {
    9, 9, // Number of jobs and machines
    1,  8, 8, 33, 7, 57, 6, 93, 3, 25, 0, 12, 2, 24, 4, 83, 5, 57, 
    0, 30, 7, 40, 8, 87, 4, 26, 1, 13, 2, 27, 5, 33, 6, 61, 3, 30, 
    8, 92, 5, 23, 4, 69, 3, 48, 0, 69, 7, 89, 2, 27, 6, 84, 1, 14, 
    7, 21, 3, 82, 6, 45, 0, 72, 8,  9, 1, 16, 2, 99, 4, 71, 5, 72, 
    4, 62, 1, 39, 3,  1, 5, 55, 6,  3, 7, 21, 8, 15, 0, 67, 2, 64, 
    2, 76, 7, 67, 1, 85, 8, 37, 0, 21, 5, 78, 6, 14, 3, 38, 4, 91, 
    5, 92, 6, 12, 4, 73, 1, 38, 2, 83, 3, 89, 0, 51, 7, 43, 8, 46, 
    7, 14, 8, 49, 2, 63, 6,  1, 0, 23, 1, 37, 5, 25, 3, 37, 4, 44, 
    2, 90, 4, 68, 0, 74, 3, 67, 7, 99, 1, 36, 8, 41, 5,  6, 6, 84
  };
  const int q6888[] = {
    9, 9, // Number of jobs and machines
    7, 59, 6, 53, 0,  8, 5, 69, 1, 29, 4, 87, 2, 18, 3, 70, 8, 76, 
    5, 69, 7,  1, 0, 39, 4,  8, 6, 71, 2, 25, 1, 10, 8, 51, 3, 58, 
    3, 27, 4, 92, 7, 54, 2, 84, 1, 23, 0, 79, 5, 66, 8, 48, 6, 12, 
    4, 20, 1, 17, 2,  7, 5, 77, 3, 13, 6, 43, 8, 84, 7, 58, 0, 70, 
    5, 36, 8,  9, 1, 71, 0,  7, 4, 92, 7, 22, 3, 72, 6, 68, 2,  2, 
    8,  5, 3,  2, 4, 20, 2, 22, 5, 10, 6, 52, 7,  4, 0,  3, 1, 28, 
    8, 64, 7, 54, 2, 78, 5, 59, 1, 42, 6, 50, 4, 83, 0, 15, 3, 64, 
    7, 22, 0, 37, 4, 37, 5, 78, 6, 36, 3, 63, 1, 63, 8, 40, 2, 43, 
    4, 39, 3, 50, 6, 81, 0, 16, 2,  7, 8, 37, 5, 83, 7, 60, 1, 27
  };
  const int q6889[] = {
    9, 9, // Number of jobs and machines
    7, 31, 4, 13, 6, 44, 2,  5, 8, 91, 5, 58, 0, 34, 3, 54, 1, 34, 
    2, 88, 8, 12, 0, 65, 7, 47, 1, 78, 6, 23, 3, 92, 5,  9, 4, 20, 
    0, 62, 6, 81, 8, 22, 4, 62, 2, 71, 3, 13, 1, 19, 5, 28, 7, 69, 
    0, 24, 8, 38, 7, 56, 5, 56, 6, 91, 2, 55, 1, 99, 4, 90, 3, 89, 
    3, 11, 5, 19, 6, 15, 2, 72, 4, 92, 8, 41, 1,  3, 0, 98, 7, 72, 
    4, 18, 2, 46, 6, 72, 1, 26, 5,  3, 7, 83, 8, 89, 0, 46, 3, 65, 
    3, 44, 0, 63, 8, 31, 2, 78, 1, 97, 4, 76, 5, 79, 6,  5, 7, 55, 
    7, 82, 5, 63, 6, 65, 0, 98, 8, 25, 4, 11, 3, 87, 1,  4, 2,  6, 
    4, 33, 1, 70, 2, 97, 7, 60, 6, 86, 0, 16, 5, 81, 3, 44, 8, 73
  };
  const int q6890[] = {
    9, 9, // Number of jobs and machines
    5, 86, 2, 73, 8, 56, 3, 18, 1, 87, 6, 76, 7, 21, 0, 10, 4, 33, 
    5, 40, 3, 52, 0, 15, 1, 93, 7, 28, 4, 96, 6, 32, 8, 40, 2,  4, 
    7, 16, 6, 82, 4, 41, 3, 96, 0,  2, 1, 43, 8, 59, 5, 86, 2, 23, 
    7, 38, 3, 70, 0, 59, 4, 95, 6, 95, 5, 19, 1, 42, 8, 52, 2, 89, 
    2, 61, 5, 23, 3, 46, 0, 29, 6, 90, 8, 84, 7, 59, 4, 96, 1, 77, 
    5, 90, 6, 79, 1, 57, 0, 87, 4, 72, 2, 75, 3, 18, 7, 48, 8, 43, 
    1, 35, 4, 95, 5, 43, 0, 37, 3, 72, 8, 56, 7, 99, 6, 90, 2, 10, 
    1, 66, 6, 60, 2, 45, 5,  7, 4, 87, 0, 11, 7, 61, 3, 10, 8, 15, 
    8, 93, 6, 29, 4, 27, 3, 58, 1, 45, 5, 70, 7, 89, 2, 62, 0, 17
  };
  const int q6891[] = {
    9, 9, // Number of jobs and machines
    6, 19, 0, 93, 8, 66, 4, 78, 7, 94, 5, 91, 3, 17, 2,  2, 1, 16, 
    4, 96, 1, 33, 5,  1, 8, 43, 2, 34, 0, 30, 6, 41, 7, 92, 3, 59, 
    4, 80, 7, 89, 2, 37, 6, 85, 5, 36, 0, 22, 1, 38, 3, 65, 8,  1, 
    8, 88, 7, 28, 2,  6, 1, 92, 5, 35, 6,  6, 4,  5, 3, 95, 0, 66, 
    2, 89, 5, 20, 3, 33, 6,  6, 7, 95, 1, 75, 0, 99, 8, 84, 4, 72, 
    5, 26, 8, 52, 4, 32, 7, 64, 1, 72, 2, 95, 0, 19, 6, 68, 3, 35, 
    0, 21, 3, 85, 7, 46, 6, 14, 4, 24, 5, 29, 8, 68, 2, 77, 1,  2, 
    4, 52, 6, 41, 2, 10, 3, 59, 1, 40, 7,  6, 0, 44, 5, 55, 8, 73, 
    7, 95, 4, 76, 8, 16, 5, 30, 1, 85, 2, 80, 3, 87, 0, 45, 6, 21
  };
  const int q6892[] = {
    9, 9, // Number of jobs and machines
    4, 30, 8, 78, 6, 39, 7, 61, 3, 12, 5, 48, 2, 99, 1, 15, 0, 23, 
    4, 67, 8, 84, 7, 33, 5, 55, 3, 81, 2, 91, 6, 45, 1, 67, 0, 40, 
    4, 71, 6, 17, 5, 47, 8, 24, 0, 99, 7, 35, 2, 95, 1, 58, 3, 91, 
    8, 95, 1, 55, 2, 93, 0, 30, 5, 46, 4, 22, 3, 83, 6, 14, 7, 85, 
    5, 16, 0, 48, 4, 63, 3, 39, 8, 26, 2, 23, 1, 75, 7,  1, 6, 70, 
    0, 54, 1, 70, 6,  9, 8, 37, 5,  6, 3, 23, 4, 10, 2, 17, 7, 42, 
    2, 27, 7, 95, 4, 51, 5,  2, 1, 59, 8, 65, 6, 92, 0, 51, 3, 15, 
    1, 24, 4, 34, 2, 99, 0, 49, 7,  3, 6, 92, 3,  4, 8, 63, 5, 16, 
    6, 12, 1, 97, 0, 83, 2, 44, 7, 19, 4, 52, 8, 26, 5,  5, 3, 57
  };
  const int q6893[] = {
    9, 9, // Number of jobs and machines
    1, 95, 8, 62, 5, 31, 7, 42, 2, 52, 6, 28, 3, 65, 0, 39, 4, 30, 
    0, 96, 3, 37, 8, 31, 2, 94, 7, 37, 5,  1, 4, 87, 6, 44, 1, 60, 
    0, 90, 1, 82, 4, 46, 2, 45, 5, 70, 6, 90, 7, 77, 8, 18, 3, 23, 
    2, 24, 5, 48, 0, 95, 1, 68, 4, 78, 6, 53, 7, 31, 8, 93, 3, 83, 
    1,  7, 2, 15, 3, 73, 0, 38, 5, 76, 6, 67, 7, 75, 8, 77, 4, 62, 
    6, 66, 3, 81, 2, 64, 8, 39, 7, 36, 1, 20, 4, 35, 0, 33, 5, 84, 
    3, 65, 5,  7, 6, 71, 2, 86, 0, 71, 8, 48, 7, 76, 1, 65, 4, 55, 
    0, 90, 4, 62, 5, 96, 8, 52, 7, 19, 2, 46, 1, 60, 6,  5, 3, 47, 
    6, 93, 8, 34, 2, 43, 0,  3, 1, 29, 5, 41, 7,  1, 3, 76, 4, 77
  };
  const int q6894[] = {
    9, 9, // Number of jobs and machines
    2, 59, 1, 32, 5, 51, 7,  5, 4, 33, 8, 65, 3, 23, 0, 81, 6, 73, 
    6, 43, 4, 62, 2, 45, 8, 34, 0, 75, 1, 80, 5, 41, 3, 55, 7, 81, 
    5, 91, 1, 65, 2,  3, 8, 73, 6, 89, 4, 34, 0,  8, 3,  5, 7, 40, 
    7, 10, 6, 97, 2, 70, 0, 81, 4, 96, 1, 53, 8, 98, 5, 34, 3, 14, 
    8, 48, 4, 18, 0, 36, 6, 13, 2,  9, 1, 89, 7, 56, 5,  7, 3, 33, 
    8, 25, 0, 12, 2,  7, 5, 94, 6, 74, 4, 36, 1, 31, 3, 53, 7, 58, 
    4, 86, 0, 85, 5, 21, 1, 85, 8, 73, 7, 31, 6, 43, 2, 71, 3, 60, 
    3, 67, 7, 33, 8, 90, 5, 40, 4, 57, 0, 15, 6, 68, 1, 12, 2, 88, 
    6, 74, 3, 50, 1, 57, 8, 70, 4, 81, 0, 44, 2, 12, 5, 58, 7, 51
  };
  const int q6895[] = {
    9, 9, // Number of jobs and machines
    5, 92, 1, 71, 0, 40, 2, 36, 8, 34, 6, 70, 7, 54, 4, 76, 3, 84, 
    0, 73, 3, 13, 7,  9, 4, 70, 2, 78, 5, 89, 8, 99, 1,  7, 6, 79, 
    2, 15, 8, 25, 5, 24, 1, 99, 0, 35, 4,  2, 3, 11, 6, 99, 7, 18, 
    3, 22, 8, 73, 2, 97, 0, 41, 1,  4, 6, 23, 5, 56, 4, 25, 7, 62, 
    5, 43, 4, 24, 6,  9, 0, 16, 1, 33, 7, 82, 3, 85, 2, 87, 8, 40, 
    0, 88, 5, 61, 4, 94, 2, 66, 7, 71, 3, 56, 6,  5, 1, 15, 8, 32, 
    1, 66, 2, 60, 3, 56, 8, 73, 7, 47, 4, 19, 5, 32, 0, 70, 6, 92, 
    4, 65, 2, 51, 5, 73, 0, 21, 6, 77, 7, 95, 1, 96, 8, 19, 3, 87, 
    2, 11, 4, 84, 1, 11, 6, 28, 0, 47, 8, 31, 3, 26, 5,  5, 7, 42
  };
  const int q6896[] = {
    9, 9, // Number of jobs and machines
    3, 58, 8, 97, 2, 28, 7, 40, 0, 93, 1, 84, 4, 25, 6, 29, 5, 58, 
    1,  5, 6, 51, 4, 72, 0, 85, 7, 26, 2, 59, 8, 78, 5, 69, 3, 64, 
    4,  8, 7,  4, 1, 19, 0, 12, 8, 57, 6, 68, 2, 95, 5, 97, 3, 25, 
    1, 62, 8,  9, 6, 79, 2, 66, 4, 67, 7, 98, 3, 86, 0, 36, 5, 26, 
    1,  3, 3,  7, 5, 53, 2,  8, 8, 12, 4,  5, 6, 66, 7, 96, 0,  9, 
    8, 29, 5, 24, 2, 40, 1, 17, 7, 65, 6, 65, 0, 16, 4, 42, 3, 50, 
    5,  6, 1, 85, 4, 11, 0, 42, 6, 67, 7, 27, 3, 51, 2, 39, 8, 24, 
    5,  3, 2, 18, 8, 24, 6, 38, 3,  8, 1, 36, 0, 69, 7, 83, 4, 73, 
    5, 13, 3, 67, 2, 78, 8, 52, 7, 59, 0, 63, 4, 45, 1, 37, 6, 23
  };
  const int q6897[] = {
    9, 9, // Number of jobs and machines
    2,  2, 6, 40, 8, 98, 0, 86, 4, 85, 3, 98, 1, 39, 5, 56, 7, 14, 
    7, 39, 6, 26, 5, 19, 8, 96, 3, 65, 1, 37, 2, 46, 0, 98, 4, 56, 
    3, 50, 5, 14, 4, 70, 8, 18, 2, 80, 1, 62, 7, 55, 6, 18, 0, 91, 
    1, 30, 6, 78, 0, 65, 8, 91, 5, 67, 7, 37, 2, 33, 3, 18, 4, 42, 
    8, 76, 3, 32, 7, 54, 5, 41, 1, 52, 2,  6, 4, 22, 0, 64, 6, 73, 
    3, 63, 5,  1, 2, 42, 1, 70, 8, 83, 7, 45, 6,  7, 4, 79, 0, 63, 
    7, 41, 8, 26, 0, 54, 6, 55, 5, 15, 2, 73, 3, 81, 4, 99, 1, 17, 
    0, 21, 5, 87, 2, 64, 3, 36, 7, 45, 6,  2, 1, 47, 8, 65, 4, 34, 
    7, 10, 4, 46, 0, 57, 8, 95, 3, 56, 2, 22, 6, 69, 1, 63, 5, 61
  };
  const int q6898[] = {
    9, 9, // Number of jobs and machines
    6, 91, 0,  6, 4, 16, 3, 63, 5, 94, 1, 55, 8, 75, 7, 49, 2, 45, 
    1, 40, 0, 25, 2, 24, 4, 21, 3, 47, 7, 25, 8, 66, 5, 55, 6, 20, 
    7,  3, 0, 76, 2, 70, 1, 39, 8, 15, 6,  7, 5, 99, 3, 51, 4, 37, 
    0, 89, 3, 53, 6, 41, 7, 86, 2,  2, 5, 47, 8, 45, 1, 98, 4, 30, 
    6, 36, 2, 83, 8, 28, 1,  2, 7, 16, 4, 14, 0,  4, 3, 54, 5, 52, 
    4,  4, 7, 22, 5, 64, 0, 10, 2, 64, 6, 21, 8, 34, 1,  1, 3, 22, 
    5, 68, 8, 59, 1, 66, 4,  6, 0, 26, 2, 95, 3,  6, 7, 43, 6, 53, 
    1, 85, 2, 65, 0, 21, 8, 94, 7, 94, 5, 23, 4, 31, 3, 17, 6, 70, 
    3, 53, 7, 28, 4, 92, 6, 13, 5,  6, 8,  8, 1,  5, 2, 79, 0, 32
  };
  const int q6899[] = {
    9, 9, // Number of jobs and machines
    8,  3, 2, 64, 7, 21, 6, 22, 1, 38, 5, 95, 4, 32, 0, 98, 3, 53, 
    1, 72, 7,  8, 2, 13, 4,  7, 3, 99, 8, 36, 6, 12, 5, 42, 0, 97, 
    2, 48, 1, 86, 0, 81, 4, 62, 6, 97, 8, 63, 3, 95, 5, 80, 7, 68, 
    7, 94, 2, 40, 4, 27, 3, 31, 8, 80, 0,  7, 5, 56, 1, 63, 6, 99, 
    0, 68, 1, 10, 5, 63, 2, 60, 6, 19, 7, 86, 3, 70, 8, 61, 4, 96, 
    7,  5, 1, 32, 5, 26, 0, 88, 3, 85, 4,  9, 6, 21, 8, 84, 2, 47, 
    7, 94, 2, 47, 3, 78, 6, 23, 4, 75, 0, 10, 5, 44, 8, 43, 1,  7, 
    4, 38, 2, 39, 7, 51, 8, 33, 6,  7, 0, 79, 3, 90, 5, 51, 1, 35, 
    5, 92, 7, 28, 2, 45, 3, 67, 1, 21, 4, 96, 8, 14, 6,  6, 0, 44
  };
  const int q6900[] = {
    9, 9, // Number of jobs and machines
    6, 71, 0, 39, 7, 55, 5, 30, 4, 75, 1, 89, 3, 38, 8, 82, 2, 55, 
    4, 57, 0, 43, 3,  1, 2, 45, 6, 84, 7, 70, 5, 41, 8, 75, 1, 38, 
    8, 37, 6, 81, 4, 78, 5, 88, 1,  3, 2, 56, 3, 88, 0,  9, 7, 36, 
    2, 75, 1, 55, 6, 23, 5, 72, 7, 90, 8, 82, 0, 31, 3,  2, 4, 93, 
    8, 10, 6, 68, 0, 59, 1, 98, 4, 69, 3, 12, 7, 84, 2, 82, 5, 94, 
    6, 47, 7, 68, 4, 50, 2, 29, 3, 46, 5, 97, 8, 63, 0, 91, 1, 73, 
    6, 78, 1, 85, 0, 62, 2, 61, 8, 81, 5, 81, 7, 50, 3, 36, 4,  5, 
    6, 71, 8, 66, 2, 83, 1,  5, 5, 31, 4, 11, 7, 20, 0, 89, 3, 55, 
    8, 24, 7, 56, 3, 35, 5, 34, 4, 33, 1, 40, 2, 80, 6, 96, 0, 19
  };
  const int q6901[] = {
    9, 9, // Number of jobs and machines
    5, 68, 0, 81, 8, 82, 7, 74, 3, 73, 4, 65, 1, 33, 6, 12, 2, 27, 
    3, 90, 1, 24, 5, 64, 2, 46, 0,  9, 6, 73, 8, 71, 7, 73, 4, 25, 
    0, 44, 4, 41, 1, 57, 7, 28, 6, 16, 5, 91, 3, 39, 8, 61, 2, 12, 
    2, 83, 3, 25, 6, 39, 0, 99, 5,  4, 4, 31, 1, 25, 8, 40, 7,  4, 
    0, 65, 3, 77, 2, 84, 4, 51, 8, 86, 6, 53, 7, 17, 5, 80, 1, 25, 
    5, 73, 8, 84, 2, 58, 0,  1, 1, 78, 6,  3, 7, 70, 4, 59, 3, 13, 
    2, 66, 8, 74, 3, 54, 5,  9, 7, 79, 6, 20, 0, 29, 4, 23, 1, 71, 
    8, 84, 5, 92, 7, 87, 3, 64, 4, 87, 1, 99, 6,  3, 2,  6, 0, 21, 
    6, 71, 3, 51, 1, 77, 4, 53, 7, 95, 2, 50, 0, 17, 8, 58, 5, 33
  };
  const int q6902[] = {
    9, 9, // Number of jobs and machines
    3, 55, 5,  4, 2, 80, 7, 33, 4, 54, 1, 74, 8, 25, 0, 36, 6, 57, 
    6, 98, 7, 55, 8, 93, 3, 48, 4, 69, 0, 22, 2, 68, 5, 27, 1, 61, 
    8, 18, 1, 82, 2, 82, 7, 56, 0, 48, 4, 56, 5, 34, 3, 16, 6, 97, 
    7, 51, 3,  6, 6, 23, 2, 20, 0, 99, 5, 13, 1, 51, 4, 83, 8, 24, 
    4, 29, 0,  8, 7, 64, 3, 12, 5, 19, 6, 16, 8, 31, 1, 66, 2, 78, 
    0, 75, 5, 71, 7, 46, 2, 19, 4, 33, 1, 72, 8,  3, 3, 56, 6, 72, 
    5, 63, 1, 22, 4, 99, 7, 87, 8, 26, 3, 78, 6, 70, 2, 59, 0, 14, 
    1, 65, 7, 44, 5, 68, 0, 36, 2, 24, 3, 74, 8, 24, 6, 44, 4, 76, 
    2, 13, 8, 38, 1, 14, 4, 93, 5, 55, 0, 99, 7, 79, 3, 78, 6, 14
  };
  const int q6903[] = {
    9, 9, // Number of jobs and machines
    3, 30, 2, 97, 7, 59, 5, 94, 1, 48, 8, 74, 6, 21, 0, 13, 4, 64, 
    8, 99, 0, 23, 7, 96, 1, 42, 2,  7, 5, 34, 4, 45, 6, 53, 3, 77, 
    8, 97, 0, 62, 4,  9, 7, 94, 1, 27, 6, 76, 2, 87, 5, 67, 3, 63, 
    1, 71, 6, 89, 7, 82, 3, 42, 8, 97, 2, 84, 4, 45, 0,  2, 5, 76, 
    8,  1, 3, 53, 5, 30, 2, 80, 1, 37, 6, 86, 4, 95, 7, 27, 0, 57, 
    3, 86, 7, 41, 6, 43, 8, 79, 0, 77, 4, 59, 1, 21, 5, 51, 2, 99, 
    0, 28, 3, 46, 5, 28, 8, 17, 6,  2, 4, 41, 7, 46, 2, 78, 1, 66, 
    0, 82, 1, 89, 7, 22, 4, 74, 3, 22, 6, 89, 5, 82, 8, 77, 2, 84, 
    3, 44, 2, 67, 6, 57, 8, 19, 5, 53, 4, 14, 0, 89, 1,  5, 7, 96
  };
  const int q6904[] = {
    9, 9, // Number of jobs and machines
    2, 84, 0, 42, 5, 81, 4, 37, 8, 47, 7, 64, 1, 88, 6,  9, 3, 64, 
    1, 45, 6,  8, 7, 33, 8, 19, 5, 70, 0, 49, 3, 17, 4, 60, 2, 23, 
    5, 38, 4, 20, 6, 11, 7, 57, 3, 98, 8, 23, 1, 40, 0, 64, 2, 93, 
    3, 98, 5, 52, 1, 78, 8, 53, 4, 67, 0, 17, 7, 19, 2, 85, 6, 64, 
    7, 74, 3, 73, 8,  6, 5, 22, 6, 44, 2, 29, 0, 27, 1, 35, 4, 34, 
    2, 76, 4, 84, 7, 96, 0, 67, 3, 26, 5, 60, 8, 60, 6, 73, 1,  8, 
    3, 27, 5, 25, 0, 71, 1, 31, 2, 85, 7, 20, 4, 26, 6, 32, 8, 82, 
    0, 25, 8, 73, 3, 10, 2,  9, 6,  7, 4, 78, 1, 39, 7, 15, 5, 61, 
    8, 87, 7, 23, 5, 65, 0, 18, 6, 29, 1, 90, 2, 54, 3, 51, 4,  4
  };
  const int q6905[] = {
    9, 9, // Number of jobs and machines
    5, 73, 1, 64, 0, 18, 7, 55, 3, 36, 2, 75, 6, 65, 8, 83, 4, 68, 
    3, 36, 4,  9, 1, 86, 0, 71, 2, 51, 5, 99, 7, 36, 6, 72, 8, 74, 
    2, 96, 6, 42, 7, 11, 4, 78, 3, 53, 8, 15, 1, 60, 0, 54, 5, 13, 
    1, 27, 2, 80, 8, 10, 3, 79, 4, 99, 7, 30, 6, 14, 5, 35, 0, 67, 
    2, 80, 5, 42, 3, 89, 4, 93, 7, 42, 8, 61, 0, 23, 1, 54, 6, 25, 
    6,  5, 8, 20, 0, 31, 1, 94, 5,  3, 2, 95, 3, 43, 7, 51, 4, 72, 
    2, 44, 8, 39, 3, 86, 7, 24, 6, 21, 5, 47, 0, 50, 4, 11, 1, 71, 
    1, 17, 0, 24, 3, 43, 6, 37, 2, 27, 4, 33, 8, 68, 5, 92, 7, 27, 
    1, 56, 2, 38, 8, 48, 3, 56, 5, 15, 6, 68, 4, 85, 0, 50, 7, 83
  };
  const int q6906[] = {
    9, 9, // Number of jobs and machines
    8, 37, 2, 37, 5, 69, 6,  3, 4, 83, 7, 77, 0, 46, 3, 32, 1, 39, 
    6, 53, 3, 77, 5, 65, 4, 79, 1, 10, 7, 65, 0, 34, 2, 65, 8, 41, 
    3, 45, 5, 12, 7, 35, 8, 28, 6, 47, 4, 91, 1,  5, 2, 10, 0, 30, 
    2, 58, 6, 23, 3, 58, 7, 15, 1, 21, 4, 13, 5,  4, 8, 64, 0, 80, 
    5, 85, 3, 89, 2, 74, 6, 57, 7, 56, 8,  3, 1, 30, 0, 76, 4, 11, 
    4, 21, 5,  3, 3, 10, 2, 81, 8, 76, 6, 67, 7, 13, 0,  1, 1, 37, 
    5, 50, 7, 80, 2, 14, 8, 40, 4, 93, 0,  8, 1, 49, 3, 19, 6, 62, 
    2, 52, 7, 19, 6, 18, 5, 60, 8, 85, 0, 42, 1, 17, 4, 81, 3, 46, 
    7, 43, 6, 95, 5, 29, 8, 97, 2, 38, 1,  9, 3, 71, 0, 40, 4, 53
  };
  const int q6907[] = {
    9, 9, // Number of jobs and machines
    7, 98, 8, 50, 0, 78, 6, 11, 1, 75, 4, 75, 5, 64, 3, 47, 2, 80, 
    0, 87, 2, 73, 4,  6, 8, 90, 6, 35, 7, 88, 5, 30, 1, 36, 3, 17, 
    5, 15, 6, 93, 3, 50, 0, 17, 1, 13, 2, 60, 8, 16, 7, 42, 4, 87, 
    3, 36, 2, 89, 4, 59, 7, 10, 8, 65, 1, 29, 6, 84, 0, 34, 5, 85, 
    1, 72, 5, 62, 4, 81, 3, 19, 2, 99, 7,  4, 8, 64, 6, 36, 0, 65, 
    0,  3, 3, 67, 6,  8, 8, 66, 7, 83, 2, 84, 1,  2, 5, 18, 4, 81, 
    3, 97, 7, 50, 2, 34, 4, 57, 1, 99, 0, 94, 8, 19, 6, 22, 5, 46, 
    5, 98, 6, 62, 4, 10, 0, 52, 7, 80, 2, 91, 3, 20, 8, 87, 1, 62, 
    3, 19, 0, 86, 8, 54, 7,  4, 6, 77, 1, 86, 2, 19, 5, 69, 4, 92
  };
  const int q6908[] = {
    9, 9, // Number of jobs and machines
    0, 64, 5, 31, 1, 29, 7, 64, 6, 93, 2, 44, 8, 31, 3, 91, 4, 78, 
    8, 48, 6, 62, 0, 27, 4, 86, 2, 54, 7, 24, 3, 99, 5, 56, 1,  8, 
    5, 30, 3,  9, 4, 73, 7, 41, 2, 61, 6, 29, 8, 56, 1, 74, 0, 33, 
    1, 94, 8, 58, 2, 99, 0, 31, 5, 84, 6, 94, 4, 71, 3,  6, 7, 85, 
    6, 75, 7, 45, 8, 22, 1, 47, 5, 77, 0, 62, 3, 20, 4, 72, 2, 33, 
    1, 99, 8, 79, 0, 30, 4, 46, 3, 34, 6, 20, 5, 64, 2, 77, 7,  9, 
    1, 51, 3, 21, 0, 97, 4, 57, 2, 67, 6, 48, 5, 41, 7, 25, 8,  7, 
    0, 37, 3, 60, 7, 14, 5, 44, 8, 29, 1, 32, 6,  8, 2, 18, 4, 79, 
    8, 70, 5, 83, 6, 73, 0, 35, 1, 61, 4, 61, 7, 84, 2, 14, 3, 56
  };
  const int q6909[] = {
    9, 9, // Number of jobs and machines
    8, 13, 7, 13, 1, 45, 5, 77, 2, 15, 4, 43, 0, 81, 6, 98, 3, 42, 
    4, 26, 6, 62, 8, 92, 1, 61, 5, 34, 2, 37, 7, 55, 0, 13, 3, 69, 
    2, 43, 4, 17, 5, 71, 1,  6, 0, 10, 6, 34, 3, 55, 7, 55, 8, 18, 
    8, 15, 3, 36, 1, 93, 7, 23, 6, 32, 2, 41, 5, 93, 4,  5, 0, 36, 
    8, 93, 4, 93, 5, 64, 1,  2, 6,  9, 2, 84, 0, 57, 7, 27, 3, 68, 
    7, 73, 5, 53, 0, 49, 6, 18, 3, 29, 2, 93, 1, 32, 8, 20, 4, 13, 
    3, 36, 5, 89, 7, 25, 1, 52, 0, 37, 4, 36, 8, 65, 6, 61, 2,  9, 
    1,  3, 4, 96, 2, 68, 6,  3, 5,  6, 0, 62, 8, 25, 7, 65, 3, 85, 
    6, 25, 8, 93, 7, 31, 1, 30, 4,  9, 3, 14, 5, 21, 2, 52, 0, 18
  };
  const int q6910[] = {
    9, 9, // Number of jobs and machines
    6, 49, 0, 96, 1, 60, 4, 86, 5, 56, 3, 78, 8, 25, 7, 35, 2, 61, 
    1, 33, 7, 38, 6, 32, 5, 31, 4, 69, 2, 21, 3, 32, 0, 36, 8, 32, 
    3, 30, 1, 46, 8, 44, 7, 25, 6, 21, 2, 93, 5, 63, 0, 63, 4, 48, 
    5, 96, 8, 82, 7, 95, 3, 83, 2, 64, 1, 95, 4, 93, 0, 29, 6, 70, 
    3, 32, 6, 69, 5, 51, 0, 94, 8, 35, 2, 27, 7, 26, 4, 41, 1, 30, 
    1, 74, 4, 79, 8, 15, 2, 52, 6, 56, 7, 55, 3, 44, 5, 66, 0, 71, 
    8, 28, 1, 42, 0, 45, 4, 93, 5, 51, 6, 34, 7, 86, 3, 90, 2,  9, 
    6, 86, 7, 68, 5, 92, 0,  1, 2, 48, 8, 67, 3, 79, 1, 28, 4, 42, 
    1,  6, 5, 51, 2, 98, 8, 86, 0, 72, 6, 18, 4, 65, 3, 30, 7, 27
  };
  const int q6911[] = {
    9, 9, // Number of jobs and machines
    7, 29, 5, 35, 6,  3, 0, 48, 1, 65, 2, 76, 3, 42, 8, 36, 4, 76, 
    2, 61, 4, 48, 3, 29, 1, 25, 0, 74, 8, 70, 7, 31, 6, 77, 5, 37, 
    0, 19, 7, 25, 6, 49, 8, 16, 2, 42, 3, 74, 1, 48, 5, 79, 4, 99, 
    6, 12, 8, 35, 2, 40, 3, 43, 7, 31, 1, 85, 4, 73, 0,  4, 5, 67, 
    2,  4, 8, 89, 4, 50, 3, 90, 7, 81, 6, 36, 0, 55, 5, 35, 1, 61, 
    1, 75, 4, 32, 3,  4, 0, 48, 6, 91, 2, 91, 8, 79, 5, 11, 7,  1, 
    1, 90, 8, 40, 3, 18, 5, 41, 2, 78, 4, 77, 6, 55, 0, 64, 7, 38, 
    0,  4, 5, 11, 3, 86, 4, 66, 2, 79, 6, 62, 7, 24, 1, 53, 8, 25, 
    1, 36, 5, 64, 2, 41, 4, 10, 8, 88, 3, 53, 6, 19, 0, 47, 7, 47
  };
  const int q6912[] = {
    9, 9, // Number of jobs and machines
    3, 11, 4, 52, 6, 60, 2, 13, 5, 55, 7, 43, 8, 40, 1, 44, 0, 85, 
    3, 49, 5, 85, 4, 25, 7, 63, 8, 77, 0, 49, 6, 95, 1, 28, 2, 77, 
    3, 61, 7, 85, 2,  3, 1, 89, 8, 43, 0, 90, 4, 41, 6, 46, 5, 72, 
    2,  5, 5, 67, 6, 70, 3, 90, 8, 21, 0, 84, 7, 73, 1, 34, 4, 93, 
    2, 59, 1, 60, 4, 86, 7, 77, 8, 86, 3, 44, 5, 94, 6,  6, 0, 74, 
    5, 48, 6, 62, 8, 62, 7, 24, 4, 20, 2, 33, 3, 57, 1, 99, 0, 58, 
    5, 56, 0, 70, 3, 79, 4, 84, 8, 75, 2, 46, 7,  5, 1, 41, 6, 46, 
    2, 66, 6, 28, 7, 54, 8,  6, 3, 93, 1, 99, 4, 79, 0, 92, 5, 98, 
    3,  7, 4,  8, 7, 35, 0, 79, 6, 85, 1, 21, 5, 91, 2,  1, 8, 74
  };
  const int q6913[] = {
    9, 9, // Number of jobs and machines
    1, 58, 0, 52, 7, 10, 2,  5, 4, 63, 3, 49, 5, 26, 6, 21, 8, 50, 
    1, 59, 3, 90, 6, 68, 7, 18, 5, 26, 2, 71, 8,  2, 0, 27, 4, 84, 
    6,  6, 3, 96, 7, 97, 8, 99, 4, 71, 1, 59, 5, 23, 0, 76, 2, 25, 
    3, 63, 2,  9, 5, 26, 7, 23, 0, 13, 8, 52, 1, 29, 4, 90, 6, 57, 
    6, 57, 2, 93, 4, 60, 5, 94, 3, 83, 0, 78, 7, 29, 1, 73, 8, 17, 
    8, 94, 4, 47, 1, 19, 5, 82, 2, 56, 0, 33, 7, 88, 6, 81, 3,  6, 
    5,  8, 6, 20, 3, 96, 2, 11, 1, 64, 8, 69, 4, 73, 7, 45, 0,  7, 
    0, 83, 1, 79, 6, 13, 8,  4, 2, 27, 4, 27, 3, 59, 7, 86, 5, 75, 
    7, 33, 0,  6, 4, 21, 1, 39, 5, 69, 8, 21, 6, 91, 3, 18, 2, 37
  };
  const int q6914[] = {
    9, 9, // Number of jobs and machines
    8, 38, 7, 19, 5, 91, 3, 73, 1, 70, 0, 78, 4, 17, 6, 68, 2, 52, 
    3, 90, 5, 90, 8, 75, 7, 34, 6,  6, 4, 87, 1, 92, 0, 23, 2,  5, 
    0, 92, 1, 36, 5, 84, 6, 29, 2, 36, 3, 74, 7, 69, 4, 27, 8, 51, 
    3, 55, 5, 80, 4, 80, 0, 39, 8, 32, 2, 40, 7, 92, 1, 48, 6, 18, 
    4, 53, 8, 27, 1, 85, 0, 66, 5, 35, 7, 81, 2, 19, 3, 79, 6, 52, 
    8, 32, 5, 61, 0, 39, 1, 72, 6, 85, 7, 64, 2, 32, 3, 28, 4, 10, 
    0, 67, 8, 75, 1, 91, 4, 37, 3, 82, 6, 78, 5, 18, 2,  5, 7, 56, 
    4, 15, 3, 32, 6, 57, 5, 69, 0, 14, 1, 41, 8, 13, 2, 52, 7,  3, 
    7, 73, 0, 24, 5, 86, 8, 76, 4, 93, 6, 16, 1, 94, 2, 13, 3, 22
  };
  const int q6915[] = {
    9, 9, // Number of jobs and machines
    6, 96, 3, 49, 7, 20, 5, 17, 8, 72, 2, 30, 4, 50, 0, 18, 1, 90, 
    3, 69, 2, 72, 6, 38, 1,  9, 4, 31, 0, 87, 7, 44, 5, 95, 8, 24, 
    7, 63, 5, 27, 8, 66, 1, 71, 0, 30, 4, 79, 2, 66, 6, 30, 3, 75, 
    6, 71, 2, 20, 0, 40, 5, 30, 4, 78, 7, 59, 8, 86, 3, 60, 1, 93, 
    7, 88, 5, 27, 8,  5, 4, 30, 1, 68, 2, 77, 0, 71, 6, 90, 3, 13, 
    8, 96, 2, 48, 6,  4, 4, 69, 0, 69, 7, 94, 1, 62, 3, 53, 5, 42, 
    0, 77, 1, 96, 4, 65, 3, 26, 2, 56, 6,  2, 7, 19, 5, 49, 8, 67, 
    5, 52, 1, 15, 8, 91, 2, 50, 3, 98, 6, 41, 7, 19, 4, 68, 0, 84, 
    5, 32, 2, 99, 1, 45, 3, 97, 8, 12, 0, 75, 6, 26, 4, 62, 7, 41
  };
  const int q6916[] = {
    9, 9, // Number of jobs and machines
    8, 43, 1, 56, 0, 93, 7, 88, 4, 91, 5, 51, 3, 89, 2, 88, 6, 40, 
    7, 39, 0, 61, 3, 63, 5, 39, 1,  7, 2, 92, 6, 43, 4, 94, 8, 12, 
    0, 24, 5, 26, 7, 70, 3, 22, 8, 48, 1, 17, 6, 92, 2, 74, 4, 43, 
    4, 97, 0, 82, 2, 12, 1, 29, 5, 71, 8, 15, 6, 19, 7,  4, 3, 45, 
    4, 44, 5, 88, 0, 60, 7,  2, 1, 89, 6, 46, 2, 19, 3, 32, 8, 54, 
    0,  4, 6, 32, 7, 93, 8, 89, 3, 79, 5, 38, 1, 22, 2, 63, 4, 64, 
    8, 27, 0,  6, 3, 74, 4, 36, 1,  6, 5, 30, 6, 48, 2, 88, 7, 88, 
    1, 69, 2, 80, 7, 34, 4, 31, 0, 33, 6, 43, 5, 86, 3, 95, 8, 29, 
    6, 96, 2, 20, 1, 23, 3, 11, 5, 20, 8, 69, 0, 52, 4, 82, 7, 18
  };
  const int q6917[] = {
    9, 9, // Number of jobs and machines
    3, 40, 8, 75, 7, 51, 4, 64, 6, 74, 2, 37, 1, 22, 5, 48, 0, 41, 
    0, 78, 3, 12, 6, 66, 8, 74, 2,  9, 5,  5, 4, 31, 1, 58, 7, 81, 
    3, 72, 4, 46, 0, 21, 7, 46, 2, 20, 6, 86, 5, 34, 1, 92, 8, 73, 
    5, 44, 6, 95, 0,  8, 8,  1, 4, 56, 3, 24, 2, 24, 7, 97, 1, 72, 
    6, 80, 4, 50, 2, 14, 0, 54, 7, 97, 3, 73, 8, 23, 5, 76, 1, 97, 
    1, 18, 2, 43, 6, 63, 5, 92, 7,  3, 8, 45, 3, 69, 0, 40, 4, 95, 
    2,  1, 0, 21, 4,  7, 1, 52, 8, 82, 6, 64, 3, 85, 7, 39, 5, 83, 
    2, 70, 4, 67, 1, 86, 0, 50, 6, 12, 3, 74, 5, 56, 8, 73, 7, 15, 
    8, 19, 6, 31, 4,  6, 2, 65, 5, 40, 1, 79, 3, 31, 7, 10, 0, 35
  };
  const int q6918[] = {
    9, 9, // Number of jobs and machines
    7, 63, 0, 74, 2, 23, 5, 50, 6, 24, 4, 73, 3, 95, 1, 75, 8, 78, 
    2, 82, 6,  7, 8, 63, 0, 16, 1, 75, 4,  1, 5, 84, 3, 22, 7, 50, 
    3, 16, 5, 28, 4, 45, 8, 49, 1, 49, 0, 66, 6, 16, 7, 53, 2,  2, 
    8, 32, 0, 20, 4, 63, 3, 53, 2, 97, 1, 76, 6, 68, 7, 37, 5, 81, 
    0, 12, 5,  5, 4, 32, 7, 86, 6, 33, 1,  6, 2, 12, 3, 73, 8,  3, 
    0, 52, 2, 58, 8, 84, 6, 75, 1, 65, 7,  2, 4, 30, 5, 67, 3, 87, 
    6, 54, 4, 19, 8, 37, 7, 91, 1, 71, 2, 20, 5, 49, 3, 11, 0, 96, 
    3, 18, 6, 60, 5, 67, 7, 30, 0, 24, 1, 75, 8, 97, 4,  9, 2, 52, 
    5, 55, 2, 87, 7, 75, 3, 38, 0, 43, 4,  3, 6, 83, 8, 11, 1, 76
  };
  const int q6919[] = {
    9, 9, // Number of jobs and machines
    5,  2, 2, 44, 4, 31, 8, 77, 1, 62, 3, 36, 7, 35, 6, 80, 0, 33, 
    5, 93, 8,  5, 2, 33, 6, 43, 0,  4, 7, 26, 4, 33, 1, 22, 3, 55, 
    3, 47, 7, 62, 5,  4, 1, 73, 0,  5, 8, 40, 6, 65, 4, 30, 2, 69, 
    7, 13, 4, 14, 8, 35, 3,  8, 6, 28, 1, 14, 2, 33, 5, 91, 0, 54, 
    4, 76, 0, 34, 5, 87, 3, 94, 1, 32, 8, 83, 7, 19, 2,  3, 6, 58, 
    0, 78, 6,  9, 3, 63, 2, 64, 4, 59, 7, 85, 8, 75, 5,  4, 1, 90, 
    2, 69, 6, 60, 8, 49, 0, 26, 5, 71, 7,  6, 4, 64, 1, 16, 3, 29, 
    6, 52, 0, 45, 1, 25, 8, 20, 3, 80, 2,  3, 4, 80, 7, 15, 5, 66, 
    6,  5, 2, 10, 0, 59, 7,  2, 1, 75, 3, 10, 8, 95, 5, 42, 4, 53
  };
  const int q6920[] = {
    9, 9, // Number of jobs and machines
    2, 37, 3, 39, 5, 98, 0, 48, 8, 57, 6, 95, 4, 22, 1, 42, 7,  3, 
    1, 67, 0, 58, 2, 12, 5, 31, 6, 84, 8, 98, 7,  8, 4, 98, 3, 69, 
    6, 72, 3, 12, 5, 18, 8, 93, 7, 21, 4, 10, 0, 20, 1, 23, 2, 92, 
    2, 11, 6, 97, 3, 41, 8, 54, 5, 71, 7, 71, 0, 10, 1, 67, 4, 51, 
    6,  2, 1, 85, 5, 12, 2, 75, 7, 79, 8, 45, 3, 21, 0, 96, 4, 97, 
    3, 85, 8, 72, 7, 46, 6, 39, 2, 20, 5, 31, 4,  1, 1, 56, 0,  8, 
    0, 68, 4,  9, 1, 98, 2, 13, 8,  8, 7, 97, 3, 21, 5, 83, 6, 59, 
    1, 76, 0, 59, 4, 35, 7, 45, 6, 91, 2, 54, 5, 44, 3, 42, 8, 29, 
    6, 67, 7, 84, 4, 22, 3, 69, 5, 29, 0, 91, 1, 97, 8, 60, 2, 75
  };
  const int q6921[] = {
    9, 9, // Number of jobs and machines
    7, 73, 3, 12, 6, 68, 0, 75, 4, 63, 2, 17, 1, 73, 8, 70, 5, 35, 
    8, 16, 3, 18, 7, 42, 1, 69, 5, 50, 2, 68, 0, 79, 4, 59, 6, 35, 
    7, 13, 4, 53, 0, 74, 3, 84, 5, 16, 8, 41, 2, 56, 1, 68, 6, 55, 
    5, 63, 2, 15, 8, 89, 3, 20, 1, 68, 0, 63, 6, 26, 7, 31, 4, 33, 
    5, 11, 6, 57, 4, 19, 7, 21, 1, 96, 0, 96, 2, 86, 8, 43, 3, 94, 
    3, 62, 1, 84, 2, 66, 5, 76, 8, 76, 7, 16, 0, 39, 4, 35, 6, 79, 
    7, 72, 1, 78, 2,  5, 4, 90, 5, 49, 6, 99, 8, 93, 3,  4, 0, 21, 
    4, 40, 6,  9, 2, 75, 7,  8, 0, 99, 1, 20, 8, 11, 5, 44, 3, 97, 
    1, 56, 6, 88, 0, 48, 4, 96, 5, 67, 8, 73, 7, 40, 3, 80, 2, 51
  };
  const int q6922[] = {
    9, 9, // Number of jobs and machines
    6, 62, 7, 86, 5, 39, 1, 56, 0, 76, 3,  1, 8,  6, 2, 40, 4, 27, 
    3, 61, 4, 96, 8,  3, 6, 50, 0, 18, 2, 75, 7, 27, 5, 70, 1, 60, 
    3, 84, 2, 77, 5, 65, 7, 36, 4, 44, 6, 97, 0, 64, 1, 14, 8, 60, 
    2, 67, 4, 60, 7, 72, 8,  8, 5, 46, 0, 57, 1, 13, 3, 12, 6, 89, 
    1, 67, 2,  7, 6, 86, 0, 46, 7, 43, 8, 40, 4, 87, 3, 29, 5, 10, 
    7, 59, 5, 98, 6, 62, 4, 47, 1, 47, 8, 64, 0, 54, 2, 91, 3, 30, 
    2, 13, 5, 80, 1, 15, 4, 29, 7, 37, 0, 12, 6, 68, 8, 57, 3, 25, 
    2, 90, 6,  2, 3, 63, 8, 59, 7, 13, 1, 18, 5, 24, 0, 10, 4,  1, 
    8, 88, 4, 14, 6, 53, 3, 96, 0, 87, 5, 52, 7, 40, 1, 96, 2,  1
  };
  const int q6923[] = {
    9, 9, // Number of jobs and machines
    7, 20, 5, 59, 8, 45, 0, 80, 6, 42, 4, 57, 2, 87, 1, 37, 3, 86, 
    8, 34, 3, 34, 2, 85, 1, 96, 5, 95, 7, 27, 6, 19, 4, 59, 0, 69, 
    8,  9, 6, 67, 3, 53, 4, 92, 0, 13, 5, 91, 2,  7, 1, 76, 7, 35, 
    4, 38, 3, 17, 0, 29, 2, 46, 6, 83, 7, 17, 8, 98, 5, 10, 1, 53, 
    6, 57, 8, 80, 5, 38, 3, 24, 1, 40, 7, 93, 2, 54, 4, 31, 0, 70, 
    5,  4, 0, 37, 4, 66, 2, 22, 6, 72, 8, 14, 1, 97, 7, 42, 3, 42, 
    4, 15, 3, 20, 0, 86, 8, 66, 7, 73, 6,  4, 2, 40, 1, 48, 5, 24, 
    8, 50, 6, 80, 0, 29, 2,  6, 4, 37, 3, 69, 7,  7, 5, 49, 1, 51, 
    6, 69, 0, 21, 2, 52, 4,  2, 3, 48, 7, 94, 8, 27, 1,  5, 5, 54
  };
  const int q6924[] = {
    9, 9, // Number of jobs and machines
    0, 60, 5, 12, 2, 82, 7, 20, 4, 38, 6, 43, 1, 60, 8, 94, 3, 43, 
    2, 25, 0, 12, 4, 37, 1, 21, 5, 31, 3,  1, 6, 89, 7,  2, 8, 36, 
    8, 97, 4, 21, 5, 82, 7, 11, 2, 82, 3, 27, 0, 19, 6, 20, 1, 51, 
    2, 87, 5, 54, 1, 58, 8, 35, 6, 22, 3, 38, 7, 36, 4, 96, 0, 86, 
    0, 54, 2, 51, 6, 24, 7, 39, 4, 23, 1, 73, 3, 67, 8, 96, 5, 72, 
    3, 95, 1, 92, 8,  5, 2, 45, 5, 18, 4, 25, 0, 17, 6, 95, 7,  4, 
    2, 59, 4, 42, 3, 70, 0, 73, 8, 47, 5, 14, 1, 76, 7, 62, 6,  5, 
    0, 25, 3, 54, 7, 86, 4, 56, 1, 69, 5, 89, 6, 82, 8, 24, 2, 60, 
    2, 82, 0, 91, 3, 20, 7, 68, 4, 56, 1, 53, 6,  4, 5, 86, 8,  9
  };
  const int q6925[] = {
    9, 9, // Number of jobs and machines
    3, 57, 6, 65, 2, 63, 1, 15, 0, 54, 7, 66, 4, 51, 8, 29, 5, 45, 
    8, 92, 7, 26, 6, 30, 2,  2, 1,  7, 5, 55, 0,  1, 3, 57, 4, 35, 
    6, 95, 1, 45, 7, 91, 5, 43, 3,  5, 2, 60, 0, 37, 4, 38, 8, 64, 
    6, 55, 2,  8, 3, 97, 4, 52, 7, 83, 0, 66, 8, 20, 5, 15, 1, 19, 
    5,  4, 2, 77, 7, 16, 4, 77, 3, 54, 8, 46, 0, 51, 6, 98, 1, 58, 
    1, 60, 4, 79, 6, 36, 7,  2, 0, 28, 5, 28, 3, 66, 8, 73, 2, 75, 
    4, 14, 6, 62, 5, 38, 0, 75, 8, 37, 3, 97, 1, 12, 7, 70, 2,  2, 
    2, 85, 1, 25, 5, 64, 6, 25, 8, 51, 7, 96, 3, 22, 0, 23, 4, 53, 
    5, 76, 0, 74, 8, 61, 4, 58, 3, 41, 1, 46, 7, 59, 6, 22, 2, 66
  };
  const int q6926[] = {
    9, 9, // Number of jobs and machines
    3, 26, 1, 64, 7,  8, 6, 96, 4, 24, 8, 70, 5,  7, 0, 16, 2, 41, 
    4, 54, 1, 81, 5, 20, 7, 45, 6, 60, 0,  3, 3, 26, 2, 11, 8, 75, 
    2, 51, 7, 17, 1,  1, 3, 53, 4, 75, 0, 80, 5, 57, 8, 92, 6, 67, 
    8,  5, 3, 59, 0, 72, 2, 38, 6, 67, 1, 87, 4, 26, 5, 91, 7, 84, 
    1, 44, 0, 94, 7, 55, 8, 13, 6, 43, 2, 72, 4, 34, 5, 19, 3, 65, 
    7, 71, 1,  5, 2, 48, 5, 14, 8, 27, 3, 47, 0, 24, 6,  2, 4, 95, 
    4, 59, 8, 46, 0, 96, 2, 33, 5, 90, 6, 51, 3, 23, 7, 78, 1, 76, 
    5, 17, 3,  7, 7, 97, 4, 32, 2, 97, 8, 94, 0, 90, 1, 47, 6, 87, 
    4, 62, 7, 76, 6,  3, 1, 84, 8, 13, 2, 43, 5, 55, 3, 78, 0,  6
  };
  const int q6927[] = {
    9, 9, // Number of jobs and machines
    1, 83, 7, 89, 8, 92, 2,  7, 3, 36, 5, 35, 4, 96, 0,  5, 6, 67, 
    0, 39, 4, 25, 2, 67, 6, 13, 5, 10, 7, 95, 8,  4, 3, 23, 1, 72, 
    8, 84, 5, 29, 7, 69, 1, 30, 2, 21, 0,  3, 4, 58, 3,  9, 6, 48, 
    0, 56, 5, 44, 1, 17, 7, 77, 3, 34, 2, 63, 8, 77, 6, 67, 4, 11, 
    5, 55, 7, 42, 2, 58, 1, 91, 8, 46, 4, 97, 0, 44, 6, 90, 3, 80, 
    4, 43, 7, 92, 0, 87, 5, 37, 6, 13, 8, 95, 2, 35, 3, 53, 1, 92, 
    0, 40, 1, 38, 3,  9, 2, 61, 6,  5, 7, 95, 4, 25, 5, 86, 8, 21, 
    8, 67, 7, 67, 6, 88, 1, 59, 4, 68, 5, 64, 3, 99, 0, 36, 2, 74, 
    5, 57, 3, 78, 8, 48, 2, 33, 4, 42, 1, 71, 0, 29, 7, 95, 6, 40
  };
  const int q6928[] = {
    9, 9, // Number of jobs and machines
    6, 74, 8, 33, 1,  1, 3,  2, 4, 48, 2, 10, 0, 22, 7, 65, 5, 70, 
    3, 40, 8, 88, 7,  6, 2, 58, 4, 62, 0, 68, 6, 70, 5, 43, 1, 45, 
    6, 93, 4,  6, 7, 34, 0, 42, 2,  6, 5, 11, 1, 72, 3, 50, 8, 24, 
    6, 15, 4, 34, 7, 16, 1, 95, 8, 91, 5, 77, 3, 26, 2, 10, 0, 58, 
    8, 49, 1, 28, 0, 91, 6, 98, 5, 45, 4, 84, 3, 87, 7, 55, 2, 29, 
    0, 70, 8, 91, 3, 20, 5, 80, 1, 97, 4,  5, 2, 88, 7, 71, 6, 69, 
    2, 49, 7, 69, 8, 88, 1,  2, 5, 28, 4, 90, 6, 48, 3, 86, 0,  4, 
    6, 85, 3, 15, 5, 76, 1, 80, 4, 69, 0, 68, 2, 84, 7, 27, 8, 39, 
    4, 47, 8, 22, 0, 24, 3, 55, 5, 68, 6, 11, 2, 57, 1, 46, 7, 83
  };
  const int q6929[] = {
    9, 9, // Number of jobs and machines
    4, 76, 6, 61, 5, 56, 1, 10, 2, 20, 3, 78, 0, 43, 8, 38, 7, 44, 
    4, 96, 0, 69, 3, 81, 6, 16, 1, 43, 8, 55, 5,  7, 2, 99, 7, 13, 
    0, 18, 3, 95, 2, 30, 7, 74, 4, 15, 6, 45, 5, 47, 1, 49, 8, 90, 
    0, 48, 3, 89, 8, 22, 4, 39, 6, 98, 5, 52, 7,  4, 2, 90, 1, 80, 
    2, 38, 7, 92, 8, 28, 0,  9, 1, 55, 5, 56, 6,  5, 4, 69, 3, 99, 
    7, 29, 1, 17, 4, 29, 3, 85, 0, 76, 5, 90, 6, 36, 8, 18, 2, 27, 
    3, 19, 8, 76, 6, 78, 5, 76, 0, 54, 7, 48, 2, 89, 4, 67, 1,  7, 
    7, 85, 1, 81, 6, 35, 0, 67, 5, 67, 4, 85, 2,  2, 3, 57, 8, 11, 
    5, 69, 8, 67, 7, 53, 0, 53, 2, 67, 3, 40, 4, 56, 1, 64, 6, 98
  };
  const int q6930[] = {
    9, 9, // Number of jobs and machines
    5, 84, 7,  6, 6, 50, 1,  4, 4, 12, 2, 65, 3, 72, 8, 80, 0, 88, 
    7, 56, 5, 73, 4, 52, 3, 64, 6, 42, 2, 33, 0, 21, 8, 47, 1, 20, 
    5, 20, 8, 72, 2, 24, 4, 67, 1, 70, 7, 23, 0, 74, 6, 66, 3, 96, 
    7, 89, 8, 57, 0, 58, 5, 81, 4, 31, 2, 51, 6, 48, 1, 91, 3, 85, 
    1,  9, 0, 79, 4,  7, 7, 83, 2, 53, 5, 20, 6, 79, 8, 32, 3, 60, 
    8, 10, 4, 16, 3, 89, 2, 38, 1, 61, 7, 13, 6, 84, 5, 19, 0,  3, 
    3, 99, 1, 13, 2, 99, 4,  6, 0, 51, 5, 24, 7, 49, 8, 40, 6, 70, 
    7, 35, 5, 38, 3, 98, 1,  2, 0, 43, 8, 88, 2, 95, 6, 37, 4, 86, 
    1, 89, 0, 96, 2, 38, 7, 53, 8, 40, 4, 53, 3, 64, 6, 98, 5, 97
  };
  const int q6931[] = {
    9, 9, // Number of jobs and machines
    6, 44, 3, 59, 8, 75, 4, 80, 7, 30, 1, 38, 2, 36, 5, 74, 0, 98, 
    4, 18, 2, 46, 8, 99, 7, 56, 6, 29, 0, 45, 1, 38, 5, 36, 3, 98, 
    4, 34, 3, 58, 5, 67, 2, 64, 1, 69, 0, 83, 8, 23, 6, 20, 7, 62, 
    3, 27, 0, 25, 8, 53, 2, 15, 1, 85, 6, 68, 4, 95, 7, 47, 5, 26, 
    0, 48, 7, 63, 8, 44, 6, 10, 4, 10, 3, 83, 2, 35, 1, 57, 5, 66, 
    0, 14, 1, 94, 3, 97, 5, 70, 8, 17, 6, 79, 4, 78, 7, 12, 2, 34, 
    2, 83, 7, 71, 0, 90, 6, 21, 1, 65, 5, 45, 8, 94, 3, 66, 4, 48, 
    4, 53, 3,  6, 1, 19, 2,  7, 5, 16, 8, 27, 7, 27, 0, 59, 6, 52, 
    5, 70, 6, 68, 2, 29, 8, 36, 1, 19, 4, 41, 0, 81, 7, 70, 3, 32
  };
  const int q6932[] = {
    9, 9, // Number of jobs and machines
    0, 67, 1,  4, 6, 25, 2, 16, 7, 93, 5, 59, 4, 47, 3, 60, 8, 25, 
    6, 14, 1, 40, 5, 69, 8, 30, 3, 91, 7, 91, 2, 75, 0, 62, 4, 72, 
    4, 67, 6, 70, 3,  5, 1, 65, 7, 82, 8,  6, 2, 91, 5, 85, 0, 38, 
    3, 34, 7, 32, 6, 50, 5, 98, 0, 72, 4, 73, 1, 96, 8, 44, 2, 87, 
    8, 88, 3,  5, 1, 97, 4, 44, 6, 64, 5, 55, 7, 64, 2, 27, 0, 12, 
    5, 75, 2, 72, 0, 15, 4, 68, 6, 17, 7, 33, 1, 39, 8, 26, 3, 41, 
    3, 95, 8, 62, 7, 64, 2, 84, 5, 82, 0, 82, 6,  7, 4, 25, 1, 75, 
    8, 88, 6, 56, 2, 82, 0, 81, 4, 90, 7,  8, 3, 61, 1, 45, 5, 60, 
    3, 56, 8, 52, 1,  9, 4, 53, 6, 84, 5, 40, 7, 17, 2, 19, 0, 88
  };
  const int q6933[] = {
    9, 9, // Number of jobs and machines
    2,  3, 7, 27, 0, 42, 1, 71, 3, 80, 5,  8, 6, 79, 4, 36, 8, 59, 
    8, 38, 0, 50, 7, 97, 6, 92, 4, 50, 5, 15, 3, 15, 1,  5, 2, 48, 
    7, 73, 0, 54, 1, 12, 2, 39, 4, 88, 5, 74, 6,  2, 8, 82, 3, 97, 
    6, 63, 7, 81, 8, 85, 0, 43, 3, 14, 1, 45, 2, 55, 5, 23, 4, 56, 
    2, 79, 4, 16, 1, 45, 7,  5, 0, 94, 8, 36, 3, 61, 6, 37, 5, 26, 
    1, 76, 7,  9, 2, 57, 0,  8, 8, 99, 3, 94, 5,  8, 4, 63, 6, 34, 
    4, 33, 6, 87, 2,  4, 8, 47, 0, 31, 5,  5, 7, 50, 1, 62, 3, 21, 
    0, 70, 3, 29, 6, 58, 7, 27, 2, 43, 4, 23, 8, 46, 1, 96, 5, 62, 
    0, 37, 1, 55, 2, 98, 4, 37, 6,  8, 8,  4, 7, 49, 3, 80, 5, 53
  };
  const int q6934[] = {
    9, 9, // Number of jobs and machines
    0, 66, 6, 93, 4, 24, 2, 60, 7, 12, 8, 36, 5, 96, 1, 12, 3, 68, 
    0, 76, 2, 72, 5, 12, 7, 60, 8, 79, 6, 91, 3, 41, 4, 16, 1, 75, 
    7, 39, 6, 27, 1, 59, 5, 65, 2, 22, 3, 32, 8, 19, 4, 50, 0,  5, 
    1, 86, 6, 38, 4, 94, 7, 92, 2, 94, 0, 50, 8,  2, 5,  3, 3, 99, 
    7, 23, 5, 51, 8, 38, 3, 36, 4, 84, 6, 58, 0, 73, 1, 83, 2, 15, 
    2, 30, 1, 60, 6, 56, 5, 83, 4, 85, 8, 28, 7, 30, 0, 51, 3, 15, 
    3, 42, 6, 15, 5, 25, 1, 50, 0, 42, 2, 41, 4, 89, 7, 40, 8,  6, 
    7, 98, 5, 62, 3, 20, 1, 31, 8, 19, 2, 84, 4, 75, 0, 15, 6, 23, 
    7, 95, 0, 44, 3, 97, 5, 55, 8, 41, 4, 63, 1, 83, 2, 36, 6, 28
  };
  const int q6935[] = {
    9, 9, // Number of jobs and machines
    8, 41, 7, 77, 0, 76, 5, 49, 2, 75, 3, 61, 1,  1, 6, 59, 4,  2, 
    4, 93, 2, 32, 1, 63, 0, 67, 6, 37, 7, 14, 8, 80, 3, 43, 5, 99, 
    4, 56, 2, 43, 5, 75, 1, 68, 6, 23, 3, 19, 7, 31, 8, 39, 0, 19, 
    5, 46, 3, 95, 1, 14, 8, 81, 6, 54, 2, 18, 7, 20, 0, 69, 4, 93, 
    8, 12, 4, 77, 7, 33, 3, 13, 6, 69, 1, 38, 2, 38, 0, 76, 5, 71, 
    8, 63, 4,  4, 6, 67, 0, 95, 1, 82, 7, 48, 2, 85, 5, 93, 3, 85, 
    8,  9, 7, 90, 1, 29, 5, 78, 3, 83, 2, 15, 6, 80, 4, 54, 0, 51, 
    4, 17, 7, 82, 6,  1, 2, 59, 8, 45, 3, 16, 1, 17, 5, 15, 0, 19, 
    2,  1, 1,  8, 4, 41, 5, 21, 8,  4, 7,  2, 3, 47, 0,  3, 6, 82
  };
  const int q6936[] = {
    9, 9, // Number of jobs and machines
    5, 64, 4, 39, 7, 24, 1, 13, 3, 42, 0, 52, 8, 63, 6, 28, 2, 95, 
    8, 14, 2, 60, 7, 67, 6, 94, 3, 38, 4,  1, 0, 94, 5,  9, 1, 39, 
    2, 62, 1,  2, 4,  4, 6, 36, 0, 38, 3, 29, 8, 49, 5, 83, 7, 23, 
    8, 37, 7, 48, 3, 34, 0, 30, 1, 56, 6, 15, 4, 47, 2, 23, 5, 45, 
    5, 67, 4, 22, 0, 34, 6, 62, 1, 19, 2, 12, 3, 69, 8, 27, 7, 69, 
    5, 13, 6, 78, 7, 83, 0, 22, 1, 27, 8, 32, 4, 71, 3, 78, 2, 16, 
    5, 19, 1, 57, 3, 55, 6, 55, 4, 92, 7, 19, 2, 27, 8, 14, 0, 93, 
    4,  2, 0, 31, 3, 52, 8, 35, 1, 72, 6, 96, 7, 22, 2, 45, 5, 22, 
    3,  6, 7, 46, 5, 53, 1, 93, 6, 47, 8, 49, 2, 67, 4, 40, 0, 31
  };
  const int q6937[] = {
    9, 9, // Number of jobs and machines
    7, 68, 0, 52, 6, 82, 2, 82, 3, 27, 4, 72, 5, 75, 1, 70, 8, 21, 
    4, 98, 5, 79, 3, 67, 8,  1, 7, 62, 1, 60, 2, 45, 0, 38, 6, 28, 
    5, 27, 0, 15, 1, 42, 2, 66, 6, 85, 8, 16, 7, 20, 3, 44, 4, 66, 
    2, 98, 0, 47, 1, 48, 7, 67, 8, 36, 6, 37, 5, 12, 3, 62, 4,  6, 
    3, 85, 6, 77, 7, 90, 4, 31, 1, 27, 2, 84, 0, 91, 5, 82, 8, 51, 
    5, 45, 0, 28, 3, 28, 4, 79, 2, 14, 6,  1, 8, 36, 1, 44, 7, 12, 
    5, 52, 4, 51, 0,  6, 1, 80, 3, 30, 2, 60, 7, 47, 6, 83, 8, 85, 
    5, 82, 8, 88, 4, 54, 3, 12, 7, 40, 6, 14, 2,  8, 1, 77, 0, 70, 
    8, 62, 6, 97, 0, 67, 1, 47, 7, 91, 3, 79, 5, 16, 2, 48, 4,  3
  };
  const int q6938[] = {
    9, 9, // Number of jobs and machines
    4,  3, 0, 59, 2, 66, 5, 59, 3, 85, 1, 63, 7, 28, 6, 91, 8, 30, 
    8, 99, 6, 97, 7, 28, 2, 12, 3, 59, 0, 72, 1, 10, 4, 98, 5, 97, 
    7, 18, 0, 79, 8, 27, 1, 86, 4,  7, 3, 41, 2, 51, 6, 49, 5, 43, 
    5, 47, 3, 67, 7, 96, 1, 25, 4, 45, 8, 92, 0, 80, 6, 43, 2, 33, 
    0, 28, 8, 40, 4, 31, 3, 30, 5, 35, 6, 31, 7, 84, 1, 59, 2, 61, 
    2, 37, 7, 71, 8, 97, 1, 97, 6, 92, 3,  3, 5, 16, 4, 61, 0, 84, 
    2, 42, 0, 35, 5, 21, 4, 24, 1, 56, 7, 43, 8, 93, 6, 85, 3, 29, 
    4, 60, 0, 84, 1, 98, 2, 15, 8, 43, 5, 98, 7,  4, 3, 53, 6, 74, 
    8, 95, 5, 57, 1, 87, 7,  4, 0, 88, 3, 37, 2, 97, 4,  1, 6, 11
  };
  const int q6939[] = {
    9, 9, // Number of jobs and machines
    8, 48, 4, 18, 6, 28, 3, 62, 7, 94, 5,  4, 2, 62, 1, 82, 0, 85, 
    1, 54, 7, 32, 8, 18, 4, 62, 5, 22, 6, 41, 0, 99, 2, 71, 3, 67, 
    3, 56, 7, 24, 1, 95, 6, 52, 4, 32, 8, 85, 0, 25, 5, 14, 2, 72, 
    7, 39, 3, 90, 0, 51, 8, 92, 4, 95, 6, 87, 5, 42, 1, 40, 2, 22, 
    7, 20, 4, 36, 2, 56, 0, 55, 5, 16, 1, 90, 8, 76, 6, 89, 3, 23, 
    1,  8, 3, 54, 6, 20, 7, 16, 5, 71, 0, 53, 4,  1, 8, 81, 2,  7, 
    5, 31, 2, 62, 1, 97, 4, 71, 0,  5, 3, 39, 6, 75, 7, 79, 8, 39, 
    4, 71, 8, 63, 1, 42, 2, 97, 0, 17, 7, 62, 5, 99, 3, 88, 6, 42, 
    5,  8, 3, 16, 0, 99, 8, 53, 1, 18, 6,  4, 2, 48, 4, 57, 7, 73
  };
  const int q6940[] = {
    9, 9, // Number of jobs and machines
    1, 21, 5,  6, 7, 74, 0, 47, 2, 27, 8, 98, 4, 55, 6,  5, 3, 56, 
    2, 36, 4, 60, 1, 84, 8, 39, 7, 25, 0, 77, 6, 98, 3, 79, 5,  9, 
    8, 58, 3, 84, 0,  2, 2, 64, 5, 30, 1, 44, 4, 72, 6, 13, 7, 61, 
    5, 72, 2,  6, 4, 67, 6, 51, 0, 37, 7,  9, 1, 77, 8, 62, 3, 99, 
    8, 44, 4, 91, 5, 50, 1, 25, 2, 62, 3, 93, 0, 10, 7, 75, 6, 57, 
    3, 97, 8, 55, 1, 43, 5, 67, 4, 24, 7, 19, 6, 82, 2, 92, 0,  2, 
    2, 35, 4, 55, 0, 84, 6, 92, 5, 65, 3, 97, 7,  1, 1,  5, 8, 79, 
    7, 45, 4, 17, 2,  6, 6, 42, 3, 33, 0,  9, 1, 86, 8, 34, 5, 10, 
    1, 26, 8, 21, 6, 77, 4, 43, 7, 13, 5, 68, 3, 71, 0, 89, 2, 94
  };
  const int q6941[] = {
    9, 9, // Number of jobs and machines
    8, 35, 1, 70, 5, 66, 6, 51, 2, 19, 0, 49, 7, 41, 4, 51, 3, 42, 
    8, 96, 1, 55, 7,  6, 0, 32, 6, 57, 4, 45, 5, 12, 3, 39, 2, 13, 
    5, 85, 8, 33, 7, 65, 3, 21, 4, 63, 1, 47, 6, 34, 2, 10, 0, 67, 
    1, 31, 3, 39, 7,  1, 8, 65, 4, 83, 0, 69, 5, 65, 6, 80, 2, 78, 
    4, 89, 0, 92, 2,  8, 5,  3, 1, 13, 8, 94, 3, 45, 7, 55, 6,  3, 
    7,  1, 6, 39, 4, 68, 5,  2, 8, 91, 1, 85, 2, 16, 0, 50, 3,  6, 
    0, 74, 6, 67, 5, 54, 7, 33, 3, 41, 4,  4, 8,  7, 2, 66, 1, 74, 
    4, 20, 8, 44, 3, 55, 0, 19, 6, 65, 2, 40, 5,  6, 1,  1, 7, 15, 
    4, 48, 7, 41, 6, 82, 5, 51, 0, 89, 2, 68, 1, 99, 8, 13, 3,  2
  };
  const int q6942[] = {
    9, 9, // Number of jobs and machines
    3, 75, 1, 49, 0, 32, 7, 39, 8, 17, 5,  1, 2, 34, 6, 38, 4,  2, 
    1, 79, 6, 89, 7, 23, 4, 98, 2, 75, 8, 80, 3, 73, 0, 49, 5, 13, 
    1,  4, 4, 63, 8, 13, 7, 11, 2, 98, 5,  6, 6, 65, 3, 25, 0, 59, 
    6, 87, 3, 35, 5, 51, 7, 31, 4, 76, 8, 47, 0, 45, 1, 18, 2, 53, 
    6, 24, 5, 56, 0,  1, 2, 16, 3, 65, 4, 88, 7, 15, 8, 51, 1, 86, 
    8, 81, 1, 90, 7, 85, 0, 24, 5, 19, 4, 37, 2, 12, 3, 27, 6, 10, 
    4, 54, 3, 92, 6, 68, 5, 41, 2, 83, 8, 35, 1, 73, 7, 32, 0, 87, 
    5,  2, 8, 78, 0, 68, 3, 33, 4, 76, 7, 85, 6, 78, 2, 72, 1, 97, 
    3, 55, 1, 32, 5, 79, 7, 65, 2, 69, 0,  8, 6, 29, 4, 93, 8, 85
  };
  const int q6943[] = {
    9, 9, // Number of jobs and machines
    4, 49, 0, 89, 1, 91, 8, 40, 6,  2, 3, 85, 2, 84, 7,  9, 5,  9, 
    7, 87, 2, 48, 8, 91, 4, 90, 5, 79, 3,  8, 0, 94, 6, 78, 1, 63, 
    6, 16, 1, 64, 7, 50, 8, 90, 5, 41, 4, 42, 3, 33, 2, 33, 0, 27, 
    6,  6, 2, 50, 1, 42, 8, 38, 4, 53, 7, 87, 5, 66, 3, 25, 0, 27, 
    3, 35, 1, 73, 2, 58, 8, 22, 4, 97, 5, 28, 0, 62, 7, 61, 6, 16, 
    6, 29, 8, 21, 0, 86, 4, 23, 2,  2, 3, 44, 1, 35, 5, 19, 7, 92, 
    7, 55, 5, 25, 0, 93, 1, 45, 4, 76, 6,  1, 8, 25, 3,  2, 2, 94, 
    6, 57, 2,  6, 1, 51, 5, 93, 4, 49, 3, 85, 8, 79, 7,  9, 0, 27, 
    2, 31, 8, 10, 1, 12, 0, 71, 6, 81, 3, 64, 7, 38, 5, 21, 4, 53
  };
  const int q6944[] = {
    9, 9, // Number of jobs and machines
    7, 63, 0, 95, 2, 56, 1, 62, 8, 28, 3, 53, 6, 45, 5, 66, 4, 74, 
    6, 65, 1, 52, 5, 15, 2, 59, 7, 49, 8, 60, 3, 23, 0, 24, 4, 45, 
    3, 40, 6, 96, 7, 49, 0, 48, 4, 93, 8, 29, 2, 92, 5, 72, 1, 10, 
    7, 63, 2, 63, 1, 27, 8, 78, 4, 50, 0, 13, 3, 40, 5,  8, 6, 96, 
    0, 46, 8, 43, 1, 74, 6, 78, 4, 85, 7, 26, 2,  6, 5, 50, 3, 21, 
    0, 10, 1, 39, 2, 63, 5, 92, 7,  2, 8, 56, 6, 11, 3, 23, 4, 39, 
    1, 41, 2, 15, 0, 53, 4, 44, 3, 33, 6, 58, 8, 30, 7, 86, 5, 52, 
    3, 51, 5, 75, 4, 58, 0, 69, 7, 84, 6, 71, 8, 32, 1, 27, 2,  8, 
    7, 78, 6, 20, 0, 93, 1, 10, 8, 71, 4, 43, 2, 74, 3, 90, 5, 61
  };
  const int q6945[] = {
    9, 9, // Number of jobs and machines
    3, 15, 2, 83, 5, 52, 0, 16, 1,  3, 8, 61, 4, 66, 6, 72, 7, 19, 
    2, 53, 0, 73, 1, 20, 8, 16, 3, 53, 4, 21, 7, 55, 5, 59, 6, 49, 
    3, 63, 2,  4, 0,  7, 6, 45, 8, 96, 4, 55, 7, 23, 1,  5, 5, 37, 
    3, 29, 2, 99, 1, 91, 4, 58, 7, 36, 5, 81, 6, 80, 0, 84, 8, 45, 
    5, 46, 2, 30, 3, 35, 1, 96, 7, 27, 0, 51, 4, 92, 6, 75, 8, 89, 
    1, 68, 0, 72, 3, 97, 8, 35, 6, 62, 7, 79, 4, 10, 5, 29, 2, 87, 
    1, 22, 4, 89, 3, 86, 5, 66, 0, 94, 7, 89, 2, 19, 8,  2, 6, 30, 
    3, 54, 4, 70, 6, 26, 8, 82, 5, 60, 2, 19, 0, 44, 7, 84, 1, 56, 
    1, 29, 8, 29, 4, 58, 5,  6, 0, 77, 3, 90, 2, 35, 7, 64, 6, 87
  };
  const int q6946[] = {
    9, 9, // Number of jobs and machines
    8, 26, 7, 20, 6, 37, 4, 36, 1, 34, 3, 16, 2,  1, 5, 51, 0, 24, 
    3, 92, 6, 98, 8, 23, 0, 17, 4, 98, 5, 14, 2, 42, 1, 86, 7, 31, 
    2, 45, 5, 27, 0, 42, 3, 57, 1,  1, 8, 25, 6, 43, 7, 92, 4, 52, 
    6, 28, 7, 20, 5, 41, 0, 26, 8, 53, 3,  6, 2, 57, 1, 70, 4, 78, 
    1, 95, 4, 53, 2, 15, 7, 70, 5, 53, 6, 89, 0, 20, 8, 26, 3, 98, 
    4, 79, 7, 20, 2, 74, 3, 27, 6, 17, 8, 13, 0, 82, 5, 28, 1, 46, 
    7, 23, 3, 92, 5, 52, 1,  2, 8, 60, 2, 37, 6, 64, 4, 58, 0,  1, 
    7, 53, 4, 89, 3, 15, 6, 48, 0, 40, 1, 47, 8, 89, 5, 62, 2, 58, 
    0, 98, 2, 62, 8, 67, 5, 99, 1, 63, 6, 24, 3, 71, 7, 83, 4, 79
  };
  const int q6947[] = {
    9, 9, // Number of jobs and machines
    2, 80, 3,  1, 8, 43, 6, 86, 0, 25, 7, 24, 5, 67, 1,  5, 4, 57, 
    8, 17, 5, 83, 6, 25, 2, 34, 1, 10, 4, 56, 0, 35, 3, 60, 7, 15, 
    5,  3, 2, 79, 6, 93, 8, 44, 7, 18, 3, 92, 4, 28, 1, 83, 0, 41, 
    6, 84, 3, 83, 0, 25, 5, 90, 4, 35, 1, 91, 7, 72, 8, 59, 2, 57, 
    8, 93, 1, 54, 5, 49, 3, 70, 4, 20, 6, 57, 7, 52, 0, 27, 2, 56, 
    1, 62, 4, 79, 5, 25, 6, 78, 3, 36, 7, 41, 2, 46, 0, 77, 8, 51, 
    3, 26, 0, 20, 7, 33, 1, 53, 4, 18, 6, 34, 5, 68, 2, 27, 8, 31, 
    8, 35, 4, 50, 0, 13, 2,  2, 1, 96, 5, 98, 7, 12, 6,  7, 3, 29, 
    4, 15, 8, 87, 3, 25, 2, 16, 0, 66, 1, 14, 7, 52, 5, 86, 6, 91
  };
  const int q6948[] = {
    9, 9, // Number of jobs and machines
    4, 46, 2, 87, 1, 58, 3, 15, 6,  1, 5, 80, 7, 62, 8, 48, 0, 54, 
    6, 20, 5, 47, 8, 85, 7, 92, 4, 56, 3, 14, 0, 54, 2, 64, 1, 88, 
    5, 62, 2, 63, 6, 78, 7, 59, 4, 15, 1, 66, 0, 44, 8, 36, 3, 27, 
    2, 73, 6, 41, 3, 34, 0, 62, 7, 58, 5, 72, 8, 22, 4, 34, 1, 43, 
    3, 60, 2, 16, 0, 47, 7, 77, 5, 82, 6, 59, 1, 67, 4, 74, 8, 76, 
    6, 36, 7, 42, 2, 87, 1, 10, 4, 75, 0, 26, 8, 15, 5, 25, 3, 58, 
    4, 31, 7, 24, 6, 89, 2, 97, 1, 26, 5, 85, 3, 60, 0, 86, 8, 79, 
    8, 44, 2, 41, 6, 89, 3, 98, 1, 23, 5, 70, 7, 19, 4, 93, 0, 55, 
    8, 72, 6, 66, 3, 59, 1,  1, 5, 64, 4, 61, 0, 82, 7, 62, 2,  2
  };
  const int q6949[] = {
    9, 9, // Number of jobs and machines
    5, 22, 4, 46, 0,  1, 1, 46, 6, 56, 2, 42, 8,  7, 3, 51, 7, 40, 
    8, 69, 5, 77, 3,  8, 6, 21, 7, 74, 0,  4, 1, 28, 4, 55, 2, 63, 
    5, 16, 7, 77, 1, 69, 6, 92, 4,  2, 3, 69, 0,  5, 8, 38, 2, 50, 
    8, 74, 1,  7, 4, 42, 3, 14, 0, 60, 5, 49, 6, 14, 7, 10, 2, 89, 
    8, 74, 4, 51, 3, 67, 2, 19, 7, 18, 5, 98, 6, 86, 0, 33, 1, 59, 
    2, 53, 3, 43, 1, 30, 6, 53, 5, 47, 0, 71, 7, 56, 8, 41, 4, 53, 
    1,  5, 5, 39, 4, 77, 2, 33, 0, 16, 3, 23, 8, 13, 6, 36, 7,  3, 
    8, 97, 1, 16, 5,  1, 7, 25, 6, 97, 0, 18, 4, 61, 2, 67, 3, 41, 
    2, 67, 1, 88, 3, 72, 4, 86, 5, 94, 6, 74, 8, 16, 7, 56, 0, 81
  };
  const int q6950[] = {
    9, 9, // Number of jobs and machines
    1,  6, 5, 32, 3, 89, 6, 98, 2, 40, 4, 94, 8, 75, 0, 52, 7,  4, 
    5, 10, 1,  7, 7, 64, 4, 38, 0, 61, 2, 52, 3, 38, 6, 98, 8, 27, 
    0,  7, 2, 82, 3,  7, 4, 72, 5, 22, 7, 70, 8, 65, 6, 59, 1, 32, 
    6, 96, 4, 55, 5, 36, 1, 33, 7, 85, 2, 72, 8, 42, 0, 57, 3, 70, 
    7,  4, 8, 22, 2, 27, 4, 19, 1, 66, 3, 91, 5, 21, 0,  9, 6, 47, 
    1,  9, 8, 52, 0, 81, 2,  5, 7, 24, 3, 47, 6, 85, 4, 47, 5, 41, 
    7, 54, 1, 49, 5, 91, 4, 52, 8, 59, 6,  3, 2, 32, 0, 91, 3, 55, 
    3, 91, 8, 75, 5, 85, 1,  8, 7, 46, 0, 17, 6, 31, 4, 93, 2, 71, 
    8,  3, 1, 39, 7, 85, 6, 29, 3, 65, 2, 24, 5,  5, 4,  6, 0, 55
  };
  const int q6951[] = {
    9, 9, // Number of jobs and machines
    6, 24, 7, 65, 4, 64, 1, 71, 5, 98, 0, 26, 8, 34, 2, 50, 3, 22, 
    1, 25, 4, 22, 8, 78, 5, 67, 3, 42, 2,  2, 6, 41, 7, 64, 0, 34, 
    6, 42, 0, 17, 8, 19, 7,  6, 4, 79, 5, 21, 1, 94, 3, 86, 2, 30, 
    5, 26, 2, 68, 6, 54, 4, 81, 7, 11, 3, 88, 0, 18, 8, 43, 1,  4, 
    2, 49, 4,  8, 6, 25, 1, 78, 7, 42, 0, 53, 3, 51, 5, 20, 8, 23, 
    6, 71, 3, 81, 4, 91, 1, 69, 7, 39, 2, 81, 8, 55, 5, 67, 0, 58, 
    1, 75, 8, 19, 2, 81, 5, 73, 0, 71, 6, 54, 4, 60, 7, 39, 3, 71, 
    3, 77, 1, 45, 5, 78, 0, 14, 7, 68, 6, 61, 2, 96, 8,  4, 4, 70, 
    0, 82, 7, 90, 2, 14, 5, 86, 1, 53, 3,  6, 4, 34, 8, 17, 6, 26
  };
  const int q6952[] = {
    9, 9, // Number of jobs and machines
    5, 96, 1, 49, 4, 93, 2, 67, 6, 10, 8, 12, 3, 43, 7, 45, 0, 59, 
    1, 50, 8,  1, 3, 37, 5, 93, 7,  1, 0, 92, 6, 94, 4,  5, 2, 86, 
    7, 60, 5, 10, 4, 54, 2,  5, 8, 80, 6, 62, 1, 41, 0, 46, 3, 33, 
    3, 66, 0, 80, 8, 31, 5, 94, 7, 41, 6, 41, 1, 35, 2, 82, 4, 70, 
    4, 95, 0,  3, 8, 84, 6, 42, 7, 85, 3, 38, 2, 29, 1, 34, 5, 36, 
    4, 93, 5, 17, 2, 29, 8, 44, 1, 50, 0, 56, 7, 72, 3, 82, 6, 29, 
    5, 97, 1, 85, 6, 79, 7,  7, 8,  1, 4, 88, 2, 59, 0, 68, 3, 95, 
    2,  4, 5, 64, 7, 92, 4, 24, 1, 92, 6, 64, 8, 62, 3, 42, 0, 55, 
    3, 77, 8, 54, 5, 88, 2, 42, 6, 27, 0, 54, 1, 94, 7, 45, 4, 42
  };
  const int q6953[] = {
    9, 9, // Number of jobs and machines
    4, 61, 3, 25, 8, 54, 0, 82, 5, 45, 6, 24, 1, 36, 2, 80, 7, 75, 
    7, 53, 3, 35, 6, 51, 2, 82, 0, 69, 5, 75, 1, 35, 4, 85, 8, 63, 
    4,  2, 5, 20, 0, 90, 2, 47, 3, 16, 7, 78, 1, 60, 6, 80, 8, 91, 
    6, 94, 3,  8, 1, 86, 2, 95, 8,  7, 7, 15, 4, 82, 5, 57, 0,  3, 
    5, 54, 1, 92, 0, 35, 3, 98, 6, 93, 7, 58, 8, 99, 2, 40, 4, 60, 
    8, 12, 5, 37, 6, 46, 3, 53, 0, 21, 2, 77, 7, 36, 4, 50, 1, 57, 
    7, 48, 1, 15, 6, 40, 8, 49, 0,  8, 4, 68, 5, 40, 2, 80, 3, 44, 
    8, 83, 4, 57, 1, 20, 6, 53, 3, 78, 7, 43, 0, 17, 5, 26, 2,  3, 
    1, 70, 8, 91, 3, 76, 2, 54, 4, 35, 7, 70, 6, 11, 5, 20, 0, 77
  };
  const int q6954[] = {
    9, 9, // Number of jobs and machines
    3, 65, 2, 39, 7, 93, 0, 68, 5, 75, 8, 20, 6, 56, 1, 70, 4, 86, 
    2, 94, 6, 84, 1, 76, 5,  3, 3, 83, 4, 69, 0, 42, 7, 19, 8, 82, 
    2, 47, 5, 56, 3, 94, 6, 59, 0, 78, 4, 42, 1, 85, 7,  8, 8, 55, 
    1, 56, 8, 27, 0, 62, 6, 59, 5,  5, 4, 83, 3, 22, 2, 53, 7, 81, 
    4, 34, 5,  7, 7,  9, 8, 48, 3, 60, 6, 87, 0, 91, 2, 93, 1, 53, 
    2, 25, 0,  3, 6, 68, 7, 24, 5, 35, 8, 15, 4, 48, 3, 69, 1, 34, 
    2, 97, 6, 97, 8,  8, 4, 29, 3, 94, 1, 70, 0, 11, 7, 38, 5, 47, 
    7, 42, 6, 98, 0, 48, 2,  8, 5,  9, 8, 73, 4, 72, 1, 66, 3, 49, 
    2, 78, 1, 15, 5, 23, 8, 59, 3, 56, 4, 11, 7, 18, 0, 29, 6, 49
  };
  const int q6955[] = {
    9, 9, // Number of jobs and machines
    1, 15, 4, 14, 2, 68, 7, 73, 6, 38, 0, 54, 3, 73, 8, 48, 5, 74, 
    5, 89, 2, 77, 4, 81, 7, 54, 3, 15, 8, 94, 1, 78, 0, 78, 6, 63, 
    2, 22, 4, 88, 3, 68, 6, 19, 5, 97, 8, 64, 0, 61, 7, 62, 1,  8, 
    8, 80, 0, 88, 7, 88, 6, 28, 5, 84, 4, 88, 1,  6, 2, 87, 3, 75, 
    2, 56, 7, 94, 8, 59, 6, 55, 0, 65, 3, 35, 1,  5, 4, 90, 5, 65, 
    1, 42, 2, 32, 8, 26, 3, 25, 4, 26, 0, 12, 6, 72, 7, 49, 5, 84, 
    3, 22, 5, 18, 8, 41, 7, 96, 2, 36, 4, 89, 1, 39, 0, 79, 6, 67, 
    4, 85, 3, 54, 2, 16, 1, 91, 5, 60, 7, 31, 0, 58, 8, 40, 6, 11, 
    0, 50, 6, 44, 5, 22, 1,  7, 8, 25, 4, 92, 3,  4, 7, 66, 2, 99
  };
  const int q6956[] = {
    9, 9, // Number of jobs and machines
    1, 69, 5, 26, 2, 52, 7, 94, 4, 61, 6, 11, 3, 67, 8, 96, 0,  1, 
    1, 36, 0, 70, 3, 53, 4, 82, 5, 54, 6,  1, 8, 31, 7, 37, 2, 19, 
    1, 69, 3, 60, 6, 87, 7, 54, 4, 97, 2, 65, 8, 61, 5,  6, 0, 89, 
    6, 56, 5, 59, 1, 81, 3,  8, 0, 88, 8, 16, 2, 50, 4, 12, 7, 62, 
    5, 81, 0, 60, 1, 56, 3, 35, 7, 78, 6, 45, 4, 88, 8, 77, 2, 95, 
    6, 30, 2, 15, 0, 57, 1, 71, 3, 27, 8, 52, 5, 67, 4, 95, 7, 60, 
    6, 42, 7, 68, 8, 12, 1, 34, 5, 55, 4, 55, 0, 23, 2, 91, 3, 42, 
    2, 22, 0, 11, 6,  7, 3, 36, 4, 80, 8, 76, 1, 58, 5, 48, 7, 52, 
    2, 90, 7, 97, 5,  4, 4, 88, 3, 22, 6, 63, 1, 45, 8,  9, 0, 41
  };
  const int q6957[] = {
    9, 9, // Number of jobs and machines
    4, 19, 3, 94, 7, 72, 6,  5, 2, 23, 5, 14, 0, 32, 8, 36, 1, 11, 
    4, 11, 7, 78, 1,  1, 6, 35, 8, 40, 5, 37, 3, 31, 0, 42, 2, 76, 
    2, 53, 8, 75, 6, 57, 7, 46, 0, 47, 1, 53, 4, 62, 3, 61, 5, 47, 
    2, 96, 0, 69, 3, 89, 8, 90, 1, 96, 5, 69, 4, 38, 7, 54, 6, 82, 
    8,  3, 4, 69, 7, 69, 3, 83, 6,  8, 0, 17, 5,  2, 1, 33, 2, 10, 
    4, 90, 6, 64, 5, 45, 8, 41, 0, 12, 3, 18, 1, 86, 7, 79, 2, 44, 
    8, 51, 5, 63, 4,  6, 2, 82, 3, 13, 6, 58, 1, 62, 7, 92, 0,  5, 
    2, 59, 8, 85, 6, 53, 7, 21, 0, 44, 4,  8, 5, 82, 1, 64, 3, 23, 
    1, 90, 0, 25, 7, 90, 2, 36, 3, 19, 8, 18, 6, 91, 5, 59, 4, 15
  };
  const int q6958[] = {
    9, 9, // Number of jobs and machines
    2, 32, 5, 29, 7, 60, 0, 49, 6, 74, 3, 79, 8, 25, 4, 51, 1, 19, 
    8, 32, 0, 41, 5, 25, 4, 15, 1, 20, 2, 85, 3, 44, 7, 36, 6, 72, 
    7, 42, 2, 79, 3, 68, 0, 69, 4, 39, 1, 62, 5, 96, 8, 29, 6, 58, 
    5, 19, 7, 34, 3, 99, 1, 14, 2, 78, 4, 69, 6, 95, 8, 81, 0, 55, 
    6, 29, 8, 76, 5, 53, 1, 98, 2, 90, 0, 35, 7, 47, 4, 73, 3,  4, 
    7, 90, 2, 76, 3, 77, 0, 63, 6, 47, 8, 73, 4, 92, 1, 85, 5, 79, 
    5,  6, 4, 13, 1, 15, 3,  3, 6,  1, 2, 59, 8, 97, 0, 87, 7,  3, 
    7, 24, 3, 48, 1, 61, 6, 10, 0, 57, 2, 98, 5, 14, 8, 24, 4, 12, 
    6, 53, 1, 56, 7, 34, 2, 40, 4, 74, 5, 61, 3, 34, 0, 10, 8, 19
  };
  const int q6959[] = {
    9, 9, // Number of jobs and machines
    4, 22, 2, 22, 7, 56, 1, 53, 8, 72, 3, 59, 0, 83, 5, 20, 6, 73, 
    6, 92, 2, 59, 8, 23, 1, 36, 3, 34, 5, 50, 4, 62, 7, 49, 0, 22, 
    8, 40, 6, 81, 7, 48, 1, 81, 3, 58, 2, 70, 0, 52, 4, 78, 5, 42, 
    2, 90, 8, 62, 1, 76, 0, 57, 6, 71, 7, 72, 4, 10, 3, 59, 5, 23, 
    5, 73, 2, 73, 0, 33, 6,  5, 3, 78, 7, 86, 8, 99, 4, 79, 1, 29, 
    3, 27, 7, 21, 4, 89, 5,  7, 0, 94, 8, 83, 6,  4, 2, 94, 1, 81, 
    6, 37, 4, 11, 2, 81, 1, 54, 3, 54, 5,  2, 8, 77, 0, 92, 7, 37, 
    0, 84, 5, 22, 1, 58, 7, 58, 6, 59, 8,  3, 2, 72, 4, 20, 3, 80, 
    7, 96, 1, 86, 4, 86, 0,  1, 6, 71, 8,  5, 5, 47, 2, 52, 3, 14
  };
  const int q6960[] = {
    9, 9, // Number of jobs and machines
    4, 59, 0, 81, 5, 75, 6, 60, 7, 16, 2, 71, 1, 83, 3, 86, 8, 70, 
    6, 75, 8, 68, 7,  3, 2, 90, 4, 89, 5, 43, 1, 51, 0, 41, 3, 26, 
    2, 77, 5, 95, 0, 39, 3, 94, 7, 71, 6, 25, 8, 83, 4, 66, 1, 93, 
    6, 86, 7, 43, 1, 69, 3, 34, 4, 42, 8, 61, 2, 40, 5, 21, 0, 30, 
    0,  9, 2,  7, 1, 94, 3, 38, 7, 47, 6, 46, 4,  5, 8,  8, 5, 92, 
    4, 63, 3, 90, 2, 26, 1, 53, 7,  6, 0, 53, 8, 51, 5, 62, 6, 29, 
    6, 87, 4, 83, 5, 28, 7,  6, 2, 37, 8, 86, 0, 82, 3, 99, 1, 24, 
    3, 80, 2, 98, 8, 78, 1, 88, 4, 34, 0, 89, 6, 47, 5, 83, 7, 57, 
    2, 42, 4, 95, 5, 85, 7, 35, 1, 51, 3, 39, 8, 26, 0, 91, 6, 24
  };
  const int q6961[] = {
    9, 9, // Number of jobs and machines
    8, 26, 6, 63, 1, 76, 3, 73, 7, 36, 5, 24, 2, 55, 0, 83, 4, 95, 
    1, 33, 3, 49, 8, 10, 2, 97, 5, 27, 0, 96, 7, 76, 6, 50, 4, 54, 
    3, 48, 0, 18, 8,  2, 5, 51, 7, 43, 6, 67, 4, 66, 1, 18, 2,  9, 
    5, 66, 7, 69, 8, 53, 0, 67, 4, 91, 3, 20, 2, 51, 1, 87, 6, 54, 
    0, 91, 5, 79, 6, 54, 1, 71, 7, 70, 4, 49, 3, 97, 2, 59, 8, 69, 
    8, 53, 7, 72, 4, 85, 3, 50, 0, 75, 2, 27, 6, 92, 5, 58, 1, 29, 
    2, 96, 6, 78, 0, 84, 3, 69, 5, 39, 1, 65, 8, 40, 7, 61, 4, 81, 
    8, 61, 6, 35, 4, 85, 0, 94, 3, 15, 5, 90, 1,  2, 2, 92, 7, 59, 
    0, 61, 2, 43, 7, 75, 1, 99, 6, 87, 5,  6, 8, 20, 4, 51, 3,  3
  };
  const int q6962[] = {
    9, 9, // Number of jobs and machines
    1, 29, 5, 41, 4, 37, 2, 91, 7, 49, 6, 13, 3, 64, 8, 99, 0, 25, 
    1,  9, 8, 77, 3, 37, 2, 76, 7, 73, 6, 16, 5, 46, 0, 45, 4,  9, 
    0, 73, 5, 58, 6, 44, 4, 98, 3, 59, 1, 89, 8, 13, 2, 69, 7, 18, 
    2, 33, 4, 77, 8, 32, 7, 74, 0, 13, 5, 53, 3, 28, 1, 67, 6, 42, 
    4,  8, 3, 96, 7, 50, 2, 57, 6,  5, 0, 35, 5, 96, 1, 48, 8, 27, 
    0, 62, 7, 97, 4, 36, 3, 39, 8,  1, 2, 11, 1, 22, 6, 30, 5, 81, 
    6, 50, 1, 21, 3,  2, 4, 65, 0, 83, 8,  5, 5, 73, 2, 18, 7, 13, 
    4, 65, 7, 67, 5, 23, 6, 27, 1, 20, 3, 13, 2, 49, 0, 54, 8, 53, 
    4, 39, 7, 70, 5, 16, 8, 22, 6, 22, 0, 27, 3, 58, 2, 38, 1, 96
  };
  const int q6963[] = {
    9, 9, // Number of jobs and machines
    0, 48, 1, 35, 4, 45, 7, 90, 6, 87, 3, 98, 2, 25, 8,  9, 5, 54, 
    4,  4, 8, 57, 0, 45, 5, 93, 6, 21, 1, 31, 7, 36, 3, 71, 2, 16, 
    0, 32, 2, 51, 5, 27, 7, 14, 3, 12, 6, 93, 4, 30, 1, 40, 8, 65, 
    0, 50, 6, 96, 7,  9, 8, 92, 4, 53, 2, 50, 1, 88, 3, 53, 5, 81, 
    8, 51, 6, 52, 2, 79, 3, 68, 0, 21, 4, 98, 7,  5, 1, 58, 5, 67, 
    2, 48, 3, 44, 0, 78, 1, 67, 6, 98, 4, 20, 8, 50, 7,  2, 5, 14, 
    5, 76, 8, 16, 4, 17, 6, 77, 0, 28, 1, 21, 2, 84, 7, 18, 3, 20, 
    1,  4, 4, 84, 5, 47, 0, 32, 7, 60, 8, 93, 6, 47, 2, 60, 3, 16, 
    1, 39, 5, 22, 2, 33, 7, 87, 6,  7, 3, 22, 8, 10, 0, 12, 4, 45
  };
  const int q6964[] = {
    9, 9, // Number of jobs and machines
    7, 46, 2, 41, 8, 87, 5, 22, 0, 11, 4, 61, 6, 24, 1, 29, 3, 22, 
    5, 48, 1, 22, 7, 14, 4, 51, 8,  3, 6, 62, 0, 23, 3,  1, 2, 10, 
    5, 56, 2, 57, 4, 71, 1, 81, 7, 24, 8, 62, 0, 10, 6, 65, 3, 70, 
    5, 13, 6, 68, 8, 98, 2, 60, 7, 61, 3, 77, 4, 37, 1, 52, 0,  9, 
    7, 43, 4, 27, 6, 64, 3, 76, 0, 95, 1, 25, 2, 85, 5, 77, 8, 88, 
    3, 65, 7, 14, 0, 79, 8, 59, 6, 47, 5, 25, 2,  2, 4, 65, 1, 29, 
    0, 55, 6,  8, 3, 44, 1, 48, 7, 52, 4, 25, 2, 33, 8, 19, 5, 18, 
    4, 29, 5, 52, 8, 23, 3, 98, 2, 48, 7, 48, 1,  6, 0, 64, 6, 29, 
    0,  7, 2, 90, 7, 71, 5, 61, 6, 78, 8, 99, 4, 45, 1, 21, 3, 41
  };
  const int q6965[] = {
    9, 9, // Number of jobs and machines
    3, 30, 4, 49, 0, 99, 1, 82, 7, 91, 6, 88, 2, 98, 8, 86, 5, 77, 
    7, 80, 0, 52, 6, 98, 2, 34, 5, 82, 3, 86, 1, 12, 8, 98, 4, 80, 
    5,  5, 8, 53, 2, 66, 7, 88, 4, 43, 3, 50, 1, 38, 0, 60, 6, 65, 
    7, 57, 2, 14, 1, 56, 6, 18, 0, 92, 8, 35, 4,  6, 5, 57, 3, 32, 
    2, 66, 4, 52, 0, 94, 6, 32, 7, 41, 8, 87, 5, 76, 3, 91, 1,  7, 
    3, 12, 4, 43, 0, 17, 5, 15, 7, 80, 6, 40, 1, 78, 2,  4, 8, 85, 
    4,  8, 0, 80, 1, 10, 3,  3, 2, 63, 8, 44, 5,  9, 6, 22, 7, 70, 
    5, 72, 0, 46, 3, 32, 2, 81, 6, 42, 4, 22, 8, 11, 1, 31, 7, 96, 
    1,  1, 3, 94, 2, 92, 0, 45, 7, 23, 6, 60, 8, 81, 5, 66, 4, 70
  };
  const int q6966[] = {
    9, 9, // Number of jobs and machines
    5, 75, 0, 80, 1, 55, 2, 97, 6, 70, 7,  6, 8, 25, 4, 34, 3, 37, 
    6, 83, 5, 55, 4, 44, 2, 67, 0, 96, 1,  7, 7, 98, 8, 27, 3, 15, 
    3, 87, 6, 69, 8, 72, 5, 27, 1, 37, 4, 30, 7, 30, 2,  7, 0, 79, 
    0, 74, 4,  1, 1, 44, 2, 19, 6, 50, 3, 35, 8, 18, 5, 44, 7, 75, 
    8,  8, 3, 31, 0, 39, 2, 47, 1, 13, 4, 41, 5, 62, 7, 96, 6, 19, 
    0, 46, 8, 76, 2, 44, 7, 53, 5, 26, 1, 87, 6, 57, 4,  5, 3, 10, 
    7, 91, 8, 34, 2,  8, 3, 88, 6, 94, 1,  5, 0, 50, 5, 17, 4, 12, 
    1, 59, 6, 14, 5, 12, 0, 45, 8, 73, 7, 73, 2, 53, 4, 86, 3, 48, 
    6, 97, 0, 15, 3, 59, 2,  7, 4, 34, 5, 48, 7, 37, 8, 98, 1, 65
  };
  const int q6967[] = {
    9, 9, // Number of jobs and machines
    7, 91, 6, 73, 3, 99, 0,  2, 8, 94, 5, 40, 2, 83, 1, 12, 4, 68, 
    2, 67, 0, 82, 1, 74, 7,  6, 4, 94, 3, 87, 8, 93, 5,  8, 6, 59, 
    5, 12, 8, 47, 1, 77, 3, 79, 6, 17, 2, 69, 0, 81, 4, 68, 7, 37, 
    8, 84, 0,  3, 1, 92, 2, 50, 5, 84, 4, 25, 7, 32, 6, 40, 3, 91, 
    6, 47, 1, 29, 3, 26, 7, 61, 5, 40, 8, 94, 2, 32, 4, 59, 0, 94, 
    3, 85, 0, 39, 2, 76, 4, 58, 6, 59, 8, 82, 7, 81, 5, 43, 1, 18, 
    3, 92, 2, 82, 1, 78, 4, 89, 8, 50, 6, 76, 5, 33, 7, 47, 0, 78, 
    8, 85, 5, 10, 6, 68, 2, 32, 1, 75, 0, 61, 7, 56, 3, 61, 4, 88, 
    2, 51, 0, 93, 8, 49, 4, 20, 3, 61, 7, 45, 6,  5, 1,  2, 5, 13
  };
  const int q6968[] = {
    9, 9, // Number of jobs and machines
    2, 15, 4, 99, 5, 90, 1, 14, 6, 12, 8, 61, 0, 73, 7, 11, 3, 48, 
    5, 26, 0, 27, 1, 25, 7, 62, 6,  5, 4, 75, 2, 71, 3, 58, 8, 20, 
    8, 17, 1, 90, 7, 29, 5, 95, 4, 24, 0, 47, 6, 56, 3, 68, 2, 28, 
    1, 43, 3, 63, 4, 27, 5, 85, 7, 22, 0, 11, 8, 47, 2, 39, 6, 20, 
    1, 45, 4, 85, 7, 23, 0, 39, 8, 91, 5, 88, 2, 99, 3, 23, 6,  2, 
    8,  1, 2, 48, 1,  9, 0, 39, 3, 74, 5, 37, 6, 62, 7, 81, 4, 28, 
    7, 66, 2, 65, 4, 85, 0, 59, 8, 57, 6, 94, 1, 68, 5, 65, 3,  5, 
    2, 16, 5, 25, 7, 28, 1, 49, 4, 33, 3, 30, 8, 14, 6, 64, 0, 15, 
    7, 58, 4, 91, 8, 68, 6, 77, 2, 51, 0, 54, 3, 72, 1, 94, 5, 64
  };
  const int q6969[] = {
    9, 9, // Number of jobs and machines
    0, 38, 5, 22, 3, 18, 2, 13, 7, 62, 6, 37, 8, 87, 4, 11, 1, 74, 
    1, 41, 5, 48, 6, 67, 2, 82, 8, 23, 7, 29, 4, 54, 0, 69, 3, 95, 
    0, 51, 6, 84, 4, 69, 3, 95, 7, 24, 8, 70, 5, 53, 1, 42, 2, 59, 
    6, 50, 1, 42, 3, 66, 2, 94, 7, 34, 5, 73, 0,  6, 4, 61, 8, 82, 
    3, 88, 1, 44, 0, 15, 6, 85, 2, 71, 8, 54, 4, 31, 5, 40, 7, 66, 
    6, 25, 2, 24, 8, 63, 7, 34, 0,  3, 1, 37, 3, 89, 5, 44, 4, 57, 
    1, 92, 6, 17, 0, 68, 4, 49, 7, 31, 5, 17, 8, 35, 2,  6, 3, 71, 
    5, 86, 7, 59, 1,  7, 6,  1, 4, 19, 0, 94, 2, 10, 8, 71, 3, 91, 
    1, 52, 5, 82, 3, 18, 0, 45, 7, 35, 8, 67, 4, 40, 6, 72, 2, 77
  };
  const int q6970[] = {
    9, 9, // Number of jobs and machines
    5, 39, 4, 55, 8, 98, 0, 40, 1, 35, 3, 67, 7, 90, 2, 84, 6, 17, 
    6, 76, 5, 68, 4, 40, 8, 96, 1,  2, 0, 53, 7, 94, 3, 17, 2, 88, 
    2, 71, 5, 20, 4, 40, 1, 79, 6, 35, 7, 12, 3, 66, 0, 37, 8, 17, 
    7, 57, 4, 23, 3,  6, 8, 76, 6, 76, 0, 20, 2, 65, 5, 99, 1, 49, 
    4, 18, 6, 15, 2, 62, 3, 92, 1, 74, 0, 11, 5, 32, 7, 89, 8, 83, 
    5, 63, 8, 72, 3, 13, 6, 53, 2, 71, 4, 78, 1, 38, 7, 54, 0, 14, 
    0, 17, 6, 59, 3, 46, 4, 96, 5, 22, 2, 29, 8, 94, 7, 46, 1, 49, 
    4, 44, 7, 84, 2, 30, 8,  7, 6, 85, 0, 83, 3, 35, 1, 47, 5, 99, 
    4, 27, 1, 69, 7, 37, 3, 67, 5, 47, 8, 48, 2, 53, 6, 14, 0, 23
  };
  const int q6971[] = {
    9, 9, // Number of jobs and machines
    0, 74, 8, 39, 4, 52, 1,  5, 6, 34, 5, 30, 3, 59, 2, 93, 7, 28, 
    4, 24, 3, 76, 2, 36, 1, 95, 7, 33, 5, 68, 8, 90, 0, 63, 6, 75, 
    6, 71, 8, 43, 4, 71, 7, 94, 1,  9, 3, 71, 5, 26, 0, 29, 2, 99, 
    5, 90, 4, 63, 3, 42, 0, 16, 7, 77, 8, 70, 2, 65, 1, 66, 6, 86, 
    6, 59, 7, 30, 5, 56, 3, 83, 0, 79, 4, 90, 1, 93, 8, 30, 2, 11, 
    8, 86, 0, 67, 3, 52, 6, 42, 5, 68, 7, 76, 4, 40, 1, 97, 2, 48, 
    4, 86, 6, 82, 7, 90, 5, 90, 1, 20, 0,  6, 8,  4, 3, 63, 2, 28, 
    1, 46, 0, 53, 2, 81, 5, 59, 6, 34, 3,  5, 8, 95, 4,  5, 7, 65, 
    4, 71, 6, 78, 8, 91, 7, 21, 5, 21, 0, 44, 1, 87, 2, 71, 3, 97
  };
  const int q6972[] = {
    9, 9, // Number of jobs and machines
    8, 61, 1, 85, 0, 98, 3, 61, 4,  6, 2, 85, 6, 97, 7, 52, 5, 57, 
    8, 17, 2, 32, 0, 59, 3, 98, 4,  1, 5, 97, 1, 19, 6, 47, 7, 16, 
    5,  7, 2, 21, 8, 88, 3, 78, 0, 71, 6, 98, 7, 43, 4, 86, 1, 88, 
    5, 45, 6, 92, 2, 56, 0, 73, 4, 19, 1, 62, 7,  3, 8, 62, 3, 97, 
    2, 81, 0, 60, 3, 57, 4, 11, 6, 26, 1, 52, 7, 69, 5, 70, 8, 16, 
    8, 42, 3, 63, 6, 51, 7, 97, 0, 72, 2, 17, 4, 81, 1, 45, 5, 56, 
    6, 54, 4, 53, 7, 34, 8, 91, 5, 34, 3, 33, 1, 66, 0, 36, 2, 77, 
    2, 16, 7, 30, 8, 85, 4, 90, 5,  2, 6, 43, 1,  7, 3, 22, 0, 35, 
    3, 89, 8,  6, 6,  6, 0, 40, 2, 27, 7, 34, 1,  8, 5, 45, 4, 28
  };
  const int q6973[] = {
    9, 9, // Number of jobs and machines
    1, 12, 6,  7, 2, 36, 8, 76, 0, 68, 7, 63, 5, 69, 3, 50, 4,  1, 
    3, 65, 4, 47, 6, 99, 8, 65, 0, 95, 1, 74, 5, 79, 7, 82, 2, 23, 
    6, 13, 8, 30, 2, 69, 3, 46, 4, 81, 1, 57, 5, 78, 7, 44, 0, 56, 
    2, 57, 0, 92, 4,  5, 5, 37, 8, 95, 1, 11, 7, 86, 3, 26, 6,  2, 
    8, 21, 6, 62, 7, 24, 2, 71, 1, 98, 3,  3, 0, 72, 5,  3, 4, 12, 
    0, 57, 3,  4, 2, 95, 1, 57, 6, 78, 8,  6, 5, 14, 4, 83, 7, 66, 
    4, 96, 1, 81, 0, 98, 7, 12, 3,  4, 6, 60, 5, 20, 2, 10, 8, 10, 
    2, 96, 8, 86, 7, 96, 0, 66, 4, 39, 5, 23, 6, 52, 1, 95, 3, 78, 
    2, 45, 3, 51, 1, 17, 7, 12, 0, 54, 4, 20, 6, 77, 8, 43, 5, 32
  };
  const int q6974[] = {
    9, 9, // Number of jobs and machines
    1, 63, 2, 49, 8, 34, 3, 63, 4, 45, 7, 50, 6, 98, 0, 10, 5, 35, 
    0, 50, 5,  8, 4, 47, 1,  1, 3, 75, 6, 47, 2, 19, 7, 93, 8, 89, 
    1, 21, 8, 75, 2,  9, 6,  9, 7, 86, 3,  6, 5, 45, 0, 72, 4, 34, 
    1, 13, 8, 72, 4, 74, 3, 21, 6, 60, 2, 11, 7,  1, 5, 67, 0,  1, 
    1, 25, 8, 89, 0, 85, 6, 36, 3, 82, 2, 89, 7, 47, 5, 56, 4, 90, 
    6, 93, 5, 19, 0, 13, 7, 53, 8, 85, 4,  1, 1, 91, 2, 14, 3, 41, 
    4, 28, 6, 41, 0, 97, 5, 17, 1, 86, 8, 98, 2, 42, 3, 39, 7, 57, 
    4, 44, 5, 39, 3, 79, 2, 53, 7,  3, 0, 80, 1, 97, 8, 36, 6, 17, 
    7, 10, 0, 70, 6, 71, 2, 67, 4, 36, 1, 84, 8, 46, 3, 66, 5, 73
  };
  const int q6975[] = {
    9, 9, // Number of jobs and machines
    6, 65, 3, 51, 8, 82, 1, 21, 7, 27, 0, 83, 5, 61, 4, 31, 2, 41, 
    1, 46, 0, 40, 4,  5, 3, 21, 8, 62, 2,  7, 5, 97, 7, 49, 6, 54, 
    5, 28, 0, 41, 6, 35, 2, 25, 4, 33, 1, 21, 7, 96, 3, 86, 8, 84, 
    1, 16, 2, 27, 8, 58, 6, 17, 5, 68, 3, 44, 0,  5, 7, 84, 4, 31, 
    0, 76, 5, 64, 1,  2, 7, 42, 4, 22, 3, 46, 6, 15, 8, 74, 2, 67, 
    5, 44, 8, 88, 0, 95, 6,  4, 3, 80, 4, 64, 7, 58, 2, 24, 1, 79, 
    5, 30, 2, 19, 1, 98, 6, 15, 4, 46, 3, 78, 0, 28, 8,  2, 7, 42, 
    7, 84, 2, 81, 1,  8, 6, 52, 8,  3, 5, 91, 0, 28, 3, 29, 4,  5, 
    3, 21, 8, 48, 2, 78, 5, 15, 0, 23, 1,  9, 7, 85, 6, 38, 4, 62
  };
  const int q6976[] = {
    9, 9, // Number of jobs and machines
    6, 44, 8, 16, 1, 87, 5, 54, 4, 78, 2, 34, 7, 60, 3, 94, 0, 73, 
    0, 31, 8, 34, 7, 55, 5, 42, 4, 61, 2, 92, 3, 67, 6, 53, 1,  1, 
    3, 99, 7, 33, 6, 60, 4, 58, 2, 15, 0, 85, 5, 64, 1, 86, 8, 42, 
    6, 82, 2, 66, 8, 50, 4, 71, 0, 34, 3,  4, 1, 70, 5, 71, 7, 32, 
    3, 64, 2, 20, 7, 30, 1, 63, 4, 99, 8, 76, 5, 66, 0,  2, 6, 39, 
    4, 21, 6, 52, 7, 63, 8, 55, 0, 46, 5, 93, 3, 35, 2, 23, 1, 67, 
    1, 35, 5, 52, 0, 92, 4, 10, 3, 62, 7, 10, 8, 97, 2, 97, 6, 78, 
    7, 95, 3, 95, 6,  3, 0, 17, 1, 70, 4, 98, 8, 66, 2, 83, 5, 97, 
    4, 28, 7, 28, 8, 19, 0, 45, 1, 32, 5, 72, 3, 33, 2, 72, 6, 33
  };
  const int q6977[] = {
    9, 9, // Number of jobs and machines
    4, 36, 7, 31, 5, 63, 0, 74, 2, 37, 3, 40, 1, 16, 8, 66, 6, 63, 
    3, 28, 8, 74, 2, 31, 6,  7, 5, 24, 7, 35, 1, 28, 0, 62, 4, 62, 
    8, 76, 5, 35, 4, 21, 1, 28, 3, 97, 2, 69, 7, 76, 0, 61, 6, 76, 
    8,  8, 7, 70, 1, 36, 2, 54, 0, 22, 4,  5, 5, 31, 6,  5, 3, 59, 
    3, 18, 5, 30, 1, 10, 2, 35, 0, 59, 7, 12, 6, 85, 4,  5, 8, 36, 
    7, 74, 0, 96, 4, 87, 8, 30, 5, 29, 3, 41, 1, 23, 2, 69, 6, 12, 
    7,  9, 5, 36, 2, 46, 6, 46, 8, 54, 0, 54, 1, 12, 3,  5, 4, 70, 
    4, 30, 8,  9, 0,  1, 2, 17, 7, 91, 5, 51, 3, 20, 6, 49, 1, 34, 
    1, 31, 2, 75, 7,  3, 4, 10, 5, 63, 3, 52, 0, 31, 8, 38, 6, 62
  };
  const int q6978[] = {
    9, 9, // Number of jobs and machines
    6, 17, 1, 98, 5, 83, 2, 20, 3, 43, 8, 65, 0, 56, 4, 18, 7, 22, 
    0, 23, 6, 37, 5, 36, 4, 83, 8, 17, 1, 55, 7, 82, 2, 77, 3, 49, 
    3, 34, 2, 14, 4, 65, 6, 40, 5, 17, 7, 21, 0, 46, 8, 57, 1, 50, 
    0, 42, 1, 68, 7, 50, 4, 50, 6, 14, 8, 47, 3, 44, 2, 53, 5, 48, 
    1, 30, 4, 21, 6, 10, 3, 97, 0, 38, 5, 58, 2, 41, 7, 15, 8, 77, 
    0, 58, 1, 10, 3,  9, 5, 67, 7, 83, 4, 72, 2, 21, 8,  3, 6, 20, 
    6,  3, 8, 78, 1, 51, 5, 23, 7, 24, 0, 65, 4, 29, 3, 23, 2, 20, 
    1, 98, 7, 36, 6,  5, 2, 69, 8, 37, 3, 89, 5, 25, 0, 44, 4, 66, 
    1, 86, 3, 83, 5, 21, 4, 24, 6, 67, 7, 42, 8, 18, 0, 70, 2, 10
  };
  const int q6979[] = {
    9, 9, // Number of jobs and machines
    5, 31, 7, 78, 1, 37, 8, 64, 0, 94, 4, 70, 6, 12, 3,  6, 2, 55, 
    2, 52, 5, 77, 3, 28, 0, 86, 8, 29, 7,  3, 1, 73, 4, 60, 6, 59, 
    6, 95, 8, 15, 3, 31, 2, 46, 7, 66, 5, 17, 1, 29, 0, 24, 4, 92, 
    8, 19, 6, 25, 0, 94, 4, 14, 1, 77, 7, 73, 3, 34, 5, 45, 2, 82, 
    3, 65, 7,  5, 8, 55, 6, 36, 1, 22, 0, 25, 2, 49, 4, 47, 5, 32, 
    0, 21, 4, 19, 6, 21, 2, 32, 7, 33, 5, 89, 3, 43, 1, 20, 8, 20, 
    2, 52, 8, 31, 0,  5, 3, 92, 5, 24, 7, 40, 4, 31, 6, 94, 1, 15, 
    7, 81, 6, 65, 8, 82, 3, 59, 4, 48, 0, 90, 2, 25, 5, 43, 1, 95, 
    6,  6, 4, 44, 7, 18, 1, 67, 8, 27, 3, 97, 5, 26, 0, 12, 2, 30
  };
  const int q6980[] = {
    9, 9, // Number of jobs and machines
    3, 51, 4, 96, 0, 42, 8, 32, 7, 42, 1,  5, 2, 81, 6, 41, 5, 34, 
    7, 37, 8, 14, 5, 49, 0, 59, 6, 36, 2, 87, 1, 43, 4, 34, 3, 51, 
    5, 67, 7, 56, 1, 64, 0, 54, 4, 59, 6, 71, 3, 78, 2, 47, 8, 35, 
    2, 44, 4, 80, 3, 44, 7, 61, 8,  6, 5,  5, 0, 18, 6, 61, 1, 21, 
    2, 75, 5, 52, 0, 53, 3, 93, 1, 62, 6, 73, 4, 59, 7, 38, 8, 54, 
    3, 57, 1, 21, 6, 82, 8, 29, 0, 57, 5, 94, 7, 76, 4, 98, 2, 59, 
    2, 28, 8, 65, 6, 25, 4, 39, 0,  7, 1, 32, 7,  6, 5, 22, 3, 13, 
    0, 72, 4, 65, 1, 86, 5,  5, 8, 27, 3, 85, 6, 25, 7, 36, 2, 87, 
    6, 75, 3, 36, 1, 87, 2, 91, 5, 84, 8, 63, 0, 72, 4, 39, 7, 13
  };
  const int q6981[] = {
    9, 9, // Number of jobs and machines
    1, 60, 8,  7, 2, 90, 6, 57, 5, 67, 4, 49, 7, 84, 3, 13, 0, 71, 
    1, 17, 3, 41, 6, 14, 4, 17, 7, 97, 2, 93, 8, 89, 5, 58, 0, 31, 
    5, 89, 3, 83, 8, 74, 4, 64, 6, 42, 2, 19, 0, 29, 1, 32, 7, 29, 
    3, 25, 6, 22, 7, 12, 1, 89, 5, 67, 8, 92, 0, 58, 4, 39, 2, 15, 
    6, 57, 4, 92, 5, 42, 8, 14, 3, 69, 2, 53, 0, 63, 7, 43, 1, 20, 
    8, 10, 0, 27, 4, 27, 2, 82, 1, 21, 7, 55, 6, 44, 3, 66, 5, 82, 
    8,  5, 5, 30, 6, 87, 0, 74, 3, 68, 2, 61, 4, 39, 1, 94, 7, 14, 
    1, 12, 3, 25, 5, 62, 6, 42, 8, 31, 7, 60, 2, 63, 4,  7, 0, 30, 
    2, 34, 0, 24, 7, 56, 1, 46, 5, 78, 3, 50, 6, 77, 8, 89, 4, 84
  };
  const int q6982[] = {
    9, 9, // Number of jobs and machines
    0, 28, 1, 21, 3, 85, 5,  1, 4, 52, 6, 62, 7, 43, 8, 82, 2, 30, 
    8, 72, 2, 46, 7, 58, 0, 94, 3, 88, 4, 92, 1, 88, 6, 14, 5, 75, 
    7, 10, 1, 13, 6, 64, 8, 72, 4,  3, 5, 35, 3, 83, 2, 27, 0, 60, 
    4, 84, 5, 25, 7, 62, 3, 16, 8, 96, 1, 36, 0, 22, 6, 12, 2, 64, 
    8, 54, 7,  2, 6, 65, 4, 75, 3, 89, 0, 62, 2, 56, 1, 19, 5, 33, 
    8, 66, 0, 63, 7, 67, 3, 70, 2, 48, 5, 34, 4, 27, 1, 26, 6, 67, 
    6, 78, 4, 54, 2, 35, 3, 72, 5, 99, 1,  6, 8, 43, 0, 91, 7, 72, 
    8, 41, 4, 92, 7, 79, 1, 43, 5, 70, 3, 43, 6, 26, 2, 88, 0,  8, 
    1,  8, 5, 57, 2, 26, 6,  9, 4, 48, 8, 14, 3, 63, 7,  2, 0, 30
  };
  const int q6983[] = {
    9, 9, // Number of jobs and machines
    2, 53, 0, 71, 4, 99, 5, 18, 8, 41, 1, 80, 7, 33, 3, 43, 6, 43, 
    4, 24, 0, 79, 3, 73, 8, 93, 7, 22, 1, 67, 5, 84, 2, 55, 6, 74, 
    1, 20, 5, 31, 0, 30, 7, 50, 4, 80, 8, 26, 2, 66, 3, 61, 6,  2, 
    0, 34, 3, 67, 2, 60, 6, 11, 1, 90, 5, 13, 8, 91, 7, 62, 4, 96, 
    5, 33, 4, 50, 6, 12, 8, 58, 0, 13, 2, 20, 1, 61, 7, 68, 3, 79, 
    7,  3, 8, 94, 2, 53, 6, 28, 4, 99, 3, 51, 0, 72, 1,  6, 5,  1, 
    5, 27, 6, 75, 8, 20, 0, 75, 7, 21, 2, 33, 1, 25, 3, 46, 4,  2, 
    4, 83, 3, 92, 0, 82, 1, 97, 2, 32, 7, 93, 6, 35, 5, 46, 8, 53, 
    5,  9, 6,  4, 2, 98, 7, 66, 1,  1, 8, 25, 0, 80, 3,  9, 4, 49
  };
  const int q6984[] = {
    9, 9, // Number of jobs and machines
    3, 32, 1, 22, 5, 64, 8, 93, 0, 62, 7, 13, 6, 11, 2, 21, 4, 23, 
    4, 33, 3, 95, 1, 88, 5, 36, 2, 69, 0, 48, 8, 76, 7, 89, 6, 22, 
    2, 10, 0, 17, 7,  5, 3, 64, 8, 43, 6,  2, 5, 19, 1, 46, 4, 42, 
    3, 95, 0, 16, 6, 60, 4, 59, 7, 44, 2, 56, 1, 89, 8, 84, 5, 28, 
    4, 33, 1, 59, 7, 78, 3, 55, 8, 15, 0, 91, 6, 34, 5, 41, 2, 44, 
    0, 43, 8, 33, 5, 27, 3, 67, 6, 85, 1, 77, 2, 10, 4, 81, 7, 71, 
    6, 62, 1, 94, 7, 85, 2, 38, 8, 85, 0, 59, 3, 56, 4, 40, 5, 67, 
    4,  6, 6, 36, 7, 54, 1, 45, 3,  2, 5, 13, 8, 79, 2, 46, 0, 80, 
    8, 80, 3, 93, 7, 38, 1, 98, 6, 56, 4, 13, 5, 75, 0, 95, 2, 68
  };
  const int q6985[] = {
    9, 9, // Number of jobs and machines
    6, 76, 5,  6, 1,  7, 3, 85, 7,  3, 0, 33, 4, 69, 8, 89, 2, 91, 
    5, 58, 6, 28, 3, 29, 4, 23, 8, 24, 0, 57, 7, 85, 2, 58, 1, 28, 
    4, 97, 2, 50, 1, 60, 8, 60, 3, 99, 5, 45, 6,  4, 7, 53, 0, 50, 
    6, 32, 1, 97, 8, 30, 4, 56, 2, 87, 0, 51, 3, 24, 7, 94, 5, 33, 
    4, 74, 3, 19, 7, 69, 1, 35, 0, 25, 6, 89, 8, 23, 5, 77, 2, 14, 
    8, 86, 5, 61, 7, 68, 6, 12, 0, 88, 1, 75, 3, 36, 4, 99, 2, 81, 
    2,  5, 5, 91, 8, 86, 6, 67, 0, 27, 7, 77, 1, 73, 4, 29, 3, 49, 
    1, 79, 5, 44, 8, 77, 7, 11, 4, 15, 2, 24, 0, 33, 6, 15, 3, 51, 
    2, 90, 5, 38, 7, 68, 0, 24, 3, 49, 6,  2, 8, 65, 4, 19, 1, 44
  };
  const int q6986[] = {
    9, 9, // Number of jobs and machines
    1, 67, 5, 98, 7, 72, 0,  1, 6, 89, 2, 73, 4, 35, 3, 92, 8, 12, 
    4, 46, 0, 68, 1, 24, 3, 12, 5, 63, 7, 67, 6, 25, 2, 33, 8, 30, 
    0, 41, 7, 31, 8, 84, 5, 47, 1, 69, 3, 84, 4, 60, 2, 79, 6, 49, 
    4, 79, 3, 71, 1, 57, 5, 80, 0, 51, 8, 70, 6,  2, 7, 15, 2, 66, 
    4, 91, 3, 81, 8, 43, 5, 12, 6, 23, 2, 16, 1, 33, 0, 53, 7, 69, 
    2, 62, 1, 86, 0, 19, 5, 69, 7, 59, 3, 25, 8, 82, 6, 57, 4, 41, 
    2, 76, 1, 37, 8, 13, 4, 73, 3, 23, 6, 14, 5, 25, 0, 72, 7, 61, 
    5, 92, 4, 68, 2, 39, 7, 42, 0, 33, 3, 77, 8,  6, 6, 28, 1, 53, 
    8, 91, 5, 14, 3, 15, 6, 34, 4, 52, 2, 19, 7, 24, 1, 73, 0, 52
  };
  const int q6987[] = {
    9, 9, // Number of jobs and machines
    3, 89, 5,  3, 2, 51, 4,  1, 0, 15, 8, 45, 6, 78, 7, 66, 1, 69, 
    2, 29, 8, 84, 6, 23, 3,  8, 1, 90, 5, 57, 4, 11, 0, 29, 7, 42, 
    1, 64, 3, 76, 5, 56, 7, 20, 4, 42, 2,  9, 6, 50, 8, 87, 0, 80, 
    7, 72, 3, 11, 8, 16, 0, 66, 4,  2, 6, 60, 1, 15, 2, 73, 5, 73, 
    4, 29, 8, 62, 5, 16, 2, 92, 0, 52, 7, 66, 1,  5, 3, 64, 6, 11, 
    7, 51, 0, 82, 4, 69, 5, 59, 3,  8, 8, 25, 2, 55, 1, 85, 6, 60, 
    0, 80, 2, 90, 3, 41, 4, 43, 7,  9, 6, 23, 8, 37, 5, 39, 1, 22, 
    7, 95, 2,  9, 8, 96, 1, 45, 3, 61, 6, 61, 0,  9, 4, 94, 5, 62, 
    2,  6, 1, 72, 8, 76, 0, 43, 4, 37, 6, 97, 5, 51, 7, 18, 3,  2
  };
  const int q6988[] = {
    9, 9, // Number of jobs and machines
    7, 16, 4, 51, 8, 74, 0, 26, 5, 35, 6, 50, 1, 39, 2, 85, 3, 10, 
    8, 85, 3, 62, 4, 66, 0, 12, 7, 20, 1, 46, 6, 74, 2,  2, 5, 70, 
    5, 85, 1, 62, 7, 36, 8, 72, 6, 19, 3, 55, 0, 99, 4, 79, 2, 50, 
    2, 21, 1, 34, 6, 49, 4, 80, 7, 26, 0, 53, 3, 21, 5, 84, 8, 24, 
    0, 15, 6, 76, 1, 24, 5,  7, 3, 79, 2, 59, 7, 52, 4, 11, 8, 10, 
    7, 34, 4, 64, 0, 17, 1, 84, 3, 57, 8, 10, 2, 87, 5, 62, 6, 45, 
    0, 28, 5, 14, 8, 42, 3, 78, 4, 22, 7, 54, 1, 28, 6, 19, 2, 92, 
    6, 55, 3, 13, 1, 22, 4, 60, 0,  9, 7, 40, 2, 83, 5, 77, 8, 19, 
    2, 90, 5, 30, 0, 27, 7, 61, 4, 96, 6, 87, 8, 49, 3, 56, 1, 75
  };
  const int q6989[] = {
    9, 9, // Number of jobs and machines
    5, 64, 3, 42, 4, 18, 8, 92, 0, 62, 2, 54, 6,  9, 7, 24, 1, 12, 
    7, 35, 4, 57, 3, 23, 1, 82, 2, 59, 0, 88, 5, 86, 6, 77, 8, 63, 
    6, 15, 8, 23, 4, 84, 3,  9, 0, 17, 7,  6, 1, 16, 2, 47, 5, 23, 
    5, 68, 1, 61, 7, 94, 4, 97, 2, 93, 6, 81, 3, 81, 0, 16, 8, 33, 
    8,  7, 1, 51, 5, 26, 3, 56, 6, 22, 4, 88, 2, 80, 0, 26, 7, 65, 
    5, 45, 8, 42, 7, 62, 4, 55, 0, 89, 6, 44, 2, 94, 3, 57, 1, 93, 
    1, 35, 2, 33, 8, 69, 7, 24, 3, 85, 6, 37, 5, 91, 4, 79, 0, 42, 
    5, 11, 0, 49, 7, 54, 6, 21, 1, 61, 8, 64, 4, 94, 2, 91, 3, 49, 
    3, 24, 5, 56, 7, 32, 8, 56, 6, 60, 1, 49, 2, 72, 0, 84, 4, 61
  };
  const int q6990[] = {
    9, 9, // Number of jobs and machines
    1,  7, 7, 91, 8, 48, 3, 73, 6, 84, 4, 16, 0,  3, 2,  3, 5, 40, 
    0, 54, 1, 66, 5, 65, 7, 19, 2, 72, 3, 25, 8, 13, 4, 56, 6, 84, 
    5, 69, 6, 35, 2, 31, 0, 85, 4, 66, 3, 42, 1, 13, 7, 18, 8, 43, 
    5, 86, 3, 14, 1, 58, 7, 65, 8, 85, 2, 32, 6, 14, 0, 81, 4, 59, 
    7, 88, 5, 28, 0, 39, 8, 91, 4, 82, 6, 62, 3, 48, 2, 49, 1, 95, 
    5, 88, 4, 37, 0, 37, 8, 22, 7, 68, 6, 79, 1, 29, 2, 31, 3, 26, 
    5, 71, 2, 94, 3, 80, 8, 83, 0, 64, 4, 74, 6, 63, 7, 47, 1, 16, 
    5,  8, 2, 24, 4, 77, 3, 34, 0, 47, 6, 82, 1, 37, 8, 50, 7, 58, 
    8,  4, 5, 79, 1, 71, 0, 96, 6, 35, 2, 98, 3, 27, 4, 10, 7, 35
  };
  const int q6991[] = {
    9, 9, // Number of jobs and machines
    4, 75, 5, 38, 7, 80, 3, 13, 2, 42, 0, 80, 8, 78, 6, 75, 1, 31, 
    0, 99, 3, 75, 7, 52, 1, 77, 6, 43, 5, 89, 2, 81, 8, 17, 4, 78, 
    4, 37, 5,  7, 1, 22, 6, 18, 8, 57, 3, 33, 2,  6, 7, 89, 0, 35, 
    4, 87, 2, 17, 8, 97, 5, 59, 3, 73, 1, 24, 6, 37, 0, 42, 7, 67, 
    0, 65, 7, 54, 1, 58, 4, 12, 3, 37, 5, 13, 2, 63, 6, 66, 8, 62, 
    8, 70, 4, 98, 6, 58, 1, 82, 2, 78, 7, 63, 3, 31, 0, 79, 5, 15, 
    4, 60, 5, 96, 1, 26, 8, 69, 2, 73, 3, 22, 7, 94, 0, 78, 6,  9, 
    7,  5, 2, 38, 0, 74, 8, 29, 4, 79, 3, 45, 1, 19, 5, 73, 6, 75, 
    7,  9, 8, 16, 6, 75, 4, 65, 1, 35, 0, 96, 2, 32, 3, 83, 5, 50
  };
  const int q6992[] = {
    9, 9, // Number of jobs and machines
    7, 31, 4, 42, 5, 34, 0, 21, 1, 53, 6, 73, 8, 74, 3,  5, 2, 40, 
    6,  6, 0, 93, 3, 74, 5,  9, 7, 86, 1,  5, 4, 42, 2, 27, 8,  8, 
    4,  5, 0, 18, 3, 97, 2, 46, 1, 70, 7, 57, 6, 63, 5, 48, 8,  3, 
    2, 99, 8,  2, 1, 25, 5, 30, 0, 14, 4, 67, 7, 14, 6, 94, 3, 47, 
    7, 84, 5, 15, 3, 95, 1, 78, 4, 50, 0, 43, 6, 72, 8,  8, 2, 45, 
    3, 14, 8,  4, 5, 77, 2, 10, 6, 81, 1, 92, 0, 85, 7,  4, 4, 13, 
    6, 66, 3, 99, 5, 42, 2, 48, 0, 78, 7, 24, 1, 27, 4, 41, 8, 80, 
    0, 42, 7, 58, 5, 75, 2, 44, 1, 33, 8, 83, 4, 40, 3,  4, 6, 57, 
    1, 60, 2,  2, 8, 98, 3, 35, 4,  4, 5, 81, 0, 93, 6, 63, 7, 79
  };
  const int q6993[] = {
    9, 9, // Number of jobs and machines
    6, 32, 3, 96, 7, 29, 0, 99, 8, 95, 1,  3, 4, 15, 2, 97, 5, 41, 
    6, 34, 7, 97, 8, 26, 4, 36, 5, 59, 1, 87, 3, 72, 2, 27, 0, 77, 
    0, 60, 4,  5, 8, 67, 5, 85, 2, 65, 6, 31, 7, 19, 3, 10, 1, 38, 
    4,  3, 1, 89, 0, 99, 7, 76, 3, 42, 2, 32, 5,  3, 6, 85, 8, 71, 
    3, 30, 4, 44, 5, 87, 1, 61, 8, 19, 7, 73, 6, 88, 2, 53, 0, 89, 
    2, 83, 4,  9, 3, 23, 5, 30, 0, 51, 8, 20, 6, 48, 7, 87, 1, 93, 
    4, 24, 0, 88, 6, 22, 7, 39, 5, 86, 3, 91, 1, 86, 2,  6, 8, 91, 
    3, 93, 2, 21, 6, 36, 1,  1, 0, 90, 7, 77, 5, 23, 8, 12, 4, 98, 
    2, 67, 7, 23, 1, 57, 3, 84, 8, 67, 5,  5, 0, 95, 6, 15, 4, 39
  };
  const int q6994[] = {
    9, 9, // Number of jobs and machines
    1, 25, 2, 22, 6, 17, 5, 56, 8, 51, 3, 99, 4, 81, 7,  2, 0, 97, 
    1, 15, 3, 82, 2, 66, 7, 43, 5, 17, 4, 31, 6, 53, 8, 58, 0, 51, 
    1, 56, 2, 38, 3, 91, 5, 98, 6, 65, 7, 75, 0, 90, 8, 21, 4, 16, 
    4, 27, 2, 75, 3, 20, 1, 42, 5, 88, 8, 63, 0, 81, 7, 10, 6, 49, 
    3, 71, 0, 56, 6, 20, 7, 69, 5, 68, 2, 43, 4, 67, 8, 24, 1, 35, 
    2, 29, 4, 65, 5, 79, 8, 28, 6, 19, 1, 20, 0, 28, 3, 77, 7, 17, 
    8, 29, 2, 88, 5, 89, 4, 99, 7, 35, 1, 28, 6, 53, 0, 26, 3, 80, 
    2, 80, 7, 40, 1,  4, 8,  6, 6, 12, 4, 86, 5, 37, 0, 61, 3, 87, 
    1, 14, 6, 14, 8, 31, 3,  6, 5, 86, 2, 67, 4, 10, 7, 74, 0, 18
  };
  const int q6995[] = {
    9, 9, // Number of jobs and machines
    4, 53, 1, 23, 6, 56, 2, 78, 5, 14, 8, 20, 3, 16, 7, 86, 0, 32, 
    3, 63, 1, 84, 0,  9, 6, 50, 7, 75, 5, 62, 8, 24, 4, 61, 2, 54, 
    3, 48, 7, 88, 6, 93, 8, 26, 5, 38, 0, 47, 2, 30, 4, 24, 1, 26, 
    7, 61, 3, 57, 6, 15, 8, 90, 4, 99, 5, 99, 1, 72, 2, 30, 0, 45, 
    5,  9, 0, 41, 2, 51, 4, 91, 6, 26, 7, 40, 3, 17, 8, 89, 1,  3, 
    5, 34, 3, 14, 6, 28, 4,  4, 0, 67, 2, 52, 8, 45, 1,  8, 7, 22, 
    0, 89, 3, 58, 7, 17, 4, 61, 6, 77, 5, 29, 1, 76, 2, 58, 8, 44, 
    1,  6, 3, 41, 0, 47, 7, 41, 6, 44, 8, 23, 2,  9, 5, 22, 4, 56, 
    5, 80, 6, 10, 7, 10, 0, 92, 8,  4, 2, 93, 3, 45, 1, 34, 4, 77
  };
  const int q6996[] = {
    9, 9, // Number of jobs and machines
    8, 65, 2, 47, 3, 78, 4, 83, 1, 43, 6,  5, 7, 67, 0, 98, 5, 68, 
    0, 29, 2, 62, 6, 26, 3, 10, 4, 68, 5, 27, 1, 14, 7, 15, 8, 21, 
    8,  2, 5, 12, 0, 89, 3, 49, 1, 70, 7, 45, 4, 36, 6, 98, 2, 38, 
    1, 69, 7, 73, 3,  2, 8, 91, 6, 41, 5, 29, 2, 19, 0, 54, 4, 10, 
    3, 82, 8, 47, 6,  1, 0, 36, 7, 79, 4, 72, 2, 30, 1, 85, 5, 77, 
    2, 91, 5, 16, 6, 64, 1, 96, 4, 73, 0, 19, 8, 79, 7, 49, 3, 90, 
    6, 25, 2, 54, 4, 59, 7, 87, 1, 95, 3, 10, 0,  7, 5, 19, 8, 98, 
    6, 25, 7, 37, 3, 62, 8, 81, 0, 26, 1, 67, 2,  4, 5, 86, 4, 85, 
    7, 29, 3, 34, 1,  7, 6,  3, 2, 45, 5, 50, 4, 46, 0, 53, 8, 11
  };
  const int q6997[] = {
    9, 9, // Number of jobs and machines
    8, 62, 1, 76, 3, 86, 7, 63, 2, 52, 0, 43, 4, 77, 5, 94, 6, 23, 
    0, 45, 2, 97, 8, 31, 3, 52, 7, 56, 5, 25, 1, 18, 4, 37, 6, 74, 
    3, 94, 2, 40, 1, 19, 7, 36, 6, 75, 0, 70, 8, 56, 5, 73, 4, 30, 
    7, 98, 0, 81, 3, 19, 2, 49, 4, 13, 1, 88, 8, 68, 6, 72, 5, 52, 
    7, 96, 3,  1, 0, 66, 2, 13, 6,  9, 4, 77, 1, 82, 8, 72, 5, 78, 
    8, 76, 6, 66, 5, 63, 4, 54, 3, 20, 7, 50, 2, 54, 0, 13, 1, 15, 
    6, 38, 1, 25, 2, 92, 5, 92, 4, 91, 7, 97, 3, 92, 8, 45, 0, 41, 
    8, 84, 7, 28, 5, 10, 1, 68, 4, 78, 0, 68, 2, 11, 3, 80, 6, 57, 
    0, 46, 3, 30, 8,  6, 6,  3, 5, 94, 1, 20, 4, 28, 7, 22, 2, 43
  };
  const int q6998[] = {
    9, 9, // Number of jobs and machines
    2, 71, 1, 33, 0, 78, 4, 64, 7, 41, 8, 55, 6,  2, 3, 23, 5, 52, 
    7, 68, 3, 11, 4, 12, 8, 58, 5, 15, 1, 92, 2, 40, 0, 20, 6, 47, 
    6, 96, 8, 56, 7, 82, 3, 79, 2, 42, 4, 35, 1, 19, 0, 53, 5, 16, 
    4, 57, 7, 82, 2, 18, 0, 70, 5, 20, 1, 81, 6, 92, 3, 68, 8, 39, 
    3,  3, 5, 15, 4, 69, 6, 83, 1, 40, 0, 78, 7, 13, 2, 40, 8,  3, 
    2, 15, 8, 31, 7, 32, 5, 10, 1, 81, 3, 13, 4, 88, 6, 77, 0, 47, 
    2, 24, 4, 60, 5, 63, 3, 55, 1, 77, 6, 11, 8, 56, 0, 83, 7, 81, 
    4, 95, 1, 18, 6, 28, 2, 18, 5, 83, 0, 41, 8, 11, 7, 28, 3, 47, 
    8, 55, 6, 29, 2, 65, 5, 49, 4, 98, 0, 87, 1, 40, 7, 97, 3, 89
  };
  const int q6999[] = {
    9, 9, // Number of jobs and machines
    3, 88, 1, 94, 2, 43, 5, 52, 8, 27, 0, 43, 7, 24, 4, 30, 6, 53, 
    2, 16, 5, 38, 1, 57, 0, 94, 6, 83, 8, 98, 7, 74, 3, 24, 4, 72, 
    6, 40, 3, 80, 2, 78, 5, 44, 7, 14, 1, 30, 4, 78, 0, 73, 8, 36, 
    4, 80, 8, 12, 6, 67, 2, 58, 0, 16, 5, 44, 1,  5, 3, 84, 7, 57, 
    3, 64, 7, 92, 5, 92, 0, 50, 6, 60, 4, 96, 2, 49, 1, 97, 8, 61, 
    7, 50, 6, 52, 5, 97, 3, 75, 8, 85, 4, 40, 1, 26, 0, 39, 2, 54, 
    1, 74, 5, 20, 0, 43, 2,  2, 4, 94, 7, 62, 6, 11, 8, 47, 3, 70, 
    2, 89, 0, 34, 1, 31, 4, 94, 3, 27, 7, 65, 6, 88, 8, 66, 5, 98, 
    1, 13, 4, 58, 0, 11, 8, 54, 5, 51, 7, 94, 3,  9, 2, 52, 6, 82
  };
  const int q7000[] = {
    9, 9, // Number of jobs and machines
    3, 49, 7, 76, 6, 16, 8, 60, 2, 42, 0, 82, 5, 78, 1, 72, 4, 24, 
    6, 25, 0, 18, 4, 16, 7, 65, 2, 20, 8, 49, 5,  1, 3,  5, 1, 63, 
    7, 70, 6, 42, 5, 89, 1, 67, 2, 18, 8, 55, 3, 63, 0, 65, 4, 84, 
    2, 51, 7,  3, 0, 23, 5, 94, 3, 14, 1, 41, 4, 35, 6,  7, 8, 57, 
    7,  1, 8, 70, 0,  5, 4, 36, 3, 40, 1, 50, 2, 62, 5, 92, 6, 84, 
    8, 73, 0, 75, 5, 59, 2, 65, 7, 55, 6, 68, 1, 98, 3, 10, 4, 97, 
    0, 75, 6, 11, 1, 43, 8, 16, 2, 86, 7, 89, 4, 16, 3, 40, 5,  3, 
    0, 89, 5, 89, 8, 54, 7, 89, 3, 52, 1,  9, 6, 87, 2, 48, 4, 56, 
    5, 71, 4,  5, 3,  7, 8, 20, 1, 70, 2, 20, 6, 30, 7,  1, 0, 73
  };
  const int q7001[] = {
    9, 9, // Number of jobs and machines
    4, 60, 6,  6, 8, 52, 3, 59, 1, 98, 7, 64, 0, 17, 2, 12, 5, 44, 
    0, 22, 6, 84, 8, 85, 5, 84, 1, 66, 2, 62, 7,  6, 4,  1, 3, 54, 
    2, 45, 8, 38, 1, 34, 7, 24, 0, 67, 6, 52, 5, 39, 3, 71, 4, 33, 
    6, 62, 2, 90, 0, 79, 3, 89, 1, 22, 7, 10, 4, 51, 8, 35, 5, 57, 
    3, 40, 4, 62, 2, 93, 1, 74, 7, 12, 5, 37, 8, 72, 6, 94, 0, 20, 
    3, 53, 8, 34, 4, 66, 7, 91, 6,  8, 5, 25, 2, 44, 0, 41, 1, 40, 
    6, 70, 7, 16, 1, 96, 3, 76, 5, 52, 4, 22, 0, 50, 8, 38, 2, 50, 
    2,  6, 7, 15, 6, 61, 4,  5, 3, 78, 0, 48, 1, 14, 5, 23, 8, 38, 
    0, 68, 4, 87, 3, 62, 8, 54, 7, 80, 6, 32, 2, 19, 1, 63, 5, 89
  };
  const int q7002[] = {
    9, 9, // Number of jobs and machines
    5, 65, 8, 47, 0,  3, 6, 46, 2, 35, 7, 51, 3,  8, 1, 92, 4, 78, 
    4, 61, 7, 71, 5, 93, 3, 27, 0,  8, 2, 72, 6, 35, 1, 93, 8, 70, 
    5, 12, 1, 40, 8, 34, 3, 89, 4, 84, 7, 18, 0,  1, 2, 18, 6, 51, 
    6,  3, 5, 74, 1, 51, 0, 39, 4,  4, 3, 45, 2, 13, 7, 17, 8, 12, 
    7, 11, 0, 93, 2, 51, 3, 39, 5, 48, 1,  4, 6, 12, 8, 45, 4, 22, 
    2, 68, 6, 16, 4, 42, 8, 78, 7, 80, 0, 14, 1, 50, 3,  4, 5, 89, 
    4, 19, 8, 36, 1, 75, 2, 86, 3, 19, 0,  5, 7, 43, 5, 96, 6, 86, 
    6, 89, 1, 87, 2, 20, 3, 18, 4, 41, 8, 83, 0,  4, 5, 29, 7, 82, 
    7, 57, 6,  3, 1, 77, 3, 29, 5, 56, 8, 48, 0, 57, 4, 66, 2, 29
  };
  const int q7003[] = {
    9, 9, // Number of jobs and machines
    4, 42, 5, 24, 7, 15, 0, 20, 3,  5, 6, 54, 1, 23, 2, 21, 8, 55, 
    4,  3, 8, 36, 0, 51, 7, 26, 5, 20, 6,  9, 2,  1, 3, 40, 1, 54, 
    0, 46, 2, 46, 1, 64, 3, 92, 6, 61, 8, 35, 4, 35, 5,  8, 7, 38, 
    7, 62, 6, 66, 1, 97, 0, 17, 3, 28, 8, 85, 4, 51, 2, 79, 5, 70, 
    7,  4, 8, 34, 3, 96, 5,  8, 1, 70, 6, 98, 4, 46, 0, 13, 2, 47, 
    1, 65, 8,  6, 0, 97, 5, 78, 7, 72, 2, 64, 6, 18, 3, 36, 4, 15, 
    4, 69, 1,  8, 0, 98, 5, 66, 7, 61, 2, 91, 8, 30, 6, 75, 3, 81, 
    7, 79, 1, 13, 0,  9, 6, 49, 8, 21, 2, 62, 3, 14, 5,  5, 4, 55, 
    5, 13, 3, 31, 1, 64, 4, 12, 0, 84, 6,  3, 2, 71, 7,  1, 8, 62
  };
  const int q7004[] = {
    9, 9, // Number of jobs and machines
    8, 63, 1, 47, 6, 38, 3, 25, 7, 34, 4, 92, 2, 21, 5, 10, 0, 43, 
    4, 83, 6, 97, 1, 39, 0,  2, 3, 54, 7,  1, 2, 64, 8, 97, 5, 45, 
    5, 33, 1, 71, 8, 91, 7, 97, 3, 85, 0, 85, 4, 94, 6, 65, 2, 21, 
    2, 55, 3, 28, 4, 58, 0, 56, 6,  1, 8, 69, 5, 15, 7, 45, 1, 64, 
    6, 50, 8, 80, 4, 57, 2, 36, 0, 39, 5, 62, 3, 16, 7, 68, 1, 78, 
    6, 83, 3, 79, 2, 21, 0, 16, 7, 62, 8,  8, 1, 90, 5, 58, 4, 27, 
    5, 64, 6, 73, 4, 60, 3, 40, 0, 70, 2, 72, 7, 28, 1, 78, 8, 68, 
    7, 74, 5, 83, 0, 54, 2, 52, 1, 11, 4, 91, 8, 61, 3, 54, 6, 15, 
    5, 37, 4, 36, 1, 12, 0, 53, 2, 51, 6, 78, 3, 67, 8, 13, 7, 11
  };
  const int q7005[] = {
    9, 9, // Number of jobs and machines
    8, 98, 3, 64, 4, 18, 7, 48, 6, 21, 2, 85, 1, 47, 0, 16, 5, 56, 
    3, 64, 0, 16, 6, 39, 7, 20, 1, 57, 5, 39, 2, 78, 8,  7, 4,  5, 
    3, 30, 6, 62, 7, 19, 8, 32, 4, 76, 5, 72, 1, 82, 0, 60, 2,  4, 
    5, 87, 0, 86, 3, 60, 7, 54, 6, 66, 2, 79, 8, 38, 1,  6, 4,  9, 
    2, 56, 7, 35, 3, 98, 8, 63, 6, 20, 1, 62, 0, 37, 5, 64, 4, 78, 
    4, 71, 2, 12, 7, 41, 8, 64, 3, 35, 5, 20, 0, 87, 1, 56, 6, 62, 
    3, 54, 4,  2, 1,  9, 0, 82, 5, 49, 6, 66, 2, 57, 7, 37, 8, 43, 
    2, 71, 6, 90, 5, 59, 4, 26, 7, 95, 8, 19, 0, 44, 1, 49, 3, 15, 
    6,  7, 7, 89, 2, 80, 0, 49, 5, 65, 4,  4, 8, 36, 3, 36, 1, 13
  };
  const int q7006[] = {
    9, 9, // Number of jobs and machines
    0, 62, 8, 86, 3, 31, 7, 53, 2, 16, 4,  1, 1, 42, 5, 86, 6, 24, 
    0, 53, 4, 67, 3, 87, 1, 91, 5, 46, 2, 32, 7, 25, 6, 70, 8, 17, 
    2, 54, 3, 73, 6, 60, 7, 95, 0, 75, 4, 32, 1, 73, 5, 61, 8,  1, 
    1, 65, 7, 78, 2, 76, 0, 69, 8, 63, 4, 30, 3, 46, 5, 53, 6, 81, 
    7, 91, 4, 10, 5, 28, 2, 89, 3, 36, 0, 28, 1, 11, 8, 83, 6, 86, 
    2, 22, 3, 68, 8, 89, 5, 74, 0, 28, 6, 16, 4, 56, 1, 62, 7, 74, 
    5, 49, 3, 40, 4, 58, 8, 89, 7, 26, 1, 57, 6, 44, 0, 22, 2, 94, 
    7, 99, 3, 21, 8, 80, 0,  8, 4, 33, 5, 51, 6, 93, 1, 92, 2, 62, 
    3, 58, 1, 79, 2, 42, 6, 80, 7, 33, 0, 42, 8, 60, 5, 16, 4, 97
  };
  const int q7007[] = {
    9, 9, // Number of jobs and machines
    1, 38, 0, 28, 6, 17, 3, 71, 5, 98, 8, 51, 2, 68, 7, 42, 4,  1, 
    0, 36, 7, 71, 8,  7, 6, 81, 5, 54, 1, 90, 4, 10, 3, 64, 2, 72, 
    1, 23, 4, 12, 0, 63, 3, 66, 8, 19, 2, 72, 7, 96, 6, 68, 5, 55, 
    2, 98, 4, 76, 0, 66, 5, 40, 8, 10, 7, 20, 3, 72, 1, 16, 6, 86, 
    8, 71, 0, 77, 7, 80, 1, 51, 3, 90, 6, 24, 2, 18, 4, 21, 5, 17, 
    5, 78, 0, 16, 7, 92, 8,  3, 3, 13, 4, 29, 6, 10, 1, 20, 2, 29, 
    7, 37, 0, 88, 2, 27, 6, 47, 5, 43, 8, 72, 1, 22, 4, 25, 3, 84, 
    3, 61, 6, 70, 5, 85, 7, 55, 8, 37, 4, 26, 0, 69, 1, 21, 2, 99, 
    4,  5, 1,  1, 7, 30, 3, 43, 2, 65, 0,  6, 6, 51, 8,  6, 5,  8
  };
  const int q7008[] = {
    9, 9, // Number of jobs and machines
    6, 44, 0, 70, 2, 42, 3, 57, 1,  4, 5, 24, 4, 78, 7, 36, 8, 39, 
    8, 73, 6, 83, 4, 78, 2, 50, 0, 41, 3, 49, 7,  1, 5, 59, 1, 96, 
    5, 80, 3, 19, 1, 72, 7, 50, 0, 35, 4, 69, 6,  8, 8, 89, 2, 98, 
    2,  5, 7, 98, 6, 94, 3, 62, 4, 36, 0,  4, 8, 92, 1, 11, 5, 23, 
    2, 94, 5, 41, 4, 75, 3, 66, 6, 32, 1, 82, 0, 62, 8, 72, 7, 39, 
    8, 13, 5, 95, 7, 31, 3, 51, 2, 67, 6, 23, 1, 35, 0, 39, 4,  2, 
    4, 17, 7, 38, 0, 16, 6, 25, 1, 92, 8, 66, 3, 51, 5, 15, 2, 19, 
    2, 73, 1, 68, 7, 54, 3, 58, 0, 82, 4,  8, 8,  7, 6, 75, 5, 37, 
    7, 80, 0, 99, 4, 37, 2, 12, 6, 81, 3,  6, 5, 17, 8, 30, 1, 17
  };
  const int q7009[] = {
    9, 9, // Number of jobs and machines
    1, 23, 2,  4, 4, 21, 8, 66, 7, 21, 0, 32, 5, 78, 3, 56, 6, 92, 
    5, 44, 8, 33, 0,  1, 6, 66, 1, 67, 7, 57, 2, 67, 3, 29, 4, 89, 
    1, 19, 3,  6, 6, 65, 8, 64, 0, 26, 5,  6, 7, 21, 4, 21, 2,  1, 
    3, 50, 7, 58, 6, 69, 4, 38, 8, 22, 0,  2, 2, 71, 1, 52, 5, 95, 
    7, 47, 0, 76, 1, 58, 8, 90, 2, 31, 5, 26, 4, 47, 6,  5, 3, 34, 
    0, 54, 2, 23, 8, 95, 3, 18, 5, 80, 4, 80, 6, 79, 7, 19, 1, 94, 
    5, 76, 7, 27, 0,  4, 2, 23, 6, 66, 3, 85, 8, 19, 4, 84, 1, 50, 
    5, 18, 1, 26, 7, 44, 2, 17, 3, 46, 4, 19, 0, 63, 6, 78, 8, 75, 
    3, 27, 8, 86, 5, 30, 4, 30, 1, 60, 2, 19, 6, 59, 7, 83, 0, 29
  };
  const int q7010[] = {
    9, 9, // Number of jobs and machines
    3, 45, 2, 79, 8, 75, 6, 20, 5, 43, 7, 18, 4, 32, 0, 70, 1, 50, 
    4, 70, 0, 34, 1, 91, 5, 31, 2, 99, 6, 10, 8, 50, 3, 14, 7, 78, 
    4, 47, 1, 25, 6, 42, 2, 26, 3, 78, 5, 96, 8, 69, 0, 18, 7, 86, 
    3,  2, 8, 42, 7, 63, 4, 34, 6, 28, 0, 19, 5, 60, 1, 69, 2, 14, 
    3, 43, 4, 77, 1, 49, 6, 98, 8,  5, 0, 36, 5,  4, 7, 85, 2, 27, 
    1, 56, 8, 76, 0, 54, 6, 19, 7, 63, 4, 24, 2,  9, 5, 68, 3, 12, 
    1, 57, 4, 91, 8, 62, 2, 95, 5, 38, 7, 97, 6, 80, 0, 16, 3, 75, 
    1, 14, 0, 62, 2, 54, 6, 83, 3, 43, 4, 68, 5, 96, 7, 24, 8, 29, 
    0, 59, 6, 45, 5, 46, 1,  1, 2, 52, 4, 54, 7, 89, 3, 85, 8, 60
  };
  const int q7011[] = {
    9, 9, // Number of jobs and machines
    2, 14, 4, 95, 6, 34, 0, 41, 7, 27, 3, 76, 1, 95, 8, 33, 5, 96, 
    0, 31, 8, 11, 1, 59, 4,  8, 2,  4, 3, 21, 6, 96, 5, 29, 7, 62, 
    3, 77, 2, 28, 5, 35, 0, 83, 7, 80, 6, 55, 8,  8, 4, 93, 1, 80, 
    4, 33, 6, 50, 2, 92, 1, 19, 7, 10, 8, 88, 5, 90, 3, 39, 0, 13, 
    1, 62, 2, 89, 4, 55, 0, 90, 6, 83, 5, 71, 3, 26, 8, 74, 7, 52, 
    2, 91, 7, 59, 8, 94, 0, 17, 1, 58, 6, 36, 5, 14, 4, 67, 3, 91, 
    1, 51, 8, 93, 7, 18, 5, 15, 3, 73, 2, 67, 6, 57, 4, 18, 0,  6, 
    3, 56, 0, 41, 5, 92, 4, 14, 1, 50, 2, 12, 6, 31, 8, 40, 7, 70, 
    6, 27, 2, 66, 4, 55, 5, 90, 8, 44, 1, 20, 3, 22, 0, 26, 7, 64
  };
  const int q7012[] = {
    9, 9, // Number of jobs and machines
    8, 24, 6, 91, 3, 96, 4, 20, 2, 76, 7, 69, 1, 91, 0, 15, 5, 72, 
    1, 80, 6, 90, 0, 17, 3, 31, 5, 11, 4, 22, 8, 18, 7, 62, 2, 47, 
    1, 82, 2, 58, 6, 13, 5, 78, 3, 94, 7, 59, 4, 18, 8, 31, 0, 72, 
    6, 62, 2, 53, 4, 46, 7, 23, 5, 72, 0, 75, 1, 87, 3, 12, 8, 51, 
    5, 44, 3, 22, 1, 68, 2,  4, 7, 63, 4, 85, 0, 12, 8, 32, 6, 99, 
    0, 70, 5, 85, 2, 32, 3, 43, 7, 67, 4, 87, 6, 87, 8, 96, 1, 52, 
    4, 45, 0,  3, 2, 73, 8,  3, 7, 61, 1, 61, 5, 48, 3, 64, 6, 36, 
    7, 96, 5, 71, 4,  5, 2, 76, 0, 52, 1, 12, 8,  9, 3, 92, 6, 90, 
    4, 87, 5, 58, 6, 34, 1, 26, 8,  1, 3, 41, 0, 97, 2, 89, 7, 67
  };
  const int q7013[] = {
    9, 9, // Number of jobs and machines
    2, 92, 0, 76, 3, 64, 5, 97, 8, 13, 7, 57, 1, 24, 6,  2, 4, 76, 
    3, 53, 7, 87, 1, 39, 0, 74, 5, 75, 2, 97, 4,  8, 6, 11, 8, 76, 
    0, 43, 8, 80, 2,  4, 3, 12, 6, 11, 4, 63, 1, 28, 5, 59, 7, 61, 
    5, 12, 7, 18, 2, 41, 4, 38, 6, 68, 8, 67, 1, 88, 3, 39, 0, 12, 
    4, 15, 0, 78, 1, 45, 5, 39, 2, 58, 6, 25, 8, 50, 7, 98, 3, 10, 
    5, 52, 6, 81, 2, 28, 7, 11, 3, 63, 0, 73, 1,  4, 8, 12, 4,  7, 
    6,  5, 1, 65, 4, 38, 8, 43, 0, 31, 5, 38, 7, 67, 3, 37, 2, 38, 
    3, 40, 0, 74, 4, 54, 7, 89, 8, 70, 2, 93, 1, 65, 6, 70, 5, 66, 
    1, 61, 3, 69, 2, 75, 5, 99, 4, 74, 0,  4, 7, 63, 6, 10, 8, 67
  };
  const int q7014[] = {
    9, 9, // Number of jobs and machines
    5, 72, 6, 25, 7, 75, 2,  1, 3, 13, 4, 72, 0, 80, 1, 58, 8, 35, 
    5, 96, 6,  6, 3, 60, 1, 92, 4, 27, 7, 47, 8, 11, 0, 80, 2, 56, 
    2, 19, 7, 41, 8, 24, 6, 78, 3, 55, 1, 23, 5, 60, 4,  6, 0, 99, 
    2, 62, 1, 83, 6, 22, 7, 43, 5, 29, 4, 86, 8, 32, 0, 67, 3, 96, 
    7, 16, 3, 65, 0, 79, 2, 36, 8, 89, 1, 66, 4, 76, 5, 69, 6, 95, 
    0, 97, 5, 98, 3, 48, 4, 19, 6, 43, 1,  4, 8,  3, 2, 60, 7, 52, 
    7, 92, 6, 62, 2, 75, 0, 97, 4, 11, 3, 60, 1, 76, 8, 25, 5, 40, 
    1, 79, 3, 75, 8, 45, 5, 13, 4, 70, 2, 91, 7, 17, 6, 42, 0, 29, 
    5,  8, 3, 39, 7, 47, 1, 16, 8,  3, 6, 24, 4,  8, 0, 26, 2, 33
  };
  const int q7015[] = {
    9, 9, // Number of jobs and machines
    4, 63, 5, 47, 8, 80, 1, 91, 3, 54, 0, 18, 6, 54, 7, 85, 2, 86, 
    5, 43, 0, 98, 8, 43, 1, 85, 7, 13, 2, 96, 3, 20, 6, 95, 4, 54, 
    4, 19, 1, 85, 5, 27, 0, 98, 2, 29, 3, 31, 7, 11, 6, 90, 8, 13, 
    6, 67, 0, 77, 8, 67, 2, 66, 4, 69, 5, 75, 3, 19, 7, 41, 1, 19, 
    5, 68, 2, 43, 4, 38, 8, 69, 0, 82, 1, 68, 7, 91, 3, 95, 6, 75, 
    1, 47, 7, 39, 2, 43, 5, 88, 3, 47, 4, 58, 0, 37, 6, 50, 8,  5, 
    3, 85, 2, 18, 8, 73, 6, 69, 4, 63, 5, 14, 1, 22, 7, 79, 0, 16, 
    8, 15, 7, 17, 0, 69, 1, 10, 4, 38, 2, 50, 6, 37, 5, 46, 3, 32, 
    0, 49, 2, 47, 7, 57, 4, 76, 8, 26, 3, 78, 5,  2, 1,  4, 6, 30
  };
  const int q7016[] = {
    9, 9, // Number of jobs and machines
    3, 72, 7,  4, 5, 72, 2, 20, 0, 98, 4, 51, 8, 66, 6, 57, 1, 91, 
    4,  3, 7, 54, 6, 92, 5, 49, 8, 12, 1, 50, 2, 15, 0,  8, 3,  9, 
    2, 48, 3, 17, 1, 56, 6, 65, 5,  4, 7, 32, 8, 61, 4, 89, 0, 91, 
    2, 60, 0, 46, 1, 11, 5, 95, 4,  4, 3, 99, 8, 99, 7, 54, 6, 58, 
    2, 54, 4, 95, 3, 44, 7,  1, 5, 20, 1, 98, 0, 75, 8, 12, 6, 70, 
    5, 34, 2, 48, 3,  9, 0, 33, 7,  8, 8, 92, 4, 64, 6, 53, 1, 43, 
    4, 64, 6, 95, 7,  8, 8, 58, 0, 48, 2, 94, 1, 11, 5, 25, 3, 62, 
    7, 25, 1, 67, 3, 89, 2, 34, 5,  1, 4, 63, 0, 56, 6, 37, 8, 55, 
    0, 85, 1, 98, 8, 79, 2,  6, 4, 54, 3, 16, 5, 24, 7, 65, 6, 50
  };
  const int q7017[] = {
    9, 9, // Number of jobs and machines
    0, 55, 7, 57, 5, 13, 6,  5, 3, 72, 2, 95, 4, 53, 1, 67, 8, 99, 
    7, 76, 5, 73, 6, 17, 3, 10, 8, 56, 2, 23, 1, 44, 4, 27, 0, 86, 
    6, 90, 4, 42, 7, 45, 3, 84, 1, 16, 5, 12, 2, 49, 8, 39, 0, 66, 
    2, 54, 4, 63, 0, 62, 6, 15, 7, 81, 5,  1, 1, 36, 3, 74, 8, 47, 
    6, 96, 4, 60, 2, 82, 7,  7, 8, 16, 5, 13, 1,  2, 0, 20, 3, 60, 
    3, 24, 6, 69, 8, 66, 7,  1, 4,  8, 2, 83, 5, 72, 0, 72, 1, 71, 
    3, 99, 6,  5, 4, 13, 0, 26, 2, 77, 5, 28, 8, 66, 1, 22, 7, 89, 
    4, 27, 3, 60, 8, 54, 5,  8, 2, 71, 0, 23, 1, 81, 6, 73, 7, 56, 
    7, 28, 4, 41, 5,  9, 8, 72, 3, 93, 0, 90, 2, 24, 6, 25, 1, 12
  };
  const int q7018[] = {
    9, 9, // Number of jobs and machines
    7,  4, 6, 26, 0, 41, 4, 10, 2, 10, 8, 36, 1, 78, 5, 61, 3, 79, 
    2, 43, 7, 76, 6, 43, 4, 44, 3, 30, 1, 63, 5, 32, 0, 59, 8, 23, 
    8, 51, 2,  6, 3, 18, 1, 52, 0, 78, 5, 77, 7, 93, 6, 29, 4, 14, 
    1, 15, 8, 32, 0, 87, 5, 73, 6, 85, 2, 77, 3, 27, 7, 29, 4, 75, 
    7, 74, 2, 72, 8, 84, 1, 21, 6, 97, 5, 29, 3, 74, 0, 88, 4, 89, 
    1, 78, 3, 49, 2,  7, 8, 42, 7, 31, 0, 90, 5,  7, 4, 70, 6, 36, 
    8, 11, 4, 15, 3, 95, 5, 18, 1, 71, 6, 49, 2, 73, 0, 27, 7, 42, 
    2, 65, 3, 51, 0,  2, 8, 89, 4, 40, 6, 57, 7, 97, 5, 93, 1, 25, 
    1, 24, 3, 86, 7, 39, 4, 92, 0, 54, 5, 80, 8, 90, 2, 75, 6,  2
  };
  const int q7019[] = {
    9, 9, // Number of jobs and machines
    1, 76, 5, 13, 2, 27, 7,  4, 6, 17, 4, 18, 0, 39, 8, 18, 3, 36, 
    5, 11, 3, 43, 1, 36, 6, 12, 8, 71, 4, 65, 0, 12, 7, 22, 2, 41, 
    4, 71, 0, 98, 1, 58, 7, 66, 2, 41, 3, 27, 8, 68, 6, 49, 5, 25, 
    3, 82, 4, 89, 0, 63, 2, 63, 1, 72, 8, 20, 5, 49, 7, 39, 6,  4, 
    2, 94, 3, 35, 4, 44, 0, 13, 6, 89, 7,  4, 5, 45, 1, 85, 8, 80, 
    2, 59, 8, 67, 6, 86, 5, 82, 3, 51, 0, 50, 1, 90, 7, 71, 4, 48, 
    8, 53, 4, 89, 3, 25, 0, 24, 7, 92, 2, 32, 1, 41, 6, 69, 5, 22, 
    6, 41, 5, 71, 2, 28, 4, 80, 1, 98, 8, 28, 3, 37, 7, 98, 0, 38, 
    5, 17, 1, 42, 2, 32, 6, 94, 0,  1, 3, 92, 8, 58, 4, 46, 7, 30
  };
  const int q7020[] = {
    9, 9, // Number of jobs and machines
    4, 27, 7, 85, 8, 48, 3, 59, 1, 83, 5, 16, 6, 55, 0, 68, 2, 34, 
    1, 72, 0, 37, 4, 89, 6, 58, 8, 20, 5, 40, 2, 24, 3, 19, 7, 82, 
    8, 58, 1, 56, 3, 60, 4, 14, 2, 87, 0,  8, 5, 49, 7, 62, 6,  8, 
    5, 67, 7,  8, 0, 11, 4, 83, 1,  2, 3, 46, 8, 27, 6,  6, 2, 70, 
    8, 83, 7, 30, 5, 95, 6, 66, 2, 86, 0, 55, 4, 16, 1, 67, 3,  6, 
    5, 88, 6, 28, 2, 42, 3, 68, 4, 87, 8, 13, 0, 84, 7, 63, 1, 67, 
    4, 62, 8, 78, 7, 64, 0, 16, 5,  7, 1, 78, 6, 56, 2, 55, 3, 78, 
    5,  7, 4, 56, 3, 94, 8, 83, 7, 24, 6, 11, 2, 18, 1, 66, 0, 77, 
    0,  6, 6, 93, 7, 49, 3, 30, 8, 31, 4, 88, 2, 21, 1, 74, 5, 37
  };
  const int q7021[] = {
    9, 9, // Number of jobs and machines
    4, 22, 8, 54, 6, 24, 7, 20, 1, 53, 2, 97, 0, 65, 3, 60, 5, 50, 
    0,  6, 7, 40, 4, 88, 5, 96, 6, 79, 3, 46, 8, 24, 2, 66, 1, 29, 
    6, 27, 0, 73, 7, 55, 2, 91, 3, 40, 1, 13, 5, 55, 8, 66, 4, 97, 
    6, 86, 0, 83, 5, 80, 2, 97, 7, 13, 4, 90, 1,  7, 8, 72, 3, 41, 
    7, 32, 2, 70, 4, 87, 0, 55, 1, 48, 5, 19, 8, 61, 6, 27, 3, 36, 
    8, 26, 3, 41, 4, 73, 2, 80, 6, 20, 0,  9, 5, 68, 7, 40, 1, 80, 
    1, 75, 7,  7, 3, 58, 5, 53, 2, 30, 6, 52, 4, 35, 0, 84, 8, 74, 
    3, 98, 5,  4, 4, 16, 2, 70, 6, 10, 1, 10, 0, 12, 8, 76, 7, 93, 
    2, 22, 1, 45, 6, 12, 7, 50, 5, 92, 0,  3, 4, 45, 3, 82, 8, 41
  };
  const int q7022[] = {
    9, 9, // Number of jobs and machines
    5, 18, 6, 91, 1, 32, 7, 75, 0, 25, 4, 56, 2, 19, 8, 25, 3, 70, 
    1, 27, 3,  8, 7, 94, 4, 86, 2, 84, 5, 84, 0, 52, 8, 29, 6, 66, 
    4, 46, 5, 89, 3, 46, 8, 89, 0, 42, 7, 34, 6, 85, 1, 20, 2, 71, 
    8, 85, 1, 37, 5, 24, 6,  1, 0, 14, 7, 90, 2, 85, 4, 42, 3, 98, 
    0, 31, 2, 81, 4, 97, 3, 12, 7, 79, 8, 12, 6, 60, 1, 48, 5, 66, 
    7, 67, 8, 79, 6, 15, 5, 55, 3, 70, 1, 69, 4, 74, 2, 19, 0, 67, 
    2, 37, 3, 21, 1, 14, 5, 71, 7, 35, 0, 85, 8, 69, 4, 52, 6, 38, 
    0, 59, 4, 52, 6, 51, 3, 32, 1, 32, 7, 52, 8, 78, 2,  8, 5, 98, 
    2, 46, 4, 88, 7, 26, 0, 35, 5, 96, 6, 40, 1, 93, 8, 16, 3, 16
  };
  const int q7023[] = {
    9, 9, // Number of jobs and machines
    4, 68, 5, 11, 1, 20, 3, 50, 8, 86, 2, 35, 6, 90, 0, 43, 7, 77, 
    7, 25, 8, 32, 5, 99, 4, 13, 3, 66, 1,  6, 6, 57, 2, 43, 0, 69, 
    7, 48, 5, 34, 0, 17, 2, 11, 6, 86, 4, 62, 8, 68, 1, 39, 3, 21, 
    3, 56, 6,  6, 8, 78, 4,  6, 2, 10, 0, 12, 7, 39, 5,  6, 1, 87, 
    2, 98, 8, 40, 5, 15, 7, 41, 0, 88, 1, 96, 6, 54, 3,  9, 4, 70, 
    6,  1, 0, 83, 4, 26, 1,  7, 5, 12, 7, 77, 3, 83, 2, 15, 8, 66, 
    1, 32, 8, 79, 7, 78, 3, 80, 4, 43, 5,  1, 0, 94, 6,  7, 2, 13, 
    1, 19, 8, 45, 6, 17, 7, 67, 5, 96, 2, 32, 4, 89, 3, 93, 0, 67, 
    4, 54, 5, 31, 7, 55, 3, 27, 1, 85, 6, 30, 8,  5, 0, 99, 2, 58
  };
  const int q7024[] = {
    9, 9, // Number of jobs and machines
    5, 84, 0, 35, 4,  7, 2, 58, 3, 74, 6, 58, 7, 51, 8, 50, 1, 91, 
    8, 94, 0, 68, 1, 26, 2, 60, 7, 73, 4, 13, 6, 95, 3, 68, 5, 63, 
    8, 28, 7,  8, 4,  6, 3, 11, 5, 92, 6, 77, 0, 91, 1, 66, 2, 18, 
    5, 41, 6,  3, 4, 11, 3, 49, 1, 24, 2, 17, 8, 34, 0, 46, 7, 22, 
    5, 70, 4, 95, 0, 59, 1, 48, 2, 61, 8, 13, 3, 86, 6, 59, 7, 11, 
    7, 89, 5, 71, 1, 62, 2, 16, 4, 98, 6, 21, 3,  4, 0, 54, 8, 82, 
    7, 21, 6, 24, 0, 28, 2, 12, 3, 24, 1, 60, 8, 75, 4, 35, 5, 41, 
    2, 84, 4, 85, 1, 95, 3,  3, 6, 33, 8, 77, 7, 69, 0, 71, 5, 21, 
    3, 70, 4, 62, 0, 37, 7, 34, 8, 92, 5, 80, 6, 37, 1, 15, 2, 34
  };
  const int q7025[] = {
    9, 9, // Number of jobs and machines
    2, 35, 8, 27, 4, 27, 1,  4, 6, 53, 0, 76, 7, 46, 3, 51, 5, 20, 
    3, 21, 4, 66, 8, 24, 2, 47, 5, 54, 1, 49, 0,  2, 6, 59, 7, 95, 
    6, 17, 4, 24, 8, 18, 0, 19, 3, 55, 5, 56, 2, 39, 1, 82, 7, 84, 
    2, 35, 7, 66, 0, 69, 1,  9, 5, 25, 3, 72, 6, 99, 4, 48, 8, 37, 
    8, 25, 5, 46, 1, 96, 4,  7, 0, 41, 3, 97, 2, 95, 7, 67, 6, 19, 
    8, 63, 5, 22, 6, 73, 2, 53, 7, 54, 4, 57, 3,  7, 1,  2, 0, 61, 
    3, 12, 0, 78, 6, 89, 5, 88, 1, 81, 8, 49, 7, 34, 4, 45, 2,  1, 
    7, 19, 0, 59, 8, 75, 3, 75, 6,  2, 1, 24, 4, 33, 2, 14, 5, 52, 
    5, 13, 4, 36, 7,  3, 3, 58, 0, 26, 8, 77, 6, 36, 1, 53, 2, 34
  };
  const int q7026[] = {
    9, 9, // Number of jobs and machines
    2, 43, 1, 86, 4, 56, 6, 60, 3, 48, 5, 35, 0, 58, 7, 52, 8, 52, 
    5, 50, 7, 52, 1, 41, 0, 82, 4, 31, 6, 40, 2, 86, 8, 63, 3,  5, 
    1, 45, 7, 94, 0, 60, 2, 43, 8, 39, 5, 11, 6,  1, 3, 59, 4, 40, 
    7, 96, 0,  8, 2, 10, 8, 53, 1,  3, 3, 23, 6, 30, 4, 54, 5,  3, 
    3, 82, 5, 71, 2, 71, 0, 63, 8, 68, 4, 60, 6, 46, 7, 45, 1,  1, 
    0, 74, 4, 82, 1, 70, 3, 57, 5, 52, 2, 95, 6, 65, 7,  9, 8, 46, 
    2, 20, 5, 36, 6,  2, 4, 33, 0, 91, 1, 95, 8, 88, 7, 56, 3, 70, 
    2, 25, 8, 67, 7, 63, 6, 78, 3, 74, 4, 46, 1, 98, 0, 56, 5, 36, 
    2, 23, 1, 37, 6, 99, 4, 45, 5, 78, 0, 50, 8, 79, 7, 13, 3, 26
  };
  const int q7027[] = {
    9, 9, // Number of jobs and machines
    4, 23, 7,  8, 8, 22, 5, 10, 1, 65, 2, 54, 6, 97, 0,  4, 3, 57, 
    7,  5, 0, 75, 5, 26, 1,  9, 6, 70, 2, 18, 4, 82, 3, 63, 8, 79, 
    6,  4, 8, 61, 3, 46, 7, 84, 1, 96, 4, 38, 0, 25, 5, 24, 2, 75, 
    1, 88, 8, 49, 0, 89, 4, 72, 3, 92, 2, 25, 7, 73, 6,  8, 5, 29, 
    4, 83, 0, 32, 7, 69, 3, 65, 1, 41, 6, 38, 8, 20, 5, 12, 2, 44, 
    1, 27, 6, 96, 0, 44, 3, 54, 4, 10, 5,  4, 8, 69, 2, 57, 7, 73, 
    7, 92, 0, 98, 1, 16, 4, 67, 8, 16, 3, 10, 6, 28, 2, 89, 5, 58, 
    8,  9, 5, 74, 1, 33, 4, 78, 3, 57, 0, 35, 2, 42, 7, 63, 6, 73, 
    8, 62, 0, 92, 5, 50, 6, 18, 7, 51, 2, 23, 4, 55, 1, 13, 3,  5
  };
  const int q7028[] = {
    9, 9, // Number of jobs and machines
    8, 29, 7, 59, 2, 35, 5, 21, 3, 22, 1, 21, 6, 80, 0, 47, 4, 48, 
    1, 99, 6, 81, 4, 41, 0, 83, 3, 76, 2, 67, 8, 71, 5, 34, 7, 31, 
    8, 84, 7, 79, 0, 83, 4, 64, 2, 73, 3, 69, 1, 58, 5, 30, 6, 25, 
    0, 46, 3, 59, 4, 99, 6, 85, 1, 80, 7, 65, 5, 95, 8, 52, 2, 53, 
    3, 86, 5, 56, 4, 85, 8, 53, 7, 51, 1, 52, 2, 82, 0, 64, 6,  8, 
    5, 26, 2, 19, 1, 92, 0,  9, 7, 90, 3, 55, 8, 40, 4, 43, 6, 41, 
    5,  9, 7, 44, 3, 23, 8, 22, 2, 80, 0, 88, 4, 10, 1, 56, 6, 82, 
    5, 51, 4, 28, 3, 92, 0, 23, 2,  8, 8, 71, 6, 34, 7,  1, 1, 14, 
    5,  4, 7, 55, 8, 23, 2, 50, 6, 70, 0, 36, 3, 34, 1, 46, 4, 78
  };
  const int q7029[] = {
    9, 9, // Number of jobs and machines
    2, 44, 3, 30, 8, 56, 4, 22, 0, 83, 5, 26, 1,  7, 6, 83, 7, 68, 
    5, 17, 6, 98, 7, 71, 3, 89, 2,  1, 8,  3, 1,  7, 0, 50, 4, 88, 
    8, 76, 3, 99, 2, 89, 1, 87, 7, 40, 4, 33, 0, 55, 6, 62, 5, 99, 
    2, 55, 8, 57, 6, 64, 4, 47, 0, 88, 5, 38, 7, 41, 3, 93, 1, 67, 
    6, 96, 1, 82, 5, 33, 8, 36, 0, 78, 7, 43, 3, 71, 2, 99, 4, 73, 
    1, 46, 0, 64, 8, 33, 7, 55, 6, 27, 5, 52, 3, 46, 2, 52, 4, 72, 
    7, 86, 5, 61, 1, 90, 4, 28, 2, 12, 3, 83, 8, 37, 6, 14, 0, 47, 
    2, 12, 3, 15, 0, 35, 8, 24, 4, 76, 1, 23, 7, 27, 6, 65, 5, 10, 
    3, 61, 0, 49, 6, 66, 5, 30, 2, 92, 4, 40, 1, 90, 8, 65, 7,  9
  };
  const int q7030[] = {
    9, 9, // Number of jobs and machines
    6, 33, 5, 10, 3, 91, 1, 47, 4, 50, 2, 95, 8, 49, 7, 83, 0, 57, 
    7, 53, 1, 54, 4, 38, 8,  2, 0, 70, 6, 67, 3, 92, 5, 87, 2, 21, 
    6, 28, 3, 36, 5, 69, 0, 74, 4, 37, 7, 44, 2,  4, 8, 90, 1, 66, 
    0, 34, 7, 99, 3, 82, 1, 77, 5, 86, 2, 86, 8, 56, 4, 88, 6, 67, 
    2, 76, 3, 16, 6, 21, 4, 59, 0, 74, 7, 93, 8, 59, 5, 84, 1, 23, 
    6, 89, 8, 83, 0, 49, 4, 79, 1, 81, 7, 67, 2,  8, 3, 45, 5, 84, 
    6, 28, 7, 96, 0, 48, 3, 38, 4, 81, 1, 38, 8, 29, 2, 47, 5, 46, 
    0, 93, 6, 77, 5, 31, 1, 85, 2,  7, 8, 10, 7, 12, 4, 73, 3, 64, 
    3, 61, 1, 39, 4, 48, 7, 78, 8, 51, 2, 95, 6, 81, 0, 93, 5, 10
  };
  const int q7031[] = {
    9, 9, // Number of jobs and machines
    0, 41, 2, 41, 6, 30, 4, 82, 8, 79, 5, 48, 3, 67, 7, 29, 1, 45, 
    7, 20, 3, 71, 8, 57, 0, 61, 5, 45, 6, 44, 4, 33, 1, 33, 2, 95, 
    2, 49, 1, 19, 0, 57, 7, 89, 8,  5, 4, 37, 6, 64, 5, 86, 3, 32, 
    0, 82, 5, 59, 6, 59, 4, 80, 8, 98, 2, 67, 1, 36, 7, 53, 3, 11, 
    6, 59, 5, 37, 2, 55, 0, 31, 8, 97, 4, 59, 7, 26, 3, 73, 1, 77, 
    4, 30, 3, 52, 2, 53, 1, 14, 5, 43, 8, 43, 7, 57, 0, 29, 6, 70, 
    8, 54, 4, 29, 0, 42, 2,  8, 5, 48, 6,  5, 1, 97, 7, 93, 3, 61, 
    3,  1, 6, 85, 2,  4, 5, 51, 0, 41, 1, 72, 7, 46, 4,  5, 8, 18, 
    7, 32, 2, 67, 1, 37, 0, 27, 3, 99, 5, 30, 6, 84, 4, 43, 8, 28
  };
  const int q7032[] = {
    9, 9, // Number of jobs and machines
    4,  4, 1,  8, 8, 41, 5, 47, 7, 93, 0, 28, 6, 50, 3, 49, 2, 33, 
    5,  3, 7, 43, 0, 86, 8, 45, 2, 76, 1, 35, 3, 23, 4, 54, 6, 68, 
    5, 49, 6, 34, 8, 43, 1, 67, 4, 64, 2, 63, 3, 67, 0, 99, 7, 80, 
    6, 65, 3,  9, 7,  1, 2,  3, 8, 83, 5, 26, 1, 22, 0, 96, 4, 83, 
    7, 59, 6, 44, 0, 57, 1, 53, 5, 55, 4, 11, 3, 78, 8, 64, 2, 76, 
    8, 54, 3, 39, 4, 71, 1, 18, 0, 51, 5, 40, 6, 93, 2, 87, 7, 46, 
    4, 41, 2, 88, 3, 20, 8, 36, 7, 73, 0, 68, 6, 34, 5, 79, 1, 86, 
    7, 47, 5, 53, 0, 10, 4, 94, 3, 12, 8, 42, 1,  1, 6, 16, 2, 26, 
    0, 97, 5, 65, 8, 75, 1, 36, 2, 38, 6, 36, 4, 50, 7, 78, 3, 36
  };
  const int q7033[] = {
    9, 9, // Number of jobs and machines
    4, 86, 2, 55, 3, 31, 8,  7, 0, 41, 7, 78, 5, 77, 1, 53, 6,  1, 
    6, 27, 2, 28, 4, 75, 3, 22, 1, 40, 7, 89, 8, 49, 5, 15, 0, 50, 
    8, 81, 4, 76, 0, 15, 3, 86, 5, 19, 6, 45, 1, 56, 2, 53, 7, 30, 
    3, 59, 5, 70, 4, 52, 6, 52, 8, 84, 2, 89, 0, 20, 7, 40, 1, 46, 
    5, 57, 6, 27, 3, 25, 8, 60, 0, 43, 4, 23, 1, 17, 7,  6, 2, 89, 
    8, 32, 3, 11, 0, 65, 5, 28, 2,  3, 6, 89, 7, 25, 1, 56, 4, 85, 
    3, 12, 5, 43, 8, 34, 0, 28, 1, 56, 6, 70, 2, 55, 7, 26, 4, 88, 
    1, 51, 5, 65, 0,  1, 7, 22, 2, 34, 3, 81, 4,  6, 8, 35, 6, 58, 
    0, 38, 4, 59, 8, 31, 7, 71, 2, 48, 5,  2, 3, 49, 6, 22, 1, 22
  };
  const int q7034[] = {
    9, 9, // Number of jobs and machines
    6, 65, 4, 22, 0, 54, 1, 64, 7,  4, 2,  4, 3, 66, 8, 61, 5, 55, 
    7,  3, 8, 48, 5, 22, 3, 89, 0, 93, 6, 34, 1, 72, 4, 47, 2, 46, 
    4, 34, 8, 21, 2, 76, 0, 31, 7, 59, 1, 38, 5, 61, 3,  1, 6, 82, 
    6, 92, 5, 39, 0,  3, 2, 74, 7, 51, 4, 45, 1, 87, 8, 96, 3, 14, 
    1, 86, 6, 52, 5, 22, 0,  3, 4,  4, 8, 53, 2, 28, 3, 12, 7, 13, 
    4, 64, 0, 59, 3, 34, 2, 97, 8, 99, 1, 22, 5, 65, 7, 64, 6, 42, 
    5, 58, 0,  6, 3, 65, 7, 25, 4, 71, 1, 30, 8, 84, 6, 55, 2,  1, 
    4, 61, 0,  4, 1, 84, 8, 85, 7,  3, 3,  4, 5, 88, 6, 59, 2, 90, 
    7, 82, 8,  9, 4, 24, 1, 63, 3, 34, 6, 21, 0, 96, 5, 94, 2, 52
  };
  const int q7035[] = {
    9, 9, // Number of jobs and machines
    2, 44, 3, 25, 5, 17, 1, 38, 8, 52, 0,  4, 7, 81, 6, 35, 4, 90, 
    3, 66, 0,  8, 8, 55, 2, 34, 5, 80, 4, 77, 6,  6, 1, 15, 7, 96, 
    8, 48, 7, 86, 0, 18, 3,  3, 4, 57, 6,  3, 5, 37, 2, 97, 1, 13, 
    0, 30, 2, 52, 4, 23, 1, 52, 8, 87, 6, 86, 5, 23, 3, 62, 7, 61, 
    5, 50, 0, 78, 1,  5, 7,  1, 2, 52, 6,  6, 8, 92, 4, 22, 3, 20, 
    1, 26, 2, 38, 4, 85, 0, 36, 7, 73, 3, 37, 6, 57, 5, 19, 8, 51, 
    4, 29, 2, 54, 8, 21, 7, 57, 6, 83, 3,  8, 1, 64, 0, 73, 5, 40, 
    4, 83, 8, 25, 2, 11, 3, 80, 5, 82, 7, 22, 0, 35, 6,  4, 1,  1, 
    8, 42, 3, 34, 7, 58, 5, 46, 4, 86, 1, 18, 6, 72, 2, 39, 0, 82
  };
  const int q7036[] = {
    9, 9, // Number of jobs and machines
    3,  8, 4, 58, 6,  8, 5, 93, 8, 53, 7, 51, 1, 94, 0, 20, 2, 96, 
    3, 42, 0, 66, 5, 72, 8, 77, 4, 77, 7, 58, 6, 18, 2, 65, 1, 64, 
    5, 59, 2, 97, 3, 84, 8, 73, 6, 57, 1, 36, 7, 12, 0, 57, 4, 88, 
    7, 78, 5, 18, 6, 83, 1, 29, 3, 89, 2, 64, 4, 36, 0, 35, 8, 99, 
    7, 36, 4, 13, 1,  2, 5, 99, 2, 18, 6, 70, 0, 68, 3, 66, 8,  5, 
    0,  9, 2, 64, 7, 87, 3, 49, 1, 88, 6, 88, 4, 72, 8, 30, 5, 66, 
    0,  6, 5, 20, 6, 95, 4, 54, 3, 71, 7, 37, 2, 41, 8, 74, 1, 15, 
    4, 87, 3, 93, 6, 24, 1, 93, 8, 69, 5, 93, 2, 72, 7, 47, 0, 22, 
    1, 31, 6, 59, 5, 69, 7, 88, 3, 51, 2, 44, 0, 20, 4,  7, 8, 29
  };
  const int q7037[] = {
    9, 9, // Number of jobs and machines
    2, 65, 6, 70, 4,  3, 5, 58, 1, 56, 0, 79, 8, 89, 3, 57, 7, 66, 
    2, 65, 3, 35, 7, 90, 6, 87, 5, 21, 0, 41, 4, 34, 1, 36, 8, 65, 
    6,  7, 0,  6, 3, 43, 7, 20, 1, 74, 5, 92, 2, 19, 4, 57, 8, 86, 
    5, 53, 4, 99, 6, 22, 0, 55, 8, 19, 2, 50, 3, 54, 1, 83, 7, 86, 
    4, 36, 3, 51, 0, 65, 1, 86, 2, 59, 5, 55, 7,  6, 6, 64, 8, 71, 
    1, 42, 8, 63, 0, 19, 3, 57, 4, 30, 5, 97, 7, 10, 2, 86, 6, 57, 
    6, 16, 3, 92, 8, 12, 0, 90, 7, 42, 1, 77, 2, 30, 5, 67, 4, 71, 
    5, 78, 4, 23, 7,  1, 0,  1, 2, 79, 1, 37, 8,  8, 6, 80, 3, 60, 
    7, 49, 6,  2, 5, 37, 3, 88, 4,  9, 1, 36, 0,  8, 8, 41, 2, 11
  };
  const int q7038[] = {
    9, 9, // Number of jobs and machines
    0, 85, 4, 18, 7,  4, 8, 62, 6, 37, 5, 74, 2, 44, 1, 85, 3, 63, 
    5, 85, 4, 98, 6, 55, 8, 22, 2, 49, 1, 10, 0, 44, 3, 26, 7, 49, 
    2, 81, 5, 18, 6, 24, 7, 28, 4, 76, 0, 80, 3, 95, 8, 21, 1, 14, 
    8, 21, 0, 79, 2, 41, 5,  2, 7, 75, 4, 29, 1, 77, 6, 78, 3, 72, 
    3, 59, 0, 44, 5, 16, 7, 80, 1, 31, 4, 96, 8, 19, 6, 22, 2,  3, 
    0, 12, 2, 88, 6, 58, 7, 94, 3, 74, 8, 73, 1, 91, 5,  9, 4, 63, 
    0, 23, 3, 31, 7,  9, 4, 81, 6, 90, 2, 65, 8, 34, 1, 48, 5, 59, 
    5, 32, 1,  2, 7, 80, 3,  7, 8, 25, 0, 11, 2, 64, 6, 63, 4, 34, 
    2, 87, 4, 67, 3, 92, 5, 47, 8, 75, 6, 35, 1, 39, 0, 16, 7, 94
  };
  const int q7039[] = {
    9, 9, // Number of jobs and machines
    0, 81, 1, 49, 8, 79, 3, 56, 6, 39, 2, 51, 5, 43, 4, 23, 7,  2, 
    2, 26, 6, 79, 8, 79, 3, 32, 7, 94, 4, 54, 5,  4, 1, 14, 0, 78, 
    2, 82, 5, 63, 0, 83, 1, 91, 3, 24, 6, 12, 4, 50, 8, 84, 7, 37, 
    1, 97, 6, 73, 2, 46, 4, 57, 8, 37, 7, 87, 3, 96, 0, 94, 5, 59, 
    7, 48, 4, 20, 8, 32, 0, 43, 3, 22, 6, 89, 1, 72, 2, 47, 5, 24, 
    6, 19, 3,  7, 4, 20, 5, 16, 1, 13, 0, 24, 7, 93, 2, 50, 8, 99, 
    8, 90, 5, 34, 6, 59, 1, 22, 0, 77, 4, 23, 2, 34, 3, 44, 7, 59, 
    2,  6, 0, 93, 3, 38, 6, 26, 1, 99, 5, 58, 8, 51, 7, 47, 4, 10, 
    5, 25, 0, 52, 1, 40, 8, 78, 3, 20, 2, 36, 7, 69, 4, 17, 6,  8
  };
  const int q7040[] = {
    9, 9, // Number of jobs and machines
    1, 26, 7,  1, 6, 14, 8, 40, 4, 35, 2, 31, 0, 38, 3, 53, 5, 26, 
    6, 55, 1,  4, 5, 39, 8, 41, 7, 53, 0, 35, 4, 48, 2, 27, 3, 48, 
    7, 81, 6, 13, 5, 30, 0, 11, 1, 25, 3, 98, 2, 29, 4, 59, 8, 47, 
    7,  5, 4,  2, 0, 71, 6, 92, 5, 65, 1, 35, 8, 14, 2, 94, 3,  5, 
    2, 67, 8, 39, 1, 92, 4, 24, 0, 94, 3, 56, 7, 28, 6, 73, 5, 83, 
    4, 51, 8, 30, 6, 72, 5, 99, 1, 71, 7, 97, 2, 48, 0, 59, 3, 79, 
    4, 67, 6, 89, 5, 22, 3, 58, 8, 75, 0, 25, 1, 98, 7, 98, 2, 11, 
    4, 24, 8, 70, 2, 87, 6, 88, 7,  4, 5, 61, 0, 69, 1,  3, 3, 39, 
    5, 27, 8, 41, 7, 44, 0, 35, 3, 77, 1, 96, 2, 81, 4, 14, 6, 47
  };
  const int q7041[] = {
    9, 9, // Number of jobs and machines
    3, 16, 7, 59, 4, 97, 1,  6, 2, 88, 5, 73, 8, 36, 0,  4, 6, 84, 
    3, 73, 6,  3, 4, 10, 7, 99, 1, 36, 5, 53, 0, 24, 8, 38, 2, 68, 
    6, 95, 5, 60, 3, 47, 1,  9, 2, 56, 7, 77, 4, 13, 0, 44, 8, 88, 
    3, 12, 2,  6, 0, 71, 6, 90, 1, 32, 7, 19, 8,  9, 5,  3, 4, 84, 
    1, 59, 3, 35, 4,  3, 8,  3, 7, 22, 5,  3, 0, 96, 2, 14, 6, 80, 
    0,  6, 5, 30, 3, 98, 7, 80, 1, 26, 4, 91, 2, 21, 6, 41, 8, 95, 
    8, 20, 4, 11, 2,  4, 0, 19, 5, 12, 6, 78, 3, 99, 1, 41, 7,  4, 
    6, 64, 4, 27, 3, 18, 2, 81, 1, 25, 8, 61, 0, 28, 7, 77, 5, 75, 
    4, 66, 3, 62, 1, 60, 7, 46, 5, 17, 6,  4, 2, 88, 0, 28, 8, 82
  };
  const int q7042[] = {
    9, 9, // Number of jobs and machines
    1, 84, 3, 40, 4, 89, 5, 69, 6, 59, 7, 20, 0, 67, 8, 37, 2, 61, 
    6, 88, 4, 43, 8, 10, 5, 57, 3, 93, 1, 99, 2,  3, 0,  9, 7, 10, 
    1, 59, 6, 69, 7, 48, 5, 28, 0, 51, 2, 35, 8, 18, 3,  9, 4, 70, 
    8, 30, 0, 92, 6, 27, 4, 99, 1, 51, 5, 14, 3, 59, 7, 44, 2, 99, 
    8, 63, 0, 58, 6, 54, 2,  6, 3, 85, 1, 17, 4, 45, 7, 21, 5,  4, 
    3, 99, 0, 64, 5, 19, 8, 93, 4, 85, 6, 48, 7, 92, 1, 24, 2, 62, 
    2, 56, 5, 74, 7, 12, 1, 59, 3, 78, 0, 28, 4, 48, 8, 61, 6, 66, 
    8, 90, 2, 48, 3, 44, 7, 84, 0, 38, 5, 36, 1, 21, 6, 42, 4, 52, 
    4,  6, 0, 32, 2, 90, 8, 58, 7, 64, 1, 94, 6, 33, 3, 83, 5, 94
  };
  const int q7043[] = {
    9, 9, // Number of jobs and machines
    1, 72, 3,  9, 7, 86, 2, 92, 8, 22, 4, 43, 6,  7, 0, 87, 5, 24, 
    6, 35, 7, 22, 0, 85, 3, 21, 5, 53, 8, 39, 1, 81, 2, 81, 4, 94, 
    7, 13, 6, 59, 2, 88, 3, 89, 4, 76, 0, 64, 8, 61, 1, 73, 5, 32, 
    6, 29, 3, 32, 2,  8, 0, 71, 4, 42, 5,  1, 7, 88, 8, 85, 1, 39, 
    2, 29, 1, 60, 4, 62, 8, 76, 0,  5, 3, 21, 6,  6, 7, 69, 5,  4, 
    4, 49, 7, 61, 8, 15, 2, 52, 5, 19, 6, 77, 1, 12, 3, 15, 0, 44, 
    0, 36, 4, 57, 6,  3, 8, 22, 5, 33, 3, 64, 1, 75, 7, 32, 2,  9, 
    2, 19, 6, 98, 0, 39, 1, 74, 5, 83, 8, 15, 3, 34, 4, 84, 7, 49, 
    0, 74, 6, 18, 4, 12, 7, 44, 5, 81, 3, 82, 2, 53, 8,  6, 1, 53
  };
  const int q7044[] = {
    9, 9, // Number of jobs and machines
    6, 63, 1, 46, 7, 50, 0, 30, 4, 56, 8, 99, 3, 51, 5, 97, 2, 78, 
    8, 88, 3, 86, 5, 35, 1, 38, 6, 23, 2, 65, 4, 95, 0, 33, 7, 75, 
    6, 89, 0, 13, 2, 76, 1, 36, 4, 29, 7, 70, 3, 78, 5, 75, 8, 61, 
    5, 80, 7, 58, 6, 14, 3, 72, 0, 31, 1, 87, 8, 78, 4, 37, 2, 18, 
    1,  2, 5, 90, 8, 51, 6, 56, 7, 13, 2, 25, 3, 93, 4, 97, 0,  2, 
    8, 38, 0, 40, 5, 64, 6,  6, 1, 88, 2, 54, 3, 41, 7, 48, 4, 64, 
    1, 53, 0, 64, 3, 69, 8, 25, 2, 24, 5, 92, 7, 20, 6,  5, 4, 82, 
    6, 25, 7, 76, 4, 85, 5, 61, 2, 82, 3, 94, 8,  6, 1,  1, 0, 71, 
    7, 99, 8, 31, 4,  7, 6, 61, 0, 24, 1, 50, 3, 96, 5, 21, 2, 47
  };
  const int q7045[] = {
    9, 9, // Number of jobs and machines
    8, 71, 5,  4, 3, 32, 0, 16, 7, 10, 4,  5, 2, 33, 6, 46, 1, 47, 
    6, 57, 0, 68, 4, 77, 3, 83, 2, 97, 5,  9, 8, 51, 7, 12, 1, 80, 
    5, 23, 4, 26, 6, 31, 8, 43, 2, 37, 3, 54, 0, 22, 1, 41, 7, 99, 
    0, 98, 7, 70, 6, 28, 1, 43, 3,  1, 4, 70, 2, 42, 5, 55, 8,  5, 
    3, 12, 8, 98, 4,  6, 0, 13, 1, 47, 6, 72, 7, 83, 5, 77, 2, 26, 
    3, 63, 1, 19, 8, 53, 5, 56, 6, 18, 4, 53, 2, 71, 0, 81, 7, 11, 
    6, 51, 8,  1, 0, 52, 5, 16, 2, 54, 1, 60, 3, 99, 4, 89, 7, 37, 
    2,  1, 4, 31, 7, 36, 3, 68, 6, 75, 5, 20, 8,  4, 0, 14, 1,  8, 
    6,  2, 2, 82, 8, 54, 4, 55, 1, 17, 0, 28, 5, 32, 3, 43, 7, 99
  };
  const int q7046[] = {
    9, 9, // Number of jobs and machines
    3, 97, 4, 68, 2, 73, 6, 20, 7, 61, 5, 34, 0, 36, 8,  9, 1, 90, 
    3,  9, 8, 11, 6, 84, 4, 99, 1, 92, 2, 45, 7, 93, 0, 78, 5, 19, 
    8, 82, 6, 79, 7, 57, 5, 88, 4, 87, 3, 62, 0, 40, 2, 12, 1, 56, 
    7, 92, 0, 70, 3,  1, 1, 63, 2, 62, 8, 39, 4, 95, 5, 84, 6, 19, 
    0, 42, 1, 88, 2, 68, 3, 50, 8, 84, 7, 55, 5, 39, 6, 27, 4, 51, 
    2, 69, 1, 94, 0, 97, 8,  2, 3, 57, 7, 83, 4, 20, 6, 55, 5, 39, 
    1, 11, 5,  1, 0, 82, 2, 60, 3, 66, 6, 62, 4, 20, 7, 29, 8, 97, 
    5, 46, 3,  4, 6, 17, 8, 74, 2, 39, 7, 17, 1, 98, 4, 91, 0, 24, 
    3, 72, 0, 55, 2, 25, 5, 13, 6, 14, 4, 34, 1, 47, 8, 58, 7, 90
  };
  const int q7047[] = {
    9, 9, // Number of jobs and machines
    1, 65, 2, 46, 4,  3, 6, 80, 0, 17, 5, 13, 7, 68, 8, 78, 3, 44, 
    1, 17, 4, 70, 8,  2, 7, 75, 2, 41, 3, 12, 6, 55, 0, 70, 5, 89, 
    6, 41, 8, 48, 7,  4, 3,  6, 4, 20, 2, 70, 0, 69, 5, 50, 1, 79, 
    5, 68, 1, 14, 3,  1, 4, 53, 7, 80, 8, 97, 6, 39, 0, 53, 2, 80, 
    3, 18, 5, 51, 6, 48, 1, 30, 8, 33, 4, 46, 7, 29, 2, 91, 0, 87, 
    5, 29, 1, 48, 7, 19, 4, 36, 3, 18, 0, 24, 6, 42, 2, 82, 8, 32, 
    2, 81, 4, 92, 5, 62, 8, 46, 1, 40, 6, 96, 0, 75, 7, 75, 3, 66, 
    1, 28, 3, 67, 0, 63, 6,  8, 5, 12, 2,  3, 7, 44, 4, 78, 8, 27, 
    8, 75, 5, 52, 2, 41, 7, 60, 0, 38, 1, 32, 3, 42, 4, 66, 6, 33
  };
  const int q7048[] = {
    9, 9, // Number of jobs and machines
    2, 60, 7, 65, 8, 49, 0,  2, 4, 19, 3, 27, 6, 34, 5, 41, 1, 75, 
    5, 19, 2, 62, 7, 77, 1,  3, 3, 40, 8, 92, 4,  7, 6, 62, 0, 75, 
    1, 89, 4, 10, 3, 69, 5, 44, 8, 83, 6, 50, 7, 10, 0, 44, 2, 87, 
    7, 65, 2, 86, 6, 76, 8, 93, 1, 27, 0, 92, 3, 10, 5, 36, 4, 70, 
    2,  8, 1, 63, 3, 83, 0, 51, 4, 11, 7, 22, 5, 24, 6, 27, 8, 50, 
    3, 69, 4, 71, 6, 77, 5, 82, 2, 73, 8, 88, 1, 48, 7, 89, 0, 81, 
    3, 81, 8, 58, 6, 80, 5, 37, 7,  8, 1, 20, 4, 45, 0, 92, 2, 25, 
    0, 36, 6, 27, 4,  4, 7, 20, 5, 99, 8, 84, 1, 20, 2, 68, 3, 80, 
    7, 67, 6, 41, 3, 55, 5, 65, 1, 52, 4, 90, 8, 52, 2, 90, 0, 45
  };
  const int q7049[] = {
    9, 9, // Number of jobs and machines
    2, 11, 0, 96, 5, 31, 6, 63, 1, 18, 4, 22, 7, 27, 3, 73, 8, 97, 
    1, 98, 2, 54, 6, 65, 7, 84, 0, 91, 8, 12, 4, 45, 3,  7, 5, 23, 
    5, 27, 7, 40, 1, 75, 3, 55, 6, 62, 0, 22, 8,  3, 2, 62, 4, 21, 
    7, 60, 0, 33, 5, 45, 6, 39, 3, 49, 2, 80, 8, 57, 1, 30, 4, 17, 
    1, 10, 8, 82, 6, 13, 2, 36, 7, 96, 5, 88, 4, 60, 0, 32, 3, 14, 
    1, 62, 5, 46, 3, 50, 0, 32, 8, 12, 7,  2, 2, 59, 4, 13, 6, 35, 
    3, 42, 8, 41, 7, 13, 5, 59, 0, 96, 6, 95, 4, 43, 2, 46, 1, 80, 
    5, 89, 7, 35, 0,  3, 4, 94, 2,  4, 3, 82, 6, 81, 1, 76, 8, 98, 
    2, 54, 1, 58, 0, 34, 7, 50, 6,  4, 5, 95, 8, 23, 4, 91, 3, 86
  };
  const int q7050[] = {
    9, 9, // Number of jobs and machines
    4, 81, 5, 15, 3,  4, 8, 12, 0,  9, 2, 39, 1, 66, 7, 28, 6, 95, 
    2, 16, 8, 42, 0, 16, 5, 83, 4, 28, 7, 99, 1, 95, 6, 90, 3, 13, 
    6, 15, 0, 82, 1, 32, 3, 82, 7, 16, 2, 89, 8, 26, 4, 19, 5, 87, 
    5, 80, 6, 33, 8, 91, 2, 55, 0, 46, 7, 26, 3, 38, 4, 78, 1, 99, 
    2, 22, 0, 33, 6, 65, 4, 66, 7, 19, 3, 58, 1, 83, 8,  6, 5, 91, 
    0, 38, 6, 15, 1, 40, 8, 51, 2, 35, 5, 85, 7, 60, 4, 36, 3, 31, 
    4,  3, 8, 47, 6, 78, 3, 10, 5, 11, 2, 12, 0, 36, 1,  2, 7, 29, 
    8, 66, 5, 67, 7,  7, 4, 88, 1, 75, 2, 59, 6, 73, 3, 80, 0, 63, 
    6, 40, 3, 88, 2, 69, 4, 18, 7, 97, 0, 47, 1, 34, 8, 21, 5, 91
  };
  const int q7051[] = {
    9, 9, // Number of jobs and machines
    4, 20, 0, 35, 6, 34, 7, 82, 3, 14, 1, 59, 2, 55, 8, 29, 5, 37, 
    1, 23, 0, 28, 4, 88, 7, 11, 8, 17, 5,  9, 2, 66, 6, 85, 3, 55, 
    8, 84, 6,  2, 1, 76, 0, 50, 5, 25, 2, 31, 4, 83, 7, 11, 3, 94, 
    8, 41, 0,  5, 6, 54, 4,  1, 5, 22, 2,  3, 3, 24, 7, 39, 1, 59, 
    8, 44, 3, 76, 2,  1, 0, 47, 7, 74, 6, 74, 4, 80, 5, 74, 1,  8, 
    2, 93, 7, 55, 1, 92, 3, 21, 5, 31, 6, 94, 8, 55, 0, 83, 4, 23, 
    7, 80, 4, 25, 8, 28, 2, 32, 0, 73, 5, 60, 3, 80, 6, 10, 1,  5, 
    0, 57, 7, 28, 8, 48, 2, 71, 1, 28, 5, 31, 4, 22, 6, 62, 3, 97, 
    4, 75, 1, 73, 7, 66, 5, 30, 2, 75, 6, 38, 3, 92, 0, 49, 8, 89
  };
  const int q7052[] = {
    9, 9, // Number of jobs and machines
    4, 64, 5, 44, 2, 28, 3, 91, 8, 50, 7, 89, 1,  9, 6, 89, 0, 47, 
    1, 56, 5, 10, 3, 60, 7,  4, 0, 73, 6, 28, 2, 58, 8, 47, 4, 62, 
    0, 90, 2,  8, 4, 22, 3, 62, 1, 24, 7, 46, 5, 62, 8, 50, 6, 73, 
    6, 27, 5,  2, 4, 84, 2, 10, 3, 71, 1, 91, 7, 44, 0, 36, 8, 65, 
    2, 18, 4,  2, 8, 59, 7, 14, 5, 70, 1, 38, 0, 51, 6, 49, 3, 99, 
    0, 10, 2, 88, 8, 79, 7, 18, 3, 67, 5, 49, 1, 55, 6, 28, 4, 31, 
    1, 86, 6, 41, 5, 44, 8, 70, 2, 80, 0, 84, 4, 69, 3, 54, 7, 46, 
    8, 97, 7, 83, 0, 50, 1, 97, 5, 35, 4, 89, 6, 24, 2, 79, 3, 90, 
    7, 52, 0, 14, 4, 11, 5, 75, 8, 24, 3, 21, 6, 59, 1, 48, 2,  6
  };
  const int q7053[] = {
    9, 9, // Number of jobs and machines
    1, 90, 2, 51, 3, 87, 7,  8, 6,  6, 5, 27, 4, 62, 8,  2, 0, 39, 
    2, 14, 7, 38, 6, 10, 0, 91, 5, 65, 1, 50, 4,  9, 8, 71, 3, 62, 
    1, 80, 4, 43, 7, 64, 0,  3, 2, 11, 8, 23, 3, 27, 6, 90, 5, 39, 
    5, 20, 7, 57, 4, 41, 1, 72, 6, 72, 3, 79, 8, 87, 0, 92, 2, 88, 
    3, 52, 7, 95, 6, 43, 1, 47, 2, 37, 4, 61, 0, 49, 5, 24, 8, 33, 
    4, 51, 5, 26, 6, 89, 3, 42, 8, 90, 1,  7, 0, 89, 7, 28, 2, 65, 
    2, 48, 7, 52, 8, 11, 6, 43, 5, 99, 3, 54, 4, 11, 1, 88, 0, 41, 
    2, 98, 6, 37, 5, 92, 1, 92, 8, 46, 7, 53, 4, 19, 0, 81, 3, 84, 
    5, 87, 2, 43, 1, 19, 7, 36, 6, 87, 0, 87, 8, 18, 3,  3, 4, 23
  };
  const int q7054[] = {
    9, 9, // Number of jobs and machines
    2, 98, 7, 33, 1, 40, 0, 38, 3, 31, 6, 25, 5, 10, 8, 72, 4, 72, 
    8, 31, 0, 29, 4, 16, 7, 58, 6, 55, 3, 54, 1, 77, 5, 60, 2, 70, 
    4, 79, 5, 38, 1, 63, 3, 20, 7, 56, 0, 79, 6, 61, 2, 83, 8, 73, 
    5, 87, 3, 65, 8, 98, 1, 72, 7, 84, 6, 61, 4, 55, 2, 64, 0, 55, 
    0, 78, 7, 45, 5, 53, 3, 88, 2, 78, 1, 62, 4,  4, 6, 38, 8, 55, 
    3, 51, 0, 68, 7, 99, 4, 88, 2, 30, 8, 41, 1,  9, 5, 22, 6, 27, 
    6, 39, 3, 91, 8, 57, 5, 62, 1, 18, 2, 21, 0, 93, 4, 17, 7, 19, 
    1, 80, 6, 38, 3, 66, 7, 21, 8, 18, 0,  4, 5, 51, 4,  7, 2, 20, 
    3, 36, 2, 60, 5, 21, 7, 21, 0, 80, 4, 33, 6, 32, 1, 56, 8, 60
  };
  const int q7055[] = {
    9, 9, // Number of jobs and machines
    0, 52, 1, 71, 2, 22, 8, 65, 6, 94, 5, 16, 7,  8, 4, 57, 3, 59, 
    7, 91, 4, 34, 3, 32, 0, 14, 2, 67, 6, 47, 5, 64, 1, 40, 8, 57, 
    2, 91, 8, 11, 7, 98, 0, 64, 6, 34, 5, 25, 3, 25, 4, 68, 1, 97, 
    8, 19, 0,  4, 3, 61, 2, 76, 7, 61, 6, 80, 4, 78, 1, 97, 5, 33, 
    4, 37, 3, 83, 2, 88, 1, 77, 5, 80, 8, 53, 7,  6, 6, 62, 0, 66, 
    1, 54, 2, 88, 3,  5, 0, 89, 6, 85, 8, 54, 4, 47, 5,  5, 7, 45, 
    6, 49, 4, 72, 2, 36, 7, 44, 5, 14, 8, 31, 1, 86, 0, 29, 3, 40, 
    3, 48, 2, 44, 1, 91, 0, 14, 5, 98, 6, 72, 8, 77, 4, 84, 7, 26, 
    5, 62, 7, 91, 2, 63, 0, 64, 8, 91, 4, 26, 1, 87, 3, 40, 6, 69
  };
  const int q7056[] = {
    9, 9, // Number of jobs and machines
    0, 70, 2,  2, 7, 48, 5, 19, 3, 79, 8, 95, 6, 84, 4, 91, 1, 83, 
    2, 29, 1, 67, 0, 68, 5,  4, 3, 75, 4, 77, 8, 10, 7, 49, 6, 11, 
    5, 53, 4, 11, 3, 87, 8, 99, 6, 98, 7, 94, 0, 41, 1, 73, 2, 39, 
    6, 96, 5, 21, 2, 85, 8, 80, 1, 96, 7, 74, 3, 79, 4, 53, 0, 46, 
    5, 79, 4, 94, 2, 96, 6, 57, 8, 34, 3, 68, 1, 91, 7, 92, 0, 64, 
    3, 52, 1, 79, 5, 38, 7, 53, 6, 51, 0, 81, 2, 64, 4, 45, 8, 83, 
    3, 50, 4, 72, 0, 83, 6,  3, 7, 36, 8, 35, 1,  4, 2, 46, 5, 91, 
    0, 91, 1, 92, 8, 21, 6, 74, 7, 16, 5, 89, 3, 48, 4, 12, 2, 30, 
    8,  5, 4, 23, 5, 32, 3, 99, 2, 25, 6, 83, 7, 76, 0, 15, 1, 15
  };
  const int q7057[] = {
    9, 9, // Number of jobs and machines
    8, 32, 7, 56, 4,  4, 5, 54, 0,  5, 2, 51, 1, 62, 6, 64, 3, 20, 
    2,  7, 1, 73, 4, 29, 5, 54, 0, 65, 3,  1, 6, 88, 7, 45, 8,  4, 
    4, 24, 3,  3, 6, 39, 1, 22, 7, 45, 5,  1, 0, 20, 2,  4, 8, 82, 
    2, 45, 1, 10, 4, 30, 5, 94, 6, 64, 7, 26, 0,  1, 3, 39, 8, 65, 
    4, 54, 2, 68, 5, 85, 7, 50, 6,  8, 0,  7, 8, 48, 1, 17, 3, 98, 
    5, 57, 1, 41, 6, 68, 3, 60, 2, 94, 7, 29, 4, 74, 8, 83, 0, 55, 
    7, 76, 3, 52, 2, 58, 0, 51, 8, 40, 6, 27, 1, 82, 5, 43, 4, 58, 
    2, 10, 3, 29, 0,  1, 4, 57, 8, 85, 1, 65, 6, 19, 5, 61, 7, 94, 
    5, 35, 6, 27, 8, 30, 4, 35, 7, 41, 1,  9, 0, 60, 3, 66, 2, 77
  };
  const int q7058[] = {
    9, 9, // Number of jobs and machines
    0, 44, 6, 78, 3, 48, 1, 77, 7, 20, 2, 97, 4, 32, 8, 44, 5, 91, 
    7, 45, 8, 83, 5, 69, 4, 69, 3, 65, 6, 80, 0, 60, 2, 59, 1, 80, 
    4, 47, 7, 41, 3, 55, 5, 25, 0, 93, 1, 32, 6, 83, 2, 37, 8, 33, 
    0, 24, 6, 27, 5,  6, 4, 80, 2,  8, 7, 94, 1, 62, 3, 87, 8, 33, 
    0, 51, 6, 78, 2, 69, 7, 35, 8, 42, 4, 26, 1, 38, 5, 26, 3,  9, 
    8, 86, 1, 16, 3,  9, 0, 15, 5, 58, 6,  3, 7, 22, 2, 42, 4,  1, 
    1, 99, 7, 47, 4, 68, 8, 23, 0, 17, 3,  1, 2, 16, 6, 72, 5, 13, 
    3, 96, 7, 32, 2, 38, 6, 18, 8, 33, 5, 37, 0, 11, 1, 46, 4, 77, 
    2, 18, 4, 76, 0, 96, 7, 39, 5, 77, 6,  2, 3, 29, 1, 47, 8, 65
  };
  const int q7059[] = {
    9, 9, // Number of jobs and machines
    2, 69, 6,  8, 8, 62, 7, 79, 1,  7, 3, 97, 4, 73, 0, 42, 5, 33, 
    0, 45, 2, 45, 8, 74, 7, 52, 5, 60, 6, 13, 3, 80, 4, 34, 1, 90, 
    1, 45, 4, 79, 8, 90, 0, 74, 7, 35, 6, 25, 3, 85, 2,  6, 5, 44, 
    4, 26, 5, 27, 1, 90, 8, 36, 6, 77, 7, 67, 0, 98, 2,  5, 3, 95, 
    7, 21, 3, 65, 0, 61, 2, 86, 4, 39, 5, 28, 6, 37, 8, 40, 1, 85, 
    7, 91, 4,  6, 3,  7, 1, 85, 5, 52, 8, 95, 6, 62, 2, 35, 0, 69, 
    6,  2, 8, 75, 1, 59, 5, 86, 7, 75, 3, 52, 2,  4, 4, 66, 0, 15, 
    2, 12, 7, 29, 4, 53, 1, 21, 3, 61, 6, 38, 0, 30, 8, 53, 5, 27, 
    0, 37, 6,  7, 4, 46, 2, 36, 3, 65, 8, 38, 1, 94, 7, 16, 5, 12
  };
  const int q7060[] = {
    9, 9, // Number of jobs and machines
    1, 16, 2, 13, 8, 36, 0, 91, 4, 37, 3, 15, 5,  9, 7, 46, 6, 61, 
    3, 91, 1, 35, 8, 27, 5, 66, 6, 46, 7, 21, 4, 14, 0, 99, 2, 53, 
    1, 11, 0, 82, 2, 47, 6, 20, 5,  8, 7, 24, 8, 60, 4, 52, 3, 11, 
    4,  3, 1, 65, 0, 53, 3, 99, 2, 86, 7, 74, 5, 90, 8, 70, 6, 88, 
    2, 33, 8, 12, 3, 88, 1, 15, 0, 91, 4, 36, 6, 33, 5, 63, 7, 17, 
    7, 26, 8, 56, 4, 81, 3, 27, 5, 34, 0, 50, 2, 39, 1, 13, 6, 47, 
    4,  3, 8, 41, 7, 15, 6, 10, 3, 62, 0, 33, 1,  5, 5, 78, 2, 51, 
    8, 32, 1, 20, 0, 45, 7, 13, 3,  6, 5, 35, 2, 67, 6, 64, 4,  5, 
    7, 14, 5, 95, 6,  5, 2, 70, 1, 91, 3, 10, 4, 17, 8, 82, 0,  3
  };
  const int q7061[] = {
    9, 9, // Number of jobs and machines
    8, 80, 5, 89, 2, 15, 3, 62, 7, 58, 0, 10, 6, 22, 4, 67, 1, 77, 
    0, 39, 6, 62, 2, 21, 4, 15, 1, 26, 5, 59, 8, 76, 3, 76, 7, 89, 
    3, 74, 4, 29, 5, 72, 2, 73, 0, 55, 1, 15, 6, 97, 8, 22, 7, 92, 
    5, 91, 0, 30, 3, 16, 7, 40, 4, 55, 1, 39, 8, 99, 6, 89, 2, 60, 
    1, 22, 5, 96, 6, 83, 3, 47, 2, 41, 7, 94, 0, 81, 8, 50, 4,  5, 
    8, 74, 0, 49, 1, 91, 3, 69, 5, 80, 7, 89, 2, 57, 4, 28, 6, 28, 
    8, 28, 6, 82, 2, 70, 3, 41, 7, 38, 4,  6, 5, 84, 0, 16, 1, 68, 
    1, 43, 4, 63, 3, 18, 7, 82, 2, 69, 6, 61, 0, 93, 5, 34, 8, 78, 
    5, 27, 3, 87, 7, 18, 2, 71, 6, 71, 8, 95, 4, 69, 0, 30, 1, 63
  };
  const int q7062[] = {
    9, 9, // Number of jobs and machines
    6, 46, 4, 58, 0, 82, 3,  3, 7, 73, 1, 49, 2,  6, 5, 11, 8, 76, 
    3, 68, 2, 59, 8, 59, 4, 37, 5, 40, 6, 96, 0, 89, 1, 83, 7, 99, 
    5, 47, 8, 23, 3, 75, 0, 95, 2, 33, 1, 96, 4, 56, 7, 70, 6, 12, 
    2, 67, 8, 15, 7, 46, 6, 62, 3, 86, 0, 18, 5, 51, 4,  1, 1, 50, 
    3, 93, 5, 99, 1,  1, 6, 77, 0, 40, 8, 34, 7, 84, 2, 83, 4, 48, 
    5, 89, 8, 91, 0, 46, 1,  8, 2, 77, 4, 25, 7, 70, 6, 19, 3, 47, 
    2, 40, 4, 46, 1, 41, 5, 18, 0, 36, 8, 60, 6, 93, 3, 68, 7, 67, 
    5, 20, 4, 20, 1, 50, 6, 43, 3, 48, 0, 85, 8, 79, 7, 10, 2, 98, 
    4, 33, 2, 68, 6, 61, 1, 54, 0, 62, 3, 58, 5, 22, 7, 54, 8, 56
  };
  const int q7063[] = {
    9, 9, // Number of jobs and machines
    8, 70, 4, 76, 0, 61, 2, 50, 3, 45, 6, 44, 5, 84, 1, 56, 7, 93, 
    2, 71, 7, 55, 5, 25, 3, 73, 0, 88, 1, 69, 8, 86, 6, 16, 4, 43, 
    5, 23, 7, 61, 0, 25, 2, 80, 8, 44, 1, 69, 4, 42, 6, 38, 3, 40, 
    8, 47, 4, 10, 5, 79, 2, 76, 1, 94, 7, 10, 6, 87, 0, 21, 3, 75, 
    8, 21, 1, 26, 5, 33, 7, 93, 3,  6, 4, 52, 2,  5, 6, 54, 0, 61, 
    2, 18, 5, 35, 3, 25, 8, 99, 6,  6, 4, 92, 1, 94, 0, 19, 7, 95, 
    2, 47, 6, 61, 1, 57, 3, 13, 8, 18, 5,  2, 4, 92, 0, 33, 7, 50, 
    0, 15, 2, 74, 3, 11, 4, 85, 7, 30, 8, 75, 1, 83, 5, 84, 6, 70, 
    4, 71, 2, 40, 3, 81, 5, 46, 7, 91, 6, 87, 1, 47, 0, 92, 8, 59
  };
  const int q7064[] = {
    9, 9, // Number of jobs and machines
    3, 52, 5,  5, 8, 74, 2, 37, 1, 87, 7, 87, 4, 26, 0, 10, 6,  5, 
    6, 80, 5, 92, 8, 38, 2, 99, 4, 92, 3, 72, 7, 51, 0, 38, 1, 70, 
    5, 30, 1, 72, 3,  1, 6, 47, 7, 79, 2, 73, 4, 40, 0, 67, 8, 24, 
    0, 63, 1, 27, 4, 91, 6, 23, 8, 53, 3, 36, 7, 14, 5, 84, 2, 75, 
    0, 74, 4, 26, 8, 24, 2, 91, 6, 99, 5, 73, 7, 88, 3, 11, 1, 51, 
    3, 53, 6, 45, 5, 32, 7, 47, 0, 38, 8, 35, 4, 22, 1, 23, 2, 54, 
    4, 25, 7,  4, 2, 68, 1, 54, 8, 14, 6, 83, 0, 57, 5, 44, 3, 32, 
    1, 14, 7, 17, 4, 65, 8, 10, 0, 86, 6, 28, 2, 19, 5, 34, 3, 70, 
    5,  8, 4, 51, 7, 65, 8, 31, 0, 52, 1,  3, 3, 90, 6, 70, 2, 15
  };
  const int q7065[] = {
    9, 9, // Number of jobs and machines
    2, 65, 6, 29, 7, 15, 8, 22, 1, 76, 0, 61, 4, 93, 5, 69, 3, 88, 
    7, 89, 6, 98, 5, 74, 0, 91, 2, 28, 8, 16, 4,  7, 3, 14, 1,  7, 
    4, 90, 3, 69, 5, 47, 1, 52, 7, 60, 8, 26, 6,  4, 0, 32, 2, 35, 
    7, 73, 3, 76, 5, 15, 8,  2, 6, 40, 1, 80, 2, 56, 4, 72, 0, 26, 
    7, 72, 5,  1, 8, 97, 3, 97, 4, 78, 6, 67, 1, 31, 2, 14, 0, 68, 
    5, 72, 1,  3, 2, 12, 3, 36, 6, 23, 8, 51, 0, 95, 7, 53, 4, 89, 
    0, 55, 5,  8, 3, 15, 7, 38, 1, 10, 2, 67, 4, 21, 6, 51, 8, 14, 
    8,  9, 2, 65, 1, 54, 3, 63, 7, 75, 0, 57, 4, 16, 6, 88, 5, 57, 
    1, 29, 6, 21, 7, 65, 2, 66, 3, 13, 5,  6, 4, 82, 8, 44, 0, 62
  };
  const int q7066[] = {
    9, 9, // Number of jobs and machines
    7, 26, 0, 97, 4, 89, 5, 79, 6, 87, 1, 36, 2, 67, 3,  3, 8, 96, 
    3, 78, 1, 31, 6, 74, 0, 30, 4,  8, 7, 36, 2, 95, 5, 65, 8, 94, 
    0, 60, 2, 82, 8, 10, 4, 34, 1, 85, 5, 86, 3, 35, 7, 97, 6, 60, 
    8, 26, 6, 36, 7, 45, 3, 61, 2, 21, 0, 67, 4, 11, 5, 24, 1, 79, 
    5, 69, 4, 68, 6, 24, 3, 69, 8, 98, 0, 67, 2, 31, 7, 34, 1, 88, 
    1, 28, 6, 40, 3, 22, 4, 55, 0, 52, 5, 81, 2, 70, 8, 69, 7, 25, 
    8, 14, 1, 85, 5, 31, 2, 79, 4,  1, 7, 50, 6, 24, 3,  5, 0, 65, 
    0, 46, 2, 57, 8, 44, 3, 67, 7, 10, 6, 82, 4, 44, 1, 25, 5, 92, 
    2, 32, 0, 24, 1,  4, 4, 95, 8, 62, 7, 19, 5, 55, 3, 36, 6, 15
  };
  const int q7067[] = {
    9, 9, // Number of jobs and machines
    8, 52, 3, 83, 1, 77, 0, 32, 4, 95, 2, 21, 6,  4, 7,  1, 5, 81, 
    7, 47, 1, 36, 5,  9, 3, 67, 4, 61, 0, 49, 2, 96, 6, 74, 8, 24, 
    5, 16, 6, 42, 4, 75, 1, 64, 8, 79, 0, 41, 7, 13, 2, 38, 3, 57, 
    8, 36, 6, 75, 4, 27, 7, 72, 3, 75, 5, 43, 0, 56, 2,  3, 1, 28, 
    6, 25, 7,  5, 3, 65, 2, 73, 0, 76, 4, 80, 8, 85, 5, 35, 1, 31, 
    5, 41, 3, 85, 6, 37, 1, 38, 8, 23, 2,  1, 0, 90, 7, 19, 4, 62, 
    8, 37, 4, 58, 0, 70, 2, 99, 7, 34, 1, 23, 6,  5, 5, 46, 3, 82, 
    5, 17, 7, 59, 8, 39, 4, 48, 2, 33, 1, 34, 6, 94, 3, 32, 0, 20, 
    2, 59, 4, 54, 6, 76, 3, 23, 8,  9, 5, 21, 7, 93, 0,  7, 1, 24
  };
  const int q7068[] = {
    9, 9, // Number of jobs and machines
    0, 97, 6, 25, 8, 23, 3, 36, 2, 97, 7, 73, 4, 18, 5,  6, 1, 32, 
    2,  9, 3, 97, 6, 89, 7, 40, 0, 49, 4, 77, 5, 77, 1, 21, 8, 86, 
    8, 98, 6, 75, 5, 24, 4, 84, 7,  8, 0, 23, 3, 53, 2, 33, 1, 25, 
    3, 35, 5, 98, 2, 38, 1, 98, 4, 88, 0, 80, 6, 39, 8, 91, 7, 66, 
    7, 70, 4, 85, 3, 91, 0, 56, 6, 83, 8, 98, 5, 52, 2, 68, 1,  6, 
    2,  9, 4, 49, 5, 82, 8, 69, 6, 96, 0, 10, 3, 59, 7,  7, 1, 68, 
    2,  8, 5, 20, 8, 87, 7,  8, 0,  8, 4, 90, 3, 37, 6, 52, 1, 82, 
    5, 86, 3, 61, 7, 97, 8, 62, 2, 98, 6, 72, 4, 17, 1, 41, 0, 68, 
    2, 70, 6,  9, 7, 17, 0, 32, 3, 26, 1, 64, 4, 16, 8,  3, 5, 36
  };
  const int q7069[] = {
    9, 9, // Number of jobs and machines
    1, 36, 4, 27, 2, 56, 8, 66, 5, 14, 6, 36, 7, 77, 0, 55, 3, 56, 
    0, 31, 1, 31, 4, 95, 7, 65, 5, 85, 3, 15, 6, 18, 2, 81, 8,  3, 
    3, 27, 4, 39, 0, 10, 8, 99, 1, 33, 5, 57, 2, 73, 6, 86, 7,  3, 
    7, 50, 3, 38, 2, 60, 8,  2, 0, 81, 6, 30, 4, 59, 5, 21, 1, 93, 
    1,  3, 0, 42, 2, 17, 6, 80, 8, 12, 4, 24, 3, 15, 5, 97, 7, 45, 
    4, 68, 2,  9, 0, 68, 8, 23, 6,  7, 3, 15, 1, 10, 5, 82, 7, 24, 
    0, 26, 6, 45, 2, 83, 1,  1, 5, 24, 3, 13, 8, 93, 7, 67, 4,  1, 
    5, 64, 3, 33, 4, 42, 7, 65, 2, 78, 6, 83, 1, 22, 0, 39, 8, 65, 
    6, 31, 3, 64, 5, 64, 4, 27, 0, 60, 7, 66, 8, 29, 2, 27, 1,  1
  };
  const int q7070[] = {
    9, 9, // Number of jobs and machines
    0, 77, 7, 26, 4, 50, 2, 94, 3, 54, 1, 49, 6, 11, 5,  2, 8, 14, 
    0, 85, 2, 81, 7, 12, 3, 45, 4, 22, 6, 20, 1, 88, 8, 37, 5,  8, 
    6, 30, 2, 65, 7, 62, 4,  8, 0, 50, 3, 28, 1, 92, 5, 66, 8, 51, 
    8, 97, 4, 75, 6, 61, 7, 30, 3, 19, 1, 32, 2, 15, 5, 59, 0, 75, 
    3, 10, 4, 68, 7, 80, 6, 42, 2,  1, 0, 18, 5, 86, 8, 41, 1, 36, 
    4, 21, 3, 77, 2, 92, 0, 88, 6, 80, 5, 27, 1, 19, 8, 49, 7, 83, 
    5, 26, 8, 37, 6, 91, 0, 66, 3, 27, 2, 10, 1, 24, 4, 21, 7, 70, 
    7, 70, 3,  5, 5, 10, 8, 96, 2, 38, 6, 91, 4,  4, 1, 46, 0, 79, 
    5, 90, 4, 86, 7, 20, 0, 65, 6, 33, 1, 75, 2, 17, 3, 27, 8, 32
  };
  const int q7071[] = {
    9, 9, // Number of jobs and machines
    7, 30, 3, 28, 1,  7, 0, 53, 5, 68, 6, 36, 8, 43, 2, 73, 4, 26, 
    6, 80, 0, 82, 1, 15, 2, 15, 4, 83, 5, 16, 8, 33, 7, 51, 3, 92, 
    6, 92, 7, 21, 0, 11, 4, 81, 2, 11, 8, 17, 5, 11, 3, 86, 1, 80, 
    3, 10, 0, 22, 8, 65, 6, 48, 4, 62, 2, 72, 7,  9, 1, 80, 5, 87, 
    0, 46, 6, 72, 7, 94, 2, 46, 1, 73, 3,  5, 8, 92, 4,  6, 5, 51, 
    1,  9, 0, 73, 4, 29, 6, 31, 2, 11, 5, 63, 8, 39, 7, 56, 3, 10, 
    1, 68, 2, 65, 5, 21, 8, 89, 4, 86, 7, 67, 6, 46, 0, 94, 3,  5, 
    8, 33, 5, 45, 7, 74, 0, 24, 4, 55, 6, 64, 1, 73, 2, 20, 3, 88, 
    6, 97, 4, 43, 7, 98, 2, 89, 3, 59, 8, 10, 0, 88, 5, 28, 1, 24
  };
  const int q7072[] = {
    9, 9, // Number of jobs and machines
    7, 12, 2, 58, 3,  3, 1, 50, 0, 80, 5, 11, 8, 41, 4, 18, 6,  4, 
    4, 98, 1, 98, 3, 98, 2, 89, 6, 12, 8, 57, 0, 16, 7, 50, 5, 11, 
    4, 58, 7, 82, 6, 43, 0, 54, 2, 64, 1, 59, 8, 35, 3, 27, 5, 29, 
    6, 26, 5, 84, 3, 56, 1, 92, 7, 45, 4, 50, 2, 92, 0, 90, 8, 32, 
    4, 80, 3, 79, 1, 20, 6, 90, 7, 10, 5, 71, 0, 23, 8, 54, 2, 51, 
    1, 62, 5,  4, 8, 60, 6, 42, 3, 63, 7, 11, 0, 71, 2, 40, 4,  7, 
    8, 53, 6, 99, 2, 72, 7, 92, 1, 29, 5, 78, 3, 40, 0, 21, 4, 24, 
    6, 75, 8, 53, 5, 50, 0, 60, 2, 56, 3, 65, 7,  4, 1, 71, 4, 96, 
    0, 45, 1, 12, 7, 98, 8, 30, 3, 23, 4, 54, 2, 81, 6, 37, 5,  5
  };
  const int q7073[] = {
    9, 9, // Number of jobs and machines
    0, 21, 6, 64, 5, 69, 7, 43, 4, 50, 8,  3, 3, 72, 2, 43, 1, 66, 
    1, 46, 6, 57, 5,  6, 0, 33, 4, 94, 8, 23, 7, 89, 3, 34, 2, 13, 
    8, 69, 7, 42, 5, 69, 3,  1, 0, 87, 4, 99, 1, 43, 6,  3, 2,  3, 
    6,  5, 3, 22, 7, 91, 4, 34, 2, 74, 5, 98, 0, 24, 8, 96, 1, 13, 
    1, 76, 7, 17, 5, 39, 2, 22, 3, 92, 0, 83, 4, 78, 8, 80, 6, 97, 
    3, 61, 1, 69, 5, 14, 0, 66, 4, 10, 6, 14, 7, 58, 2, 22, 8, 44, 
    6, 32, 3, 36, 7,  3, 8, 15, 2, 64, 1, 96, 4, 79, 0, 39, 5,  1, 
    0, 55, 8, 51, 2,  7, 5, 45, 3, 35, 7, 61, 1, 48, 4, 41, 6, 12, 
    5, 90, 0,  2, 6, 60, 4,  5, 7, 85, 3, 11, 2, 54, 8, 88, 1, 75
  };
  const int q7074[] = {
    9, 9, // Number of jobs and machines
    7, 46, 4, 18, 5, 15, 3, 96, 6, 29, 8, 67, 2, 80, 1, 68, 0, 79, 
    2, 96, 8, 21, 3, 17, 6, 28, 1, 69, 7,  5, 4, 59, 5, 26, 0, 62, 
    8, 70, 3, 46, 1,  6, 5, 24, 4, 13, 7, 76, 6, 61, 2, 64, 0, 63, 
    4, 89, 5, 83, 7, 97, 8, 18, 1, 32, 2,  8, 0, 26, 6, 56, 3, 24, 
    4,  8, 5, 99, 1, 59, 3, 36, 7,  7, 6, 54, 0,  6, 2, 70, 8, 62, 
    4,  2, 1, 49, 5, 52, 2, 18, 0, 20, 6, 79, 8, 36, 3, 29, 7, 19, 
    1, 36, 7, 73, 8, 43, 2, 23, 5, 28, 0, 26, 6, 44, 4, 89, 3, 44, 
    6,  5, 3, 70, 4, 96, 8, 77, 0, 32, 5, 73, 7, 39, 1, 41, 2, 82, 
    8, 90, 3, 29, 1, 52, 4, 83, 7, 67, 2, 37, 0, 90, 5, 72, 6, 74
  };
  const int q7075[] = {
    9, 9, // Number of jobs and machines
    4,  5, 6, 99, 7, 69, 2, 76, 1,  5, 0, 44, 5, 84, 3, 62, 8, 92, 
    0, 77, 5, 71, 4, 17, 6, 35, 7, 40, 8, 67, 1, 49, 3, 89, 2,  1, 
    7, 13, 6, 94, 4, 20, 3, 91, 1, 58, 5, 69, 8, 48, 2, 67, 0, 69, 
    4, 35, 6, 70, 5, 39, 3, 40, 7, 78, 1, 44, 0, 66, 2, 24, 8, 57, 
    0, 70, 1, 48, 8,  6, 4, 39, 3, 47, 5, 66, 6, 16, 2, 47, 7, 54, 
    5, 44, 4, 32, 8, 28, 2, 28, 0, 36, 1, 91, 6, 96, 7, 17, 3, 43, 
    4, 11, 1, 16, 0, 52, 5, 27, 7, 52, 2, 62, 3, 18, 8, 15, 6, 84, 
    5, 44, 0,  8, 4, 80, 8, 93, 1, 93, 7, 80, 3, 77, 6, 22, 2, 17, 
    5, 71, 8, 19, 7, 48, 4, 91, 6,  2, 3, 16, 0, 25, 2,  7, 1,  9
  };
  const int q7076[] = {
    9, 9, // Number of jobs and machines
    4, 19, 7, 61, 2, 51, 5, 39, 0, 98, 6, 65, 1, 10, 8, 26, 3, 43, 
    8, 89, 6, 74, 1, 60, 2, 71, 4, 79, 3, 37, 7,  2, 5, 61, 0, 30, 
    7, 30, 6, 10, 5, 15, 3, 13, 2,  2, 0,  1, 4, 73, 8, 22, 1, 37, 
    2, 66, 4, 21, 5, 98, 3, 55, 1, 13, 6, 16, 8, 66, 0,  8, 7, 64, 
    5, 98, 1, 78, 0, 37, 4, 70, 8, 38, 3, 65, 6, 49, 7, 50, 2, 79, 
    2, 54, 3, 30, 8,  7, 4, 21, 0, 53, 6, 92, 5, 93, 1, 92, 7, 87, 
    7, 61, 3, 95, 0, 82, 8, 68, 1, 86, 5, 19, 2, 12, 4, 63, 6, 20, 
    1, 93, 6, 25, 2, 43, 5, 72, 8, 31, 3, 44, 4, 12, 0,  3, 7, 99, 
    3, 32, 6, 44, 4,  1, 5, 32, 8, 80, 0, 89, 2, 89, 1, 49, 7, 49
  };
  const int q7077[] = {
    9, 9, // Number of jobs and machines
    4, 62, 3,  4, 5, 27, 6, 26, 7, 87, 8, 41, 0, 67, 1, 66, 2, 48, 
    2,  5, 6, 46, 1, 69, 4, 67, 0, 58, 5,  5, 7, 80, 3, 73, 8,  9, 
    7, 10, 4, 37, 8, 13, 6, 47, 0, 99, 2, 52, 3, 47, 5, 41, 1, 26, 
    4, 34, 8, 84, 5, 19, 7, 69, 1, 60, 0, 68, 6, 17, 3, 40, 2, 84, 
    8, 64, 3, 16, 0, 11, 1, 11, 4, 98, 7, 54, 6, 28, 5, 23, 2, 77, 
    7,  1, 2, 65, 6, 71, 5, 88, 1, 33, 8, 87, 4, 29, 0, 70, 3, 27, 
    6, 18, 1, 28, 2, 50, 0, 80, 4, 81, 5, 35, 3, 48, 8, 38, 7, 41, 
    1, 24, 4, 63, 2, 17, 5, 92, 6, 20, 3, 81, 8, 78, 0,  6, 7, 46, 
    2, 45, 5, 68, 4, 58, 0, 82, 6, 33, 8, 43, 3, 71, 1, 92, 7, 50
  };
  const int q7078[] = {
    9, 9, // Number of jobs and machines
    6, 27, 3, 36, 1, 34, 8, 42, 2, 96, 0,  7, 5,  3, 7, 41, 4, 53, 
    1,  4, 6, 92, 8, 21, 0, 43, 5,  6, 7, 66, 2, 91, 3, 40, 4, 38, 
    5, 68, 2, 27, 8,  6, 1,  4, 3, 25, 7, 55, 4, 15, 6, 35, 0, 28, 
    8, 51, 2, 93, 7, 29, 3, 98, 6, 26, 5, 90, 1, 58, 0, 30, 4, 95, 
    2, 70, 5, 47, 8, 97, 1, 20, 7, 71, 4, 51, 6,  8, 3, 28, 0, 75, 
    3, 94, 6,  8, 8, 18, 2, 60, 7, 89, 1, 51, 5, 63, 4, 96, 0,  8, 
    1, 74, 8, 45, 4, 36, 2, 82, 5, 40, 3, 24, 0, 43, 6,  5, 7, 53, 
    7, 37, 2, 57, 1, 27, 0, 69, 6, 47, 3, 53, 4, 21, 8, 40, 5, 35, 
    5, 77, 7, 15, 6, 54, 0, 64, 4, 54, 3, 49, 8, 94, 2, 65, 1, 21
  };
  const int q7079[] = {
    9, 9, // Number of jobs and machines
    1, 43, 6, 85, 3, 29, 7,  5, 2, 62, 4, 52, 5, 81, 0, 13, 8, 12, 
    7, 41, 1, 60, 8, 11, 5, 84, 2, 46, 4, 58, 6, 74, 3, 26, 0, 46, 
    3,  6, 2, 30, 8,  8, 6, 82, 7, 87, 4, 35, 1, 79, 5, 40, 0, 92, 
    0, 47, 3, 60, 8, 80, 5, 30, 7, 51, 1, 94, 2, 63, 6, 91, 4, 18, 
    4, 42, 2, 13, 7, 59, 5, 65, 3, 55, 0, 25, 1, 41, 8, 30, 6, 82, 
    5, 35, 6, 32, 3,  2, 2, 63, 0, 14, 7, 24, 1, 69, 4, 34, 8, 64, 
    1, 42, 7, 46, 5, 62, 2, 13, 8, 15, 6, 57, 4, 68, 3, 19, 0, 91, 
    8, 40, 7, 84, 1, 82, 5, 87, 0, 79, 2, 26, 6, 78, 4, 61, 3, 49, 
    4, 48, 0, 80, 1,  5, 6, 25, 8, 65, 2,  5, 7, 61, 3, 70, 5, 34
  };
  const int q7080[] = {
    9, 9, // Number of jobs and machines
    4, 38, 7, 20, 3, 79, 0, 32, 8, 45, 2,  4, 5, 47, 1, 42, 6, 85, 
    0, 16, 2, 70, 8, 30, 6, 69, 1, 64, 4, 38, 3, 70, 7, 77, 5, 85, 
    3, 54, 2, 28, 4, 11, 6, 70, 0, 41, 1, 40, 5, 91, 8, 58, 7, 17, 
    5,  3, 2, 91, 8, 32, 7, 41, 6, 46, 0, 30, 3, 72, 1, 49, 4, 74, 
    0, 82, 7, 19, 3, 82, 6, 65, 8, 77, 2, 84, 1, 91, 5, 63, 4, 18, 
    1,  3, 0, 53, 3,  2, 5, 49, 4, 63, 7, 51, 6, 99, 2, 38, 8, 47, 
    2, 24, 4, 90, 5, 55, 6, 58, 7, 79, 3, 20, 1, 97, 8, 55, 0, 20, 
    1, 27, 2, 66, 3, 54, 7, 42, 6, 22, 0, 49, 4, 15, 8, 32, 5, 10, 
    6, 14, 8, 31, 7, 88, 5, 33, 1, 85, 2, 94, 4, 36, 3, 63, 0, 75
  };
  const int q7081[] = {
    9, 9, // Number of jobs and machines
    7, 54, 3, 19, 0, 93, 2, 95, 5,  1, 6, 53, 8, 13, 4, 10, 1, 76, 
    1, 59, 0, 21, 2, 65, 8, 22, 7, 91, 4, 68, 5, 74, 6, 96, 3, 16, 
    5, 24, 0, 99, 1, 28, 8, 93, 6, 34, 7, 74, 2, 72, 4, 38, 3, 86, 
    2, 86, 3, 50, 8, 37, 6, 68, 0, 43, 4, 87, 5, 74, 7, 34, 1, 42, 
    6,  2, 4, 72, 7, 98, 3, 35, 0, 22, 8, 37, 1,  3, 2,  3, 5, 53, 
    0, 55, 5, 34, 2, 72, 6, 79, 8,  9, 7, 91, 4, 61, 3,  6, 1, 51, 
    2, 35, 8, 13, 1, 22, 4, 60, 3, 29, 6, 22, 7, 78, 5, 20, 0, 56, 
    3, 25, 2, 95, 0, 68, 1, 91, 4, 38, 5, 65, 6, 71, 7, 66, 8, 79, 
    4, 49, 8,  1, 2, 96, 3, 95, 5, 43, 1, 58, 7, 78, 6, 56, 0, 89
  };
  const int q7082[] = {
    9, 9, // Number of jobs and machines
    4, 23, 3, 92, 6, 34, 2, 93, 5, 11, 1, 91, 7, 45, 8, 77, 0, 20, 
    4, 78, 1, 30, 0, 41, 7, 87, 2, 10, 3, 52, 6, 58, 5, 59, 8, 59, 
    8, 64, 6, 72, 2, 45, 4, 43, 3,  3, 7, 93, 1, 71, 0, 27, 5, 97, 
    6, 72, 5, 92, 4, 35, 2, 56, 1,  2, 3, 68, 8, 78, 7, 11, 0, 93, 
    7, 49, 3, 40, 1, 40, 4, 58, 8, 38, 5, 98, 2, 59, 0, 61, 6, 43, 
    6,  5, 8, 90, 1, 16, 4, 74, 5, 76, 7, 39, 0, 18, 2, 88, 3, 62, 
    3, 58, 7, 25, 4, 49, 5, 27, 8, 64, 2, 79, 0, 60, 6, 73, 1, 50, 
    2, 17, 6,  9, 1, 91, 0, 80, 7, 82, 8, 85, 5, 57, 3, 13, 4, 70, 
    1, 16, 4, 33, 2,  7, 5, 34, 8, 80, 7, 85, 6, 29, 3, 93, 0, 63
  };
  const int q7083[] = {
    9, 9, // Number of jobs and machines
    4, 10, 7, 19, 1, 91, 6, 55, 8, 63, 0, 98, 5, 47, 2, 71, 3, 10, 
    2, 78, 7, 55, 8, 93, 1, 52, 6, 84, 3, 94, 5, 17, 4, 99, 0, 85, 
    5, 64, 0, 56, 1,  3, 8, 21, 6, 96, 7, 53, 3, 34, 2, 60, 4, 87, 
    5, 76, 4, 68, 6, 95, 0, 70, 7, 56, 1, 68, 2, 79, 3, 84, 8,  4, 
    3,  1, 0, 26, 6, 62, 2, 78, 4, 32, 5, 34, 8, 64, 7, 52, 1, 81, 
    0, 80, 3, 55, 2, 94, 6, 85, 5, 42, 4, 76, 7, 51, 1, 79, 8, 38, 
    4, 77, 3, 72, 7, 72, 6, 92, 8, 17, 5, 52, 0, 18, 2, 26, 1, 65, 
    5, 43, 1, 21, 4, 86, 7, 74, 8, 41, 6, 62, 0, 45, 3, 35, 2, 57, 
    4, 52, 8, 42, 7, 12, 6, 59, 3, 49, 0, 16, 5, 88, 1, 88, 2, 50
  };
  const int q7084[] = {
    9, 9, // Number of jobs and machines
    7, 13, 0, 99, 5, 88, 3, 29, 4,  7, 2, 24, 8, 76, 6, 63, 1, 53, 
    2, 20, 7, 61, 0, 33, 3, 24, 6, 88, 5, 31, 4, 42, 8, 74, 1, 60, 
    0, 54, 1, 11, 5, 68, 4, 29, 2, 86, 8, 63, 7,  5, 3, 84, 6, 41, 
    8, 62, 6, 54, 1, 99, 7,  8, 3, 97, 2, 70, 0, 42, 5, 74, 4, 55, 
    7, 64, 2, 18, 8, 71, 5, 41, 6, 38, 4, 44, 1,  9, 0,  9, 3, 21, 
    2,  5, 4, 35, 0, 11, 3, 11, 6, 56, 8, 71, 5, 38, 1, 68, 7, 55, 
    2, 92, 6, 74, 1, 19, 4, 90, 8, 10, 3, 59, 0, 62, 7, 57, 5, 40, 
    1, 34, 6, 81, 3, 11, 7, 34, 0, 39, 8, 75, 2, 88, 4, 55, 5, 60, 
    0, 68, 1, 96, 4,  6, 7, 96, 6, 23, 3, 94, 5, 75, 8, 34, 2, 32
  };
  const int q7085[] = {
    9, 9, // Number of jobs and machines
    0, 80, 3, 76, 2,  7, 6,  4, 8, 65, 5, 89, 7, 68, 4, 62, 1, 55, 
    8, 77, 2, 38, 0, 46, 4, 82, 7, 71, 5, 40, 1, 51, 6, 76, 3, 29, 
    7, 86, 4, 32, 0, 24, 5, 17, 3, 62, 8,  5, 2, 96, 6, 86, 1, 55, 
    7, 20, 6,  9, 3, 14, 4, 36, 1, 70, 2, 99, 0, 94, 8, 43, 5, 73, 
    3, 98, 5, 23, 1, 42, 4,  6, 6, 81, 0, 27, 8,  6, 2, 99, 7, 69, 
    1, 10, 0, 60, 6, 52, 2, 41, 4, 25, 5, 21, 7, 73, 8, 77, 3, 43, 
    3, 80, 0, 24, 4, 74, 8, 83, 5, 56, 7, 71, 6, 16, 2, 10, 1, 88, 
    0, 70, 6, 70, 7, 12, 1, 71, 4, 84, 3,  1, 2, 91, 8, 47, 5, 24, 
    1, 38, 7, 24, 0, 17, 6, 30, 4,  5, 3, 78, 2, 82, 8, 99, 5, 37
  };
  const int q7086[] = {
    9, 9, // Number of jobs and machines
    6, 90, 3, 18, 5, 15, 1, 70, 2, 95, 7, 94, 0, 19, 4, 40, 8, 64, 
    7, 37, 1,  3, 5, 35, 0, 73, 6,  8, 8, 90, 3, 61, 2, 27, 4, 21, 
    8, 26, 5,  7, 3, 59, 2, 19, 7, 73, 0, 38, 4, 53, 1, 99, 6, 66, 
    0, 10, 7, 96, 2, 49, 8, 52, 6, 93, 4, 15, 3, 65, 1, 50, 5, 64, 
    8, 19, 5, 32, 7,  9, 4, 10, 1, 23, 2, 14, 6, 39, 0, 96, 3, 33, 
    4, 55, 3, 79, 1, 80, 2, 88, 5, 50, 0, 37, 6, 49, 8, 30, 7, 77, 
    4,  2, 8, 52, 2, 18, 3, 64, 1,  2, 0, 24, 7, 84, 5, 84, 6, 37, 
    2, 94, 0, 42, 6, 33, 3,  9, 4, 59, 1, 37, 5, 95, 8, 78, 7,  5, 
    1, 99, 6, 89, 7, 51, 5, 78, 3, 55, 0, 56, 2, 33, 8,  6, 4, 31
  };
  const int q7087[] = {
    9, 9, // Number of jobs and machines
    2, 83, 3, 47, 0, 48, 7, 82, 4,  2, 5, 36, 6, 10, 8, 53, 1,  7, 
    2, 64, 0, 21, 1, 80, 4, 99, 3, 58, 6, 49, 5, 90, 7, 70, 8, 20, 
    6, 10, 8, 13, 0, 52, 7, 22, 3, 59, 1, 14, 5, 61, 4, 58, 2, 24, 
    7, 42, 0, 64, 8, 46, 6, 15, 5, 31, 1, 81, 3, 49, 2, 26, 4, 84, 
    2,  1, 1, 77, 7, 23, 3, 13, 4, 16, 8, 98, 5, 41, 0,  5, 6, 36, 
    6, 83, 2, 79, 7, 32, 0, 94, 8, 37, 4, 52, 3, 87, 1, 34, 5, 66, 
    6, 53, 3, 29, 2, 68, 0, 33, 7, 55, 4, 77, 8, 75, 5, 75, 1, 89, 
    8, 59, 5, 17, 7, 73, 6, 69, 0, 80, 4, 24, 3, 31, 1,  8, 2, 40, 
    6, 17, 0, 39, 2, 35, 3, 69, 4, 33, 5, 12, 8, 72, 1, 80, 7, 38
  };
  const int q7088[] = {
    9, 9, // Number of jobs and machines
    1, 79, 2, 55, 7,  5, 4,  2, 6, 66, 0,  3, 5,  9, 8, 46, 3, 72, 
    4, 58, 2, 24, 0, 75, 1, 92, 7, 62, 6,  5, 3, 71, 8, 62, 5, 90, 
    0, 16, 5, 31, 8, 80, 3,  3, 4, 58, 1, 20, 6,  7, 2, 93, 7, 29, 
    1, 87, 5, 71, 6, 42, 7, 58, 4,  7, 8, 89, 2, 60, 0, 53, 3, 96, 
    1, 27, 3, 97, 2, 95, 6, 32, 0, 17, 5, 93, 7,  2, 8, 29, 4, 66, 
    5, 52, 3, 81, 1,  8, 7,  9, 0, 56, 6,  9, 8,  5, 2, 67, 4, 33, 
    1, 90, 2, 98, 3, 75, 8, 43, 6, 74, 5, 47, 0, 98, 4, 36, 7,  8, 
    8, 95, 2, 80, 4, 91, 0, 47, 7,  2, 1, 66, 3, 46, 6, 11, 5, 42, 
    0, 36, 4, 78, 3, 62, 6, 40, 7,  2, 2, 46, 5, 43, 8, 37, 1, 50
  };
  const int q7089[] = {
    9, 9, // Number of jobs and machines
    1, 68, 0, 26, 5, 99, 3, 15, 2, 54, 4, 10, 7,  5, 6, 30, 8, 48, 
    1, 13, 8, 92, 7, 81, 4, 27, 3, 11, 5,  5, 0, 18, 2, 37, 6, 98, 
    5, 69, 8,  2, 3, 46, 1, 11, 4, 57, 2, 39, 6, 49, 7,  9, 0, 23, 
    4, 56, 2, 47, 0, 54, 5, 29, 1, 84, 6, 23, 3, 82, 8, 22, 7,  2, 
    2, 29, 3, 25, 8, 30, 7, 57, 6, 16, 4, 69, 1, 88, 5, 90, 0, 29, 
    8, 36, 1, 91, 0, 21, 6, 50, 5, 92, 4, 24, 3,  6, 2, 37, 7, 34, 
    0, 77, 2, 95, 1, 32, 4, 79, 3, 75, 5, 99, 8,  4, 7, 25, 6, 66, 
    2, 29, 4, 22, 8, 54, 1, 31, 5, 47, 0, 37, 6, 77, 7, 18, 3, 15, 
    8, 18, 6, 36, 1, 82, 2, 29, 3, 21, 4, 81, 0, 33, 5,  8, 7, 24
  };
  const int q7090[] = {
    9, 9, // Number of jobs and machines
    7, 30, 0, 36, 8, 85, 1, 30, 4, 84, 3, 61, 5, 10, 6, 78, 2, 42, 
    2, 34, 8, 13, 3, 93, 0, 31, 5, 86, 7, 13, 4, 10, 6, 29, 1, 19, 
    6,  4, 4, 63, 7, 77, 2, 37, 3, 39, 8,  7, 1, 32, 5, 32, 0, 15, 
    2, 74, 1, 27, 8, 94, 7, 93, 6, 74, 4, 36, 5, 80, 3, 56, 0, 85, 
    7, 37, 1,  9, 6, 54, 5, 13, 4, 89, 8, 82, 2, 59, 3, 82, 0, 77, 
    2, 96, 5, 34, 0, 33, 4, 85, 1,  9, 7, 27, 3, 33, 6, 33, 8, 92, 
    0, 80, 2, 25, 4, 25, 6, 15, 7, 90, 5, 55, 3, 65, 1, 60, 8, 60, 
    0, 87, 4, 39, 6,  4, 1, 99, 7, 51, 8, 39, 2, 66, 5, 21, 3, 67, 
    5, 63, 8, 81, 3, 80, 4, 95, 0,  9, 2, 34, 6, 98, 1, 46, 7, 83
  };
  const int q7091[] = {
    9, 9, // Number of jobs and machines
    0, 66, 4, 35, 3, 77, 1, 84, 6, 58, 7, 55, 5, 37, 2, 40, 8, 38, 
    3, 12, 6, 64, 8, 43, 0, 78, 1, 59, 4,  7, 2, 99, 5, 67, 7, 36, 
    5, 62, 6,  7, 8, 44, 3,  9, 4, 74, 2, 38, 7, 80, 1, 74, 0, 66, 
    4, 11, 6, 11, 1, 48, 8, 91, 5, 19, 7, 35, 0, 95, 3, 40, 2, 31, 
    6, 67, 2, 29, 5, 66, 8, 34, 3, 59, 1, 45, 4, 77, 7,  2, 0, 59, 
    0, 95, 3, 29, 7, 64, 5, 15, 1, 70, 4, 38, 6, 19, 8, 35, 2, 61, 
    1, 17, 7, 96, 6, 56, 3, 47, 4, 97, 2, 74, 0,  9, 8, 82, 5, 73, 
    3, 57, 2, 91, 5, 70, 8, 11, 4, 65, 0, 82, 7, 86, 6, 62, 1, 21, 
    7, 10, 8, 84, 3, 11, 0, 22, 1, 18, 5, 18, 4, 11, 6,  6, 2, 54
  };
  const int q7092[] = {
    9, 9, // Number of jobs and machines
    8, 62, 5, 72, 0, 41, 7, 29, 1,  3, 6, 70, 3, 68, 2, 50, 4, 47, 
    4, 32, 3, 16, 6, 51, 7, 14, 2, 13, 8, 37, 0, 27, 1, 20, 5, 44, 
    2, 93, 4, 42, 7,  4, 6, 39, 8,  2, 1, 15, 5, 29, 0,  8, 3, 16, 
    8, 82, 4, 66, 3, 38, 0, 86, 2, 80, 5, 42, 1, 59, 6, 42, 7, 25, 
    4, 84, 0, 83, 5, 30, 6, 78, 8,  8, 1,  9, 2, 27, 7, 50, 3, 55, 
    0, 92, 2, 39, 8, 47, 3, 24, 1, 80, 6, 60, 5, 71, 7, 55, 4, 29, 
    5, 85, 4, 55, 2, 65, 7, 29, 0, 24, 1, 42, 8, 21, 3, 89, 6, 76, 
    6, 43, 1,  7, 4, 30, 0, 12, 3,  1, 7, 32, 8, 47, 2, 91, 5,  2, 
    4, 19, 2, 66, 7, 78, 0, 56, 5, 96, 6, 12, 1, 46, 8, 16, 3, 57
  };
  const int q7093[] = {
    9, 9, // Number of jobs and machines
    7, 99, 1, 56, 8, 77, 0, 37, 3, 19, 4, 29, 5, 75, 2, 69, 6, 21, 
    7, 15, 0, 83, 8, 98, 5,  5, 2, 37, 3, 52, 6, 60, 1, 60, 4, 66, 
    8, 59, 7, 94, 4,  3, 5, 21, 3,  2, 0, 16, 6, 89, 2, 54, 1, 29, 
    5, 88, 8, 46, 1, 50, 2, 93, 6, 77, 4, 29, 3, 36, 0, 37, 7, 38, 
    2, 62, 7,  8, 8, 62, 5, 33, 6, 79, 3, 45, 0, 89, 4, 73, 1, 61, 
    3, 29, 8, 19, 6, 89, 2, 51, 0, 28, 4, 57, 1, 77, 5, 75, 7,  8, 
    6, 96, 1, 32, 5,  2, 0, 42, 2, 40, 8, 79, 7, 46, 4, 41, 3, 35, 
    7, 73, 5, 50, 0, 71, 3, 19, 2, 15, 6, 99, 8, 65, 4, 80, 1, 26, 
    4, 12, 2, 32, 6,  2, 8, 48, 7, 90, 0, 50, 1, 24, 5, 91, 3, 10
  };
  const int q7094[] = {
    9, 9, // Number of jobs and machines
    3,  2, 1, 56, 2, 13, 7, 89, 5, 35, 0, 17, 4, 39, 8, 98, 6, 13, 
    5, 32, 8, 43, 1, 89, 0, 67, 3, 41, 2, 70, 7, 26, 4, 43, 6, 67, 
    0, 11, 8, 93, 1, 97, 4, 78, 2, 99, 5, 61, 3, 56, 6, 19, 7, 60, 
    8, 84, 0, 62, 5, 17, 7, 95, 2, 54, 4, 45, 1, 27, 6, 23, 3, 18, 
    1, 31, 6, 31, 7, 44, 2, 67, 0, 63, 5, 58, 8,  5, 3, 79, 4, 32, 
    0, 43, 5, 13, 2, 30, 6, 14, 1, 34, 3, 96, 7, 26, 8,  7, 4, 13, 
    1, 45, 8, 20, 4, 33, 2, 85, 0,  1, 7,  7, 3, 77, 5, 16, 6, 83, 
    0, 86, 7, 50, 8,  8, 6, 44, 1, 51, 4, 62, 3, 53, 2, 10, 5,  8, 
    8, 89, 6, 85, 5, 75, 0, 51, 7, 87, 3, 43, 2, 70, 1,  5, 4, 13
  };
  const int q7095[] = {
    9, 9, // Number of jobs and machines
    8, 76, 3, 28, 6, 83, 1, 80, 2, 71, 5, 44, 4, 30, 7, 37, 0, 36, 
    7, 66, 3, 80, 5,  6, 8, 84, 0, 48, 6,  8, 2, 19, 4, 36, 1, 17, 
    8, 29, 4,  1, 3, 71, 2, 19, 0, 48, 5, 62, 1, 32, 7, 45, 6, 47, 
    0, 62, 5, 43, 1, 98, 8, 27, 3, 54, 4, 36, 2, 46, 7, 98, 6, 42, 
    6, 13, 1, 47, 5, 72, 8,  9, 4, 60, 0, 29, 3, 45, 7, 51, 2, 50, 
    0, 45, 7, 44, 5, 24, 4, 57, 6, 51, 2, 61, 8, 71, 1, 56, 3, 41, 
    2, 52, 8,  1, 6, 66, 4, 92, 0, 44, 5, 73, 7, 89, 3, 89, 1, 61, 
    0, 99, 3, 75, 2, 98, 5, 87, 8, 74, 4, 31, 7, 94, 1, 66, 6, 17, 
    3, 70, 5, 36, 0, 58, 8, 37, 2, 33, 6, 76, 7, 61, 1, 48, 4, 40
  };
  const int q7096[] = {
    9, 9, // Number of jobs and machines
    3, 70, 7,  5, 2, 85, 1, 16, 5, 20, 8, 45, 6, 65, 4, 38, 0, 12, 
    3, 91, 6, 98, 7, 96, 5, 23, 2, 85, 8, 49, 0, 76, 4, 95, 1, 35, 
    5, 31, 7, 62, 2, 61, 8, 26, 0, 41, 3, 71, 4, 99, 1, 33, 6, 15, 
    3, 47, 5, 56, 2, 30, 8, 28, 7, 53, 6, 57, 0, 38, 4, 70, 1, 19, 
    0, 14, 5, 81, 6, 40, 3,  8, 8, 30, 1, 20, 7, 28, 2, 34, 4, 10, 
    5,  4, 4, 97, 0, 78, 6, 42, 3, 36, 7, 92, 8, 36, 1, 34, 2, 30, 
    5, 46, 6, 13, 2, 95, 4, 44, 0, 45, 3, 83, 7, 15, 1, 63, 8, 89, 
    5, 19, 4, 77, 6, 51, 7, 90, 1, 82, 8, 25, 2, 39, 0, 79, 3, 73, 
    3, 96, 5, 39, 8, 50, 0, 87, 4, 65, 7, 48, 2, 14, 6, 62, 1, 31
  };
  const int q7097[] = {
    9, 9, // Number of jobs and machines
    0, 82, 1, 36, 6, 70, 2, 81, 4, 20, 8, 76, 5, 97, 3, 20, 7, 64, 
    8, 72, 1, 81, 7, 23, 3, 88, 6, 57, 5, 57, 4, 55, 0, 73, 2, 10, 
    2, 99, 0, 46, 4, 71, 1, 73, 7, 46, 5, 71, 8, 45, 6,  5, 3,  5, 
    5, 59, 7, 97, 8, 44, 6,  1, 4, 81, 2, 39, 3, 93, 1,  2, 0, 21, 
    7, 79, 1, 73, 3, 27, 2, 31, 6, 36, 4, 34, 0, 19, 8, 39, 5, 30, 
    8,  1, 5,  3, 0, 31, 1, 67, 3, 10, 6, 16, 2, 15, 7, 62, 4, 93, 
    2, 88, 3, 91, 1, 62, 5, 92, 7, 13, 6, 56, 8, 48, 0, 60, 4, 56, 
    6,  8, 1,  1, 3, 29, 2,  4, 5, 92, 7, 55, 0, 97, 8, 64, 4, 46, 
    8, 54, 7, 36, 0, 73, 2, 20, 5, 94, 6, 28, 4,  9, 3, 20, 1, 91
  };
  const int q7098[] = {
    9, 9, // Number of jobs and machines
    8, 67, 3, 34, 1, 51, 2, 81, 6, 43, 5, 11, 4, 23, 0,  7, 7, 84, 
    6, 63, 8, 60, 2, 59, 1,  2, 7, 79, 4,  4, 5, 52, 3, 60, 0, 56, 
    3, 25, 7, 67, 4, 19, 2,  6, 8, 30, 1, 21, 0, 40, 5, 35, 6, 78, 
    5, 75, 8, 89, 6, 62, 7, 77, 2, 55, 1, 54, 0, 39, 3, 42, 4, 25, 
    4, 78, 3, 34, 5, 67, 7, 94, 6, 25, 0, 57, 8, 71, 2, 70, 1, 60, 
    2, 92, 4, 29, 5, 23, 1,  8, 8, 26, 6, 67, 7, 51, 0,  4, 3, 67, 
    5, 21, 3, 97, 2, 53, 0, 96, 4,  3, 8, 89, 6,  9, 1, 79, 7, 53, 
    5, 65, 4,  9, 2, 28, 1, 34, 0, 65, 8, 81, 6, 49, 3, 13, 7, 40, 
    8,  6, 7, 78, 6, 91, 4, 56, 2, 48, 0, 64, 5, 24, 3, 22, 1, 46
  };
  const int q7099[] = {
    9, 9, // Number of jobs and machines
    3, 55, 7, 46, 0,  1, 2, 11, 5, 91, 6, 81, 1, 88, 4, 45, 8, 27, 
    2, 14, 5, 87, 7, 36, 3, 17, 8, 79, 4, 64, 1, 35, 0, 12, 6, 57, 
    2, 67, 4, 57, 7, 34, 3, 90, 8,  2, 1, 91, 6, 83, 0, 61, 5, 49, 
    3,  2, 1, 68, 5, 12, 6, 83, 8, 60, 7,  7, 0, 80, 2, 55, 4, 63, 
    0, 69, 7, 75, 6, 87, 1, 74, 5, 36, 4, 59, 8, 16, 3, 53, 2, 98, 
    5, 25, 3,  1, 6, 13, 1, 71, 8, 63, 4,  8, 2, 79, 7, 27, 0, 49, 
    5, 94, 2, 61, 8, 34, 7, 64, 1,  4, 3, 42, 4, 64, 0, 54, 6, 22, 
    3, 37, 6, 40, 4, 97, 5, 91, 7,  3, 1, 49, 8, 41, 0, 71, 2, 12, 
    1,  4, 7, 73, 5, 30, 4, 49, 2, 43, 0, 60, 6, 32, 8, 82, 3, 64
  };
  const int q7100[] = {
    9, 9, // Number of jobs and machines
    8,  5, 6, 47, 4, 32, 7, 43, 1, 52, 2, 63, 3,  4, 0, 32, 5, 11, 
    4, 10, 8,  7, 7, 56, 3, 73, 5, 95, 6, 78, 1, 41, 2, 28, 0, 74, 
    7, 51, 4, 38, 6, 72, 0, 55, 8, 15, 5, 67, 2, 53, 1, 52, 3, 25, 
    8, 42, 4, 18, 0, 48, 6, 64, 7, 83, 3, 65, 2, 38, 1, 39, 5, 11, 
    5, 70, 2, 61, 1, 19, 7, 47, 8, 22, 3, 27, 0,  5, 6,  2, 4, 39, 
    6, 92, 3, 62, 4, 47, 1, 67, 8, 47, 7, 36, 5, 85, 2, 93, 0, 29, 
    2, 45, 5, 70, 7,  3, 1, 12, 0, 98, 3, 96, 4, 31, 6, 72, 8, 56, 
    1, 39, 4,  2, 7, 58, 5, 48, 6,  9, 2, 80, 3,  1, 8, 98, 0, 79, 
    7, 40, 3, 24, 8, 16, 0, 57, 4, 90, 1, 61, 5, 47, 6, 24, 2, 23
  };
  const int q7101[] = {
    9, 9, // Number of jobs and machines
    3, 67, 7, 21, 6, 38, 4, 95, 8, 37, 2,  6, 1, 49, 5, 38, 0, 25, 
    2, 72, 0, 61, 6, 76, 4, 91, 5, 55, 1, 25, 8, 75, 3, 92, 7, 44, 
    6, 89, 8, 60, 7, 99, 1, 89, 0, 60, 3, 66, 5, 71, 4, 67, 2, 81, 
    5, 18, 4, 18, 3, 14, 2, 48, 6, 14, 0, 21, 8, 88, 7, 44, 1, 60, 
    4, 20, 8, 81, 5, 53, 2, 47, 0,  9, 7, 37, 6, 80, 3, 25, 1, 15, 
    8, 20, 2, 49, 7, 33, 5, 33, 0, 56, 3, 66, 1, 73, 6, 24, 4,  3, 
    2, 91, 1, 63, 4, 87, 5, 59, 6, 61, 3, 73, 7, 86, 8, 63, 0, 61, 
    7, 39, 6, 59, 8, 42, 0, 67, 4, 68, 1, 40, 3,  1, 2, 85, 5, 30, 
    1, 71, 5,  3, 2, 23, 3, 21, 7, 91, 0, 10, 4, 86, 8, 36, 6, 85
  };
  const int q7102[] = {
    9, 9, // Number of jobs and machines
    6, 17, 4, 42, 0, 50, 1, 78, 3, 73, 5, 34, 2, 36, 7, 66, 8,  8, 
    3, 90, 1, 69, 6, 49, 7, 36, 4, 95, 2, 24, 8, 22, 0, 37, 5, 91, 
    1, 77, 7, 65, 4, 22, 0, 20, 5, 46, 8, 62, 3, 86, 2, 25, 6, 57, 
    1, 87, 5, 39, 8, 38, 7, 71, 3, 39, 4, 41, 2, 14, 6, 23, 0,  5, 
    0, 60, 7,  4, 1, 34, 4, 91, 2,  5, 8, 44, 6, 94, 3, 46, 5, 83, 
    6, 47, 8, 32, 2, 38, 5, 26, 1, 71, 7, 11, 4, 99, 0, 75, 3, 92, 
    4,  8, 5, 35, 6, 65, 8, 66, 0, 61, 3, 47, 2, 25, 1, 95, 7, 13, 
    2, 97, 5, 90, 7, 11, 4, 19, 3, 39, 1, 44, 6, 21, 8, 76, 0, 87, 
    5, 80, 2, 66, 3, 31, 8, 80, 7, 51, 1, 97, 6, 61, 0, 51, 4,  8
  };
  const int q7103[] = {
    9, 9, // Number of jobs and machines
    3, 57, 0, 51, 8, 88, 2, 24, 7, 29, 4, 40, 1, 42, 5, 16, 6,  4, 
    3, 46, 4, 72, 8,  7, 2, 20, 6,  5, 0, 45, 7, 58, 5, 30, 1, 29, 
    1,  9, 4, 92, 6, 27, 8, 57, 7, 15, 5, 93, 0, 58, 2, 55, 3, 34, 
    2, 23, 0, 39, 7, 41, 8, 78, 4, 87, 5, 46, 6, 67, 3, 25, 1, 58, 
    7, 92, 5, 43, 0, 66, 8, 62, 1, 44, 4, 27, 2, 92, 6, 85, 3, 84, 
    5, 90, 7, 92, 6, 82, 0, 72, 3,  1, 1,  4, 2,  5, 8, 40, 4, 37, 
    1, 63, 0,  6, 4, 13, 2,  3, 5, 25, 7, 82, 6, 89, 3, 73, 8, 62, 
    7, 13, 4, 12, 6, 87, 8, 11, 3, 50, 5, 34, 1,  7, 0, 43, 2, 75, 
    0, 68, 7, 66, 4, 46, 1, 58, 6, 13, 8, 47, 2, 88, 5, 30, 3, 87
  };
  const int q7104[] = {
    9, 9, // Number of jobs and machines
    7, 27, 5, 34, 3, 20, 8, 69, 1,  1, 2, 79, 0, 58, 6, 28, 4, 40, 
    5, 85, 1, 61, 8, 57, 6, 51, 0, 66, 2, 68, 4, 39, 3, 37, 7, 18, 
    0, 49, 6, 81, 7, 10, 8, 73, 5, 85, 3, 71, 2,  7, 1, 63, 4, 43, 
    6, 37, 8, 32, 1,  2, 3, 49, 7, 86, 2, 82, 4, 60, 5,  2, 0, 89, 
    2, 59, 6, 64, 0, 58, 7, 58, 8, 97, 5, 91, 1, 87, 4, 46, 3, 54, 
    2, 46, 4, 85, 1, 46, 0, 55, 3, 47, 6, 55, 5, 69, 8, 31, 7, 15, 
    3, 69, 8, 46, 5, 63, 1, 88, 2, 31, 4, 29, 7, 61, 6, 53, 0, 25, 
    1, 30, 0, 91, 2, 96, 8, 63, 7, 68, 6, 27, 4,  5, 5, 76, 3, 39, 
    5, 73, 7, 28, 2, 33, 4, 96, 1, 82, 6, 93, 8, 94, 3, 12, 0, 68
  };
  const int q7105[] = {
    9, 9, // Number of jobs and machines
    3, 76, 2, 12, 7, 49, 0, 43, 5,  9, 1, 59, 4, 30, 8,  6, 6, 42, 
    8, 44, 6,  9, 7, 99, 3, 34, 2, 25, 1, 73, 0, 27, 5, 91, 4, 20, 
    6, 48, 1, 62, 8, 38, 2, 25, 5, 28, 0, 38, 4, 39, 3, 52, 7, 74, 
    4, 34, 1, 86, 6, 32, 8, 58, 3,  6, 7, 80, 0, 50, 5,  9, 2, 21, 
    2, 98, 6, 72, 1, 32, 5, 62, 0, 61, 3, 95, 7, 22, 8, 98, 4, 93, 
    3, 67, 2, 69, 4, 77, 1, 47, 6, 85, 8,  7, 5, 11, 0, 36, 7, 23, 
    3, 77, 1, 41, 5,  4, 6, 12, 7, 65, 0, 43, 4, 73, 2, 38, 8, 14, 
    2, 47, 0,  9, 5, 92, 7, 21, 4, 21, 8, 73, 3, 45, 6, 44, 1, 83, 
    7, 43, 5, 58, 1, 61, 2, 18, 4,  4, 3, 29, 8,  5, 6,  1, 0, 81
  };
  const int q7106[] = {
    9, 9, // Number of jobs and machines
    1, 37, 2, 44, 6, 48, 4, 95, 0, 82, 7, 16, 5, 25, 8, 99, 3, 32, 
    0, 85, 8, 76, 3, 59, 4, 43, 7, 88, 5, 24, 6, 39, 2, 15, 1, 75, 
    5, 45, 6, 43, 1, 89, 8, 28, 2, 91, 7, 19, 0, 13, 4, 82, 3, 85, 
    6, 93, 3, 23, 4, 10, 8, 12, 7, 45, 5,  7, 0, 15, 1, 54, 2, 77, 
    3, 43, 8, 17, 6, 32, 2, 16, 4, 34, 0, 41, 7, 55, 1, 75, 5, 90, 
    6, 44, 0, 78, 8, 34, 2, 72, 5, 75, 7, 11, 3, 92, 1, 75, 4, 33, 
    6, 61, 3, 12, 7, 30, 0,  3, 1, 29, 8, 60, 5, 69, 4, 94, 2, 10, 
    5, 16, 4, 26, 8, 99, 3, 94, 7, 20, 6,  4, 0, 43, 2, 48, 1, 70, 
    4, 85, 3, 48, 5, 61, 7, 57, 8, 63, 6, 14, 2, 78, 0, 77, 1, 26
  };
  const int q7107[] = {
    9, 9, // Number of jobs and machines
    4, 15, 2,  4, 1, 58, 0, 60, 5, 44, 3, 93, 6, 83, 7, 97, 8, 35, 
    0, 36, 5, 16, 1, 34, 4, 28, 8, 28, 2, 76, 7,  4, 6, 41, 3, 75, 
    4, 46, 5, 13, 3,  9, 7, 80, 0, 66, 1, 45, 8,  9, 6, 28, 2, 50, 
    6, 68, 3,  8, 4, 15, 0, 84, 2, 18, 7, 33, 8, 63, 1, 44, 5, 84, 
    6, 91, 7, 40, 5, 33, 1, 34, 8, 56, 3, 74, 4, 52, 0, 94, 2, 39, 
    5, 73, 4, 78, 0, 98, 3, 74, 1, 71, 8, 72, 6, 48, 2, 72, 7, 20, 
    0, 68, 2, 93, 7, 19, 6, 97, 8, 81, 4, 74, 1, 39, 5, 87, 3, 34, 
    6,  2, 8, 63, 0, 52, 1, 67, 2, 34, 7, 69, 4, 90, 5, 59, 3, 36, 
    1, 92, 3, 59, 2, 22, 0, 72, 8, 37, 6, 68, 5, 57, 7, 87, 4, 93
  };
  const int q7108[] = {
    9, 9, // Number of jobs and machines
    8, 62, 3, 29, 1, 90, 7, 66, 6, 43, 0, 72, 5, 53, 4, 99, 2, 72, 
    5, 22, 6, 63, 0, 80, 3, 72, 2, 67, 8, 44, 4, 47, 7, 17, 1, 11, 
    2, 56, 1, 46, 6, 44, 4, 23, 8, 14, 7, 37, 5, 15, 0, 74, 3, 59, 
    7, 58, 5, 29, 8, 87, 1, 26, 6, 38, 4, 92, 2,  9, 0, 91, 3, 98, 
    2, 12, 6,  7, 5, 41, 0, 37, 4, 80, 1, 86, 8, 37, 3, 13, 7, 16, 
    8, 76, 3, 33, 6, 53, 0, 18, 5, 91, 2, 48, 4, 49, 1, 65, 7, 76, 
    4, 64, 3, 57, 7, 68, 5, 24, 0, 15, 2, 35, 6, 15, 1, 68, 8, 12, 
    3, 11, 5, 80, 0,  8, 6, 14, 8, 77, 1,  4, 2, 91, 4, 81, 7, 68, 
    4, 38, 5, 51, 7, 94, 6, 47, 3,  2, 0, 40, 2, 18, 1,  5, 8, 46
  };
  const int q7109[] = {
    9, 9, // Number of jobs and machines
    7, 41, 3, 70, 5, 79, 2, 61, 8, 19, 6, 14, 4, 12, 0, 55, 1, 26, 
    6, 66, 0, 76, 4, 26, 1, 34, 8, 91, 5, 23, 7, 30, 3, 10, 2, 16, 
    3, 83, 7, 93, 6, 80, 1, 93, 8, 46, 4, 58, 0, 41, 2, 90, 5, 13, 
    7, 22, 8, 26, 6, 22, 0, 39, 1, 55, 3, 77, 4,  6, 5, 90, 2, 29, 
    6, 81, 2, 54, 8, 80, 4, 72, 7, 18, 1, 45, 5, 56, 3, 82, 0, 70, 
    1, 49, 3, 74, 7, 48, 2, 14, 6, 37, 5, 66, 8, 54, 4, 13, 0, 36, 
    6, 66, 3, 83, 2, 34, 4, 28, 5, 80, 0, 17, 8, 65, 1,  5, 7, 26, 
    5, 52, 8, 11, 7, 37, 2, 77, 4, 31, 6, 25, 3, 42, 1, 53, 0, 32, 
    6, 67, 1, 44, 8, 90, 3, 74, 0,  1, 2, 24, 5,  6, 4, 59, 7, 56
  };
  const int q7110[] = {
    9, 9, // Number of jobs and machines
    0, 17, 6, 95, 4, 66, 1, 32, 8, 66, 7, 78, 5, 12, 2, 67, 3, 86, 
    6, 43, 2, 15, 8, 97, 7,  2, 5, 98, 0, 14, 1, 57, 3,  1, 4, 41, 
    0, 61, 2, 48, 4, 21, 1, 25, 8, 28, 3, 51, 7, 18, 6, 39, 5, 36, 
    0, 70, 6, 54, 1, 14, 5, 65, 3, 58, 4, 25, 2, 29, 8, 43, 7, 57, 
    0, 56, 6, 54, 3, 18, 8, 59, 2, 61, 5,  6, 7, 10, 4, 37, 1, 32, 
    6,  7, 3, 44, 5,  8, 2, 55, 1, 35, 7, 67, 0, 14, 8, 86, 4, 52, 
    1, 18, 7, 31, 3, 59, 8, 18, 0,  8, 5,  1, 4, 98, 2, 72, 6, 52, 
    0, 77, 8, 75, 7, 99, 6, 34, 1, 31, 2, 62, 4, 34, 3, 34, 5, 53, 
    5, 89, 0, 92, 3,  1, 8, 68, 7, 56, 1, 94, 4, 14, 6, 36, 2, 72
  };
  const int q7111[] = {
    9, 9, // Number of jobs and machines
    5, 33, 7,  1, 2, 73, 4, 92, 0, 23, 8, 30, 6, 36, 3, 90, 1, 16, 
    0, 44, 7, 28, 2, 58, 6, 25, 8, 39, 3, 80, 1, 85, 5, 84, 4, 72, 
    0, 31, 3, 85, 4, 56, 7, 12, 2, 19, 6, 10, 8, 74, 5, 43, 1, 34, 
    4, 35, 5, 75, 2, 68, 1, 23, 6, 54, 8, 69, 3, 64, 7, 52, 0, 53, 
    1, 87, 2, 15, 8, 10, 5, 45, 3, 69, 0, 17, 4, 54, 7, 12, 6, 67, 
    8, 16, 4, 20, 5, 42, 3, 76, 6, 33, 2, 79, 0, 66, 7, 28, 1, 50, 
    6, 65, 1, 25, 3, 75, 7,  6, 0, 58, 5, 73, 4, 76, 8, 59, 2, 55, 
    5, 36, 1, 64, 6,  8, 3, 19, 4, 63, 2, 84, 8, 87, 7,  8, 0, 87, 
    6, 30, 3, 27, 2, 31, 4, 61, 8, 39, 5, 36, 0, 28, 1, 28, 7, 94
  };
  const int q7112[] = {
    9, 9, // Number of jobs and machines
    1, 43, 3, 90, 6, 66, 2, 15, 4, 30, 8, 17, 0, 66, 5, 31, 7, 15, 
    3,  9, 8, 97, 6, 74, 2, 69, 4, 30, 0, 50, 1, 99, 7, 43, 5, 11, 
    7, 35, 1, 67, 4, 17, 3,  8, 5, 84, 6, 96, 8, 28, 0, 20, 2, 13, 
    3, 44, 4, 89, 1,  6, 5, 55, 6, 58, 7, 66, 0, 35, 2, 94, 8, 33, 
    5, 63, 3, 11, 0, 62, 1, 17, 6, 51, 7, 88, 8, 36, 2,  2, 4, 25, 
    2, 70, 4, 56, 7, 76, 5, 51, 1, 89, 8, 95, 6, 49, 0, 93, 3, 52, 
    2, 24, 1, 36, 4, 54, 7, 97, 0, 91, 3, 56, 5, 46, 8, 75, 6, 76, 
    6, 46, 8, 76, 5, 32, 7, 38, 0, 34, 3, 33, 1, 42, 2, 39, 4, 14, 
    4, 14, 3, 69, 6, 24, 2,  6, 0, 67, 1, 20, 8, 71, 7, 97, 5, 60
  };
  const int q7113[] = {
    9, 9, // Number of jobs and machines
    2, 18, 0,  5, 5, 18, 7, 39, 6, 78, 8, 21, 3, 68, 1, 28, 4,  9, 
    3, 93, 4, 97, 8,  9, 0, 60, 7, 93, 1, 25, 2, 82, 5, 98, 6, 87, 
    1,  5, 0, 30, 6, 83, 8, 78, 5, 66, 3, 88, 4, 22, 2,  9, 7, 59, 
    6,  8, 2, 91, 5, 61, 1, 81, 7,  8, 0, 85, 3, 31, 8,  2, 4, 71, 
    2, 53, 8, 60, 3, 59, 4, 66, 0, 86, 5, 38, 7, 75, 1, 16, 6, 17, 
    5,  4, 8, 99, 4, 70, 7, 41, 3, 22, 1, 84, 2, 50, 0, 71, 6, 20, 
    0, 91, 3, 57, 5, 16, 6, 28, 7, 32, 8, 27, 1, 80, 4, 66, 2, 23, 
    3, 44, 2, 70, 1, 72, 8, 29, 4, 33, 7, 77, 6, 71, 5, 46, 0, 17, 
    5, 48, 1, 11, 2, 17, 8, 90, 3,  5, 0, 76, 7, 46, 4, 45, 6, 86
  };
  const int q7114[] = {
    9, 9, // Number of jobs and machines
    6, 65, 3, 31, 2, 47, 8, 91, 4,  9, 5, 51, 0, 86, 1, 36, 7, 61, 
    3,  2, 7, 35, 4, 41, 5, 68, 0, 99, 8, 21, 6,  1, 1, 44, 2, 30, 
    2, 50, 0,  5, 5, 46, 3, 51, 7, 76, 1, 97, 8, 30, 4, 46, 6, 64, 
    3, 85, 2,  3, 8, 59, 4, 81, 0,  1, 7, 80, 6, 78, 1, 17, 5, 43, 
    5, 31, 8, 62, 3, 64, 2, 94, 7, 57, 4, 88, 1, 60, 0, 70, 6, 30, 
    7, 70, 6,  6, 4, 53, 1, 42, 2, 61, 3, 30, 0, 96, 5, 33, 8, 82, 
    4, 74, 2,  8, 1, 14, 0, 76, 8, 94, 3, 79, 6, 13, 5, 99, 7, 51, 
    2, 22, 7, 81, 1, 33, 5, 18, 0,  9, 8, 20, 6, 80, 3,  8, 4, 67, 
    1, 26, 5, 45, 3, 79, 2, 24, 8, 34, 0, 92, 4, 71, 6, 73, 7, 93
  };
  const int q7115[] = {
    9, 9, // Number of jobs and machines
    5, 89, 1, 84, 7, 54, 0, 63, 3, 38, 4, 29, 8, 39, 6, 23, 2, 17, 
    3,  1, 5, 70, 6, 14, 1, 74, 8, 73, 7, 86, 2, 30, 0, 30, 4, 13, 
    7, 50, 8, 61, 0, 56, 5, 25, 4, 44, 3, 11, 2, 82, 6, 53, 1, 86, 
    4, 70, 3, 76, 5, 48, 2, 79, 6, 60, 1, 45, 0, 77, 7, 58, 8, 86, 
    6, 92, 0, 87, 8, 59, 5,  8, 7, 44, 1, 25, 4, 68, 2,  1, 3, 37, 
    3, 47, 1, 70, 6, 55, 7,  6, 0, 78, 2, 96, 5, 78, 4, 11, 8, 44, 
    6, 73, 2, 61, 0, 97, 8, 53, 4, 37, 3, 34, 7, 33, 5, 81, 1,  2, 
    4, 38, 7, 70, 0, 58, 2, 44, 3, 98, 5,  7, 8, 12, 6, 18, 1, 89, 
    2,  8, 0, 25, 3, 95, 1, 10, 8, 22, 7, 49, 5, 88, 6, 19, 4, 79
  };
  const int q7116[] = {
    9, 9, // Number of jobs and machines
    2, 92, 4, 54, 5,  2, 0, 28, 6, 82, 1, 59, 7, 59, 3, 13, 8, 16, 
    7, 80, 2, 11, 3, 82, 5, 40, 1, 75, 0, 38, 4, 13, 6, 81, 8, 65, 
    4,  6, 6, 30, 0, 47, 1, 65, 7,  9, 2, 94, 8, 40, 3, 82, 5, 53, 
    8, 41, 0, 58, 3, 90, 2, 71, 7, 23, 4,  7, 5, 66, 1, 29, 6, 35, 
    8, 61, 1,  2, 2, 43, 0, 53, 3, 12, 5, 19, 7,  7, 4, 71, 6, 42, 
    7,  6, 2, 68, 5, 50, 4, 83, 1,  8, 3, 25, 8, 49, 6, 11, 0,  2, 
    7, 46, 0, 15, 2, 56, 1, 48, 8, 90, 4, 85, 6, 52, 3, 86, 5, 34, 
    7, 18, 5, 26, 3, 25, 2, 30, 4, 20, 0, 78, 6, 45, 1,  5, 8, 89, 
    1, 25, 7, 36, 4, 71, 0, 63, 6, 13, 5, 63, 3, 39, 2, 22, 8, 73
  };
  const int q7117[] = {
    9, 9, // Number of jobs and machines
    7, 24, 3, 16, 1, 33, 2, 70, 8, 68, 5, 99, 0, 33, 4, 93, 6, 99, 
    7, 21, 8, 94, 5, 39, 3, 75, 1, 16, 0,  8, 6, 83, 4, 56, 2, 38, 
    2, 66, 6, 73, 0, 89, 4, 99, 7, 75, 3, 99, 1, 96, 8, 99, 5,  8, 
    5, 87, 3, 13, 2, 19, 7, 10, 0, 34, 6, 30, 8, 39, 1, 17, 4, 66, 
    0, 48, 1, 82, 8, 94, 6,  4, 5, 68, 3, 98, 4, 27, 2, 57, 7, 75, 
    8, 23, 4, 14, 7, 61, 2, 28, 0, 76, 6, 33, 5, 32, 3, 62, 1, 69, 
    5, 45, 7, 79, 3, 53, 8, 47, 4, 97, 2, 11, 0, 53, 6, 36, 1, 58, 
    0, 35, 6, 29, 4, 71, 5, 18, 8, 14, 3, 60, 7, 61, 1, 71, 2,  1, 
    0, 16, 3, 56, 5, 12, 2, 22, 1, 51, 7, 23, 4, 73, 6, 53, 8, 45
  };
  const int q7118[] = {
    9, 9, // Number of jobs and machines
    5, 62, 1, 54, 2, 55, 3, 17, 7,  1, 4, 40, 6, 22, 0, 55, 8, 97, 
    6, 93, 5, 55, 4, 71, 7, 39, 2, 19, 3, 77, 0, 30, 8, 72, 1, 18, 
    8, 57, 6, 74, 4, 45, 3,  7, 0,  2, 2, 55, 1, 23, 7, 47, 5, 18, 
    6, 55, 0, 99, 5, 91, 3, 43, 2,  3, 8, 14, 7, 27, 1, 75, 4,  8, 
    3, 32, 6,  1, 5, 36, 2, 26, 0, 43, 7, 70, 8,  1, 4, 53, 1, 89, 
    3, 90, 1, 48, 2, 98, 0, 46, 4, 21, 8, 84, 7, 38, 5, 90, 6, 61, 
    1, 22, 2, 82, 8, 50, 0, 49, 7, 11, 4, 52, 5, 25, 3, 44, 6, 72, 
    3, 59, 1, 15, 5, 46, 2, 17, 4, 75, 0,  7, 6,  5, 8, 70, 7,  9, 
    5, 26, 0,  2, 1, 43, 4, 70, 2, 66, 7, 21, 8, 62, 6, 75, 3, 41
  };
  const int q7119[] = {
    9, 9, // Number of jobs and machines
    3, 80, 8, 81, 5,  4, 1, 27, 0, 29, 4, 79, 7, 99, 2, 31, 6, 68, 
    7, 30, 1, 84, 3, 71, 2,  7, 6, 25, 5, 75, 4,  1, 0, 97, 8, 67, 
    1, 27, 2, 97, 7,  2, 3, 83, 0, 63, 4, 31, 8, 77, 6, 76, 5, 28, 
    5, 29, 4, 94, 1, 85, 7, 98, 0, 93, 8, 25, 2, 30, 6, 16, 3, 40, 
    5, 21, 7, 83, 2, 62, 3, 24, 8, 89, 0, 81, 6, 47, 4,  7, 1, 77, 
    1, 83, 2, 95, 6, 38, 5,  5, 4,  3, 0, 91, 3,  2, 8,  7, 7, 14, 
    3,  3, 4, 15, 8, 57, 2, 47, 1, 21, 7, 88, 0, 85, 6, 52, 5, 56, 
    3, 74, 2, 77, 4, 62, 6, 57, 1, 70, 0, 31, 7, 48, 8, 17, 5, 65, 
    3, 86, 2,  8, 8, 86, 4, 85, 5, 95, 1, 81, 6, 88, 7, 60, 0, 94
  };
  const int q7120[] = {
    9, 9, // Number of jobs and machines
    8, 81, 0, 67, 1, 37, 3,  4, 4, 30, 5, 44, 2, 41, 7, 37, 6, 86, 
    3,  3, 4, 81, 1, 72, 6, 17, 8, 56, 7, 14, 0,  6, 2, 85, 5, 69, 
    5, 78, 7, 91, 6, 54, 0, 84, 3, 68, 4, 80, 2,  2, 1, 24, 8,  8, 
    8,  9, 5, 82, 1, 42, 0, 74, 2, 74, 6, 50, 7,  5, 4, 75, 3, 84, 
    7, 95, 4, 90, 6, 75, 0, 38, 8, 56, 3, 68, 5, 77, 2, 31, 1, 75, 
    3, 11, 1, 82, 0, 69, 8, 97, 7, 45, 2, 51, 5, 15, 4, 23, 6, 93, 
    4, 23, 0, 63, 5, 27, 7,  5, 6, 38, 8, 92, 3, 37, 2, 61, 1, 15, 
    1, 54, 6, 13, 4, 87, 2, 40, 8, 67, 0, 34, 7, 89, 5, 98, 3, 65, 
    7, 25, 5, 50, 2, 18, 3, 19, 1, 44, 0, 20, 6,  7, 8, 67, 4, 95
  };
  const int q7121[] = {
    9, 9, // Number of jobs and machines
    7, 94, 4, 42, 0, 64, 6, 93, 1, 55, 2, 73, 3, 33, 8, 31, 5, 20, 
    8, 33, 6, 42, 0, 10, 1,  8, 4, 77, 7, 83, 2, 22, 5, 41, 3, 15, 
    7, 26, 6, 15, 5, 75, 8, 82, 4, 26, 0, 20, 3,  8, 1, 36, 2, 46, 
    1, 57, 5, 42, 0, 55, 2, 55, 3, 51, 4, 86, 7, 12, 6, 76, 8, 32, 
    5, 49, 0, 75, 7, 65, 2, 59, 4, 22, 8, 70, 1, 23, 6, 76, 3, 32, 
    7, 39, 3, 80, 4, 38, 0, 15, 8, 61, 5, 71, 2,  3, 6, 17, 1, 63, 
    1, 10, 7, 36, 0, 35, 3, 36, 5,  3, 2, 15, 4, 35, 6, 95, 8, 69, 
    8, 80, 6, 61, 3, 89, 1, 65, 2, 71, 4, 95, 7, 10, 5, 16, 0, 91, 
    4, 88, 7, 38, 8, 63, 0, 21, 6, 21, 3, 10, 5, 74, 2, 66, 1, 56
  };
  const int q7122[] = {
    9, 9, // Number of jobs and machines
    5, 49, 4, 55, 6, 78, 0, 72, 7, 44, 3, 15, 2, 93, 1, 23, 8, 11, 
    3, 84, 0, 69, 7,  3, 1, 50, 6, 92, 2, 92, 4, 53, 8, 91, 5, 27, 
    3, 65, 6, 74, 0,  2, 2, 42, 5, 72, 4, 90, 7, 54, 8, 57, 1, 61, 
    2, 38, 8, 53, 4, 65, 1, 78, 7, 31, 5, 88, 6, 16, 3, 56, 0,  9, 
    1, 85, 3, 27, 7,  3, 8,  7, 4, 90, 0,  2, 2, 32, 5, 96, 6, 89, 
    2, 99, 4, 21, 3, 39, 1, 37, 0, 81, 6, 70, 8, 28, 5, 47, 7, 90, 
    3, 87, 8, 58, 1, 28, 7, 32, 5, 88, 6, 88, 4, 28, 0, 34, 2, 27, 
    3, 33, 4, 58, 6, 13, 8, 65, 1, 87, 2, 72, 5, 29, 0, 56, 7, 51, 
    2, 85, 4, 76, 6, 59, 3, 81, 0, 61, 1, 49, 8, 50, 7, 83, 5, 10
  };
  const int q7123[] = {
    9, 9, // Number of jobs and machines
    0,  8, 1, 72, 7, 27, 3, 19, 4, 64, 2, 82, 6, 88, 5, 12, 8, 68, 
    0, 66, 2, 34, 6, 40, 4, 92, 7, 78, 5,  5, 3, 29, 1, 11, 8, 31, 
    2,  8, 7, 73, 6, 11, 4, 46, 5,  7, 1, 87, 8, 76, 0, 85, 3, 29, 
    7, 13, 5, 63, 2, 32, 1, 63, 0, 24, 8, 14, 3, 26, 4, 38, 6, 18, 
    0, 24, 8, 15, 2,  7, 4,  6, 1, 38, 5, 23, 3, 26, 6, 85, 7, 84, 
    3, 21, 0, 59, 4, 97, 1, 35, 8, 37, 2, 10, 5, 14, 7, 43, 6, 50, 
    0,  9, 7, 26, 4,  2, 2, 62, 6,  2, 8, 85, 5, 43, 1, 60, 3, 28, 
    4, 66, 1, 81, 3, 15, 7, 34, 6, 17, 8, 29, 5, 47, 0, 39, 2, 47, 
    2, 20, 5,  6, 7, 27, 1, 80, 6, 98, 3, 56, 4, 25, 8,  3, 0, 10
  };
  const int q7124[] = {
    9, 9, // Number of jobs and machines
    6, 39, 2, 89, 5, 41, 8, 29, 0, 52, 3, 40, 4, 29, 1, 48, 7, 91, 
    3, 67, 2, 72, 4, 82, 5, 86, 1, 84, 0, 77, 7, 76, 8, 16, 6, 77, 
    3, 17, 8, 14, 7, 37, 1, 25, 5, 36, 4, 58, 6, 60, 2, 24, 0, 36, 
    1, 14, 3, 42, 2, 93, 0, 55, 8, 15, 7, 58, 6, 82, 4, 11, 5, 20, 
    3, 31, 4, 85, 2, 80, 5,  9, 6, 63, 7, 61, 1, 27, 8, 40, 0, 56, 
    0, 98, 8, 15, 1, 97, 4, 91, 5, 20, 6, 95, 7, 12, 2, 41, 3, 27, 
    3, 17, 1, 37, 7, 98, 6, 95, 5, 86, 0, 35, 2, 88, 8, 99, 4, 54, 
    7, 52, 3,  1, 4, 32, 8, 54, 5,  9, 0, 50, 1, 67, 6, 70, 2, 57, 
    4,  9, 7, 66, 6, 38, 8, 53, 3, 50, 0, 34, 2, 55, 1, 10, 5, 87
  };
  const int q7125[] = {
    9, 9, // Number of jobs and machines
    4, 56, 2, 72, 1, 32, 6, 87, 5, 92, 8, 92, 3, 70, 7, 81, 0, 47, 
    0,  3, 2, 91, 4, 66, 8, 33, 3, 84, 1, 86, 6, 73, 7, 81, 5, 56, 
    0, 41, 4, 50, 3,  6, 2, 28, 7, 27, 1, 73, 5, 85, 6, 88, 8, 32, 
    0, 24, 1, 36, 4, 87, 6, 13, 2, 44, 3, 27, 7,  4, 8, 70, 5, 77, 
    4, 13, 5, 42, 0, 32, 7, 72, 3, 26, 1, 34, 6, 25, 2, 20, 8, 35, 
    8, 86, 1, 48, 0, 28, 5, 36, 7, 77, 2,  7, 4, 76, 3,  3, 6, 68, 
    4, 70, 7,  5, 3, 16, 2, 89, 0, 80, 5,  5, 8, 56, 6, 62, 1, 36, 
    8, 24, 6, 41, 4, 42, 7, 20, 2, 36, 5,  8, 3,  4, 1, 65, 0, 84, 
    0,  2, 2, 24, 3, 73, 1, 98, 5, 47, 6, 41, 8, 73, 7, 49, 4, 30
  };
  const int q7126[] = {
    9, 9, // Number of jobs and machines
    0, 17, 5, 53, 6, 70, 2, 51, 1, 89, 8, 92, 3, 15, 4, 16, 7, 12, 
    0, 37, 6, 40, 5, 83, 2, 64, 7,  6, 4, 34, 8, 60, 3, 21, 1, 65, 
    5, 16, 6, 28, 0, 49, 2,  7, 3, 54, 4, 50, 8, 43, 7, 77, 1, 55, 
    1, 91, 6, 79, 2, 41, 4, 43, 7, 21, 8, 94, 3, 69, 0, 34, 5, 11, 
    6, 12, 1, 36, 0, 12, 4, 64, 2, 91, 8, 56, 3, 81, 7,  6, 5, 82, 
    4, 17, 5, 56, 6, 62, 7, 19, 1, 85, 2,  8, 0, 53, 3, 41, 8, 70, 
    1, 42, 6, 73, 8, 96, 3, 98, 7, 89, 2, 68, 0, 11, 4, 17, 5, 85, 
    3, 67, 1, 83, 4, 56, 8, 89, 7, 27, 5, 42, 6, 12, 0, 18, 2, 71, 
    4, 73, 3, 70, 5, 98, 6, 68, 1, 71, 0, 77, 7, 24, 8, 66, 2, 64
  };
  const int q7127[] = {
    9, 9, // Number of jobs and machines
    6, 17, 4, 18, 7,  2, 0, 29, 5,  3, 1, 58, 8, 69, 3, 69, 2, 59, 
    5, 56, 3, 23, 1, 14, 2, 10, 0, 35, 4, 31, 7, 31, 6, 57, 8, 20, 
    4, 10, 0,  5, 6, 86, 8, 93, 3, 40, 7, 10, 5,  5, 1, 30, 2, 20, 
    7, 33, 8,  5, 5, 21, 3, 76, 0, 58, 6, 80, 1, 36, 4, 53, 2, 51, 
    5, 94, 3, 47, 0, 68, 4, 99, 1, 48, 2, 37, 6, 82, 8, 70, 7, 74, 
    8, 53, 6, 65, 4, 98, 5, 10, 3, 91, 7, 52, 0, 80, 2, 92, 1, 20, 
    1,  3, 2,  9, 4, 64, 5, 83, 8, 49, 6, 96, 3, 15, 0, 49, 7, 98, 
    4, 44, 0, 60, 3, 92, 8, 17, 6, 96, 1, 51, 7, 33, 2, 38, 5, 23, 
    5, 12, 6, 35, 7, 57, 8, 92, 4, 76, 3, 66, 0,  1, 2, 17, 1, 85
  };
  const int q7128[] = {
    9, 9, // Number of jobs and machines
    3, 42, 2, 96, 8, 68, 5, 19, 7, 30, 0, 18, 1, 95, 4, 52, 6, 51, 
    0, 13, 8,  7, 6, 84, 5, 56, 7, 93, 3, 57, 4,  1, 1, 23, 2, 17, 
    0, 41, 2, 35, 8, 80, 6, 35, 1, 86, 4, 72, 5, 36, 3, 38, 7, 25, 
    1, 82, 2, 65, 4, 64, 8, 53, 7,  6, 5, 41, 0, 41, 3, 17, 6, 36, 
    8, 32, 2, 60, 6, 77, 5, 57, 1,  1, 0, 48, 7, 75, 4,  9, 3, 23, 
    0, 61, 8, 53, 2, 47, 1, 45, 7, 65, 4, 63, 3, 24, 5, 92, 6, 87, 
    0, 44, 5, 57, 3, 37, 1, 28, 4, 79, 8,  4, 7, 84, 6, 59, 2, 98, 
    1, 64, 7, 29, 5, 80, 8, 35, 4, 53, 0,  8, 3, 20, 6, 93, 2, 50, 
    0, 68, 4, 19, 8,  8, 5, 92, 7, 70, 3,  8, 2, 82, 6, 35, 1, 62
  };
  const int q7129[] = {
    9, 9, // Number of jobs and machines
    2,  4, 5,  8, 6, 99, 8, 99, 1, 83, 3, 29, 0, 25, 4, 48, 7, 65, 
    8, 16, 3, 64, 0, 85, 6, 27, 2, 83, 1, 23, 5, 64, 4, 99, 7, 51, 
    7,  8, 0,  5, 8,  5, 4, 17, 5, 57, 2, 90, 1, 47, 6, 39, 3, 42, 
    3, 99, 8, 23, 7, 94, 2,  2, 6, 22, 1,  2, 5, 53, 0, 38, 4, 86, 
    3, 95, 7, 78, 6, 79, 2, 66, 8, 50, 4, 60, 5, 65, 0, 14, 1, 71, 
    0,  8, 3, 16, 4,  4, 7, 33, 8, 63, 5, 94, 2, 19, 6, 93, 1, 52, 
    6, 84, 5, 64, 1, 64, 0, 50, 4, 49, 8, 57, 7, 83, 2, 78, 3, 21, 
    5, 73, 8, 16, 3, 23, 2, 49, 1, 91, 4, 37, 0, 92, 6, 13, 7, 19, 
    0, 71, 5, 58, 2, 93, 8, 74, 3, 79, 1, 98, 6, 46, 4, 40, 7, 92
  };
  const int q7130[] = {
    9, 9, // Number of jobs and machines
    1, 33, 0, 81, 7, 12, 5, 71, 4, 75, 3, 73, 8, 76, 2, 93, 6, 38, 
    7,  5, 3, 76, 6, 26, 5, 55, 0, 20, 4,  8, 1, 51, 8,  5, 2, 40, 
    5, 55, 1, 68, 2, 72, 7, 66, 6, 94, 4, 31, 8, 28, 0, 28, 3, 10, 
    8, 81, 5,  7, 1,  5, 3, 61, 4, 40, 0,  4, 7, 25, 2, 81, 6, 60, 
    4, 78, 8, 84, 6, 84, 7, 54, 0, 11, 3, 45, 5, 35, 1, 43, 2, 73, 
    4, 18, 6, 40, 0, 12, 8, 98, 1, 27, 2, 36, 7, 88, 3, 38, 5, 50, 
    5, 84, 6, 35, 8, 55, 2, 82, 4, 21, 1, 48, 3, 54, 0, 30, 7, 27, 
    1, 67, 2, 36, 6, 95, 8, 99, 5, 10, 4,  5, 7, 38, 0, 30, 3, 48, 
    8, 54, 3, 97, 6, 76, 0,  7, 4, 79, 5, 42, 1, 21, 2, 72, 7, 57
  };
  const int q7131[] = {
    9, 9, // Number of jobs and machines
    1,  1, 2,  1, 5, 73, 4, 47, 6, 54, 3, 25, 8,  7, 0, 91, 7, 85, 
    5, 36, 4, 13, 3, 78, 6,  6, 2, 84, 7, 63, 1,  5, 0, 38, 8, 58, 
    7, 15, 3, 75, 6, 65, 1, 43, 8, 59, 2, 67, 5, 92, 4, 73, 0, 26, 
    3, 83, 1, 31, 6, 22, 2, 27, 4, 77, 0, 76, 5, 78, 7, 80, 8,  6, 
    2, 72, 4, 18, 5, 75, 1, 93, 0,  4, 7, 57, 8, 29, 6, 33, 3, 23, 
    6, 51, 4, 81, 8, 11, 0, 44, 3,  6, 1, 65, 2, 24, 5, 13, 7, 17, 
    8, 63, 3, 13, 4, 68, 2, 72, 0, 67, 7,  9, 1, 93, 5, 25, 6, 17, 
    1, 71, 5,  3, 3,  2, 0, 34, 7, 90, 6, 38, 2, 18, 4, 20, 8, 73, 
    0, 50, 2, 93, 5, 20, 3, 44, 6, 63, 8, 30, 4, 38, 7, 23, 1, 31
  };
  const int q7132[] = {
    9, 9, // Number of jobs and machines
    4, 73, 7, 19, 5, 19, 3, 59, 1, 17, 6, 19, 8, 26, 2, 31, 0, 76, 
    5, 99, 1, 77, 2, 38, 3, 25, 0, 57, 4, 68, 6, 18, 7, 28, 8, 86, 
    2, 88, 0, 27, 4, 90, 8, 77, 1, 82, 3, 94, 5, 44, 6, 38, 7, 12, 
    1, 20, 7, 17, 6, 22, 4, 40, 3, 42, 5, 58, 8,  5, 0, 74, 2,  2, 
    3, 23, 7, 76, 4, 74, 6, 48, 5, 51, 8, 61, 0, 98, 2, 58, 1, 78, 
    3, 70, 4, 89, 2, 63, 1, 18, 8,  3, 5, 44, 0, 71, 7, 57, 6,  7, 
    2, 48, 6, 20, 4, 70, 7, 17, 0, 97, 8, 61, 3, 51, 1, 34, 5, 72, 
    0, 59, 2, 69, 1, 60, 8, 90, 3, 27, 6, 87, 5,  5, 4, 17, 7, 92, 
    0, 17, 2, 57, 3, 20, 1, 23, 8, 76, 5, 39, 6, 42, 4, 32, 7, 73
  };
  const int q7133[] = {
    9, 9, // Number of jobs and machines
    4, 36, 5,  9, 0, 64, 3, 49, 1, 77, 2,  7, 6, 10, 8, 45, 7, 19, 
    6, 16, 0,  7, 5, 85, 3, 75, 8, 47, 7, 28, 2, 73, 4, 43, 1, 95, 
    3, 36, 5,  4, 6, 25, 0, 36, 7, 63, 8, 33, 2, 54, 1, 57, 4,  2, 
    8, 77, 4,  7, 0, 93, 3,  6, 1, 27, 5, 44, 7, 70, 6, 56, 2, 46, 
    6, 25, 2, 94, 1,  2, 0, 63, 7, 21, 4,  6, 3,  3, 5,  4, 8, 84, 
    1, 65, 7, 39, 8, 32, 3, 45, 6, 78, 5, 64, 4, 85, 2, 54, 0,  6, 
    3, 27, 2, 33, 0, 38, 4, 47, 6,  7, 7, 41, 8, 18, 5, 89, 1, 83, 
    7, 19, 8, 28, 6, 76, 3, 82, 0, 75, 1, 47, 5, 63, 4, 33, 2, 46, 
    1, 43, 8, 31, 3, 37, 7, 80, 0, 46, 5, 14, 4, 93, 2, 46, 6, 94
  };
  const int q7134[] = {
    9, 9, // Number of jobs and machines
    5, 73, 3, 64, 0,  1, 4, 86, 6, 37, 2, 97, 8, 86, 7, 85, 1, 34, 
    5, 88, 0, 35, 2, 61, 6, 74, 7, 81, 8, 87, 3, 45, 4, 76, 1, 64, 
    3, 77, 8, 23, 0, 50, 6, 52, 4,  3, 1, 61, 2, 92, 5, 33, 7,  5, 
    8, 42, 2,  6, 5, 85, 1, 76, 4,  5, 3, 52, 0, 57, 7, 43, 6, 44, 
    4,  7, 1, 50, 2, 11, 8, 11, 5, 79, 7, 45, 3, 92, 0, 11, 6, 49, 
    6, 54, 2, 34, 8,  7, 3, 12, 5, 11, 4, 24, 7, 28, 1, 29, 0, 48, 
    3, 64, 4, 22, 6, 65, 7, 73, 0, 79, 1, 86, 5, 42, 8, 48, 2, 89, 
    8, 86, 2, 87, 7, 53, 3, 37, 1, 40, 5, 89, 4, 15, 0, 94, 6, 85, 
    7, 24, 4, 94, 6, 69, 2, 28, 8, 79, 1, 11, 0, 14, 3, 57, 5, 65
  };
  const int q7135[] = {
    9, 9, // Number of jobs and machines
    3, 39, 0, 81, 1, 30, 8, 34, 5, 84, 4,  4, 2, 45, 7, 59, 6, 85, 
    1, 84, 4, 97, 6, 92, 5,  8, 0, 28, 2, 55, 3, 35, 7, 85, 8, 34, 
    4, 78, 7, 29, 0, 38, 5,  5, 6, 37, 1, 28, 8, 75, 3, 36, 2, 16, 
    7, 79, 0, 90, 2, 18, 5, 71, 8, 55, 3, 30, 4, 87, 1, 16, 6, 97, 
    4, 91, 5, 75, 7, 93, 8, 41, 2, 20, 6, 86, 0, 98, 1, 18, 3, 49, 
    6, 51, 7, 83, 4, 32, 1, 79, 2, 98, 5, 23, 0, 54, 3, 13, 8, 50, 
    2, 42, 7, 67, 0, 69, 5, 49, 6, 89, 8, 94, 1,  7, 4, 23, 3, 78, 
    2, 98, 4, 60, 7, 61, 5, 44, 3, 19, 0, 31, 6, 81, 1, 10, 8, 97, 
    8, 98, 2, 74, 3, 49, 7, 77, 1, 54, 5, 20, 4, 57, 6, 54, 0, 83
  };
  const int q7136[] = {
    9, 9, // Number of jobs and machines
    6, 74, 4, 80, 3,  1, 0, 26, 7, 66, 5, 43, 8, 43, 1, 97, 2, 24, 
    1, 16, 7, 11, 4, 49, 0, 68, 2, 54, 3, 67, 5, 73, 6, 61, 8,  2, 
    1, 78, 0, 24, 8,  2, 7, 31, 5, 13, 2, 87, 4, 64, 3, 72, 6, 58, 
    4, 73, 3, 76, 0, 83, 8, 51, 1, 36, 2, 94, 5, 52, 7, 99, 6, 44, 
    1, 47, 8, 97, 7, 65, 5, 77, 3, 13, 2, 91, 6, 62, 0, 82, 4, 21, 
    4, 20, 6, 34, 7,  4, 2, 16, 8, 97, 5, 39, 0, 90, 3, 25, 1, 91, 
    1,  9, 2,  7, 0, 62, 4, 48, 7, 87, 5, 51, 8, 95, 3, 70, 6, 39, 
    4, 24, 3, 44, 0, 79, 7, 38, 1,  9, 2, 53, 5, 85, 8, 45, 6, 27, 
    3, 39, 0,  1, 7,  8, 4, 35, 1,  1, 6, 15, 2, 64, 5, 62, 8, 22
  };
  const int q7137[] = {
    9, 9, // Number of jobs and machines
    5, 32, 1, 38, 7,  8, 2, 81, 3,  1, 0, 33, 4, 87, 8, 91, 6, 62, 
    6, 58, 0, 54, 2, 71, 5,  4, 3,  5, 1,  8, 7, 43, 8, 65, 4,  8, 
    1, 24, 6, 39, 5, 64, 7, 88, 2, 91, 4, 48, 8,  8, 3, 14, 0, 98, 
    0, 52, 4,  9, 6, 93, 7, 53, 3, 71, 8, 26, 5, 52, 2, 14, 1, 41, 
    5, 95, 7, 24, 0, 96, 8, 93, 3, 55, 6, 18, 2, 84, 1, 54, 4,  8, 
    6, 71, 3,  7, 8, 35, 7, 54, 0, 97, 2, 18, 4, 98, 5, 45, 1, 95, 
    2, 78, 5, 69, 6,  8, 0, 18, 1, 70, 3, 96, 7, 89, 4, 19, 8, 83, 
    3, 51, 6,  5, 2, 48, 8, 98, 1, 48, 4, 42, 7,  5, 5, 45, 0,  8, 
    6,  4, 5, 53, 7, 39, 4, 55, 1, 96, 3, 23, 2, 85, 8, 92, 0,  9
  };
  const int q7138[] = {
    9, 9, // Number of jobs and machines
    1, 64, 6, 92, 3, 90, 2, 67, 0, 70, 8, 43, 7, 65, 5, 23, 4, 49, 
    4, 13, 7, 76, 5, 50, 6, 37, 2,  2, 0, 27, 8, 71, 3, 97, 1, 20, 
    8, 18, 6, 24, 1, 65, 3, 52, 4, 37, 7,  6, 2, 33, 5, 54, 0, 46, 
    5, 52, 1, 85, 4, 71, 7, 70, 6, 15, 3, 53, 2, 35, 0, 99, 8,  3, 
    7, 85, 3, 13, 6, 27, 8, 24, 5, 37, 1,  5, 4, 65, 0, 59, 2, 23, 
    4, 28, 8, 22, 5, 40, 7, 80, 0, 45, 6, 17, 2, 61, 1, 66, 3, 47, 
    4, 40, 6, 59, 8, 72, 0, 43, 7, 24, 1, 70, 2, 34, 5, 89, 3, 58, 
    8, 19, 2, 58, 3, 15, 5, 56, 1, 97, 0,  7, 4, 84, 7, 65, 6, 66, 
    5, 55, 8, 32, 3, 62, 1, 58, 6, 84, 7, 57, 4, 80, 0, 56, 2, 96
  };
  const int q7139[] = {
    9, 9, // Number of jobs and machines
    3, 83, 7, 55, 2, 46, 8, 98, 5,  7, 6, 61, 0, 47, 1, 11, 4, 57, 
    2, 51, 6, 70, 3, 45, 8,  8, 1, 69, 4, 76, 7, 75, 0, 94, 5,  8, 
    3, 46, 4, 74, 8, 38, 5, 14, 7,  4, 0,  7, 1, 43, 6, 13, 2,  2, 
    7, 60, 1, 98, 0, 63, 5, 77, 8, 68, 2, 47, 4, 47, 6, 34, 3, 15, 
    5, 98, 8, 11, 4, 40, 3, 99, 2, 68, 6, 82, 7,  6, 1, 71, 0, 25, 
    5, 65, 1, 15, 0, 60, 6, 38, 2, 43, 3, 49, 7, 24, 8, 98, 4, 73, 
    8, 94, 0, 42, 4, 98, 2,  3, 3, 71, 7, 35, 5, 43, 6, 92, 1, 39, 
    3, 95, 8, 56, 4, 28, 7, 55, 6, 85, 2, 99, 5, 37, 0, 30, 1, 19, 
    3, 78, 7, 62, 1, 85, 4, 84, 5, 96, 2, 53, 8, 54, 6, 68, 0, 66
  };
  const int q7140[] = {
    9, 9, // Number of jobs and machines
    0, 32, 8, 18, 4, 88, 2, 23, 6, 25, 5, 74, 1, 92, 7, 49, 3,  6, 
    6, 84, 8, 98, 7, 14, 0, 28, 4, 38, 1, 50, 3, 26, 5, 93, 2, 86, 
    2, 55, 5, 69, 3,  7, 1, 35, 6, 70, 7, 73, 8, 74, 0, 85, 4, 70, 
    1, 73, 7, 77, 5, 19, 3, 72, 2, 31, 0, 45, 8, 51, 6, 84, 4, 11, 
    7,  2, 5, 42, 0,  7, 2, 18, 1, 30, 4,  1, 6, 19, 8, 25, 3, 72, 
    5, 12, 0,  8, 6, 24, 7, 56, 2, 58, 4, 98, 3, 64, 1, 42, 8, 82, 
    0, 46, 5,  1, 3, 55, 4, 21, 1, 65, 6, 73, 2, 32, 7, 26, 8, 32, 
    4, 34, 2, 86, 0, 91, 8, 21, 7, 90, 3, 71, 6, 65, 1, 23, 5, 99, 
    2, 82, 3, 22, 5, 90, 0,  5, 6, 92, 1, 15, 4, 23, 7, 10, 8, 38
  };
  const int q7141[] = {
    9, 9, // Number of jobs and machines
    7, 55, 4, 72, 2, 67, 8, 10, 5, 63, 3,  7, 6, 97, 1,  1, 0, 41, 
    1, 81, 7, 69, 6, 72, 8, 22, 0, 88, 3, 33, 4,  3, 5, 40, 2, 51, 
    6, 92, 3, 15, 0, 93, 2, 82, 7, 51, 5, 15, 4, 86, 8, 97, 1, 32, 
    6, 93, 5, 30, 3, 35, 1, 12, 2, 71, 4, 56, 0, 71, 7, 52, 8, 30, 
    8, 97, 6, 15, 3, 19, 7, 31, 0, 84, 4, 78, 2, 39, 1, 75, 5, 95, 
    4, 60, 7, 62, 2, 54, 3, 33, 1, 85, 0, 82, 6, 95, 8, 38, 5, 49, 
    5, 50, 2, 66, 0, 99, 8, 93, 3, 53, 1, 56, 4, 38, 7, 70, 6, 16, 
    3, 72, 7, 80, 5, 24, 2, 57, 8, 57, 1, 71, 6,  3, 4, 78, 0, 14, 
    0, 71, 3, 59, 6, 22, 5,  4, 8, 78, 4, 53, 2, 70, 7,  1, 1, 48
  };
  const int q7142[] = {
    9, 9, // Number of jobs and machines
    3, 52, 2,  5, 0, 10, 6, 98, 8, 20, 5, 31, 4, 59, 7, 75, 1, 31, 
    7, 96, 8, 72, 3, 34, 0, 32, 2, 60, 6, 33, 1, 89, 5, 68, 4,  8, 
    6, 44, 1, 16, 4,  2, 0, 17, 5, 74, 8, 62, 2, 83, 3, 48, 7, 24, 
    8, 50, 3, 94, 2, 99, 6,  3, 0, 16, 4, 32, 7, 39, 5, 62, 1, 76, 
    3, 23, 8, 94, 6, 46, 5,  1, 7, 59, 2, 20, 4,  2, 1, 85, 0, 58, 
    3, 85, 1, 53, 7,  8, 8, 32, 4, 61, 0, 31, 2, 57, 6, 46, 5,  9, 
    4, 50, 6, 67, 0, 53, 1, 74, 7, 53, 3, 64, 8, 74, 5,  9, 2, 81, 
    7, 37, 0,  5, 3, 48, 8, 89, 5, 90, 6, 70, 4, 65, 1, 20, 2, 44, 
    4, 58, 8, 20, 5, 68, 3,  7, 7, 52, 1, 55, 2, 99, 6, 75, 0, 80
  };
  const int q7143[] = {
    9, 9, // Number of jobs and machines
    4,  4, 8, 97, 7, 51, 6, 78, 5, 23, 2, 29, 3,  8, 0, 82, 1, 38, 
    0, 41, 8, 96, 5, 85, 6, 75, 2, 80, 3, 85, 1, 61, 7, 43, 4, 94, 
    2, 92, 6, 12, 4, 25, 8, 95, 5, 44, 0,  4, 1, 20, 3, 38, 7, 27, 
    2, 40, 0, 83, 5, 46, 8, 69, 6, 27, 4, 88, 1, 43, 3, 23, 7, 51, 
    0, 78, 2, 98, 5, 13, 6, 12, 8, 68, 4, 75, 3, 36, 1, 29, 7, 62, 
    8, 27, 6, 82, 3, 25, 0, 88, 5, 85, 4, 99, 1, 61, 7, 20, 2, 98, 
    8, 77, 3, 48, 1, 25, 0, 76, 7, 78, 5, 33, 4, 16, 6, 83, 2, 50, 
    8, 14, 7, 58, 5, 47, 0, 61, 1, 77, 4, 63, 2, 24, 6, 30, 3, 86, 
    5, 15, 3, 47, 6, 52, 8, 54, 1, 52, 7, 66, 4, 39, 0, 91, 2, 18
  };
  const int q7144[] = {
    9, 9, // Number of jobs and machines
    8, 46, 0, 12, 1, 18, 2, 62, 3, 50, 6, 67, 5,  2, 7, 46, 4, 70, 
    3, 66, 4, 86, 2, 63, 5, 65, 1, 32, 8, 11, 7, 43, 6, 35, 0, 82, 
    8, 32, 3, 85, 4, 33, 1, 78, 6, 54, 2, 73, 5, 55, 0, 82, 7, 61, 
    0, 63, 7, 99, 3, 42, 6, 64, 1,  7, 5, 42, 8, 56, 2, 25, 4, 17, 
    5, 29, 2, 31, 1, 15, 8, 35, 3, 64, 7, 26, 6, 61, 0, 11, 4, 86, 
    5, 24, 7, 98, 4, 93, 0, 28, 6, 13, 8, 61, 3, 40, 1, 15, 2, 81, 
    2, 40, 1, 59, 5, 22, 4, 34, 0, 80, 3, 30, 7, 34, 8, 24, 6, 45, 
    5, 24, 7, 67, 1, 51, 2, 43, 8, 31, 4, 77, 3, 79, 6, 16, 0, 79, 
    0,  4, 5, 67, 4, 26, 7, 73, 8, 41, 1, 36, 6,  8, 2, 60, 3, 26
  };
  const int q7145[] = {
    9, 9, // Number of jobs and machines
    8,  6, 1, 93, 7, 23, 0, 28, 6, 45, 4, 91, 3, 29, 5,  5, 2, 39, 
    5, 46, 0, 91, 4, 51, 1, 33, 8, 14, 2, 33, 6, 60, 7, 40, 3, 59, 
    6, 86, 4, 62, 1, 59, 5, 14, 8, 65, 2, 96, 7, 77, 3, 69, 0, 17, 
    3, 62, 1, 80, 6, 10, 7, 73, 4, 50, 0, 63, 2, 61, 5, 36, 8, 12, 
    0, 92, 1, 60, 6, 31, 8, 86, 5, 76, 4, 68, 3, 73, 7, 48, 2, 53, 
    6, 33, 1, 48, 3, 72, 4, 96, 8, 22, 7,  5, 2, 52, 0, 52, 5, 31, 
    5, 62, 8, 45, 3, 61, 7, 84, 2, 58, 4, 94, 6, 87, 0, 20, 1, 51, 
    6, 79, 7, 23, 8, 99, 4, 18, 5,  5, 2, 42, 1, 88, 0, 48, 3, 53, 
    7, 21, 2, 56, 5, 48, 6, 29, 3, 61, 4, 83, 0, 36, 8, 11, 1, 70
  };
  const int q7146[] = {
    9, 9, // Number of jobs and machines
    5, 66, 6, 67, 7, 50, 2, 93, 0, 47, 1, 99, 8, 56, 3, 78, 4, 39, 
    4, 50, 5, 97, 2, 63, 3,  1, 8, 77, 0, 80, 7, 40, 1, 96, 6, 49, 
    8, 70, 7, 66, 2,  3, 3, 49, 1, 93, 5, 22, 4, 61, 6, 48, 0, 80, 
    0, 23, 2, 53, 5, 19, 4, 78, 6, 52, 7, 30, 3, 62, 1, 21, 8, 83, 
    4, 22, 1,  9, 2, 76, 5, 12, 0,  3, 7, 28, 3, 15, 8, 81, 6, 65, 
    8, 94, 6, 41, 2, 64, 7, 87, 4, 42, 3, 73, 0, 76, 1, 55, 5, 53, 
    2, 73, 0, 73, 1, 90, 6, 81, 7, 60, 5, 97, 4, 77, 8, 77, 3, 69, 
    4, 86, 5,  5, 3, 20, 6, 31, 8, 31, 1, 89, 0, 78, 7, 47, 2, 96, 
    7, 81, 2, 12, 5,  2, 4, 34, 1, 93, 6, 63, 0, 88, 3, 16, 8, 72
  };
  const int q7147[] = {
    9, 9, // Number of jobs and machines
    0, 63, 6, 32, 2, 29, 8, 69, 7, 52, 4, 82, 1, 19, 3, 87, 5, 92, 
    2, 25, 8, 81, 6, 52, 3, 29, 5, 46, 7, 54, 4, 21, 0, 55, 1, 56, 
    0, 45, 2, 23, 4, 77, 6, 34, 7, 34, 3, 20, 1, 16, 5, 25, 8, 72, 
    2, 33, 7, 41, 1, 72, 0, 44, 4, 42, 5, 19, 8, 40, 6, 30, 3, 64, 
    1, 74, 6, 94, 5, 33, 8, 76, 0, 48, 7, 51, 4, 54, 3, 10, 2, 57, 
    2, 22, 5, 74, 1, 78, 7, 18, 8, 46, 4, 28, 3, 83, 6, 28, 0, 56, 
    0, 76, 5, 66, 7, 56, 6, 28, 8, 17, 1, 48, 4, 86, 2, 66, 3, 29, 
    4, 23, 7, 17, 8, 12, 2, 53, 0, 25, 6, 45, 5, 80, 3, 71, 1, 63, 
    8, 56, 3, 83, 1, 27, 2, 48, 6, 53, 0, 67, 7, 46, 5, 64, 4, 51
  };
  const int q7148[] = {
    9, 9, // Number of jobs and machines
    5,  6, 3, 24, 7, 57, 4, 31, 0, 39, 2, 18, 1, 21, 6, 49, 8, 55, 
    7, 51, 5, 62, 2, 98, 3, 99, 0, 79, 6, 18, 8, 20, 1,  7, 4, 75, 
    8,  2, 2, 75, 1, 24, 6, 80, 5, 16, 0, 43, 3,  7, 4, 99, 7, 79, 
    6, 79, 4, 31, 3,  6, 1, 61, 8, 77, 7, 18, 0, 81, 2, 80, 5, 31, 
    5, 68, 3, 55, 0, 92, 7, 19, 2, 54, 4, 33, 6, 46, 8,  4, 1, 94, 
    7, 27, 6, 95, 4, 73, 3, 33, 2, 50, 0, 45, 5, 16, 1, 49, 8, 36, 
    5, 91, 2, 97, 7, 57, 1, 60, 4,  8, 0, 10, 8, 75, 6, 86, 3, 86, 
    2, 64, 7, 31, 8, 90, 0, 99, 3, 55, 1, 78, 6, 52, 5, 85, 4,  7, 
    3, 86, 8, 94, 2, 58, 0, 15, 5, 78, 4, 83, 1, 43, 7, 40, 6, 87
  };
  const int q7149[] = {
    9, 9, // Number of jobs and machines
    6, 23, 2, 79, 7, 21, 1, 23, 8, 56, 5, 99, 0, 16, 4, 36, 3, 43, 
    8, 31, 4, 91, 5, 14, 0, 43, 7,  6, 6, 82, 3, 77, 1,  8, 2, 88, 
    4, 45, 2, 24, 0, 90, 1, 59, 5, 45, 7, 21, 3, 96, 6, 88, 8, 86, 
    7, 67, 3, 65, 5, 97, 2, 46, 4, 13, 0, 30, 1, 97, 6, 30, 8, 49, 
    1, 33, 3, 61, 6, 27, 0, 90, 4, 67, 7, 63, 2, 44, 5, 46, 8, 64, 
    0, 66, 7,  9, 4, 95, 6, 40, 8, 43, 1, 24, 3, 80, 5, 45, 2, 41, 
    5, 81, 2, 64, 0, 59, 8,  9, 3, 47, 1, 28, 4, 21, 7, 80, 6, 78, 
    2, 70, 1, 65, 6, 26, 4, 16, 3, 51, 8, 28, 7,  2, 5, 19, 0, 83, 
    2,  3, 1, 61, 3, 87, 4, 89, 7, 44, 0, 85, 8, 52, 5, 41, 6,  1
  };
  const int q7150[] = {
    9, 9, // Number of jobs and machines
    1, 95, 5, 68, 8, 59, 6, 22, 3, 65, 0, 22, 7, 47, 2, 35, 4,  8, 
    6, 38, 8, 45, 3, 74, 1, 14, 4, 79, 7, 55, 2,  7, 5, 83, 0, 86, 
    5, 86, 4, 84, 1, 72, 2, 36, 8, 61, 7, 10, 3, 27, 6, 56, 0, 31, 
    2, 85, 3, 98, 6, 94, 5, 57, 8, 62, 7, 51, 4, 91, 1, 44, 0, 95, 
    1, 66, 2, 73, 3, 19, 0, 97, 8, 98, 4, 90, 5, 37, 6,  9, 7, 40, 
    4, 32, 5, 42, 1, 37, 3,  7, 7, 33, 8, 18, 0,  5, 2, 67, 6, 53, 
    1, 86, 8, 60, 2, 42, 4, 94, 5, 65, 0, 76, 3, 81, 7, 57, 6, 69, 
    3, 48, 0, 53, 1, 33, 4, 55, 6, 41, 2, 84, 7, 20, 5, 13, 8, 38, 
    0, 10, 4, 87, 1, 76, 8, 88, 7, 78, 5, 30, 3, 97, 6, 99, 2, 70
  };
  const int q7151[] = {
    9, 9, // Number of jobs and machines
    5, 53, 4, 94, 0, 67, 3, 76, 6, 48, 1, 48, 8, 10, 7, 47, 2, 75, 
    5, 64, 3, 96, 6, 83, 8, 16, 7, 75, 0, 55, 1, 36, 4, 28, 2, 56, 
    1, 89, 2, 46, 6, 24, 7, 81, 5, 34, 3, 16, 8, 36, 0, 62, 4, 69, 
    3, 84, 2, 30, 1, 93, 6, 91, 7, 57, 0, 75, 5, 27, 4, 75, 8, 75, 
    1, 34, 8, 21, 7, 24, 0, 38, 3, 29, 2, 27, 6, 98, 5, 67, 4, 31, 
    2, 24, 7, 16, 0, 53, 5, 17, 8, 51, 6, 35, 4, 55, 1, 85, 3, 59, 
    3, 38, 8,  1, 0, 22, 7,  4, 4,  3, 6, 94, 1, 13, 2, 82, 5, 89, 
    1, 65, 8, 85, 7, 52, 0, 90, 3, 55, 5, 96, 6, 36, 2, 24, 4, 39, 
    8, 98, 5, 64, 2, 50, 4, 15, 7, 25, 3, 49, 6, 54, 1, 15, 0, 80
  };
  const int q7152[] = {
    9, 9, // Number of jobs and machines
    4, 91, 7, 19, 8, 30, 2, 45, 1, 20, 6, 75, 0, 35, 3, 59, 5, 84, 
    7, 28, 0, 84, 5, 87, 3, 42, 6, 20, 8, 34, 4, 48, 2, 97, 1, 22, 
    6, 26, 2, 67, 8, 59, 4, 67, 7, 41, 0, 87, 3, 47, 1, 89, 5, 56, 
    6, 68, 4, 14, 5, 13, 2, 37, 3, 83, 8, 28, 1, 55, 0, 92, 7, 26, 
    1, 98, 8, 23, 0, 54, 3, 36, 5, 96, 7, 52, 6, 71, 2, 57, 4, 61, 
    1, 11, 4, 73, 5,  6, 0, 35, 3, 24, 2,  1, 8, 24, 6, 24, 7, 96, 
    8, 73, 1, 38, 4, 93, 3, 72, 7, 23, 5, 83, 6, 95, 2, 62, 0,  7, 
    0, 91, 4, 87, 7, 23, 3, 59, 2, 47, 5,  6, 1, 38, 8, 24, 6, 34, 
    2, 91, 6, 55, 0, 99, 4, 25, 5, 58, 3, 91, 1, 96, 7, 61, 8, 71
  };
  const int q7153[] = {
    9, 9, // Number of jobs and machines
    8, 22, 1, 50, 0, 34, 4, 99, 6, 96, 7, 57, 2,  5, 3, 91, 5, 50, 
    1, 51, 5, 27, 7, 39, 0, 36, 2, 52, 8, 55, 3, 31, 4, 97, 6, 95, 
    2, 23, 6, 33, 8, 79, 1, 94, 7, 12, 4, 70, 0,  9, 3, 60, 5, 89, 
    2, 35, 4, 13, 8, 49, 3, 12, 5, 14, 6, 92, 1, 71, 0, 80, 7, 52, 
    6, 29, 5, 85, 0, 93, 2, 89, 8, 96, 3,  3, 7, 46, 4, 46, 1,  5, 
    0, 37, 8, 21, 2, 35, 6, 26, 5, 45, 3, 18, 4, 81, 7, 24, 1, 61, 
    2, 63, 8, 72, 6, 34, 4, 31, 0,  2, 7, 61, 3, 73, 1, 15, 5, 82, 
    3, 87, 1, 39, 4, 34, 8, 33, 2, 41, 6, 15, 5, 95, 0, 55, 7, 74, 
    6, 74, 5, 51, 8, 46, 7, 95, 1, 59, 0, 62, 2, 58, 3, 91, 4, 38
  };
  const int q7154[] = {
    9, 9, // Number of jobs and machines
    1, 75, 7, 23, 4, 85, 5, 31, 2, 68, 3,  1, 0, 50, 8, 74, 6, 91, 
    2,  3, 8, 22, 3, 62, 5, 58, 4, 73, 6, 45, 7, 92, 1, 10, 0, 33, 
    3, 64, 1, 20, 6, 27, 8, 99, 2, 58, 7, 75, 5, 45, 0, 99, 4, 55, 
    8, 91, 4, 56, 5, 32, 1, 61, 3, 83, 2, 54, 0, 68, 7, 45, 6, 69, 
    0,  8, 2, 98, 4, 27, 6, 95, 3, 38, 7, 87, 1, 35, 5, 62, 8, 58, 
    0, 87, 6, 81, 4, 10, 7, 11, 1, 70, 8, 77, 3,  8, 5, 45, 2, 15, 
    3,  8, 7, 24, 8,  7, 1, 51, 6, 23, 0, 89, 2, 59, 4, 35, 5, 77, 
    2, 54, 4, 65, 0, 91, 1, 18, 8, 60, 3, 66, 6, 12, 7, 80, 5,  6, 
    1, 61, 5, 90, 2, 12, 8, 12, 4, 16, 0, 42, 7, 51, 3, 33, 6, 25
  };
  const int q7155[] = {
    9, 9, // Number of jobs and machines
    7, 65, 6, 93, 8, 55, 2, 62, 3, 42, 1, 83, 0, 40, 4, 93, 5, 28, 
    1, 29, 4, 15, 2, 35, 7, 37, 5,  9, 8, 20, 6, 32, 3,  9, 0, 84, 
    6, 27, 7, 87, 1, 45, 3, 56, 4, 36, 2,  8, 0, 68, 5, 66, 8, 87, 
    1, 80, 0,  3, 8, 29, 7, 16, 3, 93, 4, 87, 5, 38, 6, 95, 2, 39, 
    6, 35, 1, 21, 7, 38, 3, 19, 5, 36, 8, 77, 4, 61, 0, 30, 2, 36, 
    2,  1, 0, 56, 3, 60, 6, 14, 1, 61, 8, 45, 5, 39, 4, 98, 7, 17, 
    2, 88, 3,  5, 4, 59, 6,  4, 7,  5, 5, 14, 8, 41, 0, 36, 1, 69, 
    7, 68, 4, 41, 0, 50, 2, 44, 1, 42, 3, 76, 8, 55, 5, 64, 6,  1, 
    3, 61, 1, 57, 8, 86, 7, 28, 4, 98, 2,  2, 0, 38, 5, 83, 6, 74
  };
  const int q7156[] = {
    9, 9, // Number of jobs and machines
    1, 71, 2, 97, 3, 96, 5, 49, 4, 65, 8, 54, 7, 38, 6, 99, 0, 10, 
    7, 65, 1, 97, 5, 52, 3, 34, 4, 58, 8,  4, 6, 16, 0, 40, 2, 12, 
    8, 87, 4, 18, 2, 30, 0, 67, 7,  2, 1, 15, 3, 59, 5, 28, 6, 17, 
    6, 63, 5, 80, 2, 27, 1, 74, 7, 25, 3, 44, 8, 26, 0, 50, 4, 55, 
    4, 69, 2, 34, 7, 48, 0, 87, 6, 59, 8, 72, 3, 35, 5, 56, 1, 46, 
    7, 92, 6, 26, 2, 30, 8,  2, 3, 74, 5, 31, 4, 26, 1, 76, 0, 12, 
    2, 10, 4,  2, 1, 11, 3, 52, 0, 11, 5,  3, 8, 70, 7, 79, 6, 74, 
    3,  4, 0, 15, 8, 45, 1, 78, 5, 26, 6, 91, 4, 49, 2, 19, 7, 94, 
    1, 65, 3, 90, 5, 72, 8, 82, 4, 38, 0, 47, 6, 81, 2, 74, 7, 47
  };
  const int q7157[] = {
    9, 9, // Number of jobs and machines
    3, 39, 2, 80, 4, 10, 7, 64, 1, 49, 6, 93, 8, 57, 5,  4, 0, 20, 
    0, 19, 3, 89, 5, 63, 6, 38, 4, 50, 2, 96, 1, 38, 7, 33, 8, 89, 
    1, 89, 4, 28, 6,  6, 5, 18, 7, 19, 3, 89, 0, 96, 2, 34, 8, 58, 
    0, 94, 8, 52, 4, 89, 1, 32, 2, 52, 5, 57, 3,  2, 6, 35, 7, 68, 
    2, 40, 3, 43, 4, 30, 6, 28, 0, 71, 1, 80, 8, 21, 7,  5, 5, 55, 
    6, 37, 8, 97, 2, 61, 5, 34, 0, 35, 3, 94, 7, 60, 4, 14, 1, 92, 
    4, 45, 6, 14, 5, 55, 2, 59, 7, 58, 3, 32, 8, 34, 0, 33, 1, 51, 
    1, 30, 6, 73, 5, 19, 7, 50, 2, 97, 0, 60, 8, 83, 3, 42, 4, 91, 
    4, 30, 2, 64, 5, 41, 3, 70, 8, 14, 6, 62, 1, 36, 7, 29, 0, 89
  };
  const int q7158[] = {
    9, 9, // Number of jobs and machines
    8, 34, 2, 39, 5, 72, 6, 86, 3, 39, 1, 12, 0, 55, 4,  8, 7, 73, 
    0, 26, 1, 24, 2,  8, 7, 15, 6, 28, 8, 61, 4, 83, 5,  7, 3, 79, 
    1, 33, 5, 84, 4,  9, 0, 13, 8, 82, 7, 87, 3, 77, 6, 62, 2, 44, 
    8,  6, 4, 28, 7, 84, 6, 41, 1, 52, 2, 23, 0, 20, 3, 53, 5, 43, 
    8, 79, 6, 39, 0, 76, 7, 66, 3, 19, 2, 45, 5, 29, 4, 50, 1, 79, 
    3, 86, 5, 47, 7, 43, 4, 32, 1, 48, 8, 96, 2, 57, 0, 68, 6,  3, 
    3, 37, 7,  5, 1, 96, 0, 97, 5, 72, 6, 54, 4, 98, 8, 88, 2, 49, 
    6, 58, 4, 49, 8, 38, 0, 85, 5, 76, 3, 72, 1, 49, 2, 75, 7, 73, 
    3, 12, 7, 46, 1, 18, 6, 75, 4, 30, 8, 94, 5, 78, 0, 93, 2, 36
  };
  const int q7159[] = {
    9, 9, // Number of jobs and machines
    0, 64, 6,  2, 3,  6, 1, 44, 5, 44, 7, 30, 2, 32, 4, 84, 8, 13, 
    6, 98, 5, 96, 0, 64, 7, 61, 1, 12, 3, 72, 4, 47, 2,  1, 8, 61, 
    1, 34, 2,  3, 4, 92, 5, 53, 8, 23, 3, 11, 6, 48, 0, 19, 7, 12, 
    1, 63, 4, 71, 3, 61, 2, 44, 7, 83, 0, 80, 8, 12, 5, 49, 6, 52, 
    5, 70, 3, 75, 6, 78, 2, 75, 0, 39, 4,  1, 1, 12, 7, 54, 8, 74, 
    6, 99, 1, 27, 5, 88, 3, 64, 2, 13, 8,  8, 4, 94, 7, 23, 0, 27, 
    2, 59, 4, 85, 8, 73, 3, 22, 1,  8, 7, 21, 6, 23, 5, 35, 0, 79, 
    8, 12, 0, 62, 5, 95, 6, 45, 4, 15, 2, 32, 3, 18, 1, 78, 7, 19, 
    6, 58, 4, 69, 8,  2, 7, 72, 0, 75, 3, 83, 1, 10, 2, 44, 5, 42
  };
  const int q7160[] = {
    9, 9, // Number of jobs and machines
    3, 90, 8, 68, 2, 41, 5, 26, 1, 88, 4, 23, 0, 48, 6, 82, 7, 85, 
    4, 40, 6, 58, 1, 81, 8,  5, 2, 31, 7, 82, 5, 94, 0, 30, 3, 82, 
    0, 24, 2, 78, 7, 57, 1,  5, 3, 25, 6, 22, 4, 74, 8, 92, 5,  1, 
    2, 59, 0, 39, 7, 52, 6, 67, 5, 95, 1, 98, 4, 13, 8, 16, 3, 86, 
    2, 15, 1, 62, 0, 49, 7, 13, 4, 90, 6, 54, 8, 12, 5, 27, 3, 65, 
    3, 93, 2, 28, 1, 24, 8, 93, 0, 55, 6, 12, 5,  5, 7, 46, 4, 31, 
    6, 50, 0, 91, 2, 62, 1, 34, 4, 88, 7, 63, 8, 19, 3, 24, 5, 19, 
    7, 91, 4,  3, 1, 49, 6, 13, 8, 38, 5, 32, 2, 32, 0, 43, 3, 22, 
    6, 25, 8, 60, 3, 76, 7, 85, 5, 76, 2, 89, 1, 44, 4, 89, 0,  9
  };
  const int q7161[] = {
    9, 9, // Number of jobs and machines
    1, 70, 8, 38, 0, 80, 2, 94, 3, 69, 5, 37, 7, 75, 4,  3, 6, 84, 
    8, 20, 0, 75, 3, 86, 5, 16, 4, 47, 2, 44, 1, 24, 6, 65, 7, 80, 
    8, 87, 6, 57, 5, 24, 4, 53, 7, 42, 1, 27, 3, 75, 0, 17, 2, 30, 
    1, 60, 7, 38, 6, 70, 4, 75, 0, 87, 8, 35, 3, 75, 5, 44, 2, 93, 
    4, 97, 6, 42, 0, 63, 5, 47, 2, 38, 1,  4, 8, 47, 7, 53, 3,  6, 
    0, 44, 2,  8, 8, 92, 6, 55, 1, 71, 5, 55, 7, 39, 4, 35, 3, 10, 
    7, 73, 2, 62, 6,  5, 0, 85, 3, 38, 5, 80, 1, 98, 4, 46, 8, 36, 
    5, 30, 7, 67, 2, 27, 4, 81, 8, 56, 0, 45, 3, 22, 1, 80, 6, 49, 
    1, 63, 8, 56, 4, 81, 6, 21, 3, 21, 5, 13, 2, 58, 0, 87, 7, 32
  };
  const int q7162[] = {
    9, 9, // Number of jobs and machines
    5, 29, 0, 31, 4, 92, 3, 83, 1, 42, 8, 66, 7, 12, 6, 55, 2, 57, 
    3, 56, 8, 53, 0, 84, 1, 56, 7, 47, 4, 41, 5, 35, 6, 57, 2, 36, 
    2, 53, 0, 23, 5, 86, 3, 11, 8, 59, 7,  9, 1, 20, 6, 27, 4, 72, 
    6, 73, 2, 91, 7, 80, 8, 84, 3, 85, 0, 73, 5, 64, 1, 37, 4, 50, 
    5, 15, 6, 92, 8, 90, 2, 21, 7, 16, 3, 98, 4, 91, 1, 78, 0,  6, 
    4, 23, 0, 83, 8, 17, 5, 61, 2,  6, 6,  6, 3, 77, 7, 25, 1, 50, 
    7, 66, 4, 56, 5, 65, 0, 52, 1,  3, 3, 12, 6,  9, 8, 58, 2, 18, 
    2, 11, 0, 30, 5, 94, 7, 35, 6, 88, 3, 38, 8, 93, 4, 30, 1, 51, 
    3, 39, 0,  8, 4,  7, 1, 22, 6, 33, 8,  1, 7, 19, 5, 71, 2, 84
  };
  const int q7163[] = {
    9, 9, // Number of jobs and machines
    8, 85, 0, 14, 6, 29, 5, 31, 2, 64, 1, 12, 3, 86, 4, 49, 7, 83, 
    3, 70, 0, 95, 8, 84, 1, 93, 7,  1, 5, 13, 4, 58, 6, 83, 2, 45, 
    3, 63, 6, 43, 8, 33, 4, 32, 2, 30, 1, 87, 5, 50, 7, 43, 0, 37, 
    8, 64, 5, 51, 0, 16, 3, 37, 4, 87, 1, 85, 2, 65, 6, 44, 7, 67, 
    5, 78, 0, 30, 1, 27, 2, 87, 8,  4, 4, 80, 3, 21, 6, 86, 7, 33, 
    7, 48, 4, 22, 0, 50, 2, 65, 1, 31, 3, 18, 6, 85, 8,  2, 5, 73, 
    0, 29, 4, 11, 7, 84, 5, 71, 3, 61, 2, 66, 8, 15, 6, 82, 1, 50, 
    5, 96, 6, 19, 4, 44, 1, 89, 2, 25, 3, 79, 0, 28, 8, 24, 7, 59, 
    7,  4, 0, 32, 8, 13, 1, 38, 3, 38, 5, 92, 6,  9, 4, 44, 2, 72
  };
  const int q7164[] = {
    9, 9, // Number of jobs and machines
    0, 43, 1, 60, 5, 15, 8, 78, 7, 29, 6, 74, 2, 13, 4, 38, 3, 37, 
    0, 37, 7, 87, 2, 79, 8, 26, 3, 71, 1, 16, 5, 30, 4, 17, 6, 92, 
    7, 29, 3, 78, 1, 64, 5, 44, 0, 30, 6,  3, 8,  5, 2, 12, 4, 16, 
    1, 87, 2, 67, 3, 39, 5, 10, 0, 25, 7, 71, 8, 38, 6,  8, 4, 60, 
    4, 47, 7, 43, 8, 69, 5, 14, 2, 10, 3, 93, 0, 35, 1, 66, 6, 29, 
    7, 26, 3, 51, 5, 64, 2,  6, 0,  4, 8, 83, 1, 63, 6, 38, 4, 87, 
    2, 51, 3, 23, 4, 43, 8, 70, 7, 42, 5, 29, 1, 58, 0, 75, 6, 62, 
    2, 11, 1,  6, 0, 93, 3, 55, 6, 62, 5, 80, 8, 25, 7, 80, 4, 56, 
    3,  4, 2, 67, 6,  6, 0, 84, 5, 51, 1, 73, 4, 92, 7, 76, 8, 70
  };
  const int q7165[] = {
    9, 9, // Number of jobs and machines
    0, 61, 6, 53, 4, 53, 8, 61, 2, 48, 5, 52, 7, 85, 3, 88, 1, 20, 
    3, 49, 2, 72, 6, 76, 7, 39, 4, 79, 1, 84, 8, 78, 5, 16, 0, 50, 
    0, 36, 4, 53, 7, 23, 6, 49, 8, 40, 2, 99, 1, 43, 5, 74, 3, 37, 
    2, 24, 6, 89, 7, 21, 4, 22, 8, 69, 3, 98, 5, 42, 0, 17, 1, 12, 
    5, 96, 3, 63, 1, 68, 8, 88, 6, 43, 2,  1, 4, 57, 7, 30, 0, 65, 
    8, 93, 5, 28, 3,  7, 7, 66, 0, 13, 4, 32, 6, 54, 1, 35, 2, 94, 
    1, 45, 0, 11, 3, 20, 8, 46, 5, 21, 4, 45, 2, 76, 7,  4, 6, 66, 
    4, 89, 1, 10, 7, 74, 0, 65, 3,  2, 6, 13, 5, 28, 2, 68, 8, 69, 
    6, 28, 2, 11, 0, 48, 4, 70, 1, 83, 5, 79, 8, 72, 7, 61, 3, 37
  };
  const int q7166[] = {
    9, 9, // Number of jobs and machines
    0, 64, 7, 70, 5, 33, 6, 61, 2, 80, 1, 29, 4, 26, 8, 49, 3, 26, 
    0, 61, 4,  4, 5, 20, 2, 49, 3, 74, 8, 76, 1,  9, 7, 34, 6, 43, 
    5, 72, 6, 88, 4, 26, 2, 82, 1,  9, 7, 44, 3, 48, 8, 95, 0, 40, 
    0, 89, 6, 10, 7, 27, 3, 87, 2, 45, 5, 56, 8, 27, 1, 23, 4, 85, 
    8, 39, 0,  2, 3, 21, 2, 40, 6, 53, 4, 29, 5, 85, 1, 14, 7, 69, 
    1, 51, 5, 41, 7, 86, 3, 91, 6, 95, 0, 91, 8, 16, 2, 67, 4, 26, 
    4, 81, 6, 92, 0, 13, 2, 48, 3, 91, 7, 34, 1, 88, 5, 37, 8, 89, 
    3, 76, 6, 32, 2, 56, 0, 37, 5, 64, 8, 83, 1, 18, 7, 87, 4, 20, 
    7, 98, 8, 96, 3, 89, 2, 23, 6, 41, 0, 69, 5, 73, 4, 29, 1, 82
  };
  const int q7167[] = {
    9, 9, // Number of jobs and machines
    1, 97, 7, 30, 3, 40, 6, 63, 2, 74, 4, 37, 5, 19, 8, 40, 0, 51, 
    3, 99, 5, 42, 7, 34, 2, 43, 6, 33, 8, 20, 1, 56, 4, 81, 0, 19, 
    7,  2, 3,  1, 6, 58, 8, 44, 5, 36, 1, 32, 0, 57, 2, 42, 4, 89, 
    7, 38, 2, 79, 0, 61, 6, 48, 3, 55, 8, 13, 5, 67, 4, 96, 1, 40, 
    4, 36, 3, 86, 2, 11, 1, 40, 5, 73, 0,  5, 6, 34, 8, 15, 7, 73, 
    2, 84, 8, 86, 5, 68, 6, 42, 3, 76, 0, 31, 4,  3, 1, 84, 7, 84, 
    6, 31, 7, 55, 2,  2, 1, 59, 3, 86, 0, 66, 5, 76, 4, 67, 8, 18, 
    1, 70, 5, 10, 0, 91, 3, 36, 8, 11, 2, 57, 7, 29, 4, 41, 6, 95, 
    6, 42, 5, 97, 3, 96, 2, 43, 1, 80, 8, 12, 0, 95, 7, 56, 4, 44
  };
  const int q7168[] = {
    9, 9, // Number of jobs and machines
    0, 93, 3, 24, 6, 97, 2, 29, 8, 18, 4, 89, 5, 19, 1, 65, 7, 64, 
    0, 86, 5, 62, 4,  7, 8, 71, 1, 85, 3,  1, 7, 37, 2, 50, 6, 73, 
    3, 68, 2, 99, 6, 80, 5,  3, 1, 89, 0, 92, 8, 36, 7, 70, 4, 33, 
    8, 32, 6, 25, 1, 28, 7, 74, 3, 22, 4, 64, 0, 73, 5, 37, 2,  9, 
    5, 23, 4, 33, 7, 94, 2, 56, 8, 94, 3, 72, 6,  2, 1, 47, 0,  1, 
    0, 16, 4, 74, 5, 81, 7, 73, 1,  8, 3, 42, 6, 24, 2, 90, 8, 71, 
    5, 11, 1, 22, 4, 28, 0,  6, 2, 10, 3, 42, 7, 37, 6, 56, 8, 66, 
    1, 75, 2, 48, 7, 96, 4, 23, 6, 27, 0,  9, 8, 13, 3, 94, 5, 85, 
    3, 79, 0, 45, 5,  9, 1, 27, 6, 51, 7, 18, 2, 47, 4, 75, 8,  3
  };
  const int q7169[] = {
    9, 9, // Number of jobs and machines
    6, 23, 4, 72, 3, 35, 8, 61, 0, 46, 5, 73, 7, 24, 1, 47, 2, 34, 
    3, 76, 1, 66, 5, 76, 7, 85, 0, 51, 4,  5, 6, 44, 8, 88, 2, 60, 
    1, 71, 6, 72, 5, 46, 3,  5, 0, 63, 2, 30, 7, 49, 8, 26, 4, 15, 
    3, 71, 1, 98, 8, 15, 5, 81, 4, 74, 6, 30, 7, 44, 0, 62, 2, 43, 
    4, 92, 0, 14, 3, 12, 8, 93, 6, 23, 1, 68, 2, 82, 5, 34, 7,  5, 
    4, 86, 5,  9, 1,  1, 6,  8, 2, 21, 7, 20, 8,  9, 0, 32, 3, 97, 
    2, 38, 0, 94, 3, 36, 5, 43, 6,  4, 4, 76, 8, 77, 7, 52, 1,  1, 
    6, 95, 7, 47, 2, 90, 0, 27, 3, 44, 1, 35, 5, 32, 8,  6, 4,  8, 
    7, 73, 5, 13, 1,  9, 3, 55, 8,  5, 0, 50, 6, 69, 2, 40, 4, 78
  };
  const int q7170[] = {
    9, 9, // Number of jobs and machines
    4, 34, 5, 76, 6, 36, 2, 55, 8, 56, 0, 54, 7, 73, 3, 49, 1, 40, 
    2, 67, 8, 82, 1, 12, 3, 94, 5, 54, 0, 50, 6, 41, 7, 72, 4, 47, 
    1, 33, 2, 79, 8, 44, 4, 46, 7, 36, 0, 86, 3, 88, 6, 93, 5, 27, 
    1, 62, 5, 72, 3, 41, 6, 92, 0, 66, 7, 70, 2, 87, 4, 94, 8, 16, 
    3, 26, 8, 39, 5, 51, 4, 89, 6, 10, 7, 15, 2, 41, 0, 88, 1, 84, 
    4, 16, 8, 93, 7, 75, 3, 61, 2, 62, 0, 77, 1,  9, 5, 99, 6, 71, 
    0, 86, 4, 69, 7, 52, 6, 55, 2, 40, 3, 64, 8, 56, 1, 70, 5, 81, 
    4, 70, 8, 81, 3, 50, 7, 66, 0, 91, 5, 47, 6, 74, 2, 72, 1, 34, 
    2, 96, 1, 69, 7, 49, 4, 45, 0, 24, 8,  5, 6, 42, 5, 35, 3, 57
  };
  const int q7171[] = {
    9, 9, // Number of jobs and machines
    1, 59, 7, 12, 0, 55, 4, 83, 3, 19, 5,  4, 6, 12, 8, 81, 2, 97, 
    2, 33, 6, 45, 3, 62, 5, 30, 8, 58, 1, 70, 0, 96, 7, 81, 4, 91, 
    4, 21, 6, 34, 7, 32, 0, 39, 1, 96, 5, 54, 3, 21, 8, 51, 2, 65, 
    7, 34, 2, 76, 1, 10, 4, 58, 0, 40, 3, 92, 5, 32, 6, 59, 8, 29, 
    0,  5, 7, 47, 6, 93, 2, 29, 8, 93, 1, 25, 5, 80, 3, 67, 4, 23, 
    8, 32, 0, 98, 7, 80, 4, 13, 3, 35, 6, 24, 1, 77, 5, 70, 2, 70, 
    3, 35, 1, 91, 0,  8, 8, 80, 5, 69, 6, 78, 4, 60, 7, 34, 2, 85, 
    5, 85, 2, 44, 0, 42, 4, 27, 7, 37, 6, 47, 1, 95, 3, 41, 8, 19, 
    6, 11, 4, 78, 0, 65, 1, 29, 5, 93, 3, 20, 2, 95, 7, 19, 8, 79
  };
  const int q7172[] = {
    9, 9, // Number of jobs and machines
    6, 46, 7, 62, 5,  8, 3, 85, 8, 49, 2, 67, 1,  5, 0, 85, 4, 56, 
    4, 63, 7, 47, 2, 37, 0, 70, 3, 75, 6, 59, 1, 36, 8, 59, 5, 46, 
    0, 62, 5, 93, 7, 53, 8, 37, 3, 81, 6, 62, 4, 40, 2, 26, 1, 73, 
    0, 21, 1, 72, 6, 58, 8, 70, 7, 44, 5, 45, 2, 48, 4, 36, 3, 80, 
    7, 21, 5, 26, 3,  6, 2, 91, 6, 62, 4, 96, 8, 57, 0, 23, 1, 54, 
    7, 33, 1, 69, 0,  6, 6,  1, 4, 85, 5, 79, 8,  8, 3, 92, 2, 51, 
    6, 24, 0,  2, 7, 95, 5,  8, 2, 17, 4, 63, 3, 64, 1, 43, 8, 11, 
    6, 37, 2, 70, 7, 62, 3, 71, 0, 31, 1, 70, 5, 38, 4, 75, 8, 20, 
    1, 98, 0, 53, 7, 44, 2, 16, 5, 90, 3, 10, 6, 90, 8, 30, 4, 20
  };
  const int q7173[] = {
    9, 9, // Number of jobs and machines
    5, 91, 1, 95, 2, 47, 7, 72, 6,  9, 3, 94, 0, 58, 8, 44, 4, 86, 
    0, 90, 8, 12, 2, 81, 7, 38, 6, 22, 3, 40, 1, 19, 5, 70, 4,  3, 
    6, 44, 8, 92, 5, 53, 1, 55, 2, 98, 0, 10, 4, 82, 7, 31, 3,  7, 
    5, 16, 6, 22, 0, 70, 1, 89, 7,  8, 4, 71, 8, 87, 2, 10, 3,  4, 
    7, 52, 6, 34, 2, 82, 0, 92, 1, 54, 5,  5, 3, 18, 8, 63, 4, 32, 
    3, 20, 7, 54, 8, 11, 1, 93, 4, 58, 2, 36, 0, 59, 5, 31, 6,  7, 
    5, 68, 1, 65, 6, 20, 8, 89, 3,  8, 4,  2, 7, 52, 2, 54, 0, 92, 
    5, 94, 3, 81, 0,  3, 1, 72, 7, 50, 2, 17, 6, 51, 8, 67, 4, 49, 
    1, 91, 3, 14, 2, 55, 7, 90, 0,  1, 8, 21, 6, 49, 4, 95, 5, 87
  };
  const int q7174[] = {
    9, 9, // Number of jobs and machines
    6,  2, 4, 30, 8, 50, 5, 47, 3,  3, 0, 14, 1, 88, 2, 45, 7, 88, 
    6, 25, 0, 65, 3, 26, 7, 55, 4, 57, 1, 21, 2, 16, 8, 70, 5, 21, 
    1, 46, 7, 24, 3, 23, 2, 29, 5,  6, 8, 87, 4, 37, 0, 65, 6, 65, 
    3, 76, 1, 85, 8, 27, 4, 13, 2, 34, 6, 57, 7, 27, 5, 39, 0, 68, 
    1, 27, 7, 92, 5, 89, 4, 85, 6, 87, 8, 48, 3, 29, 0, 90, 2, 50, 
    1, 38, 2, 55, 4, 36, 5, 91, 3, 94, 7, 66, 8, 46, 6, 68, 0, 10, 
    3, 75, 8, 59, 0, 77, 1,  5, 6, 66, 4, 23, 2,  3, 5, 57, 7, 92, 
    8, 58, 4, 47, 7, 15, 1, 43, 0,  7, 6, 16, 5, 79, 3, 26, 2, 67, 
    8, 97, 1, 68, 7, 42, 3, 31, 0, 72, 5, 19, 4, 23, 6, 62, 2, 33
  };
  const int q7175[] = {
    9, 9, // Number of jobs and machines
    2, 59, 8, 80, 4, 32, 7, 13, 0, 49, 6, 81, 1, 32, 3, 26, 5, 50, 
    1, 36, 3, 45, 2, 15, 4, 37, 7, 94, 0, 65, 6, 70, 5, 90, 8, 10, 
    3,  5, 0, 38, 4, 99, 2,  9, 1, 46, 5, 73, 8,  5, 6, 29, 7, 42, 
    2, 62, 5, 26, 8,  5, 3, 96, 4, 43, 7, 51, 1, 90, 6, 71, 0, 95, 
    5, 30, 3, 64, 8, 48, 2, 14, 6, 70, 7, 64, 1, 99, 4,  8, 0, 83, 
    3, 76, 8, 41, 6, 61, 7, 75, 0, 97, 1, 69, 2, 80, 4, 34, 5, 59, 
    2, 35, 8,  7, 3, 84, 0, 69, 7, 84, 4, 30, 6, 24, 1, 81, 5,  4, 
    3, 84, 8, 31, 0, 56, 5, 90, 4, 66, 1, 51, 7, 96, 6,  7, 2, 39, 
    7, 58, 6, 64, 3, 41, 1, 48, 2, 33, 4,  9, 0, 25, 5, 14, 8, 47
  };
  const int q7176[] = {
    9, 9, // Number of jobs and machines
    4, 39, 3, 43, 6, 97, 7, 39, 0, 64, 5, 62, 2, 87, 1, 45, 8, 90, 
    1, 92, 4, 94, 8, 27, 5, 35, 6, 38, 2, 22, 0, 59, 7, 45, 3, 48, 
    4, 15, 1, 13, 6, 84, 5, 12, 0, 64, 8, 64, 2, 73, 3, 46, 7, 26, 
    0, 75, 1, 19, 3, 44, 7, 70, 5, 25, 4, 17, 2, 80, 8, 78, 6, 29, 
    3, 96, 2, 32, 6, 23, 7, 43, 4, 81, 1, 90, 8,  4, 5,  1, 0, 89, 
    2, 86, 7, 64, 6, 96, 4, 82, 0, 42, 5, 22, 1, 88, 8, 14, 3, 92, 
    1, 50, 2, 10, 0, 70, 8, 75, 3, 47, 7, 90, 6, 39, 5, 40, 4, 26, 
    5, 81, 3, 48, 0, 41, 8, 68, 2, 72, 4, 21, 1, 79, 7, 81, 6, 94, 
    0,  1, 2, 77, 4, 69, 5, 58, 1, 69, 3,  1, 7, 38, 6, 60, 8, 34
  };
  const int q7177[] = {
    9, 9, // Number of jobs and machines
    8, 94, 5, 18, 7, 15, 1, 32, 0, 72, 4, 97, 2, 51, 6, 27, 3, 74, 
    5, 65, 4, 17, 8, 40, 1, 76, 2, 30, 7, 48, 6, 52, 0, 57, 3, 80, 
    4, 56, 3, 53, 0, 19, 2, 35, 6, 83, 7, 79, 8, 73, 5, 44, 1, 66, 
    6, 78, 1, 61, 3, 98, 2, 24, 8, 79, 5, 27, 7, 19, 4, 98, 0,  2, 
    2, 41, 3, 67, 6,  5, 7, 97, 0, 29, 1, 72, 8, 42, 5, 32, 4, 60, 
    3, 88, 8, 65, 1, 51, 6, 24, 5, 20, 0, 34, 4, 44, 2, 94, 7, 88, 
    2, 30, 6, 68, 0, 45, 8, 57, 5, 79, 7, 80, 4, 82, 1, 57, 3, 94, 
    3, 76, 2, 61, 0, 98, 7, 65, 5, 20, 1, 57, 6, 91, 4, 36, 8, 80, 
    0, 99, 3, 32, 2, 63, 1, 61, 8, 76, 5, 47, 6, 32, 7, 61, 4, 39
  };
  const int q7178[] = {
    9, 9, // Number of jobs and machines
    8,  1, 5, 33, 2, 18, 1,  5, 6, 97, 0, 10, 7, 63, 4, 55, 3, 41, 
    8, 99, 0, 59, 7, 75, 3, 94, 1, 47, 6, 38, 5, 97, 2, 63, 4, 52, 
    8, 75, 2, 70, 5, 58, 4, 51, 7, 61, 3, 77, 1, 81, 0, 66, 6, 73, 
    1, 19, 3, 72, 8, 99, 2, 87, 5, 35, 4, 24, 7, 74, 0, 96, 6, 52, 
    5, 58, 1, 70, 7, 60, 2, 47, 4,  9, 6, 63, 3, 79, 8, 96, 0, 64, 
    8, 63, 2, 17, 1, 86, 3, 71, 6, 27, 0, 30, 5, 81, 4, 55, 7, 31, 
    4, 45, 0, 22, 5, 93, 2, 57, 3, 81, 8, 93, 1, 35, 6, 23, 7, 25, 
    7, 80, 2, 80, 4, 46, 8,  6, 3, 47, 0, 53, 1, 11, 6, 72, 5, 25, 
    5, 70, 1, 65, 7, 66, 0, 64, 4, 24, 2, 42, 3, 99, 8, 11, 6,  2
  };
  const int q7179[] = {
    9, 9, // Number of jobs and machines
    2, 73, 8, 95, 4, 21, 0, 69, 1, 35, 6, 28, 5, 21, 3, 33, 7, 34, 
    4, 87, 2, 35, 6, 17, 5, 50, 0, 25, 3, 94, 1, 89, 7, 91, 8, 50, 
    7, 14, 8, 15, 0,  9, 5, 39, 3, 24, 1,  7, 4, 92, 2, 71, 6, 20, 
    1, 57, 5, 10, 4, 99, 6, 79, 8, 30, 3, 36, 2, 68, 0, 92, 7, 77, 
    8, 10, 2, 63, 0, 75, 3, 12, 6, 50, 1,  1, 5, 95, 7, 32, 4, 70, 
    2, 36, 6, 33, 4, 94, 3, 23, 5, 75, 0, 82, 1, 69, 8,  4, 7, 63, 
    4, 12, 5, 13, 1, 40, 7, 26, 0, 29, 2, 74, 8, 27, 6, 25, 3,  7, 
    8, 95, 6, 55, 0,  9, 1, 55, 4, 35, 5, 95, 3, 52, 2, 47, 7, 72, 
    1, 79, 2, 66, 7, 88, 5, 64, 6, 19, 3, 64, 8, 58, 0, 19, 4, 70
  };
  const int q7180[] = {
    9, 9, // Number of jobs and machines
    7, 28, 0,  3, 3, 93, 4, 75, 1, 77, 8, 42, 5, 51, 2, 60, 6, 40, 
    8, 44, 7, 44, 3, 64, 2,  5, 5, 13, 6,  7, 1, 95, 0, 87, 4, 26, 
    2, 79, 6, 33, 1, 59, 0, 62, 5, 46, 7, 82, 3,  8, 8, 22, 4, 33, 
    6, 92, 7, 88, 3, 56, 5, 28, 2, 66, 1, 88, 8, 84, 4, 57, 0, 20, 
    6, 30, 7, 71, 2, 57, 0,  8, 3, 54, 5, 35, 8, 72, 1, 88, 4, 51, 
    7, 35, 6, 37, 3, 49, 4, 90, 0, 94, 5, 74, 1, 69, 8, 57, 2, 10, 
    5, 99, 8, 59, 0, 64, 4, 76, 6,  7, 7,  4, 1, 48, 3, 70, 2, 53, 
    4, 21, 7, 77, 2, 11, 1, 75, 0, 57, 6, 76, 5,  2, 8, 88, 3, 58, 
    0, 30, 6, 82, 1, 52, 7, 31, 5, 77, 2, 72, 3, 59, 4, 92, 8, 91
  };
  const int q7181[] = {
    9, 9, // Number of jobs and machines
    5, 59, 2, 44, 7, 11, 4,  5, 6, 88, 1, 43, 3,  1, 0, 77, 8, 64, 
    5, 58, 7, 74, 8,  2, 4, 67, 3, 99, 2, 60, 6, 99, 1, 22, 0, 64, 
    2, 23, 8, 82, 0, 27, 4, 47, 7, 28, 3, 23, 6, 13, 1, 79, 5, 68, 
    4, 60, 6, 24, 7, 92, 0,  3, 5, 61, 1, 95, 8, 43, 3, 63, 2, 96, 
    4, 38, 0, 63, 5, 64, 7, 10, 3, 93, 6, 36, 1, 44, 8, 78, 2, 96, 
    5,  1, 8, 66, 3, 17, 1, 83, 7, 15, 0, 93, 4, 11, 2, 30, 6, 90, 
    1, 24, 6, 21, 3, 85, 8, 28, 7, 29, 4,  7, 2, 58, 0, 61, 5, 27, 
    6, 79, 2, 25, 7,  3, 3, 64, 5, 88, 4, 55, 1, 73, 0, 34, 8, 88, 
    1, 75, 4, 59, 3, 22, 2, 16, 7, 47, 6, 71, 8, 44, 0, 24, 5, 25
  };
  const int q7182[] = {
    9, 9, // Number of jobs and machines
    6, 91, 1, 65, 2, 45, 3, 26, 4, 62, 0, 71, 5, 74, 8, 45, 7, 25, 
    7, 71, 8, 21, 0,  8, 4, 36, 6,  5, 3, 64, 2, 93, 1,  8, 5, 14, 
    2, 49, 6,  6, 4, 93, 3, 58, 7, 37, 1,  9, 0, 48, 8, 51, 5, 25, 
    6, 71, 5, 97, 7, 98, 0, 10, 4, 86, 8, 63, 2, 87, 1, 52, 3, 88, 
    6, 40, 1, 18, 0, 23, 7, 13, 3, 96, 2, 25, 8, 80, 5,  9, 4, 66, 
    0, 85, 6, 68, 4, 30, 5, 31, 3, 81, 2, 74, 7, 97, 8, 80, 1, 94, 
    4, 22, 3, 48, 8, 45, 6, 19, 0, 72, 1, 33, 2, 86, 5, 67, 7, 20, 
    2, 44, 8, 34, 0,  3, 3, 46, 7, 61, 5, 82, 1, 18, 6, 98, 4, 26, 
    6, 17, 4, 22, 7, 26, 3, 65, 2, 24, 8, 49, 5, 25, 1, 58, 0, 83
  };
  const int q7183[] = {
    9, 9, // Number of jobs and machines
    1, 49, 5, 68, 7, 52, 3, 27, 0, 90, 6, 33, 8, 46, 4, 54, 2, 46, 
    1, 64, 4, 18, 2,  2, 6, 89, 0, 13, 5, 17, 3, 65, 7, 38, 8, 57, 
    8, 31, 6, 63, 7, 79, 1, 90, 5, 15, 4, 58, 2, 45, 3, 13, 0, 13, 
    0, 81, 4, 92, 7,  6, 8, 18, 2, 84, 3, 97, 1, 23, 5, 70, 6, 25, 
    5, 22, 8, 58, 3, 24, 4, 68, 2, 50, 0, 24, 6, 31, 7, 29, 1, 63, 
    2, 20, 0, 78, 8, 52, 6,  8, 5,  9, 7, 10, 1, 39, 4, 24, 3,  2, 
    7, 13, 4, 53, 2, 38, 5, 23, 8, 69, 1, 23, 0, 44, 6, 37, 3, 31, 
    6, 94, 4, 10, 3, 65, 2, 46, 7, 34, 5, 35, 1, 73, 8, 92, 0, 67, 
    8, 61, 2, 11, 7, 56, 0, 74, 5, 95, 6, 47, 1, 66, 4, 25, 3, 42
  };
  const int q7184[] = {
    9, 9, // Number of jobs and machines
    8, 54, 2, 34, 5, 33, 4, 53, 3, 63, 7, 82, 1, 56, 6, 82, 0,  6, 
    3, 75, 1, 39, 8, 95, 7, 48, 2, 88, 6, 94, 0, 43, 5, 72, 4, 34, 
    3, 30, 7,  3, 2, 60, 4, 45, 8, 15, 5, 32, 6,  9, 1, 53, 0, 28, 
    3, 38, 7, 21, 4, 69, 2, 44, 5, 27, 8, 50, 0, 42, 1, 61, 6, 73, 
    3, 45, 5, 30, 6, 93, 7, 39, 8, 40, 0, 95, 4, 34, 1,  8, 2, 27, 
    8,  4, 4, 93, 5, 60, 3, 19, 2, 23, 7, 91, 6, 67, 0, 68, 1, 39, 
    3, 12, 5, 96, 4, 53, 6, 56, 0,  5, 8, 50, 1, 72, 7, 90, 2, 31, 
    8, 52, 0, 32, 2, 28, 1, 95, 3, 82, 5, 26, 6, 66, 4, 59, 7, 63, 
    2, 24, 5, 37, 8, 75, 6, 72, 0, 89, 1, 84, 3, 77, 4, 17, 7, 13
  };
  const int q7185[] = {
    9, 9, // Number of jobs and machines
    2, 83, 7, 86, 1, 53, 0, 81, 5, 46, 8, 32, 6, 47, 3, 49, 4, 90, 
    5, 47, 3,  8, 4, 45, 6,  2, 1, 39, 7, 41, 2, 18, 8, 87, 0, 78, 
    1, 30, 6, 14, 8, 41, 0, 34, 7, 46, 2, 14, 5, 26, 3,  9, 4, 29, 
    0, 55, 2, 38, 8, 35, 3,  8, 5, 11, 6, 61, 1, 62, 7, 19, 4, 35, 
    0,  5, 3, 89, 1, 42, 4,  1, 6, 71, 2, 36, 5, 46, 8, 66, 7, 82, 
    3, 16, 6, 61, 0, 54, 8, 67, 1, 85, 4, 38, 7, 45, 5, 42, 2, 96, 
    5, 32, 0, 42, 1, 51, 8, 23, 2,  1, 3, 94, 7, 90, 6, 99, 4, 72, 
    4, 26, 5, 54, 7, 99, 2, 18, 3, 24, 0, 85, 8, 16, 6, 94, 1, 85, 
    8, 61, 4, 56, 5, 52, 2,  7, 0, 94, 6,  3, 1, 18, 3, 80, 7, 41
  };
  const int q7186[] = {
    9, 9, // Number of jobs and machines
    1, 88, 7, 29, 4, 29, 3, 25, 2, 39, 0, 58, 5, 89, 6, 86, 8, 99, 
    6, 83, 1,  4, 5, 74, 2, 45, 7, 66, 3, 22, 0, 29, 4, 74, 8, 16, 
    8, 48, 2, 72, 3,  8, 4, 93, 1, 99, 7, 56, 6, 12, 5, 11, 0, 65, 
    4, 96, 3, 11, 0, 81, 1, 34, 5, 23, 6, 95, 2, 41, 7, 71, 8, 32, 
    4, 93, 0, 70, 2, 75, 6, 28, 5,  8, 7, 30, 3,  9, 8, 66, 1, 65, 
    8, 19, 4, 40, 1, 60, 5,  7, 6, 22, 2, 82, 0, 79, 7, 45, 3, 93, 
    6, 77, 5, 81, 2, 29, 8, 65, 7, 49, 0, 18, 4,  6, 3, 67, 1, 60, 
    7, 83, 3, 50, 2,  1, 0, 24, 1, 28, 6, 98, 8, 46, 5, 83, 4, 30, 
    8, 36, 0, 79, 5, 27, 3, 20, 4, 54, 7, 57, 1, 56, 6, 64, 2, 71
  };
  const int q7187[] = {
    9, 9, // Number of jobs and machines
    3, 96, 6, 27, 8,  2, 4, 68, 0, 59, 1, 40, 5, 95, 7, 97, 2, 10, 
    7, 50, 8, 40, 0, 66, 3, 90, 1,  9, 5, 42, 2, 40, 6, 34, 4, 61, 
    1, 92, 7, 52, 0,  2, 2, 65, 6, 86, 4, 13, 8, 82, 5, 86, 3, 53, 
    8, 24, 3, 41, 0, 68, 7, 35, 2, 37, 6, 17, 5, 83, 4, 45, 1, 88, 
    8, 77, 6, 76, 3, 41, 7, 65, 4, 65, 0, 54, 1, 13, 5, 83, 2,  1, 
    4, 87, 0, 94, 1, 32, 8, 68, 7, 55, 3, 39, 2, 69, 6, 92, 5, 90, 
    1, 46, 7, 46, 2, 57, 0, 67, 8, 18, 5, 80, 6, 80, 3, 51, 4, 79, 
    2, 28, 8,  4, 7, 85, 1, 13, 3,  6, 5, 15, 0, 95, 4, 31, 6, 76, 
    0, 36, 8, 24, 6, 99, 5, 36, 2, 33, 1, 12, 3, 64, 4, 75, 7, 89
  };
  const int q7188[] = {
    9, 9, // Number of jobs and machines
    7, 80, 5, 65, 4, 79, 2, 28, 0, 33, 6, 96, 8, 36, 1, 81, 3, 75, 
    6, 86, 7, 76, 8, 18, 4,  3, 3, 37, 5, 62, 2, 71, 0, 76, 1,  3, 
    7, 66, 6,  1, 1, 55, 2, 72, 5, 75, 0, 49, 4, 29, 3, 84, 8, 59, 
    8, 15, 6, 82, 7, 89, 2, 21, 0, 35, 1, 43, 4, 43, 3, 26, 5,  4, 
    2, 34, 1, 46, 5, 29, 8,  2, 0, 87, 7, 55, 3, 67, 6, 19, 4, 66, 
    8, 22, 4, 75, 3, 86, 6, 60, 2, 13, 7,  6, 5, 25, 0, 69, 1,  1, 
    7, 31, 0, 66, 4, 23, 8, 38, 1, 33, 5, 91, 2,  5, 3, 66, 6, 15, 
    4, 64, 6, 77, 5, 91, 8, 30, 3,  2, 7, 59, 1, 29, 2, 17, 0, 11, 
    3, 56, 6, 24, 5, 49, 0, 58, 4, 91, 2,  9, 7,  6, 1, 98, 8, 61
  };
  const int q7189[] = {
    9, 9, // Number of jobs and machines
    0, 58, 1, 65, 4, 49, 5, 40, 2, 56, 3, 88, 6, 21, 7, 15, 8, 99, 
    4, 95, 6, 62, 7, 53, 8, 89, 2, 54, 1,  1, 5, 18, 3, 51, 0, 84, 
    0, 60, 1,  6, 7, 50, 2, 54, 5, 54, 6, 97, 4,  7, 8, 37, 3, 98, 
    4, 23, 3, 30, 2, 38, 0, 63, 6,  6, 1, 67, 8, 72, 7, 91, 5,  1, 
    2, 55, 0, 98, 8, 32, 6, 26, 1, 38, 5, 93, 3, 26, 4,  3, 7, 97, 
    3, 37, 0,  5, 2, 25, 4,  3, 6, 53, 7, 45, 5, 89, 1, 82, 8, 19, 
    6, 97, 3, 31, 8, 86, 1, 60, 5, 45, 7, 66, 0, 85, 4, 78, 2, 11, 
    7, 31, 1,  2, 2, 44, 8, 49, 0, 37, 6, 53, 3, 34, 4, 68, 5, 60, 
    1, 85, 3, 93, 2, 10, 0, 19, 4, 18, 8, 56, 6, 72, 5, 28, 7, 22
  };
  const int q7190[] = {
    9, 9, // Number of jobs and machines
    2, 24, 7, 64, 4, 44, 0, 58, 6, 13, 5, 85, 8,  3, 3, 72, 1, 97, 
    8, 12, 6,  7, 0, 41, 3, 76, 1, 81, 4,  9, 7, 45, 5, 52, 2, 25, 
    1, 78, 5, 31, 0, 36, 3, 94, 2, 94, 6, 80, 8, 31, 7, 86, 4, 57, 
    1, 85, 2, 40, 0, 24, 3,  6, 5, 89, 7, 52, 4, 81, 6, 92, 8, 85, 
    6, 71, 1, 63, 2, 92, 4, 24, 5, 55, 7, 12, 0, 85, 3, 16, 8, 85, 
    5, 24, 2,  4, 8, 65, 7, 33, 1, 87, 4, 38, 6, 78, 0, 25, 3, 73, 
    0,  8, 7, 55, 8, 42, 5, 93, 3, 50, 4, 12, 6, 66, 1, 46, 2, 17, 
    0, 23, 1, 52, 2, 25, 3, 45, 6, 53, 7, 72, 5, 75, 8, 56, 4, 24, 
    2, 31, 6, 59, 3, 45, 4, 65, 1, 66, 8, 49, 7, 97, 0, 73, 5, 10
  };
  const int q7191[] = {
    9, 9, // Number of jobs and machines
    0, 65, 4, 55, 5, 36, 1, 28, 8, 32, 2, 67, 6,  7, 3, 25, 7, 93, 
    0, 27, 7, 86, 1, 95, 8, 46, 4, 48, 2, 72, 3, 57, 5, 67, 6, 26, 
    1, 31, 0, 35, 7, 20, 3, 36, 4, 99, 2, 30, 8, 55, 5,  6, 6, 15, 
    2, 28, 3, 28, 8, 46, 5, 17, 4, 83, 7, 68, 0, 13, 1, 42, 6, 81, 
    2, 38, 3, 88, 4, 48, 6, 43, 8, 35, 5, 10, 1, 97, 0, 46, 7, 92, 
    8, 42, 7, 56, 0, 53, 4, 71, 3, 34, 1, 61, 6, 42, 2, 82, 5, 60, 
    5, 56, 2, 41, 3, 41, 0,  6, 1, 71, 7, 58, 6, 90, 4, 56, 8, 51, 
    6, 86, 5, 21, 2, 98, 8, 60, 0, 56, 4, 89, 1, 61, 3, 22, 7, 65, 
    6, 65, 7, 37, 0, 74, 1,  4, 2, 60, 3, 36, 4, 53, 5, 48, 8, 58
  };
  const int q7192[] = {
    9, 9, // Number of jobs and machines
    4, 47, 0, 81, 1,  5, 7, 83, 6, 25, 3,  7, 5, 67, 2, 10, 8, 36, 
    4, 43, 6, 61, 5, 58, 0, 12, 7, 60, 2, 91, 3,  7, 1, 84, 8, 97, 
    6, 70, 5, 44, 3, 92, 7, 17, 0, 21, 8, 33, 4, 54, 2,  5, 1, 27, 
    5, 93, 0, 10, 8, 19, 7, 60, 2, 72, 1, 80, 3, 83, 4, 68, 6, 76, 
    2,  1, 8, 34, 6, 54, 3, 95, 0,  1, 7, 42, 1, 84, 5, 60, 4, 63, 
    4, 39, 5,  3, 1,  1, 8, 45, 7, 30, 2, 13, 3, 82, 0, 93, 6, 56, 
    4, 32, 0, 38, 8, 44, 3, 78, 1, 56, 2, 18, 6, 64, 7, 77, 5,  9, 
    4,  6, 3, 29, 2, 60, 1, 13, 5, 71, 0, 99, 8, 21, 7, 35, 6, 36, 
    1, 37, 2, 42, 3, 15, 8, 55, 0, 33, 4,  6, 6, 23, 5,  5, 7, 68
  };
  const int q7193[] = {
    9, 9, // Number of jobs and machines
    7, 97, 3, 69, 4, 84, 2,  3, 6, 45, 8, 74, 1, 61, 5, 77, 0, 58, 
    7, 54, 3, 33, 6, 53, 4,  8, 2, 86, 0, 44, 5, 41, 8, 96, 1, 16, 
    4, 17, 5, 21, 6, 91, 0, 35, 2, 37, 8, 63, 7, 52, 3, 37, 1, 84, 
    0, 34, 5, 38, 4, 31, 2, 24, 1, 98, 6, 40, 7, 29, 3, 79, 8, 28, 
    4, 92, 0, 25, 5, 64, 3,  3, 8, 66, 1, 65, 2, 75, 7, 21, 6, 83, 
    3, 27, 8, 13, 5, 30, 0, 28, 4, 23, 1, 48, 2, 55, 6, 19, 7, 80, 
    4, 49, 7, 23, 8, 27, 6, 46, 5, 96, 2, 32, 0, 45, 1, 15, 3,  5, 
    5, 46, 4, 27, 8, 56, 7, 74, 0, 88, 2, 35, 1, 77, 6, 22, 3,  3, 
    0, 43, 8,  6, 5, 39, 6, 53, 7, 72, 1, 26, 3, 87, 4, 78, 2, 10
  };
  const int q7194[] = {
    9, 9, // Number of jobs and machines
    4, 73, 2, 59, 7, 17, 3, 60, 6, 43, 0, 23, 5, 57, 1, 67, 8, 70, 
    2, 95, 4, 76, 0, 86, 8, 99, 7, 81, 6, 28, 1,  2, 5, 40, 3, 15, 
    6,  9, 2,  9, 0, 30, 8, 55, 5, 53, 7, 86, 3, 11, 4, 72, 1, 52, 
    4, 48, 8, 38, 2,  9, 1, 18, 0, 58, 7, 86, 5, 39, 3, 78, 6, 58, 
    1, 89, 8, 81, 2, 33, 5, 43, 7, 11, 3,  2, 0, 19, 6, 12, 4, 83, 
    3, 74, 6, 50, 7, 84, 5, 88, 8, 76, 1, 43, 0, 40, 4, 85, 2, 59, 
    4, 32, 7, 45, 3, 13, 5, 83, 6, 47, 8, 42, 0, 14, 2, 72, 1, 85, 
    5, 44, 6, 16, 8, 63, 1, 49, 3, 62, 4, 87, 7, 12, 2, 52, 0, 58, 
    4, 74, 6, 63, 3, 58, 7, 25, 8, 86, 2, 74, 1, 86, 5, 29, 0,  1
  };
  const int q7195[] = {
    9, 9, // Number of jobs and machines
    2, 86, 3, 32, 5, 98, 6, 51, 8, 51, 1, 51, 4, 36, 0, 69, 7, 68, 
    2,  1, 1, 60, 6, 98, 0, 12, 5, 22, 4, 73, 7, 95, 8,  3, 3, 88, 
    2, 62, 1, 24, 0, 75, 3, 31, 5, 12, 4,  3, 8, 99, 7, 99, 6, 20, 
    3, 10, 6, 36, 5, 78, 0,  7, 2,  7, 7, 27, 4, 58, 8, 33, 1, 43, 
    7, 24, 4, 16, 8, 71, 6, 93, 1, 30, 0, 60, 2,  8, 5, 83, 3, 50, 
    2, 37, 6, 11, 5, 43, 0, 23, 4, 75, 8, 86, 1, 22, 3, 33, 7, 47, 
    8, 47, 6, 47, 0, 29, 3, 68, 2, 91, 4, 25, 7, 64, 1, 71, 5, 66, 
    2, 17, 1, 53, 4, 90, 7, 50, 3,  2, 8, 37, 5, 97, 0, 98, 6, 54, 
    2, 88, 5, 36, 6, 91, 4, 20, 7,  8, 0, 46, 1, 52, 3, 16, 8, 63
  };
  const int q7196[] = {
    9, 9, // Number of jobs and machines
    1,  7, 6, 46, 5, 18, 3, 50, 0, 34, 7, 31, 4, 73, 2, 14, 8, 92, 
    8, 40, 6, 90, 5, 57, 0, 64, 4, 75, 3, 64, 2, 84, 7,  2, 1, 21, 
    0, 72, 1, 77, 3, 49, 6, 43, 5, 59, 4, 87, 8,  6, 2, 24, 7, 72, 
    4, 67, 8, 74, 1, 43, 7, 95, 5, 30, 0, 84, 6, 41, 3, 59, 2, 31, 
    7, 26, 5, 76, 1, 39, 4, 86, 2, 17, 6,  9, 0, 81, 3, 87, 8, 46, 
    1, 21, 4, 92, 5, 51, 3, 42, 8, 59, 7, 96, 2, 56, 0, 41, 6, 14, 
    8, 43, 2, 82, 0, 90, 4, 81, 3, 15, 5, 80, 7, 29, 6, 30, 1,  1, 
    0, 50, 8, 50, 2, 56, 5,  7, 1, 59, 7, 13, 4, 47, 6, 64, 3, 96, 
    5, 38, 2, 18, 8, 72, 6, 21, 4, 99, 3, 43, 0,  6, 7,  8, 1, 33
  };
  const int q7197[] = {
    9, 9, // Number of jobs and machines
    3, 88, 7, 70, 4, 18, 5,  1, 1, 63, 0, 59, 6, 56, 2, 33, 8, 77, 
    6, 72, 0, 67, 5, 94, 7, 59, 8, 72, 4, 56, 3, 28, 2, 86, 1, 70, 
    0,  2, 2, 72, 7,  9, 5, 84, 1, 37, 8, 13, 4, 90, 3, 71, 6, 22, 
    5, 45, 1, 80, 7, 15, 4, 69, 0, 43, 8, 10, 3, 61, 2, 83, 6, 81, 
    8, 88, 5,  2, 1, 43, 7, 43, 4, 86, 6, 41, 2, 61, 0, 85, 3, 97, 
    4, 81, 0, 84, 3, 70, 1, 69, 2, 62, 5, 20, 7, 39, 6, 64, 8, 44, 
    3, 41, 2, 64, 4, 52, 5, 26, 7, 56, 1, 41, 0,  6, 6, 33, 8, 72, 
    0, 75, 5,  5, 8, 40, 4, 46, 3, 37, 1,  7, 6, 44, 7, 55, 2,  2, 
    0, 49, 4, 77, 3, 43, 7, 19, 2, 25, 5, 61, 8, 36, 6, 14, 1, 67
  };
  const int q7198[] = {
    9, 9, // Number of jobs and machines
    4, 67, 1, 55, 3, 75, 2, 24, 8, 25, 6, 94, 0, 31, 7, 25, 5,  4, 
    0, 33, 6, 89, 7, 64, 1, 87, 3, 14, 2, 90, 4, 18, 8, 81, 5, 86, 
    3, 98, 0, 53, 5, 95, 8, 60, 7, 93, 2, 95, 1, 62, 6, 21, 4, 67, 
    4, 44, 0, 87, 7, 29, 3, 68, 2, 57, 1, 95, 6, 55, 5, 66, 8, 37, 
    8, 34, 2, 10, 7, 64, 6, 26, 1,  5, 3, 71, 0, 88, 4, 67, 5, 63, 
    4, 25, 5, 18, 6, 51, 0,  6, 8, 64, 3, 15, 1, 21, 7, 48, 2, 38, 
    4, 64, 5, 86, 3, 65, 0, 94, 7, 42, 2, 63, 1, 95, 6, 84, 8, 72, 
    5, 19, 0, 35, 8, 10, 2, 23, 3, 53, 1, 11, 6, 60, 4, 78, 7, 35, 
    0, 46, 7, 43, 6, 77, 8,  2, 4, 33, 5, 23, 1, 55, 2,  6, 3, 94
  };
  const int q7199[] = {
    9, 9, // Number of jobs and machines
    4, 11, 3, 34, 5, 52, 8, 75, 7, 46, 0, 83, 2, 40, 6, 97, 1, 67, 
    2, 86, 4, 66, 3, 77, 8, 26, 7, 14, 1, 87, 5, 63, 0, 81, 6, 88, 
    5, 77, 6, 65, 8, 46, 4, 17, 1, 30, 7, 81, 0,  8, 2, 16, 3, 90, 
    6, 51, 1, 16, 5, 77, 0, 19, 8, 83, 2,  4, 4, 83, 7, 87, 3, 31, 
    8, 49, 1, 67, 6, 59, 7, 38, 5, 39, 4,  5, 0, 41, 2, 26, 3,  5, 
    2, 98, 6, 66, 8, 31, 1, 29, 0, 24, 4, 72, 5, 97, 3, 96, 7, 63, 
    1, 16, 0, 38, 7, 36, 5, 77, 2, 35, 6, 59, 4, 58, 3, 86, 8, 52, 
    7, 17, 1, 48, 0, 87, 6, 18, 5, 59, 3, 63, 2, 91, 8, 83, 4, 89, 
    6, 16, 7, 27, 2, 83, 5, 38, 8, 45, 1, 11, 3, 83, 0, 51, 4, 95
  };
  const int q7200[] = {
    9, 9, // Number of jobs and machines
    2, 72, 1, 30, 7, 35, 8, 69, 4, 12, 0,  7, 5, 88, 6, 44, 3, 84, 
    5, 47, 4,  4, 8, 85, 0, 98, 2, 34, 1, 68, 7, 28, 3, 15, 6,  3, 
    3, 98, 1, 45, 2, 96, 6, 86, 0, 66, 8, 63, 5, 85, 7, 21, 4, 34, 
    5, 39, 7, 80, 0, 79, 2, 41, 3, 25, 1, 30, 6, 64, 8, 72, 4, 48, 
    3, 22, 4, 81, 1, 59, 8, 96, 7, 35, 0, 57, 5, 72, 2, 14, 6, 59, 
    3, 12, 5, 86, 1, 29, 7, 75, 0, 97, 6,  1, 8, 86, 4, 35, 2, 91, 
    1, 81, 3, 58, 6, 68, 8, 48, 2, 51, 4, 11, 5, 10, 7, 99, 0, 14, 
    3,  4, 2, 75, 1, 17, 7,  7, 5,  6, 8, 53, 0, 84, 4, 74, 6, 94, 
    5, 38, 1, 13, 4, 62, 0,  8, 6, 19, 3, 41, 8, 34, 7, 26, 2, 13
  };
  const int q7201[] = {
    9, 9, // Number of jobs and machines
    5, 95, 3, 88, 8, 32, 7, 99, 6, 55, 0, 62, 4, 59, 2, 96, 1, 16, 
    7,  6, 6,  7, 0, 94, 3, 51, 4, 14, 1,  3, 5, 19, 8, 27, 2, 80, 
    5, 16, 0, 43, 7, 46, 2, 47, 8, 91, 3, 47, 1, 87, 4, 73, 6, 63, 
    0, 93, 7, 21, 3, 30, 2, 77, 1, 38, 5, 16, 8, 40, 6, 49, 4,  2, 
    4, 72, 0, 69, 8, 39, 2, 50, 5, 87, 1, 43, 7, 88, 3, 22, 6, 48, 
    3, 17, 8, 26, 5, 19, 6, 33, 7, 42, 1, 72, 0, 10, 2,  2, 4, 10, 
    1, 45, 6, 13, 7, 54, 0, 43, 4, 77, 3, 87, 8, 50, 5, 57, 2, 82, 
    6, 80, 5, 41, 4, 28, 1, 49, 2, 92, 8, 13, 3, 42, 0, 18, 7, 80, 
    7, 49, 1,  3, 4, 79, 0, 68, 3,  3, 6, 29, 5, 80, 2,  5, 8, 50
  };
  const int q7202[] = {
    9, 9, // Number of jobs and machines
    1, 47, 3, 60, 6, 48, 2, 13, 8, 10, 5, 97, 0, 41, 4, 70, 7,  3, 
    3, 73, 1, 28, 5, 41, 2, 19, 7, 52, 6, 77, 4, 49, 8, 56, 0, 24, 
    6, 41, 4, 41, 7, 76, 3, 61, 5, 54, 1, 50, 0, 22, 2, 94, 8, 66, 
    4, 55, 3, 84, 8, 56, 7,  8, 1, 84, 5, 41, 0, 93, 2, 40, 6, 59, 
    1, 20, 3, 95, 0, 15, 7, 92, 6, 71, 4, 29, 5, 19, 2, 78, 8,  7, 
    7, 61, 0, 16, 5, 76, 1, 94, 3, 57, 4, 58, 2, 25, 6, 18, 8, 26, 
    7, 89, 4, 69, 8, 82, 1, 43, 6, 51, 5, 20, 2, 47, 0, 20, 3, 88, 
    2, 83, 0, 32, 5,  5, 4, 32, 6, 47, 8, 15, 7, 83, 1, 87, 3,  1, 
    3, 57, 7, 28, 0, 23, 2, 52, 6,  9, 4, 95, 5, 70, 8, 79, 1, 38
  };
  const int q7203[] = {
    9, 9, // Number of jobs and machines
    8, 90, 5,  4, 7, 55, 4, 86, 3, 71, 6, 43, 2, 88, 1, 78, 0, 35, 
    8, 19, 2, 42, 0, 36, 1, 65, 3, 54, 6, 63, 4, 24, 5, 57, 7, 81, 
    0, 14, 8, 97, 4, 40, 7, 36, 6, 61, 1, 36, 5, 53, 3, 94, 2, 90, 
    3,  2, 8, 10, 6, 14, 1, 41, 4, 86, 7,  3, 0, 19, 2, 44, 5, 45, 
    4, 37, 2, 75, 5, 78, 8, 10, 3, 34, 6,  9, 1, 17, 0, 78, 7,  4, 
    1, 59, 3, 11, 4, 41, 8,  9, 2, 91, 5, 23, 6,  7, 0, 11, 7, 88, 
    6, 85, 4, 89, 7,  4, 0, 38, 2, 61, 3, 38, 8, 58, 1,  6, 5, 82, 
    6, 49, 5, 16, 7, 76, 3,  1, 2, 96, 8, 41, 1, 58, 0, 61, 4, 33, 
    6, 28, 0, 14, 3, 21, 5, 20, 1, 73, 4, 88, 7, 32, 2, 31, 8, 41
  };
  const int q7204[] = {
    9, 9, // Number of jobs and machines
    7, 47, 1, 55, 0, 98, 2, 49, 8, 25, 6, 86, 5, 77, 4, 99, 3, 86, 
    7, 90, 5, 84, 1, 34, 6, 16, 8, 69, 0, 29, 3, 94, 4, 64, 2, 60, 
    4, 82, 8, 75, 5,  4, 3, 13, 2, 36, 6, 46, 7, 27, 0, 60, 1, 84, 
    5, 73, 7, 74, 1,  8, 0, 14, 3, 55, 4, 61, 2, 64, 8, 38, 6, 25, 
    2, 39, 8, 60, 7, 29, 6, 33, 4, 41, 0, 47, 3, 28, 5, 53, 1, 62, 
    6, 60, 1, 34, 7, 34, 2, 66, 5, 59, 3,  4, 8, 79, 0, 14, 4, 66, 
    0, 79, 7, 37, 2, 90, 6, 83, 1, 73, 4, 86, 5, 77, 8, 70, 3, 91, 
    3, 92, 8, 42, 1, 35, 2, 76, 6, 81, 5, 35, 7, 37, 4, 96, 0, 46, 
    6, 95, 5,  2, 8, 87, 2, 12, 3, 98, 4, 32, 7, 13, 0, 54, 1, 12
  };
  const int q7205[] = {
    9, 9, // Number of jobs and machines
    5, 39, 4, 21, 7, 70, 2, 45, 1, 61, 6, 75, 3,  3, 8, 12, 0, 74, 
    4, 78, 3, 70, 0, 80, 8,  8, 6, 13, 7, 80, 1, 97, 2, 99, 5,  2, 
    0, 25, 8, 15, 3, 48, 7, 31, 5, 48, 4, 69, 1, 52, 2, 36, 6, 67, 
    8, 73, 5, 89, 3, 37, 0, 78, 2, 88, 7, 76, 4, 72, 1, 47, 6, 72, 
    3, 25, 2, 22, 8, 90, 5, 90, 4, 48, 1, 70, 0, 60, 6,  1, 7, 47, 
    4,  5, 2, 23, 8, 74, 7, 20, 5, 79, 6, 49, 3, 91, 1, 51, 0, 62, 
    0, 91, 7, 38, 5, 43, 6, 67, 2, 63, 4, 41, 1, 85, 3, 69, 8, 42, 
    4, 18, 7, 40, 8, 77, 3, 63, 5, 36, 2, 59, 6, 21, 0, 67, 1, 78, 
    1, 75, 5,  6, 7, 51, 2, 81, 3, 28, 4, 38, 0, 10, 8, 89, 6,  5
  };
  const int q7206[] = {
    9, 9, // Number of jobs and machines
    2, 15, 5, 28, 8, 65, 7, 93, 0, 77, 3, 33, 1, 58, 4, 31, 6, 60, 
    6, 59, 7, 69, 0, 52, 2, 26, 4, 15, 1, 13, 3, 70, 8, 65, 5, 66, 
    3, 92, 0, 63, 1, 68, 4, 36, 2, 76, 8, 81, 5, 52, 7, 15, 6, 56, 
    8, 23, 1, 95, 0, 15, 7, 32, 5, 77, 4, 51, 6, 31, 3, 82, 2, 63, 
    1, 20, 0, 69, 6, 65, 5, 86, 7, 44, 8, 99, 3, 98, 2, 69, 4, 59, 
    2, 91, 3, 88, 5, 37, 8, 70, 4, 92, 1, 94, 7, 55, 0, 62, 6, 52, 
    6, 84, 3, 99, 5, 95, 0, 83, 4, 18, 7, 76, 2, 43, 1, 83, 8, 18, 
    6, 56, 7, 33, 4, 45, 3, 40, 0, 12, 1, 57, 8, 66, 5, 88, 2,  9, 
    0, 46, 4, 39, 8, 85, 3, 45, 6, 41, 7, 28, 5, 88, 1, 39, 2, 94
  };
  const int q7207[] = {
    9, 9, // Number of jobs and machines
    5, 78, 6, 42, 0, 47, 8, 81, 7, 55, 1, 98, 3, 47, 2, 26, 4, 35, 
    8, 96, 2, 10, 3, 99, 5, 70, 7, 73, 4, 10, 1,  4, 6, 60, 0, 92, 
    1, 98, 6, 67, 7, 80, 2, 83, 5, 82, 8, 86, 3, 17, 0,  5, 4, 57, 
    7, 38, 0, 41, 8, 95, 1, 56, 2, 94, 3, 27, 5, 28, 4, 91, 6, 50, 
    7, 20, 4, 31, 3, 35, 8, 28, 5,  5, 2, 96, 0, 46, 1, 44, 6, 26, 
    0, 18, 8, 25, 6, 93, 2, 54, 4, 83, 3, 82, 7, 53, 1, 71, 5, 54, 
    6, 82, 4, 50, 2, 87, 3, 95, 1, 16, 8,  1, 0, 17, 5, 98, 7, 89, 
    3, 98, 7, 74, 6, 19, 8, 62, 4, 75, 1, 28, 2, 53, 0, 63, 5, 20, 
    5, 44, 3, 46, 1, 45, 2, 99, 8, 92, 0, 15, 7, 41, 4, 77, 6, 98
  };
  const int q7208[] = {
    9, 9, // Number of jobs and machines
    1, 29, 3, 89, 6, 53, 4, 36, 7, 20, 2, 81, 0, 90, 8, 93, 5, 28, 
    7, 97, 0,  7, 8, 74, 3, 57, 6, 51, 5, 27, 1, 38, 2, 19, 4, 62, 
    1, 33, 2,  5, 6, 22, 7, 92, 0, 52, 5, 97, 3, 47, 8, 17, 4, 79, 
    0, 56, 7, 52, 3,  5, 8, 67, 4,  1, 1, 39, 5, 93, 2, 92, 6, 29, 
    4, 74, 1, 78, 2,  6, 5, 64, 0, 40, 7, 51, 8, 12, 6, 98, 3, 70, 
    6,  8, 2, 74, 5, 14, 4, 64, 8,  9, 3, 47, 1,  4, 0, 18, 7, 84, 
    2, 59, 0, 63, 6, 34, 8, 88, 3, 62, 1,  9, 5, 57, 7,  9, 4, 70, 
    1, 61, 8, 56, 2, 28, 5, 53, 7, 33, 0, 39, 3, 33, 6, 43, 4, 26, 
    5, 69, 2, 98, 0, 21, 3, 28, 4, 87, 8, 52, 6,  7, 7, 85, 1, 81
  };
  const int q7209[] = {
    9, 9, // Number of jobs and machines
    7, 56, 2, 61, 6, 93, 4, 19, 0, 30, 8, 48, 5, 69, 1, 62, 3, 48, 
    6, 75, 8, 68, 2, 52, 1, 20, 5, 67, 4, 64, 7, 38, 0, 87, 3, 19, 
    0, 79, 3, 61, 2, 91, 7, 43, 8, 36, 5, 25, 1, 36, 6, 87, 4, 58, 
    4, 90, 8, 56, 7, 57, 6, 27, 1, 83, 2, 42, 5, 42, 3, 78, 0, 31, 
    6, 91, 2, 23, 8, 91, 0, 22, 3, 90, 7, 24, 4, 85, 1, 16, 5, 92, 
    5, 60, 6, 42, 2, 69, 8, 12, 3, 83, 1, 13, 4, 62, 7, 96, 0, 27, 
    1, 72, 3, 48, 4, 87, 6, 68, 7, 89, 8, 82, 0, 24, 5, 48, 2, 15, 
    2, 93, 0, 80, 7, 93, 4, 35, 1, 17, 3, 91, 6, 54, 8, 81, 5, 17, 
    5, 70, 6, 64, 8, 78, 4, 22, 2, 46, 3, 64, 0, 39, 1, 21, 7, 24
  };
  const int q7210[] = {
    9, 9, // Number of jobs and machines
    4, 94, 7, 73, 1, 46, 2, 29, 5, 85, 0, 23, 6, 84, 3, 42, 8, 12, 
    7, 21, 5, 16, 8, 43, 6, 37, 0, 84, 2, 41, 1, 75, 3, 67, 4, 42, 
    4, 92, 5, 38, 2, 59, 3,  4, 8, 49, 0,  4, 7, 29, 1, 90, 6, 48, 
    2, 31, 8, 20, 4, 29, 3, 35, 1, 49, 5, 58, 7, 26, 0, 11, 6, 41, 
    4, 90, 8, 67, 0, 32, 6, 59, 1, 53, 2, 87, 5, 26, 3,  2, 7, 71, 
    5, 20, 8, 37, 3, 19, 7, 91, 6, 92, 2, 41, 0, 70, 4, 85, 1, 78, 
    5, 51, 1, 46, 4, 73, 0, 55, 3, 72, 6, 23, 8, 44, 7, 19, 2, 40, 
    4, 26, 0, 68, 2, 88, 5, 19, 8, 48, 6, 77, 7, 86, 1, 78, 3, 64, 
    1, 41, 6,  5, 2, 55, 8, 41, 4, 30, 7, 72, 0, 30, 5, 65, 3,  2
  };
  const int q7211[] = {
    9, 9, // Number of jobs and machines
    0, 15, 8, 80, 5, 90, 7, 12, 3, 44, 2, 88, 4, 41, 6, 25, 1, 26, 
    0, 18, 1, 31, 6, 34, 2, 37, 8, 72, 7, 57, 4, 91, 5, 20, 3, 95, 
    1, 32, 5, 26, 4, 60, 0,  3, 8, 63, 7, 19, 6, 20, 3, 33, 2, 34, 
    8, 64, 5, 63, 4, 43, 2, 98, 1, 13, 3, 17, 6, 56, 7, 10, 0, 36, 
    0, 33, 8, 30, 1, 18, 2, 65, 7, 33, 6, 32, 3, 15, 5, 80, 4, 53, 
    1, 71, 5, 71, 3, 34, 7, 76, 0, 61, 6, 60, 8, 81, 2, 70, 4, 78, 
    7, 81, 6, 19, 2, 76, 8,  5, 0, 89, 3,  1, 4, 18, 1, 67, 5, 50, 
    7, 41, 5, 18, 3, 43, 1,  1, 8, 16, 0, 51, 6, 33, 4, 32, 2, 83, 
    6, 35, 7, 63, 4, 85, 8, 69, 2, 16, 1, 45, 5, 36, 3, 20, 0, 66
  };
  const int q7212[] = {
    9, 9, // Number of jobs and machines
    1, 40, 0, 60, 7, 12, 4, 82, 8, 50, 5, 11, 2, 86, 6, 65, 3, 27, 
    0, 53, 5, 61, 2, 73, 6, 89, 8, 99, 3, 76, 7, 72, 1,  3, 4, 27, 
    1,  8, 8, 58, 3, 75, 2,  6, 7, 96, 6, 81, 5, 69, 4, 60, 0,  3, 
    5, 76, 1, 82, 4, 46, 3, 58, 2, 58, 8, 49, 0,  4, 6, 27, 7, 65, 
    8,  5, 7,  3, 3, 51, 5, 50, 6, 46, 2, 20, 0, 30, 1, 15, 4, 89, 
    3, 56, 8, 11, 2, 56, 6,  7, 0, 25, 1, 23, 5,  5, 7, 16, 4, 20, 
    5, 92, 3, 43, 2, 14, 4, 36, 8,  4, 0, 87, 1, 71, 7, 61, 6, 17, 
    5, 60, 0, 27, 1, 92, 4, 33, 7, 40, 6, 50, 8, 64, 3, 95, 2, 66, 
    0, 54, 7,  8, 6, 66, 2, 72, 5, 44, 8,  6, 1, 37, 3, 86, 4, 56
  };
  const int q7213[] = {
    9, 9, // Number of jobs and machines
    3, 82, 1, 92, 5, 98, 0,  2, 6, 56, 4, 32, 8,  5, 2,  5, 7, 64, 
    1, 55, 4, 55, 2,  3, 7, 98, 5, 77, 6, 22, 3, 85, 0, 12, 8, 56, 
    4, 44, 6, 28, 7, 11, 0, 31, 5, 82, 3, 12, 2, 69, 8, 59, 1, 35, 
    7, 45, 4,  5, 6, 56, 3, 69, 2, 68, 0, 88, 8, 37, 5, 90, 1, 72, 
    1, 14, 8, 41, 5, 12, 0, 56, 7,  8, 4, 10, 3, 82, 2, 70, 6, 64, 
    6, 39, 5, 27, 4,  7, 2, 37, 0, 23, 8, 73, 1, 24, 3, 66, 7, 21, 
    7, 32, 8, 57, 6, 66, 2,  4, 0, 38, 1, 92, 3, 38, 5, 54, 4, 67, 
    6, 70, 8, 73, 5, 40, 7, 75, 3, 92, 0, 55, 1, 24, 2, 68, 4, 49, 
    2, 97, 7, 96, 1, 56, 0, 90, 3, 60, 5, 43, 6, 23, 4, 53, 8,  9
  };
  const int q7214[] = {
    9, 9, // Number of jobs and machines
    5, 93, 8, 87, 0, 47, 7, 82, 2, 77, 6, 74, 1, 74, 4, 14, 3, 59, 
    0, 89, 7,  9, 2, 93, 8, 71, 6, 64, 4, 92, 5, 86, 3,  3, 1, 72, 
    8, 65, 5, 46, 7, 21, 4, 35, 6, 87, 3, 74, 0, 36, 1, 43, 2, 86, 
    7, 44, 3,  7, 0, 65, 5, 54, 1, 22, 6, 26, 4, 56, 2, 86, 8, 46, 
    2, 37, 3, 38, 5, 12, 8, 31, 0, 45, 6, 24, 7, 87, 1, 54, 4, 62, 
    2, 77, 5, 76, 7, 38, 8, 41, 6, 65, 1, 39, 4, 71, 3, 76, 0,  6, 
    4, 57, 7, 90, 8, 40, 3, 57, 0, 49, 5, 99, 6, 22, 2, 98, 1,  9, 
    7, 23, 5, 75, 2, 55, 6, 20, 8, 31, 4, 49, 3, 22, 1, 99, 0, 17, 
    3, 53, 7, 56, 2, 28, 1, 54, 8, 77, 0,  9, 6,  3, 4, 99, 5, 89
  };
  const int q7215[] = {
    9, 9, // Number of jobs and machines
    5, 13, 8, 89, 2, 73, 4, 31, 3, 96, 0, 38, 6, 95, 7, 61, 1, 77, 
    7, 28, 5, 76, 4, 88, 6, 27, 0,  7, 8,  6, 2, 62, 1,  9, 3, 26, 
    0, 49, 4, 98, 7, 48, 6, 20, 5, 84, 3, 21, 1, 99, 8, 44, 2, 57, 
    3, 38, 5, 79, 6, 51, 2,  3, 0, 73, 8, 15, 4, 24, 1, 30, 7, 72, 
    6, 83, 0, 42, 5, 29, 2, 60, 8, 97, 4, 68, 7, 88, 3, 28, 1,  7, 
    7, 92, 1, 22, 5, 73, 8, 39, 3, 72, 0,  1, 4, 35, 2, 87, 6, 68, 
    1, 21, 2, 56, 8, 23, 3, 44, 5, 19, 4, 38, 0, 18, 6, 67, 7, 25, 
    1, 37, 4, 20, 0, 52, 6, 67, 7,  3, 8, 28, 3, 23, 2, 14, 5, 52, 
    5,  1, 2, 27, 8, 24, 1, 92, 4, 33, 6, 79, 7, 74, 0, 34, 3,  2
  };
  const int q7216[] = {
    9, 9, // Number of jobs and machines
    5,  5, 2, 79, 4, 33, 6, 45, 3, 28, 1, 28, 0, 30, 7, 84, 8, 37, 
    5, 94, 7, 46, 0, 40, 3, 95, 6, 62, 8, 92, 4, 29, 1, 69, 2,  1, 
    8, 19, 4,  6, 7, 27, 1,  6, 2, 72, 5, 75, 6, 29, 3, 23, 0, 91, 
    0, 66, 6,  8, 3, 10, 8, 32, 5, 68, 7, 23, 4, 96, 2, 92, 1, 99, 
    4, 28, 8, 51, 0, 21, 6, 46, 1, 30, 5, 78, 2, 94, 7, 23, 3, 82, 
    3, 98, 4, 20, 2, 65, 6, 64, 0,  1, 8, 59, 7, 35, 5, 80, 1, 11, 
    8, 38, 2, 24, 5, 57, 3,  1, 1, 47, 6, 76, 4, 24, 0, 21, 7, 30, 
    2, 15, 3, 67, 7, 53, 8, 46, 1, 20, 4, 73, 6, 88, 0, 56, 5, 30, 
    1, 92, 0, 26, 4, 34, 5, 32, 8, 55, 7, 81, 6, 64, 2, 52, 3, 39
  };
  const int q7217[] = {
    9, 9, // Number of jobs and machines
    5, 41, 0, 26, 7, 85, 1, 75, 8, 83, 2, 72, 3, 72, 6,  3, 4, 78, 
    1, 85, 3, 86, 0, 28, 8, 45, 7, 51, 2, 14, 5, 40, 4,  4, 6, 71, 
    3, 61, 5, 63, 6, 90, 4,  6, 2, 25, 7, 47, 1, 71, 0, 10, 8, 39, 
    5, 78, 4, 40, 0, 42, 6, 81, 2, 51, 1, 11, 3, 24, 8, 29, 7, 30, 
    1, 75, 7, 18, 8, 31, 5, 17, 6, 27, 3, 43, 4, 33, 0, 60, 2, 12, 
    2, 44, 1, 11, 7, 45, 3, 21, 0, 51, 5, 15, 4, 83, 6, 49, 8, 56, 
    0, 52, 7, 45, 8, 71, 2, 69, 3, 74, 6, 66, 4, 35, 5, 90, 1, 19, 
    0, 29, 1, 59, 2, 41, 6, 16, 5, 62, 7, 65, 3,  8, 4, 30, 8, 79, 
    4, 20, 8, 92, 5, 63, 7, 82, 1, 51, 6, 76, 3, 64, 2, 38, 0, 72
  };
  const int q7218[] = {
    9, 9, // Number of jobs and machines
    8, 71, 2, 70, 7, 47, 4, 56, 6, 22, 3, 74, 5, 57, 0, 74, 1, 82, 
    3, 75, 5, 45, 6, 17, 1, 64, 0, 14, 2, 80, 4, 65, 7, 24, 8, 71, 
    7, 80, 2, 88, 1, 28, 4,  8, 0, 14, 5, 89, 3, 39, 8, 27, 6,  7, 
    7, 10, 5, 90, 1, 56, 2, 77, 6, 50, 3, 73, 4, 43, 0, 77, 8, 37, 
    5, 86, 7, 36, 8, 68, 2, 63, 4, 94, 1, 29, 0, 65, 3, 18, 6, 63, 
    7, 31, 0,  6, 8, 44, 5, 18, 1, 47, 3, 95, 6, 98, 2,  4, 4, 61, 
    6, 81, 4, 30, 2, 49, 7, 56, 3, 92, 5, 85, 8, 31, 1, 98, 0, 89, 
    7, 40, 3, 83, 0, 99, 1, 89, 4, 97, 6, 16, 2, 73, 5, 10, 8, 95, 
    1, 16, 0, 16, 3, 49, 8, 29, 7, 23, 2, 22, 4, 93, 6, 53, 5, 87
  };
  const int q7219[] = {
    9, 9, // Number of jobs and machines
    6, 86, 8, 20, 4, 13, 1, 21, 0, 24, 2,  5, 7, 99, 5, 99, 3, 37, 
    0, 23, 3, 97, 6, 68, 2,  8, 5, 59, 4, 47, 7, 94, 8, 46, 1, 94, 
    8, 25, 1,  4, 3, 26, 6, 55, 7, 12, 0, 90, 2,  1, 5, 93, 4, 24, 
    8, 40, 7, 92, 0, 60, 1, 20, 3, 62, 2, 77, 5, 64, 6, 72, 4, 50, 
    6, 63, 7, 25, 0, 84, 8, 21, 5, 90, 2, 24, 3, 65, 4, 71, 1,  7, 
    6, 63, 5, 64, 4, 39, 7, 85, 2, 59, 0, 50, 8, 20, 3, 25, 1, 27, 
    6, 30, 4,  7, 0, 90, 1,  7, 7,  6, 8, 70, 5, 37, 2, 71, 3, 96, 
    7, 41, 4, 16, 3, 69, 1, 56, 8,  6, 0, 73, 6, 86, 2, 68, 5, 45, 
    0, 34, 5,  8, 8, 47, 6,  6, 2, 50, 7, 91, 1, 74, 3, 53, 4, 51
  };
  const int q7220[] = {
    9, 9, // Number of jobs and machines
    2, 40, 5, 34, 4, 63, 8, 59, 3,  8, 6, 31, 0, 98, 1, 39, 7, 21, 
    5, 55, 6, 43, 8, 84, 1, 32, 4, 12, 2, 76, 0, 64, 7, 46, 3, 42, 
    1, 96, 8, 27, 7, 82, 4, 17, 3, 87, 2, 86, 6,  3, 0, 89, 5, 51, 
    6, 46, 7, 36, 2, 71, 8, 77, 4, 67, 0,  7, 3, 44, 5, 30, 1, 32, 
    5, 57, 4, 23, 6, 25, 3, 77, 8, 49, 7, 52, 1, 58, 2, 90, 0, 51, 
    0, 57, 8, 70, 6, 44, 3, 37, 7, 24, 2, 36, 1, 78, 4, 88, 5, 37, 
    7, 31, 4, 44, 6, 46, 2, 34, 3, 27, 5,  5, 1, 41, 8, 97, 0, 90, 
    6, 37, 2, 34, 7, 20, 8,  9, 3, 10, 0, 83, 4, 33, 5, 33, 1, 96, 
    0, 35, 5, 76, 3, 40, 7, 80, 2, 83, 1, 96, 6, 93, 4, 86, 8, 49
  };
  const int q7221[] = {
    9, 9, // Number of jobs and machines
    7, 64, 3, 81, 5, 77, 4, 71, 6, 61, 8, 11, 1, 51, 0, 43, 2, 71, 
    5,  5, 4, 89, 7, 83, 8, 32, 3, 72, 2, 54, 6,  2, 0, 60, 1, 12, 
    6, 25, 4, 55, 3, 41, 7, 86, 5, 90, 0, 44, 8, 83, 2, 88, 1, 95, 
    0, 41, 1, 22, 7, 47, 8, 76, 4, 56, 3, 27, 6, 31, 2, 60, 5, 79, 
    6, 78, 5, 61, 1, 86, 7, 62, 2, 82, 0, 33, 3, 53, 4, 45, 8, 96, 
    3, 60, 5, 31, 1, 46, 8, 11, 2, 30, 7, 34, 0, 26, 6, 57, 4, 59, 
    2, 61, 0, 96, 5, 21, 8, 73, 4, 53, 7, 50, 6, 98, 1, 53, 3, 96, 
    2, 73, 8,  6, 4, 15, 6, 79, 1, 46, 0, 36, 5, 19, 7, 42, 3, 18, 
    5, 18, 2, 84, 6, 67, 4, 39, 3,  9, 1, 56, 7, 18, 8, 43, 0, 46
  };
  const int q7222[] = {
    9, 9, // Number of jobs and machines
    4, 93, 1, 20, 3, 95, 2, 58, 5, 90, 0, 91, 6, 98, 8, 57, 7, 68, 
    8, 76, 0, 91, 2, 65, 5, 65, 1, 10, 3, 46, 7, 24, 4,  5, 6, 83, 
    6, 47, 5,  9, 4, 59, 0, 42, 8,  7, 3, 84, 1, 47, 2, 11, 7, 86, 
    1, 80, 6, 82, 2, 30, 7, 51, 8, 59, 0, 73, 3, 79, 4, 50, 5, 54, 
    6, 67, 1, 27, 2, 50, 8, 11, 0,  5, 5, 14, 3, 23, 4, 71, 7, 85, 
    2, 31, 5, 86, 7,  9, 8, 31, 1, 35, 4, 33, 6, 88, 3, 56, 0, 73, 
    4, 24, 0, 99, 1, 35, 5, 25, 2, 86, 3, 24, 6, 59, 8, 20, 7, 87, 
    8, 87, 3, 16, 2, 84, 7, 66, 0, 31, 5, 67, 4, 48, 6, 31, 1, 13, 
    1,  1, 7, 46, 2, 25, 3,  2, 4, 36, 6, 94, 8,  7, 5, 86, 0, 71
  };
  const int q7223[] = {
    9, 9, // Number of jobs and machines
    0, 71, 4, 47, 6, 25, 7,  9, 3, 11, 2, 94, 8, 76, 5, 88, 1, 20, 
    8, 44, 5, 85, 4, 70, 3, 73, 2, 86, 0, 53, 6, 27, 7,  6, 1, 72, 
    7, 71, 4, 38, 2, 31, 5, 90, 1, 26, 3, 79, 0, 34, 6, 22, 8,  5, 
    5,  5, 0, 82, 3,  4, 8, 84, 6, 97, 7, 79, 2, 25, 4, 99, 1, 86, 
    3, 98, 4, 70, 2, 73, 7, 66, 0, 45, 6, 40, 5, 72, 8, 29, 1,  7, 
    1, 65, 6, 65, 3, 42, 0, 38, 4, 20, 7, 88, 8, 96, 5, 23, 2, 65, 
    3, 41, 5, 66, 4, 51, 2, 31, 6, 48, 7, 16, 1, 21, 0, 73, 8, 62, 
    6, 33, 3, 30, 4, 14, 8, 15, 2, 27, 0, 35, 5, 35, 1, 97, 7,  3, 
    3, 89, 4, 61, 0, 32, 5, 17, 7, 73, 2, 23, 8, 48, 6, 49, 1, 59
  };
  const int q7224[] = {
    9, 9, // Number of jobs and machines
    4, 31, 0, 41, 5, 30, 8, 32, 6, 67, 2, 94, 7, 43, 3, 93, 1, 82, 
    8, 24, 4, 82, 7, 41, 3, 69, 1, 21, 0, 41, 6, 53, 2, 53, 5, 56, 
    3, 76, 0, 78, 1, 57, 7, 50, 5, 38, 4, 86, 6, 83, 8,  4, 2, 35, 
    4, 91, 8, 30, 3, 29, 5, 99, 0, 81, 2, 24, 6, 24, 7, 44, 1, 63, 
    3, 83, 4, 88, 7, 56, 0, 54, 1, 19, 5, 89, 8,  2, 6, 11, 2, 64, 
    6, 57, 2, 73, 1, 29, 0, 21, 8, 78, 5,  1, 7, 12, 3, 24, 4, 61, 
    3, 64, 8, 82, 5, 61, 0, 42, 4, 63, 1, 99, 7, 10, 6, 57, 2, 26, 
    0,  2, 5, 32, 8, 46, 2,  8, 4, 69, 3,  9, 6, 61, 7, 30, 1,  6, 
    5, 95, 6, 44, 2, 30, 7, 55, 0,  6, 3, 74, 8, 16, 4, 96, 1, 61
  };
  const int q7225[] = {
    9, 9, // Number of jobs and machines
    5, 13, 0, 48, 7, 80, 6, 65, 3, 79, 2, 14, 4, 25, 1, 24, 8, 35, 
    6, 77, 8, 71, 4, 73, 1, 37, 0, 86, 2, 65, 5, 59, 3, 51, 7, 94, 
    6, 10, 4, 23, 1, 31, 3, 69, 5, 79, 8, 30, 7, 73, 2, 79, 0, 57, 
    0, 30, 8, 98, 7, 73, 3, 30, 2, 47, 1,  6, 6, 49, 5, 89, 4, 66, 
    6, 16, 2, 50, 8, 95, 3, 57, 0, 11, 1, 37, 4, 78, 7, 50, 5, 40, 
    0, 50, 4, 82, 8,  6, 3, 55, 1, 35, 7, 45, 2, 70, 6, 49, 5, 80, 
    8, 22, 6, 22, 7, 34, 5, 56, 3, 10, 0, 16, 2, 65, 1, 94, 4, 19, 
    7, 76, 4, 15, 0, 79, 1, 80, 2, 17, 3, 88, 6, 98, 8, 89, 5, 97, 
    1, 37, 0, 50, 8, 35, 7, 36, 5, 52, 2, 80, 4, 79, 6,  8, 3, 34
  };
  const int q7226[] = {
    9, 9, // Number of jobs and machines
    0,  6, 7, 24, 1, 93, 8, 54, 2, 52, 3, 29, 5, 88, 4, 13, 6, 27, 
    4,  2, 3, 28, 7, 94, 2, 89, 5, 43, 8, 10, 1, 74, 0,  5, 6, 64, 
    1, 84, 0, 36, 2, 76, 5, 64, 8, 12, 4, 10, 6, 44, 3,  5, 7, 53, 
    2, 66, 3, 11, 5, 40, 4, 84, 0,  5, 6,  7, 1, 33, 8,  3, 7, 55, 
    1, 25, 3, 26, 6, 85, 2,  8, 4, 23, 0, 89, 5, 77, 8, 10, 7,  8, 
    1, 15, 6,  9, 3,  4, 8, 70, 7,  7, 5, 74, 0, 43, 2, 35, 4, 72, 
    3, 63, 0,  5, 6,  6, 2, 51, 8, 45, 4, 67, 5, 49, 7, 36, 1, 39, 
    0, 98, 6, 75, 1, 74, 7, 83, 3, 45, 5, 64, 4, 25, 8, 31, 2, 30, 
    6, 21, 3, 33, 8, 59, 4, 54, 7, 54, 1, 60, 5,  7, 2, 28, 0,  4
  };
  const int q7227[] = {
    9, 9, // Number of jobs and machines
    6, 10, 2, 36, 8, 45, 4, 87, 7, 84, 1, 70, 0, 45, 3, 30, 5, 20, 
    6, 94, 4, 22, 1, 25, 8,  4, 2, 34, 5, 40, 0, 87, 3, 30, 7, 85, 
    7,  3, 0, 54, 4, 30, 8, 62, 3, 38, 1, 48, 6, 71, 2, 31, 5, 10, 
    7, 89, 2, 97, 4, 65, 8, 91, 5, 46, 3, 70, 6, 67, 0,  3, 1, 28, 
    4, 22, 7, 47, 0, 16, 1,  5, 8, 43, 3, 56, 5, 99, 6,  5, 2, 17, 
    8, 94, 5, 91, 6, 98, 3, 37, 4, 65, 2, 55, 7, 61, 1, 72, 0, 80, 
    2, 51, 3, 26, 4, 91, 8, 86, 6, 59, 1, 58, 5, 53, 7, 78, 0, 67, 
    4, 15, 7, 92, 6, 58, 5, 44, 0, 72, 1, 64, 2, 92, 8, 99, 3, 22, 
    6, 50, 4, 71, 7, 45, 8,  1, 5, 75, 1, 25, 3, 76, 2, 77, 0, 14
  };
  const int q7228[] = {
    9, 9, // Number of jobs and machines
    2, 37, 0, 59, 5, 59, 1, 23, 6, 61, 8, 18, 4, 33, 7, 73, 3,  7, 
    2, 98, 0, 60, 6, 25, 4, 29, 3, 63, 1, 24, 7, 30, 8, 81, 5, 51, 
    1, 15, 6, 27, 8, 11, 7, 38, 0,  6, 5, 56, 2, 91, 3, 43, 4, 30, 
    1, 36, 3, 51, 2, 80, 6, 22, 7,  7, 5, 72, 0, 72, 8, 34, 4, 11, 
    3, 36, 0, 48, 8, 15, 1, 52, 4, 35, 6, 64, 5, 31, 2, 48, 7,  6, 
    6, 72, 4, 73, 8, 40, 5, 46, 7, 42, 3, 99, 1, 71, 0, 73, 2, 44, 
    3, 43, 1, 67, 0,  8, 8, 48, 5,  2, 4, 14, 2, 39, 6, 59, 7, 73, 
    3, 62, 4, 20, 0, 71, 8,  6, 1, 68, 6,  3, 5, 41, 7, 29, 2, 16, 
    7, 18, 4, 61, 2, 97, 0, 19, 1,  8, 5, 84, 3, 88, 8, 37, 6, 61
  };
  const int q7229[] = {
    9, 9, // Number of jobs and machines
    7,  9, 5, 24, 0, 30, 4, 36, 3, 65, 1, 43, 8, 49, 6,  7, 2, 36, 
    6, 17, 3, 30, 1, 27, 8,  1, 2,  6, 5, 47, 0, 32, 7, 95, 4, 95, 
    5, 71, 1,  1, 8,  6, 6, 57, 3, 50, 7,  8, 4, 22, 0,  7, 2, 48, 
    7, 85, 5, 31, 6,  1, 4,  1, 3, 19, 2, 63, 8, 79, 1, 15, 0, 55, 
    8, 48, 7, 52, 6, 22, 5, 20, 4, 32, 3, 21, 0, 53, 2, 12, 1, 53, 
    6, 42, 2, 29, 8, 69, 4, 42, 3, 56, 0, 93, 7, 87, 1, 73, 5, 83, 
    8, 91, 5, 93, 3, 12, 2, 17, 7, 62, 1, 21, 4, 61, 0, 85, 6,  4, 
    8, 36, 7, 60, 1, 99, 6, 34, 4, 26, 2, 93, 0, 68, 5, 36, 3,  2, 
    5, 51, 8, 78, 0, 95, 3, 75, 6,  4, 2, 64, 4, 21, 7, 24, 1, 41
  };
  const int q7230[] = {
    9, 9, // Number of jobs and machines
    2, 35, 6,  9, 0, 26, 4, 53, 8, 21, 3, 68, 1, 87, 5, 19, 7, 27, 
    2, 99, 5, 65, 8, 69, 0, 95, 6, 59, 7, 91, 4, 43, 3, 40, 1, 13, 
    6, 55, 2, 85, 3, 61, 8, 18, 7, 50, 4, 46, 0, 98, 5, 57, 1, 99, 
    4,  9, 1,  8, 3, 88, 8, 52, 2, 19, 6, 14, 5, 60, 0, 82, 7, 52, 
    6, 90, 3, 78, 8, 79, 0, 47, 7, 94, 5, 13, 2, 17, 4, 25, 1, 53, 
    8,  6, 2, 66, 6, 87, 1, 87, 4, 17, 3, 89, 0, 48, 7, 61, 5, 79, 
    8,  2, 5, 54, 0, 79, 6, 95, 4, 83, 1, 34, 7, 26, 3, 42, 2, 80, 
    5, 35, 1, 40, 0, 65, 2, 30, 4, 86, 6, 58, 7, 54, 3, 16, 8, 52, 
    4, 59, 8, 46, 1, 53, 6, 94, 2, 28, 3, 52, 0, 95, 7, 12, 5, 37
  };
  const int q7231[] = {
    9, 9, // Number of jobs and machines
    7, 80, 2, 98, 6, 61, 0, 46, 1, 66, 5, 18, 4, 22, 3,  8, 8, 75, 
    2, 67, 0, 14, 5, 49, 3, 80, 8,  1, 6, 27, 4, 82, 1, 33, 7, 36, 
    8, 34, 4, 54, 0, 40, 7, 17, 6, 78, 5, 59, 1, 93, 2, 22, 3, 40, 
    1, 50, 4, 60, 3, 42, 0, 62, 8, 86, 2, 90, 5, 75, 7, 83, 6, 50, 
    4, 91, 7, 70, 0,  5, 8, 27, 6, 57, 1,  8, 5, 24, 2, 75, 3, 95, 
    7, 84, 2, 68, 8, 37, 4, 11, 3, 31, 1, 61, 0, 19, 5, 34, 6, 58, 
    0, 60, 6, 41, 5, 26, 1, 35, 7, 70, 4, 54, 8, 81, 3, 55, 2, 27, 
    4, 11, 8,  8, 6, 81, 7, 57, 2, 24, 1, 43, 3, 88, 5, 43, 0, 33, 
    5, 88, 2, 33, 1, 72, 7, 92, 4, 65, 0, 90, 8,  8, 6, 30, 3, 70
  };
  const int q7232[] = {
    9, 9, // Number of jobs and machines
    8, 96, 0, 56, 3, 49, 7, 96, 4, 25, 6,  5, 1, 37, 2, 50, 5, 30, 
    1, 90, 8, 26, 5, 33, 4, 63, 2, 59, 3, 54, 7, 77, 0, 88, 6, 29, 
    7, 60, 2, 25, 0, 75, 1, 26, 3, 14, 8, 61, 6, 77, 5, 41, 4, 35, 
    1, 10, 7, 79, 4, 70, 5, 91, 2, 77, 8,  2, 0, 90, 6, 88, 3, 46, 
    2,  9, 5, 91, 4, 37, 7,  7, 8, 42, 3, 57, 0, 10, 1, 65, 6, 76, 
    5, 45, 6, 97, 0, 71, 7, 17, 3, 59, 1, 39, 8, 62, 4, 52, 2, 15, 
    4, 66, 8, 28, 2, 47, 5, 50, 6, 66, 7, 85, 0, 84, 1,  6, 3, 67, 
    6, 13, 3, 92, 5, 67, 4, 73, 8, 73, 2, 79, 1, 60, 0, 13, 7, 30, 
    3, 16, 5, 71, 6, 84, 1, 67, 8, 48, 7,  8, 0, 87, 4, 78, 2, 63
  };
  const int q7233[] = {
    9, 9, // Number of jobs and machines
    3, 68, 8, 44, 1,  1, 7, 81, 6, 67, 4, 54, 0, 24, 5, 58, 2,  4, 
    2, 92, 3, 92, 1, 73, 4, 90, 6, 41, 5,  3, 0, 35, 7,  8, 8,  8, 
    5, 13, 8, 46, 7, 52, 0, 95, 2, 31, 6, 33, 1, 65, 3, 16, 4, 25, 
    3, 55, 4, 49, 7, 48, 0, 25, 6, 76, 1, 29, 2, 75, 5, 51, 8, 84, 
    4, 71, 2, 16, 3, 81, 7, 27, 8, 99, 5, 20, 6, 98, 1, 55, 0,  6, 
    8, 50, 5, 61, 1, 53, 0,  9, 7, 41, 6, 26, 4, 72, 2, 59, 3, 69, 
    2, 34, 1, 63, 7, 79, 8, 37, 3, 17, 6,  4, 4,  7, 5, 88, 0, 36, 
    5, 45, 7, 98, 4, 13, 6, 82, 1, 46, 2, 23, 0, 23, 8, 83, 3, 13, 
    1, 99, 7, 26, 2, 97, 4, 12, 5, 56, 0, 30, 6, 91, 3, 32, 8, 93
  };
  const int q7234[] = {
    9, 9, // Number of jobs and machines
    2, 89, 5, 77, 8, 52, 7, 61, 0, 52, 1, 94, 3, 74, 4, 42, 6, 23, 
    0, 63, 8, 96, 4, 24, 1, 61, 2, 24, 6, 96, 5, 87, 3,  5, 7,  9, 
    8, 11, 5, 12, 0, 98, 2,  1, 1, 40, 7, 59, 6, 43, 3, 40, 4, 33, 
    0,  7, 3, 62, 7, 56, 8, 19, 4, 84, 6, 94, 1,  6, 2, 74, 5, 85, 
    5, 97, 2, 29, 3,  2, 7, 75, 0, 29, 6, 60, 4,  5, 1, 50, 8, 48, 
    0, 77, 7, 96, 8, 22, 5, 28, 1, 99, 4,  5, 3, 44, 6, 69, 2, 30, 
    6, 83, 5, 62, 0, 88, 4, 60, 1, 67, 8, 76, 7, 62, 3, 77, 2, 14, 
    2, 87, 1, 11, 0, 90, 7, 42, 3, 91, 4, 11, 8, 43, 5, 19, 6, 32, 
    3,  9, 6, 64, 2, 37, 0, 77, 5, 27, 4,  4, 1, 31, 7, 28, 8, 90
  };
  const int q7235[] = {
    9, 9, // Number of jobs and machines
    3, 67, 0, 57, 2, 98, 6, 57, 1,  7, 7, 69, 8,  4, 4, 70, 5,  3, 
    7, 66, 2, 34, 6, 72, 8, 62, 1, 44, 3, 55, 0,  5, 5, 75, 4, 18, 
    7, 83, 4, 90, 3, 24, 5, 61, 8, 66, 2, 36, 1, 91, 6, 62, 0, 83, 
    3, 89, 0, 39, 6, 50, 7, 20, 4, 56, 2, 98, 8, 36, 5, 72, 1, 71, 
    7, 14, 2, 89, 0, 53, 5, 71, 3,  7, 1, 21, 8, 23, 4, 79, 6, 19, 
    8, 64, 3, 55, 0, 78, 5, 35, 6, 62, 1, 66, 2, 43, 7, 19, 4, 61, 
    5, 67, 0, 79, 1, 86, 3, 84, 7, 54, 2,  6, 8, 81, 4, 52, 6, 88, 
    8, 36, 1, 73, 0, 42, 5,  1, 3, 97, 7, 33, 6,  4, 2, 51, 4, 53, 
    4, 91, 2, 23, 0, 99, 8,  4, 6, 14, 3,  9, 5, 25, 7,  7, 1, 75
  };
  const int q7236[] = {
    9, 9, // Number of jobs and machines
    2, 57, 7, 77, 6, 28, 1, 41, 4,  1, 5, 94, 3, 48, 8, 98, 0, 34, 
    4, 90, 7, 24, 6, 76, 2, 14, 3, 62, 5, 22, 8, 70, 0,  6, 1,  6, 
    6,  9, 0, 51, 5, 32, 1, 96, 4, 80, 2, 33, 7, 17, 3, 94, 8, 66, 
    6, 25, 5, 48, 2, 31, 3, 24, 7, 57, 1, 97, 8, 97, 0, 36, 4, 52, 
    7, 74, 5, 32, 8, 49, 2, 27, 6, 50, 1, 80, 3, 38, 0, 33, 4, 91, 
    2, 40, 5, 78, 0, 30, 1, 17, 8, 64, 4, 25, 3, 92, 7, 41, 6, 96, 
    2, 75, 3, 83, 5, 56, 0, 39, 8, 28, 4, 94, 1, 39, 6, 16, 7, 45, 
    1, 68, 5, 93, 8, 34, 3, 59, 4,  7, 6, 12, 0, 60, 7, 37, 2, 46, 
    7, 47, 2, 45, 0, 35, 1, 45, 4, 79, 6, 73, 8, 21, 5, 53, 3, 83
  };
  const int q7237[] = {
    9, 9, // Number of jobs and machines
    3, 39, 1, 12, 0, 38, 4, 48, 2, 41, 5, 12, 6,  1, 8, 54, 7, 27, 
    8, 59, 4, 46, 7,  7, 3,  5, 6, 56, 1, 61, 0, 62, 5, 45, 2, 58, 
    1,  6, 6,  9, 7, 86, 2, 46, 0, 96, 4, 23, 5, 79, 8, 54, 3, 93, 
    3, 79, 0, 71, 6,  6, 8, 85, 4, 28, 1, 88, 2, 33, 5,  8, 7, 71, 
    2, 20, 6, 56, 4, 12, 1, 40, 0, 33, 7, 97, 8, 58, 5, 82, 3, 17, 
    4, 15, 6, 98, 7, 94, 5,  8, 0, 21, 8,  3, 3, 12, 2,  8, 1,  6, 
    2, 38, 4, 90, 3, 15, 8, 44, 1, 84, 5,  8, 6, 73, 7, 12, 0, 71, 
    4, 70, 0, 10, 3, 65, 8, 17, 1, 85, 5, 38, 6, 44, 7, 39, 2, 38, 
    0, 68, 3, 62, 8,  9, 4, 72, 5, 83, 7, 18, 6, 63, 2, 13, 1, 43
  };
  const int q7238[] = {
    9, 9, // Number of jobs and machines
    8, 12, 4, 48, 0, 71, 5,  6, 6, 69, 2,  8, 3, 41, 7, 78, 1, 98, 
    3, 75, 1, 13, 2, 60, 6, 97, 0, 10, 5, 77, 8, 42, 4, 14, 7, 63, 
    8, 50, 6, 22, 0, 43, 5, 69, 4, 22, 7, 76, 1, 26, 3, 50, 2, 47, 
    2, 21, 4, 66, 0, 15, 1, 46, 6, 22, 3, 84, 5, 77, 7, 86, 8,  5, 
    6,  7, 0, 98, 1, 14, 8, 65, 4,  1, 2, 52, 3, 13, 5, 54, 7,  2, 
    6, 49, 5, 38, 3, 90, 4, 18, 1, 80, 2, 20, 8, 90, 0, 64, 7, 37, 
    1, 25, 7, 19, 0, 61, 3, 50, 5,  4, 4, 22, 2, 91, 8, 45, 6, 55, 
    6, 55, 4, 15, 2, 20, 1, 18, 0, 76, 8, 57, 3, 20, 5, 71, 7, 73, 
    6, 75, 4, 22, 3, 63, 8, 39, 0, 15, 7, 68, 1, 53, 2, 19, 5, 85
  };
  const int q7239[] = {
    9, 9, // Number of jobs and machines
    5, 23, 8,  5, 1, 43, 6, 14, 0, 42, 2, 78, 3, 93, 7, 11, 4,  1, 
    4, 25, 8, 57, 0, 93, 2, 47, 6, 75, 5, 19, 3, 11, 1, 29, 7,  8, 
    6, 60, 8, 95, 3, 54, 0, 22, 2, 70, 7, 38, 4, 19, 5, 27, 1, 61, 
    6,  2, 8, 76, 4,  4, 0, 69, 7,  7, 1,  8, 3, 61, 5, 22, 2, 21, 
    6, 65, 1, 64, 2, 82, 0, 96, 5, 87, 7, 89, 8, 91, 3, 10, 4, 58, 
    8, 33, 5, 55, 7, 33, 2, 10, 1, 26, 0, 58, 6, 26, 3, 46, 4, 76, 
    8, 61, 0, 49, 2, 99, 7, 74, 6, 48, 5, 19, 4, 59, 3, 40, 1,  8, 
    1, 17, 6, 67, 7, 19, 0, 25, 8, 81, 3, 87, 4, 12, 5,  3, 2, 16, 
    1, 17, 3, 59, 5, 43, 2, 79, 0, 99, 8, 92, 6, 29, 7, 36, 4, 78
  };
  const int q7240[] = {
    9, 9, // Number of jobs and machines
    4, 74, 7, 26, 5,  3, 8, 38, 6, 74, 3, 44, 0, 46, 2, 64, 1, 96, 
    7,  5, 4, 17, 5, 76, 3,  9, 0, 28, 2, 48, 6,  6, 8, 57, 1, 57, 
    5,  8, 8, 56, 0, 22, 2, 57, 1, 90, 3, 68, 6, 48, 4, 42, 7, 62, 
    1, 11, 0,  3, 8, 35, 5, 61, 6, 11, 7, 69, 2, 77, 3, 94, 4, 41, 
    7,  7, 3, 17, 5, 97, 2, 87, 0,  7, 8,  1, 1, 43, 6, 46, 4, 50, 
    5, 32, 8, 40, 1, 87, 3, 30, 6, 76, 4,  4, 7, 63, 0,  2, 2, 14, 
    2, 52, 8, 22, 1, 33, 7, 92, 5, 31, 0, 43, 4,  9, 6, 10, 3, 49, 
    1, 19, 8, 21, 0, 27, 4, 30, 6, 99, 7, 98, 2, 32, 5, 67, 3, 31, 
    8, 32, 0, 48, 4, 89, 3,  3, 1, 38, 2, 29, 7, 96, 6, 17, 5, 19
  };
  const int q7241[] = {
    9, 9, // Number of jobs and machines
    3, 44, 8, 21, 6, 27, 5, 51, 0, 33, 2, 37, 1, 75, 4, 92, 7, 69, 
    3, 14, 5, 75, 2, 75, 7, 16, 1, 98, 4, 95, 0, 48, 6,  4, 8, 69, 
    3, 90, 2, 97, 1, 21, 0, 64, 5, 46, 8, 46, 4, 10, 7, 78, 6, 84, 
    3, 51, 1, 60, 6, 95, 2, 15, 4, 35, 0, 13, 7, 90, 8, 56, 5, 21, 
    5, 48, 0, 96, 6, 33, 1, 86, 2,  5, 7, 11, 4, 23, 3,  5, 8, 26, 
    6, 65, 8, 67, 4, 92, 0, 81, 3, 85, 5, 48, 2, 13, 7, 86, 1, 32, 
    8, 63, 1, 93, 7, 90, 0,  1, 5, 77, 3, 70, 6, 69, 2, 74, 4, 92, 
    2, 41, 0, 73, 5, 47, 1, 49, 8, 76, 4, 50, 7, 83, 3, 76, 6, 96, 
    0, 74, 2,  1, 8, 32, 6, 68, 1, 81, 7, 27, 3, 35, 4, 12, 5, 40
  };
  const int q7242[] = {
    9, 9, // Number of jobs and machines
    5, 80, 6, 79, 0, 25, 3, 73, 2, 32, 1, 35, 8, 60, 7,  4, 4,  3, 
    8, 27, 6, 79, 2, 15, 3, 97, 4, 18, 7, 17, 0, 15, 5, 20, 1, 11, 
    4, 74, 0, 65, 5, 73, 8, 87, 6, 57, 1, 27, 3, 27, 2, 73, 7, 95, 
    8, 54, 3, 67, 0, 68, 6, 96, 7, 54, 4, 38, 1, 95, 5, 23, 2, 90, 
    2, 57, 0, 89, 3, 95, 4, 82, 1, 35, 8, 29, 6, 76, 5, 27, 7, 45, 
    2, 85, 4, 97, 3, 75, 8, 31, 7, 40, 6, 39, 0, 95, 1, 24, 5, 17, 
    6, 52, 4,  8, 7, 83, 2, 49, 5, 83, 8, 39, 1, 45, 0, 16, 3, 84, 
    3, 61, 7, 80, 6, 82, 8, 44, 1, 52, 0, 55, 4, 89, 5, 40, 2, 75, 
    1, 24, 2, 74, 4,  6, 7,  2, 5, 43, 0, 28, 6, 23, 8,  7, 3, 22
  };
  const int q7243[] = {
    9, 9, // Number of jobs and machines
    1, 98, 3, 47, 5, 76, 0, 18, 4,  6, 6, 38, 8, 49, 2, 63, 7, 69, 
    2, 82, 3, 28, 1, 93, 8, 43, 0, 39, 7, 99, 4,  7, 5, 40, 6, 48, 
    8,  9, 2, 26, 4, 45, 0,  2, 3,  6, 5, 81, 1, 10, 6, 76, 7, 96, 
    7, 81, 3, 76, 4, 31, 0, 44, 1, 73, 5, 72, 6, 58, 8, 53, 2, 10, 
    6, 39, 7,  8, 3,  2, 5,  2, 1, 79, 4,  5, 0, 78, 8, 87, 2, 56, 
    7, 14, 2, 17, 3, 89, 6, 98, 1, 77, 4, 74, 5, 24, 8, 36, 0, 24, 
    8, 32, 5, 11, 1, 76, 6, 61, 7, 62, 0, 82, 2, 31, 4, 65, 3, 35, 
    1, 42, 7, 81, 8, 88, 6, 32, 0, 14, 3, 97, 4, 99, 2, 52, 5, 88, 
    8, 17, 3, 90, 2, 63, 0, 93, 7, 77, 5, 61, 6, 12, 4, 27, 1, 89
  };
  const int q7244[] = {
    9, 9, // Number of jobs and machines
    0,  1, 7, 23, 5, 87, 1, 50, 3, 55, 2, 88, 8, 24, 6,  7, 4, 82, 
    7, 18, 1,  7, 6, 22, 5, 79, 3, 59, 8, 30, 4, 90, 2, 61, 0, 94, 
    8,  4, 2, 73, 7, 82, 4,  8, 3, 41, 6, 10, 5, 68, 1,  9, 0, 97, 
    4, 90, 7, 24, 3, 71, 0, 28, 5, 86, 6, 66, 2, 44, 8, 30, 1, 15, 
    3, 48, 4, 30, 1, 88, 6, 23, 5, 86, 7, 57, 2, 18, 0, 63, 8, 73, 
    0, 21, 7, 66, 6, 93, 3, 91, 8, 45, 5, 50, 2, 96, 1, 70, 4, 27, 
    6, 12, 3, 70, 7, 30, 8, 96, 5, 55, 2, 78, 4, 90, 1, 85, 0, 21, 
    3, 18, 7, 98, 8, 23, 4, 30, 2, 57, 0, 97, 1, 37, 6, 15, 5, 24, 
    3, 50, 7, 78, 8,  7, 5,  8, 2, 31, 6, 12, 4, 93, 0, 87, 1, 70
  };
  const int q7245[] = {
    9, 9, // Number of jobs and machines
    0, 19, 7, 40, 8, 17, 2, 16, 3, 79, 4, 46, 6, 16, 1, 78, 5, 35, 
    4, 86, 0, 47, 3, 49, 2, 82, 8, 43, 1, 13, 6,  1, 7,  9, 5, 99, 
    8, 94, 7, 65, 6, 86, 4, 32, 5, 44, 3,  9, 2,  8, 1, 62, 0, 56, 
    8, 61, 2, 36, 4, 69, 6, 26, 3, 78, 5, 52, 1, 33, 0, 47, 7, 47, 
    7, 65, 3, 88, 4, 25, 0, 96, 1, 71, 8, 93, 5, 80, 2, 53, 6, 63, 
    1, 61, 4, 52, 2, 97, 6, 45, 8, 12, 7, 87, 3, 95, 0,  8, 5, 68, 
    6, 20, 7,  6, 8, 96, 2,  7, 5, 99, 1, 41, 0, 58, 3, 44, 4, 51, 
    8,  3, 5, 65, 7, 31, 1, 33, 4, 35, 6, 86, 0, 67, 3, 84, 2, 13, 
    0, 44, 7, 70, 3, 62, 2, 74, 4, 37, 5, 33, 8, 73, 1, 60, 6, 39
  };
  const int q7246[] = {
    9, 9, // Number of jobs and machines
    5, 84, 3, 98, 6, 85, 8, 94, 2, 98, 4, 43, 7, 82, 0,  8, 1, 47, 
    2, 59, 7,  9, 4, 51, 3, 47, 5, 97, 6, 38, 1, 69, 0, 85, 8, 85, 
    0, 98, 6, 28, 7, 21, 5, 13, 2, 26, 1, 31, 4, 49, 3, 81, 8, 35, 
    7, 71, 3, 35, 2, 17, 8,  8, 1, 36, 5, 39, 6, 91, 4, 58, 0, 81, 
    4,  8, 1, 53, 6, 50, 7,  5, 3, 41, 2, 97, 5, 45, 0, 85, 8, 97, 
    8, 34, 1, 13, 2, 36, 4, 18, 0, 32, 7, 70, 5, 58, 3,  3, 6,  2, 
    8, 23, 2, 31, 3, 26, 4, 99, 7, 49, 0, 31, 1, 12, 5, 69, 6, 52, 
    4, 54, 2, 94, 7, 86, 6, 56, 5, 35, 1, 25, 3, 44, 8, 58, 0, 84, 
    6, 79, 0, 21, 5,  5, 3, 86, 1, 28, 8, 87, 2,  2, 7, 50, 4, 74
  };
  const int q7247[] = {
    9, 9, // Number of jobs and machines
    3, 45, 6, 22, 1, 57, 7, 48, 8, 70, 0,  1, 2, 75, 4, 74, 5, 26, 
    6, 82, 5, 77, 4, 67, 1, 19, 8, 64, 3, 72, 7, 35, 0, 99, 2, 56, 
    8, 60, 0, 46, 4, 99, 5, 84, 3, 72, 1, 19, 2, 16, 7, 24, 6, 27, 
    0, 64, 8, 48, 2, 25, 1, 10, 5, 73, 4, 95, 6,  8, 7, 69, 3, 37, 
    6, 98, 4, 97, 2, 49, 8, 91, 1, 33, 3, 13, 0, 93, 7, 62, 5, 18, 
    4, 92, 1, 34, 7, 80, 3, 58, 0, 88, 6, 26, 2, 81, 8, 55, 5, 53, 
    7, 90, 3, 93, 1, 37, 2, 45, 5, 52, 8, 36, 0, 71, 4, 91, 6, 90, 
    4, 62, 2, 85, 3, 77, 6,  7, 7,  7, 8, 31, 0, 93, 5, 60, 1, 24, 
    3, 24, 1, 23, 7, 55, 0, 96, 4, 21, 6, 90, 8, 78, 5, 85, 2, 51
  };
  const int q7248[] = {
    9, 9, // Number of jobs and machines
    1, 81, 2, 33, 8, 85, 6, 31, 3, 29, 4, 59, 0, 52, 7, 34, 5,  1, 
    1, 15, 5, 34, 7, 62, 8, 92, 0, 70, 3, 55, 6, 94, 4, 71, 2, 22, 
    1, 28, 5,  3, 4, 87, 8,  4, 2, 29, 0, 14, 6, 76, 7, 80, 3, 87, 
    2,  8, 0, 18, 3, 10, 6, 80, 4, 44, 7, 11, 8, 50, 1, 99, 5, 13, 
    8, 95, 1, 30, 0, 70, 3, 65, 2, 64, 4, 35, 7, 46, 6,  9, 5, 78, 
    6, 50, 3, 46, 8, 60, 4, 20, 0, 41, 7, 43, 1, 91, 5, 69, 2, 31, 
    5, 41, 2, 22, 0, 15, 4, 91, 6,  3, 1,  2, 7, 63, 8,  5, 3, 35, 
    5, 61, 7, 67, 4, 32, 1, 77, 6, 68, 2, 42, 8, 16, 3, 62, 0, 25, 
    2,  3, 7, 52, 4, 55, 0, 82, 8, 18, 6, 45, 3, 62, 1, 41, 5, 72
  };
  const int q7249[] = {
    9, 9, // Number of jobs and machines
    4, 49, 2, 91, 3, 19, 0, 42, 8, 71, 5, 53, 6, 22, 7, 54, 1, 74, 
    1, 98, 8, 18, 6, 52, 4, 42, 2, 22, 3, 31, 0, 45, 7, 82, 5, 37, 
    6, 70, 1, 38, 7, 18, 2, 59, 4, 44, 3, 67, 5,  1, 8, 18, 0, 30, 
    2, 85, 4, 70, 5, 13, 7, 66, 6, 60, 8, 27, 1, 31, 3,  4, 0, 40, 
    6, 18, 2, 51, 0, 33, 4, 36, 1, 16, 8,  6, 3, 17, 5, 67, 7, 87, 
    5, 39, 6, 22, 2, 34, 1, 84, 0, 40, 4, 95, 7, 30, 8, 10, 3, 57, 
    3, 19, 2, 43, 1, 80, 6, 93, 0, 25, 8, 40, 5, 54, 4, 67, 7, 75, 
    5, 98, 4, 42, 8, 42, 7, 34, 6, 35, 1, 10, 2, 10, 3, 40, 0, 38, 
    8,  2, 2, 55, 1, 96, 5, 32, 4,  6, 6, 90, 0, 19, 7, 66, 3, 78
  };
  const int q7250[] = {
    9, 9, // Number of jobs and machines
    8, 24, 6, 88, 2, 46, 5, 90, 3, 32, 7, 23, 1, 99, 4, 61, 0, 54, 
    2, 20, 8, 82, 5, 15, 6, 60, 1,  2, 3, 36, 4,  9, 7, 86, 0, 15, 
    4, 65, 3,  3, 8,  3, 1, 37, 2, 91, 5,  7, 0, 50, 7, 41, 6, 45, 
    4, 88, 6, 55, 3,  6, 7, 55, 2, 68, 0, 15, 1, 35, 8, 32, 5, 67, 
    8, 28, 1, 75, 6, 42, 5, 48, 7, 58, 3, 50, 4, 93, 0, 93, 2, 24, 
    2, 98, 1,  5, 7, 31, 5, 29, 0, 56, 4, 30, 8,  2, 3, 88, 6, 78, 
    5, 56, 6, 72, 3, 95, 0, 98, 2, 72, 8, 45, 4, 78, 7, 97, 1, 30, 
    3, 77, 7,  9, 0, 90, 4, 40, 6, 70, 5, 39, 2, 59, 8, 37, 1, 33, 
    7, 98, 2, 44, 8, 33, 3, 27, 0, 90, 1, 71, 4, 86, 5, 56, 6, 44
  };
  const int q7251[] = {
    9, 9, // Number of jobs and machines
    5, 58, 7, 53, 0, 43, 4, 38, 8, 88, 3, 43, 6, 27, 2, 68, 1, 80, 
    3, 15, 8,  7, 2, 64, 5, 16, 0, 61, 4, 98, 7, 60, 1,  3, 6, 69, 
    1,  9, 0, 48, 4, 70, 3, 61, 2, 68, 5, 96, 8, 25, 7, 81, 6, 71, 
    2, 69, 8, 73, 7,  6, 5, 66, 1, 44, 6, 52, 4, 35, 0, 79, 3, 37, 
    4, 56, 3, 90, 8, 17, 6, 27, 0, 17, 5, 36, 7, 31, 2, 48, 1, 25, 
    5, 75, 0, 78, 6, 55, 8,  4, 1, 81, 2, 88, 3, 91, 7, 99, 4, 86, 
    3, 57, 2, 31, 7, 21, 5, 48, 6, 42, 0, 35, 8, 54, 4, 59, 1, 71, 
    6, 30, 7, 90, 0, 90, 8, 76, 1, 13, 3, 10, 4, 21, 2, 49, 5, 61, 
    1, 61, 5, 75, 0, 21, 6, 16, 7, 33, 4, 88, 2, 55, 8, 51, 3, 90
  };
  const int q7252[] = {
    9, 9, // Number of jobs and machines
    6, 64, 5, 30, 3, 62, 7, 79, 8, 14, 1, 48, 0, 10, 2, 93, 4, 24, 
    5, 59, 6, 10, 8, 62, 7, 20, 3, 18, 4, 90, 1, 78, 2, 77, 0, 29, 
    0, 45, 3, 91, 8, 31, 6, 91, 4, 56, 5, 99, 2, 37, 1, 26, 7, 59, 
    6, 41, 1, 25, 8,  2, 5, 15, 7, 48, 4, 85, 3, 40, 2, 47, 0, 95, 
    7, 78, 0, 73, 3, 69, 5, 40, 6,  3, 2, 75, 1, 25, 8, 36, 4, 99, 
    2, 32, 0, 77, 8, 29, 5, 31, 3, 66, 6, 79, 7, 17, 4, 66, 1, 37, 
    0, 43, 7, 38, 5, 47, 4, 46, 1, 63, 6, 81, 2, 35, 8, 97, 3,  7, 
    6, 27, 7, 63, 3, 14, 1, 14, 8,  7, 0, 59, 4,  2, 5,  4, 2,  2, 
    7, 77, 6, 35, 2, 35, 3, 20, 0, 82, 5, 97, 4, 89, 1, 62, 8, 90
  };
  const int q7253[] = {
    9, 9, // Number of jobs and machines
    1, 62, 4, 67, 7, 39, 0, 63, 8, 89, 6, 92, 5, 61, 2, 26, 3, 87, 
    0, 10, 3, 92, 6, 99, 7, 12, 4, 93, 5, 95, 8, 91, 2, 39, 1, 70, 
    0, 79, 4,  9, 5, 78, 7, 68, 2, 73, 8, 28, 6, 31, 3,  1, 1, 80, 
    8, 57, 2, 54, 4, 38, 3, 47, 0, 22, 7, 52, 1, 65, 6, 84, 5, 66, 
    6, 23, 8, 86, 2, 24, 0, 23, 7, 78, 5, 26, 1, 96, 4, 67, 3, 90, 
    2, 80, 6, 40, 0, 65, 8, 10, 4, 11, 1,  2, 5, 19, 3, 47, 7, 36, 
    7, 25, 0, 54, 4, 98, 6, 70, 3,  8, 8, 81, 5, 11, 1, 38, 2, 23, 
    3, 42, 8, 35, 2, 40, 1, 78, 4, 28, 0, 32, 6, 25, 5, 54, 7, 32, 
    5, 99, 0, 62, 3,  1, 7, 68, 4, 22, 6, 89, 1, 72, 2, 42, 8, 55
  };
  const int q7254[] = {
    9, 9, // Number of jobs and machines
    5, 38, 8, 14, 3,  8, 7, 58, 4, 11, 1, 43, 2, 20, 0, 47, 6, 62, 
    6,  6, 2, 60, 4, 99, 5, 24, 7,  5, 3, 65, 8, 14, 1, 44, 0,  7, 
    4, 28, 6,  2, 1, 56, 2, 36, 5, 52, 0,  9, 3, 32, 7, 11, 8, 87, 
    3, 12, 2,  6, 1, 93, 5, 15, 0, 82, 4, 50, 6, 66, 8, 39, 7, 71, 
    3, 73, 0, 52, 7, 92, 1, 68, 2, 94, 8, 93, 4, 72, 5,  4, 6, 69, 
    5, 27, 7, 84, 1, 89, 3,  8, 2, 32, 4, 48, 6, 85, 0, 52, 8, 86, 
    6, 76, 2, 42, 8, 32, 1, 11, 5,  8, 7, 40, 0, 43, 3, 82, 4, 17, 
    8, 77, 5, 78, 4, 94, 2, 64, 0, 79, 3, 14, 6, 53, 1, 16, 7, 22, 
    1, 15, 0, 50, 2, 36, 8, 14, 5, 98, 6, 12, 7, 87, 4, 21, 3, 95
  };
  const int q7255[] = {
    9, 9, // Number of jobs and machines
    5, 84, 6, 87, 0, 50, 2, 32, 8, 27, 7, 75, 4, 88, 3, 24, 1,  5, 
    5, 59, 0, 45, 7, 61, 8, 70, 3, 44, 6, 83, 4, 28, 2, 38, 1, 86, 
    5, 59, 4, 79, 2, 10, 8, 63, 0, 53, 1, 66, 6, 48, 3, 84, 7, 72, 
    4, 73, 1, 57, 7, 99, 2, 54, 8, 23, 0, 14, 3, 20, 6, 15, 5, 11, 
    7, 44, 2, 49, 4, 49, 5, 84, 6, 74, 0, 22, 3,  2, 8, 74, 1, 61, 
    3, 90, 0, 67, 8, 53, 2,  6, 5, 24, 6, 77, 1, 60, 7, 99, 4,  6, 
    1, 84, 5, 71, 7, 68, 8, 68, 0, 48, 3,  9, 4, 70, 2, 97, 6, 58, 
    2, 30, 8, 39, 5, 63, 7, 13, 3, 29, 6, 47, 4, 60, 0, 76, 1, 94, 
    6, 78, 2, 81, 5, 79, 1, 33, 8, 53, 3, 83, 4, 60, 7, 41, 0,  6
  };
  const int q7256[] = {
    9, 9, // Number of jobs and machines
    4, 28, 8, 89, 2, 70, 0, 63, 6, 33, 7, 92, 5, 58, 3, 31, 1, 24, 
    1, 49, 5, 32, 0, 50, 7, 78, 8, 21, 6,  2, 2, 56, 4, 51, 3, 97, 
    3, 56, 8, 57, 4, 24, 0, 92, 6, 99, 2,  3, 5, 84, 7, 88, 1, 77, 
    2, 13, 7, 30, 8, 59, 1, 26, 5, 51, 4, 39, 3, 17, 6, 93, 0, 26, 
    6, 11, 4, 15, 0, 85, 5, 64, 2, 23, 1, 75, 3, 62, 7, 51, 8, 63, 
    6, 67, 7, 31, 2, 42, 4,  5, 5, 83, 1, 54, 0, 86, 3, 49, 8, 72, 
    5, 88, 2, 31, 7, 83, 8, 81, 0,  7, 3, 88, 4, 83, 6, 10, 1, 13, 
    3, 46, 1, 77, 8, 71, 0, 64, 2, 45, 7, 29, 4, 83, 5, 87, 6, 49, 
    8,  8, 4,  6, 7,  9, 0, 63, 3, 12, 5, 68, 1, 77, 6, 73, 2, 34
  };
  const int q7257[] = {
    9, 9, // Number of jobs and machines
    3, 27, 5, 48, 8, 38, 4, 83, 2,  2, 0, 66, 7, 26, 6, 18, 1, 64, 
    8,  8, 1, 26, 0, 79, 3, 31, 2, 29, 5, 61, 6, 44, 7, 55, 4, 79, 
    8, 24, 0, 85, 1, 38, 5, 41, 4, 73, 7, 36, 2, 99, 6, 15, 3, 36, 
    1, 11, 4, 36, 3, 96, 5, 34, 7, 41, 0, 31, 6, 71, 2, 40, 8, 62, 
    8, 30, 3, 13, 1, 58, 5, 57, 0, 19, 4, 81, 7, 92, 2, 60, 6, 77, 
    1, 64, 8, 96, 4,  5, 0, 21, 5, 15, 3, 77, 7, 66, 2, 83, 6, 95, 
    4, 17, 5, 25, 6, 17, 0, 81, 8, 73, 2, 41, 3, 19, 1, 71, 7, 32, 
    0, 55, 5, 61, 1, 99, 6,  1, 4, 47, 8, 88, 7, 14, 3,  1, 2, 87, 
    7, 56, 3,  6, 1, 83, 0, 52, 5, 89, 4, 86, 6, 34, 2, 95, 8,  5
  };
  const int q7258[] = {
    9, 9, // Number of jobs and machines
    4, 96, 3, 61, 0, 42, 6, 15, 5, 12, 8,  4, 1, 35, 2, 47, 7, 57, 
    1, 62, 5, 19, 6, 31, 3, 85, 0, 63, 2, 11, 8, 69, 7, 37, 4, 34, 
    2, 48, 4, 73, 0, 29, 6, 94, 1, 81, 8,  6, 5, 23, 7, 31, 3, 41, 
    6, 39, 4, 72, 3, 81, 5, 76, 8, 47, 0, 32, 2, 38, 7,  8, 1, 95, 
    4, 10, 5, 91, 0, 98, 3, 50, 6, 82, 2, 15, 1, 23, 7, 41, 8, 30, 
    2, 52, 4, 81, 8, 70, 5, 19, 1, 64, 7, 43, 3, 29, 0, 59, 6,  5, 
    5, 46, 1, 29, 0, 20, 8, 55, 6, 91, 3, 78, 2, 16, 7, 84, 4, 15, 
    2,  7, 3, 17, 0, 93, 1, 15, 7, 64, 8, 20, 5,  3, 4, 20, 6, 74, 
    8, 94, 0, 94, 1, 13, 6, 48, 3, 65, 4,  4, 5, 66, 7, 27, 2, 36
  };
  const int q7259[] = {
    9, 9, // Number of jobs and machines
    0, 89, 1, 25, 3, 31, 7, 43, 4, 91, 6, 11, 2, 60, 5,  4, 8, 36, 
    0, 66, 4, 79, 8, 22, 7,  9, 1, 38, 6, 44, 2, 79, 3, 48, 5, 84, 
    7, 89, 0, 43, 5, 51, 1, 66, 4, 52, 8, 48, 3, 14, 6,  8, 2, 53, 
    0, 49, 5, 53, 8, 35, 7, 23, 2, 29, 1, 32, 6, 66, 4, 53, 3, 95, 
    8, 68, 5, 21, 3, 70, 0, 27, 1, 86, 7, 48, 2, 50, 4, 18, 6, 86, 
    4, 47, 1, 11, 2, 23, 5, 44, 8, 96, 6, 25, 0, 82, 7, 29, 3, 68, 
    3, 79, 6, 51, 7, 79, 5, 96, 2, 20, 1, 67, 0, 44, 8, 29, 4, 97, 
    5, 77, 4, 53, 2, 22, 0, 83, 7, 62, 6, 22, 1, 21, 3, 99, 8, 20, 
    4, 10, 3, 48, 1, 89, 5, 53, 2, 82, 8, 92, 6, 49, 0, 22, 7, 20
  };
  const int q7260[] = {
    9, 9, // Number of jobs and machines
    0, 58, 3, 98, 7, 17, 5, 12, 2, 65, 6, 43, 1, 30, 8, 55, 4, 92, 
    0, 39, 8, 26, 1, 40, 2,  5, 3, 20, 4, 58, 7, 32, 6,  7, 5, 75, 
    3, 21, 2, 55, 8, 89, 0, 20, 4, 53, 5, 75, 7, 80, 6, 99, 1, 51, 
    2, 49, 3, 51, 1, 91, 4, 77, 6, 96, 5, 82, 8,  7, 0, 78, 7, 48, 
    8, 95, 3, 76, 5, 55, 4,  9, 6, 58, 0, 57, 7, 66, 1, 97, 2, 59, 
    4, 86, 2, 53, 6, 51, 5, 89, 0, 19, 1, 43, 3, 91, 8, 10, 7, 17, 
    0, 28, 3, 53, 5, 45, 8, 44, 1, 64, 4, 56, 2, 38, 7,  2, 6, 41, 
    0, 66, 3, 45, 5, 77, 7, 57, 6, 39, 1, 60, 8, 80, 4, 66, 2, 74, 
    7, 47, 4, 92, 6, 83, 8, 32, 0, 75, 1, 87, 2, 70, 5, 95, 3, 92
  };
  const int q7261[] = {
    9, 9, // Number of jobs and machines
    4, 71, 6, 69, 3, 94, 8, 20, 2, 42, 7, 45, 5, 60, 0, 44, 1, 29, 
    8, 65, 0, 65, 3, 10, 7, 29, 4, 55, 2, 67, 5, 54, 1, 56, 6, 82, 
    7, 17, 2, 44, 3, 46, 8, 71, 6, 77, 1, 16, 4, 20, 5, 39, 0, 23, 
    1, 15, 4, 82, 6, 14, 5, 66, 7, 58, 3, 16, 8,  4, 0, 46, 2, 16, 
    1, 32, 3, 57, 5, 23, 0, 87, 7, 91, 2, 47, 4, 77, 8, 24, 6, 35, 
    6, 10, 5, 11, 8, 13, 3, 21, 7, 47, 1, 66, 2, 90, 0, 15, 4, 21, 
    4, 15, 3, 93, 7, 74, 0, 95, 8, 33, 1, 31, 5, 10, 2, 51, 6, 33, 
    0, 84, 8, 66, 7, 60, 2, 47, 6, 97, 4, 25, 1, 97, 5, 60, 3, 74, 
    2, 21, 6, 58, 0, 40, 1, 48, 5, 16, 7, 89, 8, 22, 3, 56, 4, 44
  };
  const int q7262[] = {
    9, 9, // Number of jobs and machines
    3, 84, 2, 26, 8, 36, 5, 91, 1, 12, 6,  2, 4, 58, 0, 76, 7, 34, 
    6, 97, 3, 76, 5, 74, 2, 67, 8, 30, 7, 35, 1, 50, 4, 41, 0, 47, 
    2, 99, 3,  7, 4, 78, 6, 35, 8, 38, 5,  5, 1, 57, 0, 45, 7, 43, 
    6, 45, 8, 68, 4, 57, 1, 29, 2, 24, 3, 46, 0, 84, 5, 71, 7, 29, 
    6,  4, 3, 57, 4, 68, 5, 41, 2, 68, 0, 90, 7, 12, 1, 26, 8, 83, 
    0, 63, 4, 62, 2,  2, 6,  7, 8, 81, 3, 64, 7, 82, 1, 33, 5,  6, 
    5, 72, 3,  2, 8, 30, 6, 82, 7, 19, 4,  8, 1, 49, 0, 97, 2, 23, 
    6, 80, 8, 45, 4, 13, 3, 80, 0, 50, 2, 88, 1, 22, 7, 43, 5, 80, 
    4, 81, 6, 21, 1, 74, 3, 51, 2, 91, 8, 92, 5, 27, 0, 97, 7, 51
  };
  const int q7263[] = {
    9, 9, // Number of jobs and machines
    7, 71, 3, 69, 0,  8, 1, 60, 2, 30, 4,  6, 5,  3, 6, 10, 8, 45, 
    6, 26, 7, 33, 4, 33, 2,  7, 0, 55, 3, 78, 5,  1, 1, 97, 8, 59, 
    3, 54, 4, 57, 7, 99, 5, 71, 2, 68, 1, 53, 0, 67, 8, 26, 6, 35, 
    1, 35, 2,  6, 6, 49, 8, 52, 7, 17, 0, 87, 5,  5, 3, 45, 4, 30, 
    6, 89, 4, 87, 3, 66, 1, 25, 2, 64, 7, 75, 5, 38, 0, 27, 8, 50, 
    8, 40, 1, 52, 4, 86, 0, 31, 5, 75, 3, 60, 2, 81, 7, 24, 6, 16, 
    1, 15, 4, 18, 7, 49, 2, 62, 6, 96, 8, 74, 3, 72, 0, 47, 5, 57, 
    2, 36, 1, 59, 4, 91, 6, 63, 7, 73, 0, 78, 3, 78, 5, 25, 8, 96, 
    0,  1, 6, 58, 3, 69, 4, 53, 1, 33, 2, 81, 7, 53, 8,  4, 5, 56
  };
  const int q7264[] = {
    9, 9, // Number of jobs and machines
    8, 44, 2, 14, 3, 82, 1, 69, 0, 12, 4, 78, 7, 78, 5, 79, 6, 13, 
    5, 59, 8, 15, 2, 84, 0, 15, 6, 79, 7, 13, 3, 91, 4, 31, 1, 89, 
    8, 91, 6, 91, 2, 34, 5, 65, 0,  5, 7, 24, 3, 20, 1, 83, 4, 28, 
    2, 21, 3, 38, 1, 77, 7, 63, 8, 80, 5, 29, 0, 52, 4, 33, 6, 64, 
    0, 71, 2, 31, 4, 98, 3,  1, 1, 91, 5, 50, 6, 91, 7, 35, 8, 27, 
    3, 29, 0, 48, 4, 12, 2,  1, 7, 80, 1, 96, 6, 63, 5, 81, 8, 88, 
    7, 90, 8,  8, 5,  4, 3, 74, 1, 16, 6, 44, 2, 99, 0, 99, 4, 25, 
    8, 35, 5, 12, 6, 80, 1, 38, 2, 69, 0, 38, 3, 23, 4, 29, 7, 77, 
    6, 20, 2,  9, 1, 23, 0, 55, 8, 22, 5, 57, 7, 52, 3, 47, 4, 88
  };
  const int q7265[] = {
    9, 9, // Number of jobs and machines
    6, 31, 1, 37, 8, 12, 2, 56, 3, 82, 0, 84, 7, 10, 5, 22, 4, 69, 
    5, 57, 7, 29, 4, 56, 1, 32, 6, 43, 8, 58, 3, 54, 0, 24, 2, 40, 
    2, 61, 7, 71, 8, 93, 0, 45, 6, 11, 3,  9, 4, 86, 5, 39, 1, 19, 
    0, 70, 5, 84, 1, 56, 4, 22, 2, 52, 7, 44, 8, 31, 3, 79, 6, 94, 
    1, 86, 8, 80, 4, 17, 6,  6, 7, 88, 2, 87, 0, 42, 3, 31, 5, 56, 
    0, 38, 4, 41, 7, 69, 6, 18, 2, 70, 8, 34, 3, 55, 5, 47, 1, 36, 
    6, 14, 5, 37, 0, 31, 3,  9, 7, 94, 4, 74, 2, 71, 8, 80, 1, 62, 
    2, 13, 8, 81, 5, 28, 3, 85, 4, 21, 0, 46, 1, 39, 6, 66, 7, 47, 
    6, 41, 7, 68, 3, 19, 4, 26, 5, 35, 1, 79, 8, 97, 2, 99, 0, 58
  };
  const int q7266[] = {
    9, 9, // Number of jobs and machines
    8, 73, 6, 35, 7, 42, 2, 15, 0,  9, 4, 21, 5, 13, 3, 67, 1, 83, 
    5, 88, 0, 65, 1, 84, 6, 33, 8, 41, 4, 90, 7, 38, 2, 84, 3, 23, 
    1, 26, 8, 51, 6, 23, 3, 77, 0, 99, 2, 64, 5, 42, 7,  2, 4,  4, 
    0, 66, 4, 51, 6, 24, 2, 68, 1, 37, 5,  6, 7, 85, 3, 93, 8, 44, 
    2, 30, 8, 93, 4, 69, 3, 56, 7, 42, 0, 19, 5, 44, 1, 36, 6, 73, 
    4, 66, 6, 28, 7, 24, 1,  7, 8, 19, 3, 51, 0, 84, 2, 26, 5, 74, 
    6, 38, 5, 29, 8, 80, 7, 49, 2, 31, 0, 76, 3,  9, 4, 12, 1, 73, 
    5, 13, 0, 26, 4, 24, 6, 46, 1, 75, 3, 52, 8, 93, 7, 60, 2, 40, 
    3, 35, 7, 33, 6, 42, 8, 98, 2, 11, 5, 40, 1, 47, 0, 29, 4, 94
  };
  const int q7267[] = {
    9, 9, // Number of jobs and machines
    3,  9, 1,  8, 8, 21, 0, 73, 6, 78, 7, 52, 4,  8, 2, 19, 5,  1, 
    7, 86, 6, 66, 4, 62, 3, 12, 8, 99, 2, 65, 1, 63, 5,  9, 0, 63, 
    0, 24, 2, 58, 7, 86, 1, 59, 6, 53, 3, 11, 5, 40, 8, 50, 4, 10, 
    5, 72, 1, 51, 2, 92, 4, 74, 3, 44, 8, 70, 0, 82, 7, 31, 6, 91, 
    4, 66, 0, 80, 2, 17, 8, 47, 3, 75, 6,  1, 5, 33, 7,  1, 1, 48, 
    1, 77, 5, 97, 7, 51, 8, 38, 3, 62, 6, 54, 0, 69, 4, 92, 2, 90, 
    2, 46, 7, 14, 3, 27, 0, 55, 5, 91, 6, 41, 8, 47, 4, 85, 1, 13, 
    7, 41, 3, 15, 6, 78, 8, 67, 5, 36, 4, 50, 2, 10, 1, 83, 0,  9, 
    7, 51, 5, 64, 4, 78, 0, 55, 1, 42, 6, 62, 8, 74, 3, 71, 2, 20
  };
  const int q7268[] = {
    9, 9, // Number of jobs and machines
    7, 66, 3, 21, 2, 41, 0, 73, 4, 61, 8, 22, 5, 30, 1,  1, 6, 26, 
    3, 57, 4, 74, 1, 80, 7, 67, 0, 40, 2,  6, 8, 87, 6, 65, 5, 42, 
    6, 25, 5, 95, 1, 37, 8, 39, 0, 98, 4, 85, 3, 72, 2, 39, 7, 67, 
    8, 39, 7, 29, 1, 79, 4, 52, 6, 67, 3, 30, 5, 24, 0, 79, 2, 89, 
    6,  5, 7, 83, 1, 83, 8, 22, 2, 33, 0, 21, 3, 79, 4,  3, 5, 88, 
    2, 63, 8, 80, 3, 59, 5, 32, 7, 83, 1, 60, 6, 29, 4,  4, 0, 76, 
    7, 97, 2, 13, 6, 32, 8, 15, 5, 28, 0, 51, 4, 26, 3, 61, 1, 51, 
    7, 54, 1, 57, 8, 79, 2,  3, 6, 90, 0, 71, 4, 90, 3, 47, 5, 99, 
    2, 26, 6, 68, 3, 90, 8, 49, 0, 91, 7, 31, 4, 54, 1, 49, 5, 37
  };
  const int q7269[] = {
    9, 9, // Number of jobs and machines
    5,  7, 3, 68, 1, 88, 0, 18, 8, 92, 4, 16, 2, 70, 6, 98, 7, 19, 
    2, 63, 1, 21, 6, 54, 4, 74, 7, 17, 8, 70, 3, 70, 5, 41, 0, 16, 
    6, 81, 7, 23, 2, 86, 5, 69, 3,  3, 1, 62, 4, 71, 0, 42, 8,  7, 
    5, 56, 8, 22, 2, 12, 4, 53, 1, 42, 3, 12, 7,  6, 0,  4, 6, 65, 
    7, 16, 6, 88, 5,  1, 0, 73, 4, 82, 8, 43, 1, 96, 3, 38, 2,  7, 
    5, 46, 7, 77, 0, 10, 2, 94, 8,  3, 4, 28, 3, 55, 6, 67, 1, 70, 
    7, 20, 8, 37, 3, 58, 0, 33, 1, 24, 4, 92, 6, 13, 5, 84, 2, 71, 
    3, 25, 2, 20, 5, 25, 0, 82, 4,  2, 8, 76, 6, 79, 1, 87, 7, 73, 
    3, 97, 0, 42, 1,  2, 6, 41, 7,  1, 5, 39, 4, 48, 8, 32, 2, 88
  };
  const int q7270[] = {
    9, 9, // Number of jobs and machines
    4, 66, 2, 27, 8, 68, 6,  8, 5, 41, 0, 15, 1, 57, 3, 19, 7, 11, 
    0, 25, 1,  5, 3,  8, 2, 56, 6, 94, 7, 72, 4, 62, 8, 59, 5, 95, 
    7, 42, 2, 52, 6, 81, 0, 57, 8, 51, 1, 31, 3, 76, 4, 27, 5,  2, 
    6, 66, 7, 97, 1, 95, 0, 23, 8, 43, 3, 30, 5, 44, 2, 30, 4, 45, 
    6, 85, 7, 34, 2, 67, 5,  2, 8, 23, 1,  2, 4, 74, 3, 67, 0, 32, 
    0, 73, 5, 22, 4, 14, 8, 91, 6, 35, 7, 55, 3, 96, 2, 84, 1, 68, 
    1, 85, 7, 63, 0, 25, 6, 59, 8,  1, 3, 10, 4, 89, 5, 84, 2, 45, 
    2, 31, 0, 57, 3, 52, 4, 42, 1, 83, 8, 79, 6,  2, 7, 33, 5, 98, 
    8, 12, 2, 23, 1, 36, 3, 49, 6, 88, 7, 63, 0, 59, 4, 15, 5, 60
  };
  const int q7271[] = {
    9, 9, // Number of jobs and machines
    2, 32, 3, 22, 6, 29, 5, 35, 7, 63, 8, 91, 0, 32, 4, 94, 1, 86, 
    2, 94, 7, 78, 4, 16, 6, 80, 5, 19, 0, 91, 1, 92, 3, 78, 8, 85, 
    2, 41, 5, 55, 0, 21, 6, 78, 8, 53, 3, 73, 1, 31, 4, 28, 7, 34, 
    8, 18, 6, 72, 1, 13, 2,  3, 5, 94, 3, 97, 4, 69, 0, 95, 7, 36, 
    0, 43, 3, 35, 7, 18, 5, 64, 6, 93, 4, 65, 8,  2, 1, 39, 2, 34, 
    0, 11, 5, 44, 3, 25, 4, 50, 8,  9, 2,  1, 7, 42, 1, 79, 6, 43, 
    1, 92, 3, 10, 6, 28, 0, 80, 8, 78, 2,  4, 7,  4, 4, 45, 5, 76, 
    8, 54, 2, 91, 0, 13, 3, 24, 7, 49, 6, 56, 5,  5, 1, 39, 4, 78, 
    0, 48, 7, 65, 4, 96, 6, 19, 3, 72, 2, 35, 8, 21, 5, 77, 1,  7
  };
  const int q7272[] = {
    9, 9, // Number of jobs and machines
    0, 12, 4, 85, 8, 38, 6, 41, 1, 80, 3, 31, 5, 76, 7,  5, 2,  5, 
    0, 35, 1, 44, 8, 88, 4, 44, 6, 71, 5, 45, 7, 79, 2, 22, 3,  7, 
    4, 28, 8,  6, 0,  9, 3, 91, 1, 87, 2, 58, 7, 33, 6, 35, 5, 65, 
    1, 92, 2, 85, 3, 32, 0, 13, 4, 14, 6, 87, 7, 51, 5, 99, 8,  4, 
    0, 10, 8, 89, 4, 57, 1, 37, 2, 98, 7,  8, 3, 66, 6, 50, 5, 29, 
    1, 81, 8, 72, 6, 52, 2, 48, 4, 76, 7, 84, 3, 37, 5,  5, 0, 98, 
    4, 23, 2, 47, 5, 80, 7, 99, 8, 17, 6, 92, 0, 39, 1, 10, 3,  1, 
    6, 43, 3,  7, 8, 55, 5, 22, 2, 99, 4, 72, 1, 74, 0, 30, 7, 52, 
    6, 69, 4, 61, 8, 35, 0, 48, 3, 29, 7, 37, 5, 76, 2, 19, 1,  9
  };
  const int q7273[] = {
    9, 9, // Number of jobs and machines
    1,  8, 5, 99, 8, 93, 4, 21, 7, 81, 0, 96, 3, 19, 2, 80, 6, 30, 
    2, 20, 7, 34, 3, 53, 8, 41, 4, 68, 5, 56, 1, 78, 6, 74, 0, 91, 
    0, 31, 4, 13, 1, 29, 5, 74, 3, 22, 7, 52, 2, 33, 6, 10, 8, 64, 
    6, 28, 2, 88, 0, 32, 7,  2, 3, 83, 5, 90, 4, 94, 8, 36, 1, 89, 
    2, 62, 6,  4, 1, 74, 7, 32, 8, 80, 4, 90, 3, 27, 0, 57, 5, 85, 
    2,  4, 6, 37, 7, 64, 5, 52, 8, 48, 3, 35, 4, 75, 1, 46, 0, 48, 
    1, 61, 6, 42, 3, 83, 4, 25, 7, 13, 5, 63, 8, 34, 2, 25, 0, 92, 
    0, 92, 8, 84, 2, 85, 6, 73, 4, 38, 7, 10, 3, 30, 1, 27, 5, 97, 
    2, 67, 4, 35, 6, 51, 5, 68, 1, 98, 7, 81, 8, 86, 3,  3, 0, 58
  };
  const int q7274[] = {
    9, 9, // Number of jobs and machines
    7, 29, 1, 94, 6,  7, 2, 13, 3, 90, 8, 92, 0, 41, 5, 68, 4, 37, 
    4, 67, 0, 45, 6, 18, 1, 13, 5, 58, 8, 47, 2, 62, 7, 45, 3, 39, 
    2, 48, 1,  6, 4, 62, 0, 31, 3, 61, 8, 50, 6, 41, 5, 40, 7, 64, 
    3,  8, 8, 52, 6, 61, 4, 95, 5, 48, 0, 98, 1, 71, 2, 26, 7, 49, 
    8, 72, 4, 95, 2,  4, 1, 95, 3,  4, 7, 11, 6, 14, 5, 53, 0,  5, 
    8, 43, 7, 84, 1, 32, 5, 41, 2, 86, 6,  5, 4, 36, 0, 54, 3, 71, 
    6, 48, 1, 52, 8, 46, 5, 48, 3, 85, 2, 17, 0, 80, 4, 40, 7, 58, 
    5, 97, 3, 56, 4, 65, 7, 44, 2, 72, 8, 99, 0, 51, 6, 25, 1, 69, 
    4, 59, 0, 50, 7, 94, 3, 32, 1, 53, 2, 88, 6,  7, 5, 42, 8,  6
  };
  const int q7275[] = {
    9, 9, // Number of jobs and machines
    7, 88, 3, 30, 2,  4, 5, 95, 4, 18, 8, 30, 1, 18, 6, 73, 0, 54, 
    4, 58, 1, 34, 8, 99, 7, 48, 3, 72, 6, 54, 5, 45, 0,  1, 2, 18, 
    1, 44, 6, 42, 4, 82, 0, 15, 3, 26, 8, 26, 2, 48, 7, 99, 5, 85, 
    1, 86, 2, 86, 8, 47, 6, 16, 4, 10, 7, 93, 5, 81, 0, 36, 3, 71, 
    5, 52, 1, 64, 0,  4, 8, 69, 6, 97, 3, 15, 2,  8, 4, 99, 7, 65, 
    5, 67, 1, 12, 0, 58, 7, 78, 3, 61, 4, 38, 6, 43, 2,  4, 8,  8, 
    1, 45, 5, 45, 3, 53, 8, 66, 0, 31, 4, 50, 2, 24, 6,  7, 7, 29, 
    0, 13, 4, 96, 1,  1, 7, 31, 2, 65, 3, 28, 8, 61, 5, 12, 6, 58, 
    5, 65, 3, 17, 6, 54, 8, 81, 2, 81, 1, 16, 0, 27, 7, 70, 4, 63
  };
  const int q7276[] = {
    9, 9, // Number of jobs and machines
    7, 25, 1, 85, 4, 86, 0,  7, 6, 11, 2, 55, 8, 53, 3,  2, 5, 55, 
    6, 21, 2,  2, 0,  7, 5, 49, 8, 36, 4, 48, 7, 66, 3,  9, 1, 13, 
    7, 12, 2, 59, 8, 73, 0, 49, 4, 10, 1, 71, 3, 40, 6,  3, 5, 43, 
    7, 73, 1, 90, 4, 58, 3, 45, 0, 66, 2,  4, 6,  5, 8, 94, 5,  6, 
    6, 26, 8, 60, 3, 42, 1, 34, 4,  1, 5, 24, 2, 62, 0, 77, 7, 16, 
    7, 48, 5, 53, 2, 54, 4, 55, 6, 74, 8, 16, 0, 73, 3, 40, 1, 15, 
    3, 45, 1, 13, 6, 69, 7, 17, 4,  6, 5, 76, 2, 19, 0, 94, 8, 14, 
    0, 86, 3, 34, 8,  7, 6, 18, 7, 39, 2, 41, 5, 16, 1, 29, 4, 59, 
    1,  1, 7, 75, 8, 68, 0, 51, 5, 66, 6, 93, 3, 23, 4, 97, 2, 71
  };
  const int q7277[] = {
    9, 9, // Number of jobs and machines
    4, 73, 7, 11, 6, 35, 2, 44, 0, 25, 3, 12, 1, 16, 5, 86, 8, 87, 
    4, 57, 0,  4, 6, 31, 2, 70, 8, 32, 3, 83, 5, 12, 7, 89, 1, 43, 
    0, 99, 2, 64, 4, 49, 5, 14, 8, 22, 1, 54, 3, 10, 6, 91, 7, 78, 
    0, 64, 1, 14, 6, 49, 5, 88, 8, 27, 4,  6, 7,  3, 3, 32, 2, 78, 
    3, 37, 0, 35, 6, 89, 7, 45, 4, 38, 2, 39, 1, 81, 8, 76, 5, 40, 
    6, 86, 2, 62, 4, 38, 5, 56, 7, 55, 1, 42, 8,  4, 3, 96, 0, 20, 
    4,  9, 8, 28, 2, 24, 0, 74, 1, 36, 7, 54, 6, 24, 5, 52, 3, 53, 
    7, 53, 3, 82, 2, 23, 0, 55, 8, 69, 5, 31, 4, 56, 1,  3, 6, 94, 
    3,  1, 7, 93, 1, 50, 8, 19, 6,  1, 2, 18, 5, 50, 4,  9, 0, 31
  };
  const int q7278[] = {
    9, 9, // Number of jobs and machines
    8,  2, 2, 66, 5, 64, 0, 92, 7, 29, 3, 40, 1, 63, 4, 50, 6, 68, 
    2, 97, 6,  1, 8, 83, 3, 11, 1, 98, 0, 35, 5, 32, 7, 12, 4, 34, 
    0, 11, 7, 18, 4, 26, 5, 97, 1, 33, 3, 16, 8,  7, 6, 74, 2, 13, 
    0, 96, 1, 14, 5, 12, 7,  9, 4, 76, 2, 67, 6, 95, 8, 17, 3, 72, 
    6, 93, 1, 76, 0,  1, 4, 41, 5, 88, 8, 78, 3, 14, 7, 10, 2, 84, 
    0, 90, 7, 89, 1, 58, 4, 92, 3, 42, 5, 12, 8, 80, 2, 62, 6, 56, 
    2, 40, 4,  9, 6,  7, 3, 43, 1, 67, 7, 36, 5, 46, 0, 79, 8, 64, 
    2, 47, 1, 36, 8, 85, 5, 39, 0, 95, 7, 99, 6, 62, 3,  9, 4,  6, 
    5, 77, 8, 38, 4, 64, 0, 24, 6, 60, 2, 79, 7, 58, 3, 35, 1, 65
  };
  const int q7279[] = {
    9, 9, // Number of jobs and machines
    0, 49, 3, 98, 5, 79, 2, 96, 1, 46, 7, 64, 4, 78, 8, 77, 6, 51, 
    3, 67, 4, 97, 7,  8, 2, 77, 1, 96, 8, 33, 0, 77, 5, 57, 6, 32, 
    8, 87, 2, 92, 6, 35, 0, 83, 3, 18, 5, 52, 4, 51, 7, 41, 1, 79, 
    8, 79, 6, 31, 4, 52, 2, 56, 1, 18, 7, 11, 5, 30, 3, 63, 0, 13, 
    1, 88, 5,  5, 0, 90, 4, 86, 3, 94, 6, 54, 7, 13, 8, 44, 2, 58, 
    5, 36, 4, 18, 0, 54, 2, 93, 1, 52, 3,  4, 7, 99, 6, 14, 8, 29, 
    7, 50, 1, 10, 8, 47, 0, 18, 2, 87, 5, 18, 4, 61, 3, 24, 6, 61, 
    4, 36, 6, 50, 1, 45, 2, 71, 5, 49, 0, 33, 8, 21, 7, 90, 3, 10, 
    2, 58, 0, 72, 7, 55, 6, 29, 5, 24, 3, 60, 1, 45, 8, 11, 4, 57
  };
  const int q7280[] = {
    9, 9, // Number of jobs and machines
    0, 95, 8, 76, 5,  1, 4, 24, 7, 62, 6, 95, 1, 65, 2, 41, 3, 79, 
    1, 17, 3, 79, 8, 33, 7, 22, 0, 81, 2, 40, 6, 25, 4, 75, 5, 41, 
    0, 18, 4, 63, 1, 82, 2, 66, 7, 98, 5, 91, 8, 72, 3, 17, 6, 11, 
    1, 17, 5, 16, 0, 34, 7, 87, 3, 55, 8, 98, 2, 42, 4, 56, 6, 35, 
    0, 22, 1, 95, 6,  6, 8, 18, 2, 18, 4, 96, 7, 72, 5, 81, 3, 72, 
    6, 29, 5, 29, 2, 62, 0, 29, 3, 32, 4, 60, 1, 90, 7, 51, 8, 71, 
    8, 32, 4, 55, 0, 80, 2, 34, 3, 17, 6, 84, 7, 50, 1, 45, 5, 38, 
    3, 81, 4, 24, 8, 99, 6, 40, 7, 46, 2, 19, 0, 66, 1, 76, 5, 61, 
    0, 22, 3,  9, 2, 80, 5, 38, 1, 38, 7, 77, 4, 58, 8, 35, 6,  7
  };
  const int q7281[] = {
    9, 9, // Number of jobs and machines
    0, 33, 3, 34, 5, 80, 1, 78, 7, 68, 4, 91, 8, 86, 2, 41, 6, 71, 
    8, 56, 5, 68, 0, 15, 2, 77, 1, 97, 7, 53, 3, 92, 6, 28, 4, 96, 
    3, 40, 4, 67, 8,  1, 6,  2, 5, 15, 2,  2, 0, 58, 1, 26, 7, 76, 
    1, 84, 6, 41, 3, 28, 7, 90, 0, 69, 4, 24, 2, 52, 5, 69, 8, 78, 
    3, 12, 8, 30, 0, 65, 7,  4, 1, 11, 6,  4, 5, 30, 4, 38, 2, 65, 
    2,  3, 4, 89, 1, 41, 0, 80, 7, 25, 5, 97, 6,  7, 3, 42, 8, 13, 
    8, 46, 1, 95, 7,  8, 5, 88, 4,  5, 6, 29, 0, 86, 3, 32, 2, 35, 
    1, 53, 2, 26, 5, 10, 4, 35, 6,  6, 7, 97, 0, 26, 8, 30, 3, 71, 
    3, 39, 0, 82, 6, 78, 4, 95, 8, 38, 5,  9, 2, 86, 1, 80, 7, 30
  };
  const int q7282[] = {
    9, 9, // Number of jobs and machines
    3, 26, 0, 64, 1, 32, 8, 87, 6, 11, 4,  6, 2, 66, 7, 97, 5, 80, 
    5,  6, 8, 51, 3, 32, 1, 20, 4, 32, 0, 93, 2, 89, 7, 47, 6, 35, 
    8, 32, 2, 84, 1, 86, 7, 48, 5, 64, 0, 83, 4, 61, 6, 70, 3,  8, 
    8, 53, 7, 86, 1, 55, 3, 50, 0, 31, 6, 22, 5, 89, 4, 25, 2, 76, 
    3, 73, 4, 56, 1, 74, 5, 98, 8, 97, 0, 96, 2, 22, 7, 59, 6, 93, 
    8, 41, 6, 59, 5, 89, 2, 51, 1, 11, 4,  5, 3, 86, 7, 24, 0, 53, 
    7, 80, 6,  5, 2, 81, 5, 96, 1, 30, 4, 32, 3, 33, 0, 31, 8, 95, 
    5, 56, 3, 25, 6, 83, 2, 82, 7,  6, 1, 30, 4, 72, 0,  4, 8, 61, 
    6, 33, 8, 63, 3, 41, 4, 10, 7, 44, 5, 66, 2, 38, 1, 23, 0, 72
  };
  const int q7283[] = {
    9, 9, // Number of jobs and machines
    1, 43, 3, 30, 4, 32, 5,  9, 2, 47, 8, 65, 6, 29, 0, 81, 7, 34, 
    5, 82, 1, 31, 2, 81, 6, 61, 8, 14, 0, 56, 7, 15, 4, 35, 3, 85, 
    0, 20, 4, 89, 7, 92, 6,  1, 5, 48, 8, 22, 2, 94, 1, 52, 3, 55, 
    8,  4, 6, 32, 4, 30, 7, 65, 3, 16, 1, 28, 5, 38, 2, 37, 0, 97, 
    8, 50, 7, 36, 1, 22, 2, 82, 4, 44, 0, 36, 5, 67, 6, 27, 3, 79, 
    1, 52, 6, 76, 8, 16, 0, 68, 4, 71, 5, 15, 3, 25, 2, 46, 7, 17, 
    4, 66, 2, 82, 3, 34, 7, 44, 5, 25, 6, 93, 8, 43, 1, 54, 0, 52, 
    1,  7, 5, 45, 4, 28, 2, 62, 0, 63, 6, 25, 7, 36, 8, 56, 3, 82, 
    0, 89, 8, 11, 6, 32, 2, 22, 3, 38, 1,  7, 4, 24, 7,  9, 5, 28
  };
  const int q7284[] = {
    9, 9, // Number of jobs and machines
    8, 43, 2, 16, 3, 39, 5, 81, 7, 59, 4, 91, 0, 48, 1, 97, 6, 69, 
    5, 53, 6, 90, 3, 51, 1, 68, 4, 25, 0, 51, 2, 95, 7, 88, 8, 73, 
    6, 17, 1, 50, 2, 58, 4, 92, 8, 13, 3,  5, 7, 70, 0, 90, 5, 18, 
    4,  9, 1, 34, 2, 36, 0,  7, 7, 36, 5, 81, 6, 83, 8, 60, 3, 90, 
    3, 30, 6, 27, 7, 46, 0,  8, 5, 63, 1, 89, 4, 58, 8, 31, 2, 43, 
    7, 39, 1, 17, 5, 39, 4, 80, 0,  5, 8, 53, 2, 58, 3, 31, 6,  5, 
    1, 61, 3, 45, 2, 50, 6, 51, 4, 92, 7, 80, 5, 34, 8, 59, 0, 12, 
    5, 77, 8, 64, 1, 42, 0, 49, 4, 21, 2, 25, 3, 22, 7, 94, 6, 35, 
    2, 33, 8, 20, 3, 98, 6, 21, 0, 91, 7, 56, 5, 64, 1, 62, 4, 73
  };
  const int q7285[] = {
    9, 9, // Number of jobs and machines
    0, 15, 6, 16, 8, 44, 5, 65, 3, 85, 1, 45, 4,  8, 7, 58, 2, 12, 
    2, 25, 3, 76, 1, 32, 6, 71, 0, 30, 4, 57, 8, 57, 5, 44, 7, 43, 
    5, 54, 2, 77, 7, 79, 6,  7, 4, 64, 0, 66, 8, 65, 1, 60, 3, 88, 
    1,  7, 4, 52, 8,  3, 6, 85, 3, 65, 2, 75, 5, 31, 0, 94, 7, 27, 
    6, 23, 1, 22, 8, 22, 0, 35, 7, 56, 5, 81, 4, 17, 2, 43, 3, 61, 
    2, 61, 1, 58, 5, 83, 7, 74, 6, 11, 0, 82, 4, 68, 8, 25, 3, 81, 
    3, 59, 0, 80, 7, 92, 2, 35, 1, 38, 4, 91, 6, 20, 8, 60, 5, 18, 
    1, 20, 0, 22, 4, 20, 2, 43, 8, 11, 5, 30, 7, 45, 3, 94, 6, 12, 
    4, 35, 0, 18, 1, 85, 8, 99, 3, 82, 5, 28, 2, 68, 6, 95, 7, 37
  };
  const int q7286[] = {
    9, 9, // Number of jobs and machines
    4, 49, 1, 79, 6, 87, 5,  7, 8, 67, 2, 43, 0, 25, 3, 27, 7, 38, 
    1, 23, 3, 69, 0, 70, 6, 88, 5, 53, 7, 77, 4,  5, 2,  2, 8, 14, 
    2, 24, 3, 71, 6, 79, 7, 18, 4, 12, 8, 54, 1, 78, 0, 84, 5, 24, 
    2, 22, 7, 34, 8, 85, 6, 36, 1,  8, 4, 30, 3,  1, 0,  7, 5, 59, 
    0, 83, 8, 40, 6, 11, 1, 91, 3, 53, 4, 89, 7, 83, 2, 69, 5, 24, 
    1, 71, 0, 93, 3, 21, 5, 29, 8,  8, 6,  8, 4, 69, 2,  7, 7, 46, 
    0,  2, 6, 28, 5, 21, 1, 98, 2,  1, 3, 37, 8, 52, 7, 87, 4, 16, 
    8, 35, 2, 29, 4, 94, 7, 32, 6,  4, 3, 82, 0, 75, 5, 73, 1, 29, 
    3,  3, 1, 86, 0, 44, 7, 28, 4, 80, 2, 64, 5, 87, 6, 88, 8, 10
  };
  const int q7287[] = {
    9, 9, // Number of jobs and machines
    4,  1, 6, 31, 5, 89, 8, 20, 2, 74, 0, 45, 1, 41, 3, 86, 7,  6, 
    8, 90, 6, 33, 1, 25, 3, 63, 2, 72, 7, 50, 0, 37, 4, 66, 5, 40, 
    1, 85, 6, 58, 5, 19, 0, 48, 7, 25, 8, 71, 3, 81, 2, 54, 4,  7, 
    1, 23, 5, 61, 3, 25, 2, 45, 6, 78, 0, 22, 7, 75, 4, 64, 8, 29, 
    3, 37, 5, 53, 1, 55, 8, 29, 0, 39, 6, 74, 2, 42, 7, 37, 4, 46, 
    3, 76, 5,  8, 1, 84, 6, 50, 4, 45, 8, 74, 7, 45, 0, 61, 2, 80, 
    5, 70, 0, 66, 1, 14, 4, 36, 3, 31, 7, 67, 8, 20, 2, 33, 6, 31, 
    7, 35, 3, 15, 0, 81, 4, 62, 6, 36, 8, 94, 2, 68, 1, 52, 5,  4, 
    2, 18, 3, 65, 5,  6, 0, 14, 1, 17, 4, 21, 7, 62, 8, 48, 6, 44
  };
  const int q7288[] = {
    9, 9, // Number of jobs and machines
    5, 42, 3, 40, 1, 31, 2, 73, 6, 90, 8, 21, 4,  3, 7, 11, 0, 96, 
    5, 34, 0, 22, 1, 37, 4, 41, 8, 86, 3, 49, 7, 18, 2, 22, 6, 59, 
    4, 71, 2, 99, 1, 32, 6, 59, 8, 33, 0, 13, 7, 82, 5, 44, 3, 49, 
    6, 60, 5, 32, 4, 39, 1,  9, 3, 88, 2,  4, 8, 89, 7, 65, 0, 26, 
    1, 79, 0, 42, 4, 93, 7, 66, 2,  7, 5, 61, 6, 25, 8, 83, 3, 53, 
    3, 95, 4, 81, 7, 43, 0, 50, 6, 22, 8, 95, 1,  8, 2,  7, 5, 83, 
    5, 48, 2, 64, 7, 54, 1, 87, 8, 20, 4, 29, 3, 78, 6, 82, 0, 36, 
    6, 40, 8, 10, 2, 83, 7, 84, 0, 28, 1, 42, 3, 80, 4, 48, 5, 62, 
    7, 68, 0, 99, 3, 41, 2,  2, 8, 11, 4, 33, 6,  2, 5, 57, 1, 18
  };
  const int q7289[] = {
    9, 9, // Number of jobs and machines
    4, 81, 8, 98, 1, 50, 6, 74, 0, 28, 2, 35, 7, 98, 5, 39, 3, 73, 
    7, 81, 5,  7, 1, 66, 6, 33, 0, 88, 4,  1, 3, 92, 8, 21, 2, 27, 
    3, 74, 2, 69, 8, 87, 1,  5, 6, 36, 4, 55, 5, 11, 0, 38, 7, 49, 
    5, 67, 0, 69, 7, 81, 1, 90, 6,  9, 3,  1, 4, 56, 8, 70, 2, 88, 
    2, 51, 7, 53, 4, 52, 3, 85, 8, 67, 5, 31, 6, 45, 1, 65, 0, 61, 
    6, 10, 2, 30, 5, 65, 3, 13, 4, 94, 8, 34, 1, 95, 0, 25, 7, 23, 
    6, 65, 2, 68, 3, 65, 5, 14, 4, 13, 8, 48, 0, 38, 1, 70, 7, 15, 
    1, 24, 2, 28, 4, 29, 6, 32, 3, 54, 8, 13, 0, 74, 7, 68, 5, 10, 
    1, 45, 2, 62, 8, 27, 5, 36, 7,  2, 3, 16, 6, 11, 0, 17, 4, 32
  };
  const int q7290[] = {
    9, 9, // Number of jobs and machines
    2, 24, 1, 23, 7, 67, 5,  5, 4, 80, 0, 22, 8, 58, 6, 27, 3, 54, 
    7,  1, 1, 65, 3, 53, 5, 41, 0,  4, 4, 65, 6, 22, 8, 60, 2, 15, 
    5,  9, 4, 86, 6,  6, 3, 41, 7, 91, 2, 81, 0, 91, 1, 73, 8, 36, 
    7, 78, 4, 53, 2, 51, 3, 91, 8, 70, 5, 58, 6, 81, 0, 76, 1,  1, 
    6, 79, 2, 89, 1, 87, 0, 35, 5, 79, 7, 64, 4, 10, 8, 29, 3, 81, 
    0, 74, 3, 50, 7, 69, 1, 16, 4, 77, 6, 17, 8, 82, 2, 49, 5,  5, 
    4, 83, 5, 65, 1, 19, 2, 66, 0, 47, 3, 94, 8, 24, 6, 91, 7, 45, 
    8, 82, 0, 96, 6, 89, 5, 46, 7, 63, 1, 27, 2, 27, 4,  6, 3, 40, 
    8, 37, 6, 71, 2, 83, 1, 12, 7, 11, 0, 31, 4, 18, 3, 70, 5, 26
  };
  const int q7291[] = {
    9, 9, // Number of jobs and machines
    8, 21, 1, 95, 4, 12, 7, 98, 3, 34, 5, 81, 6, 88, 2, 14, 0, 60, 
    6, 45, 7, 90, 2, 80, 1, 52, 8, 53, 3, 32, 5, 19, 0, 54, 4, 95, 
    4, 36, 7, 85, 0,  8, 3, 83, 1, 92, 8, 54, 5, 79, 2,  4, 6, 42, 
    0, 38, 3, 16, 4, 38, 6, 88, 2, 19, 5, 66, 8, 38, 1, 17, 7, 43, 
    8, 76, 7, 64, 6, 12, 5,  8, 0, 43, 3, 68, 2, 26, 4, 68, 1, 22, 
    2, 40, 1, 71, 8, 53, 3,  4, 6, 82, 0, 25, 4, 91, 5, 17, 7, 51, 
    7,  8, 8, 43, 5, 79, 1, 97, 0, 71, 3, 33, 2, 56, 4,  4, 6,  5, 
    0, 91, 7, 91, 2, 69, 1, 83, 8, 22, 5, 40, 6, 77, 3, 38, 4, 36, 
    8,  1, 3, 58, 2,  5, 0, 17, 4,  8, 1, 57, 5, 23, 7, 24, 6, 46
  };
  const int q7292[] = {
    9, 9, // Number of jobs and machines
    8, 93, 4, 13, 6, 67, 2, 77, 0,  5, 3,  2, 5, 59, 7,  9, 1, 80, 
    7,  7, 8, 29, 4, 62, 3, 71, 2, 67, 1, 95, 6, 40, 5, 65, 0, 80, 
    3, 72, 7, 21, 8, 26, 5, 99, 6, 75, 1, 52, 2, 59, 0, 95, 4, 53, 
    1, 45, 6,  8, 0, 94, 4, 31, 5, 34, 2, 23, 7, 59, 3, 89, 8, 47, 
    5, 88, 6, 60, 1, 16, 3, 71, 2, 39, 0, 80, 4, 91, 7, 78, 8, 64, 
    2, 90, 1, 58, 7, 80, 4, 11, 5, 20, 0, 96, 8, 77, 3, 39, 6, 76, 
    6, 30, 4, 10, 7, 88, 5, 77, 0, 75, 2, 45, 8,  1, 1, 37, 3, 71, 
    5, 43, 7, 15, 8, 67, 3, 10, 6, 18, 2, 68, 0, 44, 4, 76, 1, 68, 
    4, 70, 6, 39, 8,  7, 5, 19, 7, 52, 1, 80, 3, 98, 2, 63, 0, 72
  };
  const int q7293[] = {
    9, 9, // Number of jobs and machines
    2,  2, 5, 29, 0, 92, 6, 60, 4, 52, 8, 47, 1, 92, 7, 99, 3, 39, 
    8, 67, 1, 58, 7, 50, 2, 19, 4, 46, 0,  3, 6, 49, 5, 14, 3, 47, 
    3, 93, 4, 99, 7, 30, 6, 87, 8, 84, 2, 98, 1, 30, 5, 23, 0, 96, 
    1, 63, 7, 75, 5, 95, 4, 19, 8, 72, 6, 25, 2, 78, 3,  9, 0, 12, 
    3, 99, 0, 19, 7, 57, 2, 76, 6, 72, 5, 89, 1, 81, 4, 70, 8, 78, 
    5, 15, 2, 50, 6, 37, 8, 11, 0, 56, 1, 36, 3, 31, 7, 21, 4, 34, 
    7, 88, 4, 93, 1, 55, 8, 63, 3, 58, 2,  5, 6, 37, 0, 64, 5, 15, 
    5, 63, 4, 99, 7, 56, 1, 82, 0, 89, 6,  7, 3, 96, 8, 14, 2, 67, 
    8, 17, 3, 87, 0, 20, 7, 34, 6, 72, 5, 25, 1, 62, 4, 92, 2, 53
  };
  const int q7294[] = {
    9, 9, // Number of jobs and machines
    2, 66, 1, 91, 4, 97, 7,  3, 0, 93, 8, 34, 3, 18, 5, 60, 6, 20, 
    0, 19, 7, 51, 4,  8, 2, 95, 8, 51, 5, 92, 1, 48, 6, 84, 3, 81, 
    4, 96, 6, 24, 2, 12, 0, 33, 8, 85, 5, 88, 7, 34, 3, 86, 1, 94, 
    2, 84, 8, 75, 7, 28, 0, 49, 3, 57, 4, 98, 5, 59, 1, 42, 6, 31, 
    7, 31, 6, 64, 8, 91, 0, 40, 5, 12, 3, 61, 1, 95, 2, 56, 4,  5, 
    4, 98, 2, 61, 7,  5, 8,  5, 3, 16, 5, 39, 6,  6, 1, 88, 0, 32, 
    0, 47, 5, 81, 6, 97, 8, 29, 2, 27, 3, 27, 7, 80, 1, 66, 4, 33, 
    5, 39, 1, 36, 2, 94, 4, 51, 7, 98, 0, 36, 8, 56, 6, 31, 3,  2, 
    0, 42, 2, 33, 7,  2, 8, 49, 6, 48, 5, 88, 1, 54, 3, 58, 4, 23
  };
  const int q7295[] = {
    9, 9, // Number of jobs and machines
    2, 93, 7, 14, 5, 93, 0,  8, 1, 28, 3, 54, 4, 58, 6, 26, 8,  9, 
    7, 98, 1, 33, 2, 59, 4, 99, 0, 61, 8, 21, 3,  8, 5, 78, 6, 78, 
    1, 24, 6, 26, 4, 29, 3, 38, 8, 72, 0, 53, 7, 73, 5,  9, 2, 45, 
    6, 64, 5, 92, 0, 30, 2,  4, 8, 66, 4, 19, 1, 88, 7, 79, 3, 26, 
    3, 75, 8, 22, 0, 22, 6, 16, 2, 60, 5, 36, 4, 65, 7, 50, 1, 48, 
    0, 35, 1, 52, 6, 86, 2, 25, 5, 64, 3, 96, 4, 56, 8, 68, 7, 41, 
    1, 85, 4, 35, 6,  7, 0, 48, 8, 97, 5, 18, 2,  1, 7,  2, 3, 14, 
    1, 82, 3, 49, 8, 94, 5, 54, 6, 43, 2, 40, 0, 86, 4, 97, 7, 90, 
    2, 21, 6, 89, 4, 63, 3, 73, 0, 21, 5,  7, 7, 21, 1, 34, 8,  5
  };
  const int q7296[] = {
    9, 9, // Number of jobs and machines
    4,  5, 1,  9, 6, 55, 8, 71, 5, 24, 7, 93, 0, 36, 2, 71, 3,  4, 
    1, 77, 6,  6, 2, 29, 3, 78, 0, 47, 7, 32, 8, 10, 4, 90, 5, 39, 
    6,  3, 4, 82, 1, 44, 0, 98, 5, 94, 8, 81, 7, 50, 3,  8, 2, 96, 
    3, 25, 6, 58, 4, 37, 1, 71, 5, 20, 7, 29, 8,  8, 0, 25, 2, 56, 
    6, 99, 8, 39, 4, 80, 7, 40, 1, 96, 2,  6, 0, 71, 5, 55, 3, 81, 
    7, 74, 3,  8, 1, 82, 8, 22, 2,  9, 6, 98, 5,  5, 0, 54, 4, 55, 
    8, 24, 3, 81, 1, 92, 0, 16, 7, 11, 2, 55, 4, 74, 5, 26, 6, 91, 
    0, 58, 5, 65, 8, 60, 1, 91, 4, 93, 3, 95, 6, 30, 7, 82, 2, 45, 
    3, 40, 1, 71, 0,  3, 5,  2, 6, 79, 7, 74, 8, 47, 4, 59, 2, 14
  };
  const int q7297[] = {
    9, 9, // Number of jobs and machines
    1, 78, 0, 68, 2, 75, 6, 96, 3, 78, 4, 96, 5,  9, 8, 61, 7, 49, 
    8, 51, 6, 67, 7, 58, 1,  5, 5, 43, 3, 43, 2, 73, 4, 23, 0, 91, 
    0, 86, 8, 87, 5, 46, 2, 75, 3, 88, 1, 15, 4, 37, 6, 62, 7, 46, 
    1, 87, 5, 34, 0, 98, 7, 15, 6, 51, 8, 72, 4,  3, 3, 80, 2,  3, 
    5, 64, 6, 34, 0, 12, 2, 31, 8, 23, 1, 86, 7, 42, 3, 16, 4, 82, 
    0, 90, 6, 51, 8, 64, 4, 32, 5, 10, 1, 89, 3, 20, 7, 20, 2, 88, 
    6, 96, 4, 81, 5, 11, 3, 65, 1, 78, 8, 33, 2,  6, 0, 96, 7, 40, 
    2, 90, 0, 43, 8, 57, 5, 41, 7, 42, 3, 60, 6, 68, 4,  4, 1, 50, 
    2, 71, 4, 37, 0, 76, 1,  9, 6, 14, 8, 23, 7, 73, 3, 77, 5, 22
  };
  const int q7298[] = {
    9, 9, // Number of jobs and machines
    2, 61, 3,  5, 0, 38, 7, 74, 4, 47, 5, 33, 8, 18, 1, 85, 6,  5, 
    7, 19, 0, 90, 8, 78, 5, 16, 2, 11, 1, 70, 3, 87, 4, 58, 6, 75, 
    1, 50, 2, 96, 8, 24, 7, 50, 4, 92, 5, 83, 3, 12, 0, 77, 6, 47, 
    0, 70, 6, 28, 2, 20, 5, 30, 7, 32, 4, 76, 3, 34, 8, 64, 1, 98, 
    1, 59, 2, 99, 4, 37, 5,  2, 0, 14, 8, 44, 7, 29, 3, 59, 6, 61, 
    3,  5, 0, 73, 2, 45, 8, 21, 6, 92, 1, 89, 7, 87, 4, 80, 5, 80, 
    8, 83, 1, 91, 2, 69, 6, 25, 4, 92, 3, 74, 5, 25, 7, 77, 0, 74, 
    3, 39, 8, 58, 7, 61, 1, 86, 0, 62, 2, 78, 6, 96, 4, 49, 5, 43, 
    2, 18, 3, 19, 1, 68, 7, 79, 6,  9, 4, 94, 0, 11, 8, 28, 5, 71
  };
  const int q7299[] = {
    9, 9, // Number of jobs and machines
    7, 89, 8,  4, 0, 53, 2, 39, 3, 14, 1, 32, 5, 31, 6, 99, 4,  6, 
    1, 87, 6, 79, 3, 45, 7, 14, 0, 42, 2, 33, 8, 84, 4, 27, 5, 84, 
    7,  2, 5, 39, 8, 27, 2,  7, 0, 39, 3, 81, 4, 29, 6, 95, 1, 96, 
    7, 89, 5, 97, 6, 85, 1, 23, 0, 32, 8, 48, 3, 74, 4, 50, 2, 42, 
    3,  2, 0, 85, 5, 71, 8, 43, 7, 66, 6,  4, 1, 11, 2, 49, 4, 20, 
    5, 74, 1, 60, 7, 97, 2, 95, 3, 54, 0, 24, 8, 53, 6, 88, 4, 98, 
    3, 19, 5, 21, 4, 92, 7, 95, 8, 24, 1, 24, 2, 61, 0, 62, 6, 62, 
    0, 32, 5, 62, 6, 12, 8, 37, 1, 98, 3, 76, 4, 68, 7, 10, 2, 37, 
    8, 61, 3, 32, 7, 62, 5, 56, 4, 28, 0, 45, 1, 45, 6, 63, 2, 63
  };
  const int q7300[] = {
    9, 9, // Number of jobs and machines
    7,  1, 2, 55, 4, 95, 8, 63, 1, 34, 6, 41, 0, 16, 3, 47, 5, 12, 
    6, 10, 4, 76, 5,  2, 3, 59, 2, 58, 8, 68, 7, 60, 1, 23, 0, 67, 
    3, 29, 4, 56, 8, 91, 6, 25, 7, 61, 1, 51, 2, 66, 0, 91, 5,  5, 
    5,  6, 6, 40, 1, 95, 0, 87, 3, 37, 2, 55, 4, 60, 8, 32, 7, 98, 
    3, 66, 2, 34, 1, 83, 0,  4, 7, 86, 4, 62, 6, 82, 5, 75, 8, 11, 
    2, 96, 6, 17, 4, 15, 1,  4, 8, 82, 3, 66, 7, 97, 0,  8, 5, 35, 
    2, 32, 5, 59, 1, 62, 6, 32, 3, 45, 7, 14, 4, 14, 0, 70, 8, 51, 
    4, 59, 6, 66, 7, 50, 0, 22, 8, 28, 2, 10, 5, 79, 1, 42, 3, 51, 
    0, 79, 6, 40, 3,  3, 1, 73, 7, 53, 4, 76, 2, 78, 8, 32, 5, 37
  };
  const int q7301[] = {
    9, 9, // Number of jobs and machines
    7, 30, 2, 42, 5, 51, 0, 42, 4, 95, 8, 89, 6, 39, 1, 53, 3, 29, 
    7, 75, 1, 72, 4, 30, 0, 19, 3, 32, 8, 29, 2, 27, 5, 35, 6, 66, 
    8, 17, 7, 31, 2, 28, 3,  4, 1,  4, 0, 21, 4, 73, 5, 92, 6, 79, 
    4, 31, 5, 88, 7, 57, 6, 26, 8, 85, 0, 36, 3, 63, 1, 26, 2,  2, 
    2, 54, 4, 23, 8, 35, 5, 72, 3, 63, 0, 13, 7, 64, 1, 83, 6, 94, 
    7,  6, 3,  6, 2, 36, 8, 48, 6, 18, 1, 74, 0, 10, 4, 89, 5, 76, 
    3, 75, 4, 11, 0, 88, 7, 58, 8, 45, 5, 59, 2, 35, 6, 70, 1, 89, 
    2, 71, 1, 64, 3, 99, 5, 52, 7, 29, 6, 19, 8, 74, 4,  5, 0, 10, 
    8, 58, 1, 91, 2, 71, 6, 27, 0, 52, 4, 74, 5, 83, 3, 56, 7, 45
  };
  const int q7302[] = {
    9, 9, // Number of jobs and machines
    2, 46, 7, 94, 5,  3, 3, 82, 8, 84, 4, 62, 0, 79, 1, 63, 6, 13, 
    3, 73, 8, 21, 0, 84, 7, 37, 1, 63, 5, 42, 6, 67, 4, 43, 2, 36, 
    0, 88, 5, 23, 6, 94, 8, 28, 1, 13, 3, 34, 2,  1, 4, 99, 7, 95, 
    4, 96, 3, 95, 0, 86, 1, 33, 6,  7, 2, 15, 7, 30, 5,  9, 8,  9, 
    8, 83, 4, 23, 7, 89, 3, 31, 5, 82, 6, 90, 1, 29, 2, 16, 0, 21, 
    2, 10, 1, 67, 8, 66, 7, 38, 5, 60, 3, 11, 6, 43, 4, 22, 0,  4, 
    7, 48, 1, 40, 0, 49, 8, 81, 5, 19, 4, 71, 2,  2, 6,  3, 3, 17, 
    8, 33, 3, 78, 5, 93, 0,  9, 7, 12, 4, 68, 6, 89, 1, 34, 2, 42, 
    2, 65, 3, 44, 0, 79, 5,  2, 1, 51, 7, 68, 8, 69, 6,  5, 4, 11
  };
  const int q7303[] = {
    9, 9, // Number of jobs and machines
    0, 11, 1, 43, 2, 33, 5, 62, 8, 12, 6, 96, 3, 25, 4, 54, 7, 21, 
    5, 49, 4, 66, 0, 14, 6, 11, 1, 91, 8,  4, 2, 16, 3,  4, 7, 54, 
    1,  6, 3, 30, 0, 69, 6, 83, 2, 63, 7, 68, 8, 29, 5, 33, 4, 47, 
    4, 55, 8, 89, 3, 16, 0, 49, 2,  3, 6, 85, 1,  5, 5, 63, 7, 53, 
    4, 60, 2, 29, 6, 49, 3, 71, 1,  7, 5, 35, 0, 54, 7, 99, 8, 48, 
    8, 57, 2, 88, 5, 78, 6, 61, 7, 24, 4, 68, 0, 48, 3, 60, 1, 80, 
    8, 64, 7, 17, 0, 22, 4, 12, 1, 59, 2, 82, 3, 55, 6, 23, 5, 69, 
    6, 90, 4, 27, 7, 45, 0,  6, 1, 89, 5,  1, 8, 58, 3, 28, 2,  9, 
    5, 86, 8, 39, 2, 65, 7, 95, 4, 87, 0, 70, 6, 18, 1, 53, 3, 30
  };
  const int q7304[] = {
    9, 9, // Number of jobs and machines
    6, 44, 3, 15, 4, 98, 1, 55, 8, 45, 0,  6, 5, 53, 2, 47, 7, 84, 
    2, 63, 8, 49, 1, 12, 5, 36, 3, 55, 6, 99, 0, 81, 7, 27, 4, 64, 
    6, 90, 0, 92, 2, 65, 7,  7, 1, 48, 5, 29, 4, 59, 8,  1, 3, 63, 
    1, 42, 5, 57, 2, 42, 6,  6, 7, 29, 3, 73, 4, 75, 0, 85, 8,  3, 
    1, 34, 4,  6, 5,  1, 8, 87, 2, 36, 7, 12, 6, 89, 0, 52, 3, 18, 
    8, 95, 3, 62, 0, 67, 5, 16, 6, 14, 7, 11, 4, 78, 2,  5, 1, 96, 
    3, 11, 5, 56, 6,  4, 8, 87, 7, 98, 1, 91, 2, 37, 4, 47, 0, 32, 
    1, 88, 3, 77, 4, 27, 2, 23, 0, 44, 8, 24, 6, 81, 7, 45, 5, 43, 
    4,  8, 2, 52, 5, 87, 8, 10, 1, 92, 3, 94, 0, 86, 6, 41, 7, 13
  };
  const int q7305[] = {
    9, 9, // Number of jobs and machines
    7, 58, 1, 75, 6, 82, 4,  6, 2, 95, 5, 42, 3, 73, 0, 37, 8, 42, 
    1, 57, 6, 13, 4,  8, 3, 17, 7,  6, 8, 56, 5, 94, 0,  6, 2, 59, 
    2, 90, 4, 37, 6, 18, 7, 86, 5, 82, 3, 49, 0, 38, 1, 55, 8, 44, 
    8,  8, 7, 31, 0, 79, 6, 71, 1,  6, 5, 88, 2, 58, 3, 68, 4, 61, 
    4, 24, 5, 19, 6, 11, 7, 83, 1, 10, 2, 39, 8, 45, 3, 52, 0, 11, 
    7, 16, 0, 85, 3, 76, 4, 69, 8, 54, 6, 61, 5, 18, 1, 72, 2,  1, 
    0, 24, 5, 33, 2, 92, 3, 46, 8, 38, 1,  4, 4, 18, 7, 75, 6, 74, 
    0, 94, 4, 90, 1, 11, 8, 92, 2, 11, 5, 30, 3, 12, 7, 63, 6, 91, 
    6, 40, 5, 45, 0,  6, 8, 73, 2, 99, 3, 30, 1, 29, 7, 26, 4, 17
  };
  const int q7306[] = {
    9, 9, // Number of jobs and machines
    8, 29, 3, 90, 2, 26, 4, 86, 0, 74, 6, 63, 7,  3, 1, 52, 5, 28, 
    4,  9, 5,  9, 0, 15, 1, 72, 6,  3, 7, 83, 3, 89, 2, 11, 8, 41, 
    8, 44, 5, 89, 1, 32, 2, 85, 6, 71, 0, 28, 7, 12, 4, 29, 3, 57, 
    5, 47, 1, 40, 2, 77, 4, 33, 0, 89, 3, 87, 7, 35, 6, 98, 8,  3, 
    3, 60, 0, 81, 5, 52, 1, 12, 8, 98, 2, 87, 7, 98, 6, 69, 4,  7, 
    3,  9, 8,  3, 2, 86, 1,  3, 5, 88, 6, 27, 7, 68, 4, 61, 0, 70, 
    3, 98, 5, 80, 7, 65, 2, 32, 6, 37, 8, 65, 0, 12, 1, 16, 4, 12, 
    6,  3, 3, 85, 5, 95, 0, 32, 7, 98, 1, 39, 8, 68, 4,  7, 2, 59, 
    4, 18, 8, 13, 6, 54, 0, 91, 2, 46, 1, 64, 7, 96, 3, 43, 5, 11
  };
  const int q7307[] = {
    9, 9, // Number of jobs and machines
    3, 69, 5,  3, 7, 42, 1, 26, 0, 16, 8, 89, 4, 84, 2, 54, 6, 80, 
    0, 86, 3, 75, 6, 89, 7, 37, 5, 26, 4, 49, 2, 66, 1, 88, 8, 11, 
    8, 55, 1, 70, 0, 40, 5, 97, 4, 65, 7,  8, 6, 42, 2, 59, 3, 50, 
    3, 32, 0, 10, 2, 66, 8, 56, 6, 44, 5, 56, 1, 28, 7, 78, 4, 78, 
    4, 14, 2, 75, 0, 91, 8, 80, 7, 71, 5, 83, 3, 53, 1, 29, 6, 11, 
    2, 80, 3, 63, 5, 51, 4, 34, 0, 38, 1, 17, 8, 71, 7, 50, 6, 13, 
    1, 59, 3, 97, 6, 66, 7, 78, 8, 22, 0, 70, 5,  4, 2, 68, 4, 52, 
    1, 91, 4, 18, 6, 71, 5, 18, 8, 59, 7, 21, 3, 64, 2, 96, 0,  1, 
    4, 75, 8, 43, 2, 52, 3, 39, 1, 44, 5, 19, 7, 66, 0, 47, 6, 29
  };
  const int q7308[] = {
    9, 9, // Number of jobs and machines
    6, 54, 2, 90, 5, 88, 8, 45, 1, 72, 4, 96, 0,  2, 3, 44, 7, 38, 
    3, 10, 2, 34, 5, 19, 8, 36, 7, 81, 4, 61, 0, 88, 1,  2, 6, 79, 
    2, 46, 7, 85, 4, 16, 1, 99, 8, 46, 3,  3, 6, 61, 5, 97, 0, 29, 
    1, 71, 6, 71, 2, 99, 3, 83, 4, 86, 0, 58, 5, 39, 8,  9, 7, 86, 
    8, 49, 5, 31, 1, 32, 3, 66, 7, 30, 2,  2, 4, 53, 0, 34, 6, 11, 
    6, 81, 5, 73, 1, 56, 2, 26, 0, 68, 8, 51, 7,  7, 3, 64, 4, 31, 
    7, 35, 3, 91, 4, 19, 2, 66, 8, 20, 1, 71, 0, 43, 5,  7, 6, 14, 
    0, 69, 6, 70, 2, 71, 7, 30, 1,  8, 5, 59, 4,  5, 8, 63, 3, 34, 
    4, 48, 5, 88, 2, 86, 8, 73, 6, 56, 1, 85, 0, 77, 7, 85, 3,  5
  };
  const int q7309[] = {
    9, 9, // Number of jobs and machines
    4, 20, 5, 82, 0,  2, 1, 75, 3, 96, 6, 38, 7, 88, 2, 23, 8, 21, 
    3, 66, 1,  5, 6,  2, 2, 75, 0, 37, 8, 27, 4,  3, 7, 91, 5,  7, 
    1, 91, 0, 68, 6, 85, 7, 22, 3, 10, 8, 33, 5, 60, 2, 10, 4, 33, 
    8, 79, 3,  4, 2, 30, 7, 90, 6,  5, 1, 96, 5,  8, 0, 58, 4, 35, 
    8,  3, 4, 14, 3, 58, 6, 93, 2, 11, 0, 66, 1, 46, 7,  4, 5, 33, 
    3, 26, 7,  8, 5, 44, 4, 23, 6, 91, 0, 80, 1, 27, 2, 37, 8, 81, 
    5, 33, 0,  7, 8, 26, 7, 38, 6, 41, 4,  4, 1, 49, 2,  6, 3, 55, 
    4, 63, 8, 88, 3, 65, 5, 71, 0, 45, 1,  4, 2, 70, 6, 14, 7, 74, 
    5, 46, 4,  6, 1, 74, 7, 58, 8, 29, 2, 63, 3, 31, 0,  6, 6,  5
  };
  const int q7310[] = {
    9, 9, // Number of jobs and machines
    7, 90, 3, 34, 1, 41, 4, 58, 5,  3, 0, 32, 8, 86, 2, 91, 6, 87, 
    1, 97, 8, 62, 7, 64, 3, 10, 4, 28, 0, 10, 5, 81, 2, 20, 6, 14, 
    8, 63, 1, 18, 5, 54, 7, 35, 3, 75, 4, 31, 0, 77, 6, 19, 2, 42, 
    2, 99, 6, 21, 7, 74, 1, 53, 3, 40, 5, 86, 0, 66, 4, 94, 8, 25, 
    5, 39, 3, 40, 0, 13, 2, 39, 8,  4, 4, 56, 1, 70, 7, 21, 6, 79, 
    0, 98, 5, 92, 2, 29, 6, 33, 4, 61, 7, 89, 1,  1, 8, 12, 3, 96, 
    6, 74, 4, 56, 5, 71, 7, 34, 8, 16, 0, 50, 3, 52, 2, 69, 1, 25, 
    6, 63, 2, 76, 3, 41, 5, 72, 7, 37, 1, 97, 8, 65, 4, 41, 0, 64, 
    5, 86, 3, 44, 4, 45, 1, 99, 7, 11, 0, 61, 2, 21, 8, 32, 6,  2
  };
  const int q7311[] = {
    9, 9, // Number of jobs and machines
    5,  1, 2, 73, 1, 19, 7, 88, 3, 11, 4,  7, 8, 98, 6, 49, 0, 23, 
    7, 79, 4, 56, 8, 98, 6, 23, 2,  3, 0, 61, 3,  2, 5, 26, 1, 44, 
    1, 25, 8, 85, 2, 90, 4,  2, 3, 64, 0, 95, 6, 62, 5, 97, 7, 23, 
    7,  2, 8, 93, 6, 80, 3, 18, 0,  7, 1, 67, 4, 53, 5,  7, 2, 40, 
    1, 14, 2, 58, 4, 84, 8, 73, 7, 90, 0, 72, 5, 11, 6, 34, 3, 44, 
    3, 90, 8, 74, 1, 48, 2, 75, 5, 72, 6, 97, 4, 14, 0, 37, 7, 17, 
    0, 55, 4,  4, 6, 23, 1, 28, 8, 62, 3, 12, 7, 84, 2, 75, 5, 93, 
    0, 72, 6,  2, 7, 35, 2, 22, 5, 43, 8, 90, 1, 53, 4, 82, 3,  1, 
    0,  7, 7, 66, 3, 20, 5, 28, 1, 76, 6, 59, 2, 99, 8, 98, 4, 82
  };
  const int q7312[] = {
    9, 9, // Number of jobs and machines
    6, 69, 4, 58, 0, 55, 1, 85, 8, 11, 5, 52, 2, 12, 3, 47, 7, 46, 
    3, 15, 8,  7, 5, 70, 2, 16, 1, 26, 4, 94, 7,  6, 0,  8, 6,  9, 
    5, 54, 7,  7, 3,  1, 4, 16, 1, 54, 8, 35, 0, 87, 2, 75, 6,  8, 
    2, 44, 1, 56, 7, 87, 0, 36, 5, 88, 8, 92, 6, 90, 3, 58, 4, 74, 
    8, 76, 5, 49, 1, 88, 3, 56, 7, 89, 4, 40, 2, 86, 6, 44, 0, 21, 
    3, 47, 5, 86, 2, 11, 8, 82, 1, 59, 6, 72, 0, 94, 4, 30, 7, 61, 
    6, 72, 4, 81, 7, 56, 5, 38, 8, 17, 2, 31, 3, 96, 1, 71, 0, 80, 
    0, 57, 1, 46, 7, 21, 2, 80, 6, 50, 8,  1, 4, 21, 3, 55, 5, 19, 
    1, 43, 5,  1, 0, 99, 8, 87, 3, 43, 4,  7, 7, 68, 6,  7, 2, 62
  };
  const int q7313[] = {
    9, 9, // Number of jobs and machines
    8,  2, 7, 92, 5, 50, 2,  3, 6,  5, 0, 54, 3, 90, 1, 57, 4, 36, 
    0, 85, 3, 30, 5, 52, 2, 65, 1, 26, 4, 20, 6, 47, 7, 19, 8, 93, 
    2, 73, 5, 28, 6, 84, 3, 82, 1, 75, 4, 11, 7, 18, 0, 11, 8, 15, 
    5, 90, 0, 15, 2, 21, 6, 33, 8, 23, 3, 92, 1, 50, 4, 16, 7, 47, 
    0, 34, 8,  1, 4, 60, 3, 99, 6,  2, 2, 33, 1, 73, 5, 27, 7, 15, 
    1, 20, 6, 83, 5, 23, 4, 51, 2, 65, 0, 31, 7, 41, 3, 23, 8, 73, 
    2, 89, 3, 62, 6, 20, 7, 75, 8, 94, 1, 38, 5,  3, 0, 66, 4, 19, 
    0, 64, 2, 61, 6, 90, 8, 11, 1, 88, 5, 17, 4, 37, 7, 39, 3, 85, 
    8, 41, 7, 37, 1, 50, 0, 68, 6, 15, 3,  7, 4, 94, 5, 11, 2,  6
  };
  const int q7314[] = {
    9, 9, // Number of jobs and machines
    0, 63, 3, 29, 2, 35, 5, 23, 6, 89, 8, 80, 1, 50, 7, 32, 4,  9, 
    8, 72, 0, 10, 2, 72, 7, 17, 1, 33, 6, 14, 3, 38, 4, 28, 5, 55, 
    7,  1, 8,  9, 2, 49, 6, 83, 3, 16, 0, 34, 4,  6, 1, 78, 5, 32, 
    0, 16, 3, 12, 6, 16, 7, 40, 1, 97, 5, 76, 8, 82, 4, 85, 2, 82, 
    2, 31, 3, 41, 7, 16, 1, 30, 0, 35, 4, 22, 8, 48, 5, 66, 6,  9, 
    8, 87, 4, 56, 7, 59, 6, 26, 3, 84, 2, 85, 5, 92, 1, 83, 0, 64, 
    8, 55, 0, 79, 2,  5, 3, 68, 1, 69, 7,  7, 4, 80, 5, 70, 6,  9, 
    3, 28, 6, 92, 7, 92, 2, 67, 8, 73, 1, 46, 0, 82, 5, 87, 4, 61, 
    2, 91, 7, 74, 4, 10, 6, 48, 8, 10, 0, 57, 5,  1, 1, 57, 3, 90
  };
  const int q7315[] = {
    9, 9, // Number of jobs and machines
    1, 48, 8, 13, 2, 62, 3, 96, 6, 17, 0, 77, 5, 86, 4, 84, 7, 25, 
    1, 99, 2, 46, 3, 65, 7, 82, 8, 71, 6, 86, 5, 52, 0, 45, 4, 31, 
    3, 35, 0, 12, 5, 90, 1, 44, 8, 68, 2, 44, 4, 62, 7, 53, 6, 67, 
    5, 17, 3, 88, 6, 26, 0, 78, 4,  7, 8, 32, 7, 42, 1, 37, 2, 12, 
    8, 34, 3, 78, 0, 54, 2, 67, 6, 76, 7, 90, 4, 95, 5, 16, 1, 25, 
    3, 93, 7, 84, 8, 87, 0, 37, 5, 67, 4, 77, 6, 83, 2, 47, 1,  6, 
    1, 26, 7, 67, 3, 91, 0, 49, 6, 61, 4, 51, 8, 24, 2, 95, 5, 28, 
    5, 21, 8, 46, 2,  5, 1, 34, 7,  6, 6, 74, 3, 97, 0, 31, 4, 38, 
    3, 74, 0, 89, 4, 18, 2, 31, 1, 75, 8, 34, 7, 56, 6, 58, 5, 80
  };
  const int q7316[] = {
    9, 9, // Number of jobs and machines
    8, 85, 1, 70, 6, 58, 7, 28, 0, 19, 4, 56, 3, 21, 5, 30, 2, 29, 
    7, 83, 2, 46, 4, 39, 3, 94, 5, 91, 6, 31, 0, 10, 1, 91, 8, 59, 
    4, 16, 0, 46, 2, 76, 3, 78, 5, 70, 1, 42, 6, 72, 8, 57, 7, 53, 
    6, 20, 7, 93, 4, 62, 5,  1, 2, 84, 3, 78, 1, 20, 8, 50, 0,  9, 
    8, 20, 6, 78, 5, 16, 3, 87, 0, 35, 4, 34, 7, 66, 2,  9, 1, 66, 
    7, 18, 8, 61, 3, 45, 1, 91, 6, 63, 4, 55, 2, 30, 5, 15, 0, 26, 
    1, 49, 6, 51, 5,  8, 3, 17, 0, 61, 7, 61, 4, 89, 8, 95, 2, 46, 
    5, 61, 4, 19, 6, 86, 7, 11, 3, 40, 1, 92, 2, 58, 0, 87, 8, 12, 
    2, 22, 8, 38, 6, 87, 1, 36, 3, 61, 5, 56, 0, 27, 4, 11, 7, 68
  };
  const int q7317[] = {
    9, 9, // Number of jobs and machines
    0, 13, 7, 56, 4, 56, 3, 14, 2, 83, 8, 24, 1, 66, 6, 85, 5, 45, 
    4, 56, 3, 91, 7, 94, 1, 29, 2, 93, 8, 30, 5, 57, 6, 60, 0,  6, 
    7, 86, 3, 79, 1, 48, 8, 52, 0, 64, 5, 35, 4, 79, 6, 83, 2, 93, 
    2, 50, 3, 24, 1, 54, 8, 21, 6, 96, 0, 56, 5, 31, 7, 56, 4, 72, 
    7, 38, 4, 42, 2, 99, 1, 17, 0, 77, 5, 28, 3,  7, 6, 95, 8, 22, 
    4, 55, 8, 58, 1, 42, 3,  3, 2, 56, 5, 64, 0, 56, 7,  2, 6, 55, 
    0, 57, 4, 61, 5, 25, 7, 81, 2, 15, 3, 90, 8, 87, 1, 20, 6, 41, 
    3, 99, 2, 79, 4, 90, 8, 95, 1, 73, 7, 24, 5, 35, 6, 78, 0, 31, 
    2, 70, 0, 86, 3, 30, 5, 30, 7, 24, 6, 64, 8, 26, 1, 41, 4, 68
  };
  const int q7318[] = {
    9, 9, // Number of jobs and machines
    2, 55, 4,  7, 0, 31, 6, 22, 1, 32, 8, 47, 7, 49, 5, 51, 3, 83, 
    5, 15, 4, 94, 1, 21, 8, 23, 3, 69, 7, 46, 6, 52, 0, 85, 2, 66, 
    5, 28, 4, 76, 1, 53, 8, 26, 3,  5, 6, 60, 0, 79, 7, 54, 2, 33, 
    6, 35, 7, 63, 1, 24, 0, 12, 4, 41, 3, 71, 5, 28, 2, 81, 8, 96, 
    5, 90, 4, 20, 1,  8, 3, 17, 7, 91, 0, 20, 6,  5, 8, 18, 2, 19, 
    1, 54, 4, 38, 6,  8, 8,  4, 5, 22, 7, 76, 3, 75, 0, 28, 2, 36, 
    1, 77, 8, 67, 2, 34, 4, 88, 7,  9, 6, 52, 3, 91, 5, 40, 0, 41, 
    5, 10, 1, 67, 2, 42, 0, 34, 7, 27, 4, 47, 3, 43, 6, 56, 8, 49, 
    4, 41, 3, 76, 7,  9, 8,  3, 5, 17, 0, 71, 1, 80, 2, 41, 6, 88
  };
  const int q7319[] = {
    9, 9, // Number of jobs and machines
    3, 47, 4, 75, 6, 51, 2, 22, 0, 41, 1, 78, 8, 85, 7, 20, 5, 45, 
    8, 38, 7, 18, 2, 74, 3,  4, 4, 56, 5, 30, 1, 20, 0, 37, 6, 87, 
    1, 30, 5, 60, 7, 83, 3, 38, 6, 79, 0, 35, 4, 14, 8, 65, 2, 59, 
    3,  4, 6, 27, 0,  7, 1, 42, 8, 38, 5, 94, 4, 82, 7, 22, 2, 53, 
    4, 52, 8, 46, 5, 19, 1, 44, 6, 42, 7, 33, 0, 95, 2, 58, 3, 77, 
    2, 56, 0, 92, 4, 79, 5, 60, 8, 26, 6,  1, 3, 22, 7, 17, 1, 42, 
    1, 44, 8, 44, 4, 49, 6, 95, 5, 33, 7, 24, 2, 62, 3, 67, 0, 33, 
    0, 59, 6, 19, 4, 87, 1, 12, 8, 39, 5, 32, 3, 97, 2, 91, 7, 25, 
    1, 53, 2, 23, 4,  6, 8, 30, 3, 29, 0,  5, 7, 18, 6, 53, 5, 69
  };
  const int q7320[] = {
    9, 9, // Number of jobs and machines
    6, 56, 4, 47, 7, 83, 0, 80, 5, 79, 3, 81, 8,  6, 1, 39, 2, 52, 
    2, 18, 6, 45, 8, 36, 3, 27, 7, 19, 1, 33, 0, 51, 5, 98, 4, 86, 
    7, 25, 3, 26, 2,  5, 6, 75, 5, 23, 8, 15, 4,  2, 1, 70, 0, 77, 
    7, 80, 3, 40, 4, 45, 8, 97, 2, 73, 1,  5, 6, 94, 0, 38, 5, 39, 
    0, 59, 3, 67, 2, 15, 5, 61, 6, 72, 1, 58, 7, 30, 4, 93, 8,  5, 
    2,  8, 3, 33, 6, 12, 7, 92, 1, 99, 0, 92, 4, 50, 5, 70, 8, 23, 
    4, 59, 7, 16, 5, 34, 6, 96, 8, 51, 3, 44, 2, 19, 1, 99, 0, 13, 
    5, 38, 0, 96, 7, 34, 2, 23, 3, 78, 8, 65, 1, 58, 4, 99, 6, 36, 
    4, 20, 2, 18, 8, 61, 3, 70, 0, 71, 6, 38, 1, 67, 5, 49, 7, 75
  };
  const int q7321[] = {
    9, 9, // Number of jobs and machines
    0, 90, 3, 69, 5,  3, 6, 71, 4,  5, 7, 20, 1, 87, 8,  4, 2, 66, 
    3, 31, 0, 50, 1, 63, 2, 12, 4, 47, 6,  6, 5, 19, 8, 44, 7, 82, 
    0, 48, 6, 86, 2, 54, 5,  4, 8, 24, 3, 59, 4,  7, 7, 13, 1, 86, 
    3, 58, 2, 64, 8, 48, 6, 50, 4, 85, 1, 87, 5, 90, 0, 34, 7, 61, 
    7,  2, 3, 97, 4, 29, 8, 95, 0,  7, 2, 10, 5, 25, 6, 84, 1, 48, 
    7, 91, 0,  3, 2, 45, 5, 68, 1, 23, 3, 64, 6, 75, 8, 13, 4, 30, 
    8, 30, 7, 68, 2,  2, 3, 57, 4, 15, 6, 51, 0,  8, 5, 33, 1, 11, 
    0, 38, 1, 93, 6, 46, 4, 97, 7, 50, 5,  3, 2, 53, 8, 61, 3, 67, 
    6, 46, 3, 36, 2, 78, 4, 84, 8, 84, 1, 42, 7, 85, 0, 73, 5, 77
  };
  const int q7322[] = {
    9, 9, // Number of jobs and machines
    4, 39, 3, 90, 0, 80, 5, 39, 7, 86, 2, 11, 6, 34, 8,  3, 1, 22, 
    3, 98, 6, 55, 0, 94, 7, 25, 8, 53, 4, 31, 5, 16, 1, 50, 2, 18, 
    6, 23, 8, 40, 7,  4, 0, 86, 2, 25, 4, 72, 1, 52, 5, 49, 3, 48, 
    0, 62, 3, 35, 5, 49, 7, 87, 4,  6, 8, 90, 6, 98, 1, 98, 2, 76, 
    0, 56, 1,  1, 3, 41, 4, 35, 5, 36, 2, 91, 6, 41, 7, 93, 8, 40, 
    7, 42, 6, 13, 5, 71, 8, 12, 4, 99, 1, 24, 2, 14, 3, 88, 0, 54, 
    0, 77, 5, 15, 1, 39, 3,  1, 4, 11, 7, 83, 2, 77, 8, 36, 6, 49, 
    1,  3, 4, 46, 7, 93, 2, 16, 5, 40, 0, 54, 3, 76, 8, 27, 6, 34, 
    2, 56, 4, 33, 3, 98, 0, 67, 5, 93, 7, 10, 8, 98, 6, 17, 1, 34
  };
  const int q7323[] = {
    9, 9, // Number of jobs and machines
    2, 99, 1, 31, 6, 35, 3, 89, 8, 58, 4, 78, 5, 34, 7, 60, 0, 95, 
    7, 79, 4, 75, 8, 30, 3, 10, 6, 14, 2,  4, 1, 78, 0, 62, 5, 37, 
    6, 68, 2, 54, 5, 61, 3, 53, 8, 32, 4, 54, 7, 23, 1,  6, 0, 40, 
    5, 60, 2, 50, 6, 24, 7, 74, 4, 16, 3, 26, 1, 96, 0, 37, 8, 18, 
    1, 21, 7, 83, 6, 20, 3, 66, 0, 36, 8, 21, 5, 83, 2, 17, 4, 71, 
    2, 46, 8,  6, 6, 21, 4, 59, 1, 13, 7, 64, 3, 77, 0, 58, 5, 79, 
    7, 83, 8, 52, 3, 46, 5, 40, 4, 58, 6, 55, 1, 91, 2, 89, 0, 56, 
    6, 85, 1, 81, 2, 45, 0, 95, 8, 38, 5, 98, 3, 22, 7,  4, 4, 26, 
    7,  9, 5, 61, 3, 86, 2, 31, 6, 32, 0, 64, 4, 91, 1, 72, 8, 82
  };
  const int q7324[] = {
    9, 9, // Number of jobs and machines
    3, 16, 4, 83, 7, 36, 0, 57, 8, 91, 5, 47, 2, 70, 1, 52, 6, 27, 
    6, 79, 0, 37, 2, 91, 5, 42, 1, 90, 4, 99, 7, 41, 8, 53, 3, 72, 
    5, 11, 8,  1, 4, 96, 0, 40, 7,  9, 1, 27, 2, 23, 3, 92, 6,  9, 
    5, 55, 3, 42, 6, 80, 1, 44, 4, 82, 2, 35, 7, 93, 0, 46, 8,  2, 
    8, 92, 0, 11, 2,  6, 7,  2, 4, 85, 5, 95, 6, 36, 1, 86, 3, 82, 
    1, 84, 2, 75, 8, 11, 5, 61, 3, 30, 6, 60, 7, 88, 0, 61, 4, 30, 
    3, 30, 7, 87, 2, 10, 4, 69, 6, 73, 1, 14, 5, 68, 8, 79, 0, 31, 
    6, 33, 8,  5, 3, 38, 1, 28, 7, 41, 0, 23, 2, 67, 5, 84, 4, 85, 
    7, 94, 8, 94, 5, 19, 1, 80, 6, 73, 4, 94, 3, 51, 2, 64, 0, 20
  };
  const int q7325[] = {
    9, 9, // Number of jobs and machines
    7, 99, 2, 84, 1, 99, 8, 31, 3, 83, 5, 35, 6,  9, 4, 57, 0, 25, 
    2, 84, 1,  4, 4, 10, 3, 45, 5, 30, 7, 67, 8,  9, 0,  3, 6, 29, 
    4, 67, 1, 90, 6, 30, 2, 74, 8, 63, 3, 58, 7, 29, 0, 19, 5, 11, 
    3, 58, 6, 51, 0, 81, 8, 41, 5, 88, 7, 62, 2, 12, 4, 28, 1, 62, 
    7, 82, 5, 99, 6, 72, 2, 82, 8, 41, 3, 48, 4,  5, 0, 16, 1, 59, 
    1, 17, 5, 13, 2, 70, 8, 42, 4, 30, 0, 37, 3, 24, 7, 71, 6, 92, 
    4, 36, 1, 49, 5, 17, 7, 15, 8, 83, 0, 53, 2, 17, 3, 64, 6, 48, 
    6, 35, 0, 54, 8, 88, 4, 64, 2, 42, 3, 44, 5, 10, 7, 26, 1, 72, 
    8, 69, 1, 77, 2, 92, 6, 44, 7, 52, 3, 31, 5,  2, 0, 79, 4, 63
  };
  const int q7326[] = {
    9, 9, // Number of jobs and machines
    3, 79, 2, 78, 0, 60, 4, 43, 8, 20, 6, 85, 7, 11, 5, 26, 1, 61, 
    0, 52, 7, 97, 6, 73, 1, 52, 2, 27, 5, 95, 4, 90, 3, 44, 8, 73, 
    0, 77, 4, 99, 6,  6, 1, 87, 2, 60, 3, 82, 5,  1, 8,  6, 7, 58, 
    7, 87, 1, 88, 6, 67, 8, 85, 3, 12, 4, 14, 2, 26, 0, 84, 5, 55, 
    5, 93, 2, 46, 0, 83, 3, 73, 1, 25, 7, 12, 6, 82, 4, 10, 8, 99, 
    4, 61, 7, 28, 8, 84, 1, 98, 3, 76, 6, 59, 0,  3, 2, 87, 5, 70, 
    6, 56, 1, 34, 4, 57, 0, 83, 3, 13, 8, 19, 5, 15, 2, 63, 7, 52, 
    4, 81, 0, 89, 8, 87, 7, 52, 5, 86, 1, 48, 6, 26, 2, 21, 3, 87, 
    8, 91, 1, 60, 7,  7, 6, 37, 3,  9, 0, 96, 2, 28, 4, 26, 5, 17
  };
  const int q7327[] = {
    9, 9, // Number of jobs and machines
    1, 96, 3, 77, 4, 55, 6, 40, 0, 58, 2, 63, 8, 95, 7,  3, 5, 29, 
    0, 89, 3, 42, 7, 48, 5, 97, 6, 69, 8, 84, 4, 66, 2, 55, 1, 70, 
    7, 64, 5, 80, 4, 30, 0, 71, 2, 30, 6, 74, 3, 21, 1, 44, 8, 19, 
    5, 91, 1, 24, 7, 38, 0, 59, 3, 42, 8, 27, 6, 85, 4, 58, 2, 28, 
    7, 31, 0, 63, 6, 96, 3, 65, 2, 17, 5, 23, 8,  9, 4, 62, 1,  8, 
    8,  7, 1, 43, 5, 70, 2,  6, 7, 14, 3, 87, 4, 86, 6, 94, 0, 46, 
    1, 63, 0,  9, 4, 19, 8, 58, 7, 89, 6,  6, 3, 35, 2, 93, 5, 72, 
    0,  3, 7, 90, 5, 45, 4, 29, 3, 86, 1, 43, 6,  9, 8, 18, 2,  2, 
    0, 18, 3, 88, 6, 33, 1, 18, 8, 66, 4, 43, 2, 85, 5, 26, 7, 24
  };
  const int q7328[] = {
    9, 9, // Number of jobs and machines
    1, 72, 7, 35, 5, 66, 0, 86, 2, 33, 6, 35, 8, 49, 3, 81, 4,  4, 
    4, 61, 1, 82, 2, 10, 5, 87, 8, 17, 3, 90, 7, 39, 0, 23, 6, 32, 
    4, 75, 5, 29, 0, 41, 8, 48, 1, 47, 3, 78, 7, 25, 6, 70, 2, 24, 
    0, 73, 5, 12, 4, 66, 6, 92, 7, 13, 1, 74, 8, 81, 2, 55, 3, 74, 
    0, 13, 4,  1, 5, 37, 2, 35, 1, 64, 3,  7, 6, 42, 7, 11, 8, 71, 
    0, 70, 4, 42, 3, 65, 2, 95, 8,  3, 7, 59, 1, 48, 5,  8, 6, 88, 
    1, 71, 8, 24, 5, 24, 6, 49, 3, 44, 7, 16, 0, 53, 2, 21, 4, 58, 
    4, 13, 2, 28, 8, 77, 5,  1, 7, 97, 0, 51, 6, 19, 1, 63, 3, 90, 
    6, 63, 4,  9, 1, 35, 8, 40, 2,  3, 3, 25, 5, 24, 7, 91, 0, 98
  };
  const int q7329[] = {
    9, 9, // Number of jobs and machines
    0, 40, 5, 97, 2, 39, 3, 16, 8, 91, 6, 29, 7, 49, 4, 14, 1, 55, 
    8, 96, 1, 29, 3, 57, 5,  5, 4, 48, 0,  2, 6, 70, 7, 20, 2,  4, 
    5, 62, 1, 98, 4, 50, 2, 52, 3, 48, 8, 46, 6, 96, 7, 29, 0, 83, 
    0, 87, 5, 31, 8, 35, 7, 55, 1, 96, 2, 37, 4, 82, 6, 86, 3, 74, 
    5, 24, 2, 37, 3, 42, 1, 58, 8, 53, 7, 44, 0, 28, 4, 85, 6, 88, 
    7, 71, 6, 86, 8, 54, 5, 22, 1, 18, 0, 41, 3, 48, 2, 27, 4, 22, 
    4, 39, 3, 98, 5, 18, 8, 92, 1, 47, 0, 54, 2, 13, 7, 23, 6, 72, 
    7, 17, 6, 60, 2, 83, 5, 11, 8, 49, 1,  6, 4, 59, 3, 91, 0,  9, 
    3, 26, 4, 52, 2, 94, 8, 82, 7, 96, 5,  3, 1, 60, 0,  5, 6, 50
  };
  const int q7330[] = {
    9, 9, // Number of jobs and machines
    0, 58, 8, 42, 6, 27, 7, 34, 2, 54, 4, 20, 3, 46, 5, 80, 1, 48, 
    3, 83, 5, 95, 8, 84, 6, 97, 0, 46, 4, 71, 1, 76, 7, 12, 2, 21, 
    4, 66, 1, 50, 6, 51, 2, 82, 3, 31, 0, 72, 7, 71, 8, 96, 5, 17, 
    4, 11, 8, 40, 3, 25, 6, 77, 1, 82, 5, 50, 2,  2, 0, 37, 7, 43, 
    5, 29, 8, 75, 1, 55, 3, 87, 6, 97, 0, 62, 2, 34, 4, 62, 7, 46, 
    8, 42, 4, 75, 5, 75, 2, 43, 3, 85, 7, 69, 1, 43, 6, 29, 0, 43, 
    2,  6, 6, 61, 5, 30, 3, 59, 0, 49, 8, 24, 7, 35, 1, 26, 4, 89, 
    8, 18, 7,  9, 3, 56, 1, 70, 5,  7, 2, 79, 4, 89, 0, 85, 6, 43, 
    4,  7, 1, 85, 8,  7, 2, 22, 6, 79, 7, 52, 0, 68, 3, 57, 5, 39
  };
  const int q7331[] = {
    9, 9, // Number of jobs and machines
    8, 63, 4, 67, 5, 41, 2, 13, 0, 11, 1, 49, 3, 91, 7, 13, 6,  1, 
    6, 53, 3, 84, 7,  6, 5, 75, 4, 18, 1, 32, 8, 99, 0, 24, 2, 44, 
    8, 46, 5, 65, 1, 81, 7, 18, 2, 55, 6, 35, 3, 53, 0, 74, 4, 85, 
    0, 19, 1, 43, 3, 49, 4, 32, 8, 18, 5, 58, 2, 14, 7,  6, 6, 74, 
    8, 70, 7, 32, 0, 13, 1, 63, 5, 55, 3, 77, 2, 27, 4, 37, 6, 87, 
    3, 70, 2, 72, 0, 98, 8, 52, 5,  5, 4, 90, 7, 11, 1, 97, 6, 63, 
    5, 47, 1,  7, 0, 45, 4, 79, 6,  8, 3, 49, 2, 96, 8, 36, 7, 62, 
    3, 55, 8, 95, 7,  4, 2, 80, 4, 64, 6, 65, 5, 25, 0,  1, 1, 52, 
    0, 85, 4, 32, 8, 24, 2, 91, 1, 14, 6, 48, 5, 41, 7, 34, 3, 68
  };
  const int q7332[] = {
    9, 9, // Number of jobs and machines
    7, 95, 5, 55, 8, 99, 4, 59, 6, 61, 0, 33, 2, 22, 1, 22, 3, 55, 
    1, 42, 7, 34, 4, 68, 6,  4, 0, 14, 8,  4, 3, 97, 5,  2, 2, 30, 
    6, 13, 2, 14, 5, 82, 0, 84, 4, 45, 8, 97, 3, 96, 7, 72, 1, 34, 
    1,  3, 0, 77, 3, 40, 2, 66, 5, 70, 4, 73, 6, 55, 8,  8, 7, 64, 
    1, 26, 4, 43, 3, 17, 5, 92, 7, 19, 0, 72, 6, 75, 8,  6, 2, 58, 
    1, 65, 2, 32, 5,  9, 7, 10, 0, 79, 8, 66, 6, 77, 3, 11, 4, 29, 
    3, 98, 1, 90, 4, 65, 2, 10, 8, 36, 6,  6, 5, 54, 7, 18, 0, 47, 
    8, 77, 0, 61, 1, 78, 4, 75, 3, 81, 5,  5, 6,  2, 7,  4, 2, 14, 
    6, 53, 0, 83, 7, 81, 8,  6, 1, 80, 2, 11, 4, 10, 3, 45, 5, 41
  };
  const int q7333[] = {
    9, 9, // Number of jobs and machines
    5, 27, 3, 19, 7, 90, 1, 18, 8, 40, 4,  7, 6, 60, 0, 71, 2, 75, 
    8,  9, 7, 48, 0, 22, 6, 19, 5, 85, 2, 46, 1, 96, 4, 98, 3, 19, 
    1, 57, 7, 46, 0, 69, 5, 19, 8, 82, 2, 65, 4, 20, 3,  5, 6,  9, 
    1,  8, 4,  6, 5,  6, 2, 13, 7, 73, 6, 20, 0, 96, 3, 47, 8, 91, 
    0, 82, 2, 82, 8, 75, 6, 55, 1, 26, 4, 38, 7, 67, 3, 50, 5, 16, 
    1, 63, 3, 31, 4, 62, 6, 89, 5, 61, 2, 57, 0,  5, 8,  8, 7, 64, 
    7, 36, 8, 30, 3, 77, 2, 21, 0, 46, 4, 81, 5, 64, 1, 61, 6, 80, 
    6, 71, 0, 44, 1, 80, 4, 56, 2, 98, 5, 57, 3,  2, 7, 34, 8, 31, 
    4, 34, 8,  1, 2, 52, 3, 85, 7, 64, 0, 43, 5, 59, 6, 65, 1, 68
  };
  const int q7334[] = {
    9, 9, // Number of jobs and machines
    7, 11, 2, 57, 0, 74, 5, 73, 8, 45, 4,  2, 3, 91, 6, 81, 1, 40, 
    6, 68, 7, 16, 8, 91, 5, 93, 2, 93, 3, 57, 0, 56, 1, 57, 4, 90, 
    2, 11, 6, 33, 1, 57, 3, 54, 0, 20, 8, 52, 7, 69, 4, 26, 5, 86, 
    5, 80, 1, 35, 2, 50, 7, 28, 8, 50, 4, 39, 6, 41, 0, 33, 3, 13, 
    5, 26, 1, 13, 6, 24, 4, 90, 7, 34, 3, 70, 8, 33, 2, 21, 0, 55, 
    4, 76, 5, 65, 1, 58, 3, 26, 8, 75, 7, 20, 2,  6, 6, 76, 0, 64, 
    5, 19, 8, 27, 6, 20, 4, 73, 3, 54, 7, 63, 0, 20, 2,  2, 1, 30, 
    3, 67, 6, 61, 0,  9, 4, 96, 8, 41, 5, 89, 1, 88, 7, 22, 2, 60, 
    6, 66, 3, 25, 2, 80, 5, 30, 4, 99, 7,  9, 1, 93, 0, 94, 8,  4
  };
  const int q7335[] = {
    9, 9, // Number of jobs and machines
    2, 90, 1, 11, 4,  4, 8,  9, 6, 36, 5, 83, 7, 83, 0, 56, 3, 85, 
    8, 14, 3, 85, 1, 64, 5, 25, 7, 55, 2, 29, 4,  6, 0, 35, 6, 51, 
    6, 46, 4, 81, 3, 31, 0, 72, 1,  4, 2, 84, 5, 12, 8,  7, 7, 80, 
    5,  8, 6, 34, 1,  5, 8, 41, 4, 41, 0, 19, 2, 55, 7, 67, 3,  4, 
    7, 78, 4, 21, 5, 22, 8, 18, 6, 75, 3, 74, 1, 24, 0, 91, 2, 61, 
    3, 87, 4,  8, 6, 18, 0, 64, 1, 89, 7, 73, 2, 94, 5, 91, 8, 26, 
    3, 52, 8, 49, 0, 13, 2, 13, 6, 96, 7, 47, 4,  6, 5, 25, 1, 94, 
    0, 83, 3, 35, 2,  8, 5, 36, 6, 32, 8, 78, 7, 86, 1, 74, 4, 67, 
    5, 31, 0, 61, 7, 43, 4, 35, 1, 89, 2,  2, 6, 91, 8, 75, 3, 90
  };
  const int q7336[] = {
    9, 9, // Number of jobs and machines
    8, 91, 1, 78, 3,  2, 2, 43, 0, 76, 7, 10, 5, 43, 4, 93, 6, 12, 
    7, 63, 0,  5, 1, 56, 2, 16, 3, 43, 6, 14, 4,  9, 5, 19, 8, 53, 
    5, 66, 3, 22, 4, 72, 7, 16, 0, 11, 8,  7, 2, 80, 6, 32, 1, 73, 
    1, 90, 8, 95, 7, 81, 0, 19, 5, 94, 2, 16, 3, 33, 4, 89, 6, 89, 
    3, 56, 1, 91, 6, 78, 7, 21, 8, 16, 0, 66, 2, 92, 5, 30, 4, 11, 
    7, 29, 1,  7, 5, 58, 4, 50, 2, 99, 6, 16, 8, 78, 0, 97, 3, 22, 
    5, 93, 1, 65, 3, 52, 7, 64, 6, 84, 8, 58, 0, 74, 2, 60, 4,  2, 
    6, 50, 5, 29, 7,  7, 2, 32, 3, 69, 4, 42, 0, 67, 8,  3, 1, 43, 
    1, 22, 7, 14, 4, 29, 3,  6, 2,  1, 8, 61, 6, 32, 0, 99, 5, 74
  };
  const int q7337[] = {
    9, 9, // Number of jobs and machines
    1, 95, 2, 30, 3, 68, 8, 36, 4, 77, 0, 95, 6, 36, 7, 67, 5, 81, 
    8, 49, 5, 26, 1, 91, 6, 18, 2,  8, 7,  5, 0,  3, 3, 72, 4, 22, 
    8, 70, 4, 32, 6, 64, 3, 74, 7, 66, 1, 31, 2, 86, 5, 36, 0, 23, 
    3, 81, 6, 62, 5, 32, 7, 12, 8, 13, 4, 40, 2, 19, 1,  3, 0, 28, 
    1, 71, 3, 78, 7, 97, 0,  9, 6, 76, 2, 96, 8,  1, 4, 61, 5, 98, 
    7, 10, 2,  5, 3,  1, 0, 13, 1, 82, 6, 39, 8, 10, 5, 24, 4, 34, 
    1, 19, 4, 99, 7, 38, 8,  1, 2, 75, 0,  5, 5, 71, 6, 55, 3, 26, 
    7, 11, 3, 66, 4, 33, 1, 93, 6, 60, 0, 27, 8, 90, 5, 17, 2, 41, 
    1, 73, 2, 75, 5, 61, 6, 28, 3,  9, 0,  3, 7, 16, 4, 85, 8, 79
  };
  const int q7338[] = {
    9, 9, // Number of jobs and machines
    5, 94, 6, 52, 1, 10, 3, 10, 7, 83, 8, 21, 0, 14, 2,  9, 4, 37, 
    4, 25, 5, 45, 7, 12, 8, 26, 0, 79, 2, 43, 3, 43, 6, 92, 1, 38, 
    8, 98, 2, 59, 7, 12, 6, 15, 5, 29, 3, 26, 0, 37, 1, 66, 4, 69, 
    2, 42, 4, 25, 7, 20, 0, 62, 3, 98, 6, 92, 8, 19, 1, 45, 5, 50, 
    6, 46, 3, 86, 5, 16, 0, 49, 8, 32, 1, 47, 2, 74, 4, 56, 7, 48, 
    5, 28, 6, 57, 3, 61, 1, 46, 2, 38, 8, 58, 7, 11, 0, 54, 4, 23, 
    2, 46, 6, 51, 5, 45, 0, 68, 3, 23, 4, 55, 1, 77, 7, 57, 8, 90, 
    2, 67, 3, 43, 8, 34, 1, 29, 5, 90, 4, 55, 6, 99, 0, 44, 7, 74, 
    5, 76, 2, 68, 6, 95, 7, 96, 1, 62, 3, 52, 8, 96, 4, 71, 0, 97
  };
  const int q7339[] = {
    9, 9, // Number of jobs and machines
    8, 56, 2, 37, 0, 52, 6, 22, 1, 26, 5, 59, 4, 53, 3, 37, 7, 18, 
    6, 35, 3,  8, 7, 97, 1, 14, 4, 62, 8, 87, 5, 43, 0, 75, 2, 48, 
    4, 18, 2, 65, 0, 71, 7, 56, 3, 24, 1, 79, 8, 98, 5, 44, 6, 58, 
    3, 35, 5, 73, 2, 55, 8, 94, 1, 34, 7, 23, 4, 60, 6, 53, 0, 56, 
    7, 43, 2,  4, 3, 66, 8, 47, 6, 93, 4, 65, 1, 50, 5, 94, 0, 57, 
    1, 14, 7, 45, 6,  2, 5,  8, 8, 13, 3,  4, 4, 28, 0, 22, 2, 91, 
    3, 83, 8, 19, 2, 93, 4, 62, 0, 92, 5, 76, 7, 64, 6, 34, 1, 56, 
    3, 89, 1, 60, 8, 72, 7, 68, 2,  1, 4, 84, 5, 82, 0, 38, 6, 63, 
    8, 25, 3, 72, 6, 48, 5, 46, 4, 97, 2, 50, 7, 54, 0, 52, 1, 77
  };
  const int q7340[] = {
    9, 9, // Number of jobs and machines
    4,  3, 6, 94, 7, 78, 8, 30, 3, 81, 5, 17, 1, 52, 2, 62, 0, 58, 
    4, 95, 1, 64, 8, 96, 0, 52, 2, 75, 6, 60, 5, 74, 3, 21, 7, 86, 
    3, 47, 7, 17, 1, 47, 2, 28, 5, 58, 4, 25, 0, 65, 8, 95, 6, 34, 
    6, 19, 4, 77, 8,  3, 3, 15, 5,  4, 2, 78, 0, 91, 7, 19, 1, 82, 
    4, 21, 2, 40, 0, 30, 6, 27, 1, 59, 7, 92, 8, 84, 3, 84, 5, 97, 
    8, 75, 3, 72, 0,  8, 7, 84, 4, 69, 2, 75, 6, 60, 5, 65, 1, 61, 
    7, 97, 3, 79, 1, 35, 5, 41, 2, 62, 6, 38, 8, 56, 4, 21, 0, 13, 
    1, 75, 7, 54, 8, 18, 0, 36, 4, 23, 5, 94, 3, 71, 6, 40, 2, 29, 
    0, 81, 3, 34, 6, 59, 2, 24, 5, 92, 4, 71, 8, 96, 1, 42, 7, 54
  };
  const int q7341[] = {
    9, 9, // Number of jobs and machines
    7, 45, 4, 22, 8, 79, 0, 43, 5, 37, 1,  9, 3, 74, 2, 24, 6, 51, 
    7, 82, 8, 89, 2, 37, 3,  3, 5, 41, 6, 26, 4, 87, 1, 56, 0, 85, 
    1, 85, 2, 28, 5, 19, 7, 54, 0, 18, 3, 14, 8,  1, 4, 34, 6, 51, 
    3, 86, 4, 85, 6, 95, 7,  4, 0, 90, 5, 75, 2, 32, 8, 37, 1, 29, 
    1, 77, 0, 51, 7, 39, 8, 48, 5, 79, 2, 48, 3, 12, 6, 79, 4, 57, 
    1, 63, 6,  7, 4, 11, 0,  3, 7, 32, 3, 51, 5, 62, 2, 73, 8, 52, 
    4, 12, 2, 54, 8, 46, 6, 34, 5, 14, 1, 78, 7, 92, 0, 10, 3,  2, 
    7,  3, 2, 35, 3, 19, 1,  4, 5,  8, 4, 47, 6, 39, 8, 43, 0, 72, 
    0, 23, 2, 73, 5, 96, 6, 12, 3, 73, 1, 50, 4, 81, 7, 61, 8, 86
  };
  const int q7342[] = {
    9, 9, // Number of jobs and machines
    8, 91, 6, 88, 4, 40, 7, 66, 5, 68, 2, 87, 1, 14, 0, 87, 3, 69, 
    3, 53, 8, 22, 5, 29, 4, 33, 2, 80, 6, 62, 1, 71, 7, 99, 0, 46, 
    4, 99, 3, 93, 6, 38, 0, 98, 8, 57, 1, 97, 7, 48, 2,  5, 5, 81, 
    4, 73, 8, 23, 3, 43, 6, 42, 5, 23, 2, 13, 7,  7, 1, 17, 0, 10, 
    2, 21, 4, 57, 6, 97, 5, 97, 7, 41, 3, 21, 8, 50, 0, 56, 1, 95, 
    5, 46, 8, 17, 0,  8, 7, 44, 6, 32, 4, 55, 1, 82, 2, 93, 3, 10, 
    3, 62, 1, 55, 7, 84, 4, 33, 8, 57, 2, 30, 5, 89, 6, 87, 0, 37, 
    6, 46, 0, 29, 5, 39, 3, 91, 4, 91, 8, 54, 2, 28, 7, 93, 1, 47, 
    7, 61, 4, 42, 3, 50, 5, 89, 6, 10, 8, 98, 2, 42, 0, 17, 1, 87
  };
  const int q7343[] = {
    9, 9, // Number of jobs and machines
    5, 33, 0, 56, 2, 67, 7, 20, 6, 42, 8, 15, 1, 53, 4, 51, 3, 99, 
    4, 48, 5, 28, 2, 19, 0, 40, 1, 60, 7, 43, 6,  1, 8, 55, 3, 17, 
    0, 58, 2, 11, 1, 69, 5, 67, 8, 35, 3, 87, 4, 99, 6, 84, 7, 41, 
    5, 52, 2, 71, 4, 68, 7, 35, 1, 32, 6, 46, 0, 13, 8, 78, 3, 24, 
    8, 12, 6, 64, 4,  1, 5, 14, 2, 41, 7, 92, 1, 78, 0, 83, 3, 18, 
    4, 44, 5, 45, 7, 77, 3, 25, 1, 63, 2, 45, 0, 41, 8, 38, 6,  3, 
    3, 60, 0, 60, 7, 86, 1, 65, 6, 50, 4, 40, 5, 76, 2, 83, 8, 48, 
    6,  2, 4, 69, 1, 60, 3,  5, 5, 35, 2, 28, 7, 41, 8, 25, 0, 59, 
    3, 97, 0, 49, 1, 28, 8, 95, 2, 60, 4, 66, 6,  4, 5, 22, 7, 85
  };
  const int q7344[] = {
    9, 9, // Number of jobs and machines
    2, 97, 1, 95, 4, 82, 7, 17, 3, 20, 8, 53, 6, 25, 0, 56, 5, 63, 
    1, 88, 8,  5, 4, 88, 6, 84, 2, 76, 3, 85, 5, 99, 7, 17, 0, 97, 
    8, 74, 3, 76, 1, 83, 2, 74, 0, 40, 4, 73, 7,  4, 5, 40, 6, 80, 
    2, 84, 7, 48, 6, 71, 1, 99, 8, 72, 0,  4, 3, 30, 4, 54, 5, 99, 
    3, 53, 6, 16, 7, 43, 4, 26, 2, 44, 0, 45, 1, 14, 8, 88, 5, 24, 
    6, 69, 0, 11, 8, 81, 5, 15, 7, 52, 1, 44, 2, 88, 4, 93, 3, 42, 
    0, 93, 5, 85, 4, 90, 1, 62, 3, 88, 7, 17, 8, 93, 2, 69, 6, 24, 
    3, 22, 1, 76, 0, 70, 2, 68, 6, 70, 8, 11, 4, 32, 7, 19, 5, 56, 
    2, 44, 3, 59, 0, 53, 8, 17, 7, 76, 6, 25, 5, 15, 1, 32, 4, 50
  };
  const int q7345[] = {
    9, 9, // Number of jobs and machines
    0, 36, 7, 23, 6,  5, 3, 97, 8, 94, 1, 70, 5, 24, 2, 16, 4, 69, 
    6, 52, 8, 96, 5, 55, 4, 43, 0, 94, 3, 45, 2, 30, 1, 26, 7, 57, 
    8,  2, 5, 66, 3, 40, 6, 65, 0, 20, 1, 23, 2, 47, 4, 97, 7, 70, 
    3, 26, 2,  1, 1, 97, 6, 11, 0, 64, 8, 51, 4,  4, 7, 92, 5, 89, 
    0, 25, 6, 21, 7,  2, 8, 90, 3, 77, 2, 27, 1, 10, 4,  9, 5,  2, 
    3, 60, 7, 48, 4,  2, 6, 59, 5, 83, 8, 43, 2, 21, 0, 59, 1, 76, 
    6, 15, 3,  3, 1, 82, 5, 59, 4, 12, 8, 73, 2, 76, 0, 58, 7, 61, 
    2, 18, 5, 41, 1, 63, 4, 94, 7, 12, 8, 66, 6, 31, 3,  3, 0, 88, 
    0, 64, 3, 76, 8,  7, 2, 22, 1, 95, 4, 30, 6, 49, 5, 31, 7, 99
  };
  const int q7346[] = {
    9, 9, // Number of jobs and machines
    6, 70, 7, 70, 2, 67, 1, 11, 4, 19, 5, 15, 3, 54, 0, 32, 8, 33, 
    1, 50, 2, 38, 0, 61, 3, 92, 6, 27, 5, 27, 7, 26, 8, 97, 4, 71, 
    5, 29, 4, 47, 3, 49, 6, 20, 2, 39, 0, 25, 7, 47, 8,  3, 1, 56, 
    4, 70, 7, 78, 3, 29, 1, 88, 5, 63, 0, 45, 6, 65, 2, 98, 8, 53, 
    5, 74, 0, 32, 1,  7, 7, 52, 3, 35, 2, 71, 6, 97, 4,  2, 8, 26, 
    5, 20, 7, 85, 1, 43, 2, 35, 8, 24, 0, 83, 3, 81, 4, 37, 6, 63, 
    4, 26, 1, 29, 0, 46, 6, 68, 3,  1, 5, 65, 2, 36, 8, 93, 7, 15, 
    2, 43, 7, 29, 6, 74, 5,  4, 8, 74, 3, 24, 1, 49, 0, 39, 4, 59, 
    2, 77, 6,  3, 1,  9, 4, 59, 7, 71, 0, 36, 8, 97, 3, 32, 5, 11
  };
  const int q7347[] = {
    9, 9, // Number of jobs and machines
    5, 73, 1, 99, 3, 59, 4, 28, 0, 41, 7, 73, 8, 67, 2, 83, 6, 87, 
    7, 33, 2,  2, 0, 20, 8, 43, 4, 29, 5, 35, 1, 46, 6, 85, 3, 47, 
    8, 62, 7, 63, 0, 29, 5, 79, 6,  4, 3, 36, 2, 68, 4, 49, 1, 66, 
    5,  5, 7, 32, 0, 99, 3, 54, 6, 95, 2, 35, 8, 78, 4, 24, 1, 54, 
    2, 15, 8, 20, 3, 29, 6, 90, 5, 33, 7, 87, 4, 41, 1, 34, 0, 67, 
    8, 98, 3, 77, 2, 51, 4, 98, 7, 64, 1, 81, 6, 82, 0,  9, 5, 65, 
    2, 64, 1, 35, 7, 13, 3, 18, 6, 89, 0, 31, 8, 47, 4, 47, 5, 17, 
    2, 20, 4, 47, 7, 34, 1, 14, 0, 82, 3, 55, 8, 65, 6, 80, 5, 41, 
    2, 21, 3, 96, 4, 38, 6, 45, 5, 13, 0, 39, 1, 25, 8, 19, 7, 97
  };
  const int q7348[] = {
    9, 9, // Number of jobs and machines
    1, 46, 7, 14, 0, 91, 2, 10, 6, 60, 3, 77, 4, 48, 8, 28, 5, 15, 
    6, 17, 4, 49, 8, 50, 0, 95, 7, 76, 3, 42, 5, 99, 1, 40, 2, 62, 
    1, 99, 4, 80, 8, 18, 5, 24, 7, 75, 2, 45, 6, 44, 3, 32, 0, 68, 
    8, 72, 4, 85, 0, 47, 7, 89, 6, 35, 2,  7, 5, 48, 1, 74, 3, 10, 
    8, 48, 2, 43, 1, 47, 7, 34, 4, 96, 5, 32, 3,  4, 0, 61, 6, 28, 
    0,  3, 3, 44, 4, 10, 5, 46, 6, 57, 8, 57, 2, 61, 7,  1, 1, 92, 
    3, 76, 6, 64, 5, 35, 8, 68, 4, 64, 1, 62, 7, 52, 0, 49, 2, 72, 
    2, 82, 3, 42, 7, 99, 1, 69, 5, 42, 8, 30, 4, 96, 0, 51, 6, 90, 
    4, 86, 7, 88, 0, 90, 8,  2, 6, 29, 2, 72, 1, 24, 5, 34, 3, 54
  };
  const int q7349[] = {
    9, 9, // Number of jobs and machines
    2, 51, 6, 28, 5, 35, 4, 30, 8, 61, 3, 25, 7, 82, 0, 37, 1, 26, 
    2,  8, 1, 79, 0, 19, 3, 56, 6, 73, 8, 26, 5, 42, 7, 34, 4, 95, 
    8, 65, 1, 60, 7, 30, 4, 33, 0,  5, 2, 59, 5,  8, 3, 40, 6, 99, 
    4, 66, 2, 11, 0, 92, 1, 39, 8, 66, 3, 46, 6, 14, 7, 17, 5, 23, 
    8, 57, 2, 19, 3,  7, 4, 53, 6, 36, 5, 98, 0, 32, 1, 83, 7, 36, 
    2,  9, 6, 48, 8, 82, 1, 11, 3,  5, 0, 70, 5, 38, 7, 65, 4, 89, 
    5, 35, 0, 25, 8, 51, 6, 41, 1, 52, 4, 45, 3, 48, 7, 69, 2, 48, 
    4, 75, 1, 69, 2, 88, 5, 91, 8, 42, 6, 89, 0, 44, 3,  3, 7, 25, 
    3,  7, 1, 30, 8,  1, 5, 78, 7, 16, 6, 10, 4, 97, 2, 33, 0, 81
  };
  const int q7350[] = {
    9, 9, // Number of jobs and machines
    1, 66, 8, 40, 7, 44, 5,  1, 6, 34, 2, 97, 4,  3, 0, 60, 3, 40, 
    4,  8, 6, 53, 7, 53, 8, 90, 1, 69, 2, 17, 5, 72, 0, 64, 3,  5, 
    8, 24, 3, 90, 2, 69, 4, 77, 1, 17, 6, 39, 5, 51, 7, 51, 0, 75, 
    7, 49, 1, 10, 6, 26, 2, 57, 0, 68, 8, 26, 3, 59, 4, 70, 5, 10, 
    4, 19, 0, 22, 3, 37, 5, 75, 1, 19, 2, 66, 8, 59, 6, 80, 7, 53, 
    3, 25, 5, 24, 0, 93, 2, 53, 8, 88, 6, 94, 7, 35, 4, 97, 1, 78, 
    1, 85, 3, 41, 4, 69, 7, 75, 2, 43, 0,  1, 6, 46, 5, 41, 8, 89, 
    4,  6, 2, 75, 7, 74, 1,  1, 3, 19, 8, 28, 0, 81, 5, 59, 6, 20, 
    3, 63, 4, 93, 1, 43, 0, 84, 6, 75, 8, 61, 5, 90, 2,  8, 7, 26
  };
  const int q7351[] = {
    9, 9, // Number of jobs and machines
    2, 56, 6, 89, 3, 77, 1, 97, 7, 72, 4, 63, 5, 53, 0, 72, 8, 15, 
    4, 41, 0, 75, 8, 70, 7, 66, 2,  7, 3, 80, 1, 80, 5, 77, 6,  7, 
    3, 89, 4, 17, 1, 84, 8, 96, 7,  2, 5, 30, 6, 63, 0, 88, 2, 76, 
    4, 86, 6, 85, 8, 89, 2, 78, 7, 73, 1, 62, 3, 49, 5, 97, 0, 92, 
    4, 42, 5, 21, 2, 18, 6, 50, 8, 59, 0,  4, 1, 47, 3, 43, 7, 82, 
    0,  5, 5, 94, 1, 91, 7, 52, 2, 95, 6, 52, 8, 26, 4, 18, 3, 61, 
    0, 76, 4, 67, 5, 85, 6, 34, 8, 77, 7, 10, 1, 44, 3, 80, 2, 59, 
    7, 52, 5,  8, 0, 29, 1, 56, 8, 45, 2, 62, 4, 71, 3,  1, 6, 54, 
    6, 36, 3, 53, 4, 74, 2, 26, 1, 19, 7, 92, 5,  6, 0, 94, 8, 27
  };
  const int q7352[] = {
    9, 9, // Number of jobs and machines
    2, 77, 1, 29, 0, 43, 5, 98, 7, 74, 4, 95, 6, 25, 3, 50, 8, 70, 
    4, 23, 5, 35, 6, 17, 7, 59, 1, 30, 3, 96, 8, 19, 2, 85, 0, 66, 
    0, 31, 2, 33, 5, 64, 8, 16, 1, 37, 7, 95, 6, 72, 4, 12, 3, 93, 
    4, 91, 1, 36, 2, 44, 5, 68, 3, 75, 6, 72, 8, 35, 7, 95, 0, 47, 
    3, 18, 1, 18, 2, 84, 8, 67, 4, 98, 7, 38, 5, 29, 0, 47, 6, 47, 
    8, 87, 7, 93, 4, 97, 3, 28, 5, 13, 1, 73, 6, 17, 2,  5, 0, 24, 
    8, 36, 1, 44, 5,  6, 4, 18, 7, 46, 0, 82, 6, 59, 2,  7, 3, 35, 
    2, 27, 0, 71, 4, 25, 5, 80, 1, 90, 7, 46, 3, 97, 8, 59, 6, 94, 
    0,  7, 8, 37, 3, 56, 6, 59, 1, 36, 7, 58, 5, 58, 4, 42, 2, 58
  };
  const int q7353[] = {
    9, 9, // Number of jobs and machines
    0, 26, 2, 25, 8, 75, 3, 82, 6, 95, 5, 88, 1, 93, 7, 56, 4, 71, 
    1, 53, 6, 73, 3, 57, 2, 87, 4, 30, 8, 56, 0, 60, 7, 79, 5, 72, 
    7, 39, 3, 48, 5, 55, 4, 76, 0,  4, 2, 24, 6, 83, 8, 43, 1, 55, 
    6, 66, 8,  6, 5, 33, 4, 17, 3,  5, 1, 90, 7, 13, 2, 17, 0, 62, 
    0, 76, 7, 46, 1, 33, 6,  5, 4, 66, 5, 36, 8, 28, 3, 62, 2, 39, 
    0, 96, 3, 89, 6, 89, 8, 35, 2, 40, 5,  1, 7,  2, 1, 68, 4, 77, 
    6, 61, 0, 63, 4, 20, 2,  8, 7, 57, 8, 33, 5, 55, 3, 82, 1,  6, 
    7, 22, 5, 28, 6, 73, 4, 87, 8, 96, 0, 47, 1, 12, 3, 39, 2, 16, 
    4, 39, 1,  2, 7, 91, 6, 20, 5, 98, 2, 28, 3, 95, 0, 52, 8, 93
  };
  const int q7354[] = {
    9, 9, // Number of jobs and machines
    7, 67, 5, 40, 4, 26, 8, 76, 6, 78, 2, 64, 1, 41, 0, 84, 3, 96, 
    5, 29, 0, 10, 8, 99, 6, 21, 1, 47, 4, 38, 7, 80, 3, 47, 2, 46, 
    1, 68, 7, 36, 4, 40, 6, 57, 3, 67, 5, 70, 8, 63, 2, 32, 0, 70, 
    7,  6, 2, 83, 1, 23, 6, 43, 8, 84, 3, 96, 4, 48, 0, 24, 5, 90, 
    4, 57, 8, 15, 3, 62, 1, 34, 2,  5, 5, 61, 6, 30, 0, 90, 7, 62, 
    3, 47, 8, 45, 6, 30, 1, 81, 2, 62, 5, 73, 7, 62, 4, 19, 0, 57, 
    7, 97, 0, 97, 8, 97, 1, 91, 6, 21, 4, 99, 5, 70, 3, 58, 2, 20, 
    0, 54, 4, 30, 5, 32, 1, 24, 8, 41, 3, 87, 2, 62, 7, 28, 6, 85, 
    8, 95, 0, 33, 6, 37, 7, 69, 5, 70, 3, 86, 1, 67, 4, 23, 2, 26
  };
  const int q7355[] = {
    9, 9, // Number of jobs and machines
    2, 19, 6,  8, 4, 49, 8, 45, 5, 95, 0, 66, 1, 55, 7, 50, 3, 12, 
    1, 16, 8, 43, 0, 64, 6, 11, 5, 77, 2, 25, 4, 79, 3, 51, 7,  6, 
    3, 88, 5, 64, 1, 83, 4, 85, 8, 99, 2, 36, 6, 25, 7, 71, 0, 97, 
    1, 23, 3, 13, 7, 18, 5, 91, 8, 28, 2, 71, 6,  1, 0, 84, 4, 69, 
    5, 42, 8, 87, 4, 79, 6, 11, 0, 40, 2, 75, 1, 70, 3, 20, 7,  7, 
    5, 70, 0, 52, 2, 49, 7, 21, 1, 50, 3, 29, 8, 31, 4,  3, 6, 48, 
    7, 99, 3, 40, 1, 18, 2, 10, 5, 53, 0, 52, 4, 70, 6, 15, 8, 57, 
    6, 93, 2,  1, 5, 63, 8, 85, 0, 43, 7, 68, 1,  5, 3, 71, 4, 42, 
    1, 18, 2,  7, 3, 79, 8, 90, 7, 15, 0, 87, 4, 66, 5, 20, 6, 72
  };
  const int q7356[] = {
    9, 9, // Number of jobs and machines
    3, 68, 2, 19, 5,  2, 0, 96, 6, 96, 1, 59, 4, 36, 7, 58, 8, 75, 
    4, 61, 2,  1, 0, 87, 1, 31, 3, 64, 5, 42, 7, 28, 8, 80, 6, 55, 
    2, 47, 1, 83, 7, 29, 8, 21, 3, 87, 5, 23, 4, 24, 6, 45, 0, 43, 
    1, 16, 8, 29, 4, 20, 7, 64, 5,  1, 3, 30, 0, 56, 2, 88, 6, 80, 
    1, 22, 6, 31, 3, 58, 0, 42, 2, 65, 4, 92, 5,  9, 7, 38, 8, 76, 
    7, 95, 1, 66, 6, 68, 3, 64, 4, 98, 0, 67, 5, 28, 8, 87, 2, 12, 
    6, 31, 3, 60, 0, 50, 1,  1, 2, 15, 5, 84, 4, 18, 8, 64, 7, 51, 
    4, 88, 7, 66, 1, 84, 5, 32, 6, 33, 3, 66, 2, 37, 0, 88, 8, 27, 
    7, 58, 4, 36, 5, 82, 6, 55, 1, 95, 3, 91, 8, 47, 0, 92, 2, 33
  };
  const int q7357[] = {
    9, 9, // Number of jobs and machines
    4, 96, 7, 23, 6,  8, 3, 94, 0, 92, 5, 54, 8, 96, 2, 42, 1, 16, 
    4, 46, 6, 70, 7, 52, 3,  3, 2, 12, 0, 75, 8,  3, 1, 33, 5, 63, 
    6, 53, 8,  6, 3, 56, 5, 95, 7, 38, 4, 81, 1, 88, 2, 16, 0, 90, 
    0, 66, 2, 63, 6, 25, 3, 27, 5,  9, 4, 17, 8, 90, 7, 12, 1, 26, 
    6, 31, 4, 12, 0, 54, 3, 54, 7, 33, 5, 14, 2, 84, 1, 85, 8, 65, 
    3, 81, 7, 73, 2, 43, 4,  3, 5, 40, 8, 43, 0, 89, 6, 67, 1, 69, 
    5, 26, 0, 64, 1, 36, 4, 93, 2, 31, 3, 47, 7, 65, 8, 19, 6, 40, 
    4, 62, 2, 83, 5, 73, 1, 82, 6, 53, 8, 22, 7, 62, 0, 58, 3, 25, 
    0, 80, 2, 39, 4, 79, 8, 54, 7, 54, 3, 98, 5, 11, 6, 73, 1, 60
  };
  const int q7358[] = {
    9, 9, // Number of jobs and machines
    4, 70, 7,  4, 6, 96, 5, 15, 1, 42, 8, 21, 2, 22, 0, 81, 3, 55, 
    0, 70, 4, 43, 7, 33, 8, 44, 6, 96, 5, 56, 3,  6, 2, 89, 1,  9, 
    7, 71, 8, 99, 6, 42, 1, 95, 3, 66, 4, 35, 5, 20, 0, 47, 2,  8, 
    1, 48, 3, 18, 7, 69, 0, 83, 2, 69, 4, 46, 5, 91, 8,  3, 6,  9, 
    8, 36, 2, 89, 4, 29, 7, 68, 3,  3, 6, 93, 0, 39, 1, 64, 5, 71, 
    2,  7, 8, 21, 7, 83, 1, 41, 3, 72, 0,  8, 6, 54, 5, 86, 4, 39, 
    2, 13, 1, 65, 3, 83, 6, 56, 0, 80, 7, 57, 4, 20, 5, 19, 8, 26, 
    5, 88, 8, 55, 2, 58, 0, 93, 7, 49, 6, 97, 1, 49, 3, 21, 4, 72, 
    4, 92, 0, 37, 8, 56, 5, 50, 2, 64, 6, 62, 1, 30, 3, 85, 7, 55
  };
  const int q7359[] = {
    9, 9, // Number of jobs and machines
    7, 88, 0, 68, 6, 97, 1, 87, 8, 36, 4, 21, 3, 72, 2, 24, 5, 63, 
    2, 80, 8, 10, 4, 45, 0, 49, 6, 58, 1, 52, 5,  7, 7, 52, 3, 57, 
    7, 31, 0, 34, 5, 45, 2, 50, 4, 43, 8, 78, 3, 89, 6, 93, 1, 18, 
    6, 26, 1, 75, 2, 30, 4, 49, 0, 24, 3, 23, 8, 19, 7,  1, 5, 22, 
    3,  8, 0,  9, 6,  1, 8, 55, 4, 39, 2, 13, 7,  9, 1, 46, 5, 76, 
    5, 16, 2, 81, 4, 32, 8, 55, 1, 13, 6, 49, 0, 78, 3, 24, 7, 75, 
    2, 35, 6, 67, 5, 15, 3, 69, 1, 89, 4, 73, 0, 68, 7, 27, 8, 89, 
    2, 35, 8, 86, 1, 14, 7, 29, 6, 97, 4, 20, 0, 52, 5, 79, 3, 57, 
    2,  5, 8, 96, 5, 27, 7, 83, 3, 94, 0, 86, 1, 60, 6, 79, 4, 41
  };
  const int q7360[] = {
    9, 9, // Number of jobs and machines
    5, 47, 8, 11, 1,  6, 6, 97, 4, 78, 7, 99, 2, 54, 0, 26, 3, 50, 
    3, 99, 1, 37, 2, 21, 6, 59, 5, 84, 0, 52, 7, 65, 4, 35, 8, 86, 
    8, 55, 3, 16, 6, 87, 4, 47, 7, 29, 1, 26, 2, 53, 5, 29, 0, 52, 
    0, 56, 8,  7, 7, 72, 2, 71, 6, 88, 5, 59, 4, 82, 1, 30, 3, 86, 
    8, 81, 1, 37, 7, 33, 5, 73, 4, 36, 6, 56, 3, 39, 2, 69, 0, 57, 
    1, 91, 4, 26, 3, 99, 2, 10, 8, 10, 5, 54, 6,  5, 7, 87, 0,  3, 
    3,  5, 1, 34, 8, 34, 4, 24, 7,  5, 5, 12, 0, 40, 6, 53, 2, 40, 
    7, 39, 0, 46, 4, 10, 3, 70, 2, 77, 8, 23, 5, 57, 1, 89, 6, 18, 
    4, 91, 2, 25, 5, 73, 3, 77, 1, 16, 8, 50, 7, 91, 0, 88, 6, 91
  };
  const int q7361[] = {
    9, 9, // Number of jobs and machines
    1, 66, 5, 13, 4, 46, 7, 22, 6, 70, 3, 83, 2,  9, 0, 26, 8, 15, 
    6, 98, 7, 92, 2, 12, 4, 44, 1, 16, 3, 92, 5, 29, 8, 12, 0, 80, 
    5, 29, 2, 10, 0, 76, 3, 89, 1, 14, 8, 78, 4, 78, 7, 38, 6, 18, 
    5, 56, 6, 10, 7, 86, 0, 74, 1, 81, 2, 34, 8, 88, 3, 66, 4,  3, 
    5, 39, 0, 16, 8, 28, 4, 36, 2,  7, 1, 60, 6, 36, 3, 89, 7, 86, 
    7, 47, 0, 33, 6, 17, 1, 50, 8,  9, 2,  7, 3, 61, 5, 36, 4, 92, 
    5, 14, 4, 89, 6, 45, 8, 35, 0, 18, 2, 57, 7,  8, 3, 37, 1, 24, 
    1, 98, 5, 21, 7, 11, 2,  7, 4,  4, 0, 97, 6, 58, 3, 98, 8, 28, 
    7, 38, 6, 78, 3, 85, 0, 30, 2, 50, 4, 75, 1, 55, 5, 62, 8, 86
  };
  const int q7362[] = {
    9, 9, // Number of jobs and machines
    6,  3, 2,  5, 3, 37, 1, 33, 0, 88, 7, 98, 8, 46, 4, 58, 5, 87, 
    3, 55, 7, 66, 8, 86, 6, 21, 2, 73, 1,  5, 0, 12, 4,  7, 5, 60, 
    0, 62, 1, 42, 4,  3, 6,  4, 8, 18, 7, 19, 3, 27, 5, 98, 2, 89, 
    0, 21, 5, 17, 6, 39, 8, 24, 4, 21, 2, 62, 7, 74, 1, 99, 3, 65, 
    7, 77, 0, 64, 3, 80, 6, 96, 1, 38, 5, 38, 2, 73, 4,  3, 8, 61, 
    5, 26, 2, 75, 3, 76, 4,  3, 6, 36, 0, 50, 1, 20, 7, 98, 8, 38, 
    8, 41, 7, 57, 1, 16, 0, 78, 4, 48, 2, 31, 6, 34, 3, 35, 5, 74, 
    3,  8, 0, 67, 5, 14, 4, 64, 2, 38, 8, 34, 7, 75, 1, 91, 6, 32, 
    6, 74, 4, 94, 3, 11, 1, 52, 2, 43, 8, 22, 5, 69, 7, 10, 0, 23
  };
  const int q7363[] = {
    9, 9, // Number of jobs and machines
    5,  9, 4, 45, 0, 93, 1, 12, 6, 11, 7, 54, 2, 34, 8, 47, 3, 95, 
    8, 95, 1, 58, 6, 86, 2, 48, 3, 72, 0, 19, 7, 16, 5,  1, 4,  8, 
    6, 75, 2, 98, 7, 21, 1, 81, 4, 31, 5, 87, 8, 98, 0, 48, 3, 37, 
    4, 68, 6, 97, 2,  5, 0, 44, 3, 73, 5, 40, 1, 17, 7, 37, 8, 47, 
    7, 70, 0, 83, 8, 69, 5, 97, 4, 36, 3, 24, 1, 45, 2, 89, 6, 56, 
    4,  4, 3, 24, 2, 90, 8, 50, 5, 45, 6, 94, 7,  7, 1, 63, 0, 74, 
    2, 33, 0,  9, 1, 83, 3, 36, 7, 80, 4, 34, 5, 59, 8, 19, 6, 88, 
    6, 46, 4, 73, 1, 29, 3,  3, 0, 68, 8, 70, 7, 31, 5,  3, 2, 58, 
    1, 42, 8, 69, 2, 62, 0, 69, 3, 84, 5, 63, 6,  4, 7, 74, 4, 90
  };
  const int q7364[] = {
    9, 9, // Number of jobs and machines
    3, 65, 7, 84, 0, 39, 5,  4, 8, 63, 1, 88, 2, 12, 4, 48, 6, 38, 
    7, 61, 4, 80, 5, 52, 6, 37, 8, 89, 3, 35, 1, 27, 0, 85, 2, 56, 
    6, 34, 2, 71, 8, 89, 4, 68, 5, 98, 0, 84, 1, 76, 3,  2, 7, 83, 
    3,  1, 8, 46, 5, 60, 1, 86, 6, 58, 7, 19, 2, 96, 4, 51, 0, 51, 
    6, 80, 4, 70, 0, 25, 7, 43, 3, 46, 2, 45, 8, 31, 1, 22, 5, 14, 
    7, 13, 0, 24, 2, 73, 8, 49, 1, 51, 4, 60, 6, 30, 5,  7, 3, 61, 
    5, 23, 1, 36, 2, 84, 6, 19, 3, 60, 4, 34, 8,  9, 7, 94, 0, 32, 
    6, 94, 0, 53, 8, 58, 2, 90, 7, 66, 5,  4, 1, 74, 4, 84, 3, 50, 
    6, 94, 2,  9, 5, 63, 7, 40, 1, 19, 3, 34, 0, 24, 4,  1, 8, 38
  };
  const int q7365[] = {
    9, 9, // Number of jobs and machines
    4,  4, 6, 70, 1, 74, 2,  6, 5, 69, 8, 73, 7, 29, 3, 43, 0, 10, 
    2,  1, 3, 28, 6, 82, 4, 49, 8, 71, 0, 68, 1, 71, 5, 85, 7, 48, 
    6, 55, 4, 64, 5, 43, 8, 53, 0, 36, 7,  7, 2, 80, 1, 43, 3, 91, 
    8,  7, 4, 50, 5, 98, 3, 53, 2, 36, 1,  7, 7, 37, 6, 49, 0, 19, 
    6, 35, 4, 73, 7, 25, 1, 97, 0, 74, 8, 40, 3, 19, 2, 67, 5,  4, 
    4, 80, 5, 42, 3, 48, 6, 66, 8, 70, 0,  2, 7, 11, 1, 52, 2, 17, 
    3, 89, 2,  7, 6,  3, 0, 12, 8, 90, 1, 75, 4, 14, 5, 38, 7, 55, 
    7,  6, 2, 13, 5, 74, 0, 68, 6, 28, 3, 16, 8,  2, 4,  9, 1, 69, 
    1, 94, 3, 82, 2, 38, 0, 25, 7, 92, 6, 14, 5, 12, 8, 42, 4, 66
  };
  const int q7366[] = {
    9, 9, // Number of jobs and machines
    2, 55, 4, 77, 7, 62, 0, 41, 3, 86, 8, 54, 1, 28, 5,  3, 6, 98, 
    6, 56, 4, 30, 8, 96, 2, 86, 3, 31, 7, 28, 1, 36, 5, 21, 0, 43, 
    5, 86, 1, 17, 8, 47, 7, 60, 6, 72, 0, 34, 2, 27, 3, 63, 4, 27, 
    3, 76, 4, 90, 6, 30, 2, 68, 1, 88, 7, 73, 5, 57, 0, 84, 8, 61, 
    4, 60, 6, 13, 1, 84, 2, 77, 8, 41, 0, 26, 5, 92, 3, 88, 7, 31, 
    4, 99, 6,  3, 7, 56, 3, 14, 2, 81, 5, 67, 8, 63, 0, 98, 1, 28, 
    1, 58, 8, 18, 5, 36, 7, 43, 2, 16, 6,  9, 4, 42, 0, 29, 3, 88, 
    7, 12, 5,  2, 4,  1, 2, 22, 1, 61, 6, 53, 0, 59, 8, 55, 3, 58, 
    6, 87, 8, 73, 0, 92, 7, 61, 5, 19, 2, 62, 1, 66, 3, 39, 4, 72
  };
  const int q7367[] = {
    9, 9, // Number of jobs and machines
    2, 61, 6, 71, 8, 98, 0, 96, 5, 42, 1, 33, 7, 67, 3, 44, 4, 19, 
    6, 70, 2, 56, 7, 17, 0, 77, 8, 82, 4, 57, 1, 79, 5, 60, 3, 77, 
    3,  9, 6, 23, 0, 47, 2, 20, 7, 27, 1, 62, 5, 47, 8, 56, 4, 92, 
    2, 69, 1, 98, 6, 85, 8, 72, 5, 82, 0, 73, 3, 43, 7,  9, 4, 71, 
    4, 78, 2, 79, 6, 70, 5, 64, 0,  6, 3, 27, 7, 33, 1, 24, 8, 72, 
    7, 22, 8, 18, 2, 35, 5, 58, 6, 39, 4, 13, 3, 12, 0, 93, 1, 64, 
    4, 92, 8, 45, 0, 32, 6, 77, 3, 36, 5, 12, 7, 37, 2, 72, 1, 44, 
    7, 35, 4, 60, 5, 74, 1, 86, 3, 99, 6,  3, 0, 18, 2,  8, 8, 93, 
    3,  9, 8, 69, 7, 99, 2, 56, 4, 27, 5, 29, 6, 93, 1, 41, 0, 81
  };
  const int q7368[] = {
    9, 9, // Number of jobs and machines
    8, 11, 6, 44, 7, 16, 3, 30, 0, 91, 5, 52, 1, 51, 2, 75, 4, 91, 
    0, 46, 3, 66, 2, 25, 6, 35, 1, 70, 8, 34, 5, 32, 7, 26, 4, 57, 
    3, 62, 2, 55, 0, 33, 7, 26, 5, 86, 8, 83, 4, 64, 6, 66, 1,  2, 
    4, 59, 1, 34, 6, 90, 5, 96, 3, 16, 2, 69, 0, 72, 8, 92, 7, 61, 
    8, 38, 1, 33, 4, 13, 3, 47, 2, 60, 7, 14, 5, 20, 6, 64, 0, 94, 
    6, 57, 4,  4, 0, 15, 1, 72, 8, 32, 5, 14, 3, 20, 2, 83, 7, 60, 
    3, 32, 2, 94, 6, 68, 5, 25, 7, 12, 1,  5, 0, 31, 8, 66, 4, 71, 
    7, 48, 2, 71, 5, 24, 0, 95, 1,  4, 4, 69, 8, 39, 3, 47, 6, 52, 
    3, 64, 0, 92, 2, 80, 4, 35, 8, 34, 5, 47, 7, 37, 1, 70, 6, 60
  };
  const int q7369[] = {
    9, 9, // Number of jobs and machines
    2, 74, 4, 88, 5, 95, 8, 99, 6, 91, 3, 90, 7, 44, 0, 91, 1, 69, 
    7, 68, 4, 51, 5, 68, 0, 53, 2, 83, 6, 42, 3, 42, 8, 94, 1, 27, 
    6, 68, 2, 11, 8,  4, 4, 57, 1, 26, 7, 28, 3, 33, 5, 85, 0, 62, 
    7, 45, 2, 61, 4,  3, 6, 65, 8, 72, 1, 18, 0, 81, 5, 50, 3, 31, 
    3, 50, 6, 87, 8, 17, 2, 67, 0, 46, 1, 98, 5, 65, 4, 47, 7, 86, 
    2, 47, 4, 23, 5, 12, 0, 86, 1, 22, 7, 37, 6, 78, 3, 55, 8, 34, 
    1, 76, 7, 11, 6, 49, 3, 61, 0, 79, 5, 91, 4, 12, 8, 48, 2,  3, 
    4, 83, 1, 47, 3, 65, 2, 46, 7, 29, 0, 78, 8, 34, 6, 37, 5, 64, 
    4, 25, 7, 53, 2, 71, 5, 37, 1, 61, 3, 24, 6, 70, 0, 98, 8, 66
  };
  const int q7370[] = {
    9, 9, // Number of jobs and machines
    2, 73, 4,  8, 5, 37, 0, 81, 3, 99, 1, 40, 8, 77, 6,  2, 7, 44, 
    5, 45, 1, 39, 2, 65, 0, 98, 6, 98, 8, 44, 4, 90, 3, 81, 7, 53, 
    1, 88, 4, 81, 0, 83, 2, 69, 7, 63, 5, 84, 8, 11, 3, 78, 6, 17, 
    7, 75, 8, 60, 6, 13, 5, 51, 3, 37, 4, 77, 0, 46, 2, 90, 1, 71, 
    5, 79, 4, 78, 2, 33, 0, 90, 3, 10, 7, 37, 6, 71, 8, 48, 1, 28, 
    7, 49, 4, 76, 6, 46, 1, 21, 5, 16, 3, 95, 2, 50, 0, 78, 8, 92, 
    1, 57, 5, 67, 0, 38, 7, 77, 8, 92, 2, 23, 6, 73, 3, 41, 4, 61, 
    8, 14, 1, 34, 0, 17, 2, 89, 5, 95, 6, 57, 3, 80, 4, 55, 7, 60, 
    0,  6, 8, 99, 7, 77, 2, 45, 1, 34, 6, 99, 3, 62, 5, 22, 4, 28
  };
  const int q7371[] = {
    9, 9, // Number of jobs and machines
    6,  8, 2, 72, 3, 41, 1,  3, 7, 92, 0, 67, 8,  2, 4, 70, 5, 52, 
    4,  2, 3, 55, 2, 77, 0, 72, 7, 98, 5, 43, 8, 62, 6,  5, 1,  3, 
    2, 75, 8, 68, 4, 92, 6, 81, 1, 55, 3, 23, 0, 64, 7, 99, 5, 14, 
    3, 78, 6,  7, 1, 82, 2, 25, 0, 47, 4, 67, 5, 88, 8, 36, 7, 26, 
    2, 67, 5, 99, 6, 37, 1, 24, 0,  8, 4, 29, 3, 17, 8, 32, 7, 10, 
    6, 58, 5, 14, 0, 47, 8,  6, 7, 82, 1, 50, 3, 30, 4, 63, 2, 17, 
    2, 40, 3, 62, 8, 79, 7, 79, 5, 94, 4,  9, 6, 35, 0, 27, 1, 78, 
    0, 65, 7, 99, 2, 11, 1, 34, 8, 21, 6, 14, 3, 22, 4, 26, 5, 43, 
    4, 14, 1, 12, 6, 20, 8, 92, 3,  3, 0, 79, 2, 84, 5, 31, 7, 69
  };
  const int q7372[] = {
    9, 9, // Number of jobs and machines
    4, 82, 2, 32, 8, 61, 6, 67, 1,  6, 5, 13, 0, 13, 7,  8, 3, 76, 
    3, 34, 7, 19, 4, 15, 1, 52, 2, 50, 6, 43, 5, 60, 8, 66, 0, 63, 
    0, 64, 3, 62, 8, 86, 4, 75, 6,  6, 1, 72, 5, 66, 2,  1, 7, 37, 
    8, 68, 6,  2, 3, 21, 7, 22, 2, 56, 5, 86, 0, 60, 4, 54, 1, 35, 
    8,  2, 0, 42, 7, 82, 5, 40, 1, 16, 6, 17, 4, 72, 2, 48, 3, 77, 
    2, 16, 4, 60, 7, 44, 3, 16, 6, 98, 5, 87, 1, 56, 0, 38, 8, 72, 
    1, 81, 6, 34, 7, 42, 8, 72, 4, 20, 2, 14, 5, 14, 0, 17, 3,  2, 
    8, 16, 2, 40, 0, 79, 5, 97, 3, 71, 4, 52, 6, 78, 1, 53, 7, 12, 
    8, 17, 5, 35, 1, 46, 6, 85, 3, 30, 7, 43, 2, 48, 4, 40, 0, 23
  };
  const int q7373[] = {
    9, 9, // Number of jobs and machines
    2, 80, 6, 77, 8, 50, 3, 10, 4, 51, 5, 42, 7, 82, 0, 19, 1,  7, 
    8, 69, 3, 56, 0, 82, 1, 82, 7, 98, 2, 91, 6, 48, 4, 97, 5, 79, 
    0, 75, 8, 84, 1, 69, 6,  7, 7, 63, 4,  6, 5, 13, 3, 83, 2, 97, 
    8, 37, 1, 43, 2, 73, 5, 31, 3, 19, 7,  5, 6,  1, 4,  9, 0, 80, 
    0,  7, 7, 66, 8, 17, 3, 50, 2, 81, 5, 13, 4, 20, 6, 84, 1, 71, 
    3, 11, 1, 95, 5, 59, 0, 80, 2, 30, 7, 93, 6, 37, 8, 58, 4, 18, 
    2, 70, 5, 22, 1, 86, 4, 67, 6, 54, 7, 89, 3, 32, 0, 52, 8, 41, 
    5, 44, 6, 25, 2, 82, 1, 61, 0, 51, 3, 44, 4, 10, 7, 45, 8, 67, 
    7, 15, 8,  5, 4, 48, 3, 28, 0, 71, 5, 14, 2, 72, 1, 46, 6, 12
  };
  const int q7374[] = {
    9, 9, // Number of jobs and machines
    1, 87, 0, 81, 5,  8, 8, 17, 2,  8, 3, 41, 4,  3, 6,  9, 7, 21, 
    2, 68, 7, 30, 0, 53, 8, 54, 4, 37, 3, 15, 6, 29, 1, 22, 5, 85, 
    6, 19, 2, 66, 5, 96, 1, 59, 8, 77, 4, 96, 0, 14, 7, 94, 3, 63, 
    1,  2, 2, 86, 0, 15, 6, 41, 8, 89, 7, 91, 3, 51, 5, 22, 4, 12, 
    4, 18, 7, 25, 0, 33, 8, 69, 2, 25, 3, 90, 6, 33, 5,  4, 1, 19, 
    2, 98, 5, 66, 0, 98, 8, 30, 3, 75, 4,  2, 6, 52, 7, 32, 1, 66, 
    7, 34, 4, 80, 8, 49, 2,  9, 3, 41, 0,  4, 1,  7, 6, 48, 5, 14, 
    8, 30, 1, 13, 0, 66, 7, 87, 5, 72, 4, 89, 3, 87, 6, 50, 2, 23, 
    5, 55, 7, 63, 0,  7, 8, 33, 6, 87, 4, 47, 2, 23, 3,  8, 1, 54
  };
  const int q7375[] = {
    9, 9, // Number of jobs and machines
    1, 47, 2, 96, 3, 95, 7, 32, 5, 64, 6, 67, 0,  8, 4,  6, 8, 68, 
    5, 47, 4, 15, 0, 60, 7, 46, 6, 18, 2,  9, 3, 54, 1, 69, 8, 66, 
    8, 93, 0, 57, 1, 46, 6, 60, 2,  5, 5, 72, 7,  9, 4,  6, 3, 30, 
    4, 81, 5, 37, 2, 49, 6, 79, 7, 96, 8, 28, 0, 94, 1,  6, 3, 76, 
    3, 58, 7, 37, 0, 17, 1,  1, 6, 45, 8, 76, 4, 51, 2, 89, 5, 59, 
    6, 28, 7,  9, 1, 70, 5, 21, 8, 14, 3, 63, 4, 37, 2,  4, 0, 58, 
    2, 33, 7, 45, 6,  6, 1,  6, 3, 80, 4, 40, 8, 60, 0, 62, 5, 39, 
    0, 48, 5, 75, 2, 36, 4, 37, 3, 61, 1, 42, 6, 64, 8, 88, 7, 56, 
    2, 66, 0, 94, 3, 66, 5, 74, 7, 55, 1, 18, 4, 31, 6, 57, 8, 97
  };
  const int q7376[] = {
    9, 9, // Number of jobs and machines
    2, 99, 4, 53, 8,  2, 5, 14, 3, 95, 6,  9, 0, 65, 7, 24, 1, 99, 
    0, 95, 5, 58, 1, 46, 6, 25, 8, 44, 2,  5, 7, 30, 4, 90, 3, 22, 
    4, 94, 7, 55, 5, 14, 2, 55, 1, 19, 8, 42, 0, 95, 3, 95, 6, 36, 
    0, 81, 7, 34, 4,  9, 5, 52, 1,  5, 8, 23, 6, 14, 3,  1, 2, 42, 
    6,  6, 4, 85, 8,  1, 5, 12, 2, 29, 1, 23, 7, 73, 0, 96, 3, 94, 
    5, 41, 7, 53, 0, 98, 3, 48, 4, 21, 6, 94, 1, 56, 2, 79, 8, 85, 
    4, 39, 1, 28, 5, 67, 8, 42, 0, 41, 2, 54, 7, 53, 3, 39, 6, 30, 
    0, 17, 5, 36, 2, 41, 8, 12, 1,  4, 3, 11, 6, 70, 7, 72, 4, 41, 
    8, 90, 1, 35, 2, 21, 5, 30, 6, 70, 3, 74, 4, 82, 7, 13, 0, 47
  };
  const int q7377[] = {
    9, 9, // Number of jobs and machines
    8,  5, 5, 56, 1, 21, 4, 96, 3, 72, 7, 48, 0, 86, 2, 99, 6, 96, 
    2, 14, 8, 22, 5, 68, 3, 92, 7, 99, 4, 66, 1,  9, 0, 89, 6, 59, 
    1, 15, 4, 93, 5, 17, 0, 63, 6, 50, 2, 53, 3, 30, 8, 26, 7, 61, 
    0, 98, 3, 97, 6, 71, 4, 14, 8, 11, 7, 89, 5, 72, 1, 36, 2, 83, 
    2, 38, 5, 13, 1, 20, 0, 63, 6, 30, 7,  9, 8,  4, 3, 61, 4, 58, 
    0, 81, 4, 24, 3, 86, 1, 88, 5, 12, 2,  6, 6, 41, 7, 46, 8, 46, 
    6, 69, 2, 39, 5, 75, 1,  4, 4, 58, 7, 68, 3, 20, 8, 61, 0, 79, 
    4, 77, 7,  2, 2, 66, 6, 95, 3, 53, 0, 19, 5,  3, 8, 58, 1, 38, 
    3, 71, 2, 39, 8, 26, 6, 42, 0, 22, 1, 12, 7, 11, 4, 96, 5, 30
  };
  const int q7378[] = {
    9, 9, // Number of jobs and machines
    8, 53, 7, 83, 5, 22, 1,  3, 0, 11, 6, 30, 4,  2, 2, 86, 3, 19, 
    4, 47, 7, 87, 8, 39, 1, 95, 6, 58, 2,  9, 0, 59, 5, 88, 3, 70, 
    5, 87, 1,  3, 2, 34, 4, 11, 0, 88, 3,  3, 8,  6, 6, 17, 7, 62, 
    7, 60, 1, 18, 0, 61, 6, 75, 5, 26, 8, 72, 3, 47, 2, 26, 4, 28, 
    3, 46, 5, 16, 7, 46, 2, 14, 4, 33, 1, 20, 8,  1, 0, 51, 6, 66, 
    7, 70, 1, 40, 4, 28, 2, 70, 5,  6, 6, 37, 3, 35, 8, 83, 0, 46, 
    2, 74, 8, 34, 6, 65, 5, 84, 4, 16, 0, 79, 7, 47, 3, 48, 1, 95, 
    4,  4, 5, 15, 7, 96, 0, 66, 3, 54, 2, 52, 8, 47, 1, 72, 6, 54, 
    2,  6, 0, 23, 5, 31, 3, 88, 8, 29, 7, 86, 1, 63, 4, 70, 6, 81
  };
  const int q7379[] = {
    9, 9, // Number of jobs and machines
    2, 68, 4, 89, 8, 35, 3, 62, 7, 84, 0, 42, 5, 89, 6,  4, 1, 81, 
    8, 39, 7, 96, 3, 94, 1, 90, 6, 34, 2, 20, 4, 14, 0, 51, 5, 91, 
    5, 42, 4, 27, 6, 12, 0, 47, 7,  9, 1, 17, 3, 96, 2, 10, 8, 82, 
    3,  9, 0, 40, 5, 56, 4, 51, 1, 48, 2, 97, 7, 33, 8, 52, 6, 43, 
    3, 21, 6, 90, 0, 20, 1, 19, 8, 42, 2, 37, 4, 19, 7, 34, 5, 80, 
    8, 74, 7, 76, 5, 84, 0,  2, 2, 64, 3, 13, 4, 29, 1, 21, 6, 39, 
    8, 89, 3, 74, 4, 99, 0, 19, 6, 90, 5, 17, 1, 97, 2, 21, 7, 52, 
    6, 19, 4, 80, 5, 91, 3, 78, 7, 20, 1, 22, 2, 40, 8, 95, 0, 55, 
    0, 91, 5, 93, 8, 14, 2, 30, 7, 46, 1, 39, 6, 56, 4, 29, 3,  6
  };
  const int q7380[] = {
    9, 9, // Number of jobs and machines
    8, 28, 2, 54, 3, 20, 4, 50, 0, 73, 5, 67, 1, 14, 6, 35, 7, 80, 
    3, 14, 6, 21, 4, 13, 8, 36, 0,  9, 5, 39, 7, 67, 1, 76, 2, 40, 
    0, 82, 7, 35, 6, 12, 5, 65, 8, 70, 3,  1, 1, 59, 4, 43, 2,  5, 
    7, 72, 1,  8, 4, 41, 3, 55, 2, 98, 6, 84, 5, 35, 0, 62, 8, 78, 
    7, 50, 5, 67, 3, 29, 6, 43, 1, 70, 8, 89, 2, 20, 0, 43, 4, 75, 
    4, 78, 7, 99, 1, 18, 0, 89, 2, 86, 5, 46, 3, 68, 8, 12, 6,  2, 
    2, 46, 1, 47, 7, 88, 4, 56, 0, 16, 5, 50, 3, 37, 6,  6, 8, 80, 
    7, 31, 5, 41, 0, 62, 3, 61, 2, 97, 1, 86, 8, 51, 4, 50, 6, 76, 
    7, 23, 1, 51, 0, 59, 3, 44, 2, 67, 8,  9, 6, 13, 4,  9, 5, 23
  };
  const int q7381[] = {
    9, 9, // Number of jobs and machines
    2, 23, 1, 68, 3, 15, 5, 12, 8,  2, 7, 10, 0, 73, 4, 95, 6, 17, 
    8, 17, 4, 81, 2, 54, 0, 49, 7, 18, 6, 89, 1, 84, 5, 96, 3, 68, 
    0, 67, 6, 78, 7, 92, 8, 99, 1, 35, 5, 95, 4, 89, 3, 26, 2,  8, 
    4, 61, 7, 51, 8, 57, 6, 44, 0, 42, 5, 46, 2, 82, 3, 51, 1, 84, 
    5, 78, 8, 41, 2, 27, 7, 73, 6, 71, 1, 62, 0, 96, 4, 52, 3, 25, 
    6, 68, 3, 17, 5, 79, 7, 87, 2, 28, 0, 79, 8, 51, 1, 28, 4, 58, 
    0, 57, 2, 33, 7, 78, 1, 11, 8, 71, 4, 21, 3, 43, 5, 14, 6, 50, 
    0, 52, 3, 64, 5, 78, 4, 54, 2, 22, 8, 67, 7,  5, 1, 14, 6, 15, 
    2, 46, 4, 41, 8, 54, 0, 74, 6, 13, 3, 89, 5, 72, 1, 35, 7, 64
  };
  const int q7382[] = {
    9, 9, // Number of jobs and machines
    3, 77, 7, 35, 6, 49, 5, 78, 4, 61, 8, 95, 2, 41, 0, 96, 1, 93, 
    7, 16, 6,  3, 1, 40, 0, 29, 8, 77, 2, 48, 4, 42, 3, 81, 5, 44, 
    6, 57, 7, 37, 5, 61, 8, 67, 2, 55, 4, 53, 0, 77, 3, 90, 1, 95, 
    1, 19, 5, 51, 6, 95, 0, 87, 7, 34, 8, 98, 3, 95, 2, 81, 4, 25, 
    0, 81, 5, 21, 7, 34, 8, 29, 1, 67, 4, 78, 2,  4, 6, 66, 3, 92, 
    4,  5, 8, 78, 7, 50, 5, 16, 2, 12, 1, 67, 3, 55, 0, 93, 6, 18, 
    8, 70, 4, 82, 5, 92, 3, 27, 2, 70, 1, 36, 0, 55, 6,  2, 7,  2, 
    3, 34, 4, 38, 0, 74, 1, 97, 6,  6, 8, 95, 7, 89, 5, 18, 2, 30, 
    3,  9, 0,  2, 4, 35, 8, 81, 5, 77, 6, 56, 1, 54, 7, 25, 2, 14
  };
  const int q7383[] = {
    9, 9, // Number of jobs and machines
    1, 71, 7, 40, 5, 87, 4, 23, 2, 95, 8, 72, 6, 29, 3, 64, 0, 61, 
    1, 57, 5, 89, 3, 52, 7,  6, 0, 28, 4, 22, 8, 79, 2, 87, 6, 65, 
    2, 27, 1, 66, 6, 59, 8, 99, 5, 31, 3, 17, 7, 85, 0, 46, 4, 92, 
    8, 89, 2, 55, 6, 96, 5, 92, 3, 17, 7, 58, 1, 62, 0, 11, 4, 82, 
    8,  8, 7, 39, 5, 67, 0, 62, 3,  6, 1, 58, 2, 22, 4, 46, 6, 27, 
    2, 70, 8, 31, 5, 14, 4, 13, 0, 94, 3, 31, 7, 68, 6, 44, 1, 43, 
    1, 69, 0, 57, 5, 18, 3, 51, 6,  6, 2, 82, 4, 78, 7, 69, 8, 72, 
    4, 46, 1, 46, 3, 41, 6, 21, 7,  1, 8, 33, 2, 77, 0, 97, 5, 94, 
    8, 69, 4,  7, 6, 10, 7, 90, 0,  1, 2, 63, 3, 64, 1, 27, 5, 83
  };
  const int q7384[] = {
    9, 9, // Number of jobs and machines
    2, 88, 6, 47, 1, 34, 7, 44, 5, 84, 4, 13, 8, 13, 3, 35, 0, 25, 
    2, 37, 5,  2, 1, 32, 4, 48, 0, 25, 7,  9, 8, 50, 6, 21, 3, 95, 
    4, 37, 6, 40, 1, 43, 0, 97, 7, 94, 3, 50, 5, 47, 8,  6, 2, 92, 
    7, 13, 3, 33, 8, 50, 2, 61, 5, 63, 4, 98, 6, 25, 0, 78, 1, 66, 
    7, 82, 8,  4, 6, 48, 4, 38, 5, 11, 2, 31, 1, 77, 3, 49, 0, 10, 
    3, 42, 5, 30, 4, 34, 0, 70, 8, 65, 6, 32, 1, 19, 7, 73, 2, 93, 
    7, 80, 5, 67, 1,  9, 0, 39, 6, 74, 2, 90, 8, 26, 4,  8, 3, 84, 
    5,  2, 3, 82, 8,  1, 7, 32, 0,  7, 6, 86, 1, 60, 2, 18, 4, 65, 
    6, 66, 2,  6, 8, 79, 0, 84, 1,  3, 5, 36, 7, 97, 3, 93, 4,  2
  };
  const int q7385[] = {
    9, 9, // Number of jobs and machines
    0, 40, 8, 75, 1, 55, 6, 57, 3, 53, 4,  8, 2, 62, 7, 90, 5, 43, 
    1,  9, 8, 17, 4, 89, 0,  3, 7, 94, 2, 87, 5, 94, 3, 31, 6, 41, 
    8,  5, 4, 32, 5, 54, 1, 50, 6, 34, 3, 65, 0, 74, 2, 51, 7, 46, 
    2, 91, 8,  4, 0, 52, 1, 49, 4, 94, 5, 12, 7, 29, 6, 97, 3, 58, 
    2, 69, 3, 80, 5, 97, 4, 83, 1, 15, 7, 70, 8, 83, 6, 13, 0, 55, 
    5,  6, 3, 64, 2, 86, 0, 29, 1, 62, 7, 62, 4, 31, 8, 33, 6, 55, 
    0, 24, 8, 97, 2, 96, 5, 40, 1, 46, 4, 85, 7, 48, 6, 78, 3, 72, 
    3,  7, 6, 23, 8, 79, 2, 20, 7, 63, 5, 14, 0, 29, 1, 72, 4, 82, 
    3, 50, 2, 11, 4, 17, 0, 99, 6,  2, 7, 89, 5, 82, 1, 75, 8, 24
  };
  const int q7386[] = {
    9, 9, // Number of jobs and machines
    8, 80, 7, 99, 1, 11, 3, 13, 6, 23, 2, 14, 4, 12, 5, 94, 0, 11, 
    4, 38, 3,  1, 8, 65, 1, 15, 7, 91, 6, 88, 0, 50, 5, 99, 2, 96, 
    2, 59, 8, 19, 3, 16, 7, 27, 4, 88, 6, 60, 5, 18, 1, 43, 0, 99, 
    1, 49, 0, 41, 7, 84, 4, 74, 5, 17, 6, 55, 8, 88, 2, 27, 3, 16, 
    2, 76, 7, 15, 8, 87, 6, 73, 1, 73, 0, 69, 3,  8, 5, 31, 4, 67, 
    7, 68, 3, 90, 5, 77, 0, 71, 6, 49, 2, 43, 1, 84, 4, 10, 8, 96, 
    4, 40, 8, 26, 2, 50, 6, 59, 3, 19, 1,  8, 5, 75, 7,  6, 0, 60, 
    3, 99, 1, 47, 8,  6, 4,  2, 5, 38, 7, 64, 2, 63, 0, 34, 6, 89, 
    8, 81, 4, 33, 5, 50, 6, 49, 2, 87, 7, 76, 0, 47, 3, 71, 1, 33
  };
  const int q7387[] = {
    9, 9, // Number of jobs and machines
    0, 42, 1, 24, 4, 80, 3, 44, 2, 96, 5, 24, 6, 81, 7, 82, 8, 55, 
    1, 64, 7, 14, 5, 87, 0, 51, 2, 28, 3, 52, 8, 19, 4,  6, 6, 27, 
    0, 83, 8, 45, 3, 54, 6, 44, 1, 81, 7, 53, 4, 62, 5, 53, 2, 84, 
    1, 60, 4, 93, 5, 37, 0, 51, 7, 28, 3, 46, 6, 21, 8, 11, 2, 89, 
    2, 71, 3, 21, 6, 35, 1, 68, 8, 63, 7,  2, 5,  1, 4, 16, 0, 16, 
    1, 59, 6, 24, 0, 26, 7, 44, 8, 49, 3, 77, 2, 73, 4, 18, 5, 36, 
    0,  1, 5, 52, 4, 26, 7, 25, 2, 75, 3, 88, 1, 71, 8, 13, 6, 15, 
    6, 57, 5, 49, 8, 66, 3, 83, 1, 18, 4, 93, 2, 76, 0, 36, 7, 42, 
    6, 33, 8, 82, 1, 83, 3,  9, 2, 28, 4, 37, 5, 80, 0, 85, 7, 77
  };
  const int q7388[] = {
    9, 9, // Number of jobs and machines
    8, 23, 4, 29, 6, 53, 7, 81, 3,  2, 0, 61, 2, 61, 5, 44, 1,  3, 
    7, 25, 0, 10, 6, 88, 1, 63, 4, 96, 2, 99, 8, 68, 3, 35, 5, 22, 
    8, 74, 4,  5, 3, 84, 1, 34, 5, 22, 7, 36, 0, 27, 6, 56, 2, 98, 
    7, 95, 5, 35, 3,  5, 0, 61, 6, 71, 8, 23, 4,  9, 1, 31, 2, 40, 
    4, 11, 3, 76, 8, 44, 0, 68, 5, 86, 6, 81, 2, 98, 7,  5, 1, 97, 
    6, 25, 7,  7, 4, 29, 3, 48, 0, 14, 2, 93, 8, 91, 1,  6, 5, 35, 
    8, 77, 4,  7, 2, 48, 7, 18, 1, 63, 0, 16, 6, 50, 5, 49, 3, 20, 
    6, 42, 1, 73, 7, 98, 3, 77, 4, 89, 0,  3, 5, 99, 2, 89, 8, 89, 
    5,  7, 6, 94, 8, 52, 4,  9, 2, 29, 7, 50, 0,  9, 1, 29, 3, 27
  };
  const int q7389[] = {
    9, 9, // Number of jobs and machines
    6, 39, 4, 78, 1, 34, 2, 94, 3, 16, 8, 60, 0, 35, 5, 94, 7, 43, 
    1, 99, 8, 55, 4, 60, 6, 65, 3, 30, 0, 48, 2, 31, 5, 42, 7,  2, 
    7, 17, 0,  6, 4, 37, 6,  5, 5, 64, 2, 36, 1, 69, 8,  6, 3, 92, 
    1, 77, 5, 73, 3, 35, 6,  6, 2, 51, 0, 72, 4, 76, 7, 29, 8, 83, 
    7, 67, 5, 32, 4, 37, 3, 84, 8, 79, 1, 77, 2,  1, 6, 53, 0, 65, 
    3, 99, 8, 50, 2, 90, 6, 19, 1, 81, 0, 66, 7, 74, 5, 38, 4, 20, 
    3, 37, 6, 57, 5,  7, 8, 56, 2, 87, 1, 23, 4, 78, 7, 41, 0, 91, 
    3, 49, 8, 85, 0, 88, 5, 22, 6, 32, 1, 95, 4, 73, 7, 81, 2, 18, 
    6, 96, 8, 70, 7, 99, 2,  4, 1, 32, 5,  2, 4, 52, 0, 88, 3, 77
  };
  const int q7390[] = {
    9, 9, // Number of jobs and machines
    4, 13, 6, 51, 8,  1, 1, 92, 7, 81, 5, 97, 2,  5, 0, 48, 3, 17, 
    6, 42, 8, 21, 1, 25, 2, 55, 7, 30, 3, 30, 5,  8, 4, 32, 0, 90, 
    2, 93, 3, 92, 0, 49, 7, 36, 1, 19, 4, 44, 6, 11, 5, 23, 8, 25, 
    5, 49, 2, 66, 3,  7, 7, 54, 1, 10, 4, 30, 6, 36, 0, 10, 8, 39, 
    8, 78, 1, 64, 5, 29, 3, 47, 0, 55, 6,  2, 4, 12, 7, 89, 2, 48, 
    6, 86, 0, 59, 5, 14, 1, 83, 3, 61, 8, 13, 4,  7, 2, 77, 7, 78, 
    1, 63, 6, 79, 4, 40, 0,  3, 5, 57, 3, 98, 8, 49, 7, 42, 2, 87, 
    2, 52, 4, 28, 8, 17, 7, 98, 6, 24, 5,  5, 1, 36, 3, 66, 0, 30, 
    5, 26, 6, 77, 0, 63, 8, 79, 2, 82, 1, 37, 3, 48, 4, 81, 7, 58
  };
  const int q7391[] = {
    9, 9, // Number of jobs and machines
    4, 12, 2, 39, 0, 44, 3, 75, 7, 11, 8, 79, 6, 61, 5, 73, 1, 77, 
    6, 84, 1, 93, 2, 77, 5, 48, 7,  3, 4,  7, 0, 53, 8,  6, 3,  7, 
    7, 10, 1, 99, 6, 26, 2, 47, 3, 70, 5, 45, 4, 50, 8, 65, 0, 42, 
    6, 46, 0, 33, 3, 77, 5, 21, 8, 45, 1, 60, 4, 86, 2, 87, 7, 83, 
    2, 13, 1, 30, 6, 91, 4, 61, 0, 38, 3, 10, 5, 12, 7, 80, 8,  2, 
    3, 71, 1, 24, 4, 18, 8, 27, 2, 80, 7, 29, 0, 83, 6, 47, 5, 61, 
    2, 24, 7, 89, 3, 32, 8, 19, 5, 97, 0, 73, 6, 46, 4, 86, 1, 84, 
    7, 15, 2, 52, 8, 12, 0, 48, 6, 92, 3, 30, 5, 13, 1, 89, 4, 13, 
    8, 11, 2, 69, 5, 66, 3, 71, 6, 39, 1, 61, 0, 51, 4,  3, 7,  2
  };
  const int q7392[] = {
    9, 9, // Number of jobs and machines
    1, 35, 3, 46, 0, 14, 5, 20, 4, 24, 2, 93, 8, 15, 7, 48, 6,  7, 
    8, 20, 2, 61, 4, 81, 1, 60, 3, 45, 7, 38, 6, 98, 5, 10, 0, 37, 
    5, 82, 1, 35, 4, 35, 0, 46, 7, 62, 6, 39, 8, 95, 3, 95, 2,  7, 
    2,  6, 3, 59, 1, 42, 8, 60, 6, 70, 0, 19, 5, 39, 4, 57, 7, 70, 
    6, 87, 5, 70, 0, 19, 8, 19, 2, 46, 7, 29, 3,  5, 4, 83, 1, 56, 
    7, 63, 0, 54, 1, 25, 4, 33, 3, 23, 6, 71, 5, 79, 8, 82, 2, 25, 
    3, 63, 0, 18, 5, 19, 1, 72, 6, 98, 8, 32, 2, 43, 4, 78, 7, 43, 
    6, 96, 7, 85, 1, 90, 3, 64, 8, 42, 5, 47, 2, 12, 4, 62, 0, 80, 
    7, 56, 4, 69, 0, 18, 5, 57, 8, 55, 6, 26, 2, 22, 3, 71, 1, 27
  };
  const int q7393[] = {
    9, 9, // Number of jobs and machines
    0, 24, 3, 13, 6, 50, 2, 60, 4, 31, 7, 88, 8, 70, 1, 47, 5, 40, 
    7, 90, 4, 21, 3, 41, 5, 15, 2, 21, 1, 55, 8, 82, 0, 83, 6, 48, 
    6, 50, 1, 43, 3, 44, 4, 58, 2, 99, 5, 12, 7, 99, 8, 25, 0, 95, 
    8, 84, 2, 55, 4, 60, 5, 36, 7, 73, 3, 66, 0, 76, 1, 68, 6, 30, 
    2,  8, 4, 34, 5, 51, 7, 23, 8, 79, 6, 77, 0, 18, 3, 77, 1, 70, 
    3, 70, 5, 56, 7, 70, 6, 30, 8, 22, 4, 15, 2,  7, 0, 15, 1,  1, 
    6, 38, 8, 70, 2, 29, 3, 13, 1, 71, 4, 72, 7, 30, 5, 76, 0, 21, 
    2, 67, 6, 33, 0,  9, 4, 32, 5, 88, 8, 88, 7,  4, 1, 69, 3, 41, 
    3, 18, 5, 84, 1,  9, 2, 66, 4, 25, 0, 85, 8, 46, 7, 58, 6, 40
  };
  const int q7394[] = {
    9, 9, // Number of jobs and machines
    7, 15, 6, 40, 5, 34, 4, 86, 8, 54, 0, 75, 3, 58, 2, 44, 1, 75, 
    0, 40, 7, 31, 6, 83, 2, 65, 3,  6, 4, 14, 5, 41, 1, 37, 8, 77, 
    7, 69, 4, 63, 3, 53, 1, 94, 5, 99, 0, 67, 8, 77, 6, 39, 2, 88, 
    8, 57, 4, 11, 5, 32, 1, 91, 6, 58, 2, 40, 3, 67, 0,  9, 7, 62, 
    4, 41, 0, 99, 2, 87, 3, 17, 6, 93, 8, 63, 1, 35, 7,  3, 5, 88, 
    3, 84, 7,  6, 1, 65, 0, 68, 8, 65, 5, 85, 2, 11, 4, 73, 6, 55, 
    8, 95, 7, 35, 4, 34, 6, 20, 1, 58, 0, 57, 5, 34, 3, 52, 2, 39, 
    8, 47, 2, 91, 6, 70, 7, 93, 1, 98, 4, 33, 5, 32, 0,  6, 3, 22, 
    0, 37, 5, 75, 1, 27, 7, 28, 4, 84, 3, 75, 8, 71, 2, 85, 6, 67
  };
  const int q7395[] = {
    9, 9, // Number of jobs and machines
    8, 49, 7, 68, 2, 42, 5, 71, 6, 70, 3, 87, 4, 57, 1, 62, 0, 17, 
    6, 62, 0, 98, 8, 27, 1, 62, 2, 32, 7, 97, 5, 60, 3, 90, 4, 78, 
    7, 10, 1, 70, 0, 64, 3, 67, 4, 72, 6, 70, 8, 60, 5, 33, 2, 13, 
    0, 40, 7, 19, 8, 23, 6, 85, 5, 44, 2, 10, 1, 26, 4, 39, 3, 56, 
    4, 65, 5, 11, 6, 64, 7, 57, 8, 20, 3, 80, 1, 23, 0, 74, 2, 36, 
    8, 45, 4, 84, 1, 71, 5, 79, 7, 35, 3, 74, 0, 14, 2, 58, 6, 95, 
    3, 98, 0, 14, 6, 33, 7, 89, 4, 57, 8, 53, 5, 35, 1,  8, 2,  4, 
    2, 58, 6, 64, 8, 94, 4, 93, 7, 25, 5, 43, 3, 86, 0, 56, 1, 51, 
    8, 59, 7, 57, 3, 40, 6, 54, 5, 32, 2, 22, 1, 73, 4, 89, 0, 73
  };
  const int q7396[] = {
    9, 9, // Number of jobs and machines
    6, 69, 1, 87, 2, 59, 5, 82, 4, 94, 0, 42, 8, 60, 7, 36, 3, 65, 
    3,  3, 6, 29, 1, 84, 7, 80, 0, 74, 2, 10, 4, 82, 5, 49, 8, 97, 
    4, 10, 0, 56, 7,  2, 1,  9, 2,  7, 5, 91, 8, 37, 3,  1, 6, 20, 
    3, 26, 1, 98, 7,  8, 4, 94, 6, 30, 5,  2, 2, 81, 8, 65, 0, 46, 
    6, 75, 4, 28, 8, 23, 0, 69, 3, 34, 5, 56, 7, 82, 1, 13, 2, 34, 
    4, 94, 0,  9, 5, 62, 7, 89, 6, 18, 2, 35, 8, 40, 3, 41, 1, 51, 
    2, 63, 8, 83, 6, 13, 7, 31, 3, 73, 1, 88, 5, 54, 4, 35, 0, 36, 
    8,  9, 6, 71, 4, 95, 1, 60, 0,  1, 7, 20, 2, 62, 3, 47, 5, 39, 
    3, 74, 0,  7, 1, 17, 7, 28, 8, 39, 4, 12, 5, 28, 6, 38, 2, 91
  };
  const int q7397[] = {
    9, 9, // Number of jobs and machines
    3, 44, 2, 67, 8, 63, 7, 21, 0, 69, 1,  3, 4,  7, 6, 80, 5, 65, 
    2, 47, 7, 56, 5, 76, 8, 45, 1, 77, 0, 75, 4, 64, 3, 52, 6, 77, 
    0, 85, 8, 36, 2, 78, 1, 33, 7, 65, 3, 25, 4,  7, 5, 65, 6, 88, 
    1, 71, 8,  8, 5, 56, 0, 65, 2, 15, 3, 31, 7, 67, 4, 35, 6, 44, 
    8, 48, 2, 19, 3, 95, 1, 94, 5, 86, 6, 78, 0, 87, 4, 82, 7, 49, 
    7, 58, 4, 41, 5, 88, 8, 75, 2, 97, 0,  6, 1, 15, 3, 54, 6, 39, 
    8, 42, 6, 38, 3, 58, 7, 96, 0, 19, 2, 69, 1, 16, 5, 98, 4, 25, 
    7, 79, 8, 99, 3, 40, 4, 62, 1, 55, 6, 67, 2, 44, 5, 13, 0, 28, 
    7, 44, 0, 52, 4, 36, 5, 85, 6, 93, 1, 43, 8, 95, 2, 36, 3, 53
  };
  const int q7398[] = {
    9, 9, // Number of jobs and machines
    0, 63, 2, 88, 6, 44, 7, 59, 3, 22, 8, 49, 4, 36, 1, 89, 5, 32, 
    2, 20, 5, 23, 3, 75, 0, 91, 1, 89, 7, 42, 8, 90, 6, 84, 4, 13, 
    0, 11, 7, 74, 2, 77, 5, 83, 8, 27, 3, 40, 1, 35, 6, 27, 4, 75, 
    8, 71, 2, 27, 0, 81, 7, 98, 3, 32, 5, 62, 6, 50, 1, 57, 4, 80, 
    1, 39, 7, 18, 4, 35, 6,  2, 0, 82, 5, 66, 3, 18, 2, 76, 8, 48, 
    3, 45, 2, 28, 7, 53, 8,  3, 5, 25, 4, 30, 6, 14, 0, 41, 1, 51, 
    4, 74, 1, 77, 3, 64, 5,  4, 0, 66, 8, 91, 2,  9, 7, 85, 6, 92, 
    0,  4, 3, 53, 7, 80, 8, 98, 5, 11, 1,  6, 4, 37, 2, 78, 6, 52, 
    2, 40, 0, 19, 8, 93, 7, 10, 4, 83, 6, 95, 1, 89, 5, 84, 3, 29
  };
  const int q7399[] = {
    9, 9, // Number of jobs and machines
    4, 57, 5, 46, 0, 65, 2, 40, 3, 25, 6,  8, 8, 71, 7, 86, 1,  1, 
    5, 63, 8, 76, 6, 87, 1, 52, 7, 35, 0, 71, 4, 36, 2, 89, 3, 84, 
    4, 20, 1, 47, 5,  3, 0, 71, 6, 94, 2, 18, 7, 80, 8, 61, 3, 94, 
    8, 61, 7, 39, 5, 38, 6, 97, 3,  8, 2, 33, 0, 27, 4, 39, 1, 67, 
    4, 65, 3, 90, 0, 15, 6, 95, 5, 68, 2, 94, 8, 51, 1, 10, 7, 96, 
    0, 89, 6, 33, 3, 27, 7, 77, 5, 70, 4, 32, 8, 89, 2, 80, 1, 13, 
    1,  7, 2, 72, 8, 22, 3, 15, 6, 92, 0, 54, 4, 52, 5, 80, 7,  7, 
    0, 67, 4, 64, 5, 24, 6,  8, 2, 32, 3, 23, 1, 48, 8, 69, 7, 46, 
    6, 92, 7, 20, 1, 12, 2,  9, 0, 69, 4, 78, 5, 68, 8, 26, 3, 72
  };
  const int q7400[] = {
    9, 9, // Number of jobs and machines
    7, 46, 5, 21, 3, 49, 2, 16, 1, 62, 8, 76, 0, 40, 6, 53, 4, 82, 
    5,  2, 3, 70, 1, 45, 4, 59, 7, 83, 6, 34, 0, 57, 2, 75, 8, 78, 
    8, 34, 1, 88, 3, 58, 5, 76, 4, 61, 2, 70, 6, 19, 7, 63, 0, 65, 
    8, 41, 4, 52, 0, 82, 6, 98, 2, 93, 1, 61, 5,  2, 3, 87, 7, 92, 
    1, 53, 3, 88, 2, 65, 8,  4, 5, 77, 4, 15, 6,  8, 7, 84, 0,  8, 
    7, 43, 4, 59, 5, 25, 2, 31, 1,  4, 8,  7, 6, 14, 3, 37, 0, 93, 
    4, 46, 3, 51, 2, 85, 8, 23, 1,  7, 6, 87, 5, 49, 7, 50, 0, 17, 
    2,  9, 6, 26, 1, 94, 5, 34, 7, 91, 8, 41, 4, 37, 0, 64, 3,  5, 
    7, 84, 5, 19, 3, 16, 4, 17, 2, 12, 1, 71, 8, 46, 0, 32, 6, 76
  };
  const int q7401[] = {
    9, 9, // Number of jobs and machines
    3, 58, 8, 12, 7, 80, 0, 12, 5, 71, 4, 90, 6, 15, 1, 85, 2, 11, 
    3,  1, 4, 36, 6, 91, 8, 29, 5,  6, 2, 36, 0, 92, 1, 43, 7, 82, 
    1, 73, 2, 12, 3, 22, 7, 77, 6, 13, 5, 61, 8, 35, 4, 31, 0, 76, 
    3, 43, 6, 32, 2, 94, 0, 28, 4, 25, 7, 75, 8, 29, 5, 73, 1, 74, 
    5, 37, 7, 93, 4, 68, 6, 71, 8, 73, 1, 54, 2, 97, 0, 97, 3,  8, 
    3, 28, 1, 81, 6, 60, 7, 25, 0, 48, 5, 86, 8, 12, 4, 90, 2, 23, 
    5, 77, 6, 96, 3, 74, 1, 49, 0, 93, 2, 99, 4,  2, 8, 17, 7, 30, 
    2, 51, 5,  5, 0, 59, 4, 73, 6, 59, 1, 56, 3, 98, 7, 14, 8, 75, 
    4, 92, 1, 76, 5, 51, 6, 84, 8, 89, 2, 69, 7, 68, 3, 38, 0, 42
  };
  const int q7402[] = {
    9, 9, // Number of jobs and machines
    2, 15, 0, 41, 3, 10, 6, 27, 8, 33, 5, 38, 7, 67, 1, 93, 4, 62, 
    1, 77, 0, 90, 4, 17, 2, 49, 6, 84, 8, 11, 3, 76, 5, 54, 7, 15, 
    0, 25, 4,  7, 1, 35, 6, 43, 5, 31, 8, 63, 3, 14, 7, 99, 2, 22, 
    8, 91, 1, 63, 2, 14, 3, 77, 7, 53, 4, 15, 6, 17, 5, 13, 0, 87, 
    3, 12, 6, 96, 1, 68, 2, 22, 7, 30, 5,  8, 8, 75, 0, 75, 4, 71, 
    6, 54, 7, 55, 1, 86, 8, 41, 0, 96, 3,  3, 4, 62, 5,  3, 2, 97, 
    1, 27, 3, 73, 4, 47, 8, 30, 0, 65, 2, 19, 7,  1, 6, 41, 5, 48, 
    3, 44, 5, 60, 0, 97, 4, 25, 1, 44, 6, 50, 7, 67, 8, 75, 2,  8, 
    5, 96, 6, 10, 7, 72, 3, 54, 2, 28, 4, 27, 1, 70, 0, 83, 8, 59
  };
  const int q7403[] = {
    9, 9, // Number of jobs and machines
    4, 23, 6, 71, 0, 20, 1,  3, 3, 62, 2,  4, 7,  2, 8, 83, 5, 92, 
    3, 23, 7, 31, 4, 67, 8, 92, 1, 31, 0, 80, 5, 53, 2, 32, 6, 67, 
    1, 47, 6, 27, 4,  6, 0,  1, 3, 45, 7, 96, 5, 48, 8, 59, 2, 72, 
    6, 19, 4, 19, 1, 42, 8, 22, 5, 83, 2, 26, 3, 94, 7, 25, 0, 29, 
    6, 96, 1, 14, 3, 33, 0, 72, 8,  6, 7,  3, 2, 33, 5, 15, 4, 76, 
    7, 52, 8, 56, 1,  8, 6, 41, 4, 55, 3, 99, 2, 42, 0, 79, 5, 19, 
    6, 59, 3, 23, 5, 40, 2, 93, 1, 18, 8, 14, 7, 85, 4, 44, 0, 28, 
    1, 84, 2, 27, 0, 19, 5, 96, 6, 84, 3,  3, 4, 21, 8, 24, 7, 17, 
    5, 11, 2, 14, 0,  6, 4,  6, 7, 79, 8, 83, 6, 33, 1, 57, 3, 26
  };
  const int q7404[] = {
    9, 9, // Number of jobs and machines
    1, 38, 4, 12, 8,  7, 7, 10, 5, 43, 0, 42, 2, 16, 3, 37, 6, 30, 
    5, 47, 0, 18, 3, 87, 1, 79, 2, 70, 7, 20, 8, 90, 6, 21, 4, 14, 
    4, 15, 2, 67, 3, 57, 1, 36, 7, 59, 5, 80, 8, 70, 0, 93, 6, 95, 
    8, 51, 2, 17, 3, 57, 5, 56, 1, 50, 6, 24, 4, 99, 7, 56, 0, 86, 
    7, 47, 3, 29, 4, 65, 1, 96, 6, 21, 0, 89, 2, 75, 8, 62, 5, 41, 
    5,  8, 2, 74, 0, 90, 3,  8, 1, 47, 7, 89, 8, 86, 6, 74, 4, 45, 
    2, 22, 4, 33, 8, 59, 1, 20, 6,  6, 7, 61, 0, 18, 3, 82, 5, 60, 
    1, 26, 0, 73, 6, 41, 4, 60, 5, 38, 7, 38, 2, 58, 3,  6, 8, 84, 
    5, 18, 8, 51, 6, 60, 4,  3, 2,  5, 3, 70, 1, 26, 0,  5, 7, 35
  };
  const int q7405[] = {
    9, 9, // Number of jobs and machines
    3,  4, 1, 31, 8, 33, 5, 36, 0, 52, 2, 63, 4, 63, 6, 61, 7, 92, 
    0, 67, 1, 84, 7, 83, 4, 15, 8, 86, 2,  5, 5, 14, 3, 92, 6, 92, 
    4,  6, 3,  5, 5, 48, 6, 65, 2, 56, 0, 71, 7, 82, 8, 99, 1,  1, 
    8, 20, 6, 20, 3, 89, 5, 25, 2, 38, 1, 69, 0, 52, 4, 97, 7, 96, 
    3, 45, 0, 14, 7, 72, 4, 82, 5, 93, 6, 69, 8, 63, 1, 83, 2, 80, 
    6, 66, 5, 93, 0, 83, 8, 88, 7, 47, 4, 89, 2, 30, 3,  3, 1, 12, 
    2, 17, 7, 98, 6, 13, 0, 10, 3, 48, 4, 78, 5, 29, 8, 68, 1, 96, 
    4,  4, 3, 80, 7, 53, 0, 58, 5, 90, 2, 12, 8, 73, 6, 42, 1, 61, 
    5, 51, 2,  3, 3, 32, 1, 99, 6, 65, 4, 97, 8, 65, 7,  2, 0,  4
  };
  const int q7406[] = {
    9, 9, // Number of jobs and machines
    7, 64, 5, 84, 6, 71, 2, 80, 3, 35, 0, 79, 8,  9, 1, 62, 4, 11, 
    8, 21, 6, 79, 7, 88, 0, 98, 5, 91, 2, 43, 3,  6, 1, 44, 4, 23, 
    2,  5, 1, 71, 4, 21, 3, 66, 0, 10, 5, 68, 8, 13, 6, 42, 7, 24, 
    7, 82, 2, 77, 4, 97, 6, 16, 3, 34, 8, 41, 0, 43, 5, 67, 1, 46, 
    1, 40, 7, 80, 0, 41, 6, 69, 5, 96, 3, 49, 8, 52, 4, 37, 2, 54, 
    6, 77, 1,  9, 4, 80, 2, 61, 7, 60, 0, 37, 3, 95, 8, 77, 5, 75, 
    4, 46, 2, 79, 5, 42, 6, 26, 1, 65, 7, 71, 0, 24, 3, 13, 8,  3, 
    5, 71, 0, 66, 6, 89, 7, 70, 8, 35, 1, 21, 3, 11, 4, 14, 2, 36, 
    4,  4, 2, 48, 1, 53, 3, 67, 8, 94, 7, 16, 6, 18, 0, 98, 5, 64
  };
  const int q7407[] = {
    9, 9, // Number of jobs and machines
    8, 84, 1, 42, 0, 10, 2, 50, 3, 10, 6, 72, 7, 45, 5, 84, 4, 34, 
    0, 90, 2, 18, 3, 15, 1, 74, 8, 72, 7,  6, 4, 84, 5, 65, 6, 96, 
    0, 74, 3,  4, 7, 77, 1,  3, 5, 97, 4, 68, 2, 47, 8, 47, 6, 29, 
    4, 65, 1, 99, 2, 42, 6, 40, 0, 69, 7, 43, 8, 67, 3, 20, 5, 78, 
    6, 95, 1, 64, 0, 26, 7, 74, 5, 75, 3, 35, 2, 71, 8,  1, 4, 65, 
    7, 57, 1, 13, 4, 44, 5, 70, 6, 46, 2, 66, 3,  4, 0, 60, 8, 35, 
    1,  6, 8, 85, 4, 66, 7, 80, 6, 36, 0, 84, 3, 55, 5, 81, 2, 77, 
    1, 81, 3, 39, 5, 62, 7, 94, 8, 58, 2, 59, 4, 17, 0, 19, 6,  8, 
    7, 45, 8, 31, 3,  3, 4,  6, 0, 85, 1, 53, 2, 54, 5, 72, 6, 47
  };
  const int q7408[] = {
    9, 9, // Number of jobs and machines
    8, 63, 7, 49, 6, 84, 1, 41, 2, 35, 5, 67, 4, 33, 3, 93, 0,  3, 
    7, 47, 8, 76, 4, 29, 1, 41, 3, 23, 6, 31, 2, 43, 0, 41, 5, 66, 
    2, 59, 6,  4, 5, 57, 4, 80, 0, 92, 8, 67, 7, 69, 3, 43, 1, 77, 
    0, 66, 7, 46, 6, 38, 3, 36, 8, 85, 4, 20, 5, 24, 2, 49, 1, 29, 
    4, 15, 1, 83, 5, 74, 6, 44, 8, 11, 7,  6, 2, 34, 3, 63, 0, 84, 
    8, 68, 5, 42, 1, 52, 7, 44, 3, 10, 4, 14, 0, 25, 6, 49, 2, 76, 
    0, 89, 3, 61, 8, 98, 2, 67, 4,  9, 6, 80, 7, 61, 1, 83, 5, 18, 
    2, 90, 0,  6, 7, 29, 3, 58, 5, 10, 8, 55, 6, 73, 4, 71, 1, 78, 
    0, 81, 8,  1, 5, 44, 7, 11, 3, 37, 1, 74, 4, 80, 2, 43, 6, 94
  };
  const int q7409[] = {
    9, 9, // Number of jobs and machines
    4, 60, 8, 71, 2,  3, 5, 81, 6, 83, 1, 27, 0,  4, 3,  7, 7, 84, 
    5, 32, 2, 42, 3, 54, 7, 13, 4, 59, 8, 46, 0, 68, 6, 33, 1, 94, 
    3, 68, 0, 78, 6, 62, 5,  1, 4, 46, 8, 52, 2, 73, 7,  8, 1, 16, 
    8, 50, 1, 34, 0,  8, 6, 30, 2, 93, 7, 15, 5, 49, 3,  1, 4, 13, 
    8,  9, 1, 25, 0, 71, 4, 99, 3, 24, 5, 27, 7, 73, 6, 17, 2, 43, 
    3, 23, 6,  6, 8, 14, 1, 17, 2, 37, 5, 70, 0, 93, 4, 83, 7, 45, 
    6, 29, 7, 83, 8, 83, 4,  7, 5, 68, 0, 13, 2,  6, 1, 92, 3, 50, 
    5,  9, 8, 19, 1, 65, 6, 57, 2, 79, 4, 43, 7, 91, 3, 72, 0, 36, 
    6, 60, 3, 29, 2, 18, 0, 36, 4, 19, 1, 41, 8, 84, 5, 39, 7, 60
  };
  const int q7410[] = {
    9, 9, // Number of jobs and machines
    5, 25, 3, 85, 8, 29, 1, 24, 4, 61, 0, 27, 6, 45, 2, 87, 7, 89, 
    2, 17, 4, 31, 1, 14, 0, 67, 5, 88, 6, 10, 7, 16, 3, 66, 8,  8, 
    4, 91, 2, 26, 1, 94, 3, 53, 7,  6, 5,  8, 0, 99, 6, 54, 8, 88, 
    1, 93, 3, 99, 8, 82, 0, 80, 4, 97, 6, 35, 7, 32, 5, 16, 2, 84, 
    0, 25, 3, 80, 1, 12, 2, 94, 8, 80, 7, 80, 5, 26, 4, 93, 6, 99, 
    3, 86, 5, 11, 1,  4, 6,  3, 8, 51, 4,  1, 2, 98, 0, 41, 7, 35, 
    5, 28, 1, 23, 7, 76, 2,  7, 4, 71, 0, 24, 8, 11, 3, 84, 6, 98, 
    0, 29, 7, 77, 6, 47, 5, 54, 8, 39, 3,  2, 2,  6, 4, 29, 1, 60, 
    6, 85, 7, 82, 1, 63, 5, 68, 8, 57, 2,  5, 3, 94, 4, 39, 0, 23
  };
  const int q7411[] = {
    9, 9, // Number of jobs and machines
    5, 49, 7,  8, 2,  4, 0, 40, 1,  1, 6, 56, 4, 32, 3, 73, 8, 65, 
    2, 77, 5, 23, 7, 55, 8, 95, 3, 99, 4, 97, 1, 14, 6, 71, 0, 53, 
    8, 82, 1, 53, 7, 11, 0, 48, 5, 97, 3, 99, 2, 39, 4, 84, 6, 16, 
    1, 79, 2, 90, 5, 76, 3,  3, 6, 64, 4, 53, 7, 23, 8, 19, 0, 43, 
    8,  8, 6, 48, 1, 59, 3, 64, 5, 90, 7, 50, 0, 42, 4, 80, 2, 80, 
    1, 17, 6, 20, 0, 11, 8, 10, 7,  6, 4, 71, 5, 14, 3, 89, 2, 59, 
    7,  6, 6, 66, 3, 71, 0, 73, 8, 16, 4, 59, 5,  4, 1, 37, 2, 49, 
    2, 26, 4, 76, 5, 74, 8, 24, 0, 85, 1, 80, 6, 87, 7, 39, 3, 23, 
    0, 42, 4, 56, 1, 81, 7, 13, 3, 24, 5, 42, 8, 94, 2, 15, 6, 95
  };
  const int q7412[] = {
    9, 9, // Number of jobs and machines
    8, 72, 7, 45, 0, 93, 4, 99, 5, 50, 1, 34, 3,  1, 6, 21, 2, 20, 
    7,  4, 6, 41, 4, 79, 8, 87, 0, 80, 2, 51, 5, 69, 3, 95, 1, 55, 
    7, 85, 6, 71, 2,  4, 3, 60, 5, 19, 1, 10, 0, 21, 4, 83, 8, 48, 
    3, 13, 0, 52, 2, 53, 5, 73, 6, 45, 7, 84, 8, 23, 1, 76, 4, 50, 
    1, 27, 5, 49, 6, 72, 2, 54, 3, 14, 4, 95, 7, 13, 8, 11, 0, 73, 
    7, 12, 0, 50, 4, 39, 2, 99, 1, 54, 5, 84, 3, 15, 8, 15, 6, 79, 
    2, 50, 7, 85, 8, 97, 5,  6, 1, 78, 6, 60, 4, 70, 0, 21, 3, 99, 
    0, 60, 3, 89, 6, 41, 1, 74, 7, 25, 8, 25, 2, 85, 5, 75, 4,  7, 
    4, 93, 8,  5, 7, 13, 5, 70, 3, 96, 1, 13, 6, 57, 2, 12, 0, 17
  };
  const int q7413[] = {
    9, 9, // Number of jobs and machines
    3, 25, 1,  4, 4,  6, 0, 27, 7, 61, 2, 96, 8, 56, 5,  5, 6, 24, 
    7, 63, 2, 65, 0, 34, 6, 66, 3, 60, 4, 84, 8, 67, 1, 87, 5, 51, 
    1, 22, 4, 65, 5, 14, 2,  5, 3, 36, 0, 11, 7, 74, 6, 76, 8, 95, 
    8, 39, 6, 50, 4, 66, 2, 26, 1, 97, 7, 43, 5, 27, 3, 55, 0, 49, 
    6, 87, 2, 60, 1, 88, 8,  1, 7, 52, 3, 76, 5, 91, 4, 86, 0, 46, 
    7, 57, 5, 12, 8, 15, 6, 59, 3, 52, 0, 52, 4, 81, 2, 28, 1, 92, 
    6, 62, 2, 57, 1, 98, 7, 56, 3, 21, 0, 33, 5, 22, 8, 52, 4, 19, 
    8,  9, 0, 90, 5, 18, 4, 62, 3, 16, 2, 64, 7, 21, 6, 21, 1, 62, 
    4, 55, 0,  7, 8, 30, 2, 97, 1, 73, 5, 57, 3, 30, 6, 92, 7, 27
  };
  const int q7414[] = {
    9, 9, // Number of jobs and machines
    8, 19, 3, 98, 6,  4, 7, 38, 5, 50, 1,  4, 4, 95, 0, 57, 2, 53, 
    8, 90, 6, 67, 0, 53, 5, 41, 2, 33, 3, 81, 7, 70, 1, 80, 4, 42, 
    0, 58, 1, 91, 7, 19, 5, 48, 2, 78, 4, 15, 3, 93, 6, 71, 8, 64, 
    7, 86, 4, 59, 5, 57, 0, 39, 8, 85, 1, 66, 6, 53, 3,  3, 2,  4, 
    1, 27, 6, 23, 4, 76, 0, 88, 3, 24, 7, 31, 8, 68, 2, 23, 5, 94, 
    7, 75, 1, 84, 5, 45, 2, 97, 6, 41, 4, 63, 3,  2, 0, 95, 8, 20, 
    2, 40, 8, 85, 4,  2, 7, 73, 6, 26, 5, 77, 3, 96, 0, 15, 1,  6, 
    3, 10, 8, 30, 1, 44, 5,  4, 4, 80, 7, 19, 2, 69, 0, 35, 6, 74, 
    3, 39, 2, 29, 1, 71, 5, 17, 0, 54, 6, 20, 7, 83, 8, 99, 4, 24
  };
  const int q7415[] = {
    9, 9, // Number of jobs and machines
    7, 26, 2, 66, 8, 36, 3, 82, 5, 83, 0, 98, 1, 73, 6, 98, 4,  2, 
    3, 75, 0, 35, 6, 79, 1, 53, 2, 87, 8, 49, 4, 13, 5, 53, 7,  2, 
    6, 93, 7, 51, 0, 95, 2, 37, 8,  7, 5, 26, 4, 74, 3, 73, 1, 93, 
    4, 74, 3, 94, 6, 25, 7, 51, 0, 82, 8, 38, 1, 84, 2, 99, 5, 52, 
    3, 42, 8, 48, 0, 47, 5, 46, 7, 31, 6, 10, 4, 54, 1, 98, 2, 87, 
    2, 76, 5, 69, 7, 28, 4, 93, 0, 50, 8, 97, 3, 77, 1, 10, 6, 73, 
    3, 63, 1, 13, 6, 30, 5, 46, 4, 34, 8, 91, 0, 88, 7, 88, 2, 37, 
    4, 55, 3, 43, 8, 42, 2,  2, 7, 64, 1, 86, 5, 91, 0, 87, 6,  3, 
    2, 77, 8,  8, 5, 97, 4, 69, 6, 84, 0, 19, 3, 66, 7, 55, 1, 17
  };
  const int q7416[] = {
    9, 9, // Number of jobs and machines
    8, 84, 2, 50, 0, 16, 4, 23, 5, 11, 6, 51, 1, 69, 7, 23, 3, 34, 
    3, 93, 5, 75, 2, 93, 6, 46, 4, 34, 8, 99, 7, 74, 1, 97, 0,  1, 
    4, 46, 1, 38, 7, 77, 0, 35, 5, 22, 6, 75, 8, 15, 2, 59, 3, 62, 
    5, 27, 7, 78, 0, 95, 3, 33, 2, 25, 6, 15, 4,  1, 8, 60, 1,  7, 
    2, 25, 0, 95, 8, 76, 5, 31, 4,  1, 3, 94, 1, 36, 7,  9, 6, 10, 
    8, 24, 0, 16, 2, 63, 5, 74, 3, 34, 6, 49, 7, 34, 4,  6, 1, 91, 
    6, 31, 2, 67, 3, 71, 7, 65, 1, 39, 0, 80, 4, 61, 5, 87, 8, 61, 
    3, 61, 6, 32, 7, 28, 5, 94, 2, 76, 4, 45, 0, 95, 8, 31, 1, 23, 
    0, 12, 5, 66, 7,  6, 2, 48, 4, 17, 3, 93, 8, 86, 1, 92, 6,  1
  };
  const int q7417[] = {
    9, 9, // Number of jobs and machines
    2, 20, 6,  5, 7, 30, 0, 23, 5, 11, 8, 14, 1, 76, 4, 12, 3, 53, 
    2, 96, 0, 80, 1, 95, 4, 15, 5, 64, 8, 80, 6, 12, 7, 38, 3, 42, 
    1, 21, 7, 17, 4, 14, 3, 28, 0, 28, 8, 25, 6, 97, 5, 26, 2, 45, 
    1, 79, 8, 16, 7,  4, 3,  9, 2, 88, 4, 72, 5, 13, 6, 84, 0, 40, 
    5, 82, 1, 70, 3, 93, 0,  2, 8, 24, 2, 37, 4, 91, 6, 25, 7, 33, 
    5, 40, 2, 47, 3, 78, 4, 75, 6, 41, 1, 55, 8, 92, 0, 88, 7, 43, 
    3, 33, 2, 91, 4, 18, 1, 50, 6, 94, 0, 56, 8, 30, 7, 88, 5, 14, 
    7, 84, 5, 28, 0, 39, 4, 12, 2, 37, 1, 97, 8, 75, 6,  3, 3, 99, 
    5, 68, 7, 97, 0, 17, 8, 83, 2, 24, 3, 88, 6, 78, 1, 18, 4, 69
  };
  const int q7418[] = {
    9, 9, // Number of jobs and machines
    7, 42, 4, 17, 2, 33, 5, 43, 3,  6, 8, 54, 0, 62, 6, 61, 1, 83, 
    0, 72, 4, 61, 1, 42, 2,  3, 8, 70, 7, 54, 3, 70, 5, 31, 6, 86, 
    1, 39, 6, 67, 2, 94, 8,  4, 5, 10, 0, 81, 4, 22, 3, 21, 7,  5, 
    6, 79, 5,  6, 1, 68, 8, 56, 3, 54, 4, 54, 7, 16, 2, 10, 0, 22, 
    2, 49, 1, 80, 7, 37, 4, 68, 6, 66, 0, 85, 3, 91, 8, 81, 5, 13, 
    0, 76, 8, 36, 4, 23, 1, 33, 7,  9, 3, 67, 2, 87, 5, 41, 6, 14, 
    6, 50, 4, 85, 0, 70, 2, 96, 8, 47, 7, 13, 1, 52, 3, 23, 5, 40, 
    3, 34, 4, 38, 1, 54, 8, 96, 2,  8, 5, 49, 7, 98, 0, 97, 6, 51, 
    0, 33, 6, 32, 2,  3, 5, 72, 8, 62, 4, 17, 1, 50, 3, 54, 7, 61
  };
  const int q7419[] = {
    9, 9, // Number of jobs and machines
    1, 58, 2, 17, 6, 31, 5, 66, 3, 74, 7, 61, 4, 24, 8, 97, 0, 38, 
    4, 43, 6, 41, 7,  8, 5, 29, 8,  7, 0, 50, 1, 50, 3, 40, 2, 87, 
    0, 34, 6, 84, 8,  4, 7, 46, 2, 86, 1, 66, 4, 73, 5, 59, 3, 60, 
    4,  6, 0, 72, 8,  7, 2, 14, 6, 14, 1, 33, 5, 26, 7, 85, 3, 78, 
    2, 92, 7, 34, 6, 49, 5, 79, 0, 72, 4, 34, 8, 35, 1,  9, 3,  1, 
    8, 20, 0, 92, 7, 87, 3, 20, 2,  9, 4, 66, 6, 17, 1, 28, 5, 43, 
    2, 83, 7, 95, 4, 74, 3, 90, 1, 83, 8, 56, 6, 61, 0, 56, 5, 90, 
    6, 78, 1, 97, 4, 20, 2, 61, 3, 44, 8, 77, 7, 38, 5, 23, 0, 41, 
    3, 16, 8, 21, 0, 49, 5, 33, 2, 57, 1, 68, 4, 95, 6, 78, 7, 64
  };
  const int q7420[] = {
    9, 9, // Number of jobs and machines
    7, 70, 0,  6, 2, 37, 5, 64, 3, 16, 1, 59, 6, 75, 4, 57, 8, 55, 
    6, 83, 8, 75, 4, 36, 5, 17, 3, 72, 2, 93, 1,  2, 7, 73, 0,  5, 
    4, 58, 8, 98, 0, 33, 7, 57, 6,  8, 5, 97, 1, 60, 2,  2, 3, 35, 
    4, 91, 3, 23, 7, 41, 6, 18, 8, 97, 1, 52, 2, 91, 5, 78, 0, 52, 
    0, 87, 1, 70, 8, 37, 2,  7, 4, 92, 3, 36, 5, 99, 7, 78, 6, 27, 
    1,  3, 2, 31, 5,  1, 0,  4, 7, 81, 6, 48, 4, 36, 3, 73, 8,  7, 
    3, 61, 7, 53, 2, 90, 6, 35, 4,  1, 1, 26, 5, 18, 0, 54, 8, 64, 
    7, 24, 6, 18, 1, 40, 2, 49, 5, 57, 4, 15, 8, 71, 3, 23, 0, 71, 
    5, 18, 8,  5, 2, 37, 1,  2, 6, 88, 7, 24, 0, 21, 3, 38, 4, 90
  };
  const int q7421[] = {
    9, 9, // Number of jobs and machines
    1, 98, 6, 91, 8,  6, 2, 11, 4, 30, 0, 73, 7, 69, 3,  1, 5, 58, 
    8, 25, 7, 36, 2, 90, 0, 98, 3, 40, 5, 63, 1, 82, 6, 43, 4, 60, 
    2, 28, 5, 75, 4, 18, 8, 80, 7, 47, 3, 59, 1, 46, 6,  2, 0, 83, 
    3, 37, 6, 66, 5,  8, 2, 81, 0, 95, 7,  4, 8, 34, 4, 53, 1, 37, 
    8,  8, 7, 22, 1, 66, 5, 41, 0, 69, 4, 79, 6, 39, 3, 37, 2, 64, 
    3, 93, 0, 83, 7, 65, 8, 32, 4,  3, 2, 13, 5, 27, 1, 66, 6, 25, 
    8, 74, 5, 15, 2, 57, 7, 26, 1, 84, 4, 12, 6, 46, 3, 53, 0, 59, 
    5, 85, 0, 85, 8, 30, 3, 95, 1, 19, 6, 48, 4, 39, 7, 90, 2, 41, 
    7, 66, 0, 33, 8, 93, 3, 94, 6, 64, 2, 58, 5, 89, 1, 14, 4, 54
  };
  const int q7422[] = {
    9, 9, // Number of jobs and machines
    4,  9, 3, 18, 6, 60, 5, 67, 0, 55, 7, 96, 2, 71, 8, 46, 1, 22, 
    3, 78, 1, 57, 6, 47, 0, 16, 4, 59, 7, 24, 5, 63, 8, 82, 2, 95, 
    4, 52, 5, 98, 7, 92, 0, 72, 2,  4, 8, 50, 3, 78, 1, 25, 6, 37, 
    0, 49, 7, 63, 4, 62, 5, 79, 2, 82, 1, 53, 8, 66, 6, 90, 3, 50, 
    1, 53, 5, 94, 7, 51, 3, 17, 2, 35, 4, 33, 8, 60, 0,  4, 6, 71, 
    3, 62, 8, 33, 1, 44, 2, 23, 7, 20, 6, 72, 5, 74, 0, 82, 4, 16, 
    4, 10, 6, 73, 3,  6, 0, 87, 7, 88, 8, 49, 1, 10, 2, 42, 5, 13, 
    5,  9, 1, 59, 4, 82, 7,  8, 8, 84, 2, 98, 6, 85, 0, 59, 3, 26, 
    0,  3, 7, 69, 2, 92, 1, 81, 8, 61, 4, 82, 5,  5, 3, 78, 6, 75
  };
  const int q7423[] = {
    9, 9, // Number of jobs and machines
    5, 47, 2, 76, 0, 39, 8,  4, 7, 47, 4, 99, 3, 83, 6, 14, 1, 43, 
    6, 20, 4, 81, 8, 54, 3,  6, 2, 74, 5, 72, 1, 85, 0, 77, 7, 84, 
    1, 12, 2, 89, 5, 45, 0, 43, 7, 51, 4, 87, 3, 30, 6, 95, 8, 78, 
    7, 21, 4, 99, 5, 11, 8, 80, 1, 54, 3, 37, 0, 22, 2, 11, 6, 14, 
    3, 61, 0, 96, 2, 29, 1, 34, 8, 96, 4,  1, 7, 94, 6, 42, 5, 99, 
    7, 33, 5,  1, 8,  7, 4, 94, 3, 32, 1, 29, 6, 71, 2, 55, 0, 89, 
    8, 58, 6, 19, 5, 40, 1, 41, 4, 10, 3, 44, 7, 41, 0, 27, 2, 24, 
    0, 25, 4, 34, 8, 97, 6, 36, 2, 98, 5, 58, 3, 35, 1, 88, 7, 95, 
    3, 77, 7, 89, 2, 14, 4, 73, 8, 24, 6, 22, 0, 55, 1, 55, 5, 83
  };
  const int q7424[] = {
    9, 9, // Number of jobs and machines
    7, 53, 1, 34, 0, 73, 4, 42, 6, 13, 8, 29, 2, 54, 5, 65, 3, 86, 
    5, 94, 4, 43, 2, 59, 3, 88, 8, 15, 6, 35, 7, 27, 0, 15, 1, 39, 
    4,  5, 3, 71, 5, 69, 8, 19, 1,  2, 2,  6, 0, 50, 6, 79, 7, 65, 
    3, 77, 1, 74, 6, 64, 5, 24, 7, 47, 2, 28, 8, 87, 4, 60, 0, 66, 
    3, 26, 2, 44, 6,  9, 8, 84, 0, 84, 7, 84, 1, 55, 4, 60, 5, 10, 
    8, 22, 1, 51, 6, 48, 2, 88, 3, 50, 4, 50, 0, 79, 5, 44, 7, 92, 
    5, 53, 8, 23, 7, 20, 4, 21, 3, 46, 1, 54, 6,  7, 2, 66, 0, 38, 
    4, 12, 8, 81, 1,  2, 0, 19, 6, 16, 7, 39, 2, 42, 5, 23, 3, 82, 
    4, 15, 7, 69, 3, 74, 6, 76, 0, 74, 1, 25, 2, 93, 5, 78, 8, 84
  };
  const int q7425[] = {
    9, 9, // Number of jobs and machines
    0, 36, 5, 58, 3, 72, 7,  7, 4, 72, 6,  9, 8, 14, 2, 34, 1, 27, 
    4, 44, 7, 81, 8, 48, 1, 58, 2, 75, 3, 26, 5, 67, 6, 49, 0, 43, 
    8, 38, 0, 34, 3,  2, 4, 99, 1, 52, 5, 80, 7,  5, 2, 95, 6, 93, 
    5, 88, 6, 95, 0, 77, 4, 38, 1, 14, 8, 93, 3, 26, 2, 24, 7, 50, 
    5, 42, 6, 84, 0, 47, 4, 27, 7, 95, 1, 60, 8, 26, 2, 85, 3, 94, 
    3, 99, 1, 18, 8, 27, 5, 55, 6, 83, 2,  3, 4, 45, 7, 54, 0, 35, 
    0, 21, 4, 57, 5, 78, 8, 38, 6, 69, 3, 81, 1, 14, 7, 23, 2, 41, 
    4, 60, 1, 63, 2, 93, 5, 81, 0, 85, 7, 74, 3, 24, 8, 50, 6, 81, 
    0, 68, 8, 34, 3, 52, 4, 44, 7, 36, 2, 13, 6, 33, 1, 42, 5, 42
  };
  const int q7426[] = {
    9, 9, // Number of jobs and machines
    7, 61, 0, 86, 3, 96, 2, 83, 8, 14, 6, 19, 5,  4, 1, 50, 4, 28, 
    3, 56, 1, 58, 0, 24, 6, 12, 5, 95, 7, 60, 8, 61, 2, 67, 4, 48, 
    6, 38, 2, 76, 7, 55, 1,  8, 3, 80, 0, 87, 5, 76, 4, 37, 8, 83, 
    2, 45, 0, 15, 4, 27, 3, 60, 6, 90, 8, 32, 5, 22, 1, 91, 7,  4, 
    0, 53, 7, 23, 3, 57, 2, 84, 5, 59, 1, 87, 4, 84, 6,  6, 8, 84, 
    7, 78, 6, 33, 2, 84, 5, 25, 8, 66, 4, 58, 1, 62, 3,  7, 0, 14, 
    2, 21, 7, 74, 5, 59, 1, 20, 6,  6, 3, 93, 8, 89, 4, 21, 0, 93, 
    3, 51, 1, 42, 7, 64, 6,  1, 8, 18, 4, 63, 0, 94, 5, 27, 2,  7, 
    8, 50, 2, 61, 4, 14, 5, 91, 1, 30, 3, 69, 6, 44, 0, 95, 7, 78
  };
  const int q7427[] = {
    9, 9, // Number of jobs and machines
    3, 64, 6, 21, 2, 89, 0,  8, 4, 82, 8, 89, 5, 37, 7, 45, 1, 86, 
    6, 48, 5, 29, 8, 67, 7, 74, 4, 75, 0, 25, 1, 31, 2, 99, 3, 79, 
    4, 35, 7, 48, 1, 61, 2, 90, 3, 99, 0, 58, 8, 93, 5, 30, 6, 49, 
    6, 63, 7, 21, 3, 34, 0, 52, 1, 73, 4, 66, 8, 42, 5, 92, 2, 72, 
    8, 10, 7, 24, 0, 17, 6, 76, 1, 26, 4, 38, 5, 81, 2, 40, 3, 78, 
    0,  6, 5, 28, 7, 75, 1, 46, 6, 48, 4, 79, 3,  7, 8, 36, 2, 83, 
    8, 52, 3, 21, 0, 81, 1, 67, 6, 79, 7, 50, 4, 75, 5, 57, 2, 84, 
    8, 21, 0,  3, 4, 26, 1, 41, 7, 39, 6, 75, 3, 62, 5, 68, 2, 77, 
    8, 74, 4, 11, 5, 12, 1, 63, 6, 23, 7, 60, 2, 56, 3, 54, 0, 70
  };
  const int q7428[] = {
    9, 9, // Number of jobs and machines
    7, 20, 0, 84, 4, 59, 3, 49, 8, 25, 1, 71, 2, 33, 6,  8, 5, 64, 
    8, 62, 2, 19, 1, 86, 3, 85, 0, 58, 7, 64, 5, 89, 4, 40, 6, 22, 
    1, 78, 7, 50, 6, 53, 4, 75, 3, 71, 0, 33, 2,  5, 8, 51, 5, 57, 
    7, 53, 5, 81, 4, 70, 1, 89, 2, 34, 3, 88, 0, 93, 6, 22, 8, 55, 
    1,  9, 8, 85, 6, 50, 4, 43, 3, 72, 2, 89, 0, 19, 7, 54, 5, 31, 
    4, 98, 0, 80, 7, 73, 2, 14, 6, 69, 8, 18, 1, 43, 5, 80, 3, 38, 
    4,  3, 8, 19, 7, 49, 0, 38, 1, 38, 5, 27, 2, 16, 6, 33, 3, 37, 
    3, 31, 8, 53, 1, 10, 6, 96, 0,  8, 4, 11, 7, 44, 2, 67, 5, 47, 
    5, 57, 4, 52, 3, 46, 2, 14, 7, 65, 0,  3, 8, 90, 1, 15, 6, 82
  };
  const int q7429[] = {
    9, 9, // Number of jobs and machines
    3, 55, 7, 34, 8,  8, 4, 28, 5, 42, 0, 27, 6, 82, 1, 67, 2, 29, 
    5, 52, 2, 25, 3, 54, 0, 61, 7, 77, 1, 61, 4, 45, 6, 20, 8, 58, 
    2, 89, 6, 35, 7, 64, 5, 95, 8, 90, 0, 21, 4, 54, 1, 38, 3, 42, 
    8,  6, 5, 89, 2, 84, 0, 78, 6, 72, 3, 24, 1, 84, 7, 89, 4, 42, 
    5, 76, 4, 23, 1, 63, 7, 92, 8,  4, 0, 75, 3, 29, 6, 27, 2, 23, 
    6, 65, 3,  8, 0, 29, 4, 33, 5, 62, 8, 82, 7, 41, 2, 23, 1, 99, 
    3, 82, 2, 95, 0, 37, 1, 21, 8, 48, 5, 88, 6, 74, 7, 81, 4, 16, 
    2, 99, 8, 40, 1, 18, 3, 23, 7, 33, 6, 63, 5, 30, 0,  7, 4, 16, 
    6, 12, 0, 15, 2, 41, 5, 62, 8, 78, 7, 23, 4, 52, 3,  8, 1, 23
  };
  const int q7430[] = {
    9, 9, // Number of jobs and machines
    5, 88, 8,  2, 2, 87, 7,  1, 1, 67, 6, 57, 3,  6, 0, 31, 4, 22, 
    7, 59, 4, 86, 0, 55, 5,  1, 8, 14, 2, 92, 1, 58, 6,  7, 3, 39, 
    6, 67, 0, 41, 4, 76, 1, 33, 8, 43, 7, 73, 2, 45, 3, 21, 5, 42, 
    0,  4, 5, 60, 7, 66, 2, 26, 4, 43, 6, 51, 1, 52, 3, 11, 8, 30, 
    8, 76, 5, 34, 4, 16, 3, 17, 2, 80, 0, 42, 1, 28, 6, 43, 7, 96, 
    2, 85, 8,  1, 1, 42, 3, 76, 6, 51, 5, 19, 0, 56, 7, 70, 4, 18, 
    0,  5, 5, 33, 2, 83, 8, 13, 3, 83, 4, 79, 1, 52, 7, 80, 6, 87, 
    7, 17, 1,  1, 5, 44, 2, 21, 8, 54, 0, 28, 6, 47, 3, 89, 4, 65, 
    0, 37, 1, 46, 3, 49, 4, 33, 5,  2, 6, 66, 8, 92, 7, 46, 2, 19
  };
  const int q7431[] = {
    9, 9, // Number of jobs and machines
    1, 24, 6, 70, 3, 83, 2, 24, 8, 81, 0, 76, 4, 14, 5, 86, 7, 65, 
    8, 24, 3, 20, 5, 26, 2, 67, 0, 98, 1, 93, 4,  1, 7, 40, 6, 79, 
    4,  9, 0, 41, 3, 70, 5, 98, 1, 69, 6, 40, 2, 68, 8, 32, 7, 64, 
    5,  9, 1, 62, 0, 27, 6, 19, 2, 69, 8, 53, 3, 14, 7,  3, 4, 16, 
    4,  4, 7, 47, 6, 16, 8, 71, 1, 14, 2,  6, 3, 49, 5, 64, 0, 94, 
    0, 96, 2, 20, 3, 13, 1, 48, 4, 59, 5, 94, 8, 70, 6, 30, 7, 41, 
    1, 98, 7,  2, 2, 32, 8, 35, 5, 26, 6, 89, 4, 46, 3, 92, 0, 72, 
    8, 22, 3, 15, 7, 21, 2, 41, 6, 81, 0, 18, 4, 47, 5,  4, 1, 10, 
    2, 35, 1, 71, 5, 83, 0, 45, 6, 92, 7, 68, 4,  4, 8, 10, 3, 84
  };
  const int q7432[] = {
    9, 9, // Number of jobs and machines
    0, 55, 3, 18, 2, 63, 4, 13, 7, 39, 5, 64, 1, 50, 8, 50, 6,  7, 
    7, 35, 2,  5, 1, 35, 3, 87, 4, 91, 8, 38, 6,  1, 5, 96, 0, 60, 
    0, 93, 2, 95, 4, 73, 6, 18, 1, 85, 5, 90, 8, 88, 3, 31, 7, 93, 
    3, 80, 5,  9, 1, 44, 4, 99, 7, 79, 2,  7, 8, 87, 0, 54, 6, 30, 
    5, 22, 8, 97, 1, 18, 6, 96, 4, 94, 0, 97, 7, 37, 3, 70, 2, 68, 
    5, 51, 4, 47, 7, 56, 1, 27, 6, 61, 8, 22, 2, 79, 0, 53, 3, 91, 
    6, 57, 4, 40, 2, 81, 0, 27, 3, 24, 5, 92, 7, 72, 1, 74, 8, 35, 
    7, 40, 3, 92, 2, 66, 8, 14, 0,  6, 6, 68, 5, 33, 1, 51, 4, 74, 
    6, 39, 5, 58, 1, 26, 8, 72, 4, 13, 3,  7, 0, 12, 2, 47, 7,  4
  };
  const int q7433[] = {
    9, 9, // Number of jobs and machines
    6, 87, 3, 60, 5, 95, 0, 66, 8,  2, 4, 42, 1, 45, 7, 24, 2, 71, 
    2, 94, 5, 71, 3, 29, 0,  4, 8, 53, 1, 14, 7, 80, 6, 44, 4, 41, 
    3, 70, 7, 59, 5, 99, 4, 67, 0, 91, 2, 64, 6, 15, 8, 19, 1, 55, 
    7, 89, 0,  6, 5, 30, 4, 77, 3, 40, 2, 79, 6, 66, 8, 60, 1, 24, 
    1, 75, 4, 11, 8, 29, 6,  1, 2, 66, 3, 26, 7, 14, 5, 99, 0, 69, 
    0, 38, 4, 81, 6, 33, 3, 25, 1, 49, 7, 98, 2, 66, 5, 25, 8,  4, 
    4, 58, 2, 16, 3, 88, 1, 87, 8, 63, 5, 28, 0, 99, 7, 58, 6, 16, 
    4, 31, 1, 84, 8, 34, 2, 53, 5, 72, 0, 31, 6, 57, 3, 95, 7, 96, 
    7, 10, 0, 10, 2,  6, 8, 45, 5, 63, 1, 14, 3, 34, 4, 49, 6, 76
  };
  const int q7434[] = {
    9, 9, // Number of jobs and machines
    0,  4, 6, 23, 4, 36, 5, 69, 7, 75, 8, 18, 3, 78, 1, 61, 2, 81, 
    8, 26, 1, 98, 3, 79, 7, 22, 2, 97, 5,  5, 0, 48, 6, 36, 4, 53, 
    0, 75, 7, 46, 3, 56, 4, 57, 2,  8, 8, 28, 6, 57, 5, 19, 1, 84, 
    0, 57, 6, 59, 5, 28, 1, 67, 4, 62, 3, 59, 7, 16, 8, 42, 2, 55, 
    0, 67, 1, 88, 8, 55, 7, 54, 5, 37, 6, 50, 3, 95, 2, 47, 4, 62, 
    8, 81, 5, 12, 2,  6, 1, 51, 6, 75, 0, 70, 7, 80, 4, 54, 3, 77, 
    3, 51, 5,  9, 1,  9, 0, 12, 7, 45, 8, 85, 4, 65, 2, 10, 6, 94, 
    2, 51, 6, 33, 8, 24, 5, 35, 1, 49, 3, 96, 0, 35, 4, 16, 7,  4, 
    8, 76, 4, 53, 2, 91, 7,  6, 5, 39, 0, 73, 1, 17, 6, 33, 3, 16
  };
  const int q7435[] = {
    9, 9, // Number of jobs and machines
    8, 48, 7,  7, 0, 58, 4, 64, 6, 53, 3, 64, 5, 11, 2, 15, 1,  2, 
    7, 81, 6, 51, 3, 86, 8, 78, 2, 69, 4, 80, 1,  1, 0, 43, 5, 18, 
    3, 80, 1, 91, 7, 35, 0, 67, 6, 47, 2, 97, 4, 59, 8, 48, 5, 85, 
    8, 61, 7, 18, 0,  5, 4,  6, 3, 73, 1, 74, 2, 31, 6, 37, 5, 24, 
    3, 64, 0, 52, 2, 41, 1, 50, 5, 35, 6, 37, 8, 71, 4, 24, 7, 29, 
    2, 80, 4, 19, 1, 49, 3, 38, 8, 15, 0, 95, 6,  5, 5, 95, 7, 18, 
    4, 50, 1, 54, 8, 84, 2, 25, 5,  4, 0, 76, 7, 39, 3, 53, 6, 94, 
    3, 53, 5, 44, 8, 33, 0, 52, 7, 67, 1, 71, 6, 70, 4, 68, 2, 48, 
    6, 40, 0, 86, 7, 35, 2,  4, 5, 56, 3, 19, 1, 52, 4, 37, 8, 48
  };
  const int q7436[] = {
    9, 9, // Number of jobs and machines
    5, 82, 2,  5, 0, 75, 8, 28, 1, 49, 4, 24, 7, 39, 3, 70, 6, 27, 
    3, 52, 4, 83, 7, 18, 8, 53, 0, 55, 1, 63, 5, 88, 2, 55, 6, 72, 
    3, 95, 5, 64, 4, 94, 6, 58, 2, 72, 8, 65, 0, 77, 7, 15, 1, 16, 
    2, 96, 7, 47, 0, 56, 1, 53, 5, 66, 4, 62, 6, 25, 8, 83, 3, 84, 
    5, 55, 3, 62, 2, 86, 7, 97, 1, 14, 4, 45, 6, 98, 8, 13, 0,  4, 
    6, 35, 8, 42, 3, 63, 0, 82, 7, 75, 4, 69, 5, 74, 2,  5, 1, 51, 
    0, 46, 5, 46, 2, 20, 4, 29, 8, 48, 3, 66, 1, 27, 6, 44, 7, 97, 
    1, 92, 2, 96, 3, 58, 4, 56, 8,  6, 5, 56, 0, 40, 7, 18, 6, 35, 
    7, 84, 3, 67, 2, 30, 5, 43, 8, 16, 0, 91, 1, 71, 6, 86, 4, 82
  };
  const int q7437[] = {
    9, 9, // Number of jobs and machines
    0, 86, 6, 72, 4, 31, 3, 68, 1, 21, 2, 57, 7, 66, 5, 70, 8, 42, 
    2, 84, 7, 12, 1, 41, 4, 54, 6, 51, 0, 29, 5, 17, 8, 50, 3, 68, 
    0,  5, 1, 97, 7, 61, 8, 66, 4, 26, 3, 78, 5, 61, 6, 63, 2, 83, 
    2, 93, 1, 13, 6, 65, 0, 76, 5, 92, 8, 46, 4, 59, 3, 26, 7, 31, 
    4, 40, 0,  4, 7, 67, 2, 96, 5, 13, 8, 22, 1, 41, 6, 71, 3, 46, 
    1, 76, 3, 70, 4, 17, 5, 15, 2, 85, 0, 51, 6, 99, 8, 26, 7, 14, 
    1, 92, 8, 50, 3, 39, 4, 25, 2, 21, 6,  3, 5, 93, 0, 73, 7, 38, 
    4, 40, 6, 16, 3, 51, 1, 69, 2, 50, 7, 54, 5, 43, 8, 25, 0, 56, 
    4, 21, 3, 66, 1, 84, 0, 46, 8, 94, 7, 10, 5,  5, 6, 10, 2, 72
  };
  const int q7438[] = {
    9, 9, // Number of jobs and machines
    8, 52, 5,  5, 7, 62, 0, 67, 6, 95, 1, 77, 3, 50, 4, 19, 2, 37, 
    5, 30, 1,  5, 7,  8, 2,  9, 3, 97, 6, 60, 4, 53, 8, 32, 0, 88, 
    7, 52, 2,  6, 3, 11, 1, 67, 8, 54, 0, 75, 6,  3, 4, 89, 5, 96, 
    2, 26, 7, 37, 0, 83, 5, 87, 4, 22, 8, 50, 1,  5, 3, 30, 6, 74, 
    3, 58, 7, 80, 5, 96, 2, 52, 0, 15, 8, 96, 1, 50, 6, 82, 4, 69, 
    4, 99, 5, 79, 8, 56, 2, 40, 3, 52, 7, 91, 6, 27, 1, 18, 0, 23, 
    8, 37, 4, 29, 2, 57, 1, 46, 7, 90, 3, 57, 0, 26, 6, 32, 5, 14, 
    3, 39, 5, 90, 7, 34, 8, 36, 2, 46, 0, 19, 6, 93, 4, 89, 1,  6, 
    8, 67, 1, 39, 4, 58, 5,  4, 0, 92, 7, 55, 2, 42, 6, 71, 3, 68
  };
  const int q7439[] = {
    9, 9, // Number of jobs and machines
    1, 91, 0, 90, 8, 41, 4, 18, 3, 77, 2, 74, 6,  6, 7, 33, 5, 42, 
    6, 87, 5, 48, 2, 80, 1,  3, 0, 22, 3, 71, 7, 36, 8, 29, 4, 91, 
    0, 60, 8, 98, 1,  5, 3, 10, 4, 27, 6, 46, 7, 98, 5, 82, 2, 41, 
    0, 13, 2,  3, 8, 41, 7, 16, 3, 82, 4, 52, 5, 90, 1, 33, 6, 42, 
    8, 94, 3, 98, 5, 49, 0,  1, 2, 90, 1, 51, 6, 24, 4, 89, 7, 12, 
    3, 40, 5, 13, 7, 39, 4, 52, 2, 10, 6, 58, 8, 54, 0, 61, 1, 47, 
    2, 37, 5, 34, 3, 59, 7, 24, 0, 59, 4, 93, 6, 49, 1, 46, 8, 45, 
    6, 52, 5, 40, 8, 29, 4, 23, 3, 52, 0, 64, 2, 98, 1, 58, 7, 56, 
    2, 74, 4, 38, 8, 96, 5, 89, 1, 32, 0, 64, 7, 42, 3, 40, 6, 45
  };
  const int q7440[] = {
    9, 9, // Number of jobs and machines
    8, 66, 5,  6, 1, 13, 4, 84, 3, 26, 6, 44, 2, 70, 0, 90, 7, 30, 
    0, 67, 5, 48, 4, 95, 8, 37, 2, 38, 7, 50, 1, 65, 3, 34, 6, 65, 
    3, 50, 6, 93, 2, 87, 0, 41, 8, 91, 5, 55, 4, 70, 7, 96, 1, 69, 
    4,  2, 8,  3, 7, 21, 6, 26, 1, 31, 5, 26, 3, 90, 2, 62, 0, 77, 
    6, 13, 5, 15, 4, 50, 8, 66, 7, 28, 1, 82, 3, 37, 2, 80, 0, 56, 
    1, 58, 4, 96, 2, 48, 8, 91, 6, 22, 3,  7, 0, 58, 5, 20, 7, 82, 
    0, 91, 7, 23, 6, 56, 5, 99, 2, 58, 4, 65, 1, 70, 8, 48, 3, 12, 
    4, 55, 6, 11, 1, 86, 0, 71, 7, 83, 2, 46, 3, 89, 8, 14, 5, 29, 
    5,  8, 2, 51, 0, 19, 4, 61, 3, 93, 1, 57, 6, 64, 7, 46, 8, 31
  };
  const int q7441[] = {
    9, 9, // Number of jobs and machines
    2, 12, 6, 36, 7, 85, 3, 51, 4, 12, 0, 62, 1, 75, 8, 26, 5, 90, 
    2, 74, 0, 66, 8, 11, 6, 14, 4, 15, 3, 37, 1, 65, 7, 77, 5, 21, 
    1, 55, 4, 22, 0, 81, 3, 58, 6, 29, 7,  4, 5, 76, 2, 69, 8, 94, 
    4, 23, 6, 62, 8, 26, 2, 69, 7, 14, 5, 84, 1, 16, 3, 77, 0, 45, 
    2,  1, 1,  9, 6, 92, 0, 24, 7, 46, 4, 87, 5, 35, 8, 52, 3, 40, 
    3, 33, 4, 90, 2, 34, 0, 95, 1, 49, 7, 91, 8, 78, 6, 52, 5, 61, 
    5,  7, 4, 59, 3, 61, 1, 45, 0, 62, 6,  4, 7, 45, 2, 98, 8, 67, 
    1, 52, 2,  1, 4, 51, 0, 69, 5, 26, 7, 31, 3, 37, 6, 10, 8,  5, 
    7, 36, 8, 71, 1, 13, 0, 42, 4, 48, 3, 46, 6, 46, 2, 36, 5,  4
  };
  const int q7442[] = {
    9, 9, // Number of jobs and machines
    4, 30, 2, 93, 0, 97, 8, 70, 7, 13, 3,  8, 5,  1, 6, 33, 1,  6, 
    3, 98, 0, 93, 6, 75, 8, 16, 5, 45, 2, 69, 7, 16, 4, 67, 1, 52, 
    4, 52, 0, 89, 8, 90, 7, 88, 3, 90, 6, 29, 5, 19, 2, 12, 1, 73, 
    7, 12, 5, 33, 3, 38, 1, 14, 0, 54, 2, 90, 8, 78, 4, 49, 6, 64, 
    1, 26, 6, 56, 0, 74, 4, 71, 8, 15, 5,  2, 2, 22, 7, 37, 3, 38, 
    8, 23, 2, 91, 6, 23, 7, 69, 3, 42, 1, 71, 4, 57, 0, 56, 5, 98, 
    8, 58, 1, 90, 3,  8, 5, 73, 0, 29, 2, 87, 4, 43, 7, 91, 6, 54, 
    8, 44, 3, 94, 6, 13, 1, 28, 5, 97, 2, 11, 0, 29, 4, 62, 7, 60, 
    0, 23, 3, 91, 8, 36, 7, 46, 5, 46, 1, 34, 2, 88, 4, 53, 6, 91
  };
  const int q7443[] = {
    9, 9, // Number of jobs and machines
    7, 68, 4, 62, 0, 76, 8, 19, 2, 74, 6, 53, 5, 60, 1, 30, 3, 60, 
    2, 39, 4, 62, 6,  7, 3, 85, 8, 52, 1, 47, 0, 61, 5, 35, 7, 44, 
    7, 41, 6, 60, 3, 24, 0, 30, 1, 19, 5, 29, 8, 61, 2, 68, 4, 65, 
    4,  2, 1, 88, 7,  6, 5, 80, 3, 61, 2, 96, 8, 71, 0, 35, 6, 46, 
    8, 40, 5, 34, 3, 44, 7, 26, 2, 87, 1, 29, 6,  7, 4, 46, 0, 95, 
    4,  3, 3, 83, 5,  6, 7, 92, 2, 71, 0, 93, 8, 41, 1, 20, 6,  9, 
    3, 34, 0, 22, 4, 10, 8, 63, 5, 59, 2, 29, 6, 17, 1, 33, 7, 25, 
    0, 91, 6,  3, 4, 41, 3, 20, 8, 32, 7,  3, 2, 26, 1, 51, 5, 33, 
    7, 42, 3, 26, 6, 25, 4, 32, 0, 20, 5, 23, 2, 91, 8, 66, 1, 52
  };
  const int q7444[] = {
    9, 9, // Number of jobs and machines
    4, 63, 2, 83, 0, 87, 1,  9, 5, 20, 8, 44, 3,  5, 6, 61, 7, 32, 
    6, 22, 2, 78, 4, 69, 0,  6, 8, 46, 5, 64, 1, 52, 7, 11, 3, 41, 
    2, 50, 8, 90, 1, 25, 6, 61, 5, 37, 4, 65, 0, 28, 3, 12, 7, 46, 
    2, 46, 6, 86, 8, 34, 4, 44, 1, 80, 7,  9, 3, 14, 0, 65, 5, 78, 
    5, 82, 4, 13, 6, 57, 8, 55, 3, 65, 7, 96, 2,  7, 1, 35, 0, 41, 
    1, 71, 5, 88, 0, 94, 2, 68, 3, 15, 6, 38, 8, 67, 7,  1, 4, 36, 
    3, 99, 0, 39, 4, 41, 2, 41, 5,  9, 8, 64, 7, 33, 1, 84, 6, 47, 
    2, 28, 7,  4, 5, 54, 3, 71, 6,  9, 4, 79, 0,  7, 1, 23, 8, 12, 
    6,  8, 4, 48, 1, 18, 0, 82, 5, 43, 8, 80, 7, 93, 3, 91, 2, 16
  };
  const int q7445[] = {
    9, 9, // Number of jobs and machines
    1, 86, 2, 64, 8, 46, 3,  1, 5, 77, 4, 96, 6, 44, 0,  1, 7,  5, 
    1, 43, 4, 39, 8, 15, 6, 97, 3, 45, 2, 95, 5, 41, 7, 56, 0, 25, 
    2, 52, 5, 36, 4, 70, 3, 91, 1, 10, 8, 69, 0, 96, 6, 10, 7, 98, 
    6, 72, 8, 89, 7, 31, 1, 40, 2, 32, 5, 83, 0, 19, 3,  3, 4, 22, 
    7, 38, 6, 68, 1, 41, 2, 93, 0,  7, 5, 46, 8, 58, 3, 61, 4, 20, 
    0, 35, 2, 52, 4, 30, 1, 83, 3, 84, 7, 79, 6, 19, 8, 58, 5, 14, 
    5, 60, 7, 24, 4, 36, 6, 72, 2, 41, 3, 94, 8, 99, 0, 85, 1, 68, 
    0, 11, 6, 66, 1, 22, 2, 28, 8, 92, 4, 87, 3, 50, 5, 47, 7, 81, 
    5, 94, 6, 45, 7, 97, 8, 27, 4, 29, 1, 26, 3, 95, 0, 37, 2, 81
  };
  const int q7446[] = {
    9, 9, // Number of jobs and machines
    2, 66, 1, 44, 0, 67, 5,  3, 7, 37, 6, 26, 8, 55, 3, 45, 4, 69, 
    2, 54, 4,  2, 7, 78, 5, 19, 6, 83, 3, 60, 0, 20, 1, 95, 8, 70, 
    6, 60, 3, 63, 1, 15, 7, 44, 4, 63, 0, 46, 8, 30, 5, 25, 2, 19, 
    6, 18, 8, 38, 3, 29, 4, 29, 1, 48, 5, 71, 2, 73, 0, 16, 7, 18, 
    6, 23, 3, 32, 4, 99, 7, 19, 5,  3, 8, 83, 0, 83, 1, 58, 2, 97, 
    4, 11, 1, 43, 7,  7, 3, 66, 5, 17, 0, 43, 6, 61, 8, 96, 2, 67, 
    2, 12, 0, 69, 3, 22, 1, 52, 5, 49, 4, 10, 8, 68, 7, 54, 6, 23, 
    2, 40, 4, 65, 7, 49, 3, 55, 6, 87, 0, 56, 5, 23, 1, 60, 8, 42, 
    2, 10, 0, 22, 5, 98, 6, 24, 8, 29, 1, 31, 3, 69, 7, 59, 4, 70
  };
  const int q7447[] = {
    9, 9, // Number of jobs and machines
    5,  7, 4, 49, 2, 31, 7, 26, 8, 90, 0, 80, 3, 41, 1, 41, 6, 81, 
    2, 32, 8, 21, 6, 93, 3, 32, 5, 70, 1, 48, 4, 36, 0, 97, 7, 14, 
    0, 31, 5, 70, 7, 45, 6, 92, 3, 62, 1, 14, 8, 21, 4,  8, 2, 12, 
    6, 88, 5, 37, 8, 70, 0, 89, 7, 90, 1, 64, 4, 34, 2, 64, 3, 66, 
    8, 96, 4, 91, 5, 98, 0, 97, 2, 78, 3, 45, 7, 46, 6, 39, 1, 22, 
    1, 80, 2, 23, 4, 30, 5, 69, 0, 75, 6, 60, 3, 19, 7,  5, 8,  7, 
    6, 69, 0, 98, 2, 66, 5, 95, 7, 93, 3, 25, 1, 77, 4, 91, 8, 74, 
    0, 39, 1, 59, 3, 57, 7,  6, 2, 63, 6, 56, 8, 53, 4,  3, 5, 89, 
    7, 15, 4, 14, 5, 73, 6, 14, 1, 69, 8, 22, 3, 72, 2, 93, 0, 20
  };
  const int q7448[] = {
    9, 9, // Number of jobs and machines
    1, 25, 7, 30, 3, 25, 5, 69, 4, 97, 6, 32, 0, 67, 2, 26, 8, 52, 
    2,  9, 6, 46, 5, 84, 7, 43, 3, 85, 0, 37, 4, 32, 8, 96, 1, 46, 
    3, 98, 5, 38, 8,  5, 0, 61, 7, 75, 1, 64, 2, 65, 6, 37, 4, 42, 
    6, 60, 1, 11, 7, 48, 2, 36, 5, 94, 0, 62, 8, 83, 3, 74, 4, 87, 
    3, 56, 0,  9, 1, 41, 2, 91, 8, 11, 5, 45, 6, 60, 7, 62, 4, 48, 
    2, 16, 7, 67, 0, 32, 4, 54, 8, 99, 5, 95, 3, 19, 1, 81, 6, 20, 
    8, 21, 7, 78, 4, 97, 6, 49, 3,  8, 1, 17, 0, 87, 2, 97, 5, 13, 
    3, 87, 1, 10, 8, 47, 2, 26, 6, 95, 4, 24, 7, 30, 5, 73, 0, 30, 
    4,  8, 7, 67, 2, 42, 5, 71, 8, 41, 0, 34, 1, 26, 6, 41, 3, 31
  };
  const int q7449[] = {
    9, 9, // Number of jobs and machines
    0, 13, 2, 84, 5,  5, 3, 99, 1, 76, 7, 56, 6,  3, 4, 72, 8, 14, 
    6, 44, 8, 33, 5, 92, 3, 87, 1, 36, 7, 22, 4, 46, 0, 54, 2, 29, 
    4, 90, 2,  6, 5, 13, 3, 11, 8, 61, 0, 94, 6, 36, 7, 19, 1, 57, 
    6, 18, 1, 83, 4, 46, 3, 18, 0, 67, 8, 98, 7,  5, 2, 31, 5, 35, 
    7, 78, 6, 11, 1, 11, 8, 46, 0, 98, 2, 89, 4, 15, 5, 89, 3, 25, 
    2, 23, 7, 60, 8, 13, 1, 95, 4, 36, 6, 24, 3, 51, 0, 50, 5, 71, 
    6, 66, 8, 25, 1, 58, 5, 56, 7, 53, 3, 82, 4, 45, 0, 69, 2, 82, 
    8, 63, 1, 70, 7, 70, 4,  4, 3, 37, 5, 38, 0, 49, 6, 64, 2, 36, 
    1, 70, 6,  5, 2, 59, 3, 24, 4, 53, 5, 31, 7, 63, 8,  6, 0, 72
  };
  const int q7450[] = {
    9, 9, // Number of jobs and machines
    5, 82, 1, 12, 2, 37, 4, 29, 0, 45, 8, 98, 3, 14, 6, 55, 7, 80, 
    5, 62, 0, 45, 7, 73, 2, 15, 6, 94, 3, 13, 8, 16, 4, 77, 1, 69, 
    1, 76, 6, 48, 7, 11, 8, 20, 5, 29, 2, 67, 0, 36, 4, 92, 3, 72, 
    8, 56, 6, 46, 3, 36, 2, 30, 1, 39, 0, 18, 7, 71, 4, 98, 5, 93, 
    0, 49, 7, 18, 6, 34, 2, 80, 4,  5, 8, 52, 5, 68, 3, 52, 1, 99, 
    7, 84, 1, 67, 8, 53, 3, 37, 0, 78, 6, 41, 5, 49, 4, 62, 2, 67, 
    5, 70, 1, 19, 7, 94, 0,  8, 6, 79, 4, 73, 8, 81, 2,  5, 3, 64, 
    6, 17, 1, 89, 3, 71, 2, 26, 4, 78, 5, 65, 8, 37, 7, 65, 0, 93, 
    4, 12, 5,  5, 0, 53, 7, 48, 1, 96, 8, 32, 6, 76, 3, 45, 2, 49
  };
  const int q7451[] = {
    9, 9, // Number of jobs and machines
    2, 18, 7, 35, 6, 31, 3, 93, 8, 21, 0, 40, 1, 21, 4, 89, 5,  9, 
    5, 61, 2, 30, 6, 63, 1, 63, 8, 27, 0,  5, 4, 22, 3, 89, 7,  5, 
    2, 53, 6, 62, 4, 78, 5, 29, 3, 26, 0, 44, 1, 16, 7, 15, 8, 11, 
    0,  4, 8, 95, 7, 85, 2, 89, 3, 68, 5, 82, 6, 92, 4, 50, 1, 19, 
    0, 77, 3, 14, 1, 79, 8, 87, 2, 68, 6, 67, 7, 73, 4, 82, 5, 91, 
    5, 88, 4, 96, 7, 47, 8, 18, 3, 31, 2, 52, 6, 36, 1, 69, 0, 36, 
    7, 64, 5, 77, 3, 56, 1, 74, 6, 89, 4, 17, 0, 29, 2, 68, 8, 52, 
    2, 31, 4, 42, 3, 72, 1, 96, 5, 46, 0, 93, 8, 50, 6, 63, 7, 72, 
    4, 11, 1, 57, 5, 59, 6, 68, 7, 54, 3, 78, 2, 53, 8, 16, 0, 97
  };
  const int q7452[] = {
    9, 9, // Number of jobs and machines
    2, 62, 4, 26, 7, 59, 5, 77, 6, 38, 1, 52, 0, 39, 3, 75, 8, 33, 
    4, 69, 6, 17, 1, 80, 0, 37, 5, 25, 3, 36, 2, 57, 8, 72, 7, 76, 
    0, 44, 4, 28, 7, 95, 1, 68, 3, 99, 5, 62, 6, 40, 2, 95, 8,  3, 
    6,  5, 8, 46, 5, 55, 2, 62, 4, 41, 3, 60, 0, 88, 1, 67, 7, 45, 
    3, 67, 1, 25, 0, 12, 2, 65, 4, 13, 8, 59, 5, 49, 6,  4, 7, 61, 
    3, 84, 5, 23, 6, 29, 7,  1, 0, 29, 8, 69, 4, 14, 1, 26, 2, 37, 
    6, 76, 2, 61, 8, 87, 4, 83, 5, 64, 1, 35, 0,  3, 7, 79, 3, 78, 
    2,  3, 8, 82, 7, 17, 6, 60, 4, 39, 0, 72, 1,  3, 3, 14, 5, 87, 
    7, 99, 0,  1, 3, 53, 1, 23, 5, 17, 4, 12, 6, 76, 8, 46, 2, 46
  };
  const int q7453[] = {
    9, 9, // Number of jobs and machines
    3, 33, 5, 85, 2, 21, 6, 37, 8, 71, 1, 21, 4, 70, 0, 40, 7, 89, 
    6, 22, 5,  3, 4, 38, 3, 35, 2, 18, 1, 72, 7, 63, 0, 40, 8, 40, 
    3, 78, 4, 30, 0, 85, 6, 88, 7, 24, 5, 28, 2, 40, 8, 50, 1, 62, 
    0, 89, 1, 14, 3, 22, 5, 65, 4, 51, 8, 28, 7, 28, 6, 97, 2, 55, 
    8, 74, 6, 90, 0, 94, 7, 61, 5, 55, 2, 41, 4, 87, 1, 29, 3, 73, 
    4, 69, 8, 81, 5, 94, 2, 99, 0, 52, 3, 81, 6, 62, 7, 88, 1, 16, 
    4, 23, 8, 95, 3, 94, 5, 72, 2, 29, 1, 33, 0, 94, 6, 61, 7, 65, 
    1, 33, 7, 75, 8, 30, 4, 67, 6, 83, 5, 46, 0, 19, 2, 38, 3, 66, 
    8, 67, 5, 80, 2, 98, 4, 10, 7, 37, 0, 89, 3, 60, 6, 54, 1, 77
  };
  const int q7454[] = {
    9, 9, // Number of jobs and machines
    6, 79, 3, 58, 7,  4, 8, 17, 5, 32, 1, 61, 2, 13, 4, 21, 0, 80, 
    5, 99, 2, 91, 3, 37, 4,  3, 0, 43, 6, 66, 1, 73, 7, 46, 8, 49, 
    4, 96, 0, 67, 2, 89, 1, 95, 6, 93, 7, 90, 5,  9, 3, 67, 8, 52, 
    7, 87, 5, 32, 4, 99, 1,  5, 8, 46, 0, 52, 6, 62, 3,  1, 2,  7, 
    8, 43, 6, 26, 2, 63, 1, 59, 0, 18, 3, 60, 5, 37, 7, 21, 4,  7, 
    8, 85, 4, 77, 2, 18, 3, 45, 5, 94, 7, 43, 1, 71, 6, 89, 0, 17, 
    6, 85, 4, 95, 8, 63, 0, 10, 7, 54, 2, 42, 5, 71, 3, 78, 1, 26, 
    8, 45, 7, 81, 1, 56, 5, 60, 2, 46, 4, 94, 3, 56, 6, 43, 0, 13, 
    2,  5, 7, 60, 3, 25, 1, 47, 8, 82, 6, 73, 5, 66, 0, 75, 4, 91
  };
  const int q7455[] = {
    9, 9, // Number of jobs and machines
    6,  9, 2, 91, 4, 43, 3,  1, 1, 91, 5, 50, 0, 13, 7, 54, 8, 71, 
    0, 12, 6, 62, 5, 89, 4, 72, 1,  6, 7, 35, 3, 38, 2, 19, 8, 77, 
    3, 35, 0, 19, 8, 49, 7, 93, 1,  7, 4, 95, 2, 37, 5, 47, 6, 11, 
    0, 39, 2, 23, 8, 72, 6, 39, 4, 21, 1, 15, 5, 26, 7, 70, 3, 17, 
    1, 30, 7, 85, 8, 84, 4, 78, 0, 66, 5, 99, 3, 49, 2, 22, 6, 67, 
    3, 59, 8, 69, 0, 67, 7, 40, 6, 79, 1, 74, 4, 78, 2, 52, 5, 69, 
    8, 36, 0, 95, 2, 67, 5, 78, 4, 88, 1, 51, 6, 73, 7, 21, 3, 65, 
    0, 66, 2, 65, 3, 26, 4, 96, 1, 43, 7, 41, 8, 36, 6, 97, 5, 39, 
    8, 38, 6, 82, 0, 85, 5, 90, 4, 35, 7, 62, 1, 85, 3, 66, 2, 83
  };
  const int q7456[] = {
    9, 9, // Number of jobs and machines
    0, 21, 2, 81, 1, 70, 4, 45, 6, 42, 3, 12, 8, 32, 7, 98, 5, 38, 
    5, 70, 3, 66, 8, 26, 7, 86, 4, 30, 1, 48, 6,  9, 2, 85, 0, 83, 
    8, 98, 4, 90, 3,  4, 2, 35, 0, 56, 5, 84, 7, 86, 6, 11, 1, 69, 
    7, 20, 4, 32, 5, 33, 3, 43, 8, 61, 1, 66, 0,  5, 6, 77, 2, 83, 
    0, 61, 5, 33, 7, 10, 8, 67, 2, 77, 4, 46, 3,  6, 6, 29, 1,  4, 
    5, 30, 3, 57, 2, 40, 8, 95, 7,  7, 6, 86, 1, 52, 0,  4, 4, 94, 
    5, 39, 8, 41, 7, 37, 0, 67, 2, 63, 6, 92, 4, 50, 1, 10, 3, 75, 
    8, 17, 7, 53, 1, 91, 2, 42, 3, 88, 4, 35, 0, 77, 6, 66, 5, 27, 
    7, 93, 6, 23, 0, 94, 8, 61, 2, 58, 1, 52, 5, 58, 3, 97, 4, 45
  };
  const int q7457[] = {
    9, 9, // Number of jobs and machines
    7, 16, 8, 99, 5, 78, 0, 74, 4, 75, 2, 21, 1, 28, 6, 23, 3,  2, 
    1, 57, 2, 61, 4, 66, 0, 69, 7, 48, 8, 66, 3, 67, 5, 22, 6, 79, 
    3, 38, 2, 96, 4, 81, 5, 70, 7, 25, 8, 61, 1, 87, 0, 93, 6, 53, 
    6,  2, 4, 36, 7, 17, 0, 98, 3, 88, 2, 36, 5, 17, 8, 67, 1, 45, 
    7, 82, 1, 99, 3,  2, 2, 94, 4, 77, 6, 53, 5, 99, 0, 17, 8, 50, 
    3, 71, 0, 68, 4, 73, 1, 59, 6, 77, 2, 99, 5, 84, 8, 34, 7,  8, 
    6, 48, 4, 99, 3, 55, 1, 45, 8, 60, 2, 46, 5, 67, 7, 88, 0, 32, 
    4, 99, 3,  6, 6, 19, 1, 51, 2, 67, 7, 42, 0, 33, 5, 98, 8, 57, 
    1, 84, 5, 62, 7, 43, 4, 18, 2, 26, 0, 55, 3, 21, 6, 76, 8, 94
  };
  const int q7458[] = {
    9, 9, // Number of jobs and machines
    6,  5, 0, 29, 1, 52, 4,  7, 2, 84, 8, 28, 3, 41, 5, 17, 7, 87, 
    7, 31, 5, 87, 2, 22, 0, 62, 1, 84, 8,  1, 6, 44, 4, 38, 3, 89, 
    3,  1, 8, 63, 4, 41, 0, 98, 5, 38, 6, 36, 1, 89, 7, 80, 2, 66, 
    1,  1, 6, 68, 4, 41, 8, 67, 7, 28, 3, 71, 2, 81, 0, 88, 5,  6, 
    0, 70, 4, 92, 7, 97, 3,  5, 5, 95, 2, 35, 1, 11, 6, 73, 8, 85, 
    0, 12, 6, 54, 2, 39, 8,  5, 1, 40, 3,  7, 4,  1, 7, 91, 5, 10, 
    0, 35, 5, 77, 4,  9, 1, 75, 7, 83, 8, 23, 3, 15, 6, 84, 2, 91, 
    3, 94, 5, 30, 0, 11, 1, 80, 2, 13, 4, 68, 6, 67, 7,  7, 8, 56, 
    3, 24, 2, 39, 6,  7, 4,  8, 7, 46, 8, 76, 5, 14, 1, 33, 0, 28
  };
  const int q7459[] = {
    9, 9, // Number of jobs and machines
    1, 82, 5, 98, 8, 41, 2, 47, 3, 16, 4,  2, 0, 49, 6,  5, 7, 81, 
    6, 60, 4, 47, 3, 76, 1, 90, 7, 30, 8, 66, 2, 89, 5, 60, 0,  2, 
    8, 44, 1, 72, 2, 81, 3, 21, 6,  4, 0, 95, 7, 30, 4, 82, 5, 44, 
    7, 27, 3, 18, 0, 39, 6, 75, 5, 42, 8, 63, 1, 12, 4, 51, 2, 28, 
    3, 22, 8, 86, 1,  9, 2, 33, 7, 35, 6, 27, 5, 64, 4, 56, 0, 46, 
    4, 40, 5, 46, 3, 42, 1, 71, 2, 22, 7,  3, 0, 73, 6, 29, 8, 92, 
    4, 23, 3, 89, 2, 37, 8, 75, 0, 27, 1, 88, 7,  8, 5, 48, 6, 86, 
    7, 57, 2, 23, 3, 12, 8, 12, 4, 18, 5, 68, 6, 79, 0, 71, 1, 55, 
    4, 68, 7,  8, 6, 83, 5, 45, 1, 81, 8, 32, 0, 43, 3, 66, 2, 74
  };
  const int q7460[] = {
    9, 9, // Number of jobs and machines
    7, 67, 8, 42, 4, 13, 5,  6, 1,  8, 6, 77, 0,  5, 3, 15, 2, 43, 
    7, 84, 6, 54, 8, 19, 4, 51, 0, 17, 3, 54, 2, 37, 5,  5, 1, 35, 
    8, 37, 1, 62, 6, 51, 5, 72, 4, 31, 3, 76, 2, 64, 0, 68, 7, 94, 
    5, 98, 6, 63, 3, 68, 8, 91, 0, 61, 7,  3, 2, 56, 1, 71, 4, 94, 
    7, 56, 4, 59, 8, 96, 6, 34, 1,  9, 0, 72, 2, 32, 3, 21, 5, 11, 
    1,  7, 3, 89, 0, 84, 7, 66, 5, 26, 6, 69, 4, 13, 8, 42, 2, 22, 
    4, 52, 2, 34, 0, 55, 1, 34, 5, 42, 8, 88, 3,  8, 6,  4, 7, 18, 
    1, 31, 7, 86, 6, 52, 0, 28, 4,  7, 8, 44, 3, 58, 5, 80, 2, 42, 
    8, 78, 0, 27, 3, 25, 2, 85, 1, 72, 5, 37, 7, 45, 6, 29, 4, 39
  };
  const int q7461[] = {
    9, 9, // Number of jobs and machines
    6, 21, 1, 84, 7, 74, 0, 77, 5, 74, 3, 45, 4, 55, 8, 82, 2, 62, 
    1, 45, 2, 73, 8, 68, 3, 64, 7, 44, 6, 94, 4, 34, 0, 77, 5, 91, 
    0, 19, 8, 65, 4, 29, 7, 42, 2, 77, 6, 43, 1, 69, 3, 54, 5, 86, 
    1, 99, 2, 47, 7, 39, 4, 66, 0, 57, 3, 33, 8, 87, 5, 15, 6, 93, 
    4, 52, 5, 62, 2, 32, 6, 91, 1, 44, 0, 33, 3, 87, 7, 49, 8,  8, 
    0, 33, 8, 50, 1, 63, 5, 34, 6, 82, 4, 24, 3, 54, 2,  5, 7, 23, 
    3, 15, 8, 58, 4, 17, 1, 99, 2, 92, 0, 57, 6, 56, 5, 49, 7, 84, 
    7, 28, 5, 60, 2, 93, 8, 12, 4, 37, 1,  3, 0, 50, 6, 33, 3, 22, 
    8, 74, 7, 45, 4, 93, 2, 54, 3, 97, 6, 77, 0, 91, 5, 87, 1, 43
  };
  const int q7462[] = {
    9, 9, // Number of jobs and machines
    0, 16, 1, 63, 3, 33, 4, 65, 8, 83, 7, 20, 5, 11, 6, 44, 2, 11, 
    4, 11, 1, 88, 3, 32, 6, 47, 2, 25, 7, 69, 8,  6, 0, 10, 5, 16, 
    5, 27, 1, 28, 0, 26, 8, 55, 3, 94, 6, 62, 7,  6, 2, 20, 4, 19, 
    3, 94, 0, 45, 2, 71, 7, 62, 1, 66, 6, 86, 5, 69, 4, 73, 8, 66, 
    2, 66, 4, 80, 3, 28, 0, 49, 7, 11, 8,  5, 6, 46, 5, 47, 1, 52, 
    7, 36, 2, 18, 0, 61, 5, 67, 3, 48, 8, 93, 4, 46, 1, 69, 6, 89, 
    2, 93, 7, 95, 8, 94, 6,  7, 1, 59, 5, 40, 4, 36, 0,  3, 3,  1, 
    8, 88, 6, 32, 0, 80, 1, 40, 7, 59, 4, 31, 2, 58, 3, 96, 5, 27, 
    0, 83, 8, 38, 1, 93, 3, 33, 6, 89, 7, 92, 5, 34, 2, 55, 4, 46
  };
  const int q7463[] = {
    9, 9, // Number of jobs and machines
    3, 89, 5, 57, 6, 88, 8, 87, 2, 56, 7, 77, 4, 94, 0,  6, 1, 88, 
    4, 68, 0, 62, 8, 68, 2, 79, 5, 34, 7, 53, 1, 83, 6, 71, 3, 73, 
    4,  5, 8, 49, 5, 10, 0, 93, 2, 54, 6, 43, 1, 47, 3, 35, 7,  5, 
    5, 86, 3, 24, 4, 71, 8, 41, 7, 96, 0, 51, 6, 31, 2, 13, 1,  7, 
    3, 76, 5, 62, 7,  2, 6, 32, 1, 12, 4, 28, 2, 99, 0, 11, 8, 79, 
    5,  3, 7, 75, 8, 90, 3, 26, 2, 85, 1, 98, 4, 22, 6, 90, 0, 44, 
    4, 24, 7, 78, 6, 52, 0,  6, 2, 66, 5, 70, 1, 66, 8, 80, 3, 39, 
    2, 69, 6, 92, 8, 42, 3, 94, 0, 71, 5, 19, 7, 88, 4, 62, 1, 98, 
    1, 33, 3, 31, 4, 30, 7, 39, 2, 74, 8, 75, 5, 39, 6,  7, 0, 11
  };
  const int q7464[] = {
    9, 9, // Number of jobs and machines
    0,  3, 6, 69, 2,  9, 4, 38, 3, 21, 7, 72, 1, 23, 5, 95, 8, 39, 
    2, 96, 4, 45, 1, 66, 6, 52, 8, 83, 5, 70, 0, 84, 7, 30, 3, 63, 
    3, 70, 2, 12, 1, 59, 0, 57, 8, 11, 4, 64, 5, 61, 7, 17, 6, 67, 
    3, 67, 5, 96, 7, 49, 6,  3, 8, 95, 0, 28, 4, 61, 1, 56, 2, 51, 
    5, 90, 4, 25, 8, 94, 6, 16, 0,  3, 3, 35, 1,  3, 7, 72, 2, 88, 
    6,  8, 4,  6, 3, 80, 0, 37, 2, 39, 8,  6, 5, 61, 7, 13, 1,  9, 
    0, 86, 8, 79, 5, 79, 3, 62, 1, 57, 7, 77, 2, 40, 6, 59, 4, 78, 
    1, 55, 4,  7, 2, 38, 0, 13, 5, 32, 6, 10, 3, 26, 7, 54, 8, 95, 
    8, 27, 3,  7, 0, 94, 1, 88, 2, 14, 6, 45, 5,  2, 7, 74, 4, 66
  };
  const int q7465[] = {
    9, 9, // Number of jobs and machines
    5, 47, 3, 11, 7, 45, 1, 68, 8, 71, 0, 29, 4, 54, 6,  1, 2,  4, 
    8, 25, 1, 25, 2, 22, 4, 44, 3, 38, 6, 43, 5, 25, 7, 88, 0, 29, 
    5, 52, 7, 86, 1, 17, 2, 89, 6, 70, 4, 93, 3, 55, 0,  4, 8, 58, 
    2, 24, 4, 10, 1, 79, 7, 69, 8, 96, 5, 29, 6, 19, 0, 75, 3,  4, 
    0, 55, 8, 29, 2, 91, 1, 20, 6, 87, 3, 92, 5, 16, 4, 31, 7, 67, 
    0, 43, 2, 64, 8, 81, 5, 97, 4, 99, 7, 45, 3, 94, 1, 23, 6, 87, 
    6, 43, 1, 28, 3, 66, 4, 65, 2, 99, 0, 56, 8, 18, 7, 51, 5, 87, 
    1, 14, 6, 26, 7, 24, 2, 90, 3, 75, 8, 89, 0, 39, 4, 48, 5, 75, 
    6, 76, 4, 53, 5, 58, 2, 95, 3, 39, 7, 89, 8, 69, 0, 75, 1, 29
  };
  const int q7466[] = {
    9, 9, // Number of jobs and machines
    3, 24, 4, 29, 7,  3, 6,  2, 8, 44, 2, 54, 0, 95, 5,  8, 1, 47, 
    3, 56, 4,  2, 2, 34, 7, 17, 0, 76, 1, 68, 8, 89, 6, 11, 5, 41, 
    4, 56, 8, 50, 3,  1, 6, 64, 1, 39, 7, 51, 5, 90, 0, 93, 2, 74, 
    2, 81, 6,  2, 3, 96, 8, 63, 5, 91, 4,  5, 7, 21, 0, 58, 1, 76, 
    5, 51, 2, 19, 6, 49, 0, 46, 3, 54, 4, 94, 8, 32, 7, 18, 1, 99, 
    1, 70, 6, 62, 2,  5, 3, 47, 7, 92, 4, 75, 5, 95, 8,  1, 0, 52, 
    2, 64, 4, 29, 0, 15, 7, 72, 1, 68, 6, 96, 3, 81, 5, 21, 8, 41, 
    8, 97, 3, 49, 0, 87, 4, 52, 2, 12, 7, 83, 6, 55, 1, 89, 5, 94, 
    5, 16, 4,  4, 8, 34, 7, 28, 2, 83, 6, 75, 3, 99, 1, 14, 0, 65
  };
  const int q7467[] = {
    9, 9, // Number of jobs and machines
    7, 30, 8, 82, 4, 61, 5, 21, 2,  7, 6, 22, 1, 58, 3, 65, 0, 16, 
    1, 84, 0, 71, 6, 33, 3, 14, 7, 82, 8, 98, 5,  7, 2, 31, 4, 16, 
    1, 73, 5, 61, 7, 87, 3,  5, 0, 55, 6, 16, 4,  7, 8, 69, 2, 55, 
    6, 18, 8, 28, 5, 46, 3, 22, 4, 14, 2, 74, 7, 99, 1, 84, 0, 28, 
    5, 94, 1, 44, 7, 69, 3, 97, 6,  6, 4, 89, 0,  4, 8, 95, 2, 77, 
    6, 36, 1, 27, 0, 72, 4, 91, 2, 39, 5, 39, 7, 62, 3, 35, 8, 92, 
    0, 16, 3, 86, 8, 63, 6, 80, 7, 76, 2, 28, 4, 43, 1, 60, 5, 44, 
    2, 56, 3, 88, 7, 62, 6,  3, 4, 61, 0, 77, 5, 57, 1, 54, 8, 43, 
    1, 74, 0, 56, 4, 34, 7, 24, 8, 11, 2, 98, 6, 94, 5, 83, 3, 12
  };
  const int q7468[] = {
    9, 9, // Number of jobs and machines
    7, 72, 4, 52, 1, 14, 5, 96, 0, 18, 2, 48, 6, 77, 3, 31, 8, 31, 
    5, 27, 4, 49, 1, 16, 6, 86, 3, 99, 7, 34, 0, 16, 8,  2, 2, 19, 
    6, 20, 5, 47, 8, 25, 1, 99, 4, 88, 7, 11, 3, 58, 0, 75, 2, 26, 
    5, 79, 0, 96, 8, 82, 2, 83, 6, 20, 7, 32, 3,  2, 4, 28, 1, 46, 
    3, 98, 7, 46, 2, 75, 5, 94, 0, 81, 1, 61, 8, 11, 4, 52, 6, 30, 
    3, 25, 1, 81, 2, 53, 8, 88, 4, 53, 6, 23, 0, 93, 5, 58, 7, 32, 
    4, 28, 0, 63, 6, 24, 3, 39, 1, 41, 8, 78, 2,  4, 5, 58, 7, 30, 
    7, 95, 4, 39, 8, 88, 1, 32, 2, 30, 6, 82, 5, 40, 0, 63, 3, 98, 
    6, 37, 0, 16, 5, 35, 2, 44, 8, 64, 3,  3, 4, 82, 1, 66, 7, 96
  };
  const int q7469[] = {
    9, 9, // Number of jobs and machines
    6, 77, 8, 94, 1, 15, 5, 82, 7, 52, 0, 11, 2, 11, 4, 98, 3, 98, 
    7, 98, 3, 37, 0, 30, 5, 97, 8, 53, 4, 81, 2, 91, 6, 62, 1, 14, 
    2,  9, 0, 48, 4,  2, 6, 46, 7, 82, 1, 93, 8, 83, 3, 29, 5,  1, 
    3, 89, 2, 73, 8, 47, 1, 22, 0,  3, 6,  1, 4,  7, 7, 87, 5, 29, 
    4, 43, 0, 34, 8, 15, 7, 91, 3, 75, 6, 51, 5, 40, 1, 39, 2, 33, 
    7, 65, 5, 11, 6, 63, 2, 49, 3, 97, 8, 44, 0, 63, 1, 63, 4, 59, 
    0, 92, 5, 26, 3, 81, 8, 52, 6,  8, 4,  4, 1, 33, 7, 91, 2,  3, 
    1, 38, 4, 89, 6,  5, 8, 52, 0, 39, 7, 88, 5, 78, 3, 31, 2,  5, 
    2, 17, 4, 91, 8, 57, 3, 33, 7, 87, 6, 36, 1, 32, 5, 91, 0, 78
  };
  const int q7470[] = {
    9, 9, // Number of jobs and machines
    1, 46, 7, 85, 2, 95, 5, 33, 6, 46, 0, 18, 4, 18, 8, 11, 3, 90, 
    8, 80, 1, 57, 3, 96, 7, 86, 6, 59, 5,  5, 4, 28, 2, 33, 0, 82, 
    2, 75, 5, 66, 7, 43, 0, 21, 8, 24, 4, 45, 6, 87, 3, 76, 1, 26, 
    5, 22, 0, 89, 1, 73, 7, 77, 4, 88, 2, 79, 6, 58, 8, 25, 3, 92, 
    2, 19, 5, 69, 0, 91, 3, 20, 1, 51, 7, 14, 4, 68, 6, 55, 8, 81, 
    7,  1, 8, 41, 4, 24, 2, 30, 5, 22, 1, 17, 6, 86, 3, 37, 0, 65, 
    8, 33, 2, 90, 5, 29, 3, 79, 0, 89, 1, 40, 6,  5, 7, 88, 4, 91, 
    1, 47, 2, 97, 8,  6, 0, 93, 5, 87, 3, 22, 4, 36, 7, 16, 6, 30, 
    7, 57, 5, 25, 8, 60, 3, 19, 2, 36, 1, 78, 0, 59, 4, 18, 6, 69
  };
  const int q7471[] = {
    9, 9, // Number of jobs and machines
    5, 64, 2, 74, 8, 62, 1, 44, 7, 66, 3, 10, 0, 69, 6,  2, 4, 81, 
    7, 13, 2, 82, 1, 86, 3, 53, 6, 30, 5, 65, 4, 94, 8, 20, 0, 18, 
    5, 46, 1, 12, 0, 88, 7, 62, 8, 90, 4, 53, 6, 99, 2, 50, 3, 24, 
    5,  5, 6, 93, 8,  5, 4, 13, 1, 36, 7, 60, 2, 62, 3, 40, 0, 30, 
    8, 93, 3,  7, 2, 88, 1, 98, 6, 55, 0, 29, 4,  2, 5, 67, 7, 67, 
    7, 21, 6, 41, 0, 13, 8, 73, 5, 32, 3, 75, 1, 83, 4, 93, 2, 45, 
    0, 52, 7, 75, 8,  6, 2,  6, 5, 27, 3,  5, 6, 61, 1, 38, 4,  4, 
    4,  3, 5, 13, 2, 95, 3, 98, 7, 85, 8, 20, 1, 76, 6, 80, 0, 11, 
    6, 32, 0, 55, 1, 39, 5,  1, 4, 68, 2, 18, 3, 56, 8, 50, 7, 70
  };
  const int q7472[] = {
    9, 9, // Number of jobs and machines
    8, 68, 6, 92, 0,  4, 1, 37, 4, 27, 2, 36, 3, 91, 5,  9, 7, 48, 
    3, 29, 4, 91, 2, 89, 5, 19, 8,  9, 6, 65, 7, 19, 0, 74, 1, 90, 
    1, 89, 5, 18, 2, 28, 4, 58, 8, 53, 7, 73, 6, 38, 3, 54, 0, 22, 
    4,  2, 1, 94, 7, 69, 8, 58, 2, 37, 3, 54, 0, 23, 5, 93, 6, 64, 
    1, 33, 2, 40, 8, 87, 3, 94, 4, 24, 5, 44, 6, 92, 0, 74, 7, 86, 
    6, 57, 1, 42, 0, 27, 8, 93, 2, 50, 5,  6, 7, 23, 3, 29, 4, 63, 
    5, 60, 6, 13, 4, 72, 1, 76, 7, 42, 2, 29, 0, 18, 3,  6, 8, 30, 
    8, 84, 5, 31, 2, 44, 7, 46, 6, 25, 3, 78, 4, 91, 0,  8, 1, 32, 
    0, 26, 5,  2, 2, 23, 6, 75, 1, 65, 8,  3, 7, 41, 3, 19, 4, 20
  };
  const int q7473[] = {
    9, 9, // Number of jobs and machines
    2, 42, 5, 90, 4, 52, 3, 24, 1, 41, 6, 43, 7,  3, 0, 82, 8, 20, 
    8, 50, 2, 14, 4, 52, 3, 28, 5, 57, 0, 36, 7, 49, 6, 45, 1, 73, 
    2, 52, 6, 86, 7, 57, 3, 24, 4, 94, 0, 99, 8, 75, 5, 38, 1, 40, 
    0, 13, 1, 88, 8, 44, 2, 59, 4, 13, 6, 75, 3, 38, 5, 28, 7, 51, 
    2, 41, 0, 59, 3, 13, 5, 31, 8,  5, 7, 29, 4, 34, 6, 61, 1, 70, 
    7, 85, 2, 67, 1, 95, 5, 14, 8, 39, 3, 51, 6, 37, 4, 81, 0, 22, 
    7, 25, 5, 75, 3, 59, 4, 57, 1, 95, 2, 93, 0, 96, 6, 31, 8,  2, 
    7, 84, 8, 59, 6, 18, 4, 13, 0, 45, 5, 56, 2, 69, 3, 24, 1, 69, 
    6, 84, 0, 73, 8, 78, 4, 41, 7,  5, 5, 83, 3, 17, 1, 72, 2, 68
  };
  const int q7474[] = {
    9, 9, // Number of jobs and machines
    1, 80, 4, 49, 2, 14, 5, 76, 6, 99, 3, 22, 7, 43, 0, 43, 8,  7, 
    5, 23, 2, 74, 8, 51, 0, 44, 4, 44, 1, 99, 6, 80, 7, 34, 3, 72, 
    4, 34, 8, 93, 5, 78, 3, 91, 1, 43, 0, 50, 2, 44, 6, 40, 7, 87, 
    2, 63, 6, 29, 3, 74, 7, 61, 4, 20, 1, 75, 5, 50, 8, 36, 0, 51, 
    4, 61, 6, 46, 7,  5, 0, 56, 3,  1, 2, 87, 8, 39, 5, 12, 1, 27, 
    5,  3, 6, 65, 1, 84, 8, 68, 2, 50, 7, 64, 4, 65, 3, 84, 0, 93, 
    4, 91, 7, 36, 5, 21, 6, 83, 8, 55, 1, 90, 3, 19, 2, 56, 0, 84, 
    1, 61, 0, 25, 5, 93, 3, 37, 4, 94, 7, 99, 6, 27, 2, 53, 8, 51, 
    6, 37, 2, 56, 7, 15, 0, 57, 3, 70, 8, 25, 5, 94, 1, 56, 4, 53
  };
  const int q7475[] = {
    9, 9, // Number of jobs and machines
    1, 40, 8, 43, 2, 74, 0, 57, 4, 29, 5, 45, 3, 52, 6, 85, 7, 79, 
    7, 35, 2, 16, 3, 15, 6, 43, 1, 25, 8, 62, 5,  3, 0, 16, 4, 15, 
    1, 44, 3, 99, 0, 40, 2, 27, 8, 46, 6, 85, 4, 52, 7, 67, 5, 93, 
    4, 38, 0, 37, 6, 35, 7, 94, 2, 84, 8, 23, 1, 48, 5, 93, 3, 56, 
    1, 99, 0, 69, 7, 99, 8, 85, 4, 56, 5, 43, 2,  5, 6, 76, 3, 57, 
    8, 83, 2, 16, 6, 74, 4,  3, 7, 42, 5, 19, 3, 49, 0, 61, 1, 20, 
    0, 50, 7, 48, 2, 48, 4,  1, 8, 95, 5, 73, 1, 79, 6, 80, 3, 63, 
    4, 98, 5, 73, 0, 51, 1, 64, 6, 49, 7, 76, 2, 30, 3, 36, 8, 48, 
    3, 94, 8, 15, 7, 14, 2,  1, 0,  7, 5, 76, 6, 68, 1, 63, 4,  9
  };
  const int q7476[] = {
    9, 9, // Number of jobs and machines
    7, 14, 5, 74, 1, 14, 4, 58, 0, 57, 3, 48, 6, 46, 2, 11, 8, 30, 
    5, 67, 2, 49, 7,  3, 6, 83, 0, 41, 8, 44, 3, 28, 4, 61, 1, 57, 
    4, 68, 1, 87, 5, 89, 8, 85, 2, 88, 6, 96, 7, 66, 0, 77, 3, 82, 
    6,  5, 7, 28, 0, 36, 8, 91, 1, 53, 2, 32, 5, 94, 3, 33, 4, 65, 
    0, 92, 6, 98, 3, 42, 5, 43, 2,  9, 1, 87, 4, 11, 8, 60, 7, 38, 
    6, 79, 4, 48, 0, 54, 2, 85, 8,  1, 1, 78, 7, 90, 5, 88, 3, 81, 
    7, 85, 4, 89, 3, 88, 2, 93, 5, 57, 1, 59, 6, 97, 8, 44, 0, 75, 
    8, 94, 7, 68, 6, 81, 2, 74, 4, 52, 3, 73, 5, 77, 1, 67, 0, 62, 
    1, 90, 6, 92, 0, 67, 7, 35, 5, 53, 3, 64, 2, 29, 8, 67, 4, 97
  };
  const int q7477[] = {
    9, 9, // Number of jobs and machines
    1, 67, 8, 41, 0, 27, 2, 43, 7, 70, 3, 70, 6, 51, 4, 97, 5, 99, 
    5, 96, 8,  1, 7, 76, 3, 33, 6, 73, 2, 23, 0, 81, 1, 96, 4, 23, 
    6,  8, 3, 17, 2,  7, 8, 42, 4, 93, 1, 58, 7, 63, 0, 65, 5, 32, 
    4, 41, 2,  4, 3, 71, 0, 62, 6, 23, 7, 39, 1,  7, 8, 92, 5, 76, 
    8, 17, 5, 52, 6, 88, 0, 98, 2, 45, 1, 62, 3, 15, 4, 95, 7, 50, 
    2, 43, 6, 95, 5, 68, 0, 59, 8, 49, 4, 11, 1, 74, 3, 65, 7, 63, 
    4,  7, 0, 55, 3, 87, 8, 36, 6, 18, 2, 97, 1, 86, 5, 48, 7, 32, 
    5, 41, 3, 93, 8, 79, 4, 31, 2, 83, 7,  3, 0, 15, 6, 84, 1, 26, 
    5, 95, 3, 47, 2,  6, 0, 26, 6, 60, 7, 33, 8, 50, 4, 52, 1, 64
  };
  const int q7478[] = {
    9, 9, // Number of jobs and machines
    0, 67, 3, 91, 4, 75, 2, 77, 8, 74, 7, 70, 6, 44, 5, 89, 1, 79, 
    3, 77, 5, 56, 0, 65, 2, 27, 1, 82, 7, 33, 8, 88, 4, 14, 6, 56, 
    7,  7, 1, 68, 3, 32, 4, 15, 8, 37, 2, 82, 0, 83, 5,  4, 6, 32, 
    2,  9, 7, 97, 5, 56, 1, 59, 4, 73, 3, 67, 8, 22, 6, 40, 0, 69, 
    4, 56, 0, 51, 1, 32, 3, 95, 6, 99, 5, 34, 2, 92, 7, 94, 8, 60, 
    4, 74, 7, 14, 5, 67, 3, 69, 8, 88, 2, 71, 1, 10, 0, 51, 6, 86, 
    5, 26, 3, 95, 0, 18, 6, 14, 8, 66, 7,  2, 2, 99, 4, 44, 1, 88, 
    7, 18, 2, 12, 5, 32, 3, 25, 1, 47, 0, 99, 8, 45, 6, 65, 4,  7, 
    3, 39, 0, 47, 6, 14, 5, 62, 8, 69, 7, 60, 2, 28, 4, 55, 1, 95
  };
  const int q7479[] = {
    9, 9, // Number of jobs and machines
    8, 16, 1, 76, 6, 96, 5, 97, 3, 40, 4, 53, 2, 91, 0, 69, 7, 74, 
    6, 83, 0, 24, 2, 29, 8, 22, 5, 26, 7, 99, 4, 45, 1, 65, 3, 29, 
    8, 38, 7, 97, 2, 39, 3, 40, 0, 87, 6, 55, 1, 74, 5, 45, 4, 63, 
    8, 89, 5, 18, 6, 55, 1, 98, 7, 43, 3, 56, 2, 44, 4, 19, 0, 34, 
    0, 36, 3, 95, 1, 10, 4, 36, 7, 23, 6, 88, 5, 26, 8, 15, 2, 76, 
    4, 55, 2, 64, 5, 30, 8, 70, 1, 38, 6, 86, 3, 64, 7, 91, 0, 89, 
    3, 47, 8, 60, 0, 31, 5,  5, 6, 83, 2, 31, 4, 31, 7, 64, 1, 92, 
    5, 68, 3, 16, 7, 32, 1, 89, 6, 86, 0, 90, 4,  6, 2, 62, 8, 42, 
    5, 49, 7, 18, 0, 23, 3,  8, 8, 31, 4, 93, 1, 83, 6, 81, 2, 18
  };
  const int q7480[] = {
    9, 9, // Number of jobs and machines
    1, 60, 5, 66, 0, 94, 8, 90, 7, 13, 4, 20, 6, 51, 2, 57, 3, 20, 
    6, 27, 8,  7, 0, 33, 2,  6, 5, 70, 1, 77, 7, 41, 3, 35, 4, 75, 
    0, 68, 3, 14, 4, 80, 1, 44, 6,  2, 7, 17, 8, 26, 5, 96, 2, 84, 
    7, 68, 0, 77, 1, 19, 4, 11, 3, 51, 8, 41, 6, 66, 5, 56, 2, 11, 
    7, 23, 6, 54, 0, 97, 2, 32, 1, 59, 4,  8, 3, 69, 5,  7, 8, 96, 
    2, 61, 8, 66, 4, 96, 1, 96, 0, 61, 7, 82, 5,  9, 6, 46, 3, 93, 
    1, 23, 0, 85, 5, 67, 4, 22, 8, 49, 7,  6, 2, 22, 6, 68, 3, 37, 
    4, 97, 3, 44, 0, 43, 6,  8, 1, 23, 5, 26, 8, 44, 2, 53, 7, 90, 
    6, 18, 4, 19, 0, 96, 8, 40, 1, 39, 2, 33, 7, 35, 3, 72, 5, 39
  };
  const int q7481[] = {
    9, 9, // Number of jobs and machines
    8, 28, 6, 64, 5, 72, 4, 61, 1, 84, 0,  8, 3, 14, 2,  1, 7, 37, 
    8, 24, 3, 50, 6, 33, 7, 96, 5, 30, 0,  5, 4, 23, 2, 75, 1, 10, 
    6, 46, 4, 25, 3, 49, 1, 91, 8, 49, 0, 75, 5, 21, 7, 47, 2, 91, 
    8, 89, 6,  7, 0, 96, 3, 35, 1, 11, 7, 57, 4, 67, 5, 68, 2,  1, 
    3, 75, 1, 10, 4, 44, 6, 29, 8, 53, 2, 87, 5, 81, 0, 84, 7, 30, 
    5, 84, 8, 77, 4, 81, 6, 12, 3, 46, 1, 51, 2, 60, 0, 50, 7, 55, 
    3, 81, 0, 53, 1, 80, 5, 53, 2, 64, 4, 23, 8,  8, 6,  2, 7, 94, 
    6, 64, 1, 45, 0, 54, 8, 70, 7, 70, 3,  2, 5, 73, 2, 35, 4, 80, 
    0, 81, 3, 13, 6, 15, 8, 46, 4, 33, 5, 34, 7, 28, 1, 31, 2,  2
  };
  const int q7482[] = {
    9, 9, // Number of jobs and machines
    3, 94, 5, 75, 7, 16, 8, 95, 1, 58, 4, 84, 2, 59, 0, 37, 6,  4, 
    5, 71, 2, 45, 8, 98, 3, 17, 1, 13, 4, 27, 6, 53, 7, 40, 0, 40, 
    4, 34, 2, 70, 8, 65, 0, 39, 6, 44, 5, 65, 7, 75, 3, 97, 1, 59, 
    6, 18, 1, 70, 3, 50, 7, 37, 2, 45, 4, 93, 8, 40, 5, 31, 0, 39, 
    8, 35, 7, 65, 3, 48, 6, 22, 5, 18, 4,  9, 1, 14, 2, 87, 0, 61, 
    0, 73, 6, 68, 3,  1, 2, 23, 1, 32, 5, 63, 7, 85, 8, 39, 4, 41, 
    5, 41, 4, 91, 7, 66, 6, 39, 0, 79, 1, 56, 8, 15, 3, 50, 2, 25, 
    1, 77, 5, 74, 0, 18, 3, 17, 7, 60, 4, 91, 6, 49, 8, 92, 2, 89, 
    6,  3, 8, 19, 1, 47, 4, 90, 5, 96, 2, 26, 7, 44, 0, 16, 3, 31
  };
  const int q7483[] = {
    9, 9, // Number of jobs and machines
    3, 31, 0, 52, 5, 97, 7, 71, 8, 76, 6,  6, 4, 73, 2, 70, 1, 66, 
    8, 63, 0, 71, 4, 48, 3, 22, 1, 96, 6, 61, 7, 63, 5, 24, 2, 48, 
    1, 43, 5, 14, 2, 35, 4, 36, 0, 11, 7,  4, 3, 17, 6, 32, 8, 80, 
    6, 61, 3, 54, 1, 93, 0, 95, 5, 32, 8, 26, 4, 18, 7, 46, 2, 90, 
    7,  6, 5, 15, 3, 43, 4, 64, 1, 30, 0,  6, 2, 64, 8,  7, 6, 27, 
    1, 35, 7,  7, 8, 34, 4, 75, 3, 96, 5, 36, 2, 76, 0, 69, 6, 31, 
    2, 32, 0, 11, 7, 60, 5, 90, 3, 56, 1, 97, 6,  4, 4, 52, 8, 59, 
    3, 48, 4, 71, 7, 27, 1, 55, 5, 28, 2, 36, 6, 48, 8, 65, 0, 36, 
    7, 92, 4, 91, 6,  8, 2, 27, 0, 26, 8, 64, 5,  3, 3,  9, 1,  6
  };
  const int q7484[] = {
    9, 9, // Number of jobs and machines
    5, 22, 6, 71, 3, 84, 7, 44, 8, 95, 0, 83, 1, 91, 4, 19, 2, 89, 
    8, 50, 4, 11, 7, 93, 1, 38, 3, 16, 6, 25, 5, 19, 2, 18, 0, 11, 
    4,  3, 0, 37, 2, 27, 1,  5, 5, 32, 3, 19, 8, 50, 6, 48, 7, 31, 
    8, 47, 1, 92, 4, 31, 3, 32, 0,  8, 6, 63, 7, 30, 5, 85, 2, 88, 
    2, 65, 6, 16, 3, 39, 0, 67, 5, 57, 7, 67, 4, 77, 8, 33, 1, 85, 
    8, 81, 4, 63, 7, 40, 2, 96, 5, 37, 1, 63, 6, 30, 3, 47, 0, 86, 
    0, 24, 6, 45, 7, 61, 8,  6, 4, 37, 5, 50, 3, 46, 2, 56, 1, 95, 
    0, 34, 7, 10, 6, 19, 1, 79, 5, 21, 4, 20, 2, 97, 3, 65, 8, 48, 
    3, 44, 7, 25, 8, 57, 1,  1, 6, 67, 0, 16, 4,  5, 5, 15, 2, 43
  };
  const int q7485[] = {
    9, 9, // Number of jobs and machines
    1, 59, 0, 74, 5, 21, 2, 89, 7,  2, 4, 90, 3, 89, 8, 75, 6, 50, 
    3, 36, 8, 90, 0, 88, 5, 42, 2,  9, 6, 12, 4, 82, 7, 13, 1, 83, 
    1, 51, 6, 67, 7, 65, 2, 61, 5, 86, 0, 60, 4,  1, 8, 54, 3, 75, 
    8, 33, 2, 44, 4, 46, 3,  4, 7, 18, 5, 16, 6, 10, 1, 38, 0,  5, 
    1, 47, 3, 28, 5, 95, 4, 47, 6, 99, 0, 56, 2, 29, 7, 96, 8, 94, 
    6, 76, 5, 31, 3, 76, 0,  5, 1, 75, 4, 73, 2, 99, 8, 93, 7, 21, 
    5, 60, 8, 47, 3,  6, 4, 77, 0, 45, 2, 95, 6, 68, 7, 54, 1, 43, 
    4, 62, 8, 81, 5, 40, 1, 20, 3, 70, 2, 58, 0, 30, 6, 93, 7, 37, 
    4, 93, 1, 76, 8, 26, 0, 90, 5, 54, 3, 98, 6, 51, 7, 46, 2, 19
  };
  const int q7486[] = {
    9, 9, // Number of jobs and machines
    7, 60, 5, 39, 6, 63, 4, 71, 8, 76, 2, 37, 1, 12, 3, 81, 0, 78, 
    4, 58, 1, 22, 6, 23, 0, 40, 8, 45, 7, 21, 3, 86, 5, 18, 2, 56, 
    2, 67, 4, 51, 6, 94, 3, 69, 1, 93, 8, 57, 5, 73, 7, 98, 0, 53, 
    3, 29, 8, 66, 1, 80, 7, 80, 4, 57, 5,  2, 2, 11, 6, 17, 0, 59, 
    4, 50, 2, 72, 5, 62, 3, 55, 0, 82, 1,  5, 6, 12, 8, 43, 7, 66, 
    6, 32, 7,  1, 2, 54, 1,  5, 8, 23, 3, 21, 5, 24, 4, 60, 0, 52, 
    8, 52, 0, 25, 3, 32, 1, 71, 6, 31, 2, 74, 5, 45, 7, 39, 4, 98, 
    5, 46, 0, 29, 7, 57, 2, 56, 3, 44, 6, 25, 1, 52, 8, 70, 4, 26, 
    8, 75, 5, 66, 0, 47, 6, 32, 3, 86, 1, 14, 4, 23, 2, 58, 7,  7
  };
  const int q7487[] = {
    9, 9, // Number of jobs and machines
    8, 12, 7, 52, 2, 55, 5, 26, 0, 95, 3,  3, 1, 69, 6, 19, 4, 67, 
    8, 76, 5, 54, 0, 79, 2, 35, 4, 29, 6, 13, 3, 43, 1, 98, 7, 56, 
    4,  3, 2, 17, 1, 23, 8, 12, 5, 37, 0, 99, 6,  4, 3, 55, 7, 15, 
    8, 19, 5, 66, 1, 63, 2, 73, 4,  5, 3, 37, 0, 60, 6, 31, 7, 45, 
    8, 75, 6, 49, 3,  5, 1, 41, 7, 67, 2,  9, 0, 33, 4, 18, 5, 27, 
    2, 64, 6, 34, 1, 92, 8, 83, 5, 62, 7, 48, 3, 57, 0, 34, 4, 47, 
    2, 21, 4, 76, 1, 39, 3, 81, 7, 84, 8, 97, 5, 57, 6, 90, 0, 78, 
    7, 35, 8, 17, 1, 61, 0, 70, 2,  3, 3, 69, 4, 22, 6, 96, 5,  2, 
    6, 43, 1, 98, 5, 80, 0, 34, 3, 14, 2, 90, 4, 25, 7, 50, 8, 77
  };
  const int q7488[] = {
    9, 9, // Number of jobs and machines
    0, 48, 3, 43, 5, 82, 2, 68, 8, 36, 4, 47, 6,  9, 7, 43, 1, 36, 
    7, 77, 4, 99, 2, 19, 3, 93, 5, 77, 6, 12, 1, 45, 8, 94, 0, 76, 
    7, 14, 6, 13, 1, 78, 4, 11, 8, 89, 3, 48, 0, 13, 2, 54, 5, 86, 
    2, 73, 0, 96, 6, 71, 7, 77, 5,  7, 1, 29, 3, 76, 4, 70, 8, 35, 
    6, 98, 7, 41, 3, 79, 0, 58, 1, 58, 5, 69, 2, 47, 8, 72, 4, 18, 
    1, 80, 5, 70, 6, 69, 7, 84, 2, 54, 8, 80, 4, 80, 0, 91, 3, 76, 
    6, 15, 5, 41, 8, 24, 0, 46, 1, 81, 3, 78, 2, 73, 7, 91, 4, 10, 
    5, 97, 1,  9, 6, 15, 7, 58, 0, 83, 8,  6, 4, 54, 3,  5, 2, 46, 
    0, 85, 1, 20, 6, 32, 8, 88, 7, 54, 2, 14, 4, 54, 5, 56, 3, 90
  };
  const int q7489[] = {
    9, 9, // Number of jobs and machines
    2, 30, 3, 48, 0, 94, 5, 67, 7, 70, 1, 26, 8, 53, 4, 49, 6, 13, 
    0,  8, 1,  9, 5, 17, 4, 48, 3, 67, 7, 95, 2, 87, 6, 14, 8, 36, 
    2,  7, 0, 83, 1, 29, 8, 71, 6, 83, 4, 27, 5, 87, 3, 63, 7, 10, 
    3, 38, 4, 23, 1, 25, 2, 37, 0, 19, 6, 93, 5, 56, 8, 75, 7, 45, 
    8, 86, 5, 94, 1, 34, 3, 14, 0, 41, 6,  9, 2, 39, 4, 30, 7, 65, 
    8, 46, 5, 51, 0, 40, 3, 26, 4, 52, 6, 84, 1, 82, 2, 18, 7, 59, 
    6, 70, 1, 84, 0, 84, 2, 51, 3,  5, 5, 52, 4, 88, 8, 58, 7, 74, 
    6, 69, 1, 15, 4, 39, 0, 69, 7, 77, 8, 87, 3, 73, 5, 63, 2, 72, 
    3, 83, 1, 30, 8, 59, 0, 95, 5, 81, 6, 39, 7,  2, 2, 23, 4,  3
  };
  const int q7490[] = {
    9, 9, // Number of jobs and machines
    6, 91, 3, 86, 7, 16, 5, 25, 2, 51, 0, 68, 4, 65, 8, 74, 1, 43, 
    5, 29, 2, 55, 1, 16, 8, 81, 4,  4, 3, 14, 6, 57, 7, 56, 0, 94, 
    7, 89, 2, 55, 6, 36, 3, 64, 8, 45, 4, 58, 1, 72, 5, 47, 0, 67, 
    4, 44, 1, 93, 5, 57, 8, 76, 6, 54, 3, 27, 0, 68, 7, 29, 2, 41, 
    8, 24, 1, 73, 4,  1, 0, 63, 7, 10, 5, 51, 3, 90, 2, 87, 6, 96, 
    2, 25, 3, 63, 4, 60, 0, 62, 8, 11, 1, 73, 6, 60, 7, 76, 5,  8, 
    5, 36, 3,  5, 4, 32, 7, 98, 8, 53, 1, 19, 2, 57, 6, 59, 0,  2, 
    3, 45, 1, 56, 7, 74, 2, 93, 5, 64, 8, 70, 4, 26, 0, 55, 6, 48, 
    4, 55, 7, 74, 8, 74, 1, 89, 6, 97, 3, 84, 0, 18, 2, 75, 5, 55
  };
  const int q7491[] = {
    9, 9, // Number of jobs and machines
    3,  6, 0,  1, 7,  8, 1, 44, 8, 86, 2, 94, 6, 46, 4, 43, 5, 31, 
    1, 51, 2, 87, 5, 68, 8, 18, 0, 87, 4, 74, 3, 29, 6, 48, 7, 67, 
    1, 84, 0, 23, 8, 71, 3,  7, 6, 54, 4, 22, 7,  6, 5, 55, 2, 83, 
    7, 77, 5,  8, 2, 58, 4, 37, 6, 11, 1, 66, 3, 48, 8, 59, 0, 95, 
    7, 58, 1, 98, 8, 99, 5, 81, 0, 77, 2, 97, 6, 12, 3, 43, 4, 93, 
    7,  4, 0, 80, 3, 69, 1, 11, 6, 12, 5, 41, 2, 45, 8, 17, 4, 83, 
    8,  8, 7, 84, 5, 12, 2,  7, 1,  3, 6, 94, 3, 93, 4,  5, 0, 44, 
    4, 79, 3, 15, 1, 13, 8, 67, 0,  2, 2, 47, 5, 42, 6, 75, 7,  4, 
    7, 20, 3, 37, 2, 36, 5, 95, 8, 99, 0, 58, 4, 87, 6, 27, 1, 72
  };
  const int q7492[] = {
    9, 9, // Number of jobs and machines
    5, 14, 3, 48, 2, 94, 8, 73, 1, 78, 0, 85, 4, 94, 7, 32, 6, 32, 
    6, 13, 2, 38, 3, 44, 7, 94, 1, 91, 0, 32, 4, 12, 5, 69, 8, 56, 
    7,  8, 0, 44, 8, 70, 1, 24, 2, 94, 3, 11, 6, 67, 5, 91, 4, 50, 
    6, 81, 0, 75, 3, 19, 5, 21, 8, 17, 7, 59, 4, 48, 1, 65, 2,  4, 
    4, 87, 2, 78, 5, 17, 7, 73, 1, 31, 3, 32, 6, 43, 8, 89, 0, 70, 
    7, 91, 0, 61, 3, 26, 4, 52, 1, 30, 6, 56, 2, 21, 5, 93, 8, 79, 
    2, 30, 3, 86, 1, 92, 5, 69, 6, 31, 8, 14, 0, 92, 4,  7, 7, 71, 
    4, 65, 0, 92, 3, 11, 8, 94, 6, 45, 1, 49, 2, 31, 5,  7, 7, 48, 
    7, 45, 8, 54, 5, 37, 4, 11, 1, 11, 2, 14, 0, 52, 6, 13, 3, 70
  };
  const int q7493[] = {
    9, 9, // Number of jobs and machines
    6,  4, 2, 28, 8, 66, 4, 78, 0, 97, 7, 11, 3,  9, 1, 69, 5, 44, 
    7, 85, 8, 13, 0, 42, 4, 89, 5, 22, 2, 74, 1, 72, 3, 26, 6, 67, 
    5,  2, 7, 31, 6, 17, 4, 11, 8, 15, 0,  2, 3, 81, 2, 62, 1,  7, 
    7, 98, 4, 73, 1, 71, 6, 86, 0, 86, 3, 68, 2, 48, 5, 79, 8, 55, 
    3, 40, 1, 28, 4, 27, 5, 59, 7, 72, 8, 65, 0,  1, 6, 53, 2, 50, 
    6, 86, 4, 84, 8, 20, 0, 47, 1, 30, 2, 26, 5, 56, 7,  2, 3, 22, 
    0, 34, 6, 25, 2, 43, 7, 42, 3, 81, 4, 28, 1, 53, 8, 89, 5, 15, 
    3, 99, 8, 10, 1, 19, 6, 32, 2, 26, 4, 41, 7, 99, 5,  3, 0, 52, 
    2, 10, 5, 53, 3,  3, 1, 36, 6,  4, 0, 21, 4, 41, 7, 22, 8, 27
  };
  const int q7494[] = {
    9, 9, // Number of jobs and machines
    8, 40, 5, 60, 6, 96, 0, 58, 1, 22, 3, 41, 7, 92, 2, 35, 4, 62, 
    3, 10, 4, 28, 0, 25, 1, 65, 8, 88, 7, 51, 2, 91, 6, 33, 5, 79, 
    2, 33, 5, 82, 3, 47, 4, 86, 0, 11, 1, 16, 6, 40, 8, 96, 7, 47, 
    2, 84, 6, 92, 3,  2, 7, 88, 8, 23, 0, 52, 1, 42, 5, 37, 4, 53, 
    6, 95, 7, 38, 4, 19, 0, 18, 1,  6, 8, 39, 2, 80, 5, 93, 3, 95, 
    4, 35, 8, 56, 3, 47, 6, 99, 5, 37, 2, 30, 0, 28, 7, 75, 1, 25, 
    8, 38, 5, 21, 7, 22, 4, 75, 0, 22, 6, 12, 2,  7, 1, 25, 3, 23, 
    0, 47, 5, 14, 3, 72, 2, 71, 7, 89, 4, 87, 6, 47, 8, 32, 1, 79, 
    0, 84, 5, 61, 8, 93, 7, 97, 4, 92, 1,  5, 3, 56, 2, 41, 6, 85
  };
  const int q7495[] = {
    9, 9, // Number of jobs and machines
    5, 65, 0, 81, 2, 73, 1, 37, 7, 45, 4, 76, 8, 25, 6, 14, 3, 87, 
    3, 38, 5, 96, 2, 89, 0, 43, 7, 18, 1, 21, 4, 19, 8, 58, 6,  6, 
    4,  3, 0, 21, 8, 92, 7,  2, 3, 63, 5, 41, 2, 66, 6, 94, 1, 31, 
    2, 90, 0, 14, 1,  9, 3, 11, 5, 70, 6, 87, 7, 62, 8, 97, 4, 19, 
    7,  5, 3, 28, 8, 34, 4, 80, 1, 71, 5, 14, 2, 75, 6,  4, 0, 13, 
    1, 45, 5, 36, 0, 32, 8, 81, 2, 53, 4, 18, 6, 41, 7, 27, 3, 36, 
    0, 70, 3, 57, 2, 23, 1, 81, 4, 59, 7, 70, 8, 53, 6, 14, 5, 29, 
    4, 85, 7, 85, 8, 77, 5, 75, 0, 76, 6,  9, 1, 44, 3, 12, 2, 92, 
    1, 23, 4, 10, 3, 18, 8, 22, 6, 60, 7, 87, 2, 79, 0, 94, 5, 27
  };
  const int q7496[] = {
    9, 9, // Number of jobs and machines
    5, 48, 3, 76, 8, 62, 0, 69, 6,  7, 4, 96, 1, 41, 2, 49, 7, 36, 
    3, 31, 5, 26, 8,  9, 1,  2, 7, 68, 4, 30, 6, 11, 0, 71, 2, 59, 
    7, 46, 2, 33, 6, 82, 3, 75, 8, 76, 5, 36, 1,  8, 0, 44, 4, 71, 
    7, 14, 6,  1, 1, 83, 4, 45, 5, 71, 3, 29, 8, 63, 2, 55, 0, 23, 
    5, 36, 2, 97, 6, 91, 7, 46, 1, 51, 8, 66, 3, 15, 0, 39, 4,  8, 
    5, 52, 4, 49, 7, 88, 3, 22, 2,  3, 6, 29, 0, 42, 1, 77, 8, 81, 
    7, 10, 0, 36, 4, 10, 8, 97, 1, 82, 3, 55, 5, 17, 2, 12, 6,  2, 
    2, 74, 7, 40, 8, 18, 6,  9, 5, 11, 0, 97, 3,  9, 4, 86, 1, 43, 
    3, 64, 8, 79, 5, 23, 0, 91, 2, 85, 1, 24, 7, 92, 4, 27, 6, 82
  };
  const int q7497[] = {
    9, 9, // Number of jobs and machines
    8, 98, 2, 80, 7, 26, 6, 98, 0, 87, 4, 96, 5, 42, 1, 80, 3, 89, 
    8,  2, 0, 91, 3, 28, 4, 72, 7, 75, 2, 79, 1, 70, 5, 67, 6, 72, 
    5, 21, 3, 90, 6, 69, 7, 29, 8,  1, 4, 57, 0, 27, 1, 28, 2, 27, 
    7, 96, 6, 86, 0, 16, 2, 82, 5, 31, 3, 63, 1, 81, 8, 25, 4, 94, 
    8, 37, 7, 40, 6, 63, 1, 53, 3, 25, 2, 91, 4, 70, 0, 68, 5, 56, 
    0, 91, 8, 67, 1, 14, 4, 77, 2, 70, 5, 53, 3, 20, 6, 24, 7, 75, 
    7, 32, 0, 58, 2,  4, 8, 78, 5, 72, 1, 30, 6,  5, 4, 12, 3, 58, 
    8,  1, 7, 96, 3,  2, 2, 79, 5, 18, 0, 12, 1, 49, 6, 46, 4, 30, 
    8, 31, 7, 19, 5, 37, 3,  6, 0, 75, 4, 11, 1, 92, 6, 46, 2, 38
  };
  const int q7498[] = {
    9, 9, // Number of jobs and machines
    0, 49, 4,  7, 1, 30, 6, 70, 7, 86, 8, 88, 5, 78, 2,  6, 3, 85, 
    5,  9, 8, 41, 2, 94, 0, 90, 7,  1, 4, 13, 6, 29, 1, 75, 3, 35, 
    5, 29, 7, 31, 3, 76, 4, 75, 6, 55, 2, 91, 1, 18, 0, 64, 8, 19, 
    0, 90, 4, 78, 3, 81, 2, 16, 7, 25, 6, 88, 1, 76, 8, 53, 5, 52, 
    5, 93, 6, 64, 0, 21, 3, 58, 4, 62, 7, 49, 8,  5, 2, 82, 1, 73, 
    0, 21, 3, 13, 4, 47, 8, 94, 6, 83, 1, 59, 2, 14, 5, 36, 7,  2, 
    1, 55, 5, 81, 4, 31, 7, 20, 6, 20, 0, 85, 2, 21, 8, 68, 3, 45, 
    8, 39, 4, 70, 1, 24, 7, 54, 5, 99, 2, 53, 6, 84, 0, 31, 3, 65, 
    6, 31, 2, 82, 3, 55, 4, 15, 8, 77, 5, 70, 1, 19, 0, 96, 7, 29
  };
  const int q7499[] = {
    9, 9, // Number of jobs and machines
    4, 37, 3, 12, 6, 54, 1, 58, 0, 36, 7, 13, 8, 75, 2, 68, 5, 91, 
    0, 37, 2, 18, 8,  7, 4, 31, 1, 71, 6, 64, 3, 36, 5, 12, 7, 28, 
    1,  2, 4, 95, 5, 42, 7, 22, 6, 81, 0,  7, 3,  3, 2, 97, 8, 36, 
    5, 33, 7, 10, 3, 90, 1, 14, 6, 73, 0, 58, 2, 34, 4, 56, 8, 11, 
    6, 94, 3, 59, 4, 64, 1, 11, 0, 81, 8, 35, 2, 82, 5, 10, 7, 11, 
    5, 90, 7, 68, 6,  2, 8, 11, 4, 63, 3, 28, 1, 44, 0, 11, 2,  1, 
    3, 44, 4, 97, 7, 19, 1, 54, 0, 46, 8, 85, 6, 89, 5, 76, 2, 58, 
    2, 73, 1, 66, 8, 44, 4, 93, 3, 75, 7,  2, 0, 87, 6, 97, 5, 51, 
    0, 40, 1,  6, 3, 35, 6, 70, 8, 42, 7, 69, 2, 37, 5,  1, 4, 60
  };
  const int q7500[] = {
    9, 9, // Number of jobs and machines
    7, 15, 4, 62, 1, 82, 3, 88, 8, 97, 0, 46, 6, 43, 5, 47, 2, 47, 
    6, 67, 5, 87, 0, 17, 2, 24, 1, 91, 8, 35, 3, 11, 4, 68, 7, 53, 
    5, 72, 4, 40, 0, 64, 2, 67, 1, 80, 3, 43, 8, 46, 7, 29, 6,  8, 
    0, 50, 2, 30, 4, 10, 7, 92, 3, 91, 5, 79, 1,  9, 8,  6, 6, 66, 
    8,  9, 4, 33, 3, 89, 2, 80, 1, 98, 0, 44, 6, 70, 7, 31, 5, 85, 
    0, 54, 4, 50, 7,  6, 8, 74, 3, 90, 6, 94, 2, 89, 5, 40, 1, 40, 
    0, 96, 6, 57, 5, 75, 8, 23, 1, 49, 7, 36, 2, 40, 3, 39, 4, 91, 
    7, 64, 4, 28, 2, 68, 1, 97, 5, 82, 3, 31, 6, 28, 0, 92, 8, 39, 
    8, 84, 1, 65, 7, 53, 0,  7, 3, 72, 4, 65, 5, 21, 6, 87, 2, 65
  };
  const int q7501[] = {
    9, 9, // Number of jobs and machines
    2, 84, 3, 20, 4, 64, 6, 69, 1, 10, 0, 52, 7, 66, 8, 52, 5, 26, 
    3, 26, 8, 75, 1, 46, 6, 96, 0, 97, 5, 50, 7, 34, 4, 42, 2, 86, 
    7, 76, 1, 62, 3, 33, 4, 97, 8, 29, 5, 83, 2, 57, 0, 18, 6, 15, 
    6, 95, 7, 54, 2, 26, 4, 84, 5, 58, 3, 59, 1, 97, 0, 93, 8, 16, 
    6, 26, 3, 11, 4, 35, 0, 59, 7, 20, 2, 57, 8,  9, 5, 67, 1, 41, 
    5, 25, 0, 76, 6, 92, 2, 35, 4, 68, 1,  5, 7, 32, 3, 28, 8, 51, 
    5, 75, 1, 38, 0, 59, 3, 43, 6, 16, 4, 91, 2, 91, 7, 78, 8, 84, 
    3, 69, 0, 64, 1, 40, 2, 28, 6,  8, 8, 52, 4, 17, 7, 14, 5, 50, 
    5, 73, 0, 92, 7, 99, 8, 71, 2, 20, 4, 74, 6, 81, 3, 99, 1,  5
  };
  const int q7502[] = {
    9, 9, // Number of jobs and machines
    4, 41, 1, 62, 3, 69, 2, 39, 0, 65, 6, 77, 5, 80, 7, 85, 8, 24, 
    8, 25, 7, 32, 4, 28, 6, 96, 0,  8, 5, 40, 2,  9, 1,  5, 3, 87, 
    2, 97, 7, 87, 8, 36, 4, 64, 1,  9, 0, 89, 6, 35, 3, 52, 5, 26, 
    6, 31, 3, 25, 0, 18, 5,  4, 1,  1, 7, 74, 4, 62, 2,  1, 8, 57, 
    2, 94, 1, 31, 7, 50, 3, 87, 4, 51, 5, 62, 6, 31, 0, 78, 8, 18, 
    0,  2, 7, 89, 1, 99, 2, 96, 8, 98, 6, 51, 3, 87, 5, 43, 4, 99, 
    5, 29, 3, 96, 4, 85, 8, 95, 7, 52, 1, 81, 0, 70, 6, 18, 2, 14, 
    0, 82, 6, 52, 1, 14, 5, 75, 3, 49, 2, 96, 7, 74, 8, 19, 4, 89, 
    2, 31, 5, 73, 0, 96, 8, 45, 4, 94, 7, 27, 6, 78, 3, 78, 1, 33
  };
  const int q7503[] = {
    9, 9, // Number of jobs and machines
    7, 34, 0, 46, 6, 72, 2, 28, 1, 98, 4, 35, 8, 37, 5, 79, 3, 58, 
    4, 23, 2, 68, 6, 84, 7, 59, 5, 39, 0, 70, 3, 97, 8, 10, 1, 94, 
    6, 96, 3, 80, 7, 20, 0, 39, 8, 75, 4,  5, 2, 70, 5, 25, 1, 76, 
    1, 10, 3, 23, 6, 13, 5, 10, 0, 80, 8, 68, 2, 31, 4, 78, 7, 19, 
    1, 71, 5, 66, 6, 14, 3, 68, 2, 82, 8, 47, 4, 26, 0, 70, 7, 24, 
    5,  6, 8, 53, 0, 75, 3, 21, 4, 70, 2, 32, 1, 94, 6, 14, 7,  8, 
    6, 48, 7, 68, 1, 52, 0, 78, 5,  1, 4, 85, 8, 44, 3, 36, 2, 11, 
    5, 19, 7, 70, 2, 17, 4,  4, 8, 98, 0, 56, 1, 75, 6, 33, 3, 65, 
    1, 79, 5, 22, 2, 96, 6, 57, 8, 96, 0, 31, 7, 12, 4, 11, 3, 19
  };
  const int q7504[] = {
    9, 9, // Number of jobs and machines
    4, 28, 8, 44, 1, 38, 0, 70, 3, 80, 6, 13, 2, 98, 5, 86, 7, 38, 
    1, 14, 7, 36, 6, 35, 8, 66, 5, 48, 2, 99, 0, 61, 4, 42, 3, 20, 
    0, 77, 2, 18, 4, 60, 6, 61, 7, 96, 8, 34, 5, 56, 3, 96, 1, 67, 
    3, 46, 6, 42, 7, 80, 1, 76, 8, 79, 4, 27, 2, 92, 5, 97, 0, 31, 
    2, 58, 4,  1, 3, 45, 7,  2, 0, 75, 6, 98, 1, 31, 8,  6, 5, 97, 
    0, 31, 3, 73, 6, 10, 5, 70, 2, 34, 4, 18, 7,  1, 1, 66, 8, 66, 
    7, 54, 3, 16, 5, 55, 1, 89, 4, 85, 0, 46, 2, 39, 8, 46, 6, 38, 
    6,  5, 7, 15, 0, 13, 5, 61, 3, 40, 8, 35, 1, 65, 4, 40, 2, 46, 
    3, 20, 0, 84, 7, 14, 2, 73, 4, 50, 6, 66, 5, 39, 8, 80, 1, 43
  };
  const int q7505[] = {
    9, 9, // Number of jobs and machines
    8, 73, 7, 19, 5, 35, 3, 21, 4, 85, 1, 66, 0, 12, 6, 75, 2, 23, 
    0, 38, 8, 15, 4,  4, 6, 40, 5, 67, 3, 53, 1, 82, 2, 90, 7, 77, 
    5,  1, 2, 22, 1, 20, 3, 42, 7, 48, 8, 77, 0, 60, 4, 12, 6, 26, 
    1, 14, 0, 89, 3, 86, 2, 95, 6, 18, 4,  1, 5, 25, 8, 65, 7,  6, 
    6, 26, 7,  2, 3, 48, 5, 92, 1, 22, 0, 91, 8, 14, 4,  1, 2, 29, 
    4, 63, 1, 75, 2, 91, 3, 96, 0, 47, 6, 36, 7, 79, 8,  3, 5, 41, 
    8, 50, 6, 57, 5, 88, 1, 31, 3, 86, 0, 68, 4, 82, 2, 89, 7, 37, 
    5, 25, 4, 27, 0, 24, 6, 71, 3, 41, 8, 40, 7, 27, 1, 63, 2, 75, 
    5, 64, 4, 85, 1, 50, 8, 76, 0, 40, 3, 22, 6,  7, 2, 63, 7, 60
  };
  const int q7506[] = {
    9, 9, // Number of jobs and machines
    8, 85, 3, 36, 5, 15, 0, 83, 4, 94, 7, 74, 1, 66, 6, 63, 2, 16, 
    6, 12, 5, 63, 4, 17, 0, 98, 7, 42, 1, 10, 8,  8, 2, 92, 3, 31, 
    5, 37, 6, 10, 2, 19, 1, 93, 0, 52, 4, 31, 7, 18, 8, 42, 3, 55, 
    2, 11, 4,  6, 8, 77, 0, 41, 3, 22, 6, 97, 1, 92, 5, 45, 7, 48, 
    7, 92, 0,  6, 2, 97, 6, 49, 4, 66, 8, 77, 5, 76, 3, 74, 1, 43, 
    1, 87, 6, 15, 4, 14, 8, 81, 5, 38, 7, 78, 0, 82, 3, 85, 2, 63, 
    0, 34, 4, 28, 3, 79, 1, 62, 7, 16, 5, 39, 8, 39, 2, 78, 6, 37, 
    8, 93, 1, 90, 7, 79, 6, 15, 0, 30, 4, 48, 5,  7, 3, 40, 2, 88, 
    4, 53, 2, 31, 5, 42, 1, 31, 3, 31, 8, 19, 0, 29, 6, 11, 7, 70
  };
  const int q7507[] = {
    9, 9, // Number of jobs and machines
    8, 22, 2, 99, 0, 67, 3, 95, 4, 80, 7, 40, 6, 21, 1, 64, 5, 89, 
    7, 22, 6, 53, 4, 93, 1, 48, 3, 32, 8,  5, 2, 93, 5, 81, 0, 74, 
    8, 98, 7, 86, 5, 64, 2, 59, 6, 69, 1, 94, 4, 99, 0, 67, 3, 33, 
    8,  6, 4, 82, 6, 43, 7, 40, 5, 62, 1, 69, 0, 63, 2, 31, 3, 93, 
    7, 28, 0, 69, 8, 10, 6, 56, 4, 54, 5, 33, 3,  9, 2, 63, 1, 39, 
    3, 49, 7, 23, 5, 52, 1, 34, 2, 89, 0, 20, 4, 21, 6, 14, 8, 78, 
    7, 81, 2, 57, 4, 32, 0, 10, 6, 61, 1,  3, 3, 31, 8, 13, 5, 87, 
    8, 40, 5, 46, 0, 97, 4, 98, 2, 69, 1,  7, 3, 35, 7,  8, 6, 12, 
    8, 35, 3, 17, 7, 44, 4, 48, 2, 41, 1, 42, 0,  2, 6, 31, 5, 90
  };
  const int q7508[] = {
    9, 9, // Number of jobs and machines
    3, 40, 2, 26, 7, 34, 1, 61, 6, 18, 4, 19, 8, 89, 5, 87, 0, 67, 
    4, 75, 0, 51, 5, 85, 3, 20, 8, 32, 2, 10, 7, 60, 1, 60, 6, 18, 
    0, 23, 2, 38, 3, 85, 6, 45, 7, 60, 1, 50, 8, 54, 4, 15, 5,  6, 
    2, 28, 5, 35, 3, 62, 4, 73, 8, 88, 6, 88, 0, 91, 7, 50, 1, 23, 
    4, 10, 3, 71, 8, 82, 1, 86, 5, 88, 6, 24, 2, 68, 7, 57, 0,  4, 
    4, 50, 8, 41, 5, 35, 1, 29, 6, 64, 7, 27, 2, 47, 0,  3, 3, 49, 
    8, 16, 4, 15, 1, 27, 3, 94, 2, 46, 6, 97, 0, 25, 7, 90, 5, 78, 
    4, 82, 1, 25, 0, 45, 7, 51, 5, 10, 3, 79, 6, 28, 8, 38, 2, 20, 
    3, 93, 8, 59, 2, 93, 1, 78, 6, 67, 4, 68, 5, 88, 7, 38, 0, 33
  };
  const int q7509[] = {
    9, 9, // Number of jobs and machines
    1, 91, 6, 32, 5, 16, 2, 46, 8, 34, 4, 37, 3, 66, 0, 13, 7, 58, 
    3, 33, 4, 76, 6, 90, 8, 56, 5, 54, 7, 44, 1, 67, 0, 80, 2, 74, 
    2, 11, 8, 26, 7, 88, 5, 65, 6, 82, 0, 17, 3, 99, 4, 38, 1, 91, 
    5, 99, 4, 38, 2, 11, 1, 10, 0, 75, 8,  5, 3, 16, 7, 25, 6, 52, 
    0, 32, 5, 74, 7, 90, 2, 24, 1, 53, 4, 43, 8, 57, 6, 61, 3, 29, 
    6, 67, 4, 72, 0, 93, 5, 16, 7, 45, 1, 17, 3, 41, 2, 56, 8, 49, 
    3, 94, 1, 19, 2, 11, 6, 39, 5, 84, 0, 91, 7, 50, 8,  1, 4, 15, 
    7, 11, 4, 22, 0, 45, 5, 14, 2, 56, 6,  4, 3, 17, 1, 15, 8, 29, 
    2, 91, 7,  3, 8, 14, 6, 56, 0, 53, 3, 32, 1, 80, 4, 56, 5, 58
  };
  const int q7510[] = {
    9, 9, // Number of jobs and machines
    2, 78, 6, 71, 4, 29, 0, 84, 5, 31, 3, 54, 7,  3, 8, 37, 1, 87, 
    1, 76, 5, 38, 0, 34, 2, 20, 8, 56, 7,  3, 3, 68, 4,  4, 6, 55, 
    5, 63, 4, 60, 7,  7, 0, 87, 3, 84, 1, 73, 2,  8, 8, 92, 6, 70, 
    4, 29, 5, 81, 6,  8, 7, 83, 8, 67, 2, 71, 3, 61, 0, 54, 1, 11, 
    6, 95, 0, 89, 2,  9, 1, 29, 5, 66, 4, 64, 3, 32, 8, 99, 7, 13, 
    6,  2, 2, 65, 1, 55, 8, 55, 0, 69, 3,  8, 7, 14, 5, 90, 4, 62, 
    6, 45, 3, 54, 7, 63, 4, 36, 1, 53, 2, 88, 5, 87, 0, 13, 8, 44, 
    4, 29, 5, 55, 2, 87, 6, 10, 3, 32, 1, 42, 0, 24, 8,  3, 7, 71, 
    3, 73, 1, 59, 4, 40, 0,  8, 5, 73, 2, 98, 8, 41, 6, 72, 7, 51
  };
  const int q7511[] = {
    9, 9, // Number of jobs and machines
    8, 77, 2, 29, 1, 36, 3, 15, 5, 61, 4, 45, 7, 13, 6, 90, 0, 53, 
    0, 13, 6, 24, 3, 55, 1, 59, 4, 36, 2, 29, 5, 15, 7, 61, 8, 71, 
    2,  1, 5, 46, 6, 92, 0, 61, 3, 15, 8, 97, 4, 23, 1, 18, 7, 61, 
    5, 14, 0, 57, 7, 99, 6, 78, 8, 67, 4, 24, 2, 46, 3, 30, 1,  6, 
    3, 49, 6, 74, 8, 92, 4, 41, 7, 74, 0, 81, 1, 62, 2, 35, 5, 14, 
    1, 22, 4, 68, 0,  4, 6, 73, 3, 55, 5, 81, 8, 82, 2, 41, 7, 57, 
    7, 94, 0,  7, 4, 33, 8, 97, 6, 80, 3, 58, 2, 97, 1, 20, 5, 54, 
    0, 45, 7, 24, 1, 63, 8, 10, 4, 75, 5, 19, 3,  1, 2,  5, 6, 36, 
    6, 15, 5,  6, 2, 37, 4, 10, 0, 54, 3, 43, 7, 57, 1, 83, 8, 24
  };
  const int q7512[] = {
    9, 9, // Number of jobs and machines
    2, 87, 0, 87, 4, 28, 6, 24, 7, 46, 3, 58, 1, 63, 8, 68, 5, 77, 
    7,  1, 2, 64, 3, 71, 8,  9, 1, 31, 0, 15, 5, 82, 4, 50, 6, 84, 
    2, 59, 8,  5, 6, 99, 3, 54, 5, 24, 1, 25, 7, 61, 4,  2, 0,  9, 
    4, 81, 6, 68, 3, 78, 0, 98, 2, 28, 8, 86, 1, 84, 7, 93, 5,  8, 
    1, 28, 7, 22, 6, 79, 8, 65, 3, 15, 5, 37, 0, 54, 4,  3, 2, 16, 
    0, 73, 6, 68, 3, 33, 8, 85, 5, 48, 2, 37, 4, 40, 7, 61, 1, 86, 
    5, 11, 3, 25, 2, 14, 8, 45, 7, 81, 0, 85, 1,  4, 4, 80, 6, 71, 
    6, 76, 0, 22, 4, 38, 7, 37, 2, 66, 1, 91, 5, 40, 8, 26, 3, 43, 
    0, 53, 5, 40, 4, 78, 3, 29, 6, 23, 7, 47, 1, 95, 8, 11, 2, 12
  };
  const int q7513[] = {
    9, 9, // Number of jobs and machines
    4,  6, 5, 47, 3, 26, 6, 44, 1, 79, 8, 26, 2,  8, 0, 57, 7, 90, 
    1, 59, 2, 85, 6, 71, 7,  3, 0, 90, 5, 30, 8, 83, 4, 30, 3, 65, 
    1, 76, 2, 14, 8, 42, 3, 30, 0, 48, 6, 24, 4, 50, 7, 56, 5, 60, 
    8,  6, 0, 58, 2, 82, 4,  2, 1,  7, 5, 16, 6, 48, 7, 81, 3, 93, 
    5, 58, 7,  3, 1, 88, 6, 48, 3, 36, 2, 25, 4, 46, 8, 87, 0, 22, 
    8, 96, 0, 71, 2, 75, 7,  5, 6,  6, 1, 74, 3, 99, 4, 98, 5, 69, 
    7, 70, 4,  8, 2, 79, 8, 70, 5, 41, 0, 85, 6, 79, 1,  4, 3, 57, 
    4, 87, 1, 59, 6, 48, 7, 64, 8, 10, 5, 42, 2, 91, 0, 45, 3, 36, 
    4, 57, 2, 71, 6, 73, 7, 37, 3, 32, 5, 24, 8, 96, 0, 66, 1, 41
  };
  const int q7514[] = {
    9, 9, // Number of jobs and machines
    4, 21, 8, 80, 5,  9, 7, 15, 2, 31, 0, 21, 3, 80, 6, 19, 1, 10, 
    3, 74, 2, 45, 7, 76, 4, 70, 8, 13, 0, 98, 5, 55, 6, 48, 1,  6, 
    4,  7, 3, 24, 6, 33, 0, 38, 2, 96, 8, 26, 1, 84, 5, 37, 7, 66, 
    7, 17, 1, 94, 4, 70, 5, 24, 8, 14, 0, 60, 6, 90, 3, 61, 2,  8, 
    5, 78, 3, 73, 8, 78, 0, 99, 2,  7, 6, 19, 7, 92, 4, 18, 1,  5, 
    8, 52, 0, 46, 3, 36, 4, 85, 6, 77, 7,  3, 1, 16, 2, 45, 5, 23, 
    2, 20, 0, 51, 7,  8, 4, 77, 1,  6, 3, 58, 8, 66, 5, 91, 6, 61, 
    5, 27, 4, 23, 1, 90, 6, 92, 3, 36, 7, 32, 0, 96, 8, 20, 2, 32, 
    5, 59, 0, 50, 7, 84, 4, 78, 2, 13, 1, 60, 6,  2, 8, 86, 3, 41
  };
  const int q7515[] = {
    9, 9, // Number of jobs and machines
    0, 56, 7, 71, 5,  2, 4, 44, 1, 51, 3, 53, 6, 27, 8, 10, 2, 78, 
    6, 11, 5, 57, 8, 46, 2, 76, 0, 99, 3, 25, 1,  5, 4, 15, 7, 39, 
    7, 25, 5, 58, 1, 49, 8, 49, 2, 49, 3, 61, 6, 99, 4, 90, 0, 24, 
    3, 58, 4, 88, 7, 87, 1, 83, 8, 61, 6,  3, 2, 43, 5, 50, 0, 45, 
    8,  4, 3, 92, 2, 68, 5, 87, 0, 63, 7, 13, 6, 88, 4, 64, 1, 45, 
    5, 29, 1, 17, 3, 30, 2, 79, 6, 63, 0, 38, 4, 48, 7,  6, 8, 56, 
    2, 64, 6, 14, 0, 57, 3, 77, 8, 22, 1, 17, 7, 16, 5, 85, 4, 47, 
    2, 70, 6, 59, 8, 34, 5, 52, 3, 30, 0, 95, 7, 19, 4, 36, 1, 63, 
    8, 80, 4, 42, 1,  9, 0, 38, 7,  5, 6,  9, 2, 42, 3, 21, 5, 58
  };
  const int q7516[] = {
    9, 9, // Number of jobs and machines
    4, 73, 1, 47, 3, 55, 8,  2, 5, 77, 6, 84, 7,  4, 0, 39, 2, 87, 
    6, 71, 1, 28, 4, 46, 7, 14, 2, 41, 3, 27, 5, 40, 0, 32, 8, 34, 
    5, 44, 3, 66, 6, 11, 8, 37, 7, 14, 2, 46, 0, 28, 4,  9, 1, 25, 
    0, 62, 8, 98, 5, 43, 7, 29, 6, 70, 2, 16, 1, 46, 3, 33, 4, 59, 
    1, 64, 8, 70, 3, 84, 2, 49, 4, 60, 5,  6, 0, 67, 7, 80, 6, 18, 
    7,  8, 1, 26, 8,  2, 6, 40, 0, 25, 3, 97, 2, 12, 5, 83, 4, 40, 
    8, 17, 4, 66, 6, 74, 7, 29, 3, 92, 5, 29, 1, 87, 0, 90, 2, 76, 
    8, 53, 3, 27, 5,  6, 4, 76, 6, 10, 7, 80, 2, 64, 1, 99, 0, 64, 
    8, 75, 4, 80, 2, 99, 1, 16, 5, 89, 3, 24, 0,  8, 6, 55, 7, 15
  };
  const int q7517[] = {
    9, 9, // Number of jobs and machines
    0, 88, 7, 95, 3,  2, 6, 88, 2, 34, 4, 55, 8, 32, 5, 65, 1, 54, 
    2, 81, 1,  5, 7, 97, 4, 34, 3, 18, 0, 41, 6, 44, 5, 67, 8, 35, 
    8, 58, 6, 31, 5, 22, 4, 76, 3, 49, 7,  9, 2,  4, 0, 75, 1, 45, 
    5, 78, 1, 36, 6, 79, 7, 43, 0, 96, 4, 77, 2, 43, 8, 76, 3, 50, 
    6, 27, 7, 84, 0, 41, 5, 21, 3, 55, 8, 63, 4, 44, 1, 71, 2, 39, 
    3, 82, 2, 53, 4, 23, 0, 66, 7, 27, 1, 71, 6, 55, 8, 87, 5, 59, 
    6,  5, 5, 40, 2, 75, 8, 63, 4, 39, 1, 54, 7,  6, 0, 11, 3, 34, 
    3, 42, 7, 59, 5, 53, 8, 26, 4, 81, 1, 92, 6, 98, 2, 49, 0, 80, 
    1, 29, 6, 55, 4, 27, 7,  3, 8, 42, 0, 54, 5, 17, 3, 29, 2, 12
  };
  const int q7518[] = {
    9, 9, // Number of jobs and machines
    6, 36, 5, 34, 0, 42, 7,  2, 2, 58, 1, 24, 4, 17, 3, 57, 8, 13, 
    7, 37, 8, 70, 6, 52, 0, 56, 1, 74, 4, 89, 5, 71, 2, 51, 3, 52, 
    8, 61, 3, 75, 2, 22, 4, 28, 1, 73, 5, 33, 0, 96, 6, 98, 7,  2, 
    2, 58, 0, 93, 8, 83, 5, 88, 3, 59, 1, 36, 7, 19, 6,  2, 4, 96, 
    5, 13, 2,  8, 6, 99, 0, 42, 1, 43, 8, 54, 7, 50, 4, 51, 3, 10, 
    7, 76, 6,  7, 1, 59, 2,  9, 0,  9, 8, 38, 5, 47, 3, 10, 4, 74, 
    6, 73, 4, 67, 2, 81, 7, 42, 5, 39, 8, 46, 3, 61, 1, 37, 0,  8, 
    1, 51, 3, 47, 5, 16, 7, 72, 2, 18, 8,  9, 0, 31, 6, 75, 4,  2, 
    0, 16, 7, 54, 4, 23, 3, 18, 5, 69, 8,  8, 1, 32, 6, 86, 2, 92
  };
  const int q7519[] = {
    9, 9, // Number of jobs and machines
    5, 69, 8, 90, 4, 40, 7, 86, 0, 89, 6, 29, 1, 75, 3, 25, 2, 62, 
    7, 10, 5, 36, 4, 61, 3, 21, 1, 92, 6, 78, 0,  1, 8,  1, 2, 81, 
    1, 25, 4, 97, 5, 59, 3, 38, 2,  2, 6,  4, 0, 83, 8, 52, 7, 41, 
    7, 11, 4, 15, 5, 17, 2, 52, 3, 90, 1, 65, 8, 14, 6, 58, 0,  2, 
    1, 79, 8, 73, 3,  5, 2, 46, 4, 30, 6, 26, 0, 62, 5, 59, 7, 76, 
    3, 17, 2, 13, 8, 78, 0, 74, 6, 33, 7, 42, 5, 96, 1, 81, 4, 30, 
    1, 31, 5, 45, 2, 24, 0, 30, 4, 13, 6, 79, 8, 60, 3, 45, 7, 17, 
    5, 19, 7, 64, 4,  2, 1, 49, 8,  1, 6, 62, 3, 87, 2, 33, 0, 85, 
    5, 36, 2, 33, 3, 21, 7, 67, 1, 65, 0, 36, 4, 76, 6, 65, 8, 48
  };
  const int q7520[] = {
    9, 9, // Number of jobs and machines
    5, 76, 0, 48, 2, 20, 7, 39, 6, 60, 4, 24, 3, 46, 1, 22, 8, 13, 
    1, 92, 7, 21, 5, 17, 6, 17, 4, 72, 3, 56, 2, 31, 0, 68, 8, 43, 
    5, 98, 8, 23, 4, 97, 1,  9, 6, 10, 7, 98, 3, 25, 0, 42, 2,  5, 
    0, 36, 6, 87, 2, 79, 1, 58, 7, 23, 8, 98, 4, 40, 5, 15, 3, 95, 
    8, 43, 6, 70, 1, 13, 7, 79, 3, 22, 4, 95, 5, 91, 2, 47, 0, 70, 
    6, 75, 0,  7, 8, 99, 4, 86, 3, 33, 2, 43, 1, 17, 5, 82, 7, 24, 
    7, 33, 5, 67, 4, 40, 0, 48, 6, 86, 2, 50, 3, 83, 1, 73, 8, 46, 
    4, 73, 1, 40, 6, 97, 2, 72, 3, 97, 7, 12, 0, 57, 8, 30, 5, 29, 
    5, 10, 4, 75, 3, 39, 0, 24, 8, 35, 2, 69, 1, 98, 7, 61, 6, 17
  };
  const int q7521[] = {
    9, 9, // Number of jobs and machines
    6, 97, 5, 20, 2, 23, 3, 43, 0, 78, 4, 88, 8, 27, 1, 24, 7, 30, 
    4, 87, 1, 93, 5, 37, 6, 13, 3, 82, 7, 42, 0, 17, 2, 83, 8, 46, 
    0, 81, 7, 94, 8, 15, 1, 32, 5, 87, 3, 29, 6, 90, 2, 48, 4, 79, 
    6, 99, 2,  5, 5, 29, 7, 80, 0,  2, 4, 20, 8, 72, 3, 83, 1, 62, 
    0, 34, 4, 30, 2, 75, 3, 84, 7, 59, 6, 78, 5, 69, 1, 75, 8, 29, 
    7, 80, 1, 57, 2, 78, 8, 93, 6,  1, 0, 24, 3,  5, 5,  7, 4, 34, 
    7, 57, 2, 12, 4, 53, 5, 97, 3, 95, 0,  3, 6, 88, 1, 45, 8, 27, 
    7, 88, 1, 13, 8, 20, 4, 80, 6, 26, 2,  3, 0, 85, 5, 99, 3, 83, 
    0, 24, 1, 18, 5, 77, 4,  3, 3, 88, 8, 68, 2, 58, 6, 54, 7, 78
  };
  const int q7522[] = {
    9, 9, // Number of jobs and machines
    1, 72, 3, 78, 0, 48, 4, 50, 5, 57, 2, 30, 8, 19, 6, 41, 7, 70, 
    4, 96, 5, 17, 7, 86, 8, 34, 2, 66, 6, 78, 1, 56, 0,  2, 3, 88, 
    2, 45, 3, 11, 4,  4, 8, 89, 1, 34, 7,  3, 6, 19, 5, 37, 0,  8, 
    4, 27, 5, 64, 3, 85, 2,  4, 0, 31, 6, 71, 7, 67, 8, 84, 1, 70, 
    5, 45, 7, 68, 6, 58, 3, 75, 1, 66, 2, 87, 0, 24, 8,  8, 4, 79, 
    2, 51, 6, 82, 1, 68, 4, 88, 5, 59, 7, 36, 0, 20, 8, 70, 3, 50, 
    0, 86, 5, 25, 2, 59, 6, 62, 1, 44, 3, 18, 4, 15, 7,  2, 8, 33, 
    5, 71, 6,  3, 0, 20, 7, 27, 8, 43, 4, 98, 2, 80, 1, 26, 3, 20, 
    4, 21, 8, 83, 1, 93, 7, 97, 6, 65, 5,  4, 2, 35, 3, 25, 0, 59
  };
  const int q7523[] = {
    9, 9, // Number of jobs and machines
    5, 82, 0, 96, 2, 88, 8, 91, 3, 73, 4, 11, 6, 14, 1, 69, 7, 85, 
    2, 99, 5, 89, 1, 63, 7, 22, 0, 81, 8, 33, 3, 96, 6, 61, 4, 72, 
    6, 40, 4, 51, 7, 32, 3,  1, 5, 41, 1, 90, 0, 42, 8, 53, 2, 10, 
    4, 36, 1, 50, 8, 76, 7, 24, 2, 46, 6, 36, 0, 84, 3, 29, 5,  9, 
    2,  1, 4, 58, 5, 69, 7, 72, 1, 71, 6, 17, 3, 24, 8, 48, 0, 51, 
    8, 94, 3, 27, 2, 29, 4, 98, 0, 43, 7, 67, 5, 66, 6, 55, 1, 93, 
    7, 24, 3, 41, 0, 83, 8, 85, 1,  5, 4, 32, 5, 21, 6, 39, 2,  2, 
    4, 32, 2, 12, 5, 97, 6, 91, 1, 95, 3, 40, 7, 52, 0,  2, 8, 34, 
    4,  4, 5, 68, 0, 33, 2, 10, 3, 17, 8, 89, 6, 83, 7, 54, 1, 80
  };
  const int q7524[] = {
    9, 9, // Number of jobs and machines
    2, 95, 0, 97, 1, 61, 6, 95, 5, 34, 7, 77, 4, 38, 8, 11, 3, 25, 
    5, 85, 3, 20, 1, 88, 2, 59, 6, 51, 8, 72, 0, 30, 7, 73, 4,  7, 
    2, 96, 4, 57, 5, 26, 3, 61, 1, 15, 6, 26, 7, 24, 8, 96, 0, 29, 
    1, 52, 2, 96, 8,  9, 7, 99, 3, 79, 0, 46, 4, 80, 6, 68, 5, 36, 
    4, 84, 6, 94, 5, 36, 8, 63, 2, 49, 1, 17, 3, 59, 0, 90, 7, 72, 
    7, 48, 8, 21, 0, 89, 4, 16, 3, 66, 5, 54, 1,  3, 2, 21, 6,  3, 
    8, 96, 0, 60, 5, 52, 6, 98, 7, 25, 2, 93, 3, 65, 1, 17, 4, 48, 
    2, 59, 5, 96, 8, 20, 4, 43, 6, 74, 3, 87, 7, 71, 0, 11, 1, 31, 
    4, 45, 8, 49, 1, 15, 3, 22, 7,  7, 6, 14, 5, 91, 0, 74, 2, 23
  };
  const int q7525[] = {
    9, 9, // Number of jobs and machines
    1, 75, 7, 25, 6, 60, 3, 53, 5,  5, 4, 30, 2,  4, 8, 81, 0, 72, 
    6, 35, 1, 47, 5, 76, 2, 57, 7, 81, 3, 44, 8, 98, 0, 31, 4,  9, 
    5,  1, 8, 24, 3, 75, 1, 82, 4, 66, 2, 58, 6,  3, 0, 10, 7,  7, 
    1, 95, 8,  9, 3, 28, 6, 23, 7, 54, 2, 14, 5, 55, 4, 41, 0, 96, 
    0, 17, 4,  9, 7, 74, 8, 56, 1, 17, 3, 48, 6,  1, 2, 86, 5, 47, 
    8, 10, 0, 83, 7, 68, 3,  2, 2,  7, 6, 93, 5, 58, 1, 15, 4, 55, 
    1, 90, 6, 29, 0, 24, 4, 29, 8,  2, 3, 92, 2, 21, 5, 99, 7,  5, 
    5, 51, 1, 71, 0, 50, 6, 15, 4, 63, 7, 79, 2, 36, 8, 40, 3,  6, 
    6, 22, 3, 96, 0, 18, 7, 22, 4, 64, 8, 30, 5, 44, 2, 83, 1, 36
  };
  const int q7526[] = {
    9, 9, // Number of jobs and machines
    2, 44, 7, 31, 1, 64, 5, 65, 6, 63, 3, 59, 4, 72, 8, 93, 0, 78, 
    3, 61, 8, 50, 5, 18, 0, 60, 6, 33, 2, 70, 7, 42, 1, 79, 4, 17, 
    0, 10, 1, 36, 2, 89, 4, 11, 6, 33, 3, 99, 8, 12, 5, 14, 7, 59, 
    5, 85, 7, 73, 2, 30, 8, 75, 0, 50, 6, 16, 3, 62, 4, 68, 1, 61, 
    4, 85, 1, 33, 6, 31, 0, 83, 2, 10, 7, 56, 3, 64, 5, 91, 8, 58, 
    3, 24, 8,  6, 0, 95, 1, 90, 7, 72, 6, 47, 5,  1, 4, 19, 2, 32, 
    3, 96, 4, 33, 1, 21, 6, 92, 8,  4, 2, 35, 0,  8, 7, 30, 5, 15, 
    6, 79, 4, 87, 8, 71, 7, 49, 2, 69, 3, 92, 5, 72, 1, 31, 0, 45, 
    1, 74, 4, 69, 2, 66, 5,  3, 0, 92, 8, 40, 3, 98, 7, 20, 6, 11
  };
  const int q7527[] = {
    9, 9, // Number of jobs and machines
    0, 34, 2, 99, 1, 83, 8, 32, 5, 44, 6, 21, 3, 17, 4, 48, 7, 26, 
    3, 32, 1, 26, 6, 16, 2, 24, 0, 22, 4, 36, 5, 82, 7, 95, 8, 80, 
    6, 79, 1, 28, 5, 13, 0, 64, 7, 31, 2, 92, 4, 85, 8, 82, 3, 75, 
    7, 40, 3, 39, 6, 80, 8, 33, 0,  6, 2, 20, 1, 79, 4, 79, 5, 71, 
    6, 57, 5, 80, 3, 15, 2, 23, 1, 44, 8, 74, 4, 99, 0, 25, 7, 18, 
    8, 88, 0, 91, 1, 26, 4, 47, 5, 66, 2, 19, 6, 56, 7, 94, 3, 61, 
    8, 32, 1, 69, 5, 44, 3, 91, 0, 35, 4, 89, 6, 56, 2,  3, 7, 85, 
    7, 74, 5, 51, 0, 99, 3, 83, 4, 81, 1, 63, 2, 18, 8, 60, 6, 13, 
    2, 45, 1, 12, 8, 88, 7, 95, 4, 84, 3, 93, 0, 72, 6, 30, 5, 62
  };
  const int q7528[] = {
    9, 9, // Number of jobs and machines
    1, 73, 5,  6, 8, 80, 2, 50, 4, 36, 6, 71, 7,  5, 3, 37, 0, 36, 
    0, 40, 3, 96, 6, 47, 5, 38, 8, 37, 2, 57, 1, 49, 4, 53, 7, 36, 
    8, 38, 7, 55, 3,  1, 1, 76, 5, 97, 6, 98, 4, 81, 2, 78, 0, 18, 
    4, 32, 1, 92, 7, 75, 0, 43, 5, 47, 2, 89, 8, 94, 6, 16, 3, 45, 
    1, 18, 4, 93, 0, 34, 3, 85, 6, 34, 7, 42, 2,  4, 8, 37, 5, 62, 
    3, 19, 4, 12, 8, 42, 1, 31, 6, 41, 2, 18, 0, 47, 5, 70, 7, 46, 
    6, 58, 2, 28, 0, 79, 8, 71, 4,  8, 1, 57, 5, 95, 3, 12, 7, 24, 
    0, 15, 2, 37, 3, 77, 4,  1, 1, 11, 6, 50, 7, 84, 8, 63, 5, 69, 
    5,  3, 1, 30, 0, 74, 2,  4, 8,  8, 7, 82, 4, 53, 3, 67, 6, 83
  };
  const int q7529[] = {
    9, 9, // Number of jobs and machines
    8, 35, 6, 34, 3, 34, 5, 67, 2, 24, 7, 25, 4, 31, 1, 68, 0, 66, 
    6, 34, 3, 22, 7, 81, 1, 59, 4, 99, 5, 27, 0, 45, 2, 23, 8, 66, 
    3, 48, 6, 15, 7, 49, 5, 92, 1, 40, 2, 28, 8, 31, 0, 25, 4, 49, 
    2,  4, 4, 11, 6, 69, 1, 54, 8,  3, 5, 92, 3, 37, 0,  2, 7, 94, 
    4, 51, 0, 90, 5, 31, 8, 23, 1, 83, 6, 95, 3, 76, 7, 84, 2, 83, 
    5, 28, 7, 99, 1, 80, 0, 25, 6, 38, 3, 45, 4, 28, 2, 75, 8, 73, 
    6, 73, 4,  8, 3, 66, 8, 97, 1, 49, 5,  6, 0, 69, 7, 43, 2, 30, 
    2, 66, 4, 53, 0, 50, 7, 15, 8, 63, 5, 24, 6,  7, 1, 99, 3, 59, 
    6, 70, 2, 66, 1, 89, 4, 60, 7, 37, 0,  9, 5, 13, 8, 71, 3, 62
  };
  const int q7530[] = {
    9, 9, // Number of jobs and machines
    6, 77, 2, 45, 4, 81, 0, 99, 8, 33, 1, 46, 3, 57, 5,  2, 7, 35, 
    7, 46, 0, 34, 2, 10, 4, 53, 6, 50, 1, 74, 3, 66, 8,  7, 5, 65, 
    6, 75, 2,  3, 0, 51, 3, 43, 8, 77, 7, 41, 1, 12, 4, 65, 5, 91, 
    5, 65, 1,  4, 7, 84, 6, 21, 8, 64, 2, 20, 4,  1, 3, 64, 0,  5, 
    1, 30, 2, 87, 8, 85, 7, 12, 0, 21, 4, 75, 3, 10, 5,  9, 6, 60, 
    8, 20, 3, 28, 7, 43, 6, 23, 1, 69, 0, 97, 4,  7, 2, 18, 5, 29, 
    2, 69, 5, 78, 4, 19, 1, 30, 0, 37, 7, 79, 8, 27, 3,  5, 6,  5, 
    4, 38, 0, 26, 6, 90, 5, 63, 7, 65, 8, 24, 3, 88, 1, 43, 2,  5, 
    1, 39, 6, 21, 5, 36, 0, 99, 2, 62, 3, 19, 4, 81, 8, 52, 7, 87
  };
  const int q7531[] = {
    9, 9, // Number of jobs and machines
    7, 82, 5, 99, 4, 38, 6, 31, 2, 65, 0, 82, 8, 60, 1, 36, 3, 14, 
    1, 58, 5, 97, 2, 39, 0, 41, 7, 10, 8, 61, 6, 80, 3, 78, 4,  3, 
    0, 53, 3, 90, 7, 17, 8, 65, 4,  5, 2, 41, 5, 56, 6,  8, 1, 62, 
    0, 91, 2, 87, 4, 49, 1, 15, 3, 57, 6, 83, 8, 41, 5, 34, 7, 81, 
    6, 90, 0, 58, 4,  6, 5, 65, 7, 31, 3, 40, 2, 11, 1, 84, 8, 64, 
    6,  4, 3, 24, 1, 95, 7, 63, 8, 73, 2, 27, 0, 61, 4, 23, 5, 27, 
    0, 22, 8, 53, 1, 13, 7, 21, 3, 82, 6, 73, 2, 84, 4, 66, 5, 57, 
    2, 43, 7, 63, 6, 55, 0, 75, 4, 63, 1, 99, 8, 92, 3, 56, 5, 71, 
    3, 46, 7, 32, 6,  5, 4, 91, 5, 69, 1, 33, 2, 71, 8, 88, 0, 19
  };
  const int q7532[] = {
    9, 9, // Number of jobs and machines
    4, 11, 8, 13, 0, 81, 5, 24, 2, 38, 3, 23, 6,  3, 1, 84, 7, 99, 
    1, 49, 8, 22, 5, 20, 7, 80, 4, 51, 6, 11, 0, 59, 3, 64, 2, 77, 
    7, 19, 0, 50, 5, 81, 6, 95, 8, 79, 2, 31, 1, 21, 4, 74, 3,  2, 
    7,  1, 8, 32, 4, 80, 0, 32, 6, 65, 3, 29, 1, 22, 5, 83, 2, 48, 
    3, 32, 0, 65, 8, 18, 1, 79, 2, 15, 5, 33, 7, 65, 4, 91, 6, 46, 
    5, 20, 0, 15, 8, 49, 4, 93, 2, 96, 3,  7, 6, 71, 1, 24, 7, 22, 
    6, 58, 2, 76, 1, 68, 8, 39, 3, 78, 0, 46, 5, 31, 7, 45, 4, 40, 
    1, 59, 2, 29, 7, 94, 0, 26, 5, 41, 6, 75, 8, 95, 4, 29, 3, 18, 
    3, 35, 6, 89, 2, 95, 5, 77, 8, 82, 1, 13, 7, 39, 0, 93, 4, 50
  };
  const int q7533[] = {
    9, 9, // Number of jobs and machines
    6, 78, 7, 98, 2, 40, 0, 91, 8,  5, 5, 58, 4, 45, 1, 58, 3, 31, 
    5, 72, 8, 14, 7, 62, 4, 22, 6, 90, 0, 11, 3, 59, 1, 30, 2, 45, 
    2, 69, 5, 19, 0, 73, 1, 57, 4, 63, 7, 32, 6, 74, 8, 81, 3, 25, 
    8, 94, 7, 37, 5, 32, 2,  3, 1, 26, 3, 78, 0, 38, 6, 60, 4, 79, 
    5, 46, 6, 51, 0, 66, 4, 99, 3,  8, 1, 40, 7, 36, 2, 72, 8, 97, 
    6, 21, 1, 61, 3, 12, 8, 95, 0, 95, 2, 96, 5, 66, 7, 91, 4, 17, 
    1, 37, 2, 62, 7,  6, 8, 61, 4, 23, 6, 47, 5, 84, 0, 62, 3, 70, 
    6, 98, 2, 74, 4, 45, 1,  8, 0, 77, 5, 46, 3, 81, 7, 62, 8, 57, 
    1, 53, 2, 48, 8, 27, 4, 46, 0, 15, 5, 89, 3, 88, 7, 73, 6, 52
  };
  const int q7534[] = {
    9, 9, // Number of jobs and machines
    0, 28, 8, 64, 1, 46, 2, 48, 3, 32, 4, 36, 7, 75, 6, 37, 5, 70, 
    8, 88, 4, 93, 3, 27, 5, 74, 7, 51, 6, 87, 0,  8, 2, 19, 1, 90, 
    7, 91, 3, 16, 6, 19, 8, 36, 5, 53, 0, 18, 1, 23, 4,  9, 2, 78, 
    2,  8, 7, 48, 3, 20, 0,  9, 6,  9, 8, 51, 4, 41, 1, 77, 5,  6, 
    4, 36, 3, 31, 5, 95, 8, 29, 7, 35, 1, 95, 2, 80, 0,  1, 6, 23, 
    2, 15, 5, 34, 1, 63, 6, 75, 7, 50, 8, 62, 3, 85, 0, 99, 4, 43, 
    1, 95, 4, 99, 5, 84, 2, 93, 8, 71, 7, 79, 0, 53, 3, 53, 6, 12, 
    6, 69, 1, 98, 7, 43, 8, 11, 3, 15, 0, 80, 5, 68, 2,  2, 4, 68, 
    7, 92, 8, 27, 6, 37, 4, 60, 3, 60, 2, 61, 5,  2, 0, 19, 1, 64
  };
  const int q7535[] = {
    9, 9, // Number of jobs and machines
    4, 35, 1, 44, 5, 90, 6, 86, 2, 59, 7, 56, 8, 53, 3, 45, 0, 60, 
    0, 32, 7, 71, 8, 56, 6, 40, 1, 89, 2, 23, 3, 82, 5, 10, 4, 28, 
    5, 14, 6, 18, 0, 27, 4, 36, 8, 27, 1, 52, 7, 58, 2, 13, 3, 34, 
    4, 38, 5, 63, 2, 62, 8, 31, 0, 63, 1, 22, 7, 47, 6, 99, 3, 97, 
    3, 63, 2, 19, 0, 29, 4, 57, 8, 58, 1, 58, 7, 30, 6, 23, 5, 43, 
    6, 24, 0, 89, 1, 67, 2, 28, 8, 49, 4, 34, 3, 80, 7, 96, 5, 69, 
    1, 64, 3, 31, 2, 45, 6, 96, 0, 19, 5, 97, 4, 12, 8, 95, 7, 57, 
    4,  6, 8, 92, 5, 70, 1, 56, 7, 99, 6, 79, 2, 97, 0, 80, 3, 62, 
    4, 33, 7, 13, 2, 79, 0, 67, 3, 88, 1, 47, 8,  7, 5, 96, 6, 47
  };
  const int q7536[] = {
    9, 9, // Number of jobs and machines
    6,  7, 2, 46, 5, 59, 8, 39, 1, 71, 3, 95, 0, 43, 4, 16, 7, 29, 
    6, 14, 2, 72, 5, 58, 8, 19, 3, 71, 4, 80, 7,  7, 1, 99, 0, 93, 
    4, 86, 5, 91, 3, 10, 2,  1, 8, 67, 1, 94, 7, 84, 6, 13, 0, 88, 
    5, 34, 6,  5, 0, 74, 8, 37, 7, 35, 2, 85, 3, 90, 4, 55, 1, 46, 
    0, 62, 6, 62, 1, 32, 7, 70, 5, 25, 4, 53, 3, 77, 8, 74, 2, 80, 
    4, 78, 6, 34, 1, 44, 8, 94, 7, 55, 3, 96, 2,  2, 5, 97, 0, 33, 
    0, 96, 5, 81, 8, 99, 3, 41, 6, 30, 7, 50, 4, 32, 1, 54, 2, 79, 
    2, 15, 7, 88, 1, 37, 6, 83, 0, 26, 4,  3, 8,  7, 3, 83, 5, 41, 
    3, 92, 5, 16, 0, 55, 7, 93, 4, 56, 6, 54, 1, 11, 8, 95, 2, 18
  };
  const int q7537[] = {
    9, 9, // Number of jobs and machines
    7, 94, 3, 49, 6, 44, 2, 76, 4, 36, 8,  7, 0, 98, 5,  3, 1, 79, 
    8, 82, 5, 17, 1, 60, 3, 77, 7,  7, 6, 23, 2, 27, 4, 47, 0, 54, 
    0, 89, 7, 77, 8, 51, 1, 45, 4, 57, 2, 82, 3,  9, 6, 43, 5, 38, 
    3, 20, 7, 35, 2, 39, 0, 97, 4, 44, 6, 26, 1, 42, 5, 90, 8, 43, 
    8, 83, 2, 30, 1, 55, 3, 64, 5, 82, 7, 76, 4, 91, 6, 95, 0, 45, 
    2, 18, 8,  7, 5,  7, 6, 14, 0, 84, 3, 45, 4, 26, 1,  4, 7, 94, 
    8, 57, 0, 55, 7, 11, 4, 28, 3, 99, 2, 94, 6, 74, 5,  4, 1, 21, 
    5, 19, 2, 19, 6, 39, 3, 76, 0,  5, 1,  9, 7, 38, 8, 96, 4,  2, 
    8, 53, 2, 92, 1, 37, 5, 66, 7, 23, 3,  2, 4, 61, 6, 68, 0, 48
  };
  const int q7538[] = {
    9, 9, // Number of jobs and machines
    0, 48, 1, 34, 3, 61, 5, 91, 6, 49, 2, 27, 4, 22, 7, 37, 8,  1, 
    1, 48, 7, 45, 3, 43, 4,  7, 0, 18, 5, 76, 2, 52, 6, 15, 8, 31, 
    1, 92, 2, 54, 0, 69, 5, 12, 6, 96, 4, 65, 3, 27, 8, 66, 7, 91, 
    5, 36, 7, 90, 6, 83, 2, 73, 1, 57, 4, 56, 8, 63, 3, 33, 0, 12, 
    0, 16, 5, 39, 7, 97, 1, 69, 6, 73, 2, 23, 8,  9, 4, 94, 3, 93, 
    5, 59, 0, 86, 2, 22, 3, 83, 6, 39, 8, 50, 7, 60, 4, 67, 1, 42, 
    3, 47, 5, 60, 0, 47, 1, 76, 6, 51, 2, 58, 4, 61, 7, 30, 8, 42, 
    2, 57, 7, 77, 8, 96, 1, 49, 3, 41, 6, 22, 0, 35, 4, 29, 5, 85, 
    5,  5, 4, 29, 8, 82, 6, 85, 3, 25, 2, 55, 7, 70, 0, 24, 1, 80
  };
  const int q7539[] = {
    9, 9, // Number of jobs and machines
    4, 77, 3, 32, 6, 93, 7, 17, 1, 40, 5, 58, 0, 37, 2, 92, 8, 86, 
    3, 77, 5, 53, 4, 66, 2, 96, 6, 94, 0, 11, 8, 82, 7, 69, 1, 82, 
    7, 16, 1, 41, 3, 57, 6, 47, 8, 12, 2, 24, 0, 98, 5, 55, 4,  5, 
    8, 21, 2, 64, 6, 84, 5, 39, 7, 62, 3, 45, 4, 94, 1, 41, 0, 85, 
    4, 93, 0, 65, 6, 90, 8, 21, 2, 84, 1, 50, 3, 47, 5, 22, 7, 90, 
    2, 16, 1, 15, 5,  1, 4, 41, 7, 78, 8,  9, 6, 37, 0, 12, 3, 27, 
    1, 38, 6, 82, 8, 85, 0, 42, 4, 28, 7, 15, 3, 35, 2, 20, 5, 37, 
    5, 98, 8, 53, 7, 81, 0, 36, 6, 96, 1, 74, 2, 15, 4, 77, 3, 38, 
    5, 49, 7, 51, 6, 72, 3, 59, 8, 60, 4, 75, 2, 40, 0, 96, 1, 59
  };
  const int q7540[] = {
    9, 9, // Number of jobs and machines
    5, 87, 2, 67, 7, 33, 8, 83, 0, 55, 3, 39, 1, 68, 6, 98, 4, 86, 
    6, 26, 3, 74, 8, 58, 0, 30, 5, 72, 4, 68, 7, 35, 1, 66, 2, 23, 
    6, 99, 0, 56, 2, 13, 5, 84, 7, 81, 8, 92, 3, 67, 1, 81, 4, 35, 
    6, 50, 8, 10, 2, 16, 7, 67, 5, 10, 0, 31, 4, 33, 1, 80, 3, 95, 
    5, 70, 8,  2, 4, 43, 7, 52, 1, 36, 2, 10, 6, 91, 0, 46, 3, 10, 
    2, 95, 4, 88, 3, 58, 7, 62, 1, 64, 0, 11, 8, 20, 5, 51, 6, 56, 
    5, 21, 0, 11, 4, 84, 8, 49, 3, 20, 1,  3, 7, 23, 6, 83, 2, 82, 
    5, 32, 8, 55, 6, 96, 7, 89, 3, 43, 2, 53, 0,  9, 4, 72, 1, 37, 
    4, 36, 1, 73, 3, 86, 7, 75, 8, 70, 6, 80, 0, 92, 5, 37, 2, 81
  };
  const int q7541[] = {
    9, 9, // Number of jobs and machines
    6,  9, 8, 96, 2, 65, 3, 46, 7, 53, 4, 41, 0, 77, 1, 84, 5, 22, 
    4, 12, 8, 74, 0, 42, 1, 95, 6, 87, 5, 26, 2, 70, 7, 14, 3, 59, 
    4, 68, 3,  9, 7, 75, 2, 61, 6, 78, 0,  2, 1, 10, 5, 37, 8, 21, 
    3, 76, 4, 40, 0, 20, 1, 55, 5, 31, 2, 73, 7, 42, 6, 17, 8,  2, 
    6, 99, 7, 77, 2, 94, 4, 98, 1, 42, 5, 69, 0, 31, 3,  9, 8, 27, 
    6, 19, 2, 15, 3, 34, 5, 17, 7, 53, 0, 40, 4, 35, 8, 69, 1, 28, 
    4, 24, 8, 41, 1,  4, 2,  4, 5, 25, 7, 18, 0, 63, 3, 89, 6, 26, 
    0, 38, 4, 92, 3, 17, 6, 88, 5, 83, 1, 66, 2, 85, 7, 36, 8,  3, 
    0, 46, 6, 67, 7, 81, 2, 75, 8, 14, 4, 47, 5,  9, 1, 49, 3, 18
  };
  const int q7542[] = {
    9, 9, // Number of jobs and machines
    3, 89, 8, 69, 5, 82, 4,  7, 1, 86, 7, 12, 0, 30, 2, 61, 6, 88, 
    4, 73, 8, 35, 0, 13, 1, 13, 7, 75, 5, 71, 6, 40, 3, 22, 2, 58, 
    0, 97, 2, 83, 6, 14, 4, 86, 8, 85, 3, 69, 5, 80, 7, 29, 1, 97, 
    0, 95, 1, 71, 5, 42, 8, 48, 4,  5, 2, 13, 7,  3, 3, 77, 6, 99, 
    7, 95, 1, 94, 2,  5, 0,  8, 4, 90, 8, 36, 6, 93, 3, 44, 5, 32, 
    0,  8, 2, 74, 7, 44, 6, 13, 4, 82, 3, 58, 1, 60, 8,  4, 5,  2, 
    4, 59, 6, 85, 8, 27, 5,  9, 0, 94, 7, 14, 3, 51, 1, 58, 2, 42, 
    3,  9, 0, 52, 4, 12, 5, 35, 7, 65, 1, 75, 2, 92, 8, 42, 6, 49, 
    5, 28, 7, 78, 8, 69, 3, 21, 4, 95, 6, 53, 0, 50, 2, 46, 1, 16
  };
  const int q7543[] = {
    9, 9, // Number of jobs and machines
    2, 36, 4, 72, 6, 36, 3, 60, 7, 78, 8, 13, 1, 38, 0, 49, 5, 11, 
    7, 27, 2,  4, 1, 21, 5, 66, 6, 17, 3, 84, 0, 57, 4, 37, 8, 21, 
    8, 86, 2, 50, 4, 15, 0, 33, 6,  3, 5, 55, 7, 13, 1,  6, 3, 15, 
    8, 10, 5, 14, 6, 11, 7, 22, 1, 12, 2, 36, 4, 66, 0, 86, 3, 57, 
    5, 73, 7, 33, 4, 22, 1, 27, 6, 40, 2, 92, 8, 56, 3, 95, 0, 30, 
    2, 15, 5, 21, 1, 93, 3, 16, 6, 27, 0, 56, 7, 71, 8, 58, 4,  7, 
    4, 16, 2, 34, 3, 18, 5, 79, 1,  4, 7,  1, 0, 35, 6, 85, 8, 13, 
    2,  8, 1, 95, 7, 70, 3, 30, 5, 69, 6, 33, 4, 58, 0, 33, 8,  3, 
    3, 67, 7, 78, 1, 56, 2, 55, 0, 54, 4, 87, 6, 86, 5, 54, 8, 56
  };
  const int q7544[] = {
    9, 9, // Number of jobs and machines
    8, 25, 7, 85, 0, 49, 2, 26, 1, 92, 5, 51, 6, 35, 3, 26, 4, 62, 
    8, 38, 2, 76, 4, 84, 1, 46, 5, 71, 0, 32, 3, 57, 6, 13, 7, 40, 
    4, 21, 1, 22, 3, 58, 6, 86, 8, 95, 5,  2, 7, 90, 0, 63, 2, 77, 
    7, 94, 0, 18, 8, 96, 6, 37, 4, 20, 1, 14, 3, 80, 5, 43, 2, 65, 
    1, 72, 6, 22, 4, 48, 2, 58, 5, 52, 8, 89, 7, 68, 0, 16, 3,  3, 
    4, 23, 3, 48, 8, 62, 5, 54, 2, 20, 7,  7, 6, 38, 1, 65, 0, 88, 
    0, 54, 5, 38, 8, 33, 2, 14, 1, 70, 7, 54, 4, 95, 6, 45, 3, 51, 
    7, 88, 3,  8, 4, 12, 5, 37, 1, 88, 6, 19, 2, 27, 0, 35, 8,  9, 
    3, 35, 0, 22, 4, 16, 8,  8, 7, 79, 6, 38, 2, 32, 1,  5, 5, 73
  };
  const int q7545[] = {
    9, 9, // Number of jobs and machines
    2, 16, 3, 99, 4, 76, 7, 27, 6, 81, 0, 61, 8, 32, 5, 22, 1, 71, 
    5, 90, 8, 64, 3, 45, 0, 42, 1, 82, 7, 88, 6, 12, 2, 94, 4, 24, 
    7, 65, 0, 16, 6, 72, 2, 36, 8, 44, 1, 73, 5, 46, 3, 51, 4, 96, 
    8, 51, 5, 67, 4, 13, 1, 64, 2, 82, 0,  4, 7,  6, 3, 41, 6, 39, 
    7, 16, 0, 70, 2, 12, 1, 10, 3, 77, 5, 22, 4,  7, 8, 33, 6, 27, 
    7,  6, 1, 44, 4, 76, 2, 90, 0, 27, 8, 49, 3, 61, 6, 16, 5, 30, 
    3, 87, 5,  7, 0, 64, 8, 54, 6, 89, 1, 90, 4, 51, 7, 46, 2, 59, 
    5, 19, 3,  4, 4, 81, 2, 82, 6, 40, 1, 34, 0, 18, 7, 80, 8, 35, 
    4, 40, 5, 95, 2, 74, 1, 63, 0, 88, 3, 41, 7, 53, 8, 34, 6, 75
  };
  const int q7546[] = {
    9, 9, // Number of jobs and machines
    7, 69, 6, 27, 0, 10, 1, 37, 4, 63, 3, 65, 5, 21, 8, 94, 2, 93, 
    1, 26, 0, 16, 8, 79, 7, 19, 3, 68, 2, 98, 5, 72, 4, 43, 6, 43, 
    1, 67, 2, 83, 6, 64, 7,  9, 0, 61, 4, 33, 8, 17, 3, 36, 5, 31, 
    6, 55, 0, 10, 5, 21, 1, 34, 2, 17, 7, 67, 3, 44, 8, 15, 4, 84, 
    7, 74, 6, 10, 1, 19, 5,  3, 0, 79, 4, 69, 2, 67, 3, 61, 8, 24, 
    6, 40, 4,  8, 7, 20, 3, 81, 1, 46, 0, 27, 5, 54, 8, 41, 2, 61, 
    0, 47, 4, 48, 5, 70, 7, 62, 6, 96, 2, 75, 1, 99, 8, 98, 3, 29, 
    8, 58, 4, 94, 7, 47, 6, 50, 3, 63, 2, 47, 5, 65, 0,  3, 1, 53, 
    7, 62, 1, 48, 0, 79, 3, 36, 4, 97, 2, 21, 6, 20, 5, 33, 8, 81
  };
  const int q7547[] = {
    9, 9, // Number of jobs and machines
    3, 62, 6, 83, 5, 91, 7, 38, 4, 50, 1, 72, 8, 91, 0, 68, 2, 77, 
    4, 65, 2,  7, 0, 20, 5, 57, 6, 22, 3,  4, 7, 90, 8, 13, 1, 76, 
    0,  3, 4, 24, 3, 37, 1, 90, 5, 81, 6, 78, 2, 98, 7, 93, 8, 93, 
    2, 20, 1, 91, 8, 37, 6, 38, 4, 86, 0, 49, 3, 53, 7, 99, 5, 21, 
    8,  6, 7, 13, 1, 84, 3, 71, 4, 44, 0, 86, 6, 51, 2, 20, 5, 49, 
    4, 15, 2, 58, 6, 56, 7, 97, 0, 87, 3, 40, 5, 53, 8, 95, 1, 99, 
    1, 42, 0, 62, 2,  1, 6, 94, 3, 12, 4, 45, 5, 92, 7, 98, 8, 71, 
    4, 26, 0, 35, 5, 83, 7, 85, 1, 88, 8,  6, 6, 53, 2, 27, 3, 33, 
    5, 50, 8, 83, 4, 82, 2, 63, 6,  4, 0, 58, 1,  7, 7, 21, 3, 37
  };
  const int q7548[] = {
    9, 9, // Number of jobs and machines
    1, 50, 7, 58, 3, 61, 5, 61, 4, 71, 8, 61, 6, 56, 2, 31, 0, 72, 
    8, 20, 2, 41, 7, 82, 1,  6, 6, 53, 0, 12, 3, 14, 5, 58, 4,  8, 
    4, 61, 1, 59, 5, 51, 8, 90, 2, 91, 0,  4, 6, 32, 7, 91, 3,  8, 
    1, 23, 4,  1, 2, 19, 8, 38, 5, 79, 6, 47, 0, 95, 3,  6, 7, 16, 
    7, 79, 0, 34, 8, 98, 6, 34, 3, 39, 2, 55, 5, 82, 4, 66, 1, 58, 
    7, 79, 4, 31, 8, 95, 5, 46, 6, 95, 0, 44, 3, 80, 2, 63, 1, 58, 
    5, 95, 8, 29, 6,  1, 1, 19, 7, 24, 0, 69, 3, 72, 2, 58, 4, 74, 
    5, 80, 7, 54, 6, 45, 0, 97, 2, 92, 3, 38, 1, 44, 4, 19, 8, 92, 
    1, 34, 4, 26, 6, 71, 2, 20, 5, 56, 8,  9, 3,  6, 7,  3, 0, 37
  };
  const int q7549[] = {
    9, 9, // Number of jobs and machines
    0, 89, 8, 87, 1, 16, 2, 52, 4, 28, 3, 10, 6, 78, 5, 69, 7, 39, 
    5, 56, 8, 17, 6,  8, 2, 32, 7, 71, 4, 20, 1,  5, 0, 72, 3, 46, 
    6,  5, 4, 95, 1, 37, 0, 86, 8, 60, 2, 86, 5, 14, 7, 75, 3, 48, 
    8, 79, 3, 10, 2, 89, 1, 31, 7, 62, 5, 31, 0, 10, 4,  6, 6, 36, 
    3, 48, 4, 41, 5, 94, 6, 34, 7, 82, 0, 25, 2, 67, 1, 16, 8, 78, 
    0, 65, 4, 69, 2, 59, 7, 88, 5, 51, 6, 59, 1, 43, 8, 38, 3, 85, 
    0, 48, 4, 96, 1, 16, 5, 19, 3, 98, 2, 55, 8, 11, 7, 85, 6,  9, 
    6, 47, 5, 80, 0, 89, 7, 57, 8,  2, 4, 55, 1, 22, 3, 77, 2, 96, 
    3,  2, 5, 68, 6, 65, 7, 26, 1, 50, 4, 71, 8, 84, 0, 44, 2, 65
  };
  const int q7550[] = {
    9, 9, // Number of jobs and machines
    4, 48, 0, 28, 8, 97, 5, 53, 6, 70, 2, 77, 1,  1, 7, 38, 3, 46, 
    1, 99, 5, 69, 6, 14, 4, 24, 3,  1, 2, 50, 8, 49, 0, 57, 7, 66, 
    4, 78, 1, 25, 5, 90, 3, 71, 0, 30, 8, 77, 2, 91, 6, 40, 7,  8, 
    6, 31, 7, 11, 1, 51, 5, 36, 2, 78, 0, 93, 4, 11, 3, 50, 8, 49, 
    0, 60, 2, 70, 1,  3, 6, 58, 4, 84, 3, 22, 8, 54, 5, 33, 7, 56, 
    3, 38, 2, 56, 4, 15, 7, 47, 6, 57, 5, 40, 0, 79, 8, 42, 1, 97, 
    6, 42, 5, 91, 2, 50, 7, 65, 4, 98, 3, 88, 0, 67, 8, 10, 1, 78, 
    2, 77, 0, 47, 3, 88, 7, 27, 1,  2, 8,  1, 4, 44, 5, 52, 6, 20, 
    3, 45, 2, 59, 0, 57, 1, 26, 5, 21, 6, 27, 8, 41, 4, 33, 7,  1
  };
  const int q7551[] = {
    9, 9, // Number of jobs and machines
    3, 85, 0, 18, 2, 44, 8, 11, 4, 33, 1,  3, 6, 76, 7, 87, 5, 17, 
    4, 81, 3, 84, 2, 79, 7, 51, 1, 89, 0, 37, 5, 39, 6, 98, 8, 88, 
    2, 16, 5, 95, 0, 54, 8, 16, 4, 39, 1, 66, 6, 18, 3, 37, 7, 85, 
    3, 64, 0, 12, 8,  4, 2, 61, 5, 42, 1, 21, 7, 87, 4, 50, 6, 28, 
    7, 20, 2, 55, 3, 34, 6, 57, 4, 20, 1, 86, 5, 73, 0,  8, 8, 65, 
    0, 88, 6, 14, 4, 95, 3, 22, 2, 17, 8, 21, 5, 69, 7, 83, 1, 38, 
    8, 53, 3, 99, 6, 78, 1, 33, 2, 30, 7, 82, 4, 57, 5, 40, 0, 75, 
    0, 40, 6, 32, 4, 54, 5, 58, 8, 34, 1, 90, 3, 57, 7, 46, 2, 91, 
    7, 30, 8, 98, 6, 35, 4, 23, 3, 12, 0, 71, 1, 10, 2, 62, 5, 25
  };
  const int q7552[] = {
    9, 9, // Number of jobs and machines
    1, 98, 2,  2, 0, 31, 8, 76, 3, 82, 5, 64, 6, 14, 7, 28, 4, 10, 
    3, 37, 4, 55, 6, 53, 7, 43, 8, 97, 0, 70, 2, 33, 1, 53, 5,  1, 
    7, 27, 8, 39, 6, 50, 4, 37, 1, 54, 0, 73, 3, 69, 5, 65, 2, 83, 
    3, 42, 0, 54, 2, 67, 1,  9, 6, 33, 7, 54, 5, 86, 8, 89, 4, 35, 
    7, 86, 4, 72, 1, 13, 3, 13, 6, 28, 8,  8, 5, 18, 2, 10, 0, 73, 
    2, 66, 4, 29, 5, 14, 8, 25, 7, 93, 6, 88, 3, 19, 1, 75, 0, 44, 
    5, 10, 0, 16, 1, 90, 8, 76, 2, 52, 7, 13, 4, 64, 3, 56, 6, 66, 
    0, 74, 8, 76, 4, 75, 2, 49, 1, 72, 5,  4, 3, 23, 7, 95, 6, 63, 
    8, 98, 1, 56, 7, 93, 6, 10, 2, 52, 5,  8, 0, 72, 4, 16, 3, 62
  };
  const int q7553[] = {
    9, 9, // Number of jobs and machines
    7, 70, 3, 49, 6,  8, 2,  6, 8, 58, 1, 78, 0, 46, 5, 12, 4, 90, 
    3, 61, 6, 81, 5, 69, 1, 44, 0, 67, 2, 65, 4, 45, 8, 13, 7,  1, 
    0, 78, 7, 38, 4, 78, 5, 35, 2,  3, 3, 47, 6,  8, 1, 44, 8, 73, 
    7, 27, 5, 67, 3, 96, 1, 83, 2, 52, 0, 63, 4, 29, 8,  4, 6, 39, 
    5, 15, 8, 84, 0, 24, 4, 93, 7, 68, 2, 25, 1, 57, 3, 61, 6, 73, 
    1, 48, 8,  9, 5, 10, 7, 81, 0, 92, 6, 27, 3, 68, 4, 45, 2, 50, 
    4, 95, 8, 39, 2, 15, 1, 52, 0, 29, 3, 37, 5, 64, 7, 39, 6, 44, 
    5, 24, 0, 60, 1, 89, 8, 64, 3, 53, 6, 87, 4, 93, 7, 13, 2, 67, 
    2, 44, 7, 82, 1, 77, 5, 90, 8, 21, 6, 59, 3,  7, 0, 67, 4, 51
  };
  const int q7554[] = {
    9, 9, // Number of jobs and machines
    5, 74, 2, 33, 4, 33, 3, 42, 1, 35, 8,  3, 6, 13, 0, 86, 7, 69, 
    8, 39, 6, 45, 7, 16, 0, 98, 3, 42, 4, 67, 5, 94, 2, 47, 1, 78, 
    3, 97, 4, 72, 0, 56, 1, 56, 6, 77, 5, 28, 2, 34, 8, 37, 7, 87, 
    6, 15, 7, 16, 5, 95, 3, 81, 0, 89, 2,  1, 4, 62, 1, 15, 8, 70, 
    3, 18, 4, 98, 1, 95, 5, 75, 7,  9, 6, 24, 2, 72, 8, 43, 0, 70, 
    1, 30, 4, 50, 8, 82, 5, 96, 0, 49, 3, 39, 2, 80, 6, 95, 7, 39, 
    5, 42, 1, 82, 2, 14, 4, 46, 3, 26, 7, 38, 0, 15, 8, 12, 6, 30, 
    6, 20, 2, 15, 4, 89, 1, 38, 5, 28, 8,  4, 7, 79, 0, 27, 3, 62, 
    2, 38, 3, 53, 0, 10, 6, 40, 5, 10, 1, 17, 7, 33, 4, 35, 8, 77
  };
  const int q7555[] = {
    9, 9, // Number of jobs and machines
    1, 43, 8, 27, 7, 39, 5, 91, 4, 48, 0, 84, 6, 38, 3, 83, 2, 28, 
    5, 43, 8, 79, 0,  4, 1, 98, 4, 94, 7, 41, 3, 14, 6,  4, 2, 35, 
    0,  7, 2, 39, 8, 30, 4, 58, 6, 25, 1, 58, 7, 88, 5, 99, 3, 60, 
    5, 44, 6, 78, 4, 25, 8, 63, 3, 21, 0,  8, 7, 26, 1, 68, 2, 20, 
    3, 93, 7, 82, 1, 45, 6, 63, 2, 79, 8, 75, 4, 35, 5, 19, 0, 23, 
    8, 81, 5,  3, 7, 69, 4, 50, 6, 27, 3, 72, 0,  1, 1, 61, 2, 25, 
    5, 21, 2,  9, 6, 93, 8, 87, 7,  3, 4, 16, 0, 97, 3,  2, 1, 60, 
    8, 97, 6, 21, 5, 72, 4, 13, 2, 56, 1, 93, 0, 60, 3, 68, 7, 87, 
    0, 62, 3, 99, 8,  7, 5, 31, 1, 55, 4, 73, 6, 43, 7, 32, 2, 35
  };
  const int q7556[] = {
    9, 9, // Number of jobs and machines
    6, 85, 0, 58, 4, 67, 5, 55, 1, 87, 7, 13, 3, 45, 2, 61, 8, 62, 
    8, 13, 2, 86, 5, 19, 4, 84, 7, 91, 1, 11, 3, 79, 6, 94, 0, 89, 
    2,  4, 0, 23, 4, 65, 7, 41, 3, 36, 6, 42, 5, 64, 8, 64, 1, 78, 
    2, 16, 8, 27, 1,  3, 3, 87, 4, 38, 6, 20, 7, 84, 5, 28, 0, 78, 
    1, 86, 0, 42, 8, 83, 2, 25, 3, 45, 4, 95, 5, 98, 6,  7, 7, 28, 
    1, 59, 7, 32, 0, 20, 6, 29, 8, 89, 4, 94, 2, 41, 3, 55, 5, 68, 
    7, 18, 8, 14, 1, 60, 5, 47, 6, 80, 0, 20, 4, 69, 2, 21, 3, 24, 
    6, 83, 1, 99, 2, 95, 0, 84, 5, 68, 3,  6, 7, 55, 4, 94, 8, 21, 
    3, 12, 4, 35, 5, 86, 2,  7, 6, 55, 1, 24, 8, 54, 0, 95, 7, 45
  };
  const int q7557[] = {
    9, 9, // Number of jobs and machines
    3, 98, 8, 80, 1, 80, 5, 24, 2, 64, 4, 12, 0, 18, 6, 87, 7,  4, 
    0, 86, 2, 69, 7, 22, 6, 62, 4, 49, 1,  9, 3, 54, 8, 79, 5, 77, 
    1, 25, 6,  5, 2,  4, 0, 31, 3,  6, 5, 82, 4, 15, 7,  4, 8,  4, 
    7, 96, 5, 27, 0,  4, 4, 73, 2, 44, 1, 15, 8, 77, 3, 49, 6, 96, 
    2,  3, 6, 19, 1, 62, 8, 70, 0, 67, 3, 16, 5, 59, 4, 30, 7, 52, 
    4, 26, 2, 95, 7, 90, 1, 45, 0, 81, 5, 34, 3, 79, 8, 32, 6, 22, 
    6, 96, 8, 21, 2, 76, 4, 16, 7, 98, 1, 90, 3, 66, 5, 45, 0, 58, 
    5, 22, 7,  1, 4, 52, 8, 14, 1, 11, 6, 78, 2, 20, 0, 93, 3, 44, 
    4,  2, 1,  8, 0, 59, 5, 67, 6, 16, 8,  8, 7, 17, 3, 68, 2,  9
  };
  const int q7558[] = {
    9, 9, // Number of jobs and machines
    7, 41, 2,  7, 0,  4, 5, 13, 1, 54, 3, 33, 4, 86, 8, 30, 6, 39, 
    1, 97, 4, 12, 7, 20, 2, 21, 6, 13, 8, 44, 3, 65, 5, 32, 0, 27, 
    3, 52, 6, 55, 7,  6, 8, 12, 0, 41, 4, 36, 2, 99, 1, 43, 5,  7, 
    3, 41, 1, 43, 5, 17, 2, 47, 6, 77, 7, 75, 4, 90, 8,  8, 0, 35, 
    6, 55, 0, 81, 3, 70, 8, 17, 5, 20, 4, 45, 2, 77, 7, 63, 1,  1, 
    8, 41, 4, 49, 3, 62, 5, 92, 2, 54, 6, 43, 1, 69, 0, 17, 7, 16, 
    5, 22, 3, 61, 7, 51, 2, 17, 0, 74, 8, 35, 1, 91, 6, 61, 4, 16, 
    3, 15, 0, 26, 2, 17, 8, 21, 4, 46, 5,  9, 7, 59, 6, 38, 1, 17, 
    7, 66, 3, 34, 4,  3, 1, 95, 8, 76, 5, 66, 2, 77, 6, 88, 0, 98
  };
  const int q7559[] = {
    9, 9, // Number of jobs and machines
    3, 76, 0, 92, 8, 62, 7, 28, 5, 87, 1, 97, 4, 25, 2, 60, 6, 72, 
    2, 31, 0, 63, 4, 94, 8, 59, 5, 40, 3, 95, 1,  8, 6, 87, 7, 27, 
    0, 13, 1, 99, 8, 70, 2, 81, 4, 89, 3, 17, 5, 11, 6, 44, 7, 89, 
    3, 20, 7, 32, 4, 49, 5, 20, 0, 56, 2, 81, 6, 63, 8, 82, 1, 54, 
    6,  3, 3, 96, 8, 46, 1, 23, 4,  5, 0,  9, 2, 83, 7, 73, 5, 95, 
    3, 17, 2, 88, 7, 52, 0,  8, 1, 38, 8, 90, 4, 89, 6, 67, 5, 15, 
    2, 65, 3, 55, 8, 23, 6, 78, 4, 19, 1, 15, 5, 67, 0, 57, 7, 49, 
    8, 10, 6, 46, 1, 26, 5, 82, 3, 30, 7, 65, 2, 29, 0, 45, 4, 46, 
    8, 54, 3, 21, 2, 80, 7, 77, 0,  9, 6, 81, 5, 20, 1, 11, 4, 19
  };
  const int q7560[] = {
    9, 9, // Number of jobs and machines
    1, 33, 0, 11, 4, 12, 7, 65, 6, 79, 3, 30, 2, 39, 8,  7, 5, 66, 
    8, 34, 6, 92, 4, 24, 2, 60, 1, 63, 7, 19, 0, 52, 3, 90, 5, 34, 
    0, 22, 4, 46, 5, 87, 1, 70, 6, 25, 8, 72, 7, 55, 2, 30, 3, 20, 
    6, 41, 1, 77, 2, 87, 8, 13, 4, 43, 5, 94, 3, 79, 0, 90, 7, 82, 
    3, 62, 8, 95, 2, 75, 0, 35, 4, 85, 7, 75, 5, 42, 6, 58, 1, 23, 
    4, 16, 3, 85, 1, 93, 6, 42, 8, 93, 2, 33, 7, 73, 0,  2, 5, 72, 
    5, 33, 7, 88, 0, 28, 8, 16, 2, 21, 1, 39, 3, 63, 6, 19, 4, 82, 
    1, 45, 2, 62, 4, 90, 5, 79, 6, 64, 7, 16, 8, 25, 0, 51, 3, 88, 
    2, 34, 4, 14, 8, 41, 5, 26, 7, 44, 1,  5, 0,  2, 3, 59, 6, 82
  };
  const int q7561[] = {
    9, 9, // Number of jobs and machines
    2, 52, 8, 49, 1, 10, 7, 78, 3, 61, 6, 47, 4, 70, 0, 48, 5,  2, 
    5, 74, 4, 17, 1, 63, 2, 54, 0, 71, 8, 76, 6, 19, 3, 54, 7, 19, 
    0, 44, 4, 92, 1, 33, 2, 56, 8, 29, 6, 88, 3, 48, 5,  8, 7, 80, 
    3, 40, 2,  5, 4, 15, 5, 52, 1, 31, 7, 71, 8, 33, 0, 31, 6, 84, 
    3, 56, 1, 21, 8, 82, 6, 84, 0, 23, 7, 73, 4, 53, 2, 32, 5, 73, 
    8, 46, 1, 92, 7, 21, 0, 92, 5, 36, 6, 61, 3, 63, 2, 17, 4, 73, 
    7, 57, 5, 75, 6, 74, 3, 10, 4, 45, 1, 73, 2, 75, 0,  4, 8, 49, 
    0, 72, 7, 14, 6, 59, 4,  1, 8, 37, 5, 39, 3, 44, 1, 60, 2, 74, 
    0,  8, 7, 12, 1, 99, 8, 30, 6, 58, 3, 79, 5, 41, 2, 14, 4, 55
  };
  const int q7562[] = {
    9, 9, // Number of jobs and machines
    1,  8, 2, 93, 3, 15, 0, 24, 8, 79, 7, 24, 4, 92, 5, 57, 6,  2, 
    2, 49, 6, 72, 7, 64, 3, 21, 0, 49, 8, 62, 4, 54, 5, 68, 1, 92, 
    7, 90, 6, 87, 0, 51, 4, 71, 2, 30, 3, 69, 1, 49, 5, 31, 8,  1, 
    3, 19, 1, 40, 2, 48, 0, 27, 5, 98, 4, 73, 7, 36, 8, 39, 6, 80, 
    6, 12, 1, 88, 5, 68, 2, 90, 0, 10, 8, 84, 3, 30, 7, 41, 4, 53, 
    8,  2, 0,  4, 1, 89, 5, 75, 3, 13, 2, 88, 4, 56, 6, 68, 7,  7, 
    6, 88, 4, 14, 3, 13, 7, 47, 2, 56, 5, 78, 1, 57, 8, 90, 0, 93, 
    5, 57, 1, 30, 6, 70, 7, 20, 4, 10, 3, 96, 0, 54, 2, 62, 8, 67, 
    2, 70, 6, 72, 4, 20, 8, 45, 0, 41, 1, 41, 3, 46, 7, 34, 5,  5
  };
  const int q7563[] = {
    9, 9, // Number of jobs and machines
    0, 24, 3, 91, 5,  6, 1, 83, 8, 61, 4, 41, 2, 23, 7, 14, 6, 53, 
    5, 87, 8, 49, 3, 36, 1, 12, 0, 33, 4, 26, 7, 33, 2, 63, 6, 68, 
    0, 97, 7, 15, 2,  2, 8,  5, 5, 41, 4, 26, 6, 33, 1, 32, 3, 10, 
    6, 34, 0, 33, 7, 98, 8, 67, 3, 56, 4,  7, 1, 86, 2, 87, 5, 11, 
    1, 28, 2, 38, 8, 25, 3,  7, 5, 97, 6, 70, 4, 11, 0, 87, 7, 13, 
    8, 17, 0, 60, 7, 10, 2, 27, 5, 92, 1, 67, 4, 96, 6, 45, 3, 30, 
    1, 94, 2, 34, 3, 20, 0,  3, 5, 47, 7, 28, 4, 99, 6,  2, 8, 39, 
    5, 30, 1, 36, 8, 71, 2, 42, 3, 18, 4, 64, 0, 45, 6, 14, 7, 19, 
    5, 81, 8, 68, 7, 40, 4, 36, 3, 95, 0, 58, 2, 63, 6, 85, 1, 23
  };
  const int q7564[] = {
    9, 9, // Number of jobs and machines
    5, 11, 3, 67, 7, 98, 0, 42, 2, 11, 1, 97, 6,  2, 8, 90, 4, 80, 
    1, 52, 8, 70, 6, 93, 5, 86, 7, 13, 2, 11, 3, 33, 0, 61, 4, 75, 
    2, 48, 3, 30, 8, 91, 6, 71, 0, 33, 1, 79, 5, 90, 4,  6, 7, 26, 
    4, 32, 2, 65, 0, 82, 3, 17, 5,  4, 6, 46, 1, 67, 8, 25, 7, 34, 
    7,  5, 4,  8, 0, 17, 5, 18, 2, 91, 8, 30, 6, 50, 3, 51, 1, 58, 
    8, 55, 0, 91, 6, 36, 5, 80, 1, 43, 7, 58, 4,  1, 3,  6, 2, 71, 
    7, 66, 0, 25, 1, 12, 8, 17, 5, 36, 3, 27, 2, 88, 6, 68, 4, 74, 
    0,  9, 6, 50, 2, 42, 4, 59, 3, 91, 7,  2, 5, 32, 8, 60, 1, 71, 
    3, 68, 5, 55, 4, 43, 7, 87, 0, 51, 1, 97, 2, 43, 8, 40, 6, 59
  };
  const int q7565[] = {
    9, 9, // Number of jobs and machines
    7, 47, 3, 56, 8, 33, 2, 21, 4, 40, 6, 72, 1, 43, 5,  1, 0, 74, 
    2, 94, 3, 97, 0, 82, 4, 79, 5, 43, 8,  8, 1, 65, 6, 54, 7,  7, 
    8, 12, 7, 65, 4, 23, 3, 50, 6, 94, 5, 30, 2, 93, 1, 32, 0, 69, 
    0, 53, 6, 88, 2, 16, 1, 15, 7, 49, 3, 26, 8, 43, 4, 26, 5, 87, 
    8, 50, 7, 95, 3, 84, 2, 55, 1, 41, 6,  3, 5, 47, 4, 78, 0, 58, 
    1, 44, 8, 27, 0, 77, 3, 44, 7, 63, 2, 56, 5, 36, 6, 31, 4, 29, 
    0, 80, 3, 99, 6, 92, 5, 91, 1, 39, 8, 91, 2, 30, 4, 17, 7,  6, 
    1, 95, 2, 61, 5, 90, 3, 11, 8, 30, 4, 40, 0, 76, 6, 26, 7, 18, 
    6, 23, 2, 55, 7, 67, 0, 73, 8, 54, 4, 10, 3, 69, 5, 80, 1,  6
  };
  const int q7566[] = {
    9, 9, // Number of jobs and machines
    8, 23, 5, 70, 4, 12, 7, 69, 1, 14, 0, 44, 3, 15, 2,  5, 6, 22, 
    2, 35, 8, 26, 5, 61, 6,  6, 1, 12, 0, 63, 7, 40, 4, 96, 3, 95, 
    5, 50, 6, 16, 2,  9, 3, 46, 4, 59, 7, 89, 0, 15, 8, 25, 1, 35, 
    2, 65, 3, 94, 8, 71, 1, 99, 0, 87, 5, 95, 7, 46, 6, 88, 4,  4, 
    0, 77, 2, 42, 6, 98, 7, 89, 4, 11, 1, 15, 8, 48, 5, 33, 3, 61, 
    2, 46, 4, 98, 3, 16, 1, 83, 8,  6, 5, 64, 7, 75, 0, 95, 6, 70, 
    2, 81, 3, 65, 6, 37, 4, 85, 5, 13, 1, 32, 0, 33, 8, 92, 7, 49, 
    6, 77, 0, 25, 7, 79, 5, 55, 3, 62, 2, 53, 4, 26, 1, 37, 8, 72, 
    3, 41, 6, 18, 2,  9, 7, 42, 5, 37, 1,  2, 0, 31, 4, 22, 8, 15
  };
  const int q7567[] = {
    9, 9, // Number of jobs and machines
    4, 40, 1, 19, 8, 60, 6, 93, 3, 79, 7,  7, 0, 19, 2, 94, 5, 71, 
    8, 76, 6, 53, 0, 16, 5, 81, 1, 96, 3, 40, 2, 99, 4, 26, 7, 26, 
    3, 23, 1, 51, 4, 67, 0, 43, 7, 13, 5, 92, 2, 22, 8,  1, 6, 89, 
    5, 15, 1, 64, 6, 54, 4, 86, 0, 22, 3, 45, 2, 85, 8, 10, 7, 86, 
    7, 50, 8, 87, 5, 89, 1, 29, 4, 89, 6, 36, 3, 94, 2, 23, 0, 24, 
    2,  5, 5, 21, 3, 67, 1,  9, 4, 52, 8, 48, 0, 12, 7, 86, 6, 75, 
    5, 32, 1, 99, 8, 36, 3, 42, 4, 97, 7, 94, 2, 55, 6,  8, 0, 78, 
    2, 62, 3, 38, 8,  8, 5, 61, 7, 12, 4, 67, 1, 84, 0, 53, 6,  5, 
    6, 29, 2, 74, 0, 33, 7, 62, 3, 39, 5, 52, 4, 49, 8, 58, 1, 47
  };
  const int q7568[] = {
    9, 9, // Number of jobs and machines
    5, 23, 0, 54, 1, 66, 4, 93, 6, 72, 3, 42, 7, 41, 8, 13, 2,  3, 
    8,  7, 2, 50, 4, 15, 1, 57, 5, 15, 0, 95, 3,  2, 7, 30, 6,  6, 
    4, 21, 5,  6, 3, 89, 6, 49, 8, 99, 7, 81, 0, 10, 1, 95, 2,  1, 
    4, 50, 5, 13, 2, 49, 0, 37, 3, 43, 1, 40, 7, 67, 8, 41, 6, 90, 
    7, 43, 0, 74, 6, 43, 5, 20, 4, 65, 2, 87, 3, 44, 8,  9, 1, 33, 
    4, 49, 7, 29, 8, 17, 6,  9, 0, 92, 3, 84, 5, 84, 2, 59, 1, 92, 
    7, 96, 8,  9, 3, 75, 1, 21, 5, 21, 0, 99, 4,  6, 6, 70, 2, 41, 
    5, 71, 2, 35, 7, 82, 0, 58, 6, 51, 3, 42, 4, 40, 1, 84, 8, 31, 
    2,  2, 4, 76, 1, 56, 8, 26, 3, 45, 5, 94, 7, 51, 0, 51, 6, 36
  };
  const int q7569[] = {
    9, 9, // Number of jobs and machines
    2, 81, 7, 48, 1, 40, 3, 32, 4, 48, 0, 10, 5, 42, 6, 50, 8,  9, 
    7, 84, 2,  3, 1, 15, 8,  1, 3, 69, 6,  9, 0,  5, 5, 44, 4,  7, 
    5, 48, 2, 42, 0, 42, 8, 39, 7, 67, 6, 13, 3, 71, 4, 78, 1, 76, 
    3, 34, 6, 82, 4, 93, 2, 45, 8, 60, 7, 82, 1, 22, 0, 82, 5,  1, 
    6, 20, 7, 85, 1, 55, 2, 71, 3, 77, 8, 57, 5, 41, 4,  9, 0, 94, 
    5,  8, 4, 51, 2, 25, 1, 21, 8, 98, 0, 60, 7, 13, 3, 35, 6,  3, 
    4,  5, 8, 44, 5, 70, 3, 45, 2, 61, 1, 77, 0, 51, 6,  8, 7, 53, 
    2, 11, 7, 20, 6, 23, 4, 54, 1, 56, 8, 71, 3, 67, 5, 35, 0, 21, 
    2, 42, 5, 66, 0, 25, 8, 77, 3, 25, 1, 66, 6, 53, 7, 67, 4, 61
  };
  const int q7570[] = {
    9, 9, // Number of jobs and machines
    7, 91, 3, 73, 0, 99, 5, 28, 2,  7, 8,  5, 1, 33, 6, 25, 4, 22, 
    4, 82, 6, 25, 2, 24, 0, 10, 1, 41, 3, 63, 7, 27, 5, 33, 8, 77, 
    6, 89, 2, 42, 1, 71, 0, 86, 5, 90, 4, 86, 3, 61, 8, 49, 7, 68, 
    8, 60, 2, 75, 7, 66, 5, 84, 4, 33, 1, 95, 6,  8, 3, 19, 0,  6, 
    6,  8, 8,  8, 0, 45, 3, 13, 2, 41, 5, 83, 7,  9, 1, 13, 4,  7, 
    0, 20, 5, 37, 6, 64, 3, 40, 1, 14, 4, 30, 7, 56, 8, 21, 2, 77, 
    2, 85, 7,  5, 3, 85, 5, 40, 4, 59, 6, 68, 1, 84, 8, 86, 0, 31, 
    1, 49, 4, 84, 6, 99, 8, 16, 2, 43, 7, 61, 3, 98, 0, 72, 5,  3, 
    2, 90, 4, 30, 3, 55, 5, 16, 6, 37, 8, 21, 7, 31, 0, 61, 1, 68
  };
  const int q7571[] = {
    9, 9, // Number of jobs and machines
    8, 39, 6, 26, 5, 45, 1, 76, 2, 59, 4, 19, 7, 26, 0, 20, 3, 40, 
    3, 12, 8, 79, 1,  6, 0, 91, 4, 13, 6, 20, 5, 17, 2, 87, 7, 67, 
    3, 28, 8, 79, 4, 93, 2, 54, 7, 71, 0, 80, 5, 80, 6,  6, 1, 53, 
    5, 66, 7, 57, 3, 32, 1,  2, 6, 73, 8, 84, 4,  5, 2,  8, 0, 57, 
    6, 39, 0, 83, 1,  9, 2, 61, 5, 33, 7, 65, 3, 94, 4, 42, 8, 26, 
    2, 96, 0, 70, 8,  6, 1,  8, 4, 65, 3, 13, 7, 98, 6, 52, 5, 28, 
    4, 93, 3,  2, 7, 79, 6, 55, 1, 14, 5, 33, 0, 96, 8, 72, 2,  3, 
    4, 10, 5, 39, 2, 81, 0, 86, 6, 71, 3, 84, 8, 25, 1, 77, 7, 15, 
    6, 85, 7,  9, 1, 44, 2, 91, 8, 65, 0,  4, 5, 39, 3, 48, 4, 43
  };
  const int q7572[] = {
    9, 9, // Number of jobs and machines
    2, 47, 4, 15, 0, 51, 5, 91, 6, 73, 7, 23, 3, 90, 8, 51, 1, 54, 
    5, 72, 8, 14, 0, 62, 2, 71, 7, 34, 6, 66, 4, 30, 3,  1, 1, 66, 
    3,  6, 8, 49, 0, 54, 5,  5, 6, 45, 2, 29, 7, 85, 1, 34, 4, 88, 
    8, 24, 7, 82, 5, 59, 4,  2, 2, 84, 0, 23, 3, 86, 6,  4, 1, 97, 
    4, 41, 2, 30, 6, 65, 8, 13, 7, 24, 0, 47, 1, 34, 3, 29, 5,  2, 
    8, 90, 4, 16, 7, 51, 6, 90, 2, 31, 1, 79, 5, 14, 3, 63, 0, 91, 
    0, 25, 8, 19, 6, 28, 4, 95, 2,  1, 3, 65, 5, 24, 7, 97, 1, 66, 
    0,  9, 2,  1, 5, 85, 6, 67, 3, 16, 8,  9, 4, 25, 7, 36, 1,  2, 
    3, 44, 2, 95, 5, 42, 1, 55, 7, 33, 0, 41, 4, 46, 6, 57, 8, 97
  };
  const int q7573[] = {
    9, 9, // Number of jobs and machines
    8, 86, 4,  4, 3, 26, 2, 68, 7, 10, 0,  3, 1, 55, 6, 67, 5,  3, 
    8, 65, 3, 41, 4, 83, 1, 26, 0, 58, 5, 10, 6, 62, 2,  6, 7, 67, 
    8, 58, 2, 38, 7, 38, 5, 14, 3, 32, 6, 20, 1, 62, 4, 23, 0, 42, 
    5, 47, 7, 83, 0, 46, 2, 51, 1, 82, 8, 29, 6, 86, 4, 17, 3, 98, 
    5, 19, 8, 14, 7, 29, 2, 90, 3, 20, 0, 38, 4, 26, 6, 40, 1, 83, 
    8, 15, 6,  5, 3,  2, 5, 49, 1, 97, 4, 16, 7, 21, 2, 54, 0, 26, 
    1, 16, 7, 87, 5, 70, 4, 34, 2, 48, 8, 52, 3, 56, 6, 90, 0, 65, 
    0, 93, 1, 52, 3, 77, 2, 92, 8, 89, 6, 62, 7, 92, 5, 62, 4, 43, 
    2, 80, 0, 50, 3, 47, 5, 65, 1, 37, 8, 25, 4, 71, 6, 39, 7,  7
  };
  const int q7574[] = {
    9, 9, // Number of jobs and machines
    8, 38, 4, 95, 0, 47, 7, 16, 3, 16, 6, 16, 5, 24, 2, 21, 1, 46, 
    3, 95, 0, 35, 8, 74, 5, 35, 2, 36, 6,  6, 7, 48, 1, 25, 4, 41, 
    7, 91, 3, 41, 6, 80, 4, 33, 2, 29, 1, 68, 5, 41, 8, 75, 0, 79, 
    0, 72, 8, 49, 4, 19, 7, 10, 2, 77, 1, 42, 6, 85, 3, 54, 5, 77, 
    4, 55, 6, 92, 2, 27, 3, 43, 8,  1, 7, 52, 0, 58, 5, 34, 1, 26, 
    8, 53, 1, 82, 5, 14, 3, 17, 7, 99, 2, 66, 6, 52, 4, 73, 0, 11, 
    5, 37, 6, 15, 0, 48, 3, 59, 8, 77, 7, 78, 2, 26, 1, 13, 4, 48, 
    8, 83, 6, 41, 2, 62, 3, 60, 4, 13, 1, 24, 5, 25, 0,  1, 7, 70, 
    1, 25, 6, 94, 7, 63, 0, 17, 8, 88, 5, 22, 3, 18, 4, 80, 2, 55
  };
  const int q7575[] = {
    9, 9, // Number of jobs and machines
    6, 31, 0, 32, 4, 14, 2, 80, 5, 67, 7, 34, 1, 67, 3, 86, 8, 52, 
    7, 39, 0, 70, 3, 50, 1, 79, 5, 72, 8, 33, 2, 91, 4, 43, 6, 25, 
    5, 12, 0, 45, 6, 34, 2, 43, 7, 65, 4, 85, 8, 96, 1, 56, 3, 12, 
    4, 16, 1, 65, 6, 78, 2, 52, 5, 64, 7, 84, 0, 55, 3,  4, 8, 60, 
    5, 12, 4, 86, 3, 18, 2, 70, 6, 70, 0,  9, 8, 23, 7, 37, 1,  7, 
    3, 70, 4,  1, 0,  7, 1, 68, 2, 20, 6,  1, 5, 93, 8, 45, 7, 84, 
    3, 66, 2, 70, 1, 29, 7, 24, 6, 84, 5, 95, 8, 98, 4, 12, 0,  3, 
    3, 98, 7, 75, 6, 30, 2, 29, 4, 32, 5, 50, 1, 93, 8,  9, 0,  4, 
    6, 93, 4, 63, 8, 47, 3, 84, 5, 57, 2, 44, 1, 51, 0,  5, 7, 14
  };
  const int q7576[] = {
    9, 9, // Number of jobs and machines
    8, 89, 5, 16, 3, 23, 6, 24, 1, 23, 7,  6, 0, 49, 4, 87, 2, 23, 
    8, 55, 0, 11, 4, 65, 2, 87, 6, 23, 7, 50, 3, 78, 5, 71, 1, 93, 
    6, 51, 1, 65, 8, 60, 4, 79, 2, 20, 7, 24, 3, 35, 5, 97, 0, 42, 
    3, 56, 8, 58, 7, 93, 5, 87, 2, 30, 1, 77, 6, 73, 4, 21, 0, 78, 
    8, 71, 5, 45, 1, 34, 6, 36, 4, 10, 2,  6, 7, 91, 0, 64, 3, 77, 
    4, 22, 5, 65, 2, 84, 3, 93, 8, 57, 1, 85, 7, 69, 0,  9, 6, 35, 
    4, 90, 3, 17, 6, 10, 7, 28, 5, 23, 0, 35, 8, 34, 1,  1, 2, 33, 
    2, 65, 1, 27, 5, 67, 4, 20, 0, 17, 8, 38, 6, 62, 7, 68, 3, 89, 
    4, 90, 3, 37, 1, 38, 8, 83, 5, 43, 2,  8, 0, 65, 6, 37, 7,  5
  };
  const int q7577[] = {
    9, 9, // Number of jobs and machines
    7, 63, 3, 17, 1, 80, 8, 47, 4, 43, 2, 77, 0, 88, 5, 33, 6, 39, 
    2, 50, 4, 68, 7, 34, 3,  2, 0, 93, 5, 29, 8, 91, 6, 50, 1, 56, 
    2, 27, 7, 95, 4, 85, 6, 23, 8,  5, 1, 59, 0, 37, 5, 86, 3,  9, 
    2, 34, 6,  2, 0, 66, 5, 52, 3, 20, 4, 91, 1, 52, 8, 63, 7, 92, 
    1,  9, 6, 59, 8, 24, 5, 18, 0, 38, 2, 45, 4, 67, 7,  3, 3, 57, 
    3, 38, 8, 29, 7, 14, 2, 90, 4, 72, 6, 56, 0,  4, 1, 21, 5, 68, 
    6, 61, 7, 20, 0,  3, 1, 61, 4, 49, 8, 39, 5, 45, 2, 19, 3, 96, 
    6, 10, 3, 39, 5, 77, 2, 66, 7,  9, 4, 29, 1, 64, 8, 67, 0, 84, 
    4, 65, 6, 23, 7, 47, 1, 93, 2, 87, 5,  2, 0, 55, 3, 86, 8, 16
  };
  const int q7578[] = {
    9, 9, // Number of jobs and machines
    0, 67, 5, 43, 7, 44, 2, 99, 6, 69, 8, 49, 4, 51, 3, 20, 1, 30, 
    8, 60, 1, 46, 7, 63, 3, 77, 2, 10, 6, 59, 5, 14, 4,  6, 0, 66, 
    8, 77, 2, 44, 1, 34, 7, 59, 5, 67, 3, 81, 6, 77, 4, 59, 0, 28, 
    7, 88, 5, 33, 0, 54, 2, 43, 4,  9, 3, 77, 1, 31, 6, 67, 8, 26, 
    1, 26, 2, 86, 0, 17, 8, 88, 4, 91, 7, 10, 5, 92, 6,  8, 3, 74, 
    0, 61, 7, 27, 4, 29, 5, 92, 1, 76, 3, 20, 8, 85, 6, 44, 2, 61, 
    8, 97, 5, 23, 4,  1, 7, 23, 3, 83, 1, 35, 2, 55, 0, 23, 6, 83, 
    0, 56, 2, 81, 8, 60, 1, 64, 5, 26, 7, 12, 3, 73, 4, 41, 6,  9, 
    0, 69, 1, 63, 6, 84, 7,  8, 3, 35, 8, 78, 2, 74, 5, 61, 4, 11
  };
  const int q7579[] = {
    9, 9, // Number of jobs and machines
    8, 19, 3, 42, 2,  5, 7, 56, 6, 20, 5, 90, 1, 50, 4, 26, 0, 57, 
    5, 55, 3, 68, 4, 55, 6,  7, 8, 30, 7, 12, 1, 94, 2,  2, 0, 78, 
    5, 12, 8,  1, 6, 77, 0, 10, 7, 30, 4, 32, 2, 28, 3, 33, 1,  2, 
    1, 63, 8, 38, 3, 14, 5, 55, 4, 27, 7,  1, 2, 59, 6, 23, 0, 62, 
    2,  5, 3, 34, 1,  6, 0, 18, 5, 78, 8, 46, 4, 77, 7, 93, 6, 31, 
    6, 10, 7, 71, 2, 39, 3, 26, 5, 86, 4, 58, 1, 55, 0,  7, 8, 11, 
    0, 58, 3, 25, 7, 79, 5, 18, 6, 88, 4,  7, 2, 34, 8, 52, 1, 19, 
    7, 16, 2, 51, 1, 26, 6, 18, 3,  4, 0, 52, 4, 55, 8, 83, 5, 11, 
    4, 14, 2, 33, 8, 11, 0, 68, 3, 46, 6, 84, 5, 11, 7, 54, 1, 99
  };
  const int q7580[] = {
    9, 9, // Number of jobs and machines
    6, 76, 4, 47, 2, 32, 3, 36, 7, 93, 5, 59, 0, 78, 1, 10, 8, 83, 
    2, 85, 3, 62, 6,  9, 5, 61, 4,  8, 1,  7, 8, 91, 7, 94, 0, 12, 
    4, 67, 6, 44, 1, 91, 3, 56, 2, 41, 7, 61, 0, 33, 5, 11, 8, 57, 
    2, 28, 0, 59, 6, 12, 7, 75, 5,  7, 3, 97, 1, 20, 8, 26, 4, 33, 
    0,  9, 1, 20, 2, 79, 8, 25, 5, 81, 4, 37, 7, 84, 6, 52, 3, 71, 
    8, 17, 4, 78, 0, 92, 5, 28, 1, 48, 7, 27, 6,  8, 2, 41, 3, 64, 
    1, 16, 2, 45, 6, 10, 7, 77, 3, 58, 4, 81, 5, 34, 8, 76, 0, 95, 
    2, 52, 7, 24, 1, 48, 4, 60, 8, 51, 5,  1, 0, 75, 6, 35, 3, 36, 
    6, 44, 2, 50, 0, 56, 8, 17, 5, 48, 7, 73, 4, 63, 3, 79, 1, 65
  };
  const int q7581[] = {
    9, 9, // Number of jobs and machines
    4, 85, 0, 67, 8, 63, 1, 58, 5, 30, 2, 32, 6, 13, 3, 11, 7, 33, 
    8, 86, 5, 69, 1, 42, 7, 69, 4,  1, 6, 35, 0, 59, 2, 94, 3, 28, 
    8, 98, 0, 52, 3, 30, 2,  5, 5,  4, 7, 25, 1, 13, 4, 10, 6, 19, 
    3,  6, 1, 89, 0, 45, 5,  5, 4, 64, 7, 24, 6, 84, 2, 71, 8, 65, 
    4, 23, 0, 42, 8, 49, 3, 73, 5, 31, 7, 85, 2, 46, 6, 93, 1, 35, 
    0, 84, 6, 38, 8,  4, 3, 79, 7, 65, 1, 65, 2, 13, 4, 34, 5, 35, 
    5, 68, 7, 58, 4, 45, 8, 91, 1, 89, 6, 37, 0, 55, 3, 62, 2, 13, 
    8,  7, 7, 83, 2,  9, 4, 99, 5, 26, 1, 49, 0,  5, 6, 31, 3, 36, 
    6, 79, 8, 32, 5, 65, 1, 26, 7, 94, 3, 66, 4, 13, 2, 54, 0, 22
  };
  const int q7582[] = {
    9, 9, // Number of jobs and machines
    0, 11, 2, 24, 7, 81, 8, 86, 1, 85, 3, 43, 5, 93, 6, 72, 4, 55, 
    4,  2, 7, 26, 2, 56, 6, 84, 5, 23, 8, 75, 1, 91, 3, 57, 0,  4, 
    1, 27, 8, 17, 7, 32, 4, 51, 5, 30, 0, 30, 2, 26, 3, 65, 6,  1, 
    8, 18, 7, 59, 1, 81, 3, 26, 4, 99, 0,  8, 2, 20, 5, 29, 6,  2, 
    4,  6, 1, 65, 2, 47, 7, 34, 8, 14, 3, 44, 5, 81, 0,  2, 6, 36, 
    0, 18, 4, 15, 1, 90, 5, 27, 8, 59, 3, 59, 7, 27, 6, 44, 2, 94, 
    5, 28, 0, 21, 1, 12, 3, 95, 7, 58, 2, 19, 4, 52, 8, 71, 6, 73, 
    1, 51, 2, 74, 3, 52, 8,  7, 5, 28, 4, 93, 0, 27, 7, 37, 6, 81, 
    8, 93, 2, 71, 7, 49, 6, 36, 1, 71, 0, 25, 3,  3, 5, 30, 4,  2
  };
  const int q7583[] = {
    9, 9, // Number of jobs and machines
    6, 22, 7, 14, 0, 72, 2, 68, 4,  4, 8, 81, 3, 22, 5, 16, 1, 66, 
    8,  3, 4, 98, 3, 76, 0, 95, 7, 26, 5, 80, 2, 58, 1, 20, 6, 67, 
    4, 19, 8, 14, 6, 54, 3, 94, 0, 25, 7, 52, 2, 13, 1,  3, 5,  6, 
    2, 11, 5, 37, 3, 89, 1, 48, 6,  3, 7, 83, 4, 58, 0, 68, 8, 27, 
    0, 80, 5, 68, 1, 67, 8, 93, 2, 71, 7, 93, 6, 12, 3, 64, 4, 44, 
    3, 85, 2, 60, 8, 81, 0, 26, 5, 37, 7, 29, 1, 45, 4, 43, 6, 18, 
    0, 70, 2, 88, 5, 89, 3, 57, 8, 47, 1, 28, 7, 12, 4, 73, 6, 20, 
    4,  3, 6, 83, 3, 35, 1,  9, 2, 29, 0,  4, 8, 48, 7, 20, 5,  4, 
    1, 80, 5, 82, 2, 18, 7, 26, 4, 72, 3, 44, 8, 48, 6, 78, 0, 48
  };
  const int q7584[] = {
    9, 9, // Number of jobs and machines
    1, 93, 2,  1, 8,  5, 4, 13, 6, 40, 7, 97, 0, 10, 3, 66, 5, 68, 
    7, 16, 6, 93, 8, 93, 3, 66, 4, 35, 1, 46, 5, 92, 2, 84, 0, 30, 
    3, 45, 5, 66, 1, 42, 4, 60, 2, 81, 8, 66, 7, 15, 0, 88, 6, 72, 
    4,  2, 1, 88, 5, 65, 6, 26, 8, 94, 7, 50, 0, 81, 2, 70, 3,  7, 
    4, 63, 8, 66, 1, 27, 3, 26, 7, 64, 6, 37, 0, 86, 5, 26, 2, 60, 
    2, 47, 3, 66, 8, 82, 1, 56, 0, 79, 5, 24, 7, 72, 4, 64, 6, 55, 
    3, 47, 5, 91, 2, 14, 6, 27, 8, 97, 1, 83, 0, 53, 4,  4, 7, 52, 
    4, 96, 3, 95, 8, 70, 5, 52, 7, 58, 0, 39, 1, 35, 6, 74, 2, 40, 
    6, 74, 7, 63, 5,  3, 8, 39, 4, 50, 1, 74, 0, 80, 2,  4, 3, 70
  };
  const int q7585[] = {
    9, 9, // Number of jobs and machines
    3, 39, 7, 31, 5, 35, 2, 18, 1, 50, 0, 95, 8, 15, 4, 96, 6, 82, 
    3, 73, 2, 66, 5, 70, 6, 36, 7, 21, 8,  5, 0, 78, 4, 24, 1, 99, 
    8,  7, 6, 26, 5, 71, 4, 74, 7, 27, 1, 33, 2, 99, 3, 52, 0, 55, 
    8, 98, 4, 37, 1, 74, 0, 83, 6, 65, 5, 93, 2, 64, 3, 95, 7, 16, 
    0, 97, 4, 22, 7, 92, 1, 94, 3, 43, 2, 58, 8, 85, 5, 46, 6, 49, 
    5, 13, 2, 85, 8, 67, 6, 35, 4, 86, 0, 14, 3, 63, 1, 63, 7, 81, 
    2, 65, 4, 59, 8, 34, 3, 33, 6, 34, 5, 82, 7, 57, 0, 34, 1, 71, 
    2, 10, 6, 67, 1, 85, 4, 50, 0, 10, 8, 55, 3, 65, 7, 11, 5, 26, 
    1,  8, 3, 45, 6, 31, 4, 77, 0, 94, 8, 74, 2, 40, 7, 12, 5, 49
  };
  const int q7586[] = {
    9, 9, // Number of jobs and machines
    7, 33, 0, 73, 2,  5, 4, 90, 6, 75, 5, 81, 3,  6, 1, 63, 8, 67, 
    4, 83, 8, 53, 1, 95, 7, 63, 0, 91, 5,  1, 6, 90, 3, 34, 2,  1, 
    3, 80, 2, 39, 1, 33, 4, 51, 0, 27, 6, 16, 8, 93, 7, 14, 5, 88, 
    1,  4, 5,  8, 8, 38, 4,  1, 7, 94, 2, 44, 6, 54, 3, 51, 0, 62, 
    4, 92, 7, 80, 3, 95, 8, 89, 1, 72, 5, 56, 6, 27, 2, 98, 0, 56, 
    1, 72, 8, 56, 4, 65, 6, 55, 0, 39, 5, 20, 2, 48, 3,  2, 7, 75, 
    2, 13, 1, 23, 6, 36, 5, 19, 8, 84, 0, 61, 4, 23, 7, 91, 3, 53, 
    6, 23, 5, 90, 4, 76, 1,  1, 0, 59, 3, 40, 8, 83, 2, 95, 7, 72, 
    0, 62, 4, 81, 7, 55, 2, 88, 5, 36, 6, 27, 8, 50, 1, 39, 3, 66
  };
  const int q7587[] = {
    9, 9, // Number of jobs and machines
    2, 68, 0, 50, 6, 34, 1,  5, 4, 63, 7, 77, 5, 22, 3, 55, 8, 55, 
    8, 85, 0, 62, 7, 68, 1, 69, 2, 89, 3, 82, 5, 67, 6, 98, 4, 97, 
    1, 27, 2, 12, 6, 67, 3, 54, 4,  8, 7, 25, 0, 69, 8, 93, 5,  5, 
    2, 96, 4, 54, 1, 17, 8, 44, 5,  3, 6, 13, 7, 54, 3, 29, 0,  2, 
    4,  2, 7, 30, 0, 49, 1, 47, 6, 13, 8, 60, 3, 32, 2, 67, 5, 58, 
    2, 48, 8, 42, 3, 85, 1, 87, 7, 98, 5, 47, 6, 98, 0, 36, 4,  8, 
    3, 57, 6, 36, 1, 50, 8, 18, 2, 80, 7, 69, 0, 87, 4, 51, 5, 98, 
    3, 68, 4, 82, 6, 37, 8, 95, 0, 62, 1, 15, 5, 63, 7, 11, 2, 12, 
    8, 47, 2, 31, 4, 42, 7, 15, 0, 71, 3, 63, 5, 85, 1, 97, 6, 80
  };
  const int q7588[] = {
    9, 9, // Number of jobs and machines
    4, 68, 1, 44, 5, 15, 6, 58, 2, 78, 0, 68, 7, 20, 3, 85, 8, 21, 
    0, 24, 4, 32, 2, 47, 3, 64, 8, 64, 7, 53, 5,  9, 6, 46, 1, 43, 
    8, 90, 0, 45, 1, 87, 3, 52, 2, 75, 5,  8, 7, 62, 4, 78, 6, 90, 
    5, 27, 4, 48, 3, 63, 0, 57, 2, 19, 7, 51, 8, 77, 1, 71, 6, 81, 
    4, 97, 2, 95, 6, 93, 3, 63, 5, 77, 1, 29, 7, 34, 0, 23, 8, 37, 
    2, 34, 5, 40, 3, 92, 6, 96, 8, 62, 7, 31, 0, 38, 1, 21, 4, 75, 
    8, 39, 7, 90, 2, 24, 6, 43, 3, 84, 4, 52, 0, 57, 5, 56, 1,  6, 
    3,  1, 4, 52, 6, 70, 0,  5, 7, 42, 1, 77, 5, 31, 8, 58, 2,  9, 
    2, 64, 8, 17, 4, 27, 3, 35, 7, 72, 0, 18, 5, 64, 6, 27, 1,  1
  };
  const int q7589[] = {
    9, 9, // Number of jobs and machines
    1, 32, 0, 29, 4, 52, 8, 12, 7,  3, 3, 11, 5, 64, 6, 21, 2, 36, 
    5, 17, 0, 63, 7, 13, 4, 83, 6, 55, 1, 44, 2, 93, 3, 93, 8, 59, 
    4, 78, 5, 68, 8, 52, 0, 97, 2, 28, 3, 67, 1, 21, 7, 62, 6, 72, 
    3, 21, 0, 78, 1, 86, 2, 17, 6, 85, 7, 14, 8, 82, 4, 21, 5, 86, 
    5, 20, 7, 19, 8, 20, 2, 42, 3, 69, 4, 38, 1, 14, 6, 80, 0, 29, 
    4, 96, 0, 40, 5, 68, 3, 28, 6, 43, 2, 77, 7, 37, 1, 37, 8, 46, 
    8, 67, 3, 79, 5, 55, 7, 96, 2, 53, 0, 98, 1, 53, 4, 13, 6, 94, 
    1, 57, 3, 47, 8, 88, 5, 62, 6, 21, 2, 18, 0, 21, 7, 19, 4, 96, 
    4, 42, 7,  2, 0, 66, 6, 69, 1, 90, 3, 10, 5, 61, 2, 41, 8,  6
  };
  const int q7590[] = {
    9, 9, // Number of jobs and machines
    2, 71, 6,  2, 7, 32, 0, 60, 8, 71, 3, 85, 4, 44, 1, 67, 5, 35, 
    8, 63, 2, 70, 0, 50, 3, 98, 1, 28, 4, 80, 7, 44, 6, 36, 5, 56, 
    5, 39, 6, 76, 8, 88, 1, 69, 4, 83, 3,  1, 7, 63, 0, 68, 2, 90, 
    3,  4, 4, 31, 7, 23, 5, 92, 2,  4, 1, 16, 8, 42, 6, 11, 0, 26, 
    1,  4, 0, 21, 6, 39, 4, 40, 8, 61, 2, 97, 5, 79, 7, 86, 3, 40, 
    3, 25, 5, 55, 0,  9, 2, 93, 7, 62, 1, 15, 6, 68, 4, 26, 8, 30, 
    3, 51, 1, 85, 2, 62, 6, 24, 5, 78, 0, 76, 7, 24, 8, 14, 4,  5, 
    3,  1, 1, 61, 6, 71, 2, 63, 7, 13, 4, 84, 5, 22, 8, 35, 0,  9, 
    0, 46, 1, 32, 4,  8, 2, 61, 7, 71, 5, 49, 8, 55, 3, 70, 6, 42
  };
  const int q7591[] = {
    9, 9, // Number of jobs and machines
    3, 63, 4, 12, 0, 82, 1, 44, 8, 33, 2, 33, 7, 29, 5, 39, 6, 61, 
    3, 17, 7, 47, 4, 74, 6, 26, 1, 59, 8, 99, 2, 89, 5, 12, 0, 68, 
    4, 31, 8, 63, 5, 24, 2, 29, 6, 16, 1, 96, 7, 33, 3, 21, 0, 72, 
    6, 79, 7, 67, 5, 59, 3, 56, 1, 84, 8, 90, 4,  7, 0, 42, 2, 15, 
    3, 32, 1, 79, 7, 58, 4, 95, 6, 12, 8, 56, 2, 72, 0, 92, 5, 94, 
    2, 39, 7, 47, 4, 21, 3, 22, 5, 16, 0, 15, 6, 40, 1,  1, 8, 21, 
    0, 90, 4, 58, 6, 94, 1, 75, 7, 22, 3,  8, 5, 55, 8, 33, 2, 95, 
    6, 83, 1, 37, 8, 25, 7, 40, 2, 48, 0, 27, 3, 43, 4, 13, 5, 41, 
    8, 36, 6, 62, 3, 84, 1, 13, 2, 28, 5, 44, 7, 36, 4, 58, 0, 74
  };
  const int q7592[] = {
    9, 9, // Number of jobs and machines
    7, 62, 1, 23, 8, 67, 2, 84, 5, 68, 3, 56, 0, 49, 6, 30, 4, 68, 
    0, 77, 3, 14, 4, 23, 8, 50, 2, 48, 5,  6, 1, 10, 7, 30, 6, 85, 
    7, 64, 0, 35, 3, 26, 4, 36, 2, 99, 8, 59, 1, 30, 6, 49, 5, 39, 
    6, 81, 4, 10, 3,  7, 0, 99, 1, 24, 5, 34, 7, 77, 2, 31, 8, 55, 
    6, 73, 7, 75, 3, 92, 1, 32, 5, 58, 2, 55, 4, 38, 8, 26, 0, 60, 
    4, 43, 5, 44, 7, 15, 8, 63, 2, 82, 3, 58, 0, 23, 6, 78, 1, 41, 
    1, 10, 5, 35, 7, 14, 4, 48, 2, 95, 3, 59, 8, 30, 6, 94, 0, 59, 
    3,  9, 8, 14, 4, 81, 5, 77, 1, 25, 7, 87, 0, 53, 6, 12, 2, 60, 
    7, 15, 2,  6, 5, 51, 0, 97, 6, 15, 1, 83, 4, 39, 8, 39, 3, 38
  };
  const int q7593[] = {
    9, 9, // Number of jobs and machines
    2,  7, 7, 18, 5, 25, 4, 13, 3, 54, 0, 83, 1, 69, 6, 88, 8, 37, 
    4, 90, 6, 50, 0, 61, 1, 44, 5, 48, 2,  3, 7, 19, 3, 38, 8, 87, 
    5, 74, 1,  5, 6, 88, 7, 11, 8, 78, 4, 34, 0, 50, 3,  8, 2, 45, 
    5, 64, 0, 86, 2, 83, 7, 43, 3, 45, 8, 93, 6, 84, 1, 18, 4, 94, 
    2, 33, 6, 48, 4,  1, 1, 58, 7, 26, 5, 75, 0, 79, 3, 35, 8, 51, 
    3, 43, 5, 96, 2, 26, 0, 14, 4,  8, 6, 31, 1, 23, 7, 11, 8, 94, 
    4, 17, 8, 46, 1, 56, 2, 95, 3, 92, 0, 53, 6, 65, 7, 35, 5,  4, 
    8,  9, 0,  2, 2, 19, 5, 33, 1, 16, 7, 21, 6, 22, 3,  8, 4, 95, 
    7, 21, 3, 38, 8, 15, 0, 34, 6, 22, 2, 19, 4, 81, 1, 34, 5,  7
  };
  const int q7594[] = {
    9, 9, // Number of jobs and machines
    2, 95, 8, 79, 6, 35, 1, 22, 4, 12, 0, 51, 5, 24, 3, 29, 7,  3, 
    1, 48, 3, 26, 4,  9, 7, 67, 5,  4, 6, 69, 8, 53, 0, 79, 2,  7, 
    1,  8, 6,  1, 5, 19, 0,  4, 2, 65, 3, 13, 4, 17, 8, 18, 7, 29, 
    6, 27, 7,  8, 1,  1, 0, 10, 3, 82, 8,  5, 2, 91, 4, 69, 5, 14, 
    0,  6, 5, 93, 6, 48, 1,  7, 8, 55, 7, 95, 2, 56, 4, 32, 3, 41, 
    3,  1, 6,  4, 8, 43, 0, 61, 5, 71, 7,  1, 1, 48, 4, 28, 2, 60, 
    1, 69, 4, 78, 2, 52, 7, 94, 0, 72, 8,  1, 5,  6, 3, 29, 6, 28, 
    1, 76, 4, 69, 7,  1, 0, 40, 3, 39, 2, 30, 6, 27, 5, 46, 8, 15, 
    4, 89, 8, 84, 3, 55, 0, 48, 7,  2, 6, 33, 2, 14, 1, 50, 5, 89
  };
  const int q7595[] = {
    9, 9, // Number of jobs and machines
    2, 24, 8, 71, 0, 44, 3, 51, 6, 27, 1, 80, 4, 66, 5,  6, 7, 15, 
    0, 13, 4, 63, 3, 87, 8, 55, 7, 91, 5,  8, 2, 24, 1, 90, 6,  4, 
    4, 32, 2, 48, 3, 17, 5, 53, 8, 84, 6, 52, 1,  4, 7,  2, 0,  9, 
    0, 90, 1, 46, 6, 28, 5, 72, 7, 46, 2, 27, 3, 38, 4, 80, 8, 15, 
    5, 31, 1, 41, 3, 39, 0, 48, 4,  5, 8, 96, 2, 92, 7, 75, 6, 96, 
    1, 99, 8, 52, 6, 73, 0,  1, 7,  4, 3, 79, 4, 88, 2,  2, 5, 49, 
    5, 82, 2,  2, 4, 70, 3, 52, 6, 22, 1, 29, 7, 43, 8, 17, 0, 69, 
    4,  7, 3, 26, 8, 40, 6, 99, 5, 67, 7, 77, 0, 87, 2, 60, 1, 48, 
    1, 45, 4, 46, 6, 98, 3, 71, 5,  8, 8, 91, 7, 28, 2, 72, 0, 41
  };
  const int q7596[] = {
    9, 9, // Number of jobs and machines
    1, 78, 6, 83, 8, 90, 0, 99, 3, 31, 4, 11, 7, 22, 2, 15, 5, 36, 
    1, 42, 2, 79, 3, 56, 0, 19, 4, 78, 7, 13, 8, 98, 5, 64, 6,  9, 
    6, 34, 2, 96, 5, 96, 0, 39, 7,  6, 3, 32, 1, 22, 8, 76, 4, 17, 
    5, 99, 3,  2, 2, 66, 7,  5, 4, 34, 8, 90, 6,  9, 0, 58, 1, 73, 
    1, 19, 3, 46, 6, 34, 2, 57, 8,  5, 5, 47, 0, 59, 7, 29, 4, 32, 
    3, 79, 1, 22, 8, 86, 6, 44, 7, 65, 4, 23, 2, 56, 5, 41, 0, 64, 
    4,  5, 3, 16, 8, 15, 7, 12, 2, 54, 1, 26, 5, 77, 6, 33, 0, 25, 
    2, 67, 4, 82, 8,  1, 1, 29, 7, 75, 3, 60, 6, 53, 5,  7, 0, 38, 
    8, 95, 2, 35, 1, 45, 4, 78, 6, 23, 7, 63, 5, 70, 0, 62, 3, 28
  };
  const int q7597[] = {
    9, 9, // Number of jobs and machines
    6, 57, 2, 37, 0, 62, 4, 56, 8, 37, 3, 46, 5, 53, 1, 69, 7, 78, 
    1, 59, 7, 75, 3, 21, 5, 59, 4,  1, 8, 62, 6, 42, 2, 29, 0, 59, 
    4, 46, 3, 29, 2, 48, 6, 30, 0, 81, 1, 56, 7, 51, 8, 52, 5,  3, 
    3, 12, 1, 36, 2, 75, 0, 54, 6, 46, 5, 60, 7, 41, 4, 36, 8, 78, 
    5, 80, 1, 34, 4, 42, 3, 43, 0, 91, 8, 42, 7, 37, 6, 47, 2, 53, 
    5, 85, 7, 60, 4, 74, 3, 94, 2,  9, 6, 19, 1, 33, 0, 51, 8,  4, 
    7, 53, 1, 36, 4, 30, 0, 95, 2, 36, 5, 25, 8, 43, 6, 68, 3, 78, 
    8, 37, 2, 71, 0, 31, 6, 37, 7, 65, 5, 14, 3, 67, 1, 60, 4, 99, 
    1, 60, 8, 42, 0,  2, 4, 77, 2, 53, 5, 95, 7, 53, 6, 94, 3, 60
  };
  const int q7598[] = {
    9, 9, // Number of jobs and machines
    2, 92, 5, 15, 3, 98, 8, 45, 0, 70, 6, 81, 1, 91, 4, 10, 7, 88, 
    2, 82, 4, 47, 8, 30, 1,  5, 0, 40, 6, 82, 5, 95, 7, 79, 3, 26, 
    8, 47, 6, 11, 5, 92, 0, 98, 1, 39, 2, 64, 3, 24, 4, 67, 7, 42, 
    4, 38, 1, 14, 5, 49, 3, 67, 0, 15, 6, 94, 7, 23, 8,  8, 2, 60, 
    5, 61, 0, 46, 4, 76, 6, 98, 2, 55, 8, 82, 3, 84, 7, 71, 1, 41, 
    3, 25, 2, 38, 7, 31, 8, 53, 5,  5, 0, 14, 6, 24, 4, 43, 1, 68, 
    3, 38, 7, 41, 5, 36, 0, 95, 4, 28, 8, 35, 6, 25, 2, 33, 1, 76, 
    5, 30, 0, 47, 7, 84, 4, 54, 8, 61, 3, 45, 6, 79, 2, 28, 1, 33, 
    6, 39, 7, 87, 4, 46, 1, 93, 0,  3, 5, 26, 8, 18, 3, 62, 2, 32
  };
  const int q7599[] = {
    9, 9, // Number of jobs and machines
    0, 25, 4, 31, 3, 68, 6, 61, 1, 31, 2, 96, 5, 69, 8, 34, 7, 82, 
    0,  6, 5, 13, 8, 82, 1, 62, 7, 66, 2, 24, 3, 23, 4, 87, 6, 23, 
    3, 26, 1, 76, 2, 20, 4, 69, 6, 37, 5, 41, 8, 15, 0, 98, 7,  5, 
    8,  2, 2, 26, 1, 41, 0, 72, 3, 24, 5, 62, 6, 40, 7, 82, 4, 49, 
    6, 95, 3, 33, 1,  3, 4, 77, 0, 58, 8, 53, 2, 50, 5, 31, 7, 97, 
    6, 11, 1, 13, 3, 26, 0, 41, 5, 56, 8, 82, 7, 62, 2, 18, 4, 18, 
    8, 73, 6, 11, 7, 54, 2,  6, 3, 81, 4, 50, 5, 86, 0, 15, 1, 40, 
    0, 41, 7, 45, 4, 73, 3, 62, 5, 14, 1, 20, 2, 64, 8, 21, 6,  6, 
    1, 61, 8, 42, 4, 53, 5, 27, 6, 49, 0,  2, 2,  1, 3, 22, 7, 97
  };
  const int q7600[] = {
    9, 9, // Number of jobs and machines
    7, 29, 0, 99, 8, 34, 3, 71, 1, 13, 5, 52, 2, 59, 4, 74, 6, 27, 
    2, 90, 6, 84, 5, 61, 4, 35, 1, 18, 0,  4, 7, 56, 8, 29, 3, 93, 
    5, 51, 3,  5, 8,  3, 1, 10, 6, 30, 4, 15, 0, 76, 7, 18, 2,  9, 
    8, 54, 1, 40, 7, 11, 3, 15, 6, 58, 0, 81, 2, 55, 5, 70, 4, 70, 
    0, 76, 5,  4, 6, 31, 1, 63, 8, 76, 4, 11, 3, 67, 2, 32, 7, 59, 
    6, 97, 1, 37, 3, 87, 4, 35, 8, 31, 5, 48, 0, 16, 2, 51, 7, 35, 
    1, 33, 5, 41, 2, 85, 3, 80, 4, 11, 6, 88, 0, 33, 7,  6, 8, 98, 
    3, 96, 0,  9, 6, 10, 2, 29, 4, 82, 8, 37, 5, 30, 7,  7, 1, 54, 
    3, 76, 4, 62, 1, 85, 5, 80, 0, 39, 8, 21, 7, 63, 2, 84, 6, 64
  };
  const int q7601[] = {
    9, 9, // Number of jobs and machines
    3, 26, 6, 77, 5, 61, 8, 17, 2, 23, 0, 22, 1, 62, 7, 46, 4,  1, 
    5, 23, 3, 71, 6, 16, 1, 98, 8, 48, 4, 62, 2, 17, 7, 97, 0, 32, 
    5, 96, 6, 51, 8, 86, 2, 12, 1, 68, 0, 14, 4, 80, 7, 69, 3, 83, 
    5, 82, 4, 92, 1, 22, 7, 72, 0, 11, 6, 88, 8, 42, 3,  5, 2, 92, 
    3,  4, 1, 11, 0, 87, 7, 64, 8, 32, 4, 93, 6, 74, 2, 65, 5, 50, 
    3, 51, 8, 41, 0, 76, 1, 55, 2, 74, 7, 21, 4, 11, 5, 29, 6, 52, 
    4, 51, 8, 51, 6, 68, 1, 53, 2, 69, 0, 90, 3, 26, 5, 92, 7, 36, 
    8, 16, 0, 60, 1, 10, 5, 94, 4,  7, 2, 19, 6, 37, 7, 98, 3, 93, 
    1, 50, 2, 62, 8, 28, 6, 36, 7, 43, 4, 38, 3, 73, 0, 18, 5, 78
  };
  const int q7602[] = {
    9, 9, // Number of jobs and machines
    4, 93, 1, 70, 8, 94, 3, 30, 5,  1, 6,  7, 2, 90, 7, 45, 0, 15, 
    6, 24, 1, 32, 5, 60, 3, 68, 7, 48, 8, 85, 0, 47, 4, 31, 2, 36, 
    0, 50, 2, 75, 5, 93, 6, 25, 1, 55, 7, 15, 3, 32, 4, 45, 8, 74, 
    6, 76, 5, 63, 1, 73, 0,  4, 2, 22, 4, 69, 3, 71, 8, 59, 7, 29, 
    2, 78, 6, 51, 4, 83, 7, 51, 8, 80, 1, 67, 3, 78, 0, 35, 5, 39, 
    2, 21, 3, 69, 8, 18, 1, 24, 6, 83, 5,  8, 4, 98, 7, 87, 0, 45, 
    1, 20, 0, 85, 4, 25, 5, 34, 2,  4, 8, 57, 3, 37, 6, 45, 7, 59, 
    0,  8, 7, 41, 6, 45, 8, 98, 4, 29, 3, 29, 1, 37, 2, 46, 5, 92, 
    3, 82, 7, 96, 4, 40, 6, 62, 8, 19, 2, 89, 5, 54, 1, 80, 0, 17
  };
  const int q7603[] = {
    9, 9, // Number of jobs and machines
    8, 89, 2, 44, 5, 66, 1, 79, 3,  7, 0, 80, 4, 26, 6, 39, 7, 79, 
    5, 95, 1,  4, 7, 56, 3, 29, 2, 76, 0, 37, 4, 51, 8, 59, 6, 79, 
    7, 32, 8, 10, 1, 94, 3, 10, 2, 49, 5, 95, 6, 74, 4,  4, 0, 42, 
    7, 77, 2, 53, 5, 73, 4, 34, 1, 17, 8, 60, 0, 85, 6, 28, 3, 35, 
    4, 79, 0, 95, 1, 79, 8, 98, 5, 14, 3, 90, 6, 15, 2, 60, 7, 10, 
    4, 64, 0, 63, 7, 66, 6, 28, 2, 72, 5, 98, 8, 14, 1, 37, 3, 61, 
    0, 44, 3, 92, 6, 41, 7, 51, 2, 65, 8, 30, 5, 41, 4, 93, 1, 62, 
    7, 22, 6,  5, 2, 77, 3, 63, 4, 63, 0, 30, 5, 88, 8, 19, 1, 45, 
    7, 83, 5, 60, 2, 77, 3, 96, 8, 76, 4, 93, 0, 91, 6, 50, 1, 97
  };
  const int q7604[] = {
    9, 9, // Number of jobs and machines
    1, 97, 7, 46, 6, 15, 3, 69, 5, 82, 2, 24, 8, 50, 0, 52, 4, 32, 
    3, 92, 4,  2, 1, 72, 2, 86, 0, 44, 8, 81, 6, 41, 7, 30, 5, 26, 
    8, 52, 6, 19, 4, 73, 3, 86, 5, 20, 7, 83, 2, 81, 1, 70, 0, 53, 
    0, 86, 5, 90, 7, 36, 3, 41, 2, 93, 8, 44, 1, 63, 6, 55, 4, 26, 
    2, 91, 4,  1, 6, 96, 5, 91, 0, 51, 1, 36, 8, 73, 7, 57, 3, 36, 
    3, 86, 4, 34, 0, 43, 1, 97, 2, 83, 6, 12, 5, 41, 7, 96, 8,  5, 
    6, 29, 2, 40, 7, 10, 8, 52, 0, 66, 1, 93, 3, 90, 5, 61, 4, 96, 
    6, 38, 3, 23, 7, 94, 0, 82, 2, 31, 5, 30, 8, 88, 1, 57, 4, 75, 
    7,  3, 6, 81, 4, 41, 3, 37, 8, 80, 2, 76, 0,  6, 1, 32, 5, 81
  };
  const int q7605[] = {
    9, 9, // Number of jobs and machines
    7, 98, 8, 50, 0, 89, 1, 56, 5, 28, 2, 28, 3, 36, 4, 31, 6, 94, 
    4, 36, 1, 73, 2, 30, 0, 21, 7, 82, 8, 51, 5, 40, 6, 27, 3, 29, 
    7, 99, 5, 82, 1, 29, 4, 37, 8, 29, 2, 81, 6, 37, 3, 41, 0, 33, 
    2, 80, 7,  5, 0,  6, 5, 95, 8, 47, 1, 90, 3, 53, 4, 96, 6, 75, 
    3, 39, 8, 79, 6, 59, 7, 12, 0, 13, 1, 85, 4, 55, 5, 66, 2, 28, 
    0, 52, 7,  5, 1, 29, 6, 92, 5, 48, 4, 34, 8, 57, 2, 20, 3, 60, 
    2, 75, 5, 63, 3, 84, 0, 53, 6, 41, 7, 72, 4, 93, 1,  7, 8, 49, 
    5, 64, 2, 38, 0, 26, 1,  2, 3, 13, 6, 19, 4, 91, 8, 57, 7, 80, 
    1, 45, 7,  9, 8, 16, 5, 10, 0,  1, 3, 13, 6, 32, 4, 13, 2, 54
  };
  const int q7606[] = {
    9, 9, // Number of jobs and machines
    2, 18, 6, 11, 5, 48, 7, 33, 1, 49, 0, 23, 8,  1, 4, 89, 3,  2, 
    4, 41, 1, 88, 3, 86, 2, 17, 5, 51, 7, 93, 6, 61, 0, 63, 8, 36, 
    0, 75, 1, 68, 3, 57, 6, 39, 2, 57, 4, 80, 5, 75, 7, 38, 8, 70, 
    2, 58, 8, 42, 6, 62, 5,  7, 0, 22, 7, 17, 1, 84, 4, 63, 3, 44, 
    1, 82, 2, 33, 5,  6, 6, 82, 7,  9, 0, 28, 8, 33, 3, 68, 4, 49, 
    6, 75, 7, 58, 1, 30, 5, 81, 3, 29, 8, 99, 2, 16, 4, 11, 0, 47, 
    6,  8, 3, 83, 0, 15, 8, 53, 4, 33, 2, 37, 1, 86, 5, 97, 7, 63, 
    2, 11, 0, 11, 7, 25, 5, 76, 3, 98, 1, 48, 6, 84, 4, 29, 8, 21, 
    3,  5, 8, 72, 7, 16, 5,  8, 0, 70, 4, 77, 2, 15, 6, 55, 1, 52
  };
  const int q7607[] = {
    9, 9, // Number of jobs and machines
    2, 99, 6, 32, 3, 94, 5, 61, 0, 24, 7, 12, 1, 28, 8, 86, 4, 19, 
    8, 18, 4, 74, 0,  6, 1, 64, 2, 26, 5, 16, 6, 29, 3, 54, 7, 67, 
    6, 86, 3, 10, 7, 34, 1, 49, 2, 58, 5, 56, 0, 34, 4, 49, 8, 11, 
    1, 12, 5, 71, 4, 67, 6, 54, 0, 30, 2, 24, 7, 71, 8, 76, 3, 70, 
    0, 30, 8, 46, 5,  6, 4, 98, 6,  7, 7, 81, 2, 14, 1, 42, 3, 90, 
    5, 52, 0, 46, 6, 98, 7, 81, 8, 71, 4, 37, 2, 30, 1, 93, 3, 75, 
    2,  7, 1, 24, 6, 31, 0, 14, 7, 75, 4, 60, 8, 66, 5, 38, 3, 35, 
    1, 66, 6, 76, 2, 65, 3,  5, 5, 98, 7, 71, 8, 37, 4, 77, 0, 34, 
    7, 45, 0, 44, 8, 33, 4, 31, 6, 74, 1, 66, 2, 84, 5, 67, 3, 47
  };
  const int q7608[] = {
    9, 9, // Number of jobs and machines
    0, 64, 8, 52, 3, 20, 1, 52, 5, 19, 2, 97, 6, 31, 4, 53, 7, 57, 
    5, 24, 2,  4, 4, 10, 8, 69, 7, 31, 6, 34, 3, 91, 1, 98, 0, 32, 
    7,  5, 2, 88, 4, 56, 8, 90, 6, 55, 3, 74, 5, 37, 1, 10, 0, 59, 
    3, 14, 5, 18, 4, 38, 2, 29, 7, 46, 1, 84, 6, 30, 0, 23, 8, 55, 
    1, 54, 4, 40, 2,  2, 0, 94, 3, 91, 8, 16, 6, 87, 7, 61, 5, 84, 
    6, 97, 7, 44, 4, 38, 3, 98, 8,  1, 5, 50, 1, 88, 2, 87, 0, 70, 
    3, 21, 8, 96, 2,  9, 5, 58, 0, 92, 4, 68, 7, 82, 6,  5, 1, 38, 
    0, 24, 8, 69, 1, 37, 3, 55, 2, 77, 5,  9, 7, 84, 4, 68, 6, 65, 
    6, 69, 0, 42, 1, 19, 5, 17, 2, 92, 3, 75, 8, 54, 7, 73, 4, 32
  };
  const int q7609[] = {
    9, 9, // Number of jobs and machines
    0,  2, 5, 82, 4, 79, 7, 42, 8, 37, 3, 13, 6, 25, 2, 12, 1, 84, 
    1, 37, 6, 80, 5, 16, 3, 45, 7, 76, 0, 53, 4, 90, 2, 39, 8, 59, 
    2, 60, 5, 20, 3, 37, 0, 91, 4, 95, 8, 49, 6, 54, 7, 57, 1,  3, 
    0, 19, 4, 92, 7, 28, 3,  4, 1, 65, 8, 40, 5,  3, 2, 40, 6, 54, 
    2, 94, 0, 51, 5, 53, 7, 19, 8, 33, 6,  8, 4, 62, 1, 45, 3,  8, 
    0, 24, 2, 10, 4, 60, 8, 95, 6, 78, 3, 85, 5, 90, 7, 45, 1,  1, 
    0, 29, 2, 95, 1, 50, 4, 97, 8, 28, 5, 70, 7, 41, 6, 56, 3, 60, 
    2,  2, 3, 11, 1, 98, 7, 71, 6,  9, 4, 44, 0, 23, 8, 63, 5, 97, 
    7, 77, 5, 81, 1, 56, 4, 52, 3, 43, 0,  2, 6, 93, 8, 76, 2, 46
  };
  const int q7610[] = {
    9, 9, // Number of jobs and machines
    2, 59, 4, 58, 5, 29, 0, 28, 3, 17, 8, 90, 7, 47, 1, 14, 6, 94, 
    4, 49, 0, 23, 6, 52, 8, 81, 2,  1, 3, 63, 5, 71, 1,  8, 7, 10, 
    1, 59, 6, 75, 8, 19, 3, 28, 5, 21, 7, 35, 2, 81, 0, 31, 4, 35, 
    8, 94, 7,  2, 0,  7, 4, 45, 3, 15, 5, 61, 2, 82, 1, 52, 6, 49, 
    0, 77, 2,  8, 4, 45, 7, 49, 5, 22, 6, 27, 1, 38, 3, 51, 8, 53, 
    2, 56, 7, 39, 4, 73, 8, 19, 1, 25, 5, 72, 0, 45, 6, 88, 3, 84, 
    5, 36, 1, 33, 6, 19, 2, 67, 7, 13, 8,  8, 4, 13, 0, 91, 3, 11, 
    8, 86, 3, 30, 0, 26, 6, 93, 5, 78, 7, 68, 1, 90, 2,  1, 4,  4, 
    7, 19, 8, 16, 1, 79, 0, 49, 5,  1, 2, 57, 6, 54, 4, 85, 3, 94
  };
  const int q7611[] = {
    9, 9, // Number of jobs and machines
    0, 20, 1,  6, 8, 40, 6, 85, 2, 86, 7, 55, 5, 90, 4, 72, 3, 48, 
    1, 42, 6, 88, 2, 91, 7, 41, 4, 35, 0, 57, 3, 24, 8, 38, 5, 36, 
    3, 31, 0, 84, 4, 20, 5, 62, 2, 42, 7, 57, 1, 10, 8, 48, 6, 17, 
    7, 31, 8,  2, 4, 97, 2, 71, 0, 47, 3, 41, 5, 87, 6, 32, 1, 43, 
    5, 27, 4, 26, 7, 85, 3, 64, 2,  5, 6, 19, 1,  3, 8, 49, 0, 83, 
    0, 54, 2, 49, 4, 74, 7, 22, 3, 78, 5, 94, 1, 53, 6, 76, 8, 96, 
    5, 53, 8, 16, 7, 87, 3, 50, 4, 70, 0, 36, 6, 62, 1, 24, 2, 51, 
    6, 29, 0, 25, 2, 28, 1, 88, 4, 15, 7, 64, 8, 27, 5, 92, 3,  4, 
    4, 25, 7,  3, 6, 55, 0, 61, 8, 48, 5, 13, 3,  8, 1, 16, 2, 57
  };
  const int q7612[] = {
    9, 9, // Number of jobs and machines
    7, 31, 8,  5, 6, 41, 2,  9, 5, 31, 3,  9, 1, 34, 4, 92, 0, 32, 
    4, 16, 2, 96, 5, 43, 0, 93, 7, 26, 1, 85, 3, 97, 8, 62, 6, 46, 
    8, 21, 5, 17, 1, 21, 2, 75, 4, 48, 3, 56, 0, 32, 6, 26, 7,  8, 
    8, 15, 1, 16, 5, 28, 0, 21, 7, 69, 2, 39, 4, 10, 3, 30, 6, 27, 
    3, 94, 6, 15, 2, 97, 4, 73, 1, 92, 8,  8, 7,  5, 0, 96, 5, 18, 
    0, 92, 8, 98, 5, 68, 4, 71, 6, 59, 2, 26, 7, 18, 3, 56, 1, 52, 
    5, 23, 6, 45, 4, 51, 2, 39, 8, 46, 0, 56, 1,  5, 7, 14, 3, 78, 
    5, 46, 2, 17, 1, 19, 3, 64, 4, 94, 8,  5, 0, 55, 7, 87, 6, 10, 
    6, 63, 0, 54, 3, 65, 5, 94, 8, 98, 4, 11, 2, 51, 1, 46, 7, 47
  };
  const int q7613[] = {
    9, 9, // Number of jobs and machines
    4, 18, 7, 38, 5, 55, 2, 58, 8, 84, 1,  7, 6, 77, 0, 51, 3, 11, 
    0, 84, 2, 35, 8, 86, 1, 80, 7, 60, 4, 68, 3, 13, 5,  6, 6,  3, 
    3, 14, 6, 71, 5, 82, 7, 38, 2,  6, 4, 21, 0, 13, 8,  7, 1, 40, 
    1, 45, 2, 90, 7, 62, 4, 70, 3, 29, 8, 96, 6, 99, 5, 21, 0, 19, 
    1, 40, 4, 64, 6, 34, 2, 76, 5, 62, 0, 92, 8, 90, 3, 60, 7, 57, 
    2, 47, 8, 44, 4, 25, 6, 97, 3, 72, 5, 19, 0, 74, 7, 30, 1, 98, 
    1, 29, 6, 11, 2, 76, 7, 67, 5, 65, 8, 36, 0, 54, 3, 61, 4, 17, 
    6, 38, 8, 65, 0,  3, 1, 48, 4, 83, 7,  7, 5, 35, 3,  2, 2, 72, 
    7, 23, 5,  8, 2, 63, 3, 97, 0, 85, 6, 86, 1,  3, 4, 89, 8, 10
  };
  const int q7614[] = {
    9, 9, // Number of jobs and machines
    4, 66, 3, 79, 1,  9, 7, 47, 0,  5, 6, 61, 2, 43, 8, 26, 5, 53, 
    8, 28, 1, 53, 2, 41, 0, 83, 5, 35, 4, 37, 7, 17, 6, 23, 3, 22, 
    1, 83, 4, 82, 6, 86, 0, 79, 2, 38, 5, 92, 7,  2, 3, 73, 8, 65, 
    5,  4, 3,  7, 2, 77, 0, 57, 8, 66, 7, 85, 1, 96, 6,  1, 4, 21, 
    8, 71, 1, 51, 3, 90, 5, 48, 2, 18, 0, 16, 7, 49, 6, 20, 4, 96, 
    5,  5, 2, 37, 7,  2, 6, 73, 0, 19, 3, 32, 1, 76, 8, 51, 4, 22, 
    6, 32, 8, 19, 4, 27, 2,  8, 0, 15, 7, 69, 5, 94, 1,  3, 3, 90, 
    5, 31, 1, 61, 2, 11, 0, 39, 8, 10, 3, 62, 4, 93, 7, 91, 6, 87, 
    3, 78, 7, 23, 4, 82, 5,  6, 0, 72, 6, 17, 8, 88, 2, 70, 1, 83
  };
  const int q7615[] = {
    9, 9, // Number of jobs and machines
    1, 96, 4, 26, 2, 97, 6, 31, 7, 58, 8, 51, 0, 68, 5, 46, 3, 26, 
    3, 47, 4, 95, 8, 23, 5, 48, 7, 54, 6, 63, 2,  4, 1, 23, 0, 78, 
    2, 96, 0, 70, 7, 49, 8, 84, 3, 11, 6, 27, 5, 17, 1, 66, 4, 45, 
    0, 54, 7, 30, 5, 42, 6, 34, 4, 70, 8, 60, 3, 68, 1, 95, 2, 71, 
    6, 70, 5, 66, 7, 16, 8, 41, 1, 48, 3, 29, 0, 67, 4, 91, 2, 63, 
    3, 51, 0, 54, 1, 43, 5, 75, 4, 57, 6,  6, 7, 73, 2, 16, 8, 40, 
    0, 92, 8, 55, 1, 59, 5, 98, 6, 56, 3,  3, 2, 20, 7, 28, 4, 46, 
    6, 92, 7, 73, 1,  6, 3, 96, 8, 45, 0, 88, 4, 67, 2, 51, 5, 78, 
    4, 79, 3, 95, 2, 96, 6, 51, 5, 74, 8, 18, 7, 51, 1, 21, 0, 76
  };
  const int q7616[] = {
    9, 9, // Number of jobs and machines
    7,  7, 0, 45, 4, 81, 6, 65, 3, 80, 5, 63, 1, 11, 2, 70, 8, 55, 
    8, 13, 6, 86, 3, 50, 4, 11, 2,  5, 5, 25, 7, 81, 1, 68, 0,  7, 
    6, 93, 4, 60, 3, 55, 7, 33, 0, 17, 8, 33, 5,  6, 2, 29, 1, 43, 
    2, 43, 5, 94, 7, 87, 1, 93, 6, 31, 8, 78, 4,  5, 0,  1, 3, 96, 
    7,  9, 3, 58, 2, 76, 6, 89, 1, 89, 0, 42, 5, 61, 4, 26, 8, 12, 
    6, 26, 1, 69, 3, 80, 8, 31, 5, 57, 0, 74, 2, 15, 4,  5, 7, 24, 
    6, 20, 7, 71, 5,  3, 0, 95, 2,  1, 1, 31, 8, 87, 3, 34, 4, 86, 
    3, 89, 7, 95, 4, 80, 6, 73, 8, 56, 2, 21, 5, 33, 0, 90, 1, 65, 
    0, 58, 2, 51, 6, 41, 3, 76, 4, 50, 7, 77, 1, 12, 8, 16, 5, 14
  };
  const int q7617[] = {
    9, 9, // Number of jobs and machines
    3, 63, 4, 17, 2, 11, 1, 96, 5, 48, 0, 69, 7, 56, 6, 22, 8, 81, 
    7, 90, 3, 52, 5, 26, 0, 86, 1, 82, 8, 84, 4, 44, 6, 56, 2, 25, 
    1, 51, 3, 81, 4, 71, 6, 16, 7, 47, 8, 80, 0, 20, 5, 95, 2, 67, 
    3, 58, 5, 36, 4, 46, 8, 43, 7, 51, 1, 79, 2, 15, 6, 35, 0, 37, 
    4, 24, 5, 74, 3, 76, 1, 80, 8, 11, 7, 27, 2, 40, 0, 79, 6, 30, 
    8,  4, 0, 80, 7, 75, 5, 30, 2, 25, 1, 52, 6, 43, 3, 62, 4, 82, 
    4, 93, 7, 23, 8, 67, 5, 81, 6, 81, 1, 46, 2,  9, 3, 62, 0, 57, 
    3, 13, 1, 47, 8, 46, 2, 12, 4, 37, 5, 40, 7, 96, 6, 24, 0, 13, 
    3, 94, 5, 58, 7, 31, 2, 24, 1, 62, 4, 79, 0, 49, 6, 81, 8,  5
  };
  const int q7618[] = {
    9, 9, // Number of jobs and machines
    1,  3, 4, 54, 6,  6, 8, 64, 3, 35, 5, 12, 2, 55, 7,  1, 0, 71, 
    7, 59, 5, 34, 6,  7, 3, 24, 1, 12, 8,  5, 4, 73, 2, 25, 0, 28, 
    3, 84, 2, 75, 4, 24, 1, 18, 5, 94, 7, 21, 8, 97, 6, 34, 0, 87, 
    3, 10, 2, 61, 7,  5, 8, 92, 0, 44, 6,  8, 5, 11, 4,  1, 1, 46, 
    8, 20, 0, 66, 4, 78, 7, 35, 3, 59, 5, 55, 2, 39, 6, 61, 1, 39, 
    8, 38, 0, 49, 4, 40, 7, 44, 1, 98, 3, 17, 2, 26, 6, 62, 5, 65, 
    0, 38, 7, 41, 3, 46, 1, 54, 6, 88, 5, 75, 4,  5, 8, 86, 2, 98, 
    0, 10, 7, 15, 1, 49, 3, 15, 4, 38, 2, 36, 6,  8, 5, 58, 8, 49, 
    1, 63, 8, 22, 4,  1, 0, 80, 6, 55, 3, 18, 2, 91, 5, 37, 7, 42
  };
  const int q7619[] = {
    9, 9, // Number of jobs and machines
    5, 87, 6, 25, 3, 44, 8, 74, 0, 62, 1, 77, 2, 86, 4, 28, 7, 82, 
    4, 43, 5, 33, 3, 10, 2, 37, 0, 14, 6, 49, 8, 31, 1, 54, 7, 54, 
    6, 26, 0, 47, 3, 74, 2, 30, 7, 30, 1, 83, 4,  6, 5,  3, 8, 55, 
    4, 49, 7, 24, 6, 91, 5, 28, 8, 69, 2, 48, 1, 95, 0, 81, 3,  2, 
    6, 92, 1, 99, 0, 93, 5, 49, 2, 99, 4, 83, 8, 49, 7, 89, 3, 24, 
    5, 21, 1, 24, 2, 87, 7, 66, 4,  4, 6, 62, 3, 28, 0, 15, 8, 89, 
    7, 31, 4, 57, 8, 24, 5, 32, 1, 12, 0, 18, 3, 74, 2, 26, 6, 70, 
    3, 81, 7, 81, 8, 83, 5, 94, 6, 66, 1, 63, 0, 65, 4, 38, 2, 95, 
    0, 44, 5, 63, 1, 31, 2, 52, 6, 97, 3, 36, 8,  5, 7, 50, 4, 58
  };
  const int q7620[] = {
    9, 9, // Number of jobs and machines
    6, 52, 8, 32, 0, 93, 2,  7, 7, 21, 5, 14, 3, 96, 4, 31, 1,  8, 
    1, 91, 8, 48, 5, 24, 7, 32, 0, 99, 6, 84, 4, 78, 2, 84, 3, 85, 
    2, 20, 1, 23, 5, 71, 7, 48, 6, 22, 3, 99, 8, 92, 4, 79, 0, 61, 
    0, 87, 7, 91, 5, 44, 1, 48, 4, 75, 6, 47, 3, 87, 8, 46, 2, 81, 
    7,  3, 4, 40, 3, 58, 5, 94, 1, 61, 6, 76, 0, 35, 2, 20, 8, 75, 
    1, 68, 4, 61, 2, 15, 3,  8, 0, 43, 7, 41, 8, 53, 5, 90, 6, 49, 
    0, 59, 5, 55, 2, 42, 4, 91, 8, 42, 6, 38, 1, 57, 3,  1, 7, 59, 
    2, 50, 7, 10, 6,  2, 3, 14, 8, 70, 0, 57, 1, 59, 5, 31, 4, 79, 
    1,  9, 7, 22, 8, 69, 2, 16, 0, 95, 5, 40, 3, 22, 6, 28, 4, 98
  };
  const int q7621[] = {
    9, 9, // Number of jobs and machines
    1, 74, 3,  4, 4,  2, 2, 49, 7, 53, 5,  8, 0, 83, 8, 94, 6, 53, 
    4, 13, 0,  2, 3, 56, 7, 22, 2, 79, 8, 18, 5, 70, 1, 54, 6,  6, 
    4, 18, 3, 62, 6, 24, 5, 81, 2, 34, 1, 12, 7, 76, 8, 46, 0, 75, 
    0, 75, 4, 39, 5, 35, 2, 29, 8, 46, 7, 75, 1, 34, 3, 92, 6, 78, 
    5, 90, 2, 83, 4, 72, 3, 34, 8, 29, 6, 58, 1, 27, 0, 30, 7, 13, 
    4, 42, 3, 34, 6,  6, 5, 65, 8, 66, 0, 66, 7, 60, 1,  5, 2, 46, 
    1,  2, 5, 90, 7,  8, 6, 91, 4, 94, 3,  4, 0, 66, 2, 16, 8, 28, 
    4, 33, 7, 55, 8, 74, 6, 98, 5, 11, 1,  2, 0, 63, 2, 42, 3, 79, 
    8,  7, 3, 45, 7, 43, 4, 67, 5, 40, 6, 99, 0, 51, 2, 16, 1, 70
  };
  const int q7622[] = {
    9, 9, // Number of jobs and machines
    5, 26, 4, 34, 2, 67, 6, 97, 1, 39, 7, 55, 0, 36, 3, 13, 8, 68, 
    2,  6, 7, 80, 1, 69, 0, 50, 5,  9, 4, 84, 8, 22, 3,  3, 6, 88, 
    4, 48, 3, 93, 5, 65, 7, 15, 8, 82, 1, 76, 6, 46, 0, 17, 2,  6, 
    0, 80, 3, 17, 4, 91, 2, 59, 5, 33, 8, 87, 7, 66, 1, 18, 6, 42, 
    1, 45, 6, 95, 0, 84, 2, 38, 4, 20, 8, 59, 7, 78, 3, 84, 5, 91, 
    8, 97, 3, 20, 1, 26, 7, 23, 0, 27, 6, 74, 2, 82, 4,  3, 5, 42, 
    6, 74, 4, 55, 2, 65, 1, 31, 0, 10, 8, 89, 5, 92, 3, 96, 7, 56, 
    7, 81, 0, 21, 4, 92, 1, 11, 2, 75, 8, 99, 3,  3, 5, 80, 6,  2, 
    7, 23, 2, 76, 0,  6, 3, 39, 8, 43, 1,  3, 4, 46, 5, 92, 6, 30
  };
  const int q7623[] = {
    9, 9, // Number of jobs and machines
    3,  9, 5, 26, 8, 61, 7, 12, 4, 48, 1, 16, 2, 56, 6, 55, 0, 64, 
    1, 78, 6, 49, 4, 28, 5, 61, 8, 55, 0, 22, 7, 25, 2, 52, 3, 78, 
    6, 97, 1, 90, 8, 39, 2,  8, 3,  7, 4, 10, 0, 62, 7, 12, 5, 33, 
    4, 17, 2, 61, 5, 14, 8, 52, 1, 55, 0, 80, 3, 44, 6,  5, 7, 68, 
    6,  7, 0, 28, 2, 52, 5, 86, 4, 91, 1, 36, 3, 48, 8, 59, 7, 80, 
    8, 72, 3, 16, 4, 62, 0, 43, 7, 48, 2, 27, 1, 94, 5, 36, 6, 44, 
    2, 49, 0, 76, 5, 74, 8, 17, 4, 58, 3,  5, 1, 29, 7, 39, 6, 32, 
    4,  6, 0, 45, 2, 65, 7,  8, 5, 88, 3,  7, 1, 87, 8, 72, 6, 10, 
    5, 65, 0, 93, 1, 42, 3, 47, 2, 89, 4, 27, 6, 84, 8, 54, 7, 86
  };
  const int q7624[] = {
    9, 9, // Number of jobs and machines
    8, 21, 4, 45, 3, 51, 0, 81, 5, 28, 2, 26, 6, 93, 7, 85, 1, 44, 
    4, 83, 8, 79, 0, 20, 6, 11, 5, 77, 7, 33, 3, 12, 1, 30, 2, 26, 
    3, 55, 4, 10, 0, 69, 2, 52, 1, 20, 5, 96, 7,  2, 8,  3, 6, 28, 
    4, 61, 3, 76, 2, 73, 0, 64, 6, 35, 5, 28, 7, 70, 1, 44, 8, 82, 
    8, 49, 3, 25, 1, 82, 4, 25, 7, 78, 6, 70, 2, 66, 5, 23, 0, 89, 
    1, 30, 6, 88, 4, 91, 0, 75, 7, 73, 5, 56, 2, 81, 3, 13, 8,  7, 
    1, 61, 3, 83, 8, 22, 7, 93, 5, 99, 6,  4, 0, 85, 4, 45, 2, 84, 
    3, 54, 7, 45, 2, 96, 5,  6, 4, 54, 6,  4, 0, 13, 1, 66, 8, 56, 
    8,  3, 5, 14, 0, 48, 2, 96, 6, 57, 4, 75, 7, 50, 3,  2, 1, 32
  };
  const int q7625[] = {
    9, 9, // Number of jobs and machines
    7, 40, 0, 22, 4, 34, 2, 66, 8, 25, 5, 22, 6, 96, 3, 31, 1, 14, 
    8,  1, 6,  9, 3,  5, 0,  9, 7, 61, 1, 78, 4, 85, 5, 93, 2, 40, 
    7, 62, 4, 80, 3, 74, 5, 34, 1, 93, 8, 88, 6, 88, 0, 52, 2, 66, 
    2, 45, 5, 69, 3, 98, 8, 69, 0, 46, 6, 14, 4, 98, 7, 84, 1, 94, 
    7, 65, 8, 73, 4, 42, 1, 77, 2, 32, 0,  9, 6, 64, 5, 12, 3, 64, 
    5, 11, 1, 76, 3, 19, 0, 41, 2, 69, 7, 29, 8, 21, 4, 67, 6, 43, 
    1, 29, 7, 17, 8, 66, 2, 64, 4, 80, 5, 39, 6, 56, 0, 37, 3, 99, 
    2, 75, 8, 43, 5, 18, 7, 85, 1, 70, 0, 48, 6,  8, 4, 10, 3, 54, 
    2, 77, 3, 45, 6, 19, 7, 96, 5, 96, 8, 33, 0, 98, 4, 71, 1, 29
  };
  const int q7626[] = {
    9, 9, // Number of jobs and machines
    5, 15, 8, 37, 6, 77, 0, 34, 7, 18, 3, 77, 2, 61, 4, 25, 1, 71, 
    4, 12, 7, 76, 5, 86, 0, 16, 6, 57, 1, 50, 3,  2, 8, 41, 2, 34, 
    5, 87, 6, 92, 2, 48, 1, 15, 8, 61, 0, 22, 4, 88, 7,  4, 3, 55, 
    0, 40, 1,  8, 5, 49, 4, 29, 3, 74, 8, 78, 7, 31, 2,  9, 6, 66, 
    7, 70, 5, 64, 2, 79, 3, 63, 1, 88, 8, 58, 6, 22, 4, 38, 0, 95, 
    0, 23, 4, 75, 8, 53, 6, 41, 1, 14, 2,  7, 7, 40, 5, 32, 3, 59, 
    5, 45, 1, 81, 0, 31, 4, 17, 7, 24, 3, 25, 2, 44, 8, 13, 6,  3, 
    3,  1, 1, 85, 4, 61, 5, 82, 2, 40, 0, 48, 6, 99, 7, 50, 8, 95, 
    2, 55, 0,  9, 7, 63, 4, 78, 8,  9, 6, 38, 5, 17, 3, 28, 1, 28
  };
  const int q7627[] = {
    9, 9, // Number of jobs and machines
    5, 43, 2, 34, 4, 70, 3, 71, 1, 77, 6, 91, 8, 90, 0, 80, 7, 41, 
    6, 28, 8, 84, 0, 46, 2, 83, 4, 77, 5, 71, 3, 92, 7, 30, 1, 84, 
    4, 36, 1, 48, 3, 76, 2, 62, 0, 38, 5, 36, 7, 93, 8,  4, 6, 35, 
    1, 64, 5, 93, 7, 99, 8, 53, 6, 79, 2, 67, 4, 48, 3, 18, 0, 12, 
    0, 27, 2, 35, 4, 61, 6, 26, 7, 24, 8, 67, 3, 33, 5, 67, 1, 61, 
    1, 17, 8, 83, 0, 36, 5, 83, 3, 51, 2, 72, 6, 71, 4, 95, 7, 19, 
    3, 88, 0, 88, 4, 56, 6, 78, 2, 49, 5, 75, 7, 91, 8, 52, 1, 25, 
    6, 55, 7, 29, 5, 41, 3, 51, 0, 67, 4, 72, 2, 92, 1, 46, 8, 37, 
    8, 49, 5, 24, 3, 73, 1, 40, 2, 48, 4, 39, 0,  1, 6,  4, 7,  1
  };
  const int q7628[] = {
    9, 9, // Number of jobs and machines
    1, 45, 2, 88, 6, 38, 0, 42, 7, 85, 8, 19, 4, 27, 3, 11, 5, 31, 
    1, 94, 6,  9, 8, 40, 3,  3, 7, 95, 5, 33, 4, 18, 2, 10, 0, 42, 
    2, 89, 0, 58, 3, 26, 5, 33, 6, 75, 1, 59, 7, 16, 8, 90, 4,  3, 
    3, 29, 0, 93, 8, 92, 5, 44, 1, 66, 4, 74, 6, 96, 2, 40, 7, 79, 
    8, 24, 2, 84, 1, 51, 7, 37, 0, 29, 5, 68, 6, 43, 4, 66, 3, 73, 
    4, 18, 5, 73, 0, 89, 2, 58, 3, 37, 1, 37, 7, 59, 6, 80, 8,  6, 
    4, 91, 1, 28, 7, 24, 3, 16, 2, 67, 8, 33, 0, 96, 5, 18, 6, 15, 
    3,  3, 5, 98, 6, 39, 0, 89, 8, 94, 1,  2, 4, 42, 7, 50, 2, 36, 
    4, 91, 6, 23, 3, 82, 7, 73, 2,  1, 8, 27, 1,  6, 0, 46, 5, 67
  };
  const int q7629[] = {
    9, 9, // Number of jobs and machines
    6, 56, 8, 15, 7, 53, 3, 83, 2, 99, 5, 65, 0, 81, 4, 70, 1, 88, 
    6, 99, 0,  1, 1, 55, 4, 21, 7, 96, 8, 99, 5, 18, 3, 90, 2,  9, 
    0, 83, 4, 21, 3, 30, 2, 57, 7, 49, 1, 89, 8, 34, 6, 46, 5, 26, 
    1, 83, 4, 55, 0, 18, 3, 39, 7, 22, 6, 64, 2, 84, 8, 25, 5, 51, 
    3, 70, 8, 62, 5, 56, 4, 12, 7, 95, 2, 20, 6, 20, 0, 98, 1, 66, 
    1, 92, 0, 33, 7, 29, 8, 13, 5, 70, 2, 88, 3,  8, 4, 93, 6,  5, 
    4, 40, 3, 14, 0, 45, 6,  1, 5, 91, 2, 23, 7, 41, 1, 98, 8, 94, 
    8, 28, 4, 42, 1, 25, 3, 69, 5, 30, 2, 33, 7, 24, 0, 56, 6, 18, 
    1, 79, 4, 81, 8, 96, 6, 78, 3, 86, 7, 44, 2, 21, 0, 11, 5, 19
  };
  const int q7630[] = {
    9, 9, // Number of jobs and machines
    6,  6, 8,  7, 2, 78, 7, 54, 1, 29, 5, 54, 3, 97, 0, 85, 4, 81, 
    7, 63, 1, 83, 5, 41, 4, 42, 6, 90, 3, 81, 0, 82, 8, 30, 2, 57, 
    2, 93, 5, 11, 7, 33, 1, 29, 4, 73, 8, 84, 6, 73, 0, 51, 3,  9, 
    1, 99, 5, 34, 7, 45, 2, 37, 6,  9, 0, 49, 4, 66, 3, 21, 8, 59, 
    2, 77, 6, 83, 1, 12, 5, 51, 4, 78, 0, 12, 7, 23, 3,  1, 8,  6, 
    5, 53, 6, 63, 0, 61, 8, 50, 3, 71, 7, 20, 2, 39, 1, 30, 4, 80, 
    2, 40, 4, 32, 6, 46, 1, 64, 8, 17, 7, 98, 5, 57, 0, 69, 3, 56, 
    4, 33, 7, 66, 6, 81, 2, 35, 3, 65, 8, 73, 5,  2, 1, 61, 0, 17, 
    7, 17, 4, 22, 8, 22, 3, 32, 0, 52, 5, 78, 6, 41, 1, 27, 2, 31
  };
  const int q7631[] = {
    9, 9, // Number of jobs and machines
    5, 81, 8, 53, 3, 15, 4, 62, 6, 10, 7, 67, 0,  4, 1, 46, 2, 39, 
    8, 53, 7, 78, 6, 40, 0, 88, 5, 76, 1, 53, 3, 91, 2, 81, 4, 14, 
    0,  5, 7,  2, 6, 49, 2, 78, 3, 51, 1, 73, 4,  7, 8, 27, 5, 30, 
    6, 30, 3, 94, 1, 93, 5, 16, 7, 82, 8,  1, 2, 22, 4, 61, 0, 79, 
    5, 16, 4,  4, 8, 98, 7, 53, 0, 86, 3, 33, 2, 19, 1, 40, 6,  1, 
    3,  8, 4,  1, 2, 63, 1, 55, 8, 14, 6,  7, 5, 33, 7, 48, 0, 91, 
    5, 46, 6, 91, 0, 79, 7, 88, 1, 97, 8, 88, 3, 11, 4, 47, 2, 50, 
    3, 28, 4, 85, 8,  6, 0, 82, 2, 76, 6, 48, 7, 50, 1,  7, 5, 45, 
    7, 52, 1, 16, 4, 25, 5, 28, 8, 12, 6, 53, 0, 93, 3, 88, 2, 30
  };
  const int q7632[] = {
    9, 9, // Number of jobs and machines
    4, 96, 1, 48, 7, 86, 5, 55, 2, 60, 0, 97, 6,  2, 8, 95, 3, 23, 
    8, 47, 3, 66, 7, 55, 4, 78, 5, 52, 1, 42, 0, 63, 6, 53, 2, 12, 
    6, 43, 2, 33, 4, 76, 5, 69, 1, 16, 7, 68, 8, 88, 3, 25, 0, 68, 
    8, 56, 7, 76, 1, 72, 4, 15, 0, 24, 2, 46, 6, 34, 5, 51, 3, 30, 
    1, 27, 6, 84, 3, 31, 5, 24, 4, 48, 8, 24, 0, 57, 7, 96, 2, 52, 
    7, 38, 6, 65, 0, 46, 2, 35, 8, 56, 4, 56, 3, 90, 1, 89, 5, 17, 
    3, 90, 6, 20, 1, 68, 8, 15, 2, 72, 0, 42, 5, 99, 4, 82, 7, 69, 
    6, 52, 2, 28, 0, 54, 4, 37, 5, 34, 3, 49, 1, 68, 7, 28, 8, 69, 
    4, 51, 1, 85, 6, 98, 3, 28, 0,  1, 2, 26, 5, 26, 7, 26, 8, 91
  };
  const int q7633[] = {
    9, 9, // Number of jobs and machines
    6,  2, 7, 27, 4, 98, 5,  3, 8, 63, 0, 93, 1, 63, 2, 66, 3,  4, 
    7, 21, 0, 72, 2, 28, 3, 34, 4, 29, 1, 99, 5, 46, 6, 84, 8, 56, 
    6, 73, 0, 46, 7, 76, 4, 82, 5, 70, 1,  9, 8, 85, 3, 92, 2, 94, 
    0, 62, 6, 75, 1,  2, 7, 36, 3, 58, 2, 54, 4, 69, 5, 36, 8, 25, 
    5, 62, 7, 93, 0, 88, 4, 41, 8, 93, 1, 10, 2, 52, 3, 72, 6, 37, 
    4, 90, 6, 45, 7, 32, 1, 95, 3, 71, 2, 79, 8, 89, 5, 48, 0, 87, 
    4, 93, 6, 87, 7, 77, 2, 80, 3, 70, 5, 36, 8,  6, 0, 32, 1, 45, 
    8, 58, 1, 22, 3, 62, 0, 78, 6,  7, 5, 10, 2, 73, 4, 13, 7, 33, 
    0, 36, 6, 49, 7, 46, 5,  1, 1, 34, 4, 30, 3, 88, 2, 66, 8,  7
  };
  const int q7634[] = {
    9, 9, // Number of jobs and machines
    7, 42, 3, 31, 2, 35, 1, 46, 6, 90, 4, 92, 0,  1, 5, 35, 8, 53, 
    4, 75, 5, 87, 6, 95, 8, 59, 0, 72, 2, 55, 7,  6, 1, 87, 3, 45, 
    4, 99, 8, 90, 1,  7, 3, 94, 2, 58, 6, 31, 5, 72, 7, 54, 0, 98, 
    6, 50, 5, 49, 1, 34, 3, 50, 7,  8, 0, 41, 4, 16, 8, 38, 2, 93, 
    1, 23, 3, 33, 8,  1, 7, 76, 6, 50, 4, 39, 5, 73, 2, 47, 0, 82, 
    3, 30, 8,  9, 7, 62, 5, 47, 4, 49, 2, 44, 0, 63, 1, 75, 6, 53, 
    7, 10, 1, 37, 0, 19, 4, 54, 6, 35, 2, 45, 3,  5, 8, 46, 5, 95, 
    5, 27, 2, 39, 8, 51, 1, 73, 4, 85, 7, 31, 3, 10, 6, 66, 0, 57, 
    8, 79, 7, 33, 5, 21, 0, 86, 6, 36, 1, 84, 4,  9, 2, 28, 3, 51
  };
  const int q7635[] = {
    9, 9, // Number of jobs and machines
    3, 79, 4, 37, 2, 66, 0, 34, 6, 26, 8, 59, 7, 61, 5, 58, 1, 15, 
    1, 89, 7, 82, 3,  4, 5, 94, 0, 82, 2, 91, 4, 12, 8, 19, 6, 50, 
    5,  7, 8, 56, 1,  1, 4, 35, 7, 82, 0, 16, 2, 38, 6, 11, 3, 63, 
    0, 89, 8, 88, 4, 12, 2, 48, 7, 73, 3, 33, 1, 17, 5, 12, 6, 10, 
    7, 48, 0, 57, 5, 45, 4, 21, 3, 24, 8, 62, 1, 45, 6, 75, 2, 26, 
    6, 57, 5, 40, 8, 15, 2, 22, 0, 14, 3, 64, 4, 33, 1, 69, 7, 57, 
    1, 85, 2, 38, 8, 83, 4, 65, 5, 12, 3, 65, 6, 57, 7,  5, 0, 70, 
    8,  9, 0, 40, 7, 77, 2, 98, 5, 51, 3, 71, 6, 79, 4, 50, 1, 30, 
    8, 92, 3, 20, 4, 40, 5, 91, 7, 65, 0, 63, 6, 56, 1, 29, 2, 40
  };
  const int q7636[] = {
    9, 9, // Number of jobs and machines
    0,  2, 4, 11, 2, 30, 5, 35, 3, 31, 7, 10, 8, 43, 6, 80, 1, 16, 
    1, 20, 2, 70, 5, 33, 6, 84, 8, 37, 7, 33, 4, 40, 3,  9, 0, 75, 
    5, 27, 7, 44, 4, 93, 2,  7, 6, 59, 8, 24, 0, 74, 1, 55, 3,  1, 
    6, 10, 3, 69, 5, 67, 4, 33, 7, 93, 2, 90, 0, 82, 8, 39, 1, 12, 
    8, 93, 4, 75, 6,  3, 1,  9, 3, 19, 0, 97, 2, 54, 5, 78, 7, 15, 
    6, 30, 3, 88, 5, 80, 4, 91, 0, 17, 7, 71, 2, 17, 8, 59, 1, 60, 
    7, 92, 0, 33, 4, 41, 6, 94, 5, 41, 2, 31, 3, 41, 1, 11, 8, 35, 
    8, 35, 1, 94, 3, 76, 2, 73, 7, 76, 4, 97, 5, 15, 0, 12, 6, 66, 
    5, 12, 0, 11, 3, 85, 8, 67, 2, 41, 4, 77, 6, 55, 7, 80, 1,  9
  };
  const int q7637[] = {
    9, 9, // Number of jobs and machines
    7, 82, 6, 73, 4, 53, 0, 28, 2, 96, 3, 89, 8, 48, 1, 59, 5, 26, 
    7, 18, 4,  2, 8, 97, 5, 24, 2, 51, 1, 38, 6, 88, 0,  8, 3, 68, 
    0,  9, 5, 54, 3, 23, 4,  5, 1, 55, 8, 46, 7, 84, 2, 35, 6, 78, 
    3, 51, 4, 41, 7, 74, 8, 65, 6, 78, 5, 58, 2, 10, 1, 99, 0, 20, 
    1, 30, 4, 47, 7, 94, 0, 85, 3, 47, 5, 94, 2, 67, 8, 69, 6, 23, 
    6, 72, 7, 76, 3, 38, 1, 62, 2, 95, 0, 67, 4, 16, 5, 78, 8, 12, 
    7, 74, 0, 64, 2,  9, 3, 57, 4, 94, 6, 15, 5,  6, 1, 57, 8,  4, 
    6, 39, 8, 43, 2, 35, 1, 56, 0, 88, 7, 88, 5, 36, 4, 47, 3, 90, 
    1, 38, 6, 41, 3, 31, 0, 19, 8, 74, 7, 65, 5,  6, 2, 17, 4, 59
  };
  const int q7638[] = {
    9, 9, // Number of jobs and machines
    3,  4, 6, 19, 1, 28, 2, 15, 7, 44, 4, 39, 0, 16, 5, 76, 8, 10, 
    6, 81, 5, 16, 8, 69, 7, 68, 2, 74, 3, 60, 4, 62, 1, 89, 0, 14, 
    1, 81, 5, 95, 4, 26, 3, 78, 2, 19, 7, 88, 6, 83, 8, 35, 0, 56, 
    5, 10, 7, 41, 0, 71, 1, 84, 6, 29, 3,  4, 8,  6, 2, 88, 4, 44, 
    3, 77, 8, 91, 1, 75, 6, 32, 0, 41, 2, 90, 5, 50, 4, 85, 7, 43, 
    3,  8, 5, 70, 6, 52, 8, 68, 2, 84, 0,  4, 7, 83, 4, 42, 1, 85, 
    7, 63, 4, 53, 2, 78, 1, 40, 5, 60, 8, 44, 3, 61, 6, 70, 0, 62, 
    5, 54, 4, 76, 7, 81, 2, 32, 1, 93, 0, 46, 8, 89, 3, 77, 6, 20, 
    6, 84, 3, 54, 2, 45, 4, 67, 8, 22, 1,  5, 0, 80, 7, 98, 5,  6
  };
  const int q7639[] = {
    9, 9, // Number of jobs and machines
    1, 70, 8, 86, 7, 34, 0, 26, 3, 11, 2, 52, 5, 25, 6, 73, 4, 22, 
    8, 74, 7, 38, 2, 58, 4, 82, 6, 64, 0, 68, 3, 83, 1, 47, 5, 66, 
    6, 53, 4, 69, 3, 97, 8, 46, 2, 39, 1, 66, 7, 13, 0, 40, 5, 79, 
    5, 58, 6, 50, 3, 41, 2, 85, 0, 52, 8, 76, 4, 53, 1, 83, 7, 47, 
    2, 81, 4, 70, 8, 40, 1, 69, 7, 10, 5, 95, 0, 20, 6, 82, 3, 97, 
    3, 86, 2, 15, 6,  6, 8, 58, 7, 39, 1, 99, 5, 33, 4, 93, 0, 35, 
    2, 15, 0, 24, 6, 64, 8, 68, 3, 31, 1, 50, 5, 64, 7, 79, 4,  1, 
    0, 27, 6, 94, 5, 60, 4, 96, 8, 47, 2, 31, 1, 37, 3, 48, 7, 59, 
    4,  7, 8, 21, 6, 79, 0, 50, 2,  1, 5, 46, 3, 37, 1,  6, 7, 35
  };
  const int q7640[] = {
    9, 9, // Number of jobs and machines
    1, 75, 5, 51, 6, 33, 8, 85, 4, 51, 0, 77, 2, 44, 7, 29, 3, 29, 
    7, 63, 2, 42, 3, 87, 5, 37, 1, 67, 4, 93, 6, 14, 8, 15, 0, 34, 
    6, 85, 8, 49, 4, 57, 1, 25, 7, 85, 2, 69, 3, 77, 0, 58, 5, 21, 
    2, 46, 5, 12, 4, 62, 1, 59, 8, 35, 3, 12, 7, 86, 6, 36, 0, 83, 
    3, 97, 6, 61, 0,  4, 4, 68, 7, 60, 2,  4, 1, 82, 8, 44, 5, 21, 
    3, 23, 5, 77, 8, 25, 4, 41, 6, 87, 1, 41, 2, 29, 0, 78, 7, 35, 
    3, 90, 8, 25, 1, 22, 0, 10, 5, 14, 4,  3, 2, 43, 7, 33, 6, 40, 
    8, 91, 4, 60, 0, 82, 3,  6, 6, 61, 2, 42, 1, 16, 5, 10, 7, 58, 
    3,  4, 8, 25, 7, 66, 2, 36, 0, 53, 6,  2, 4, 24, 5, 22, 1, 34
  };
  const int q7641[] = {
    9, 9, // Number of jobs and machines
    8, 87, 6, 96, 1, 80, 3, 54, 7, 80, 2, 75, 0, 44, 5, 20, 4, 43, 
    2, 72, 6,  2, 7, 58, 5, 13, 0, 87, 4, 93, 3, 17, 8, 13, 1, 67, 
    7, 45, 8, 77, 2,  4, 1, 84, 5, 36, 0, 79, 3,  9, 4, 77, 6, 94, 
    6, 59, 0, 79, 3, 58, 1, 60, 5, 29, 2, 15, 7,  6, 4, 70, 8, 82, 
    5, 52, 3, 65, 8, 82, 0, 12, 7, 53, 4, 33, 2, 57, 6, 10, 1, 36, 
    5, 40, 3, 62, 0, 68, 8, 88, 6, 54, 1, 92, 2, 67, 7, 98, 4, 47, 
    0,  9, 5, 53, 1, 83, 8, 64, 2, 19, 4, 76, 3, 87, 6, 20, 7, 79, 
    7, 94, 3, 14, 2, 39, 5, 91, 8, 89, 1, 17, 6, 26, 4,  3, 0,  9, 
    6, 89, 2, 11, 3, 52, 7, 19, 1, 45, 5, 18, 0, 64, 8, 98, 4, 77
  };
  const int q7642[] = {
    9, 9, // Number of jobs and machines
    3, 27, 5, 18, 6, 53, 0, 84, 2,  8, 1, 36, 4, 53, 8,  2, 7, 83, 
    0,  7, 2, 62, 3, 51, 1, 53, 8, 17, 5, 16, 6,  9, 7, 84, 4, 53, 
    2,  7, 1, 78, 7, 51, 3,  9, 4, 30, 5, 85, 0, 71, 8, 64, 6, 33, 
    2, 50, 0, 51, 7, 64, 8, 93, 3, 59, 6, 68, 5, 56, 1, 25, 4, 43, 
    1, 15, 6, 21, 5, 82, 7,  8, 0,  8, 3, 17, 4, 70, 2,  5, 8, 71, 
    3, 70, 7, 95, 4,  5, 8, 40, 6, 10, 0, 94, 2, 17, 1, 67, 5, 77, 
    8, 37, 5, 99, 0, 16, 2, 46, 1, 71, 6, 89, 4, 69, 3, 16, 7, 29, 
    2,  6, 6, 63, 5, 63, 7, 93, 1, 95, 4, 88, 0, 96, 8, 77, 3, 30, 
    7, 32, 8, 58, 2, 94, 5, 63, 1, 59, 4, 54, 3, 22, 6, 46, 0,  9
  };
  const int q7643[] = {
    9, 9, // Number of jobs and machines
    3, 99, 0, 59, 1, 57, 6, 20, 2, 50, 7, 72, 8,  1, 4, 36, 5, 98, 
    6, 63, 0, 37, 8, 41, 2,  6, 3,  6, 5, 41, 4, 28, 1, 64, 7, 85, 
    7, 54, 0,  8, 3, 74, 2, 96, 4, 35, 5, 20, 6, 44, 8, 68, 1,  2, 
    1, 69, 3, 46, 7, 26, 0, 78, 6, 40, 2, 92, 8, 83, 5, 47, 4, 11, 
    3, 88, 8, 80, 6, 31, 7, 99, 1, 90, 0, 80, 5, 90, 2, 28, 4, 90, 
    3, 53, 7, 72, 8, 88, 1, 59, 5, 39, 2, 99, 6, 41, 4, 57, 0, 73, 
    8, 43, 5, 54, 7, 63, 0, 64, 6, 89, 4, 80, 2, 79, 3, 47, 1, 49, 
    0, 54, 3, 25, 6,  2, 7, 45, 1, 50, 2, 82, 8,  6, 5, 86, 4, 74, 
    1, 37, 7, 56, 8, 91, 6, 47, 0, 27, 5, 73, 4, 84, 2, 83, 3, 66
  };
  const int q7644[] = {
    9, 9, // Number of jobs and machines
    5, 84, 1, 36, 6, 95, 8, 51, 0, 73, 2, 73, 3,  9, 4, 58, 7, 56, 
    4, 30, 8, 34, 6, 67, 0, 62, 2, 29, 7, 62, 5, 41, 1, 55, 3, 16, 
    3, 18, 6, 50, 2, 50, 8, 69, 5, 52, 7, 64, 0, 12, 4, 19, 1, 10, 
    4, 31, 1, 90, 8, 98, 3, 44, 0, 29, 7, 59, 2, 68, 5, 54, 6,  7, 
    5, 61, 0, 44, 1, 29, 6, 63, 4, 60, 8, 40, 7, 99, 3, 88, 2, 32, 
    3, 80, 8, 50, 4, 58, 2, 65, 7,  5, 5,  2, 0, 24, 6, 28, 1, 28, 
    4, 87, 6, 10, 8, 61, 3, 45, 2, 99, 5, 20, 7, 50, 1, 69, 0, 59, 
    3, 38, 1, 12, 2, 79, 5, 33, 6, 75, 0, 41, 4,  9, 7, 66, 8, 41, 
    7, 19, 1, 33, 4, 92, 8, 57, 0,  3, 3, 49, 6, 43, 5, 90, 2, 89
  };
  const int q7645[] = {
    9, 9, // Number of jobs and machines
    8, 83, 4, 69, 7, 42, 3,  2, 0, 85, 2, 71, 1, 51, 5, 96, 6, 68, 
    2, 66, 8, 31, 5, 24, 4, 67, 7, 88, 6, 66, 0, 14, 1, 37, 3,  5, 
    1, 72, 7, 38, 0,  6, 2,  2, 5, 79, 3, 86, 8, 45, 4, 93, 6, 95, 
    4, 54, 6, 51, 3, 31, 5, 26, 7, 46, 0, 44, 2, 94, 8, 80, 1, 22, 
    2, 73, 1, 52, 7, 20, 3, 28, 4, 39, 6, 49, 5, 80, 0,  4, 8, 45, 
    1, 49, 2, 13, 7, 73, 8, 16, 0,  3, 5, 98, 6, 94, 4, 16, 3, 33, 
    2, 98, 0, 60, 3, 63, 8, 99, 4, 67, 1, 83, 6, 48, 5, 51, 7, 84, 
    7, 90, 5, 59, 4, 96, 8, 70, 0, 77, 3, 65, 1, 25, 6, 72, 2, 30, 
    2, 88, 1, 71, 3, 87, 0, 59, 6, 86, 4, 95, 8, 67, 5, 22, 7, 23
  };
  const int q7646[] = {
    9, 9, // Number of jobs and machines
    4, 68, 3, 61, 7, 86, 2,  7, 6, 83, 8, 51, 0, 10, 1, 61, 5,  2, 
    1, 18, 2, 35, 7, 55, 5, 76, 4, 67, 8,  4, 6, 26, 0, 94, 3,  9, 
    3, 33, 6, 28, 1, 13, 8,  1, 0, 65, 2, 16, 5, 69, 7,  4, 4, 78, 
    5, 46, 6,  7, 2, 88, 0, 62, 4, 46, 7,  5, 1, 37, 3, 27, 8, 72, 
    0, 89, 4,  5, 7, 18, 2, 68, 6,  9, 5, 96, 8,  1, 3, 93, 1, 74, 
    2, 75, 8, 68, 0, 63, 7, 18, 4, 55, 1, 10, 5,  5, 6, 53, 3, 22, 
    5, 11, 2, 85, 7, 83, 8, 68, 0, 94, 3, 47, 6, 16, 4, 40, 1,  6, 
    0, 11, 1, 82, 2, 79, 4, 16, 3, 12, 7,  3, 6, 51, 5,  3, 8, 60, 
    2, 17, 6, 46, 0, 49, 1, 76, 8, 47, 4, 24, 3, 39, 5,  6, 7,  6
  };
  const int q7647[] = {
    9, 9, // Number of jobs and machines
    7, 28, 4,  4, 3, 48, 6, 84, 0, 23, 5,  8, 1, 40, 2, 74, 8,  7, 
    5, 94, 0, 25, 1,  8, 7, 40, 8, 85, 4, 93, 6, 97, 2, 78, 3, 91, 
    6, 52, 4, 79, 2, 88, 7, 34, 1, 15, 8, 49, 3,  2, 0, 13, 5, 37, 
    7,  4, 4, 53, 2, 29, 6, 75, 8, 21, 5, 19, 1, 20, 0, 60, 3,  5, 
    3, 16, 7, 23, 1,  3, 0, 32, 8, 50, 2, 97, 5, 97, 4, 47, 6, 75, 
    4, 74, 6, 50, 8, 79, 5, 56, 2, 37, 7, 48, 3, 46, 0, 21, 1, 37, 
    5, 18, 7,  9, 8, 36, 2, 88, 3,  4, 1, 90, 4, 25, 0, 50, 6, 49, 
    5, 24, 2, 49, 6, 80, 4, 75, 7, 36, 0, 30, 8, 81, 1, 95, 3, 84, 
    1, 19, 0, 80, 3, 53, 5, 21, 7,  4, 2, 19, 4, 56, 6, 50, 8,  9
  };
  const int q7648[] = {
    9, 9, // Number of jobs and machines
    6, 13, 2, 58, 7, 67, 4, 53, 1, 84, 5, 16, 8, 34, 3, 81, 0, 72, 
    0, 46, 2, 68, 3, 81, 6, 24, 7, 49, 1, 38, 4, 45, 5, 24, 8,  5, 
    4, 27, 8, 41, 1, 15, 3, 33, 7, 47, 6, 86, 0, 66, 2, 21, 5, 41, 
    6, 76, 7, 45, 8, 71, 5, 45, 2, 18, 0, 44, 3, 24, 4, 44, 1, 41, 
    2,  2, 1, 50, 8, 54, 4,  2, 6, 70, 7, 98, 3, 26, 0, 43, 5, 90, 
    4, 43, 8, 52, 2, 43, 6,  4, 7, 79, 1, 22, 5, 94, 3,  8, 0, 80, 
    8, 47, 0, 78, 6, 48, 4, 52, 5, 81, 7, 20, 2, 36, 1, 53, 3, 22, 
    6, 47, 3, 96, 1, 67, 8, 11, 5, 27, 4, 80, 0, 13, 2, 87, 7, 25, 
    8, 49, 0, 87, 4, 86, 3,  3, 7, 54, 6, 31, 2, 66, 1, 64, 5, 57
  };
  const int q7649[] = {
    9, 9, // Number of jobs and machines
    0, 50, 3, 94, 2, 65, 8, 72, 1, 35, 7, 45, 4, 89, 6, 32, 5, 40, 
    4, 61, 6, 91, 0, 91, 7, 10, 1, 37, 3, 17, 8, 64, 5, 99, 2, 50, 
    7, 18, 2, 50, 0, 72, 8, 25, 1, 51, 4, 49, 3,  7, 6, 62, 5, 69, 
    6,  7, 7, 97, 0, 24, 4, 65, 2, 17, 8, 64, 3, 58, 5, 22, 1, 87, 
    6, 59, 1, 92, 4, 74, 2, 96, 5, 16, 3, 16, 8, 38, 0,  5, 7, 51, 
    1, 80, 4, 20, 2, 97, 0, 14, 6, 44, 8, 89, 7, 81, 5, 22, 3, 43, 
    2, 64, 5, 18, 1, 45, 0, 10, 4, 24, 7, 21, 8, 55, 3, 13, 6, 90, 
    5, 56, 6, 47, 3, 94, 8, 71, 2, 47, 4, 97, 0, 30, 1, 75, 7, 49, 
    6, 40, 8, 42, 4, 85, 2, 62, 3, 10, 1, 58, 0, 64, 5, 37, 7, 12
  };
  const int q7650[] = {
    9, 9, // Number of jobs and machines
    6, 87, 7, 35, 0,  8, 8, 84, 2, 55, 4, 93, 1, 92, 3, 65, 5, 70, 
    2, 54, 6, 40, 5, 29, 8, 61, 1, 66, 7, 99, 3,  2, 0,  5, 4, 64, 
    3, 98, 0, 91, 5, 10, 6, 28, 8, 81, 4, 54, 2, 63, 1, 29, 7, 19, 
    2, 18, 1, 93, 7, 36, 6, 17, 8, 92, 3, 34, 5, 27, 4, 59, 0, 43, 
    2, 64, 7, 33, 5, 40, 8, 91, 0, 30, 1, 52, 3, 65, 4, 74, 6, 49, 
    6, 57, 2, 72, 8, 51, 0, 96, 1,  1, 5, 61, 3, 50, 4, 35, 7, 50, 
    7, 66, 0, 57, 1, 47, 2, 79, 3, 43, 5, 10, 4, 65, 6, 66, 8, 75, 
    0, 59, 8, 94, 3, 60, 6, 40, 1, 93, 7, 94, 4, 44, 5, 41, 2, 51, 
    7, 13, 1, 63, 0, 47, 8, 72, 6, 96, 2, 82, 3, 85, 4, 52, 5, 11
  };
  const int q7651[] = {
    9, 9, // Number of jobs and machines
    2, 86, 3, 65, 1, 48, 8, 86, 4, 35, 7, 79, 0, 71, 6, 92, 5,  9, 
    5, 62, 0, 44, 2,  5, 7, 73, 8, 21, 6, 34, 3, 79, 4, 25, 1,  1, 
    2, 88, 8, 68, 4, 17, 5, 25, 0, 88, 6, 43, 7, 76, 3, 29, 1, 42, 
    3, 71, 1, 88, 4, 14, 0, 24, 7, 51, 8, 38, 6, 94, 2, 14, 5, 43, 
    6, 43, 3, 12, 2, 15, 8, 52, 7, 16, 1, 70, 0,  1, 5, 25, 4, 38, 
    3, 51, 4, 65, 8,  9, 5, 60, 6, 73, 0, 12, 2, 85, 7, 49, 1, 70, 
    0, 94, 3, 28, 6, 70, 8, 98, 7, 41, 1, 55, 2, 89, 4, 89, 5, 41, 
    8, 59, 2, 85, 4, 95, 5, 45, 1, 12, 6, 92, 0, 83, 7, 50, 3, 15, 
    4, 35, 7, 60, 3,  2, 1, 95, 6,  9, 2, 13, 8, 17, 0, 75, 5, 81
  };
  const int q7652[] = {
    9, 9, // Number of jobs and machines
    3,  6, 8, 68, 5, 82, 6, 17, 7, 20, 1, 22, 4, 81, 0, 76, 2, 58, 
    0, 85, 2, 88, 5, 68, 4, 14, 8, 24, 1, 98, 6, 90, 3, 48, 7, 21, 
    0, 89, 1, 42, 8, 10, 3, 40, 7, 63, 2, 48, 4, 74, 6, 84, 5, 67, 
    5, 50, 7, 77, 2, 44, 8, 37, 0, 87, 6, 24, 4, 70, 1, 23, 3, 78, 
    3,  1, 4, 77, 6, 53, 0, 91, 2, 59, 5, 69, 8, 47, 7, 36, 1, 80, 
    3, 51, 6, 20, 2, 38, 1,  6, 4, 89, 8, 18, 0,  2, 5, 59, 7, 64, 
    8, 14, 3, 27, 5, 74, 1, 48, 0, 55, 4,  7, 2, 90, 7, 22, 6, 82, 
    6, 97, 5, 92, 3, 37, 7, 35, 4, 12, 2, 30, 1, 44, 0, 47, 8, 37, 
    5, 32, 0, 56, 2, 71, 6, 28, 8, 57, 7, 91, 1, 83, 3, 35, 4, 94
  };
  const int q7653[] = {
    9, 9, // Number of jobs and machines
    4,  1, 5, 35, 8, 72, 3, 88, 0, 26, 1, 77, 2, 84, 7, 91, 6,  5, 
    1, 31, 5, 49, 3, 14, 2,  8, 7, 84, 8, 59, 6, 32, 0, 31, 4, 76, 
    1, 86, 7, 85, 2, 28, 0, 31, 4, 56, 5, 66, 8, 91, 6, 41, 3,  5, 
    3, 13, 5, 82, 8, 19, 2, 76, 4, 81, 0, 95, 1, 57, 7, 83, 6, 58, 
    4, 40, 7, 28, 6, 83, 1, 45, 5, 89, 3, 44, 2, 45, 8, 29, 0, 24, 
    6,  2, 3, 77, 8, 32, 0, 73, 5, 40, 2, 84, 4, 26, 7, 29, 1, 54, 
    1, 30, 2, 57, 8, 46, 5, 76, 6,  9, 3, 74, 4, 64, 0,  7, 7,  8, 
    1,  8, 2, 24, 3, 18, 7, 57, 0, 49, 5, 77, 4, 43, 8, 50, 6, 64, 
    5, 29, 6, 68, 7, 44, 8, 93, 0, 31, 2, 41, 1, 97, 4, 18, 3, 23
  };
  const int q7654[] = {
    9, 9, // Number of jobs and machines
    3, 63, 2, 15, 4, 36, 1, 56, 8, 16, 6, 51, 5, 52, 0, 81, 7, 96, 
    4, 33, 0, 51, 8,  9, 5, 14, 1, 98, 7, 36, 6, 54, 3, 53, 2,  7, 
    1, 14, 4, 56, 8, 68, 0, 68, 3, 22, 5, 66, 6, 14, 7,  8, 2, 83, 
    7, 99, 3, 36, 8, 89, 1,  3, 5, 91, 2, 87, 6, 80, 4, 19, 0, 23, 
    8, 28, 2, 50, 5, 77, 7, 89, 3, 84, 1,  8, 0, 26, 6, 95, 4, 39, 
    4,  1, 6, 21, 3, 82, 7, 87, 5, 73, 0, 82, 2, 69, 1, 49, 8, 64, 
    0, 17, 2, 76, 6, 61, 7, 90, 8, 95, 5,  7, 3, 19, 1, 33, 4, 99, 
    0, 39, 2, 44, 5, 70, 3,  3, 6, 24, 1, 35, 4, 59, 8, 56, 7, 94, 
    3, 72, 6, 76, 5, 45, 4, 10, 7, 30, 1, 35, 8, 74, 0, 80, 2, 39
  };
  const int q7655[] = {
    9, 9, // Number of jobs and machines
    6, 91, 1, 30, 3, 67, 0, 59, 4, 50, 7, 48, 2, 46, 5, 74, 8, 71, 
    6, 35, 5, 73, 2, 32, 8, 48, 1, 68, 3, 79, 0, 57, 4, 56, 7, 21, 
    5,  4, 3, 79, 0, 62, 4, 63, 7, 68, 6, 45, 2,  3, 8, 23, 1, 75, 
    5, 17, 6, 61, 1, 61, 7, 75, 3, 49, 8,  6, 0, 42, 2, 68, 4, 46, 
    3, 35, 7, 45, 4, 27, 0, 30, 5, 58, 1, 37, 6, 88, 2, 52, 8, 40, 
    1, 16, 8, 77, 0, 82, 7, 39, 3, 43, 4, 35, 2, 80, 5, 75, 6, 60, 
    6, 86, 2, 86, 5,  2, 3, 23, 4, 22, 0, 75, 7,  4, 1, 51, 8, 64, 
    4, 75, 5, 86, 2, 82, 7, 15, 0, 30, 1, 24, 8, 59, 3, 12, 6, 52, 
    5, 61, 4, 93, 2, 21, 3, 42, 6, 21, 8, 19, 0, 12, 1, 94, 7, 24
  };
  const int q7656[] = {
    9, 9, // Number of jobs and machines
    8, 67, 1, 48, 4, 37, 5, 64, 6, 68, 3, 38, 2, 87, 0, 20, 7, 16, 
    6, 90, 8,  1, 7, 74, 4, 75, 5, 19, 0, 32, 3, 23, 1, 31, 2, 75, 
    2,  3, 4, 81, 0, 46, 5, 48, 8, 68, 7, 61, 6, 52, 1, 63, 3, 91, 
    4, 53, 6,  8, 8, 99, 2, 73, 7,  9, 1, 44, 3, 12, 5, 54, 0, 93, 
    1, 17, 7, 22, 4, 63, 3, 13, 5, 18, 0, 63, 6, 57, 2, 42, 8,  9, 
    0,  2, 7, 82, 4, 45, 5, 30, 8, 34, 2, 76, 1, 52, 3, 39, 6, 74, 
    8, 42, 5, 67, 6, 18, 0, 34, 7, 76, 1, 88, 4, 25, 3, 93, 2, 39, 
    3, 85, 5, 39, 2, 35, 4,  9, 0, 61, 7, 91, 8, 82, 1, 74, 6, 74, 
    2, 41, 8, 17, 5, 87, 1, 33, 6, 58, 7, 35, 3, 82, 4, 23, 0, 84
  };
  const int q7657[] = {
    9, 9, // Number of jobs and machines
    0, 29, 4, 27, 1, 15, 7, 60, 6, 55, 8, 51, 2, 58, 3, 36, 5, 52, 
    6, 34, 0, 68, 8, 88, 1, 18, 4, 37, 7, 84, 3, 38, 5, 80, 2, 78, 
    1, 80, 4, 75, 6, 86, 5, 12, 3, 97, 0, 21, 7, 63, 8,  4, 2, 87, 
    5, 93, 6, 85, 7, 73, 4, 38, 0, 23, 3, 60, 8, 22, 2, 80, 1,  9, 
    3,  2, 6, 33, 5, 43, 7, 27, 0, 36, 2, 87, 4, 68, 1, 44, 8, 46, 
    6, 80, 1, 90, 2, 70, 0, 86, 4, 38, 7,  9, 3,  1, 5, 75, 8, 58, 
    1, 47, 2, 89, 4, 63, 0, 74, 7, 54, 3, 99, 5, 44, 8, 58, 6, 97, 
    0,  6, 5, 92, 6, 91, 3, 25, 2, 30, 8, 96, 7, 86, 1, 44, 4, 86, 
    8, 45, 1, 37, 5, 66, 3, 73, 4, 60, 7, 51, 0, 71, 6,  9, 2, 16
  };
  const int q7658[] = {
    9, 9, // Number of jobs and machines
    6, 20, 8, 44, 7,  6, 3, 80, 5, 51, 0, 60, 4, 50, 1, 31, 2, 79, 
    3, 16, 5, 80, 1, 83, 6, 10, 7, 16, 4, 88, 0, 60, 2, 48, 8, 50, 
    6, 42, 0,  8, 8, 72, 2,  1, 4, 69, 1, 45, 5,  1, 3,  8, 7, 76, 
    7, 45, 4, 16, 2, 26, 3, 57, 6, 36, 1, 18, 0, 50, 5, 30, 8, 37, 
    7, 21, 2, 93, 4, 42, 6, 49, 3, 64, 0,  9, 1, 87, 8, 50, 5, 80, 
    4, 45, 5, 19, 2,  2, 0,  6, 8, 61, 3, 75, 1, 36, 7, 43, 6, 83, 
    2, 34, 1, 92, 3, 81, 7, 55, 5, 94, 8, 76, 4, 59, 6,  5, 0, 24, 
    5, 12, 2, 86, 7, 81, 1, 92, 6, 99, 8, 92, 4, 80, 0, 36, 3, 71, 
    3, 19, 2, 48, 6, 46, 8, 34, 7,  7, 1, 49, 5, 80, 4,  7, 0, 17
  };
  const int q7659[] = {
    9, 9, // Number of jobs and machines
    6, 65, 8, 57, 0,  8, 1, 74, 4, 82, 5, 76, 2,  2, 3, 66, 7, 79, 
    6, 38, 7, 60, 3, 81, 1, 23, 8, 71, 0, 96, 2, 30, 5, 95, 4, 89, 
    3, 81, 2,  3, 5, 86, 6,  5, 4, 35, 7, 77, 8, 96, 0, 15, 1, 67, 
    3, 74, 0, 78, 1, 39, 5, 31, 2, 23, 4, 23, 7, 44, 6, 18, 8, 33, 
    8, 98, 0, 75, 6, 22, 1, 13, 5, 13, 3, 57, 2, 19, 7, 28, 4, 96, 
    6, 72, 5, 29, 7, 21, 2, 98, 1, 39, 0, 94, 3, 43, 8, 11, 4, 14, 
    7, 13, 3, 64, 2, 38, 8, 60, 6, 84, 5,  1, 1, 30, 4, 43, 0, 68, 
    8, 15, 1, 53, 2, 53, 6, 96, 5, 78, 4, 34, 3,  5, 7, 96, 0, 56, 
    7,  3, 3, 20, 4, 43, 5, 63, 6, 92, 1,  6, 0, 96, 8, 41, 2, 14
  };
  const int q7660[] = {
    9, 9, // Number of jobs and machines
    3, 68, 1, 31, 5, 34, 2, 79, 6, 33, 7, 89, 8, 35, 0, 93, 4, 12, 
    5, 48, 6, 43, 7, 60, 8, 20, 2, 69, 0, 44, 3, 88, 1, 90, 4, 69, 
    3, 30, 0, 29, 8, 82, 4, 52, 1, 48, 6,  2, 2, 71, 7, 98, 5, 64, 
    0, 49, 2, 29, 5, 47, 8, 20, 7, 63, 3, 99, 6, 26, 1, 16, 4, 42, 
    7, 20, 3, 68, 4, 74, 2, 60, 5, 22, 8,  5, 1, 45, 6, 18, 0, 80, 
    6, 90, 0,  8, 7, 20, 2, 37, 3, 22, 8, 53, 5, 76, 1, 80, 4, 18, 
    4, 12, 6, 17, 5,  1, 1, 28, 7,  3, 0, 49, 2,  5, 8, 97, 3, 98, 
    7, 43, 1, 50, 4, 77, 6, 69, 8, 95, 3, 90, 5, 22, 0, 32, 2, 93, 
    0, 82, 2, 80, 1, 13, 8, 71, 5,  5, 7,  4, 3, 62, 4, 58, 6,  8
  };
  const int q7661[] = {
    9, 9, // Number of jobs and machines
    0, 20, 6, 90, 1,  5, 3, 64, 2, 86, 4, 60, 5, 80, 7, 45, 8, 36, 
    3, 40, 5, 51, 7, 10, 2, 29, 0, 61, 8, 97, 4, 35, 6, 40, 1, 58, 
    8, 56, 7, 67, 4, 62, 5,  8, 3, 75, 6, 63, 0, 50, 2, 16, 1, 19, 
    3, 12, 5,  7, 0, 75, 8, 52, 2, 71, 4, 65, 6, 39, 7,  5, 1, 92, 
    1, 52, 0, 72, 5, 52, 8, 47, 6, 34, 3,  4, 4,  8, 2, 44, 7, 73, 
    5, 28, 8, 92, 7, 14, 0, 92, 2,  7, 3, 37, 4, 84, 1, 41, 6, 82, 
    3, 97, 0, 97, 2, 78, 5,  8, 6,  2, 7, 79, 4, 35, 1, 81, 8,  7, 
    0,  9, 8, 46, 1,  8, 3, 94, 4, 95, 5, 10, 6, 83, 7, 60, 2, 38, 
    0, 82, 2, 37, 7, 86, 8, 17, 4, 67, 1, 54, 3, 50, 5, 94, 6, 70
  };
  const int q7662[] = {
    9, 9, // Number of jobs and machines
    1, 46, 6, 30, 3, 14, 5, 17, 7, 41, 8, 30, 2, 38, 4, 77, 0, 69, 
    1, 87, 8, 60, 5, 15, 6, 39, 7, 46, 2, 65, 4, 16, 0, 98, 3, 81, 
    6, 41, 0, 41, 3, 75, 1, 82, 2, 83, 8, 38, 5,  6, 7, 63, 4, 62, 
    1, 11, 6, 92, 2, 44, 7, 92, 3, 37, 5, 43, 0, 53, 8, 97, 4, 92, 
    6,  5, 7, 89, 3, 86, 0, 62, 1, 78, 5, 70, 8, 65, 2, 84, 4, 82, 
    7, 13, 6, 18, 0, 34, 3, 49, 1, 23, 8, 85, 5, 13, 4, 19, 2, 14, 
    0, 58, 2, 41, 3, 69, 7, 81, 8, 93, 6, 75, 4, 26, 5, 65, 1,  1, 
    1, 25, 0,  5, 2, 56, 3, 53, 7, 72, 6, 14, 4, 26, 5, 60, 8, 92, 
    7,  2, 3, 90, 0, 83, 1, 26, 4, 80, 5, 24, 2, 93, 6, 61, 8, 10
  };
  const int q7663[] = {
    9, 9, // Number of jobs and machines
    8, 63, 1, 82, 3,  9, 6, 12, 4, 60, 5, 42, 2, 42, 0, 78, 7, 98, 
    1, 89, 5, 53, 2, 77, 8, 16, 4,  8, 0, 71, 3, 98, 7, 98, 6, 71, 
    8, 22, 0, 58, 4, 23, 7, 33, 3, 71, 6, 86, 2, 24, 5, 35, 1, 23, 
    2, 12, 1, 85, 6, 55, 8, 23, 5, 81, 3, 59, 7, 17, 4, 12, 0, 31, 
    6, 56, 3, 76, 5, 33, 7, 73, 4, 64, 0, 13, 2, 21, 8, 35, 1, 59, 
    3, 94, 6, 87, 1, 45, 7, 25, 0, 13, 2, 76, 5, 40, 4, 60, 8, 69, 
    7, 72, 3, 97, 8, 90, 5, 82, 6, 70, 0, 36, 4, 50, 2, 48, 1, 10, 
    2, 14, 7, 86, 0,  9, 4, 99, 3, 47, 8, 73, 5, 47, 1, 33, 6,  6, 
    1, 93, 3, 35, 4, 38, 2, 88, 7, 20, 6, 66, 0, 98, 8, 73, 5, 55
  };
  const int q7664[] = {
    9, 9, // Number of jobs and machines
    1, 78, 2, 13, 7, 68, 5, 33, 6, 19, 4,  6, 3, 40, 8, 32, 0, 62, 
    5,  5, 8, 31, 0, 70, 4, 24, 3, 38, 1, 73, 6,  9, 7, 92, 2, 22, 
    3, 28, 6, 99, 8, 65, 7, 22, 5, 62, 0, 50, 2, 15, 1, 87, 4, 32, 
    3, 42, 7, 91, 1, 87, 4, 38, 6, 51, 2, 99, 0, 84, 5, 90, 8, 10, 
    6, 97, 5, 84, 3, 42, 1, 18, 2, 24, 0, 14, 8, 99, 4, 21, 7, 50, 
    8, 68, 3, 44, 5, 46, 6, 87, 4, 82, 7, 88, 1, 90, 2, 98, 0, 87, 
    5, 29, 0, 27, 2, 90, 4, 31, 6, 83, 1, 21, 3, 73, 8, 62, 7, 12, 
    6, 27, 7, 55, 8, 32, 2, 25, 5, 39, 3, 44, 0,  4, 4,  6, 1, 76, 
    8, 23, 4, 63, 3, 35, 5, 88, 7, 52, 0, 56, 6, 57, 1, 50, 2, 63
  };
  const int q7665[] = {
    9, 9, // Number of jobs and machines
    2, 59, 5, 22, 8, 85, 4, 64, 6, 38, 0, 49, 7, 36, 1, 49, 3, 87, 
    8, 33, 4, 75, 2, 98, 5, 67, 6,  2, 3, 79, 7, 67, 0,  5, 1, 35, 
    7, 49, 2, 49, 8, 29, 3, 99, 6, 37, 5, 86, 1,  6, 0,  9, 4,  9, 
    2, 61, 6, 95, 8, 87, 0, 51, 1, 90, 4, 80, 7, 30, 3, 56, 5, 66, 
    5, 20, 4, 24, 0, 60, 1, 42, 3, 82, 6, 83, 2, 58, 7, 99, 8, 23, 
    4, 93, 5,  7, 8, 99, 0, 94, 6, 17, 2, 30, 3, 88, 7, 17, 1, 58, 
    1, 99, 8, 91, 4,  3, 6, 30, 0, 16, 7, 65, 3, 61, 2, 63, 5, 13, 
    4, 36, 8, 22, 3, 18, 0,  8, 6, 11, 1, 62, 2, 19, 7, 13, 5, 49, 
    5, 72, 3, 13, 1, 96, 0, 24, 4,  5, 6, 39, 7, 65, 8, 72, 2, 82
  };
  const int q7666[] = {
    9, 9, // Number of jobs and machines
    5, 80, 6, 12, 4, 91, 3, 15, 1, 72, 7, 78, 8, 96, 0, 73, 2, 27, 
    5, 99, 8, 81, 7, 70, 3, 82, 2,  6, 4, 81, 0, 52, 6, 71, 1, 49, 
    8, 74, 5, 86, 3, 35, 6, 62, 4, 35, 7, 79, 1, 38, 0, 42, 2, 33, 
    5, 92, 6, 76, 2, 97, 0, 38, 8,  5, 3,  1, 1, 26, 7, 32, 4,  7, 
    2, 40, 1, 37, 5, 96, 6, 33, 4, 76, 8, 98, 0, 58, 3, 91, 7, 95, 
    3, 28, 4, 45, 6, 67, 0, 86, 8,  7, 7,  6, 1, 48, 2, 80, 5,  9, 
    1, 92, 4, 23, 7, 25, 2, 61, 8, 66, 3, 52, 6, 84, 0, 68, 5, 67, 
    0, 43, 4, 73, 2, 47, 7, 29, 5, 46, 3, 30, 6, 75, 1, 10, 8,  5, 
    0,  5, 8, 66, 3,  9, 4, 12, 6, 65, 2, 36, 7, 38, 1, 14, 5, 60
  };
  const int q7667[] = {
    9, 9, // Number of jobs and machines
    7, 32, 2, 34, 5, 49, 8,  7, 1, 52, 3, 35, 0,  1, 6, 48, 4, 68, 
    8, 33, 7,  6, 5, 41, 3, 96, 4,  1, 2, 92, 1,  9, 0, 11, 6, 94, 
    7,  8, 3, 20, 4, 64, 6, 75, 0, 78, 2, 41, 8, 52, 1, 49, 5, 31, 
    1, 20, 2, 73, 7,  4, 4, 39, 3, 12, 8,  2, 6, 25, 0, 97, 5,  8, 
    1, 59, 3, 96, 5, 34, 8, 27, 6, 60, 0, 36, 2, 57, 7, 32, 4, 68, 
    7, 77, 1, 36, 8, 11, 5, 85, 0, 66, 3,  3, 4, 88, 2, 12, 6, 66, 
    5, 73, 1, 12, 4, 20, 8, 86, 6, 65, 7, 42, 0, 72, 3, 31, 2, 87, 
    8, 10, 5, 50, 6, 53, 7, 29, 2, 41, 3, 11, 1, 59, 0, 20, 4, 62, 
    6, 82, 7, 31, 3, 92, 8, 69, 0, 72, 4, 45, 1,  1, 2, 26, 5, 62
  };
  const int q7668[] = {
    9, 9, // Number of jobs and machines
    2, 37, 3, 91, 1, 48, 0, 40, 6, 85, 5, 89, 4, 72, 7, 63, 8, 29, 
    7, 56, 6, 72, 8, 73, 0, 17, 4, 49, 1, 76, 2, 97, 5, 63, 3, 94, 
    8,  7, 0, 90, 1, 31, 7, 47, 2, 34, 3, 72, 5, 61, 4, 81, 6, 40, 
    5, 26, 6, 38, 4, 91, 0, 10, 1, 20, 7, 36, 8, 85, 2, 66, 3, 12, 
    4, 68, 2, 14, 5, 46, 6, 90, 3, 62, 8, 28, 0, 37, 1, 24, 7, 30, 
    6, 53, 3,  5, 2, 13, 7, 67, 4, 68, 0, 14, 5, 19, 8, 28, 1, 16, 
    5,  6, 0, 45, 4, 73, 3, 25, 8, 96, 2, 74, 7, 82, 1, 37, 6,  6, 
    6, 86, 2, 43, 7, 84, 4, 11, 5, 93, 8, 19, 1, 19, 3, 57, 0, 53, 
    7, 55, 5, 75, 6, 64, 3, 68, 8, 53, 2,  2, 1, 18, 0, 37, 4, 16
  };
  const int q7669[] = {
    9, 9, // Number of jobs and machines
    0, 73, 6, 69, 7, 78, 3, 46, 5, 50, 4, 44, 2, 16, 1, 51, 8, 89, 
    6, 18, 7, 95, 5, 45, 0, 63, 3, 57, 8, 58, 2, 66, 1, 62, 4, 72, 
    0, 56, 5, 76, 1, 95, 4, 15, 8, 46, 7, 21, 6, 14, 2, 55, 3, 78, 
    3, 23, 2, 81, 4,  2, 5, 13, 0, 96, 6, 44, 8,  9, 1, 73, 7, 53, 
    2, 23, 5, 89, 1,  5, 8, 49, 6, 52, 3,  2, 4, 94, 7, 50, 0, 10, 
    6, 75, 4, 61, 2,  3, 1, 58, 7, 42, 3,  4, 8, 42, 0, 57, 5,  9, 
    8, 26, 1, 21, 0, 77, 4, 86, 6, 61, 5, 84, 3, 84, 7, 70, 2, 34, 
    7, 91, 2, 60, 6, 98, 5, 68, 4, 38, 3,  7, 0, 66, 8, 49, 1, 75, 
    3, 54, 2, 34, 6, 47, 7,  7, 1, 82, 4, 37, 5, 87, 0, 80, 8, 76
  };
  const int q7670[] = {
    9, 9, // Number of jobs and machines
    0, 83, 1, 74, 5, 96, 6, 67, 8, 96, 7, 41, 3, 84, 2, 15, 4, 94, 
    7, 64, 2,  1, 5, 10, 6, 43, 4, 68, 0, 13, 1,  5, 3, 75, 8,  1, 
    0, 93, 4, 46, 1, 49, 7, 89, 3, 47, 5, 22, 8, 39, 2, 89, 6, 81, 
    3, 55, 6, 43, 4, 12, 0, 28, 5, 78, 7, 30, 8,  1, 1, 51, 2, 60, 
    6, 35, 1, 35, 8, 98, 4, 13, 2, 46, 5, 43, 3, 45, 7, 80, 0, 32, 
    4, 40, 6, 32, 2, 81, 0, 48, 5, 25, 3, 30, 1, 21, 8, 11, 7,  8, 
    4, 99, 0, 99, 5, 94, 6, 34, 7, 74, 3, 49, 2, 59, 8, 94, 1, 98, 
    1, 81, 6, 61, 7,  8, 5, 43, 4, 62, 2, 63, 3, 44, 8, 30, 0, 31, 
    7, 89, 2, 22, 4, 51, 3, 36, 8, 99, 1, 52, 6, 83, 0, 72, 5, 49
  };
  const int q7671[] = {
    9, 9, // Number of jobs and machines
    2, 81, 4, 54, 3, 55, 7, 74, 5, 77, 1, 38, 6, 44, 8, 19, 0, 19, 
    6, 67, 5,  7, 1, 20, 3, 81, 4, 18, 7, 43, 0, 37, 8, 25, 2, 44, 
    4, 34, 8, 71, 7, 67, 0, 19, 1, 67, 6, 55, 2, 70, 5, 52, 3, 64, 
    5, 26, 2, 59, 8, 80, 7, 38, 0, 10, 6,  8, 4, 37, 1, 42, 3, 56, 
    7, 26, 0, 33, 4, 74, 2, 58, 5, 33, 3,  6, 1, 73, 8, 20, 6, 14, 
    2, 94, 8, 83, 0,  1, 4, 69, 7, 92, 3, 61, 6, 20, 1, 49, 5, 83, 
    2, 57, 0, 42, 8, 48, 6, 86, 7, 77, 4, 27, 3, 19, 5,  5, 1, 86, 
    4, 65, 0, 91, 1, 58, 3, 91, 2, 12, 8, 29, 7, 23, 6, 72, 5, 21, 
    8, 27, 6, 45, 7, 76, 0, 85, 4, 62, 3, 69, 5, 71, 1, 86, 2, 92
  };
  const int q7672[] = {
    9, 9, // Number of jobs and machines
    5,  2, 8,  8, 7, 56, 3, 45, 4, 13, 0, 33, 2, 28, 1, 48, 6, 28, 
    1, 52, 5, 79, 0, 36, 4, 53, 7, 94, 2, 33, 8, 22, 3, 81, 6, 36, 
    6, 40, 2, 17, 8, 94, 1, 99, 4, 79, 3, 37, 0, 37, 7, 47, 5, 85, 
    0, 31, 2, 53, 5,  2, 4, 74, 8, 78, 3, 60, 6, 60, 1, 64, 7, 89, 
    0,  6, 7,  5, 4, 38, 5, 15, 6, 80, 1, 22, 8, 69, 2, 24, 3, 82, 
    6, 21, 4, 15, 1, 82, 7, 58, 2, 95, 0, 75, 5, 40, 3, 19, 8, 63, 
    2, 21, 8, 47, 1, 49, 3, 90, 7, 97, 6, 42, 5, 72, 4, 78, 0, 74, 
    7, 57, 2,  1, 3, 55, 4, 29, 6, 61, 0, 25, 8, 64, 1, 17, 5, 93, 
    2, 59, 0, 10, 5, 47, 1, 86, 6, 92, 4, 47, 7, 16, 3, 89, 8, 45
  };
  const int q7673[] = {
    9, 9, // Number of jobs and machines
    3, 56, 2, 38, 7, 20, 8, 63, 0, 16, 1, 67, 4, 27, 6, 13, 5, 88, 
    2, 13, 1, 28, 0, 74, 3, 88, 4, 42, 5, 81, 8, 70, 6, 72, 7, 82, 
    0, 50, 8, 24, 7, 60, 6, 53, 3, 58, 1, 89, 4, 23, 2,  7, 5, 61, 
    8, 64, 6, 27, 1, 86, 0,  1, 4, 81, 2, 32, 7, 95, 5, 87, 3, 23, 
    7, 97, 8, 25, 3, 21, 6, 71, 5, 56, 2, 53, 0, 92, 4, 38, 1, 90, 
    7, 27, 1, 91, 4, 49, 8,  2, 3, 79, 5, 94, 0, 57, 2, 85, 6,  1, 
    6, 49, 0, 14, 8, 59, 7,  4, 3, 53, 2, 73, 5, 53, 1, 50, 4, 64, 
    2, 25, 8, 78, 4, 95, 6, 14, 3, 54, 5, 49, 7, 56, 1, 83, 0, 95, 
    2, 30, 5, 31, 4, 50, 0, 96, 6, 17, 3, 42, 1, 26, 7, 29, 8, 19
  };
  const int q7674[] = {
    9, 9, // Number of jobs and machines
    7, 26, 3, 85, 4, 40, 5, 31, 2, 36, 8, 67, 0, 13, 6, 85, 1, 47, 
    8, 49, 5, 10, 1, 36, 4, 58, 7, 80, 6, 76, 0, 42, 2, 96, 3, 81, 
    6, 87, 7, 65, 5, 79, 1,  9, 4, 61, 8, 89, 0, 59, 2, 62, 3, 60, 
    3, 57, 8, 33, 5, 44, 2, 20, 1, 10, 6, 24, 4, 78, 7, 57, 0, 70, 
    1, 38, 8, 40, 7, 61, 5, 31, 6, 84, 2, 50, 4, 47, 3, 78, 0, 93, 
    2, 22, 5, 77, 7, 95, 1, 24, 0,  8, 8, 94, 4, 27, 3, 34, 6, 20, 
    8, 23, 5, 90, 6,  8, 4, 44, 3, 47, 7, 43, 2, 47, 0, 74, 1, 31, 
    1, 82, 8, 45, 7, 94, 6, 84, 5,  1, 3, 29, 0, 74, 4, 24, 2, 22, 
    4, 97, 2, 91, 8, 22, 1, 68, 3, 71, 6, 72, 5, 67, 0, 10, 7, 95
  };
  const int q7675[] = {
    9, 9, // Number of jobs and machines
    2, 54, 8, 65, 4, 22, 6, 23, 7, 86, 0, 12, 5, 27, 1, 10, 3, 20, 
    2, 79, 0, 26, 1, 58, 5, 63, 6, 23, 3, 74, 4, 71, 7, 31, 8, 95, 
    6, 80, 8, 18, 4, 62, 2, 86, 7, 89, 0, 60, 3, 27, 5, 41, 1, 59, 
    0, 13, 6, 15, 7, 63, 4, 19, 2, 24, 3, 56, 8, 18, 1, 86, 5, 45, 
    4, 79, 3, 54, 0, 62, 5, 54, 6, 34, 7, 39, 1, 55, 2, 63, 8, 56, 
    6, 14, 1, 34, 0, 54, 7, 44, 8, 78, 3, 76, 4, 55, 5, 29, 2, 24, 
    5, 75, 3, 94, 6, 70, 1, 87, 4, 57, 2, 77, 0,  1, 7, 56, 8, 17, 
    6, 76, 0, 30, 1, 92, 4, 81, 3, 14, 2, 64, 7, 80, 5, 46, 8, 95, 
    8, 85, 0, 72, 3, 23, 7, 19, 1, 80, 6, 62, 4, 50, 5, 79, 2, 31
  };
  const int q7676[] = {
    9, 9, // Number of jobs and machines
    3, 19, 7, 65, 4, 19, 2, 83, 5, 84, 6, 29, 1, 55, 8, 91, 0, 45, 
    1,  7, 5, 62, 2, 71, 0, 30, 8, 96, 6, 60, 7, 71, 4, 11, 3, 61, 
    5, 34, 0, 75, 8, 32, 6,  5, 7, 75, 2, 13, 1, 84, 3,  7, 4,  8, 
    1, 85, 4, 46, 7,  8, 2, 54, 6, 82, 8,  5, 3, 66, 5, 86, 0, 90, 
    4, 83, 0, 37, 1, 76, 3, 63, 7, 18, 5, 97, 8, 39, 2, 29, 6, 70, 
    8, 26, 3, 97, 4, 15, 1, 59, 5, 34, 0, 19, 6,  2, 7,  1, 2, 73, 
    2, 46, 3, 69, 1, 75, 0, 33, 8, 74, 7, 90, 6, 36, 4, 79, 5, 12, 
    1, 62, 0, 40, 5, 83, 2, 91, 3, 11, 6, 16, 4, 96, 7, 30, 8, 46, 
    1, 60, 3, 41, 2, 47, 4, 23, 7, 74, 8,  5, 5, 71, 0, 80, 6, 12
  };
  const int q7677[] = {
    9, 9, // Number of jobs and machines
    8, 78, 4, 77, 1, 71, 3, 12, 2, 56, 7, 22, 6, 93, 0, 49, 5, 63, 
    2, 44, 6, 39, 8, 30, 0, 97, 5, 40, 1, 54, 3, 37, 4, 99, 7, 74, 
    8, 39, 7, 58, 6, 70, 4, 87, 5, 25, 1, 27, 3, 25, 2, 48, 0, 64, 
    5, 91, 2, 31, 0,  5, 1, 35, 6, 73, 7, 23, 8, 47, 4, 89, 3, 93, 
    3, 89, 1,  7, 7, 93, 5, 55, 2, 30, 8, 81, 4, 59, 6, 96, 0, 95, 
    0, 18, 1, 22, 6, 99, 7, 97, 8,  9, 5, 87, 3, 15, 2, 80, 4,  3, 
    5, 40, 1, 79, 6, 42, 3, 93, 4, 20, 2, 55, 8, 65, 0, 81, 7, 16, 
    1, 88, 3, 90, 8, 64, 5, 30, 4, 53, 0, 55, 6, 99, 7, 52, 2, 33, 
    4, 70, 6, 62, 2, 76, 3, 17, 5, 34, 0, 22, 7, 54, 8, 32, 1, 57
  };
  const int q7678[] = {
    9, 9, // Number of jobs and machines
    4, 21, 1, 33, 3, 28, 2, 95, 6,  1, 8, 50, 5, 39, 7, 25, 0, 26, 
    2,  3, 5, 63, 4, 84, 1, 75, 8, 50, 0,  6, 3, 96, 6, 32, 7, 66, 
    7,  4, 8, 10, 6, 27, 0, 59, 2, 73, 1, 47, 5,  6, 4, 58, 3,  1, 
    8, 13, 5, 15, 7, 54, 6, 47, 0, 12, 1, 98, 3, 53, 4, 45, 2, 41, 
    6, 71, 1, 53, 3, 30, 5, 55, 8, 68, 0, 54, 2, 49, 4, 43, 7, 30, 
    7, 85, 6, 12, 0, 83, 2, 95, 1, 10, 4, 23, 8, 69, 5, 69, 3, 74, 
    0, 16, 3, 65, 1, 49, 2, 63, 4, 40, 5, 74, 7, 30, 6, 42, 8, 27, 
    2, 59, 4, 54, 0,  6, 1, 42, 6, 42, 3, 70, 8, 33, 7,  3, 5, 51, 
    5, 52, 8,  2, 1,  4, 4, 60, 2, 63, 6, 12, 7, 69, 3,  7, 0, 84
  };
  const int q7679[] = {
    9, 9, // Number of jobs and machines
    5, 61, 0, 36, 4, 52, 3, 90, 2, 25, 7,  2, 1,  4, 8, 99, 6, 42, 
    6, 76, 8, 52, 5,  4, 0, 37, 3, 72, 2, 24, 1, 40, 4, 33, 7, 30, 
    1, 46, 7, 68, 0, 52, 2,  7, 5, 45, 3, 72, 6, 65, 4, 80, 8, 22, 
    7, 32, 5, 98, 1, 67, 6, 77, 0, 32, 3, 80, 2, 47, 8, 56, 4, 96, 
    3, 11, 5, 98, 0, 73, 2, 59, 1, 54, 4, 82, 6, 16, 8, 94, 7, 49, 
    8, 96, 3, 19, 7, 52, 1, 82, 6, 12, 5, 72, 0, 68, 2,  7, 4, 89, 
    6, 85, 1, 39, 5, 71, 8, 86, 4, 18, 7, 78, 3, 17, 2, 56, 0, 12, 
    3, 12, 0, 95, 1, 63, 7, 76, 2, 12, 4, 68, 8, 28, 6, 15, 5, 46, 
    7, 44, 3,  2, 8, 95, 1, 60, 6, 20, 0, 88, 4, 12, 2, 92, 5, 78
  };
  const int q7680[] = {
    9, 9, // Number of jobs and machines
    7, 58, 5, 42, 4, 82, 0, 67, 3, 25, 6, 39, 1, 12, 8, 59, 2, 70, 
    2, 89, 5, 16, 6, 16, 3, 11, 7, 18, 8, 75, 4, 83, 0, 27, 1, 16, 
    8, 97, 4, 44, 0, 99, 5, 33, 2,  4, 1, 83, 6, 27, 7,  2, 3, 27, 
    1, 96, 2, 33, 6, 86, 8, 86, 3, 74, 4, 97, 0,  8, 5, 60, 7, 29, 
    1,  8, 2, 96, 4, 83, 6, 49, 3, 98, 5, 98, 0, 40, 7, 11, 8,  5, 
    7, 52, 8, 37, 3, 85, 0, 26, 5, 32, 6, 12, 1, 39, 4, 73, 2, 90, 
    7, 68, 8, 85, 1, 10, 5, 82, 4, 49, 0, 35, 3, 70, 6,  2, 2, 77, 
    5, 15, 7, 22, 1, 83, 3,  6, 0, 26, 4, 72, 6, 44, 2, 48, 8, 44, 
    0, 78, 1, 91, 3, 33, 6, 65, 8,  6, 7, 73, 5, 55, 2, 76, 4,  7
  };
  const int q7681[] = {
    9, 9, // Number of jobs and machines
    8, 57, 0, 99, 7, 23, 3, 84, 6, 42, 2, 89, 1, 76, 5, 45, 4, 16, 
    8, 40, 3, 33, 7, 28, 5, 20, 2, 67, 0, 25, 1, 65, 6, 28, 4, 47, 
    2,  5, 0,  2, 5, 50, 4, 23, 8, 14, 7, 78, 6, 73, 3, 89, 1, 98, 
    0, 80, 3, 41, 7, 43, 6, 61, 4, 22, 1, 73, 2, 79, 8, 12, 5, 87, 
    3, 55, 1, 36, 8, 24, 2, 73, 0, 96, 6,  9, 7, 38, 4, 27, 5, 85, 
    2, 31, 6, 37, 8,  7, 3, 71, 1, 79, 4, 11, 5, 59, 7, 89, 0, 11, 
    0, 42, 3,  5, 6, 19, 4, 92, 2, 32, 5,  1, 7, 55, 1, 17, 8, 76, 
    7, 91, 3, 49, 2, 88, 5, 23, 1, 24, 4, 19, 0, 99, 6, 33, 8, 10, 
    1, 97, 4, 98, 7, 45, 5, 88, 0, 76, 6, 20, 8, 46, 2,  2, 3, 63
  };
  const int q7682[] = {
    9, 9, // Number of jobs and machines
    4, 22, 6, 19, 7, 19, 5,  9, 8, 45, 2, 11, 1, 10, 0, 74, 3, 94, 
    2, 24, 8, 68, 0, 53, 6, 94, 4, 60, 1, 41, 5, 61, 3, 58, 7, 13, 
    3, 74, 6,  1, 2, 18, 4, 28, 5,  1, 8, 74, 0, 44, 7, 50, 1, 11, 
    0, 76, 4, 35, 7, 89, 1, 64, 2, 44, 5, 94, 3, 13, 8, 13, 6, 91, 
    2, 67, 0, 85, 3, 36, 7, 19, 4, 15, 8, 35, 1, 35, 6, 28, 5,  3, 
    6,  1, 3, 26, 8, 55, 0, 22, 7, 53, 5, 10, 2, 53, 1, 75, 4, 29, 
    4, 86, 3, 70, 0,  4, 7, 58, 5, 45, 2, 10, 1, 82, 6, 73, 8, 69, 
    2, 69, 5, 29, 1, 65, 8, 98, 7, 30, 4, 24, 6,  3, 3, 45, 0, 94, 
    0, 42, 8, 55, 7, 38, 6, 93, 5, 41, 4, 88, 2, 77, 3, 28, 1, 17
  };
  const int q7683[] = {
    9, 9, // Number of jobs and machines
    3, 17, 5, 45, 2, 44, 1, 22, 0, 53, 8, 17, 6, 65, 4, 31, 7, 27, 
    1, 90, 6, 44, 3, 85, 7, 45, 0, 27, 2, 65, 4,  4, 8, 18, 5, 32, 
    7, 24, 1, 85, 0,  6, 2, 50, 8, 98, 6, 69, 5,  9, 3,  7, 4, 63, 
    6, 76, 4, 67, 0, 33, 2, 39, 5, 87, 8, 68, 1, 98, 3, 41, 7,  4, 
    7, 90, 6, 67, 8, 47, 3, 12, 4, 27, 1,  5, 2, 90, 0, 17, 5, 45, 
    3, 46, 5, 93, 6,  7, 1,  2, 7, 32, 0, 33, 4, 95, 8, 30, 2, 91, 
    2, 45, 1, 20, 6, 59, 5, 56, 4, 87, 8, 72, 3, 85, 0, 31, 7, 16, 
    2, 56, 5, 68, 6, 93, 8, 21, 4, 99, 3, 21, 0,  4, 7, 53, 1, 52, 
    5, 52, 3, 20, 2, 75, 6, 90, 4, 54, 1, 63, 0, 22, 8, 31, 7, 85
  };
  const int q7684[] = {
    9, 9, // Number of jobs and machines
    4, 59, 6, 81, 5,  9, 3, 58, 7, 37, 8, 80, 1, 80, 2, 69, 0, 16, 
    3, 46, 4, 56, 5, 49, 0, 64, 7, 77, 2, 42, 8, 58, 1, 50, 6, 98, 
    7, 51, 8, 76, 0, 23, 2, 75, 6, 68, 1, 79, 4, 93, 3, 38, 5, 57, 
    3, 46, 1, 94, 8, 17, 5, 35, 4, 42, 2, 63, 6, 70, 7, 76, 0, 59, 
    1, 95, 7, 17, 5, 50, 3, 35, 2, 20, 8, 73, 4, 81, 0, 25, 6, 65, 
    6, 93, 1, 63, 5, 37, 8, 34, 4, 49, 2, 77, 3, 35, 7, 29, 0, 89, 
    7, 13, 8, 55, 2, 97, 1, 37, 5, 87, 6, 40, 0,  6, 4, 36, 3, 27, 
    4,  3, 7, 51, 2, 79, 0, 27, 3,  7, 5, 32, 1, 79, 8, 84, 6, 92, 
    4,  2, 6, 62, 1, 41, 2,  5, 5, 46, 0,  6, 7, 88, 3, 23, 8, 12
  };
  const int q7685[] = {
    9, 9, // Number of jobs and machines
    7, 55, 1, 28, 0, 91, 8, 68, 3, 71, 2,  5, 4, 75, 6, 84, 5,  3, 
    7, 78, 3, 97, 8, 64, 6, 67, 5, 10, 0,  6, 4, 95, 1, 45, 2, 14, 
    7, 29, 6, 81, 4, 50, 5, 86, 2, 68, 8, 10, 3, 43, 0, 78, 1, 72, 
    7, 77, 2, 21, 1, 24, 8,  4, 3, 45, 6, 28, 4, 97, 5, 53, 0, 20, 
    0, 61, 2, 91, 8, 33, 6, 87, 1, 69, 5,  9, 7, 36, 3, 34, 4, 15, 
    1, 67, 3, 43, 8, 39, 2, 48, 5, 60, 4, 26, 6, 78, 7, 24, 0,  6, 
    7, 34, 2, 50, 5, 89, 1,  5, 3, 62, 8, 80, 6, 54, 4, 32, 0, 37, 
    0, 28, 2, 64, 8, 36, 4, 21, 3, 61, 7, 34, 1, 47, 5, 36, 6, 88, 
    7, 81, 1, 69, 5, 64, 4, 41, 6, 15, 8, 10, 2, 46, 3, 84, 0, 65
  };
  const int q7686[] = {
    9, 9, // Number of jobs and machines
    5,  2, 2, 91, 0,  9, 6,  6, 1, 42, 8, 81, 4, 52, 3, 40, 7, 23, 
    1, 91, 5,  9, 7, 89, 4, 80, 2, 83, 6, 15, 0, 89, 8, 47, 3,  6, 
    8, 39, 4, 25, 1, 89, 2, 41, 5, 23, 7, 82, 6, 12, 0, 31, 3, 30, 
    7, 92, 2, 17, 4, 16, 5, 63, 8, 25, 3, 25, 0, 45, 1, 15, 6, 40, 
    7, 12, 2, 42, 1, 97, 3, 90, 5, 44, 6, 42, 0, 52, 8, 63, 4,  8, 
    1, 41, 7, 65, 6, 69, 2, 15, 5, 43, 8,  2, 0, 40, 3,  2, 4, 61, 
    0, 19, 8, 49, 2, 77, 6, 91, 4, 10, 5, 41, 1, 92, 3, 79, 7, 98, 
    1, 93, 3, 10, 6, 71, 7, 34, 0, 98, 5, 39, 4, 66, 2, 44, 8, 29, 
    3, 37, 1, 75, 4, 91, 5, 40, 6, 82, 2, 50, 8, 57, 7, 67, 0, 57
  };
  const int q7687[] = {
    9, 9, // Number of jobs and machines
    5, 39, 1, 20, 2, 96, 0, 20, 4, 29, 8, 46, 3, 16, 6, 84, 7, 62, 
    5, 30, 6,  6, 4, 31, 8, 36, 2, 94, 3, 36, 0, 75, 1, 88, 7,  9, 
    0,  2, 3, 87, 4, 62, 2, 67, 8, 95, 6, 27, 5, 42, 7, 90, 1, 11, 
    2, 61, 7, 12, 4, 43, 3, 72, 1,  1, 6, 36, 0,  7, 8, 12, 5, 63, 
    4, 17, 0, 17, 6, 94, 1, 94, 5, 72, 7, 16, 8, 33, 3, 30, 2, 68, 
    4, 46, 2, 39, 5, 66, 8, 76, 6, 79, 0, 59, 3,  1, 7, 53, 1, 78, 
    2, 19, 6,  1, 8, 39, 1, 20, 5, 97, 4, 18, 0, 71, 7, 72, 3, 64, 
    5, 94, 3, 34, 2, 71, 1, 25, 0, 58, 6, 15, 4, 27, 8, 33, 7, 40, 
    0, 19, 7, 61, 4, 23, 2, 38, 5, 30, 8, 12, 3, 76, 6, 94, 1, 88
  };
  const int q7688[] = {
    9, 9, // Number of jobs and machines
    5, 47, 8,  4, 0, 41, 2, 19, 6, 24, 3, 96, 7, 64, 4, 73, 1, 32, 
    4, 60, 1, 50, 3,  1, 5, 39, 7, 31, 2, 99, 8, 83, 6, 79, 0, 95, 
    1, 78, 3, 39, 4, 87, 6, 78, 2,  4, 5,  8, 7, 52, 8,  6, 0, 75, 
    3, 77, 5, 16, 0, 94, 7, 75, 2, 24, 6,  7, 8, 61, 4, 60, 1, 27, 
    7, 29, 2,  2, 3, 74, 1, 74, 5, 54, 8, 38, 6, 81, 0, 90, 4, 27, 
    2, 30, 4, 52, 7, 90, 5, 28, 0, 12, 1, 19, 8, 27, 6, 15, 3, 24, 
    2, 60, 4,  6, 1, 83, 8, 45, 0, 30, 6, 30, 3, 68, 5, 20, 7, 75, 
    5, 85, 0,  2, 7, 74, 3, 76, 4, 22, 8,  4, 2, 12, 6, 54, 1, 74, 
    2, 59, 5, 70, 3, 79, 4, 50, 1, 71, 0,  9, 8, 47, 6, 56, 7, 70
  };
  const int q7689[] = {
    9, 9, // Number of jobs and machines
    0,  4, 4, 50, 3, 74, 6, 11, 5, 15, 1, 33, 7, 34, 8, 59, 2, 88, 
    7, 93, 3, 92, 2,  1, 5, 99, 8,  6, 4, 79, 6, 80, 1, 32, 0, 77, 
    0, 25, 3,  9, 7, 70, 4, 15, 2,  6, 8, 61, 5, 57, 6, 76, 1, 30, 
    6, 36, 2, 33, 4, 41, 8,  1, 1, 77, 5, 69, 7, 86, 3, 69, 0, 73, 
    7, 76, 4, 28, 1, 92, 3, 23, 0, 89, 6, 41, 5, 74, 2, 17, 8, 35, 
    6, 94, 5,  4, 0, 57, 3, 25, 7, 31, 4, 63, 8, 54, 1, 60, 2, 93, 
    6, 82, 1, 45, 7, 89, 5, 56, 4, 27, 2, 57, 0,  4, 3, 92, 8, 37, 
    4, 94, 0, 21, 2, 98, 3, 40, 1, 36, 6, 49, 8, 14, 5, 72, 7, 31, 
    8, 64, 3, 92, 0, 75, 1, 17, 4, 24, 5, 64, 6, 64, 2, 37, 7, 62
  };
  const int q7690[] = {
    9, 9, // Number of jobs and machines
    8, 91, 6, 74, 3, 33, 2, 46, 7,  6, 5, 27, 0, 61, 1, 62, 4, 31, 
    2, 24, 3, 95, 1, 85, 7, 86, 6, 35, 8, 61, 5, 96, 4, 90, 0, 26, 
    7, 74, 1,  3, 8, 48, 5, 26, 3, 39, 2, 18, 0, 79, 6, 13, 4, 35, 
    4, 33, 3, 96, 5, 81, 2, 20, 8,  1, 1, 47, 6, 46, 7, 70, 0, 73, 
    3, 59, 1,  2, 2, 20, 4, 65, 7, 21, 5, 54, 0,  7, 8, 96, 6, 32, 
    1, 24, 4,  9, 3, 80, 0, 32, 8, 42, 7, 67, 5, 16, 6, 43, 2, 50, 
    6, 49, 1, 34, 4,  7, 5, 84, 3, 27, 8, 13, 2, 37, 0, 11, 7, 89, 
    4, 44, 3,  8, 1, 53, 7, 95, 8, 76, 5, 54, 6, 67, 2, 76, 0, 53, 
    8, 22, 0, 38, 5, 52, 1, 87, 2, 61, 4, 49, 7, 88, 6, 17, 3, 34
  };
  const int q7691[] = {
    9, 9, // Number of jobs and machines
    0,  7, 6, 21, 3, 27, 4, 67, 8, 85, 5, 22, 2, 34, 7, 48, 1, 69, 
    0, 36, 2, 64, 3, 21, 1, 81, 6, 88, 7, 76, 5, 50, 4, 86, 8, 71, 
    6, 59, 8, 70, 4, 79, 2, 53, 0, 43, 3, 44, 7, 37, 1, 61, 5, 83, 
    7, 48, 5, 60, 6, 76, 4, 22, 3, 53, 1, 83, 8, 74, 0, 10, 2, 82, 
    3, 44, 6, 42, 4, 94, 1, 72, 7, 43, 5, 13, 0, 63, 2, 48, 8,  1, 
    7, 59, 1, 35, 0, 57, 5, 67, 2,  2, 6, 61, 3,  8, 4, 84, 8, 69, 
    5, 95, 7, 61, 3, 29, 8, 41, 0, 87, 6, 21, 1, 95, 2, 10, 4, 58, 
    6, 31, 7, 53, 2, 24, 4, 13, 5, 36, 0, 98, 8, 99, 3, 65, 1, 28, 
    6, 81, 2, 40, 7, 22, 3, 81, 1, 64, 0, 26, 4, 20, 8, 46, 5,  6
  };
  const int q7692[] = {
    9, 9, // Number of jobs and machines
    6, 76, 0, 32, 8, 96, 4, 78, 5, 17, 1, 53, 2, 84, 7, 67, 3,  9, 
    8, 70, 0, 77, 3, 15, 5, 69, 2, 62, 6, 25, 7, 72, 1,  1, 4, 16, 
    5, 41, 2, 58, 1, 34, 0, 52, 3, 41, 7, 86, 6, 36, 8, 95, 4, 44, 
    7, 75, 8, 15, 1, 33, 4, 94, 2, 97, 6, 69, 5, 47, 3, 14, 0,  1, 
    0, 84, 4, 60, 8, 35, 7, 44, 2, 89, 3, 93, 6, 15, 1,  2, 5, 16, 
    4, 54, 2, 41, 0, 69, 8, 69, 1, 17, 7, 53, 6, 49, 3, 46, 5, 78, 
    6, 40, 2, 68, 0,  7, 1, 95, 5, 44, 3, 58, 8, 96, 7, 88, 4, 34, 
    6, 78, 0, 41, 8, 65, 2, 76, 3, 37, 4, 96, 5, 92, 7, 97, 1, 93, 
    1, 64, 0, 17, 6, 97, 3, 41, 4, 53, 5, 82, 2,  8, 8, 70, 7, 86
  };
  const int q7693[] = {
    9, 9, // Number of jobs and machines
    4, 68, 8, 89, 1, 88, 7, 24, 5,  8, 2, 23, 3, 74, 0, 80, 6, 48, 
    6, 94, 2, 12, 5, 75, 1, 51, 8,  1, 4, 39, 3, 61, 0, 63, 7, 74, 
    3, 46, 6,  6, 7, 32, 5, 27, 0, 46, 4, 58, 2,  4, 8, 33, 1, 87, 
    3, 65, 5, 85, 8, 13, 4, 15, 0,  8, 1, 33, 7, 20, 2, 29, 6, 94, 
    4, 65, 1, 70, 3, 61, 5, 23, 7,  3, 2, 81, 6, 64, 0, 89, 8, 88, 
    0, 64, 2, 12, 3, 26, 8, 91, 4, 47, 1, 76, 6, 62, 5, 80, 7, 51, 
    3, 12, 4,  8, 5, 29, 8,  1, 0, 63, 2, 37, 6, 76, 7, 44, 1, 14, 
    4, 77, 1, 53, 0, 24, 8, 50, 6,  7, 2, 65, 5, 95, 3, 11, 7, 11, 
    3, 55, 8, 35, 4, 59, 0, 14, 6, 28, 7, 80, 2, 75, 1, 39, 5, 91
  };
  const int q7694[] = {
    9, 9, // Number of jobs and machines
    4, 56, 0, 85, 8, 78, 6, 63, 1,  7, 7, 48, 5, 81, 3, 74, 2, 42, 
    1, 78, 3, 45, 6, 37, 5, 63, 7, 53, 2, 96, 0, 46, 8, 61, 4, 31, 
    2,  7, 1, 27, 6, 28, 7, 30, 4, 88, 3, 63, 0, 99, 5,  1, 8, 74, 
    8, 62, 7, 87, 5, 10, 2, 64, 0, 97, 3, 64, 6, 23, 4, 40, 1, 66, 
    0, 78, 3, 46, 4,  2, 8, 24, 5, 70, 1,  4, 6, 59, 7, 57, 2, 97, 
    7,  7, 3,  5, 4, 17, 5,  8, 0, 53, 1, 99, 2, 43, 8, 59, 6, 72, 
    2, 74, 4,  4, 8, 69, 1, 90, 0, 69, 6, 27, 5, 40, 3, 16, 7, 46, 
    6, 37, 1,  7, 0, 90, 8, 45, 2, 14, 4, 48, 7, 88, 5, 32, 3, 17, 
    6, 36, 3, 45, 4, 34, 1, 95, 8, 71, 2, 48, 0, 30, 5, 43, 7,  9
  };
  const int q7695[] = {
    9, 9, // Number of jobs and machines
    4, 38, 5, 99, 0, 53, 1, 73, 8, 26, 2, 47, 6, 66, 7, 62, 3, 50, 
    5, 48, 6, 29, 1,  4, 3, 22, 4, 68, 2, 10, 8, 46, 7, 87, 0, 96, 
    5, 26, 1, 67, 0, 86, 7, 10, 3, 79, 8,  3, 4, 49, 6, 11, 2,  8, 
    8, 37, 7, 19, 1, 12, 0, 15, 6, 34, 5, 75, 2, 76, 4, 38, 3, 91, 
    1, 80, 3, 38, 8, 83, 2,  4, 7, 86, 4,  3, 6, 71, 5, 68, 0, 81, 
    7,  3, 5, 10, 2, 38, 0, 50, 1, 47, 8, 50, 3, 42, 4, 53, 6, 90, 
    2, 14, 4, 75, 6, 24, 7, 94, 0, 30, 3, 62, 8, 60, 1,  5, 5, 59, 
    3, 65, 2, 87, 8, 39, 5, 12, 7, 68, 0, 75, 1, 14, 4, 13, 6, 48, 
    8, 52, 1, 76, 6, 25, 2, 12, 5, 67, 4, 87, 0, 68, 7, 32, 3, 90
  };
  const int q7696[] = {
    9, 9, // Number of jobs and machines
    2, 21, 1, 64, 6, 25, 5, 21, 8, 16, 0, 12, 7, 83, 4, 70, 3, 13, 
    7, 21, 1, 69, 3, 62, 8, 17, 4, 68, 2, 64, 6, 15, 0, 54, 5, 87, 
    0,  5, 8, 91, 2, 49, 4, 60, 6, 93, 5, 79, 7, 88, 1, 63, 3, 75, 
    3, 91, 1, 84, 5, 86, 7, 41, 0, 73, 6, 58, 8, 70, 4,  1, 2, 16, 
    0, 72, 1,  6, 5, 30, 7, 71, 2, 31, 6, 29, 4, 41, 8,  2, 3,  7, 
    4, 34, 7, 31, 6, 77, 0, 25, 5,  3, 2,  1, 8, 83, 3, 66, 1,  2, 
    3, 95, 0, 31, 5, 60, 2, 67, 8, 73, 1, 65, 6, 86, 7, 36, 4, 13, 
    1, 70, 5, 88, 8, 81, 4, 39, 6, 60, 0, 22, 2,  5, 7, 71, 3, 18, 
    8, 49, 7, 98, 5,  2, 4, 48, 2, 71, 3, 72, 6, 20, 0, 67, 1, 74
  };
  const int q7697[] = {
    9, 9, // Number of jobs and machines
    6, 15, 0, 21, 8, 76, 5, 34, 4, 30, 1, 81, 3, 95, 7, 77, 2, 77, 
    8, 76, 5, 65, 4, 92, 1, 58, 2, 77, 0, 32, 7, 57, 3, 27, 6, 30, 
    4, 15, 8, 93, 5, 48, 7, 69, 1, 27, 3, 71, 0, 88, 2, 84, 6, 70, 
    8, 16, 6,  1, 0, 40, 4, 18, 7,  3, 2, 48, 3, 37, 5, 45, 1, 20, 
    7, 31, 6, 32, 8, 73, 2, 10, 3,  2, 0, 84, 4, 43, 1, 81, 5, 20, 
    0, 35, 4, 34, 1, 62, 6, 16, 3, 44, 2, 74, 8, 96, 5, 12, 7, 11, 
    2, 94, 8, 62, 3, 56, 4, 29, 5, 62, 6, 39, 7, 96, 1, 87, 0, 77, 
    8, 43, 7, 44, 3, 32, 0, 97, 5, 84, 1, 38, 2, 68, 6, 29, 4, 52, 
    3, 51, 8, 94, 4, 85, 2, 46, 7, 34, 5, 14, 0, 34, 1, 87, 6, 49
  };
  const int q7698[] = {
    9, 9, // Number of jobs and machines
    1, 44, 6, 85, 2, 27, 4, 36, 8, 87, 7, 50, 0, 39, 3, 71, 5, 61, 
    4, 88, 8, 90, 3,  8, 5, 58, 6, 33, 1, 41, 7, 16, 2, 15, 0, 53, 
    4, 82, 2, 25, 6, 43, 5, 93, 1, 25, 7, 25, 3, 94, 8, 39, 0, 72, 
    1, 11, 7, 51, 5,  4, 0, 66, 6, 42, 3, 56, 8, 27, 4, 22, 2, 63, 
    4, 64, 7, 25, 1, 81, 8,  6, 6, 34, 0, 58, 3, 10, 2, 62, 5,  8, 
    6, 18, 4, 15, 2, 36, 0, 88, 5, 49, 1, 72, 3, 30, 8, 47, 7, 45, 
    6, 92, 1, 11, 2, 50, 7, 37, 0, 74, 4, 68, 5, 61, 8, 57, 3, 59, 
    7, 60, 2, 39, 3, 68, 6, 81, 8, 44, 1, 25, 0, 24, 4, 86, 5, 81, 
    3,  5, 2, 40, 4, 54, 0, 82, 1, 80, 5, 95, 6, 98, 7,  4, 8, 62
  };
  const int q7699[] = {
    9, 9, // Number of jobs and machines
    8, 98, 7, 99, 6, 51, 5, 66, 0, 67, 1, 49, 2, 94, 4, 98, 3, 18, 
    0, 30, 6, 77, 8, 58, 7, 97, 3, 51, 5, 86, 2, 26, 1, 91, 4, 35, 
    0, 80, 4, 31, 7, 14, 8, 60, 3,  5, 2, 29, 5, 23, 6, 23, 1, 31, 
    8, 31, 1, 38, 5, 59, 6,  5, 3, 65, 7, 31, 0, 76, 4, 95, 2, 28, 
    0, 97, 1, 68, 8, 24, 2, 16, 5, 63, 4,  5, 3, 69, 7, 18, 6, 47, 
    3, 12, 0, 65, 7, 70, 4, 58, 2, 88, 1, 19, 6, 15, 8, 21, 5, 43, 
    1, 51, 4, 24, 5, 28, 7, 21, 2, 41, 0, 86, 6, 55, 3, 28, 8, 88, 
    7, 26, 0, 40, 5, 49, 1, 65, 6, 31, 2, 22, 4, 47, 3, 83, 8, 31, 
    8, 28, 2, 22, 6, 20, 4, 71, 0, 73, 1, 49, 3, 73, 5, 78, 7, 28
  };
  const int q7700[] = {
    9, 9, // Number of jobs and machines
    0, 15, 5, 34, 6, 55, 8, 86, 4, 39, 2,  3, 1, 74, 3, 24, 7, 80, 
    3, 27, 4, 11, 5, 77, 8, 90, 6, 17, 7,  8, 2, 26, 0, 19, 1, 33, 
    8, 54, 2, 63, 4, 49, 3, 78, 1, 99, 6, 97, 0, 94, 5, 88, 7, 89, 
    5, 86, 0, 88, 8, 68, 4, 91, 1, 47, 3, 47, 6, 71, 2, 94, 7, 30, 
    2, 68, 1, 40, 6,  1, 5, 82, 7, 62, 8,  8, 0, 27, 3, 14, 4, 20, 
    1,  7, 8, 53, 6,  5, 5, 99, 0, 19, 2,  7, 4,  9, 3, 82, 7, 53, 
    6, 62, 3, 10, 5, 54, 0, 82, 7, 15, 2, 80, 1, 49, 4, 49, 8, 75, 
    8, 48, 6, 72, 0, 45, 1,  5, 4, 93, 2, 34, 3, 79, 5, 46, 7, 97, 
    8, 72, 5, 46, 7, 18, 2, 39, 0, 51, 6, 86, 1, 14, 4,  2, 3, 80
  };
  const int q7701[] = {
    9, 9, // Number of jobs and machines
    1, 84, 4, 77, 3, 34, 0, 73, 8, 48, 6, 98, 2, 39, 5, 20, 7, 38, 
    2, 61, 0, 19, 7, 94, 4, 67, 6, 92, 8, 20, 5, 39, 1, 74, 3, 94, 
    5,  4, 8, 86, 3, 26, 2, 45, 7, 11, 4, 23, 6, 81, 1, 32, 0, 70, 
    4, 43, 7, 76, 5, 82, 2, 23, 6, 11, 1, 47, 3, 88, 8, 82, 0, 18, 
    0, 58, 4, 26, 1, 81, 6, 77, 8, 69, 2, 39, 7, 92, 5, 29, 3, 43, 
    5, 55, 1, 85, 4, 18, 6, 75, 7, 35, 0, 52, 3, 26, 2, 71, 8, 34, 
    0, 92, 3, 22, 4, 60, 5, 25, 7, 24, 1, 95, 8,  9, 2, 39, 6, 45, 
    0, 24, 5, 62, 3, 99, 8, 80, 7, 82, 1, 82, 6, 98, 2, 11, 4, 96, 
    2, 27, 0, 80, 7, 78, 5, 50, 3, 89, 8,  5, 4, 36, 1, 85, 6,  1
  };
  const int q7702[] = {
    9, 9, // Number of jobs and machines
    4, 29, 5, 83, 3, 77, 2, 36, 8, 36, 0, 92, 7, 46, 6, 69, 1, 80, 
    8, 50, 6,  4, 4, 48, 1, 42, 3,  4, 0, 47, 5, 47, 2, 50, 7, 49, 
    5, 30, 2, 49, 3,  4, 6,  6, 7, 71, 8, 53, 1, 31, 0, 31, 4, 72, 
    1,  8, 6, 63, 5, 36, 3,  3, 7, 15, 2, 74, 0, 87, 8, 59, 4, 25, 
    4, 17, 6, 32, 0, 35, 7, 42, 2,  4, 5, 11, 8, 39, 3, 74, 1, 93, 
    2, 92, 3, 37, 1, 40, 5, 27, 4,  9, 7, 12, 8, 59, 0, 87, 6,  2, 
    8, 99, 6, 20, 0,  7, 7, 52, 3, 55, 1,  5, 4, 88, 2, 98, 5, 59, 
    8, 68, 2,  9, 7, 55, 1, 53, 3, 83, 5, 67, 4, 29, 6, 63, 0, 59, 
    3, 29, 2, 18, 7, 25, 8, 19, 6, 10, 0, 48, 4, 29, 1, 76, 5, 92
  };
  const int q7703[] = {
    9, 9, // Number of jobs and machines
    1, 73, 2, 32, 7, 16, 0, 22, 4, 61, 5, 46, 6, 96, 3, 90, 8, 95, 
    3, 95, 5, 77, 4, 55, 8, 97, 2,  9, 7, 26, 6, 18, 1,  9, 0, 63, 
    0, 68, 4, 99, 3, 31, 2, 26, 8, 28, 5, 48, 1, 37, 6, 24, 7, 56, 
    1, 20, 2, 82, 5, 78, 6, 81, 8, 67, 7, 11, 0, 77, 4, 34, 3, 41, 
    5, 27, 8, 38, 2, 72, 0, 10, 6, 42, 7, 11, 4, 13, 1, 46, 3, 17, 
    0, 27, 5, 35, 2, 38, 7, 50, 4, 76, 1, 83, 3,  4, 6, 53, 8, 31, 
    2, 44, 8, 78, 1, 85, 4, 80, 3, 97, 7, 14, 0, 37, 6, 43, 5, 85, 
    6, 79, 7, 87, 5, 24, 4,  9, 2, 93, 8, 50, 0, 34, 3, 23, 1, 21, 
    5, 36, 7, 32, 0, 47, 1, 99, 6, 56, 4, 94, 3, 87, 8, 90, 2, 70
  };
  const int q7704[] = {
    9, 9, // Number of jobs and machines
    4,  5, 1,  2, 8,  4, 0, 62, 2, 24, 3, 61, 7, 86, 6, 53, 5, 39, 
    3, 80, 7, 45, 2, 42, 4,  6, 5, 37, 6, 43, 8, 58, 0, 45, 1, 17, 
    2, 86, 5, 32, 0, 65, 6, 30, 1, 37, 4, 60, 8, 54, 7, 80, 3, 27, 
    4, 21, 3, 12, 6, 99, 5, 25, 8, 73, 1, 47, 2, 95, 0, 21, 7,  5, 
    8, 70, 2, 99, 5, 41, 7, 30, 0,  6, 3, 86, 4, 33, 6, 86, 1, 88, 
    0, 18, 2, 18, 6, 28, 4, 90, 3, 82, 7,  7, 8, 93, 5, 21, 1, 35, 
    5, 68, 6, 68, 8, 59, 7, 17, 2, 88, 1, 73, 4, 71, 0,  9, 3, 60, 
    5, 65, 0, 19, 2, 57, 7,  5, 8, 23, 1, 80, 3, 98, 4, 29, 6, 81, 
    3, 84, 7, 81, 2, 86, 6,  2, 8, 39, 0, 77, 4, 33, 5, 62, 1, 70
  };
  const int q7705[] = {
    9, 9, // Number of jobs and machines
    7, 74, 1, 41, 6, 10, 5, 56, 4, 24, 3, 53, 0, 96, 8, 83, 2, 90, 
    0, 62, 3, 28, 4, 79, 5, 54, 8, 47, 1, 35, 2, 52, 7, 77, 6, 40, 
    6, 81, 7, 61, 8, 99, 5, 64, 2, 28, 3, 94, 1,  5, 4, 58, 0,  8, 
    7, 95, 1, 64, 5, 40, 8, 35, 6, 24, 0, 11, 4,  4, 3, 38, 2, 74, 
    4, 10, 2, 84, 6, 99, 7, 66, 1, 51, 3, 98, 8, 20, 5, 73, 0, 23, 
    2, 81, 6, 35, 0,  6, 7, 82, 8, 92, 5,  2, 1, 24, 4, 76, 3, 45, 
    6, 85, 1, 12, 8, 64, 2, 83, 4, 66, 3, 31, 0, 93, 5, 48, 7, 27, 
    8, 30, 1, 56, 4, 59, 3, 28, 2, 47, 5,  5, 7, 82, 6,  6, 0, 39, 
    5,  2, 8, 55, 3, 49, 2, 62, 7, 33, 1,  2, 0, 49, 4, 96, 6, 56
  };
  const int q7706[] = {
    9, 9, // Number of jobs and machines
    3,  8, 0, 65, 1, 56, 7,  8, 8, 71, 6, 60, 4, 86, 5, 44, 2, 64, 
    3, 35, 2, 76, 5, 26, 8,  8, 4, 80, 7, 47, 0, 11, 1, 63, 6, 54, 
    6, 71, 5, 23, 1, 67, 3,  4, 8,  9, 4, 43, 7, 85, 2, 84, 0, 14, 
    1,  8, 6, 89, 4, 94, 0, 36, 3, 73, 2, 83, 8, 76, 7, 89, 5, 56, 
    3,  7, 7, 14, 6, 33, 5, 24, 0, 77, 4, 13, 8, 40, 1,  8, 2, 26, 
    4, 21, 8, 13, 2, 63, 7, 71, 0, 62, 5, 67, 6, 21, 3, 11, 1, 88, 
    8, 23, 4, 16, 1, 79, 0, 30, 2, 37, 7, 82, 6, 83, 5, 59, 3, 23, 
    2, 60, 7, 47, 0, 77, 6, 68, 3, 43, 5, 31, 1, 65, 4, 37, 8, 60, 
    2, 27, 8, 90, 0, 47, 6, 89, 3, 20, 1, 20, 5, 24, 7, 60, 4, 19
  };
  const int q7707[] = {
    9, 9, // Number of jobs and machines
    8, 54, 4, 50, 0, 68, 1, 90, 2, 35, 6, 85, 5, 34, 7, 46, 3, 76, 
    5,  6, 4, 50, 2, 58, 7,  6, 8, 25, 6,  3, 1, 52, 0, 14, 3, 42, 
    7, 96, 2, 83, 0, 98, 6, 54, 3, 62, 1, 87, 4, 66, 5, 64, 8,  6, 
    8, 99, 1, 53, 6, 88, 3,  2, 2, 97, 7, 18, 5, 11, 4, 72, 0, 51, 
    1, 78, 5, 76, 2, 40, 0, 68, 6, 44, 3, 56, 7, 73, 4, 87, 8, 42, 
    0, 41, 4, 71, 2, 39, 8, 18, 3, 52, 5, 70, 6, 18, 1, 70, 7, 50, 
    0, 64, 5, 33, 2, 59, 7, 19, 6, 83, 1, 71, 4, 40, 8, 11, 3, 64, 
    5,  5, 1, 24, 0, 14, 3, 43, 8, 26, 2, 97, 4, 46, 7,  2, 6,  3, 
    6, 69, 0, 13, 8, 19, 7, 14, 4, 23, 1, 13, 2, 12, 3, 79, 5, 55
  };
  const int q7708[] = {
    9, 9, // Number of jobs and machines
    5, 40, 6, 41, 0, 81, 4, 90, 3, 34, 7, 88, 2, 35, 1, 50, 8, 56, 
    5, 32, 4, 85, 7, 33, 3, 96, 1, 15, 6, 78, 2, 60, 0, 46, 8, 71, 
    5, 28, 6,  8, 0, 97, 7, 24, 3, 21, 4, 47, 8, 13, 2, 95, 1,  8, 
    4, 91, 5,  2, 0, 31, 3, 62, 1, 17, 6, 30, 8, 11, 2, 86, 7, 32, 
    3, 20, 6, 65, 0, 80, 1, 50, 7, 15, 2, 82, 8, 55, 4, 31, 5, 95, 
    7, 86, 3, 66, 0, 30, 6, 50, 4, 66, 1, 49, 8, 40, 5, 24, 2, 42, 
    5, 52, 1, 12, 4, 54, 6, 23, 7, 46, 8, 33, 0, 60, 3, 47, 2, 44, 
    2, 49, 8, 95, 0, 34, 1, 67, 7,  2, 6, 53, 3, 82, 4, 46, 5, 84, 
    8, 25, 3, 77, 6, 33, 5, 99, 1, 70, 0,  3, 7, 83, 2, 24, 4, 23
  };
  const int q7709[] = {
    9, 9, // Number of jobs and machines
    7, 95, 6, 19, 0, 76, 5, 89, 4, 78, 3, 74, 2, 80, 1,  2, 8, 21, 
    0, 29, 5, 59, 2, 21, 1, 43, 4, 98, 8,  9, 6, 75, 7, 26, 3, 67, 
    7, 81, 1, 32, 6, 11, 8, 38, 5, 32, 4, 38, 0, 82, 3, 65, 2, 57, 
    6,  6, 7,  8, 3, 53, 1, 51, 4, 36, 5, 34, 0, 78, 8, 14, 2, 21, 
    3,  5, 7, 31, 2, 37, 4,  1, 5, 30, 6, 77, 8, 46, 1, 34, 0,  9, 
    3, 82, 6, 30, 4, 69, 7, 51, 1, 88, 0, 76, 2, 78, 5,  5, 8, 46, 
    6, 59, 8, 45, 7, 13, 1, 68, 0, 74, 2, 82, 4, 19, 5,  7, 3, 37, 
    1, 64, 0, 97, 8, 34, 2, 41, 5,  2, 4, 64, 7,  5, 6,  5, 3, 18, 
    1, 99, 7, 71, 0, 92, 5, 66, 8, 70, 3, 57, 6, 24, 2, 92, 4,  9
  };
  const int q7710[] = {
    9, 9, // Number of jobs and machines
    7, 68, 3, 27, 8, 33, 2, 83, 6, 83, 5, 97, 1, 35, 4, 34, 0, 33, 
    2, 13, 1, 64, 0, 51, 6,  5, 8, 19, 4, 23, 5, 73, 7, 82, 3, 47, 
    7, 85, 2, 81, 3, 33, 8, 41, 1, 92, 0,  9, 4, 64, 5, 60, 6, 36, 
    0, 89, 4, 79, 2,  2, 5, 37, 8, 99, 3, 90, 6, 49, 7, 83, 1, 45, 
    8, 99, 5, 22, 4, 65, 2, 36, 0, 64, 1,  5, 3, 47, 7, 59, 6, 33, 
    5, 45, 1, 49, 4, 69, 0, 73, 2,  3, 6, 20, 3, 54, 7, 42, 8, 45, 
    6, 52, 3, 30, 5, 35, 4, 94, 7, 99, 0, 40, 1, 78, 8, 75, 2, 33, 
    4,  3, 5, 66, 2, 31, 3, 35, 8, 98, 1, 55, 0, 78, 7, 36, 6, 39, 
    3, 33, 5,  1, 4, 25, 1, 18, 0, 69, 8,  7, 6, 12, 2, 96, 7, 73
  };
  const int q7711[] = {
    9, 9, // Number of jobs and machines
    2, 25, 3, 83, 1,  9, 6, 79, 8, 11, 4, 16, 7,  2, 5, 63, 0, 86, 
    2, 47, 6, 68, 4, 32, 3, 59, 0, 75, 1,  4, 7, 14, 8, 10, 5, 44, 
    3, 22, 7, 46, 2, 25, 0, 87, 8, 72, 6, 60, 5,  2, 4, 41, 1, 53, 
    1, 65, 7, 80, 3, 45, 2, 24, 0, 82, 4, 49, 5, 85, 6, 96, 8, 88, 
    4,  6, 7, 21, 8, 27, 2, 43, 3,  4, 5, 52, 6, 59, 0, 95, 1, 12, 
    6, 64, 1, 13, 0, 95, 3, 75, 7, 60, 4, 80, 2, 23, 5, 17, 8, 52, 
    7, 20, 2, 52, 3, 37, 5, 11, 0, 57, 8, 27, 1, 56, 4, 65, 6, 68, 
    3, 87, 1, 74, 4, 93, 6, 67, 5, 51, 8, 76, 2, 99, 0, 22, 7, 29, 
    8, 38, 0, 48, 5, 93, 1, 10, 3, 21, 4, 66, 2, 90, 7, 24, 6, 92
  };
  const int q7712[] = {
    9, 9, // Number of jobs and machines
    2, 61, 0, 99, 3, 79, 8, 60, 7,  2, 6, 38, 1, 95, 5, 44, 4, 42, 
    0,  8, 7, 74, 6, 55, 5, 27, 8, 52, 4, 99, 2,  4, 3,  5, 1, 19, 
    8, 33, 0, 47, 7, 22, 4, 76, 1, 59, 6, 12, 2, 47, 5, 26, 3, 54, 
    4, 50, 8, 49, 2, 96, 1, 58, 6, 65, 7, 59, 5, 91, 0, 61, 3, 91, 
    4, 93, 6, 20, 7, 97, 1, 32, 3, 31, 8, 47, 0, 84, 5, 24, 2, 55, 
    1, 79, 0, 89, 6, 77, 3, 16, 4, 15, 5,  3, 2, 64, 7, 57, 8, 16, 
    5, 33, 2, 75, 3, 41, 4, 89, 0, 16, 8, 63, 1, 56, 6, 34, 7, 27, 
    1, 41, 2,  4, 5,  5, 0, 99, 6, 29, 8, 79, 4, 92, 3, 77, 7, 71, 
    2, 18, 0, 43, 5, 31, 3, 76, 1, 26, 7, 36, 6, 25, 4, 22, 8, 63
  };
  const int q7713[] = {
    9, 9, // Number of jobs and machines
    0, 44, 3, 11, 1, 13, 4, 40, 5, 10, 2, 71, 8, 14, 6, 42, 7, 41, 
    8,  9, 6,  2, 1, 37, 2, 74, 4, 67, 0, 27, 5, 75, 3, 97, 7, 20, 
    3, 97, 7, 51, 2, 86, 8, 12, 1,  9, 6, 54, 4, 60, 5, 37, 0, 20, 
    5,  6, 7, 21, 4, 78, 1, 16, 3, 45, 8, 27, 6, 24, 0, 50, 2, 88, 
    6, 22, 1, 74, 0, 10, 3, 39, 4, 77, 2, 32, 8, 75, 5, 65, 7, 63, 
    8, 98, 5, 70, 7, 91, 3, 61, 1, 67, 2, 34, 4, 32, 6, 49, 0, 56, 
    7,  7, 6, 57, 3, 64, 0, 73, 1, 84, 4, 49, 2, 43, 8, 19, 5, 58, 
    6, 58, 4, 51, 3, 45, 2, 24, 5, 91, 1, 97, 8,  5, 7, 38, 0, 96, 
    3, 21, 6, 33, 5, 16, 8, 37, 0, 91, 4, 62, 1, 45, 2, 10, 7, 35
  };
  const int q7714[] = {
    9, 9, // Number of jobs and machines
    7, 62, 4, 68, 6,  4, 1, 38, 0, 44, 5, 30, 8, 79, 2, 56, 3, 18, 
    6, 15, 1, 41, 4, 11, 7, 96, 0,  6, 5, 52, 2, 90, 3,  1, 8, 47, 
    0, 45, 5, 33, 1, 77, 2, 53, 8, 26, 3, 11, 6, 18, 4, 47, 7, 91, 
    3, 40, 6, 64, 4, 64, 7, 90, 0, 27, 1, 89, 2, 95, 8, 68, 5, 56, 
    7,  8, 5, 84, 6, 43, 0, 35, 4,  2, 3, 51, 8, 32, 1,  9, 2, 66, 
    5, 73, 1, 92, 8, 10, 6, 81, 2, 17, 4, 79, 7, 59, 0, 56, 3, 21, 
    0, 28, 8, 78, 4, 39, 7, 76, 5, 54, 3,  1, 1,  1, 6, 95, 2,  6, 
    8, 35, 2, 57, 5, 60, 4, 56, 6,  4, 0,  7, 7, 52, 1, 38, 3, 30, 
    2, 83, 1, 27, 0, 58, 5,  4, 4, 75, 3, 73, 6, 50, 8, 54, 7, 82
  };
  const int q7715[] = {
    9, 9, // Number of jobs and machines
    6, 47, 1, 65, 2, 34, 4, 17, 3, 64, 7, 51, 5, 65, 0, 89, 8, 46, 
    5, 97, 0, 56, 3, 81, 4, 76, 1, 10, 8, 35, 7, 94, 6, 86, 2, 93, 
    7, 98, 6, 27, 1,  5, 8, 77, 3, 45, 0, 22, 4, 85, 2, 46, 5, 19, 
    0, 89, 8, 97, 3, 47, 5, 35, 6, 18, 7, 41, 4, 41, 2, 55, 1, 20, 
    0, 63, 1, 29, 8, 33, 7, 49, 4, 78, 5,  7, 3, 63, 2, 37, 6, 46, 
    3,  8, 0, 98, 6, 21, 4, 23, 2, 21, 8, 28, 7, 47, 1, 75, 5,  3, 
    2, 86, 8, 58, 1, 41, 4, 22, 6, 91, 5, 42, 0, 59, 3,  1, 7, 10, 
    7, 25, 5, 28, 2, 29, 8, 62, 1, 87, 6, 45, 3, 91, 4, 92, 0, 33, 
    0, 69, 3, 62, 5, 30, 4, 52, 2, 20, 1, 77, 8, 40, 6, 21, 7,  2
  };
  const int q7716[] = {
    9, 9, // Number of jobs and machines
    4, 17, 2, 38, 0, 95, 7, 82, 8, 80, 5, 36, 1,  3, 6, 41, 3, 51, 
    7, 80, 8, 46, 6, 67, 1, 88, 4, 95, 2, 75, 3, 12, 0, 25, 5, 49, 
    2, 15, 0, 72, 4, 31, 3, 35, 5, 56, 1, 22, 6,  7, 8, 39, 7, 51, 
    2, 70, 6, 68, 0, 26, 4, 35, 8, 78, 5, 52, 3, 61, 7, 83, 1, 89, 
    8, 75, 2,  4, 1,  1, 0, 78, 6, 79, 4, 28, 5, 19, 7, 36, 3, 73, 
    1, 44, 2, 19, 8, 21, 6, 76, 3, 58, 0, 92, 4, 94, 7, 91, 5, 47, 
    7, 18, 1, 13, 2, 25, 6, 96, 0, 17, 5, 35, 4, 45, 3, 71, 8, 80, 
    2, 60, 4,  8, 1, 86, 8, 19, 0, 83, 5, 94, 6, 67, 3, 37, 7, 45, 
    8, 65, 1, 21, 0, 28, 4, 12, 7, 57, 3, 55, 5, 97, 2, 11, 6, 67
  };
  const int q7717[] = {
    9, 9, // Number of jobs and machines
    4, 95, 2, 32, 7, 61, 8, 23, 0, 85, 6, 14, 1, 53, 5, 58, 3, 56, 
    7, 77, 3, 68, 4, 64, 6, 20, 2, 67, 1, 51, 5, 70, 8, 28, 0, 19, 
    4,  2, 1, 51, 6, 90, 5, 84, 0, 39, 3,  7, 2, 44, 7, 49, 8, 12, 
    3, 46, 1, 16, 2, 55, 5, 74, 8, 68, 6,  5, 4, 88, 0, 60, 7, 56, 
    3, 61, 1, 93, 0, 91, 7, 79, 5, 38, 2, 18, 8, 63, 4, 69, 6, 18, 
    8, 89, 6, 82, 5, 54, 7, 72, 3, 20, 4, 23, 1, 41, 0, 22, 2, 66, 
    0, 35, 8, 71, 5, 87, 6, 54, 7, 83, 4, 80, 3, 54, 1, 12, 2, 36, 
    4, 41, 1,  4, 3, 11, 7, 26, 2, 25, 0, 72, 5, 69, 8, 76, 6, 60, 
    4, 94, 6, 38, 5, 49, 2, 68, 0, 42, 1, 77, 7, 50, 3, 36, 8,  4
  };
  const int q7718[] = {
    9, 9, // Number of jobs and machines
    6, 43, 0,  5, 8, 19, 4, 88, 3,  9, 5, 69, 2,  6, 1, 84, 7, 65, 
    4, 58, 7, 41, 3, 35, 6,  3, 0, 60, 2, 70, 1, 64, 8,  3, 5,  8, 
    7, 14, 6, 65, 3, 41, 5, 45, 2, 37, 1, 77, 4, 86, 8, 76, 0, 35, 
    6, 84, 4, 81, 2, 51, 0, 93, 5, 50, 1, 39, 8, 52, 7, 18, 3, 91, 
    5, 24, 1, 94, 6, 94, 8, 11, 3, 54, 0, 19, 2, 52, 4, 32, 7, 65, 
    4, 70, 3, 52, 8, 51, 7, 25, 5, 23, 1, 16, 2, 49, 6, 61, 0, 63, 
    1, 88, 2, 16, 6, 64, 5, 10, 0, 35, 8, 60, 3, 10, 7, 61, 4, 55, 
    8, 24, 2, 33, 1, 79, 5, 98, 7, 80, 0, 51, 6, 91, 3, 29, 4, 34, 
    5, 69, 3, 91, 6, 73, 0, 29, 8,  5, 7, 79, 2, 65, 1, 17, 4, 54
  };
  const int q7719[] = {
    9, 9, // Number of jobs and machines
    0, 61, 2, 29, 7,  7, 5, 48, 8, 10, 1, 91, 4, 83, 3, 54, 6, 87, 
    2, 80, 1, 45, 7, 14, 3, 37, 0, 67, 4, 86, 5, 53, 6, 22, 8, 87, 
    2, 69, 1, 82, 6, 62, 0, 24, 8, 75, 4, 23, 3, 55, 7, 70, 5, 61, 
    0, 48, 7, 74, 3,  5, 2,  6, 8, 56, 6, 32, 1,  1, 5, 62, 4,  8, 
    7, 23, 1, 75, 5, 67, 0, 16, 4, 15, 6, 51, 3, 21, 2, 26, 8, 34, 
    2, 41, 7, 50, 0, 15, 1, 20, 8, 13, 3, 38, 4, 49, 5, 64, 6, 93, 
    6, 59, 0, 34, 3, 68, 1, 41, 4, 14, 8, 30, 5,  4, 7, 70, 2, 22, 
    8, 97, 4, 88, 7, 47, 6, 73, 0,  9, 5, 93, 3, 69, 2, 35, 1, 65, 
    0, 52, 1, 73, 8, 95, 2, 30, 5, 30, 3, 65, 4,  1, 6, 96, 7, 60
  };
  const int q7720[] = {
    9, 9, // Number of jobs and machines
    0, 81, 8, 87, 3, 57, 1, 73, 4, 53, 6, 24, 7, 23, 2, 53, 5, 55, 
    1, 24, 2, 31, 6, 60, 8, 35, 4, 48, 3, 92, 7, 30, 5, 41, 0, 82, 
    3, 93, 5, 62, 0, 42, 4, 29, 7, 23, 1,  5, 6, 88, 8, 48, 2, 47, 
    4, 64, 7, 46, 8, 25, 1, 42, 5, 42, 6, 91, 2, 28, 3, 68, 0, 43, 
    4, 60, 7, 63, 0, 16, 5, 60, 1, 39, 6, 94, 3, 75, 2, 37, 8, 42, 
    8, 79, 0, 15, 5, 69, 2, 31, 1, 98, 6, 61, 3, 70, 7, 52, 4, 75, 
    5, 31, 8, 11, 1, 22, 3, 31, 2, 87, 7, 44, 6, 87, 0,  2, 4, 80, 
    5, 39, 8, 32, 2, 97, 7, 70, 4, 32, 6, 48, 3,  2, 1, 41, 0, 60, 
    6, 66, 0, 89, 4, 68, 2, 23, 5,  5, 7, 24, 3, 37, 8, 51, 1, 54
  };
  const int q7721[] = {
    9, 9, // Number of jobs and machines
    5, 45, 8, 22, 7,  9, 2, 75, 6,  5, 4,  9, 3, 70, 1, 31, 0, 18, 
    6, 49, 5, 88, 2,  1, 1, 30, 8, 36, 7, 55, 3, 30, 0, 53, 4, 20, 
    3, 24, 5, 39, 7, 25, 8, 54, 2, 15, 4, 19, 1, 96, 6, 65, 0, 43, 
    2, 45, 5, 84, 3, 14, 0, 97, 8, 54, 1, 35, 6, 49, 7, 33, 4, 67, 
    8, 96, 0, 88, 1,  8, 3, 11, 2, 88, 5, 62, 7, 72, 4, 42, 6, 16, 
    2, 80, 3, 57, 4,  4, 7, 37, 6, 53, 1, 45, 0, 54, 5, 23, 8, 39, 
    7, 61, 5, 57, 3,  4, 1, 85, 6, 18, 2, 83, 8, 20, 0, 35, 4, 30, 
    7, 85, 5, 88, 2, 41, 0, 36, 6, 38, 8, 24, 4, 86, 1, 71, 3, 43, 
    0,  7, 5, 75, 3,  2, 1, 55, 2, 31, 7, 68, 6, 29, 8,  8, 4, 86
  };
  const int q7722[] = {
    9, 9, // Number of jobs and machines
    6, 14, 3, 24, 1, 67, 2, 53, 7, 86, 4, 13, 8, 22, 0, 80, 5, 80, 
    0,  4, 2,  1, 7, 74, 6, 46, 4, 77, 8, 41, 5, 84, 1, 18, 3, 92, 
    4, 50, 1,  2, 8, 60, 5, 83, 0, 30, 3, 40, 6, 63, 7, 31, 2, 73, 
    8, 37, 7, 25, 2, 31, 6, 71, 3, 93, 5, 38, 0, 84, 4, 72, 1, 39, 
    8, 55, 4, 44, 5, 91, 6, 28, 3, 66, 0, 17, 2, 93, 7, 59, 1, 84, 
    7, 47, 0, 90, 4,  8, 8, 46, 3, 15, 1, 43, 6, 34, 2, 20, 5, 99, 
    7,  9, 6, 76, 5, 88, 1, 23, 3, 73, 0, 15, 2, 19, 8,  8, 4, 60, 
    4,  4, 3, 13, 6, 20, 7, 13, 0, 61, 5, 88, 2, 83, 1, 39, 8, 74, 
    6, 75, 5, 61, 3,  6, 2, 97, 7, 42, 1, 97, 4, 21, 0, 15, 8, 75
  };
  const int q7723[] = {
    9, 9, // Number of jobs and machines
    2,  2, 0, 51, 3, 51, 8, 52, 6,  2, 4, 26, 5, 36, 7, 78, 1, 30, 
    4, 51, 5, 81, 0, 97, 8,  7, 7, 38, 1, 61, 3, 76, 6, 15, 2, 12, 
    1,  5, 6, 48, 5, 21, 0, 72, 8, 81, 4, 42, 7, 73, 3, 55, 2, 14, 
    2, 55, 3,  8, 8, 74, 7, 15, 4,  5, 1, 69, 6, 21, 0, 23, 5,  6, 
    0, 62, 5, 12, 2, 76, 6, 99, 4, 22, 7, 71, 8, 52, 3, 46, 1, 73, 
    5,  5, 1,  1, 4, 47, 6, 26, 7,  9, 8, 23, 0, 98, 2, 36, 3, 49, 
    0, 79, 2, 53, 7, 14, 5, 34, 8, 16, 6, 44, 1,  4, 3, 72, 4,  4, 
    8, 66, 0, 58, 3, 71, 5, 52, 1, 44, 7, 29, 2, 47, 4,  3, 6, 72, 
    3, 47, 6,  7, 1, 94, 5, 70, 0, 96, 8, 90, 4, 55, 7, 82, 2, 94
  };
  const int q7724[] = {
    9, 9, // Number of jobs and machines
    2, 78, 4, 95, 0, 27, 8, 14, 3, 81, 6, 60, 5, 18, 7, 45, 1, 13, 
    8, 37, 2, 21, 6, 42, 0, 16, 1, 96, 5, 53, 3, 19, 4, 33, 7, 53, 
    3, 89, 5, 34, 7, 39, 0, 49, 2, 92, 1, 29, 8, 82, 4, 10, 6, 38, 
    4, 31, 8, 52, 1,  4, 0,  1, 2, 71, 6, 68, 5, 92, 7, 97, 3, 14, 
    1, 44, 7, 18, 4,  9, 3, 25, 6,  9, 5, 76, 8, 58, 2, 56, 0, 57, 
    8, 35, 0, 68, 5, 97, 2, 38, 1, 62, 4, 81, 7, 87, 6, 81, 3, 81, 
    4, 87, 2, 76, 1, 60, 6, 20, 5,  8, 8, 50, 3, 30, 7, 57, 0, 29, 
    1, 79, 4, 73, 6, 81, 2, 39, 7, 31, 3,  1, 5, 70, 8, 69, 0, 38, 
    4, 28, 5, 36, 6, 86, 7, 26, 0, 76, 2, 32, 8,  8, 1, 65, 3, 15
  };
  const int q7725[] = {
    9, 9, // Number of jobs and machines
    6, 31, 0, 47, 2, 52, 7, 82, 3, 61, 1, 30, 5, 30, 8, 29, 4, 77, 
    3, 19, 0, 58, 2, 78, 5, 98, 7, 91, 8, 40, 4, 41, 6, 60, 1, 71, 
    4, 81, 5, 81, 0, 94, 7, 80, 6,  2, 3,  7, 8, 32, 2, 79, 1, 35, 
    0, 82, 7, 58, 3, 77, 4, 74, 8, 85, 6, 93, 2, 89, 1, 45, 5, 19, 
    4,  7, 2, 29, 8,  2, 3, 90, 0, 35, 5, 12, 6, 82, 1, 89, 7, 98, 
    1, 30, 5, 27, 4, 54, 7, 29, 2, 37, 3, 17, 8, 37, 6, 72, 0, 53, 
    6, 16, 7, 88, 0, 12, 8, 15, 5, 34, 3, 27, 2, 81, 4, 98, 1, 35, 
    7, 51, 3, 78, 6, 62, 5, 74, 2, 45, 4, 91, 8, 61, 0, 91, 1, 94, 
    5, 26, 2, 27, 1, 80, 6, 66, 4, 27, 0, 76, 7,  7, 8, 10, 3, 35
  };
  const int q7726[] = {
    9, 9, // Number of jobs and machines
    7, 40, 0,  4, 6, 34, 1, 97, 2, 13, 8,  1, 3, 62, 4, 55, 5, 55, 
    7, 36, 0, 59, 5, 83, 3, 25, 1, 41, 4, 44, 2, 89, 6, 42, 8, 62, 
    5, 55, 6, 93, 4, 97, 3, 25, 2, 31, 8, 17, 7, 75, 1,  1, 0, 67, 
    1, 87, 6, 51, 3, 51, 7, 79, 5, 88, 8, 40, 2, 63, 4, 76, 0, 69, 
    8, 56, 5, 19, 7, 74, 1, 31, 2, 63, 4, 11, 6, 52, 3, 61, 0, 35, 
    5, 40, 8, 21, 1, 82, 0, 46, 7, 47, 6,  2, 3, 30, 2, 25, 4, 84, 
    4, 37, 6, 25, 7, 29, 1, 29, 3, 68, 0, 38, 2, 11, 8, 39, 5,  2, 
    6, 93, 8, 76, 1, 66, 0, 52, 4, 33, 5, 13, 7, 83, 3, 52, 2, 29, 
    1, 48, 7, 37, 2, 39, 0, 93, 3, 63, 6, 93, 8, 27, 5, 57, 4, 31
  };
  const int q7727[] = {
    9, 9, // Number of jobs and machines
    4, 23, 1, 81, 2, 92, 8, 51, 6, 96, 7, 54, 5, 12, 0, 35, 3, 16, 
    5, 35, 7, 54, 1, 69, 8, 25, 4, 55, 2, 29, 3, 68, 6, 54, 0, 18, 
    6, 65, 3, 38, 4, 69, 8, 26, 7, 82, 1, 58, 0, 75, 5, 34, 2, 19, 
    3, 33, 4, 74, 2, 74, 5, 13, 8, 62, 0, 30, 7, 26, 1, 49, 6, 68, 
    6, 20, 3, 61, 4, 89, 2, 84, 8, 31, 7, 29, 1, 80, 5,  5, 0, 42, 
    8, 49, 7, 56, 4, 68, 2, 17, 5, 41, 6, 45, 0, 55, 3, 68, 1, 59, 
    5, 26, 0, 37, 8, 41, 1, 46, 2, 72, 4, 64, 3, 95, 6, 82, 7, 16, 
    4, 73, 7, 44, 2, 88, 3, 24, 1,  1, 6, 10, 0, 98, 8, 31, 5, 39, 
    0, 36, 6, 56, 8, 41, 4, 89, 1, 90, 2, 35, 3, 75, 7, 31, 5, 99
  };
  const int q7728[] = {
    9, 9, // Number of jobs and machines
    6, 72, 5, 70, 4, 30, 3, 78, 2, 30, 7,  6, 8,  9, 0, 10, 1, 89, 
    8, 59, 2, 53, 7, 67, 4, 51, 0, 97, 3, 82, 5, 44, 1, 70, 6, 27, 
    3, 82, 2, 50, 1,  8, 4, 46, 5, 27, 6, 91, 8, 76, 7, 85, 0, 54, 
    5, 90, 6, 64, 7, 44, 8, 74, 4, 27, 2, 72, 1, 90, 3, 75, 0, 47, 
    3, 66, 8, 90, 1, 93, 6, 54, 0, 94, 2, 26, 5, 94, 7, 35, 4, 40, 
    4, 69, 5, 54, 3, 80, 6,  1, 8, 50, 1,  9, 7, 84, 0, 42, 2, 52, 
    8, 26, 7, 18, 2,  5, 3, 90, 5, 98, 1,  8, 4,  9, 6, 77, 0, 74, 
    2, 19, 8, 57, 7, 85, 5, 72, 1, 92, 4, 78, 6, 26, 3, 87, 0, 53, 
    4, 87, 3, 70, 5, 29, 0, 72, 1,  1, 2, 63, 7, 45, 8,  8, 6, 32
  };
  const int q7729[] = {
    9, 9, // Number of jobs and machines
    6, 97, 4, 60, 3, 28, 5, 33, 7, 57, 1,  2, 2, 52, 8,  7, 0, 17, 
    5, 70, 6, 40, 8, 41, 4, 50, 2, 74, 7, 40, 1, 83, 3, 37, 0, 16, 
    2, 62, 1, 14, 6,  6, 5, 38, 3, 39, 8, 42, 4, 44, 7, 75, 0, 46, 
    2, 28, 5, 56, 8, 53, 4,  7, 7, 39, 3, 71, 1, 65, 6, 41, 0, 82, 
    1, 39, 4, 13, 2, 67, 5, 91, 7, 87, 6, 73, 0, 21, 8, 80, 3, 15, 
    7, 87, 0, 16, 4, 20, 8, 18, 3, 43, 2, 63, 5, 80, 6, 93, 1, 42, 
    2, 13, 0, 79, 8, 43, 5, 62, 1,  5, 3, 32, 6, 84, 7,  6, 4, 70, 
    5, 34, 8, 62, 2, 53, 7, 73, 0, 51, 3, 69, 4, 26, 6, 21, 1,  2, 
    2, 22, 5, 98, 4,  8, 3, 26, 0, 45, 6,  8, 1, 54, 8,  9, 7, 77
  };
  const int q7730[] = {
    9, 9, // Number of jobs and machines
    5, 53, 3, 45, 6, 55, 0, 30, 7, 31, 2, 23, 8, 57, 4, 28, 1, 94, 
    1, 69, 4,  4, 7, 33, 6, 44, 0,  4, 2, 17, 3, 65, 8, 74, 5, 54, 
    0, 55, 7, 79, 4, 53, 1, 34, 3, 78, 5, 95, 6, 38, 2, 59, 8, 55, 
    1, 65, 0, 60, 7, 11, 8, 30, 5, 80, 4, 44, 2,  9, 6, 49, 3, 18, 
    1, 10, 4, 91, 0, 98, 3, 92, 8, 92, 6,  3, 2, 15, 5, 98, 7, 91, 
    3, 41, 5, 58, 4, 99, 7, 26, 6, 75, 2, 19, 8, 11, 1, 30, 0, 36, 
    5, 18, 1, 76, 0, 67, 8, 85, 2, 78, 4, 23, 6,  2, 7, 17, 3, 99, 
    8, 52, 5, 65, 6, 31, 2, 55, 0, 91, 4,  8, 3, 90, 1, 98, 7,  4, 
    3, 69, 0, 74, 4, 86, 6, 19, 8, 70, 5, 85, 1, 78, 2, 37, 7, 60
  };
  const int q7731[] = {
    9, 9, // Number of jobs and machines
    0, 31, 2, 26, 1, 18, 4, 28, 5, 79, 8, 22, 7, 16, 6, 64, 3, 18, 
    5, 39, 1, 95, 6, 33, 7, 64, 0,  4, 4, 59, 3,  9, 2, 15, 8, 90, 
    0, 26, 6, 61, 1,  4, 5, 72, 4, 38, 2, 13, 8, 24, 7, 16, 3, 65, 
    8, 39, 0, 16, 7, 59, 1, 40, 6, 12, 2, 11, 5, 27, 3, 57, 4, 69, 
    8,  5, 2, 45, 0, 11, 6, 52, 7, 10, 1, 48, 5, 36, 3, 29, 4, 61, 
    0, 20, 1, 62, 7, 91, 5, 95, 3, 24, 6, 52, 8, 34, 4, 96, 2, 47, 
    1, 49, 8,  1, 2, 49, 7, 32, 4, 79, 6, 11, 0, 81, 3, 27, 5, 74, 
    0, 50, 7, 27, 1,  9, 5, 13, 4, 93, 8, 68, 2, 23, 6, 90, 3, 17, 
    5,  2, 0, 27, 6, 90, 3, 40, 4, 78, 8, 53, 1, 91, 2,  7, 7, 75
  };
  const int q7732[] = {
    9, 9, // Number of jobs and machines
    4, 93, 3, 80, 0, 45, 8, 96, 2, 68, 1, 25, 6, 33, 7, 48, 5, 25, 
    3, 75, 4,  1, 1, 31, 2, 30, 7, 38, 0, 39, 5, 44, 6, 97, 8, 80, 
    0, 77, 4, 68, 2, 92, 1, 16, 8, 26, 7, 53, 3, 45, 5, 29, 6, 81, 
    4, 88, 5, 79, 8, 75, 3, 30, 6, 73, 0,  1, 2,  7, 1, 88, 7, 18, 
    7,  7, 2, 25, 8,  6, 6,  7, 5, 25, 4, 99, 1, 54, 3, 86, 0, 93, 
    7, 81, 2, 63, 4, 86, 0,  1, 8, 38, 3, 61, 1, 20, 6, 30, 5, 71, 
    1, 27, 5, 60, 0, 88, 3, 54, 2, 99, 7, 60, 6, 13, 8, 98, 4, 41, 
    6, 22, 3, 84, 4,  4, 0, 79, 5, 57, 2, 68, 1, 80, 8, 72, 7, 33, 
    4, 38, 0, 80, 1, 44, 3, 71, 2, 74, 8, 12, 5,  2, 6, 38, 7,  2
  };
  const int q7733[] = {
    9, 9, // Number of jobs and machines
    1, 18, 8, 86, 0, 89, 6, 30, 5, 43, 4, 44, 7, 75, 2, 43, 3, 27, 
    2, 39, 7, 57, 0, 10, 1, 56, 4, 91, 6, 64, 8, 31, 5, 90, 3, 55, 
    3, 86, 6, 24, 0, 26, 5, 11, 2,  6, 1, 79, 4, 49, 8, 72, 7, 50, 
    2, 55, 6,  2, 0, 78, 8, 50, 7,  8, 4, 80, 3, 45, 5, 74, 1, 85, 
    8, 26, 7, 50, 2, 56, 4, 40, 0, 81, 6, 24, 5, 48, 1, 64, 3, 11, 
    8, 44, 3, 70, 6, 50, 0,  4, 5, 11, 2, 13, 1, 90, 4, 78, 7, 73, 
    3, 92, 5, 68, 4, 95, 1, 57, 0, 33, 7,  9, 8,  4, 6, 67, 2,  1, 
    8, 97, 7, 12, 2, 11, 1, 17, 4, 49, 5, 42, 0,  6, 6, 70, 3, 13, 
    0, 22, 5, 33, 1, 88, 6, 92, 3, 41, 2, 40, 4, 67, 8, 83, 7, 38
  };
  const int q7734[] = {
    9, 9, // Number of jobs and machines
    1, 77, 8, 71, 0, 97, 4, 65, 3, 39, 2, 31, 5, 65, 7, 50, 6, 68, 
    8, 87, 1, 99, 6, 20, 3, 73, 4, 17, 2, 28, 0,  1, 5,  4, 7, 25, 
    0, 10, 5, 59, 7, 67, 6, 69, 3,  4, 1, 55, 8, 74, 4, 16, 2,  9, 
    5, 99, 4, 89, 0, 42, 8, 74, 7, 81, 1,  6, 2, 96, 6, 37, 3, 54, 
    7,  7, 2, 15, 0, 14, 4, 77, 8, 41, 6, 93, 1, 38, 3, 69, 5, 18, 
    8,  6, 3, 83, 6,  2, 1, 37, 5,  3, 2,  2, 7, 61, 4, 67, 0, 48, 
    4, 24, 0, 46, 7, 58, 3, 47, 8, 72, 1,  9, 6, 65, 2, 74, 5, 63, 
    6, 55, 1, 98, 0, 73, 5, 36, 4, 10, 7, 92, 8, 49, 3, 22, 2, 30, 
    8,  3, 2,  5, 0, 84, 4, 42, 5, 33, 7, 23, 6, 97, 1, 53, 3, 29
  };
  const int q7735[] = {
    9, 9, // Number of jobs and machines
    5, 80, 6, 27, 8, 98, 1, 45, 4,  1, 7, 26, 3, 88, 0, 26, 2, 94, 
    7, 74, 2, 57, 8, 61, 3, 39, 5, 83, 1, 13, 0, 18, 6, 63, 4, 52, 
    4,  8, 8, 41, 6, 88, 5,  8, 2,  9, 0, 17, 7, 10, 1, 92, 3, 58, 
    7, 52, 6, 27, 4,  2, 0,  4, 5, 76, 3, 10, 8,  9, 2,  2, 1, 66, 
    1,  4, 2,  9, 4, 76, 3, 92, 0,  9, 6, 42, 7, 26, 8, 25, 5, 73, 
    3, 76, 2,  2, 1, 60, 5, 76, 7, 60, 8, 11, 4,  7, 6, 12, 0, 20, 
    2, 86, 6, 38, 8, 28, 5, 43, 4, 52, 1, 41, 3,  7, 0, 48, 7, 80, 
    2, 34, 1, 86, 5, 62, 7, 50, 6, 28, 8,  5, 4, 32, 0, 64, 3, 40, 
    6, 40, 1, 25, 0, 43, 5, 98, 3, 39, 8, 25, 7, 25, 4, 51, 2, 37
  };
  const int q7736[] = {
    9, 9, // Number of jobs and machines
    6, 77, 8, 91, 4, 95, 1, 24, 7, 92, 0, 55, 5, 21, 2, 83, 3, 46, 
    5, 97, 6,  2, 4, 10, 3, 37, 7, 85, 8, 91, 0, 44, 1, 96, 2, 53, 
    3, 38, 7, 60, 1, 97, 2, 15, 8, 64, 5, 84, 4, 61, 6, 23, 0, 73, 
    6, 39, 8, 32, 7, 66, 2, 77, 1,  5, 0, 64, 4, 86, 5, 43, 3, 55, 
    2, 40, 1, 66, 4, 53, 8, 79, 5,  4, 6, 37, 0, 70, 3, 64, 7,  8, 
    2, 69, 8, 72, 1, 36, 0, 80, 5,  2, 4, 19, 3, 85, 7, 41, 6, 37, 
    4, 99, 1, 95, 8, 21, 3, 62, 6, 36, 0, 98, 7, 19, 5, 36, 2, 50, 
    8, 30, 5, 25, 4, 88, 0, 24, 6, 74, 3, 83, 1, 27, 7, 29, 2, 72, 
    2, 27, 7, 56, 6, 29, 3, 55, 5, 88, 0, 91, 1, 84, 4, 67, 8, 74
  };
  const int q7737[] = {
    9, 9, // Number of jobs and machines
    8,  7, 1, 90, 5, 48, 3, 96, 7, 88, 6, 35, 0, 91, 2, 98, 4,  2, 
    4, 49, 5, 17, 2, 91, 0, 77, 1, 71, 6, 72, 3, 27, 8, 54, 7, 70, 
    0, 75, 1, 59, 5, 91, 3, 71, 4, 40, 7, 24, 2, 76, 6, 58, 8, 20, 
    2, 90, 8, 98, 1, 82, 7, 14, 0, 19, 3, 36, 6, 80, 4, 88, 5, 97, 
    2, 82, 1, 76, 4, 12, 8, 18, 5, 48, 7, 43, 0,  3, 6, 14, 3, 19, 
    3, 46, 4, 58, 8, 57, 5, 99, 1, 85, 2, 10, 6, 43, 7, 24, 0, 21, 
    8, 82, 3, 14, 0, 79, 5, 31, 7, 89, 6, 67, 1, 67, 4, 44, 2, 99, 
    8, 16, 0, 84, 2, 29, 1, 53, 7, 73, 6,  5, 3, 85, 5, 74, 4, 46, 
    7, 81, 1, 63, 3, 79, 4, 16, 5, 14, 2, 64, 8, 61, 0,  1, 6, 69
  };
  const int q7738[] = {
    9, 9, // Number of jobs and machines
    4, 38, 2, 91, 7, 92, 5, 68, 6, 10, 0, 90, 3, 90, 1, 76, 8,  5, 
    3, 30, 8, 73, 4, 45, 0, 99, 2, 72, 6, 81, 1,  6, 7,  5, 5, 95, 
    3, 87, 8,  8, 6, 94, 5,  9, 1, 10, 0, 22, 7, 72, 4, 69, 2, 60, 
    0, 69, 1, 89, 8, 65, 5, 63, 4, 27, 3, 12, 6, 56, 2, 34, 7, 45, 
    1, 83, 0, 15, 2, 67, 7, 90, 8, 68, 4, 85, 3, 32, 5, 14, 6, 16, 
    5, 22, 2,  7, 0, 34, 8, 32, 4, 22, 1, 27, 6, 82, 3, 29, 7, 85, 
    5,  9, 3, 32, 4, 16, 6,  4, 7, 90, 1, 45, 0, 28, 8, 45, 2, 37, 
    5, 65, 6, 99, 3, 62, 2, 18, 1,  5, 7, 68, 0, 37, 8, 84, 4, 55, 
    8, 97, 7, 50, 3, 66, 6, 46, 0,  4, 2, 80, 4, 65, 5, 31, 1, 28
  };
  const int q7739[] = {
    9, 9, // Number of jobs and machines
    4,  2, 3, 83, 2, 98, 5, 36, 0, 61, 1,  9, 6, 53, 8,  3, 7, 71, 
    4, 61, 8, 95, 6, 80, 5, 38, 3, 64, 2, 36, 0, 97, 1,  4, 7, 32, 
    1, 16, 5, 67, 7, 88, 4, 46, 8, 97, 3, 31, 0, 21, 2, 61, 6, 82, 
    7, 56, 8, 71, 1,  4, 3,  6, 6, 25, 5, 91, 0, 42, 4, 37, 2, 85, 
    7, 74, 4, 84, 5, 96, 1, 94, 0, 84, 6, 77, 2, 50, 3, 72, 8, 86, 
    8, 51, 3, 51, 2, 82, 4, 74, 6, 49, 1, 66, 0, 36, 5, 67, 7, 97, 
    3, 64, 1, 89, 0, 12, 8, 94, 4, 67, 2, 14, 7, 46, 5,  6, 6, 68, 
    7, 87, 1, 77, 2, 58, 0, 83, 8, 32, 6, 79, 3, 22, 5, 64, 4, 31, 
    1, 25, 6, 29, 8, 23, 7, 49, 2, 77, 0, 88, 4, 98, 5, 72, 3, 44
  };
  const int q7740[] = {
    9, 9, // Number of jobs and machines
    6, 56, 7, 60, 8, 38, 4, 26, 1, 18, 2, 47, 5, 90, 0, 80, 3, 35, 
    7, 34, 1, 20, 4, 17, 2, 31, 5, 74, 0, 79, 3, 86, 6, 55, 8, 74, 
    3, 72, 1, 83, 4,  9, 5, 20, 2, 21, 8, 72, 0, 19, 6, 48, 7, 65, 
    4, 11, 5, 36, 3, 25, 8, 94, 1, 26, 2, 19, 6, 63, 7, 71, 0, 52, 
    5, 50, 6, 80, 8, 22, 1, 18, 3, 38, 0, 40, 2, 54, 7, 30, 4, 49, 
    7, 94, 3, 79, 8, 65, 6, 84, 5, 49, 2, 78, 0, 86, 4, 89, 1, 73, 
    0, 99, 7, 31, 2, 39, 8, 27, 4, 74, 1,  1, 3,  7, 5, 45, 6, 67, 
    1, 17, 7, 99, 3, 58, 5, 87, 2, 85, 4, 13, 6, 36, 0, 52, 8,  4, 
    3, 87, 8, 38, 2, 73, 0, 49, 1, 61, 6, 59, 4, 14, 7, 21, 5, 61
  };
  const int q7741[] = {
    9, 9, // Number of jobs and machines
    1, 15, 5, 76, 3, 47, 2, 75, 7, 43, 6, 83, 0, 48, 4, 93, 8,  4, 
    4, 67, 8, 89, 5, 22, 6, 54, 2, 88, 3, 66, 1, 80, 0, 22, 7, 84, 
    5, 39, 0, 42, 3,  5, 4, 52, 7, 83, 1, 68, 2, 56, 6, 71, 8, 43, 
    4, 59, 1, 23, 8, 59, 0, 49, 5, 87, 2,  3, 7, 64, 6, 89, 3, 18, 
    5, 95, 4, 78, 7, 10, 6, 75, 0, 50, 8, 44, 2, 85, 1, 34, 3,  3, 
    1,  1, 6, 49, 5, 31, 0, 23, 2, 33, 3, 37, 7, 64, 8, 28, 4, 26, 
    3, 71, 5, 60, 1, 94, 0, 56, 8, 70, 6, 17, 7, 57, 2, 79, 4, 71, 
    1, 32, 8, 46, 5,  9, 6, 91, 2, 31, 3, 33, 0, 99, 4, 37, 7, 34, 
    2, 33, 4, 45, 0, 74, 6, 96, 7,  3, 3, 61, 1, 90, 5, 96, 8, 25
  };
  const int q7742[] = {
    9, 9, // Number of jobs and machines
    4, 18, 7, 29, 1, 48, 5, 42, 3, 43, 8, 32, 6, 63, 2, 25, 0, 52, 
    8, 82, 1, 34, 7, 91, 4, 75, 5, 17, 3, 71, 0, 84, 6, 28, 2, 58, 
    3, 22, 4,  6, 2, 49, 8, 48, 0, 86, 6,  1, 1, 50, 5, 87, 7,  7, 
    1, 14, 5, 85, 7, 74, 0, 65, 2, 48, 8, 69, 3, 37, 6,  7, 4, 47, 
    0, 66, 5, 95, 4, 78, 3, 72, 6, 94, 7,  7, 1, 18, 2, 11, 8, 23, 
    6, 16, 7, 90, 3, 91, 0, 81, 8, 37, 1, 46, 5, 56, 4, 19, 2, 95, 
    3, 11, 1, 61, 8, 63, 4, 99, 5, 95, 7, 59, 2, 20, 6, 94, 0, 74, 
    5, 81, 2, 67, 6, 91, 3, 96, 7, 20, 8, 62, 4, 46, 1, 86, 0, 97, 
    0,  3, 4, 51, 7, 43, 6, 25, 2, 21, 1, 79, 8, 53, 5,  7, 3, 80
  };
  const int q7743[] = {
    9, 9, // Number of jobs and machines
    2, 82, 4, 48, 5, 29, 0, 75, 8, 53, 3, 81, 1, 99, 7, 83, 6,  3, 
    1, 87, 8, 99, 6, 55, 2, 82, 4, 70, 3, 38, 5, 45, 0, 94, 7, 76, 
    3, 54, 8, 28, 5, 20, 2, 59, 6, 11, 7,  4, 1, 12, 0, 91, 4,  9, 
    2, 87, 5, 67, 4, 37, 8, 81, 0, 52, 7, 41, 6,  1, 3, 50, 1, 88, 
    5, 41, 7, 52, 8, 53, 0, 67, 4,  5, 6, 45, 3, 46, 2, 76, 1, 56, 
    6, 98, 7, 39, 0, 30, 3, 16, 4,  4, 5, 80, 1, 68, 2, 78, 8, 62, 
    2, 73, 3, 72, 5, 11, 6, 24, 0, 80, 4, 14, 7, 36, 1, 97, 8, 38, 
    2, 58, 0, 58, 4,  2, 5, 30, 1, 56, 6, 54, 8, 77, 7, 34, 3, 54, 
    8, 69, 7, 78, 3, 27, 1, 47, 0, 35, 4, 61, 2, 14, 6, 11, 5, 46
  };
  const int q7744[] = {
    9, 9, // Number of jobs and machines
    2, 79, 7, 81, 0, 92, 1, 32, 8, 28, 3, 64, 6, 95, 4, 46, 5, 51, 
    0, 45, 5, 76, 1, 54, 2, 59, 3, 45, 6, 69, 7, 56, 8, 21, 4, 17, 
    0, 69, 8, 27, 3,  9, 1, 93, 7, 21, 2, 92, 6, 36, 4,  6, 5, 75, 
    3, 93, 5,  1, 8, 63, 2, 48, 7, 47, 6,  1, 1, 84, 4, 74, 0, 87, 
    2, 27, 4, 18, 3, 39, 8, 10, 1, 63, 5, 76, 0, 79, 7,  1, 6, 61, 
    5,  8, 0, 46, 8, 39, 4,  8, 1, 39, 3, 98, 7, 34, 2, 22, 6, 46, 
    7,  6, 5, 41, 1, 43, 3, 94, 0, 39, 4, 58, 8, 26, 6,  8, 2, 94, 
    6, 85, 0, 54, 1, 24, 3, 78, 2, 72, 8, 51, 7, 34, 4, 39, 5, 54, 
    3,  3, 1, 34, 5, 66, 0, 15, 4,  6, 6, 97, 2, 10, 8, 49, 7, 69
  };
  const int q7745[] = {
    9, 9, // Number of jobs and machines
    2,  2, 0, 75, 8, 76, 5, 78, 6, 64, 4, 25, 7, 88, 3, 69, 1, 73, 
    3, 60, 5, 37, 2, 29, 8, 34, 6, 31, 0, 80, 1, 92, 4, 64, 7, 68, 
    0, 97, 2, 58, 5, 52, 3, 14, 6, 90, 4, 27, 7, 61, 8, 24, 1, 98, 
    2, 44, 3, 28, 7, 67, 1, 12, 6, 28, 5, 26, 0, 56, 8, 94, 4, 35, 
    5, 14, 6, 35, 0, 51, 3, 12, 7, 12, 8, 83, 4, 85, 2, 12, 1, 30, 
    7, 88, 3, 40, 1, 22, 0, 83, 6, 21, 4, 34, 5, 51, 8, 18, 2, 59, 
    6, 65, 1, 26, 7, 90, 4, 36, 8, 24, 2, 19, 3, 96, 0, 22, 5, 79, 
    7, 14, 1, 10, 3, 95, 5, 78, 2, 56, 4, 38, 6, 64, 8, 35, 0, 77, 
    2,  3, 8, 41, 0, 89, 4, 43, 7, 81, 6, 24, 3, 89, 1,  7, 5, 77
  };
  const int q7746[] = {
    9, 9, // Number of jobs and machines
    4, 82, 3, 92, 0,  4, 2, 21, 6, 13, 1, 47, 5, 11, 8, 20, 7, 47, 
    0, 82, 2, 31, 1, 41, 8, 72, 5, 62, 3, 19, 4, 22, 7, 22, 6,  5, 
    0, 74, 2, 26, 8, 79, 6,  8, 3,  6, 1,  9, 7, 55, 5, 19, 4, 54, 
    6, 73, 1,  4, 4, 14, 0, 34, 8,  8, 2, 41, 5, 24, 7, 81, 3, 44, 
    1, 25, 6, 88, 0, 90, 8, 30, 4, 75, 3, 38, 2, 89, 5, 73, 7, 35, 
    0, 24, 8, 72, 2, 43, 4, 21, 5, 54, 1, 58, 7, 12, 3, 32, 6, 69, 
    0, 96, 8, 20, 2, 77, 7, 55, 4, 91, 5, 81, 1, 83, 3, 84, 6, 54, 
    6, 48, 5, 30, 2, 43, 1, 82, 4, 64, 0, 53, 7,  5, 3, 68, 8, 48, 
    4, 52, 8, 33, 3, 41, 0, 24, 1, 64, 2, 78, 6,  5, 5, 37, 7, 12
  };
  const int q7747[] = {
    9, 9, // Number of jobs and machines
    4, 16, 7, 79, 8, 50, 5, 65, 0, 62, 3,  1, 1, 86, 2, 70, 6, 21, 
    0, 73, 7, 95, 4, 35, 2, 58, 3, 31, 8, 87, 5, 79, 1, 94, 6, 12, 
    5, 60, 0, 16, 1, 85, 3, 45, 2, 83, 7, 62, 8, 87, 6, 23, 4, 62, 
    5, 53, 6, 99, 2,  9, 7, 98, 0, 63, 8, 78, 3, 82, 1, 50, 4, 96, 
    4, 59, 1, 21, 8, 23, 6,  4, 7, 22, 2,  6, 3, 75, 0,  6, 5,  3, 
    0, 75, 2, 16, 7, 43, 3, 49, 5, 43, 8, 80, 4, 67, 1, 73, 6, 57, 
    0,  8, 4,  2, 5, 69, 7,  4, 3, 86, 2,  1, 1, 74, 6, 26, 8, 59, 
    4, 71, 6, 32, 3, 99, 8, 69, 1, 74, 5, 75, 0,  3, 2, 79, 7, 86, 
    6, 77, 5, 92, 0, 70, 3, 49, 8, 98, 1, 75, 7, 16, 2, 93, 4, 25
  };
  const int q7748[] = {
    9, 9, // Number of jobs and machines
    6, 49, 3, 91, 2, 72, 1, 79, 5, 91, 0, 92, 4, 48, 8, 50, 7, 75, 
    1, 22, 8, 15, 3, 25, 0, 29, 7, 28, 2, 87, 4, 46, 6, 94, 5, 91, 
    3, 16, 6,  3, 7, 37, 0, 14, 1, 70, 5, 99, 2, 93, 8, 98, 4,  2, 
    3, 97, 7, 99, 8, 11, 2, 36, 0, 47, 5, 57, 4, 73, 6, 51, 1, 53, 
    7, 88, 2, 26, 5, 77, 8, 19, 0, 22, 4,  5, 1, 31, 6, 11, 3, 43, 
    8, 20, 1, 33, 3, 84, 2,  9, 0, 75, 4, 71, 6, 48, 5, 27, 7, 51, 
    5, 75, 8, 98, 4, 15, 3, 57, 0, 15, 7, 31, 6, 41, 1, 98, 2, 19, 
    8, 50, 1, 92, 4, 38, 3, 47, 6, 61, 0, 57, 7,  7, 5, 74, 2,  5, 
    3, 39, 5, 11, 7, 26, 8, 61, 6, 66, 4, 59, 0, 69, 2, 24, 1, 27
  };
  const int q7749[] = {
    9, 9, // Number of jobs and machines
    0,  6, 1, 36, 5, 16, 6, 70, 4, 31, 7, 10, 3, 28, 8, 75, 2, 75, 
    6, 90, 0, 28, 2, 44, 7, 24, 1, 98, 8, 86, 5, 65, 3, 29, 4, 81, 
    6, 92, 0, 16, 8, 99, 5, 83, 3, 73, 2, 34, 4, 91, 7, 69, 1, 87, 
    0, 81, 1, 79, 5, 18, 7, 78, 2, 21, 3, 81, 4, 74, 6,  2, 8, 13, 
    1, 91, 3, 20, 2, 31, 8, 85, 5, 17, 6, 37, 7, 14, 4,  7, 0, 57, 
    0, 91, 1, 23, 4, 92, 6, 53, 5, 69, 7, 85, 3, 51, 2, 68, 8, 57, 
    7, 56, 3, 66, 5, 55, 2, 49, 8, 86, 6, 79, 4, 66, 1, 99, 0, 33, 
    5, 95, 6, 56, 2, 21, 4, 80, 1, 93, 8, 17, 7, 95, 3, 39, 0,  1, 
    0, 46, 1, 32, 5, 10, 6, 22, 3, 75, 2, 86, 7, 36, 4, 73, 8, 43
  };
  const int q7750[] = {
    9, 9, // Number of jobs and machines
    8, 45, 1, 73, 6, 28, 4, 83, 2, 48, 3, 31, 7, 98, 0, 93, 5, 57, 
    1,  2, 2, 75, 5,  5, 7, 86, 4, 19, 0, 14, 6, 80, 8, 69, 3, 97, 
    0, 47, 2, 98, 6, 30, 4,  6, 8, 83, 5, 73, 7, 40, 3, 92, 1,  2, 
    2,  5, 7, 73, 5, 12, 4,  9, 1, 90, 0, 51, 8, 38, 3, 92, 6,  2, 
    7, 55, 8, 92, 3, 35, 6, 98, 2, 47, 0, 19, 1, 99, 5, 65, 4, 39, 
    1, 88, 2, 48, 0, 92, 7, 67, 4, 60, 3, 48, 8, 53, 6, 57, 5, 32, 
    5, 44, 7, 98, 2, 73, 8, 69, 1, 26, 6, 92, 3, 41, 0, 93, 4, 81, 
    3, 93, 2, 37, 7, 82, 0, 59, 1, 69, 5, 68, 4, 76, 6, 61, 8, 10, 
    7, 85, 3, 48, 6, 49, 0, 38, 8, 61, 4, 80, 2, 57, 5, 62, 1, 60
  };
  const int q7751[] = {
    9, 9, // Number of jobs and machines
    4,  2, 5,  1, 7, 74, 1, 23, 8, 46, 3, 91, 2, 59, 6, 98, 0, 81, 
    2, 77, 7, 12, 4, 12, 3, 94, 5, 73, 1, 38, 8, 42, 0, 83, 6, 51, 
    6,  8, 3, 25, 1, 74, 8, 94, 5, 34, 2, 31, 7, 36, 0, 32, 4, 20, 
    2, 59, 5, 37, 4, 60, 7, 81, 8, 74, 0, 13, 3, 40, 1, 20, 6, 69, 
    8, 29, 6, 34, 4, 54, 5, 42, 2, 22, 3, 23, 7, 84, 0, 88, 1,  7, 
    3, 80, 7, 61, 5, 15, 4, 59, 0, 68, 6, 72, 1, 29, 8,  2, 2, 18, 
    6, 91, 4, 19, 8,  7, 2, 67, 5, 50, 0, 59, 3, 29, 1, 56, 7, 19, 
    8, 21, 7, 50, 3, 75, 1, 14, 4, 60, 6, 24, 5, 18, 0, 61, 2, 14, 
    2, 69, 0, 17, 6, 34, 3, 59, 1, 80, 7, 59, 8,  9, 5, 38, 4, 28
  };
  const int q7752[] = {
    9, 9, // Number of jobs and machines
    7, 91, 5,  1, 0, 28, 8, 79, 4, 41, 1, 29, 3, 52, 2, 95, 6, 13, 
    5, 53, 1, 29, 0, 91, 4, 56, 6, 49, 2, 79, 8, 63, 3, 36, 7, 67, 
    6, 81, 0, 78, 8, 63, 5, 53, 3, 93, 1, 15, 2,  2, 7, 28, 4, 18, 
    1,  7, 6, 16, 2, 38, 0, 78, 5,  2, 3, 84, 4, 11, 8, 95, 7, 38, 
    1, 29, 7, 50, 6, 79, 0, 42, 3,  5, 4, 94, 5, 38, 8,  1, 2, 42, 
    7, 84, 3, 69, 5, 88, 2, 83, 6, 36, 4, 17, 8, 37, 1, 43, 0, 68, 
    5, 81, 2, 26, 7, 79, 0, 13, 8, 10, 6, 65, 4, 30, 1, 91, 3, 40, 
    8, 51, 3, 68, 5, 16, 6, 64, 7, 42, 4, 88, 1, 49, 2, 46, 0, 78, 
    3, 94, 1, 52, 7,  6, 2, 99, 4, 38, 5, 96, 0, 21, 8, 78, 6, 78
  };
  const int q7753[] = {
    9, 9, // Number of jobs and machines
    8, 34, 2, 26, 7, 93, 1, 21, 4,  3, 3,  7, 0, 16, 5, 93, 6, 86, 
    5, 44, 3, 25, 7, 62, 6, 38, 2, 18, 0, 65, 8, 36, 4, 26, 1, 25, 
    7, 35, 5, 20, 2, 23, 0,  8, 3,  9, 6, 41, 1, 19, 8, 55, 4, 63, 
    6, 69, 3, 23, 2, 20, 0, 24, 1, 43, 8, 17, 7,  4, 4, 51, 5, 71, 
    5, 36, 2, 14, 7, 49, 1, 49, 6, 37, 4, 38, 0, 80, 3, 33, 8, 96, 
    1, 43, 5, 73, 7, 82, 6, 87, 0, 99, 8, 40, 4, 47, 3, 26, 2, 24, 
    3, 83, 0, 58, 4, 66, 6, 77, 8, 60, 7, 84, 1, 46, 2, 51, 5, 60, 
    1,  3, 2, 73, 0, 46, 8, 25, 4, 98, 3, 91, 6, 76, 7, 89, 5, 69, 
    1, 51, 0, 86, 2, 36, 6, 73, 4, 67, 8, 16, 5, 19, 3, 41, 7, 11
  };
  const int q7754[] = {
    9, 9, // Number of jobs and machines
    7, 86, 0, 28, 4, 51, 5, 82, 8, 40, 1, 49, 6, 18, 2, 31, 3, 99, 
    3, 32, 5, 10, 1, 51, 0, 52, 4, 54, 8, 89, 7, 14, 6, 97, 2, 34, 
    5, 69, 7, 15, 3, 63, 6, 53, 8, 15, 4, 76, 1, 53, 2, 24, 0, 47, 
    8, 40, 2, 67, 3, 55, 5, 35, 6, 92, 4, 76, 7, 25, 0, 76, 1, 84, 
    4, 34, 0, 70, 5, 20, 8, 17, 7, 81, 1, 99, 6, 37, 3, 83, 2, 40, 
    8, 27, 7, 68, 6, 74, 5, 55, 2, 71, 1, 42, 0, 94, 3, 51, 4, 67, 
    5,  1, 7, 72, 4, 18, 2, 50, 1, 31, 8, 53, 3, 80, 6, 65, 0, 17, 
    6, 68, 1, 54, 5, 10, 4, 18, 0, 71, 8, 71, 2, 57, 7, 23, 3, 39, 
    1, 38, 3, 83, 8, 57, 0, 26, 5, 54, 2,  9, 7, 68, 6, 52, 4, 27
  };
  const int q7755[] = {
    9, 9, // Number of jobs and machines
    3, 44, 7, 31, 6, 84, 0, 37, 4, 92, 8, 82, 2, 86, 5, 29, 1, 15, 
    6, 15, 0, 68, 2, 89, 4, 19, 8, 44, 3, 39, 1, 86, 5, 51, 7, 31, 
    6, 32, 3, 11, 1, 32, 5,  4, 0, 31, 2,  6, 4, 85, 8, 94, 7, 83, 
    8, 44, 4, 90, 3, 77, 6, 45, 1, 52, 0, 41, 5, 51, 2, 95, 7, 67, 
    6, 44, 1, 66, 4, 52, 7,  7, 5, 35, 2,  7, 3, 41, 0, 97, 8, 30, 
    0, 31, 7, 36, 6, 17, 8, 20, 1, 99, 2,  5, 4, 24, 3, 12, 5, 88, 
    5, 14, 0, 17, 3, 91, 1, 70, 8, 73, 6, 98, 4, 71, 7, 38, 2, 34, 
    4, 92, 1, 76, 7, 42, 0, 60, 3, 23, 8, 10, 6, 68, 2, 12, 5, 36, 
    8, 30, 2, 14, 6, 17, 3, 38, 4, 83, 5, 11, 7, 25, 0, 20, 1, 15
  };
  const int q7756[] = {
    9, 9, // Number of jobs and machines
    3, 26, 4, 22, 0, 57, 7, 31, 8, 21, 2, 24, 1, 94, 6, 16, 5,  2, 
    7, 41, 0, 73, 4, 81, 8, 45, 1,  3, 6, 39, 3, 51, 2, 63, 5, 60, 
    2, 86, 5, 95, 8, 68, 3, 57, 0, 31, 1, 48, 6, 32, 4, 72, 7, 41, 
    1, 43, 4, 60, 7, 58, 2, 59, 5, 76, 6,  8, 3, 31, 8, 65, 0, 60, 
    8, 29, 6, 29, 4, 82, 5, 29, 7, 49, 0, 60, 1, 10, 2,  8, 3, 90, 
    7,  8, 1,  1, 3, 70, 2, 14, 8, 75, 6,  7, 4, 90, 5, 13, 0, 96, 
    6, 57, 0,  2, 1, 26, 7, 93, 3, 91, 2, 37, 4, 63, 5,  2, 8,  3, 
    7, 97, 6, 33, 1, 49, 5, 38, 3, 27, 2, 45, 4, 86, 0, 64, 8, 42, 
    8, 69, 2, 46, 5,  8, 4, 93, 1, 74, 6, 43, 3, 84, 0, 27, 7, 72
  };
  const int q7757[] = {
    9, 9, // Number of jobs and machines
    1, 14, 7, 65, 2, 31, 3, 95, 0, 30, 4, 50, 6,  1, 5, 73, 8, 14, 
    0, 61, 8, 74, 3, 48, 1, 53, 4, 25, 6, 59, 2,  2, 5, 41, 7, 31, 
    6,  3, 5, 74, 4, 18, 1, 75, 3, 13, 2, 57, 0, 47, 8, 17, 7, 21, 
    7, 73, 6, 32, 3, 75, 0, 36, 1, 11, 4, 74, 2, 98, 8, 17, 5, 96, 
    6, 66, 4, 80, 5, 78, 8, 79, 0, 69, 3, 14, 7, 57, 1, 29, 2, 37, 
    6, 64, 3, 29, 5, 83, 7, 17, 1, 77, 8, 86, 0, 97, 2, 40, 4, 68, 
    1,  1, 0, 99, 5, 34, 4, 52, 2, 36, 7, 69, 6, 22, 8, 87, 3, 40, 
    4, 58, 6, 45, 7, 45, 2, 55, 1,  1, 0, 63, 8, 96, 5, 72, 3, 73, 
    6, 64, 2, 90, 4, 43, 8, 52, 0, 18, 3, 27, 1, 22, 7,  5, 5,  4
  };
  const int q7758[] = {
    9, 9, // Number of jobs and machines
    6, 56, 2, 95, 1, 88, 3, 46, 5,  6, 7, 53, 4,  4, 0, 70, 8, 24, 
    0,  7, 3, 37, 8, 70, 4, 41, 2, 70, 6, 81, 1, 29, 5, 97, 7, 97, 
    6, 99, 4, 78, 2, 20, 7, 61, 8, 96, 1, 50, 3, 71, 5, 67, 0, 56, 
    5, 67, 7, 16, 1, 63, 0, 61, 6, 40, 2, 28, 8,  1, 3, 37, 4, 86, 
    2, 80, 4, 40, 3, 48, 0, 99, 7, 10, 5, 50, 8, 45, 6, 33, 1,  1, 
    7, 40, 8, 22, 2, 64, 6, 63, 3, 99, 1, 86, 4, 11, 5, 38, 0, 82, 
    7, 19, 2, 17, 8,  2, 6, 22, 1, 39, 0, 79, 5, 99, 4, 20, 3, 47, 
    1, 82, 2, 10, 0, 45, 6,  3, 8, 84, 4, 18, 3, 37, 5, 19, 7, 87, 
    7, 99, 4, 56, 0, 83, 3, 23, 2, 65, 1,  3, 5, 68, 6, 24, 8, 44
  };
  const int q7759[] = {
    9, 9, // Number of jobs and machines
    6, 72, 4, 83, 0, 11, 7,  7, 3, 38, 2, 58, 1, 61, 8, 40, 5,  8, 
    4, 14, 3, 89, 1, 89, 2, 61, 0, 61, 5, 37, 8, 67, 7, 73, 6, 23, 
    7,  4, 4, 93, 8, 63, 5, 77, 6, 27, 3, 15, 1, 12, 0, 54, 2, 81, 
    2, 51, 7, 37, 1, 60, 8, 20, 5, 32, 6, 63, 3, 68, 4,  1, 0,  5, 
    5,  2, 4, 84, 6, 41, 2, 15, 7, 17, 1, 83, 0, 52, 3, 34, 8, 47, 
    6, 86, 0, 20, 5, 92, 4, 95, 3, 13, 2, 35, 7, 84, 1, 97, 8, 87, 
    6,  4, 0, 64, 1, 42, 3,  8, 5, 75, 4,  1, 8, 90, 2,  2, 7, 34, 
    6, 58, 1, 29, 7, 96, 4, 87, 0, 56, 5, 55, 3, 56, 2, 56, 8, 36, 
    6, 66, 1, 20, 2, 70, 7, 65, 0, 97, 4, 92, 8, 55, 5,  7, 3,  5
  };
  const int q7760[] = {
    9, 9, // Number of jobs and machines
    1, 86, 3, 60, 8, 54, 7, 44, 0, 24, 4, 78, 6, 24, 2,  9, 5, 98, 
    0, 83, 3, 57, 7, 84, 4, 15, 6, 33, 5, 72, 1, 18, 2,  1, 8, 98, 
    3, 36, 2, 43, 0, 92, 1, 26, 4, 90, 7, 81, 6, 50, 5, 71, 8, 26, 
    5, 21, 1, 79, 3, 80, 7, 30, 4,  2, 6, 28, 8, 43, 0, 67, 2, 14, 
    0, 78, 6, 93, 5, 56, 2, 37, 1, 89, 4, 75, 3, 74, 8, 17, 7, 37, 
    8, 56, 6, 75, 1, 91, 4, 21, 5,  5, 0, 59, 3, 26, 2, 44, 7, 66, 
    1, 23, 2, 75, 8, 91, 3, 49, 5, 52, 4, 22, 7, 67, 0, 66, 6, 50, 
    8, 48, 3, 49, 6, 92, 5, 69, 7, 94, 1, 60, 4, 80, 2, 97, 0, 18, 
    5, 29, 3, 41, 8, 22, 7, 20, 6, 51, 2, 43, 1, 33, 0, 49, 4, 67
  };
  const int q7761[] = {
    9, 9, // Number of jobs and machines
    1, 50, 8, 29, 4, 59, 0, 42, 7, 79, 2, 72, 6, 44, 5, 19, 3, 27, 
    8, 32, 6, 81, 5, 80, 0, 73, 7,  5, 3, 31, 4, 45, 1, 74, 2, 21, 
    1, 23, 2, 80, 5, 12, 8, 13, 6, 56, 4, 60, 0, 52, 3,  8, 7, 44, 
    1, 22, 5, 19, 2, 43, 7, 78, 3, 50, 6, 77, 8, 62, 4, 46, 0,  9, 
    0, 43, 8, 30, 2, 14, 4, 21, 1, 60, 3, 82, 5, 76, 7, 85, 6, 80, 
    5, 99, 2, 70, 0, 39, 7, 15, 4,  4, 8, 82, 6, 11, 3, 46, 1, 40, 
    6, 66, 5, 14, 3, 74, 7, 22, 1, 18, 4, 87, 2, 71, 0, 68, 8, 27, 
    4, 71, 2, 40, 1, 44, 3, 34, 6, 51, 0, 60, 8, 59, 7, 96, 5, 15, 
    1, 47, 3,  6, 2, 19, 8, 73, 5, 20, 0, 28, 7,  2, 4, 24, 6, 44
  };
  const int q7762[] = {
    9, 9, // Number of jobs and machines
    7, 30, 8, 47, 6, 62, 1, 88, 4, 84, 5, 54, 0, 29, 3, 41, 2, 80, 
    2, 95, 6, 27, 3, 65, 1,  4, 8,  2, 0, 87, 7, 85, 5, 20, 4, 61, 
    3, 20, 5,  9, 4, 57, 0, 79, 1,  4, 8, 59, 7, 37, 6, 58, 2, 19, 
    7, 90, 5, 19, 4, 89, 2, 46, 0, 27, 6, 53, 1, 51, 8, 20, 3, 74, 
    0, 74, 4, 35, 3, 95, 1, 28, 8, 21, 7, 86, 6,  3, 2, 23, 5, 52, 
    5, 86, 8, 77, 3, 72, 0, 31, 2,  6, 6, 28, 4, 51, 7, 95, 1, 17, 
    6, 19, 7, 97, 0,  7, 5, 82, 2, 46, 3, 36, 8, 51, 1, 27, 4, 60, 
    3, 32, 2, 88, 7, 54, 6, 69, 1, 99, 5, 97, 4, 42, 8, 11, 0, 23, 
    2, 65, 8, 99, 3, 14, 6, 74, 7, 35, 1, 27, 0, 71, 4, 21, 5, 47
  };
  const int q7763[] = {
    9, 9, // Number of jobs and machines
    5, 25, 1, 19, 3, 59, 8, 12, 0, 94, 4, 49, 7, 24, 2,  4, 6, 45, 
    2, 32, 0, 25, 3, 64, 4, 74, 1, 48, 7, 93, 8, 57, 6, 78, 5, 77, 
    1, 82, 0, 62, 2, 54, 7, 36, 4, 25, 3, 58, 6, 43, 5, 43, 8, 36, 
    8, 77, 0, 72, 3, 79, 6, 75, 2, 61, 5, 35, 1,  7, 4, 62, 7, 81, 
    1, 44, 8, 62, 4, 68, 3, 61, 5,  3, 6,  8, 2, 34, 0, 70, 7, 16, 
    7, 50, 6, 80, 1, 77, 2,  3, 5, 70, 8, 46, 4, 43, 3, 33, 0, 70, 
    5, 61, 8,  9, 4, 46, 0, 91, 1, 54, 7, 62, 2, 28, 6, 89, 3, 38, 
    5, 11, 3, 18, 1, 89, 6, 55, 0, 66, 7, 34, 8, 25, 2, 83, 4, 72, 
    6, 22, 7, 73, 8, 25, 0, 61, 2, 58, 5, 78, 1, 20, 4, 38, 3, 15
  };
  const int q7764[] = {
    9, 9, // Number of jobs and machines
    8, 57, 1, 11, 7,  4, 6, 47, 4, 99, 0, 92, 3, 86, 2, 18, 5, 39, 
    7, 94, 0, 26, 3, 36, 5, 34, 1,  8, 2, 74, 8, 94, 4, 80, 6, 46, 
    1, 11, 4, 27, 5, 78, 6, 79, 0, 37, 7, 60, 2, 41, 8, 32, 3, 67, 
    3, 27, 2, 25, 0, 48, 1, 98, 4, 99, 7, 27, 6, 83, 5, 35, 8, 57, 
    8, 85, 0, 22, 6, 41, 7, 42, 1, 23, 2, 83, 4, 62, 3, 33, 5, 69, 
    8, 29, 6, 25, 4, 60, 1, 20, 3, 35, 2, 18, 7, 92, 5, 89, 0, 12, 
    5, 47, 1, 85, 6, 45, 0, 99, 3, 18, 7, 91, 8, 88, 2, 57, 4, 91, 
    0, 42, 5, 30, 4, 68, 7, 18, 6, 93, 3, 69, 2, 82, 8, 79, 1, 21, 
    4, 13, 3, 10, 7, 36, 6, 62, 8, 91, 1, 95, 5, 91, 0, 18, 2, 67
  };
  const int q7765[] = {
    9, 9, // Number of jobs and machines
    5, 13, 4, 54, 8, 27, 2, 79, 1, 29, 0, 15, 6, 12, 7, 97, 3, 71, 
    3, 43, 6, 20, 8, 30, 7, 55, 0, 66, 4, 87, 2, 35, 5, 12, 1, 81, 
    2, 15, 1, 68, 5, 36, 6, 59, 8, 96, 0, 89, 3, 35, 4, 17, 7, 75, 
    0,  8, 2, 81, 3, 60, 7, 10, 8, 25, 6, 49, 5, 49, 4, 13, 1,  2, 
    6, 42, 5, 32, 8, 24, 3, 60, 2, 47, 0, 81, 4, 57, 1, 49, 7, 68, 
    8, 21, 5, 86, 0, 93, 2, 36, 1, 56, 4, 76, 6, 95, 3, 95, 7, 22, 
    0, 85, 2, 53, 5, 15, 8, 55, 3, 38, 4, 58, 1,  6, 7, 68, 6, 97, 
    5, 10, 4,  8, 3, 43, 1, 49, 6, 85, 8, 73, 2, 27, 7, 30, 0,  9, 
    3, 49, 5, 44, 0, 28, 8, 95, 2, 91, 7, 14, 6,  7, 4, 25, 1, 66
  };
  const int q7766[] = {
    9, 9, // Number of jobs and machines
    0, 92, 7, 62, 1, 74, 5, 14, 2, 97, 4, 45, 8, 52, 3, 23, 6,  7, 
    1, 27, 8, 41, 6,  1, 3, 71, 5, 68, 4, 54, 0, 25, 7, 69, 2, 92, 
    0,  9, 6, 78, 1, 22, 8, 18, 3, 86, 4, 80, 7, 53, 2, 38, 5, 27, 
    5, 64, 8, 27, 7, 29, 1, 91, 4, 57, 3, 41, 2, 78, 6, 55, 0, 90, 
    1, 42, 3, 79, 6, 62, 2, 34, 7, 23, 4, 53, 0, 74, 8, 42, 5, 39, 
    1, 44, 6, 83, 5, 60, 8, 49, 2, 96, 4, 31, 3, 51, 7, 93, 0, 25, 
    2, 96, 7, 47, 5, 15, 8, 42, 0, 35, 3, 52, 6, 63, 1, 70, 4, 25, 
    8, 87, 1, 84, 2, 71, 3, 86, 6,  2, 7, 96, 0, 71, 4, 30, 5, 61, 
    8,  2, 4, 44, 0, 79, 7, 39, 3,  3, 5, 16, 6, 52, 2, 16, 1, 50
  };
  const int q7767[] = {
    9, 9, // Number of jobs and machines
    0, 94, 4, 77, 6, 63, 7, 98, 1, 25, 3,  4, 2, 27, 5, 97, 8, 69, 
    1, 69, 3, 72, 8, 83, 6, 93, 4, 97, 7, 45, 0,  3, 5, 23, 2, 33, 
    7, 68, 3, 50, 6, 53, 5, 26, 0,  4, 2, 41, 4, 84, 8, 84, 1, 81, 
    1, 90, 8, 53, 4, 80, 7,  4, 5, 42, 6, 25, 3, 80, 2, 22, 0, 46, 
    4, 43, 1, 95, 8, 31, 2, 99, 6, 92, 7, 60, 3, 13, 0, 76, 5, 92, 
    3, 30, 8, 41, 0, 94, 5, 29, 7, 22, 4, 61, 1, 18, 6, 37, 2, 83, 
    7, 90, 2, 18, 3, 50, 6, 71, 4, 50, 0, 61, 8, 47, 5, 35, 1, 71, 
    0, 43, 6, 48, 7, 67, 4, 99, 3, 21, 1, 36, 8, 33, 5, 35, 2, 23, 
    1, 88, 6, 60, 2, 30, 0, 90, 8, 98, 3, 25, 7, 66, 5, 57, 4, 69
  };
  const int q7768[] = {
    9, 9, // Number of jobs and machines
    0, 56, 4, 49, 3, 83, 5, 33, 8, 53, 2, 76, 7, 91, 6, 57, 1, 93, 
    1, 98, 0, 97, 2, 11, 7, 62, 5, 18, 3, 27, 4, 89, 6, 81, 8, 40, 
    4, 48, 1, 34, 8, 30, 6, 62, 3, 19, 7, 49, 0, 66, 2, 89, 5, 10, 
    5, 52, 2, 54, 3, 57, 4, 55, 0, 52, 1, 70, 7, 93, 8, 18, 6,  5, 
    6,  6, 2, 73, 5, 45, 3, 75, 8, 39, 0, 16, 4, 86, 7, 70, 1, 75, 
    0, 64, 1, 55, 3, 55, 7, 35, 2, 89, 6, 73, 4, 29, 5, 22, 8, 52, 
    6, 49, 1, 46, 3, 89, 4, 95, 8, 56, 5, 31, 0, 87, 7, 21, 2, 61, 
    0, 22, 6,  2, 8, 60, 3,  2, 4, 23, 1, 91, 5, 59, 7, 63, 2, 90, 
    4, 47, 6, 78, 0, 70, 7, 75, 2,  4, 1, 45, 5, 74, 3,  9, 8, 77
  };
  const int q7769[] = {
    9, 9, // Number of jobs and machines
    8, 23, 7, 53, 3, 13, 6, 57, 5, 94, 4, 34, 1, 73, 0, 55, 2,  4, 
    6, 47, 5,  2, 8, 85, 0, 17, 7, 81, 4, 80, 3, 33, 2, 22, 1, 36, 
    7, 45, 2, 42, 6, 57, 5, 32, 0, 72, 3, 84, 1, 35, 8, 34, 4, 39, 
    6, 53, 8,  9, 7, 47, 4, 77, 5, 83, 1,  4, 3, 38, 0,  7, 2,  6, 
    3, 36, 2,  6, 7, 18, 8, 42, 1, 54, 5, 34, 4, 36, 6, 12, 0, 42, 
    8, 28, 4, 39, 0, 86, 1, 83, 7, 31, 2, 82, 6, 77, 3, 32, 5, 26, 
    4, 37, 3, 27, 2, 31, 7, 60, 0, 57, 1, 99, 6, 31, 5,  3, 8, 85, 
    7, 99, 2, 14, 6, 42, 5, 63, 0,  1, 4, 33, 8, 67, 1, 11, 3, 96, 
    0, 23, 2, 96, 5, 36, 4, 33, 7, 23, 8, 13, 3, 92, 6, 51, 1, 16
  };
  const int q7770[] = {
    9, 9, // Number of jobs and machines
    4, 79, 8, 93, 1,  3, 5,  5, 7, 90, 3, 79, 2, 25, 0,  8, 6, 20, 
    8, 10, 6, 88, 7, 55, 3, 48, 4,  1, 5, 60, 2, 82, 1, 13, 0, 15, 
    6, 90, 0, 43, 7, 19, 3, 30, 8, 58, 2, 33, 1, 80, 5, 70, 4, 35, 
    4, 48, 1, 39, 2, 63, 7, 96, 8, 70, 6, 56, 5, 43, 0, 21, 3, 87, 
    5, 32, 6, 21, 3, 92, 7, 74, 1, 15, 8, 21, 2, 60, 4, 44, 0, 51, 
    3, 20, 2, 68, 6, 51, 4, 33, 1, 40, 0, 83, 7,  8, 8, 82, 5, 81, 
    1,  5, 7, 15, 3, 21, 0,  9, 6, 22, 8, 69, 4, 77, 5, 64, 2, 48, 
    3, 24, 0, 74, 7, 84, 4, 30, 1, 69, 8, 57, 6, 44, 2, 22, 5, 43, 
    6, 22, 0, 95, 2, 22, 1, 98, 5, 45, 7, 12, 3, 57, 4, 76, 8, 57
  };
  const int q7771[] = {
    9, 9, // Number of jobs and machines
    3, 60, 5,  2, 4, 27, 6, 14, 2, 91, 7, 17, 0, 26, 8, 36, 1, 12, 
    7, 37, 6,  4, 3, 25, 0, 75, 1, 75, 2, 10, 5,  5, 4, 91, 8, 29, 
    2, 18, 6, 87, 7, 67, 5, 76, 0, 71, 8, 61, 3, 95, 4,  8, 1, 27, 
    1, 72, 8, 14, 0, 17, 2, 82, 7, 49, 4, 22, 5, 88, 6, 90, 3, 23, 
    5, 83, 0, 82, 8,  3, 1, 18, 7, 80, 2, 99, 3, 52, 4, 73, 6, 92, 
    6, 33, 4, 85, 0, 94, 2, 60, 7, 59, 3, 12, 5,  6, 1, 94, 8, 22, 
    1, 82, 4, 33, 5, 30, 3, 34, 7, 27, 2,  3, 8, 50, 0, 16, 6, 30, 
    5, 36, 4, 35, 6, 74, 0, 10, 7, 32, 1, 74, 2, 74, 8, 67, 3, 92, 
    3, 24, 0, 93, 7, 88, 6, 28, 2, 79, 4, 33, 8, 68, 1,  6, 5, 97
  };
  const int q7772[] = {
    9, 9, // Number of jobs and machines
    8,  9, 7, 74, 6, 64, 1,  2, 2, 13, 3, 88, 4, 76, 5, 91, 0, 78, 
    5, 73, 1, 75, 4, 45, 3, 78, 7, 96, 2, 41, 8, 36, 6, 71, 0, 31, 
    7,  5, 8, 26, 2,  7, 3, 63, 4, 31, 0, 15, 6, 24, 5,  5, 1,  1, 
    5,  3, 4, 69, 2, 12, 3, 97, 0, 85, 6, 67, 8, 80, 1, 96, 7, 72, 
    3, 34, 1, 59, 0, 46, 5, 45, 2, 61, 4, 25, 7, 48, 6, 23, 8,  2, 
    2, 87, 7, 76, 5, 64, 8, 33, 4, 21, 6,  8, 1, 74, 3, 58, 0, 15, 
    4, 66, 3, 65, 2, 13, 0, 54, 7, 17, 1, 98, 5,  2, 8, 99, 6, 70, 
    6, 56, 7, 34, 4, 32, 0, 73, 8, 89, 3, 39, 1, 94, 5, 58, 2, 55, 
    8, 81, 1, 80, 4, 64, 6, 63, 3, 90, 2, 12, 5, 45, 7, 21, 0, 80
  };
  const int q7773[] = {
    9, 9, // Number of jobs and machines
    8, 99, 7, 78, 2,  5, 5, 53, 0, 90, 1, 46, 3,  1, 6, 20, 4, 53, 
    0, 72, 6, 26, 1, 68, 4, 80, 7, 57, 8, 20, 5, 41, 3,  4, 2, 80, 
    2, 93, 0, 68, 7, 45, 3, 82, 5, 50, 6, 86, 4, 98, 8, 34, 1, 28, 
    1, 40, 2, 30, 5, 49, 0, 30, 6, 51, 7, 48, 4, 33, 8, 90, 3, 18, 
    6,  5, 1, 56, 7, 13, 5, 98, 2, 74, 3,  4, 0, 56, 8, 83, 4, 26, 
    0, 12, 6, 10, 1, 57, 8, 71, 7, 60, 4, 95, 3, 15, 2, 34, 5,  7, 
    2, 23, 6, 16, 3, 97, 5, 46, 1, 87, 4, 29, 7, 63, 0, 76, 8,  3, 
    5, 28, 4, 26, 1, 23, 6, 31, 3, 74, 0, 78, 7, 22, 2, 12, 8, 73, 
    2, 40, 3, 31, 6, 56, 7, 88, 1, 14, 0, 38, 5, 16, 4, 61, 8, 72
  };
  const int q7774[] = {
    9, 9, // Number of jobs and machines
    4, 70, 2, 53, 8, 96, 3, 42, 0, 51, 6, 88, 1, 56, 5,  1, 7, 93, 
    5, 95, 2, 11, 7,  4, 0,  2, 8, 79, 6, 23, 1, 10, 3, 84, 4, 93, 
    0, 91, 2, 45, 6, 25, 1,  8, 3, 99, 8, 79, 4, 76, 7, 84, 5, 44, 
    5, 60, 6, 58, 3, 22, 7, 90, 2, 66, 0, 96, 1, 15, 4, 37, 8, 52, 
    7, 39, 6, 65, 0, 19, 8, 56, 5, 30, 4, 86, 2, 87, 3, 55, 1,  1, 
    3, 64, 1, 88, 4, 52, 6, 41, 7,  4, 2, 41, 8, 21, 5, 93, 0, 87, 
    8, 58, 1, 90, 6, 30, 0, 77, 7, 77, 5, 23, 4, 37, 3, 87, 2, 77, 
    2, 89, 4,  5, 8, 16, 3,  5, 7, 33, 0,  7, 1, 95, 5, 34, 6, 93, 
    6, 52, 3, 20, 1, 84, 2, 29, 5, 91, 0, 69, 8, 18, 7, 32, 4, 28
  };
  const int q7775[] = {
    9, 9, // Number of jobs and machines
    3, 34, 2,  4, 4, 53, 1, 63, 5, 83, 6, 36, 0, 12, 7, 92, 8, 11, 
    7, 99, 6, 17, 5, 61, 4, 50, 1, 83, 8, 80, 3, 89, 0,  1, 2, 91, 
    1, 69, 8, 84, 7, 34, 0, 84, 5, 96, 4, 31, 2, 66, 3, 44, 6, 93, 
    4, 93, 3,  5, 0, 27, 2, 42, 6, 94, 5, 21, 8, 21, 1, 97, 7, 33, 
    4, 82, 7, 75, 2, 99, 5, 26, 8, 39, 6, 40, 0, 55, 1, 70, 3, 62, 
    1, 53, 3, 60, 4, 14, 6, 51, 8, 91, 7, 48, 5, 54, 2, 77, 0, 60, 
    0, 77, 6, 11, 5, 45, 4, 84, 1, 97, 7, 46, 2, 11, 8, 41, 3, 87, 
    6, 49, 5, 64, 4, 44, 1, 28, 8, 26, 7, 51, 3, 76, 2, 42, 0, 29, 
    1,  5, 6, 79, 5, 98, 4, 30, 8,  7, 2, 58, 0, 75, 7, 94, 3, 99
  };
  const int q7776[] = {
    9, 9, // Number of jobs and machines
    6, 21, 7,  2, 0, 80, 3, 55, 4, 71, 2, 58, 5, 18, 8, 99, 1, 74, 
    1, 88, 3, 11, 7, 28, 5, 89, 2, 61, 0, 57, 8, 46, 4, 19, 6, 52, 
    7, 92, 2, 91, 0, 89, 5, 71, 3, 96, 1,  4, 6, 45, 8, 94, 4,  5, 
    5, 80, 3, 31, 7, 12, 1, 86, 2, 30, 6, 20, 0, 68, 8, 70, 4, 80, 
    2, 69, 3, 95, 4, 75, 0, 88, 8, 68, 6, 17, 7, 26, 1,  6, 5, 25, 
    3, 10, 7, 36, 2, 59, 0, 83, 8, 53, 1, 18, 4, 47, 5, 34, 6,  7, 
    4, 50, 5,  8, 8, 21, 1, 43, 3, 64, 0, 92, 7, 38, 6, 29, 2, 92, 
    8, 85, 7, 87, 6, 84, 5, 73, 3, 34, 1,  2, 2, 34, 0, 65, 4, 70, 
    4, 52, 2, 43, 1, 38, 0, 19, 7, 52, 5, 61, 3, 97, 6, 81, 8, 65
  };
  const int q7777[] = {
    9, 9, // Number of jobs and machines
    1, 74, 3, 40, 7, 56, 0, 38, 4, 19, 2, 61, 6, 45, 5,  8, 8, 87, 
    0, 60, 8, 27, 3, 40, 2, 36, 7,  7, 6,  7, 1, 86, 5, 69, 4, 78, 
    2, 17, 4, 97, 3, 26, 7, 29, 8,  1, 5, 58, 6, 86, 1,  9, 0, 28, 
    2, 13, 4, 52, 3, 90, 1, 80, 5, 75, 8, 78, 0, 52, 6, 46, 7, 81, 
    1, 35, 3, 71, 0, 34, 5, 41, 4, 17, 7, 13, 2, 62, 8, 19, 6, 39, 
    1, 32, 5, 56, 8, 38, 6, 18, 4, 14, 3, 52, 0, 93, 2,  9, 7,  8, 
    5, 25, 8, 88, 2, 35, 4, 22, 0, 37, 3, 15, 6, 95, 1, 37, 7, 38, 
    4, 71, 8, 80, 5, 29, 2, 43, 3, 16, 0, 50, 1, 57, 6, 71, 7, 15, 
    6, 40, 8, 29, 5, 58, 3, 19, 7, 37, 0, 60, 1, 11, 2,  7, 4, 55
  };
  const int q7778[] = {
    9, 9, // Number of jobs and machines
    0, 89, 2, 62, 8, 67, 5, 65, 3, 45, 6, 50, 7, 30, 1, 62, 4, 13, 
    5, 21, 2, 57, 6,  7, 1, 57, 8, 36, 7, 55, 4, 33, 3, 15, 0, 80, 
    0, 72, 4, 68, 1, 26, 6, 81, 5, 95, 3, 88, 2, 40, 8, 20, 7, 94, 
    0, 69, 7, 48, 8, 71, 2, 26, 5, 93, 4, 73, 6, 98, 1, 73, 3, 88, 
    5,  5, 8, 31, 3, 89, 4, 92, 2, 37, 0, 53, 6, 14, 7, 24, 1, 38, 
    1, 29, 7, 79, 8, 14, 6,  5, 2, 33, 3, 79, 4, 16, 5, 84, 0, 97, 
    7, 35, 6, 43, 3, 22, 1, 51, 8, 48, 2, 15, 0, 79, 4, 52, 5, 58, 
    4, 12, 3, 87, 5, 37, 7, 25, 8, 75, 0, 48, 1, 14, 2, 97, 6, 28, 
    8, 10, 2, 98, 4, 33, 0, 60, 3, 38, 7, 30, 6, 85, 1, 84, 5, 61
  };
  const int q7779[] = {
    9, 9, // Number of jobs and machines
    3, 29, 1, 35, 8, 51, 0, 68, 2, 57, 5, 30, 7, 83, 6, 78, 4, 86, 
    4, 62, 1, 45, 5, 67, 8, 64, 0, 72, 3, 15, 7, 33, 2, 96, 6, 85, 
    2, 41, 1, 16, 0, 31, 4, 94, 5, 22, 7, 26, 6, 29, 8, 71, 3, 72, 
    3, 86, 0, 38, 8, 53, 6, 29, 7, 67, 4,  9, 2, 82, 5, 89, 1, 13, 
    6, 67, 7, 21, 5, 48, 1, 63, 3, 22, 0, 26, 2, 68, 8, 40, 4, 78, 
    7, 52, 3, 96, 4, 96, 0, 63, 1, 97, 5, 10, 2, 29, 6, 24, 8, 51, 
    4, 31, 0, 28, 8, 17, 2, 48, 1,  2, 3, 75, 7, 45, 6, 38, 5, 74, 
    7, 66, 4, 93, 1, 38, 6, 17, 0, 55, 3, 20, 2,  6, 5, 43, 8, 95, 
    4, 36, 5, 24, 0, 39, 6, 13, 3, 34, 1, 33, 2, 23, 8, 94, 7, 75
  };
  const int q7780[] = {
    9, 9, // Number of jobs and machines
    3, 15, 1, 55, 0, 73, 2, 27, 5, 76, 4, 87, 7, 20, 6, 27, 8, 78, 
    4, 42, 6, 56, 8, 39, 2, 75, 0, 27, 5, 58, 7, 79, 3, 32, 1, 94, 
    0, 52, 6, 26, 3, 43, 2, 42, 1, 62, 4, 56, 7, 76, 5, 35, 8, 99, 
    7, 21, 2, 15, 5, 60, 6, 53, 3, 76, 0, 65, 8, 13, 1, 57, 4,  2, 
    3, 11, 4, 57, 2, 83, 7, 75, 0, 99, 6, 82, 8, 37, 5, 57, 1, 49, 
    6, 13, 1,  3, 4, 57, 8, 18, 2,  3, 7, 86, 0, 83, 3,  9, 5, 45, 
    7, 75, 8, 63, 4, 63, 3, 79, 5, 21, 1, 69, 2, 77, 6, 76, 0, 80, 
    1, 93, 2, 61, 6, 15, 7, 65, 0, 90, 8, 46, 3, 97, 5, 89, 4, 72, 
    7, 63, 0, 88, 5,  5, 6, 60, 1, 17, 3, 19, 4, 76, 2, 42, 8, 62
  };
  const int q7781[] = {
    9, 9, // Number of jobs and machines
    5, 36, 7, 43, 4, 24, 6, 36, 8, 33, 0,  4, 3, 15, 2, 63, 1, 16, 
    6, 86, 7, 14, 4, 79, 0, 65, 3, 81, 8, 72, 1, 20, 2, 63, 5, 86, 
    1, 82, 7, 92, 6, 80, 4, 15, 0, 12, 3, 80, 2, 52, 8, 35, 5, 19, 
    6,  7, 4, 21, 2, 21, 7, 14, 3, 53, 5, 62, 1, 26, 0, 86, 8, 25, 
    1, 42, 2, 53, 7, 61, 0, 50, 6, 34, 5, 63, 4, 75, 8, 41, 3, 75, 
    7, 40, 0, 20, 2,  6, 4,  7, 1, 71, 6, 20, 5,  5, 3, 78, 8, 20, 
    4, 47, 2, 48, 7, 29, 6, 14, 1, 80, 5, 32, 8, 67, 3, 20, 0, 39, 
    4, 91, 8, 81, 0, 39, 3, 95, 7, 89, 1, 47, 2, 10, 5, 82, 6, 90, 
    4, 54, 8, 85, 7, 38, 2, 45, 5, 26, 0, 84, 3, 53, 1, 96, 6, 59
  };
  const int q7782[] = {
    9, 9, // Number of jobs and machines
    6, 71, 2, 21, 5, 57, 3, 84, 0, 67, 7, 29, 8, 63, 4, 13, 1, 97, 
    2, 43, 5,  4, 1, 34, 3, 86, 7, 58, 8, 75, 6, 90, 0, 32, 4, 84, 
    8, 39, 0, 91, 7, 69, 5, 67, 2, 55, 3, 61, 4, 33, 6, 20, 1, 67, 
    0, 33, 4, 59, 3, 85, 6, 51, 7, 17, 2, 88, 5, 12, 1, 34, 8, 28, 
    2, 65, 7, 20, 4, 43, 0, 19, 1, 66, 6, 56, 8, 78, 5, 50, 3, 62, 
    2, 33, 4, 62, 5, 99, 1, 74, 0, 13, 8, 13, 3, 20, 7, 96, 6, 25, 
    1, 51, 8, 27, 4, 42, 6, 70, 3, 54, 7, 43, 2, 11, 0, 67, 5, 28, 
    8, 61, 4, 83, 6, 63, 3, 77, 2, 89, 1, 24, 5, 92, 7,  9, 0, 48, 
    4, 23, 2,  2, 1, 15, 5, 24, 8,  7, 7, 42, 6, 96, 0, 15, 3, 24
  };
  const int q7783[] = {
    9, 9, // Number of jobs and machines
    3,  1, 4, 20, 1, 39, 0, 96, 6,  4, 7, 44, 5, 87, 8, 75, 2, 51, 
    0, 82, 2, 84, 7, 25, 8, 90, 5, 33, 6, 64, 4, 66, 1, 40, 3,  6, 
    5, 12, 3, 73, 1, 54, 6, 90, 4, 58, 8, 84, 0, 69, 2, 14, 7, 33, 
    3, 75, 6, 89, 8, 89, 7, 50, 2,  2, 0, 22, 4, 15, 1, 42, 5, 35, 
    1, 65, 2, 86, 3,  5, 6, 87, 5, 21, 8, 59, 0, 24, 4, 65, 7, 52, 
    6, 46, 7, 73, 0, 23, 4,  7, 5, 56, 3,  1, 2, 13, 1, 99, 8, 83, 
    7, 25, 6, 61, 1, 88, 4, 85, 0, 41, 5, 63, 3, 40, 8, 58, 2, 26, 
    3, 67, 1, 16, 5, 62, 6, 31, 7, 80, 2, 35, 0,  1, 4, 73, 8, 52, 
    4, 74, 5, 94, 3, 10, 6, 41, 0, 47, 7, 32, 2, 44, 8, 36, 1, 56
  };
  const int q7784[] = {
    9, 9, // Number of jobs and machines
    3, 88, 7, 48, 0,  1, 8, 11, 4, 70, 6, 93, 2, 85, 1, 47, 5, 88, 
    7, 79, 6, 80, 4, 14, 8, 85, 1, 74, 2, 19, 3, 53, 5, 25, 0, 58, 
    4, 28, 5, 73, 8,  8, 6, 70, 7, 72, 2, 38, 3, 79, 1, 33, 0, 56, 
    8, 16, 0, 54, 2, 98, 6, 97, 1, 68, 5, 45, 4, 88, 3, 53, 7, 11, 
    3,  5, 6, 58, 5, 51, 1, 80, 0, 15, 8, 20, 4,  8, 7, 59, 2, 71, 
    7, 18, 6, 93, 4, 27, 5, 67, 3, 97, 8, 96, 1, 82, 0, 75, 2, 52, 
    1, 90, 5, 71, 4, 14, 2, 37, 3, 19, 7, 74, 0, 81, 6, 64, 8, 93, 
    5, 54, 7, 45, 4, 69, 0, 47, 1, 42, 8, 38, 6, 74, 2, 23, 3, 54, 
    5,  6, 0, 46, 2, 48, 8, 38, 6, 88, 4, 11, 1, 80, 7, 17, 3, 85
  };
  const int q7785[] = {
    9, 9, // Number of jobs and machines
    0, 13, 1, 88, 7, 25, 2, 78, 4, 26, 5, 73, 3,  6, 8, 93, 6, 75, 
    2, 85, 5, 34, 7, 74, 1, 62, 0, 97, 8, 90, 3, 77, 6, 92, 4, 43, 
    4, 63, 0, 52, 1, 28, 2, 28, 3,  4, 5, 99, 7, 48, 6, 68, 8,  2, 
    3, 39, 5, 13, 6, 77, 0, 24, 1, 53, 7, 33, 2, 68, 8, 63, 4, 62, 
    2, 71, 3, 34, 4, 36, 1, 77, 0, 73, 5, 23, 8, 27, 6, 56, 7, 43, 
    8,  4, 0, 83, 7, 44, 1, 10, 3, 24, 5, 58, 4, 99, 2, 80, 6, 64, 
    6, 53, 5, 14, 8, 75, 2,  5, 4, 34, 1, 62, 0, 30, 3, 82, 7, 36, 
    3, 20, 2, 26, 6, 64, 8, 77, 7, 95, 4, 72, 0, 82, 1, 85, 5,  9, 
    3, 27, 1, 99, 0, 85, 6, 99, 7, 89, 4, 90, 8,  3, 5, 74, 2, 60
  };
  const int q7786[] = {
    9, 9, // Number of jobs and machines
    5, 83, 4, 15, 6, 52, 0, 85, 3, 50, 2, 20, 8, 44, 7, 84, 1, 78, 
    3, 73, 7, 56, 6, 58, 4, 18, 8, 34, 0, 88, 5, 14, 1, 39, 2, 36, 
    8, 56, 1, 29, 5, 86, 0, 21, 7, 22, 4, 77, 3, 54, 6, 56, 2, 53, 
    5,  9, 4, 18, 8, 85, 1, 47, 7, 48, 0,  6, 3, 44, 2, 20, 6, 26, 
    2, 81, 1,  1, 3, 98, 7, 66, 6, 99, 0, 39, 4, 53, 5, 83, 8, 80, 
    7, 48, 3, 98, 6, 92, 1, 71, 2, 49, 8, 15, 5, 33, 4, 77, 0, 77, 
    7, 26, 5, 32, 2, 19, 1, 49, 0, 42, 8, 60, 3, 69, 6, 98, 4, 28, 
    5, 92, 2, 42, 8, 42, 0, 42, 1,  2, 7, 36, 4, 92, 3, 26, 6, 94, 
    6, 69, 4, 44, 8, 81, 3, 93, 5, 88, 7,  5, 0, 90, 2, 89, 1, 92
  };
  const int q7787[] = {
    9, 9, // Number of jobs and machines
    7, 32, 0, 60, 8, 24, 4, 33, 1, 64, 5, 42, 2, 21, 3, 74, 6, 84, 
    7, 29, 3, 27, 0, 67, 4, 47, 1, 55, 2, 55, 8,  3, 6, 29, 5,  7, 
    3, 97, 1, 63, 0, 69, 6, 13, 4, 76, 7, 86, 8, 94, 2, 45, 5, 71, 
    4, 96, 0, 88, 7, 37, 8, 55, 2, 88, 1,  1, 3, 50, 5, 97, 6, 63, 
    7,  4, 2, 11, 0, 95, 4, 51, 5, 80, 3,  6, 1, 74, 8, 32, 6, 14, 
    1, 84, 6, 81, 5, 51, 0, 55, 3, 58, 7, 35, 4, 82, 8, 87, 2, 68, 
    4, 99, 8,  5, 7, 86, 3, 52, 6, 30, 2, 13, 0, 35, 1, 76, 5, 80, 
    3, 27, 2, 63, 7,  2, 1,  4, 5,  3, 0, 50, 6, 98, 4, 20, 8,  7, 
    8, 49, 1, 11, 4, 32, 5, 65, 6, 57, 0, 59, 2, 19, 7, 73, 3, 11
  };
  const int q7788[] = {
    9, 9, // Number of jobs and machines
    3, 55, 6, 10, 7, 67, 4, 83, 8, 60, 1, 99, 2, 45, 0, 82, 5, 65, 
    1, 83, 0, 31, 6, 84, 2, 80, 8,  2, 3, 19, 7, 62, 4, 47, 5, 29, 
    2,  8, 5, 44, 1, 11, 0, 26, 7, 97, 6,  8, 3, 31, 8, 53, 4, 10, 
    5, 18, 4, 24, 1, 84, 2, 26, 3, 90, 0, 76, 6, 98, 8, 80, 7, 55, 
    5, 27, 7, 58, 1,  5, 2, 66, 4, 24, 6, 72, 0, 72, 8, 77, 3,  7, 
    2, 90, 4, 62, 7, 34, 8, 96, 3, 55, 0, 36, 1, 59, 6, 88, 5, 24, 
    1, 25, 5, 20, 4, 35, 6, 13, 0, 63, 2, 15, 3, 61, 8, 84, 7, 12, 
    6, 30, 8, 88, 5, 81, 1, 46, 4, 84, 7, 54, 0, 54, 2, 25, 3, 82, 
    8, 90, 5,  8, 6, 93, 3, 10, 0, 99, 1, 26, 7, 58, 2,  8, 4, 38
  };
  const int q7789[] = {
    9, 9, // Number of jobs and machines
    0, 11, 8, 31, 5, 46, 6,  6, 4, 47, 7, 45, 2, 12, 3, 56, 1, 70, 
    6, 18, 7,  8, 3,  1, 4,  2, 2, 97, 5, 24, 0, 29, 8, 28, 1, 32, 
    6, 15, 8, 63, 5, 68, 0, 49, 3, 55, 4, 65, 1, 32, 7, 49, 2, 36, 
    6, 78, 4,  3, 8, 45, 7, 16, 2, 97, 5, 40, 3, 45, 1, 93, 0, 15, 
    6, 25, 0, 35, 7, 93, 1, 46, 2,  1, 4, 16, 8, 37, 3, 36, 5, 76, 
    5, 17, 1, 72, 8,  3, 3, 34, 2, 66, 6, 43, 7, 67, 0, 77, 4, 54, 
    1, 86, 6, 20, 0, 29, 8, 35, 4, 85, 2, 66, 3, 25, 7, 36, 5, 88, 
    7, 25, 2, 68, 8, 19, 4, 40, 5, 91, 6,  3, 0, 75, 3, 17, 1, 34, 
    4, 24, 0, 70, 7, 33, 3,  4, 6,  5, 2, 95, 1, 12, 5, 50, 8, 12
  };
  const int q7790[] = {
    9, 9, // Number of jobs and machines
    8,  3, 5, 48, 2, 56, 4, 60, 6, 34, 3, 67, 1,  5, 0, 59, 7, 59, 
    2, 92, 7, 14, 0, 76, 5, 13, 1, 13, 8, 69, 4, 89, 3, 54, 6, 50, 
    4, 22, 0, 67, 3, 52, 7, 29, 6, 60, 1, 62, 8,  6, 5, 29, 2, 32, 
    1, 96, 7, 38, 3, 18, 5, 37, 4, 86, 2, 97, 0, 96, 6,  5, 8, 35, 
    2, 97, 3, 98, 0, 43, 1, 12, 4, 48, 6, 44, 7, 17, 8, 97, 5, 79, 
    5, 60, 3, 79, 2, 54, 1, 81, 7, 91, 6, 93, 4, 81, 8, 59, 0,  3, 
    7, 68, 8, 95, 2, 84, 6, 51, 4, 85, 1,  8, 5, 22, 3,  9, 0,  3, 
    3, 27, 2, 49, 7,  1, 6,  5, 0, 22, 8, 87, 4, 73, 1, 97, 5, 36, 
    2, 90, 4, 89, 8, 10, 0, 25, 6, 63, 7, 81, 3, 54, 1, 11, 5, 36
  };
  const int q7791[] = {
    9, 9, // Number of jobs and machines
    7, 66, 6,  5, 0, 98, 5,  9, 1, 41, 2, 52, 3, 35, 4, 63, 8, 87, 
    7, 52, 0, 23, 8, 84, 5, 80, 4, 82, 3, 56, 6, 75, 1, 72, 2, 90, 
    1, 22, 8, 83, 6, 10, 5, 19, 2, 66, 7,  2, 3, 14, 0,  3, 4,  8, 
    8, 73, 7, 56, 0, 54, 6, 83, 1, 53, 2, 14, 4, 57, 3, 23, 5, 67, 
    4, 41, 3, 91, 1, 94, 2, 75, 5, 73, 6, 56, 7, 76, 8, 44, 0,  6, 
    0, 45, 1, 74, 6, 14, 2, 64, 5, 34, 4, 20, 3, 99, 8, 67, 7, 98, 
    0, 78, 5, 29, 7, 66, 2, 90, 1, 79, 8, 21, 4, 99, 3, 88, 6, 92, 
    6, 66, 3, 47, 4, 29, 5,  6, 0, 68, 1, 18, 7, 23, 8, 13, 2, 49, 
    7, 81, 5, 11, 2, 53, 6, 85, 3, 32, 1, 65, 8, 93, 0, 32, 4, 43
  };
  const int q7792[] = {
    9, 9, // Number of jobs and machines
    7, 39, 6, 22, 0, 74, 4, 95, 1, 60, 3, 73, 5, 76, 2, 88, 8, 84, 
    5, 78, 8, 79, 7, 75, 6, 21, 1, 98, 4, 86, 2, 93, 3, 28, 0, 65, 
    6, 37, 0, 40, 8, 54, 4, 75, 2, 13, 3,  7, 1, 48, 5, 36, 7, 25, 
    0, 53, 4, 94, 2, 22, 3, 13, 5, 89, 8, 23, 1,  5, 6, 54, 7, 96, 
    8, 82, 2, 29, 5, 13, 6, 15, 1, 99, 0,  3, 4, 39, 7, 50, 3, 14, 
    6,  7, 3, 71, 7, 21, 8,  3, 1, 57, 4, 54, 5, 34, 2, 48, 0, 89, 
    3, 12, 6, 10, 8, 83, 4, 52, 2, 82, 0,  2, 7, 15, 5, 82, 1, 56, 
    1, 84, 0, 39, 2, 58, 6, 79, 4, 29, 7, 41, 3, 15, 5, 99, 8, 22, 
    0, 54, 1, 54, 6, 20, 7, 50, 3,  6, 2, 75, 4, 81, 5, 23, 8, 54
  };
  const int q7793[] = {
    9, 9, // Number of jobs and machines
    3, 82, 8, 99, 2, 41, 6, 34, 4, 27, 0, 55, 7, 28, 5, 28, 1, 64, 
    1, 17, 3, 42, 8, 90, 0, 91, 5, 32, 4, 76, 2, 80, 6, 76, 7, 21, 
    1, 77, 0, 46, 5, 28, 2, 54, 7, 33, 8,  9, 4, 29, 3, 89, 6, 93, 
    6, 72, 8, 14, 4, 10, 0, 16, 3, 11, 5, 50, 1, 96, 2, 37, 7, 35, 
    0, 77, 6,  3, 5, 58, 8, 90, 7, 10, 4, 34, 3, 46, 2, 58, 1, 16, 
    5, 42, 4, 19, 0, 19, 6, 96, 3, 13, 2, 52, 7, 30, 8, 75, 1, 12, 
    3,  3, 6, 31, 4, 15, 5, 22, 2, 82, 7,  8, 8, 43, 1, 67, 0, 82, 
    7, 75, 3, 46, 2, 24, 8, 80, 5, 47, 0, 17, 4,  4, 1, 57, 6, 59, 
    4, 54, 1,  3, 8, 67, 7, 45, 5, 34, 6, 34, 0, 60, 2, 52, 3, 85
  };
  const int q7794[] = {
    9, 9, // Number of jobs and machines
    3, 96, 7, 82, 6, 11, 1, 10, 4, 32, 0, 25, 2, 41, 8, 53, 5,  5, 
    0, 18, 2, 43, 7, 41, 4,  8, 6, 91, 8, 72, 5, 28, 1, 44, 3, 73, 
    2, 29, 3, 28, 0, 90, 8, 20, 5,  4, 4, 84, 1, 31, 6,  4, 7, 39, 
    3, 63, 5, 49, 4, 64, 0, 22, 8, 23, 1, 38, 2, 48, 6, 78, 7, 93, 
    4,  8, 6, 86, 8, 41, 1, 85, 5,  1, 0, 88, 3, 68, 2, 93, 7, 81, 
    1, 35, 3, 48, 7, 88, 4, 56, 6,  5, 8, 65, 5, 89, 2, 49, 0, 53, 
    7, 51, 0, 67, 1, 17, 2, 77, 4,  6, 8, 72, 3, 12, 6, 53, 5, 66, 
    7, 34, 3, 39, 6, 50, 5, 48, 4, 24, 1,  7, 8, 13, 0,  7, 2, 98, 
    3, 19, 7, 54, 1, 89, 5, 21, 2, 23, 8, 70, 0, 74, 6,  5, 4, 61
  };
  const int q7795[] = {
    9, 9, // Number of jobs and machines
    0, 35, 5,  6, 8, 46, 6, 64, 1, 88, 7, 15, 2, 18, 3, 33, 4, 11, 
    6, 53, 8, 20, 4, 44, 1, 29, 3, 15, 2, 18, 7, 54, 0, 77, 5, 63, 
    3, 81, 6, 55, 4, 23, 0, 92, 5, 57, 1, 35, 8, 36, 7, 77, 2, 87, 
    6, 67, 1, 61, 2, 57, 3, 83, 5, 92, 4, 71, 8, 66, 0, 74, 7, 25, 
    8, 50, 3, 94, 2, 72, 4, 59, 6, 67, 7, 69, 5, 44, 0, 94, 1, 34, 
    7, 84, 4, 11, 0, 96, 5, 73, 6, 67, 3, 25, 8, 66, 2, 44, 1, 80, 
    8, 37, 3, 29, 2,  9, 7, 40, 0, 25, 1, 11, 6, 24, 5, 69, 4, 73, 
    7, 39, 6, 20, 1, 36, 0, 25, 5,  5, 8, 15, 2, 38, 4, 86, 3, 93, 
    7, 70, 2, 61, 6, 13, 3, 42, 8, 98, 0, 17, 5, 26, 4,  5, 1,  8
  };
  const int q7796[] = {
    9, 9, // Number of jobs and machines
    5, 94, 3, 15, 0, 56, 4, 23, 7, 89, 8, 57, 2, 70, 6, 43, 1, 93, 
    8,  3, 5, 66, 1,  4, 7, 35, 4, 64, 0, 62, 6,  2, 2, 19, 3, 64, 
    7, 79, 2, 80, 3, 86, 8, 68, 1, 59, 0, 62, 5,  8, 6, 40, 4, 26, 
    6, 36, 3, 53, 2, 13, 1, 81, 8, 31, 7, 56, 0,  8, 4, 86, 5, 18, 
    2, 72, 4, 55, 3, 48, 0, 34, 1, 90, 5, 28, 6, 29, 7, 48, 8,  8, 
    6, 63, 3, 92, 8, 61, 1, 11, 4, 38, 5, 50, 7, 62, 0, 95, 2, 98, 
    1, 23, 8, 84, 0, 67, 3, 43, 5, 26, 4, 97, 2, 55, 6, 19, 7, 55, 
    5, 28, 3, 35, 8, 93, 1, 88, 2, 91, 0, 42, 4, 66, 6, 90, 7, 18, 
    5, 68, 2, 20, 4, 86, 8,  6, 1, 75, 7, 96, 3, 78, 0, 42, 6, 20
  };
  const int q7797[] = {
    9, 9, // Number of jobs and machines
    1, 44, 2,  8, 3, 95, 0, 19, 5, 53, 6, 28, 7, 57, 8, 64, 4, 40, 
    2, 26, 3, 36, 8, 98, 7,  1, 4, 25, 0, 24, 6, 19, 1, 46, 5, 85, 
    3, 43, 1, 61, 4, 72, 7, 95, 6, 31, 8, 68, 2, 91, 5, 13, 0, 31, 
    7, 18, 5, 87, 8, 14, 1, 79, 4, 60, 2, 28, 0, 38, 6, 41, 3, 86, 
    3, 97, 4,  9, 8, 53, 1, 97, 6, 85, 2, 40, 5, 30, 7,  6, 0,  8, 
    1, 85, 6, 83, 8, 57, 5, 22, 7, 55, 3, 54, 2, 81, 0, 66, 4, 48, 
    7, 59, 1, 68, 2, 39, 3,  7, 4, 60, 0, 20, 6, 43, 8, 41, 5, 31, 
    7, 71, 8, 66, 2, 68, 6, 47, 0, 38, 3, 74, 1, 55, 4, 40, 5, 36, 
    4,  6, 3, 61, 1, 36, 5, 61, 0, 83, 2, 79, 8,  4, 7,  4, 6, 54
  };
  const int q7798[] = {
    9, 9, // Number of jobs and machines
    4, 57, 1, 21, 6, 25, 8, 79, 0, 53, 7, 17, 2,  7, 5, 16, 3, 71, 
    0, 65, 3, 83, 4, 63, 6, 29, 2, 79, 7, 45, 1, 62, 5, 33, 8, 59, 
    5, 49, 3, 10, 1, 99, 4, 31, 6, 93, 0, 65, 8, 54, 2,  3, 7, 10, 
    0, 45, 5, 68, 1, 46, 7,  1, 2, 39, 8,  8, 3, 13, 4, 18, 6, 70, 
    5, 60, 3, 31, 4, 19, 2, 31, 0, 45, 6, 71, 7, 50, 1, 35, 8, 29, 
    3, 29, 1, 57, 4,  1, 0, 47, 5, 85, 7, 21, 2, 76, 6,  4, 8, 82, 
    8, 42, 1, 89, 0, 81, 3, 85, 6, 83, 2, 33, 5,  5, 7, 26, 4, 69, 
    2, 76, 6,  5, 5,  8, 7, 68, 0, 98, 4, 32, 1, 84, 8, 95, 3,  8, 
    6, 12, 7, 17, 8, 80, 4, 40, 3,  9, 2, 80, 1, 31, 0, 45, 5, 59
  };
  const int q7799[] = {
    9, 9, // Number of jobs and machines
    7, 75, 4, 56, 1, 94, 2, 26, 8, 51, 5, 40, 6, 55, 0, 92, 3, 20, 
    4, 13, 6, 77, 2, 24, 0, 55, 7, 22, 3, 17, 1, 30, 8, 60, 5, 86, 
    1, 20, 8,  8, 7, 54, 6,  6, 4, 50, 3, 63, 0, 60, 5, 74, 2, 74, 
    5, 97, 3, 45, 0, 98, 4, 15, 7, 19, 8, 12, 2,  7, 6, 23, 1, 35, 
    7, 94, 8, 65, 1, 94, 4, 28, 2, 50, 6,  1, 3, 17, 0, 89, 5, 69, 
    3, 80, 1, 82, 7, 67, 6, 45, 2, 68, 5, 43, 8, 39, 4, 68, 0, 33, 
    1, 36, 0, 64, 3, 18, 4, 68, 8, 63, 2, 67, 5, 76, 6, 55, 7, 99, 
    2, 94, 0, 77, 8, 58, 5, 69, 3, 93, 7, 25, 1, 10, 6, 63, 4, 31, 
    5, 82, 2, 84, 6, 40, 4,  8, 8, 37, 1, 80, 3, 38, 0,  5, 7, 35
  };
  const int q7800[] = {
    9, 9, // Number of jobs and machines
    2, 31, 0, 18, 1, 94, 6, 51, 7, 26, 5, 69, 3, 40, 8, 84, 4, 43, 
    0, 89, 4, 13, 2, 74, 6, 19, 3, 16, 8, 21, 7, 85, 1, 99, 5, 56, 
    4, 26, 7, 54, 5, 99, 1, 76, 3, 46, 0,  2, 2,  6, 6,  4, 8, 77, 
    4, 61, 7, 70, 0, 25, 3, 16, 2,  5, 6, 82, 5, 11, 8, 57, 1, 88, 
    0, 94, 3, 89, 6, 45, 1, 91, 5,  9, 7, 56, 8, 41, 2, 70, 4, 40, 
    1, 60, 6, 85, 7, 80, 0, 27, 8, 55, 3, 87, 2, 92, 5, 31, 4, 87, 
    3, 83, 2, 19, 5, 91, 6, 38, 1,  8, 8, 84, 7, 38, 0, 83, 4, 57, 
    3, 29, 0, 29, 8,  5, 2, 38, 6,  4, 5, 25, 1, 22, 4, 35, 7, 81, 
    2,  7, 5,  9, 0, 52, 4, 70, 7, 76, 3, 57, 1, 23, 6, 80, 8, 51
  };
  const int q7801[] = {
    9, 9, // Number of jobs and machines
    0, 23, 8, 70, 5, 49, 2, 54, 1, 64, 6, 26, 4, 61, 3, 78, 7, 37, 
    2, 84, 1, 74, 6, 94, 0, 82, 7, 80, 8, 11, 4, 61, 3, 29, 5, 16, 
    4, 59, 5, 27, 8,  7, 2, 39, 3, 58, 1, 38, 0, 47, 7, 51, 6, 80, 
    6, 45, 0, 49, 7,  8, 5, 63, 4, 28, 2, 12, 3, 95, 8, 15, 1, 59, 
    3, 86, 8,  3, 2, 23, 5, 92, 1, 46, 4, 74, 6, 43, 7, 58, 0, 87, 
    7, 19, 5, 78, 0, 81, 6,  7, 4, 29, 1, 10, 3, 26, 8, 11, 2, 52, 
    2, 49, 4, 82, 5, 85, 8, 74, 7,  7, 3, 34, 1, 69, 6, 77, 0, 28, 
    8, 75, 5, 53, 1, 82, 7, 19, 0, 77, 3, 72, 6, 21, 4, 18, 2, 31, 
    0, 97, 3, 51, 6, 27, 4, 73, 2, 14, 8, 48, 7, 40, 5, 29, 1, 90
  };
  const int q7802[] = {
    9, 9, // Number of jobs and machines
    2, 24, 7, 68, 8, 66, 4, 76, 6, 45, 0, 57, 3, 22, 5, 94, 1, 42, 
    1, 76, 6, 69, 4, 38, 8, 46, 5, 63, 0, 21, 2, 25, 7, 55, 3, 84, 
    3, 44, 7, 52, 2, 15, 6,  3, 4, 98, 0, 40, 5, 41, 1, 42, 8,  9, 
    4,  2, 0, 56, 3, 49, 5, 78, 6, 41, 2, 58, 7, 97, 1, 55, 8, 77, 
    4, 34, 2, 17, 8, 13, 1, 99, 6, 57, 5,  8, 3, 65, 7, 39, 0, 84, 
    8, 98, 0, 24, 4, 37, 3, 92, 7, 46, 2, 47, 1, 35, 6, 93, 5, 91, 
    2, 44, 8, 11, 1, 95, 0, 17, 6,  8, 5, 96, 4, 85, 7, 85, 3, 33, 
    3, 60, 4, 56, 5, 60, 2, 60, 6,  2, 8, 84, 1, 45, 0, 12, 7, 89, 
    8, 67, 0, 34, 2,  4, 7, 28, 6, 19, 1, 74, 3, 28, 4, 90, 5, 23
  };
  const int q7803[] = {
    9, 9, // Number of jobs and machines
    6, 92, 7, 44, 4, 96, 1, 12, 5, 91, 2, 71, 0,  2, 3, 69, 8, 89, 
    6, 20, 2, 26, 5,  2, 3, 12, 4, 78, 7, 63, 1, 51, 0, 56, 8, 64, 
    2, 25, 6, 10, 8, 39, 1, 23, 3, 19, 4, 37, 7, 27, 0, 89, 5, 33, 
    4, 13, 6, 80, 1, 27, 5, 61, 7, 82, 2, 72, 8, 88, 0, 87, 3, 96, 
    2, 56, 8, 95, 3, 89, 0, 10, 7, 41, 4, 53, 5, 97, 6, 10, 1, 13, 
    0, 13, 1, 49, 5, 81, 3,  1, 8, 87, 6, 64, 4,  3, 7, 85, 2, 75, 
    6, 86, 2, 29, 0, 84, 1, 31, 7, 37, 5, 57, 3,  2, 4, 23, 8, 63, 
    7, 74, 3, 98, 4, 84, 1, 44, 6, 20, 8,  3, 5, 86, 0, 35, 2,  7, 
    8, 32, 1,  7, 2,  8, 3, 68, 4, 65, 6,  2, 0, 92, 5, 67, 7, 60
  };
  const int q7804[] = {
    9, 9, // Number of jobs and machines
    7,  4, 4, 49, 5, 12, 3, 78, 1, 22, 0, 73, 8, 39, 6, 49, 2, 76, 
    8, 46, 0, 10, 6, 98, 7, 47, 1, 99, 2, 77, 4, 31, 3, 19, 5, 73, 
    6, 15, 4, 46, 5,  2, 3, 41, 1, 90, 7,  8, 0, 52, 8, 54, 2, 33, 
    1, 11, 5,  4, 7, 80, 3, 67, 8, 35, 0, 43, 4, 72, 6, 65, 2, 82, 
    5, 75, 2, 74, 3,  8, 1, 53, 8, 79, 4, 43, 0, 20, 7, 35, 6, 26, 
    1, 15, 3, 93, 5, 56, 4,  2, 8, 29, 7, 19, 0, 82, 2,  5, 6, 42, 
    1, 73, 5, 10, 7, 16, 8, 35, 4, 21, 6,  9, 3,  1, 0, 53, 2, 91, 
    6, 50, 2,  9, 4, 92, 5, 94, 8, 14, 3, 23, 7, 37, 0,  7, 1, 50, 
    6, 30, 1, 17, 4,  1, 5, 58, 8, 94, 2, 89, 0, 80, 7, 58, 3, 56
  };
  const int q7805[] = {
    9, 9, // Number of jobs and machines
    0, 17, 2, 53, 4, 43, 7, 48, 6, 22, 5, 18, 1, 85, 8, 35, 3, 26, 
    2, 90, 4, 87, 1, 34, 7,  5, 6, 61, 8, 44, 5, 86, 3, 80, 0, 69, 
    6, 99, 8, 74, 7, 41, 1, 97, 0, 62, 4, 73, 3, 36, 2, 12, 5, 97, 
    0, 37, 6, 47, 2, 20, 3, 85, 8, 20, 4,  8, 1, 57, 7, 87, 5, 82, 
    1, 53, 4, 38, 8, 55, 2, 83, 0, 29, 5, 84, 7, 38, 6, 93, 3, 93, 
    4, 18, 8, 51, 3, 56, 0, 25, 1, 15, 7,  5, 5, 76, 6, 33, 2, 48, 
    2, 56, 4, 40, 7, 28, 3, 65, 5, 35, 6, 56, 0, 56, 8, 53, 1, 39, 
    4, 59, 0, 47, 2, 73, 8, 86, 6, 34, 5,  2, 3, 41, 1, 18, 7, 88, 
    2, 76, 0, 16, 4, 80, 8, 96, 7, 88, 5,  8, 1, 94, 3, 74, 6, 10
  };
  const int q7806[] = {
    9, 9, // Number of jobs and machines
    1, 66, 8, 84, 5, 62, 4, 45, 7, 53, 3, 45, 2, 26, 0, 99, 6, 13, 
    2, 49, 8, 25, 6,  5, 5, 67, 3, 15, 1, 91, 0, 59, 4, 80, 7, 98, 
    0, 69, 6, 55, 7, 19, 4, 68, 5, 28, 1, 75, 8, 83, 3, 80, 2, 92, 
    0, 69, 2, 62, 5, 98, 7, 62, 8, 43, 1,  9, 6, 78, 3, 86, 4, 59, 
    2, 95, 8, 41, 6, 12, 3, 21, 5, 20, 1, 87, 0, 52, 4, 15, 7, 24, 
    4, 60, 8, 44, 7, 97, 5, 39, 2, 54, 0, 28, 3, 89, 6, 21, 1, 87, 
    6, 40, 4, 21, 7, 55, 0, 76, 5, 51, 1, 10, 2, 30, 8, 98, 3,  5, 
    2, 38, 5, 53, 1, 65, 0, 75, 4, 80, 8, 36, 7, 12, 6, 87, 3, 79, 
    5, 53, 4, 49, 6, 23, 1, 70, 8, 68, 3, 85, 0, 58, 7, 50, 2, 64
  };
  const int q7807[] = {
    9, 9, // Number of jobs and machines
    6, 19, 8, 55, 1, 60, 2, 66, 5, 24, 7, 68, 0,  2, 3, 89, 4, 45, 
    8, 34, 1, 64, 2, 64, 3, 55, 4, 45, 0, 57, 7, 66, 6, 89, 5, 48, 
    1, 37, 6,  8, 0, 63, 2, 55, 5, 40, 3, 99, 8, 94, 4, 13, 7, 69, 
    8, 28, 5, 53, 2, 51, 0,  3, 3, 11, 6, 37, 1, 29, 4,  8, 7, 52, 
    0, 19, 7, 30, 3, 66, 2,  2, 6, 52, 1, 25, 8, 48, 5, 66, 4,  1, 
    2, 94, 3, 68, 1, 68, 8, 19, 4, 81, 6, 10, 7,  7, 0, 51, 5, 44, 
    7, 20, 6, 19, 2, 76, 5, 60, 3, 21, 8, 67, 0, 80, 1, 21, 4,  4, 
    4, 77, 6, 67, 1, 17, 0, 82, 5, 19, 3, 51, 2, 26, 7, 43, 8,  5, 
    5, 58, 3, 72, 8, 80, 6, 48, 2, 14, 0, 52, 1, 37, 7, 86, 4, 23
  };
  const int q7808[] = {
    9, 9, // Number of jobs and machines
    0, 61, 8, 70, 5, 68, 4, 22, 3, 38, 1, 22, 2, 18, 6, 47, 7, 77, 
    3, 46, 1, 84, 5, 14, 7, 89, 6, 72, 4, 85, 2, 83, 0, 13, 8, 78, 
    4, 48, 5, 65, 6, 72, 8, 41, 7, 98, 2, 27, 1, 96, 0, 84, 3, 88, 
    0, 45, 3, 92, 6, 88, 8, 87, 1, 42, 5, 14, 7, 12, 2, 74, 4, 92, 
    2, 94, 0, 24, 5, 84, 1, 33, 8, 91, 7, 32, 6, 80, 3,  2, 4, 71, 
    2, 97, 4, 13, 0,  6, 5, 69, 8, 62, 6, 87, 3, 94, 1, 29, 7, 96, 
    3, 85, 1, 28, 7, 37, 4, 91, 8, 53, 0, 11, 6, 16, 2, 62, 5, 55, 
    6, 34, 5, 80, 3, 67, 8, 75, 0, 53, 7, 57, 4, 18, 2, 50, 1, 48, 
    6, 69, 5, 10, 0, 23, 4, 33, 3, 15, 8, 96, 7, 96, 2, 37, 1, 63
  };
  const int q7809[] = {
    9, 9, // Number of jobs and machines
    2, 40, 3, 16, 5, 96, 4,  1, 1,  3, 8, 52, 6, 76, 0, 85, 7, 98, 
    2, 75, 1, 30, 0, 99, 8,  5, 5, 69, 4, 34, 6, 51, 3, 54, 7, 76, 
    0, 82, 7, 90, 8, 70, 6, 59, 2, 73, 5, 98, 3, 21, 1, 50, 4,  8, 
    7, 50, 6, 85, 8, 44, 2, 49, 0, 98, 1, 77, 4, 34, 5, 58, 3, 30, 
    2, 72, 5, 30, 7, 25, 4, 11, 8, 19, 0, 91, 3, 75, 1, 81, 6, 44, 
    0, 82, 3, 21, 1, 92, 8, 29, 6, 17, 2, 48, 7, 30, 4, 83, 5,  2, 
    4, 63, 2, 31, 1, 21, 5, 29, 6, 91, 7,  8, 3, 86, 8, 20, 0, 77, 
    1, 41, 5, 40, 3, 84, 8, 51, 6, 57, 7, 98, 2, 66, 0, 82, 4, 84, 
    1, 50, 4, 33, 3, 45, 8,  8, 5, 61, 7, 84, 6, 78, 0, 39, 2, 13
  };
  const int q7810[] = {
    9, 9, // Number of jobs and machines
    1, 41, 6,  6, 4, 60, 3, 76, 0, 87, 5, 74, 2,  4, 7,  3, 8, 85, 
    8, 37, 7, 25, 0, 87, 2, 30, 3, 26, 4, 35, 1, 24, 5, 84, 6, 34, 
    7, 83, 4, 89, 8, 83, 6, 17, 2,  6, 3,  1, 0, 45, 5, 49, 1, 82, 
    4, 81, 0, 55, 2, 48, 3, 17, 7, 67, 1, 90, 8, 89, 6, 79, 5, 40, 
    6, 26, 4, 51, 5, 68, 7, 76, 3, 56, 2, 61, 0, 38, 1, 36, 8, 10, 
    3, 62, 0, 38, 7, 91, 4, 76, 2,  9, 6, 51, 1, 63, 8, 20, 5, 19, 
    5, 34, 6, 82, 8, 18, 7, 95, 1, 29, 0, 91, 3, 15, 4, 94, 2, 81, 
    7, 70, 8, 81, 3,  4, 2, 67, 4, 13, 6, 92, 0, 62, 1, 84, 5, 82, 
    0, 92, 1, 91, 5, 46, 8, 36, 6,  6, 3, 54, 2, 11, 7, 61, 4, 63
  };
  const int q7811[] = {
    9, 9, // Number of jobs and machines
    5, 60, 1, 69, 8, 12, 4, 88, 6, 59, 7, 77, 2, 76, 0, 81, 3, 86, 
    6, 56, 1, 19, 3, 21, 4, 54, 2, 94, 5,  9, 8, 35, 0, 66, 7, 45, 
    7, 37, 8,  8, 1, 82, 6, 90, 0, 99, 4, 28, 5,  4, 2, 45, 3, 33, 
    1, 86, 3, 47, 4, 33, 0, 77, 7,  5, 6, 51, 5, 61, 8, 68, 2, 35, 
    6, 64, 0, 86, 1,  1, 7, 30, 3, 29, 8, 74, 5,  9, 4, 86, 2, 74, 
    8, 84, 7, 12, 0, 43, 5, 20, 1, 99, 4, 48, 3, 50, 2, 73, 6, 83, 
    7, 52, 1, 83, 6, 37, 8, 92, 2,  9, 5, 72, 4, 69, 0, 90, 3, 48, 
    2, 85, 1, 37, 4, 28, 7, 16, 6, 42, 5, 37, 0,  4, 8, 70, 3, 34, 
    0, 54, 1, 86, 6, 24, 3, 11, 7, 91, 4, 37, 8, 12, 5, 78, 2, 70
  };
  const int q7812[] = {
    9, 9, // Number of jobs and machines
    8, 53, 3,  3, 0, 26, 2, 41, 1, 31, 6, 78, 7, 23, 5,  9, 4, 15, 
    5, 31, 6, 36, 7, 21, 2, 93, 1, 86, 0,  3, 3, 59, 4, 85, 8, 85, 
    2, 74, 1, 59, 6,  3, 4, 35, 5, 30, 0, 10, 7, 95, 3, 36, 8, 92, 
    2,  7, 3, 85, 0, 12, 4, 93, 8, 56, 1, 92, 6, 84, 7, 23, 5, 87, 
    8, 93, 2,  2, 3, 92, 5, 47, 6, 27, 1, 43, 4, 22, 7, 86, 0, 11, 
    8,  2, 7, 23, 0, 97, 1, 59, 6, 63, 3, 32, 5, 73, 4, 71, 2, 93, 
    1, 43, 6, 28, 8, 56, 4, 94, 7,  9, 2, 69, 3, 19, 5, 42, 0,  6, 
    6, 42, 1, 39, 5, 37, 4, 56, 8, 63, 3, 72, 0, 26, 2,  1, 7, 14, 
    1, 11, 4, 78, 0, 16, 5, 93, 3, 34, 7, 55, 2, 28, 8, 37, 6, 21
  };
  const int q7813[] = {
    9, 9, // Number of jobs and machines
    7, 90, 1, 84, 5, 13, 8, 15, 4, 11, 3, 39, 0, 78, 2, 80, 6, 44, 
    7,  5, 3, 17, 6, 15, 4, 55, 1, 55, 8, 25, 0, 79, 2, 88, 5, 90, 
    3, 58, 8, 69, 6, 97, 7, 58, 1, 53, 5,  9, 2, 31, 4, 17, 0, 46, 
    4, 88, 3, 35, 0, 44, 7,  9, 5,  8, 1,  3, 8, 82, 6, 56, 2, 39, 
    1,  7, 6, 74, 7, 11, 2, 49, 5, 35, 4, 26, 8, 38, 3,  5, 0, 85, 
    6, 83, 8, 39, 7, 38, 0, 48, 2, 37, 1, 59, 5, 61, 4,  7, 3, 46, 
    4, 89, 0,  6, 3, 82, 1,  3, 2, 55, 8, 65, 7,  8, 6, 45, 5, 50, 
    6, 68, 3, 21, 1,  4, 4, 30, 0, 59, 7, 92, 2, 76, 5, 20, 8, 36, 
    1, 80, 6, 82, 3, 16, 0, 54, 7, 37, 4, 26, 2, 21, 5, 12, 8, 31
  };
  const int q7814[] = {
    9, 9, // Number of jobs and machines
    4, 58, 5, 94, 1, 11, 6, 23, 2, 89, 3, 26, 7, 94, 0, 75, 8, 17, 
    4, 88, 1, 85, 2, 41, 6,  4, 0, 82, 7, 26, 3, 82, 8, 13, 5, 29, 
    1, 90, 6, 85, 8,  3, 4, 66, 0, 80, 3, 78, 7, 68, 5, 57, 2, 49, 
    6, 62, 4,  2, 7, 59, 3, 75, 5, 50, 1, 33, 2, 58, 0, 70, 8, 38, 
    0, 43, 3, 91, 4,  2, 1, 92, 8, 51, 5, 95, 2, 34, 6, 93, 7, 12, 
    3, 27, 0, 19, 7,  6, 8, 34, 5, 67, 1, 13, 4, 60, 2, 40, 6, 69, 
    6, 96, 2, 27, 4, 91, 0, 80, 7, 53, 8, 86, 5, 49, 1, 98, 3, 65, 
    6, 49, 3, 70, 8, 75, 0, 64, 1, 45, 2, 94, 5, 31, 4, 32, 7, 20, 
    3, 59, 2, 86, 8,  2, 5, 43, 7, 95, 1, 65, 4, 99, 0, 42, 6, 57
  };
  const int q7815[] = {
    9, 9, // Number of jobs and machines
    4, 38, 2, 69, 7, 90, 3, 47, 0, 33, 1, 72, 8, 44, 6, 26, 5, 66, 
    4,  3, 7, 61, 5, 56, 6, 19, 8, 97, 2, 12, 1, 25, 3, 21, 0, 37, 
    4, 57, 3, 25, 0, 72, 2, 49, 1, 33, 7, 27, 6, 86, 8, 71, 5, 66, 
    7, 65, 2, 25, 4, 44, 8, 22, 6, 15, 3, 71, 1, 39, 0, 85, 5, 17, 
    7, 24, 0, 51, 6, 71, 1, 39, 5, 84, 2, 20, 3, 35, 4, 28, 8, 99, 
    8, 85, 6, 89, 4, 45, 1, 19, 0, 51, 5, 25, 3, 40, 2, 85, 7, 37, 
    2, 86, 8, 54, 0, 19, 6, 80, 7,  4, 4, 48, 3, 30, 5, 63, 1, 98, 
    5, 35, 4, 51, 2,  7, 3, 27, 6,  2, 0, 23, 1, 74, 8, 98, 7, 27, 
    2, 31, 8,  9, 1, 94, 0, 80, 6,  5, 7, 33, 5, 27, 3, 51, 4, 91
  };
  const int q7816[] = {
    9, 9, // Number of jobs and machines
    2, 51, 3, 99, 6, 20, 4, 17, 7, 64, 5, 91, 8, 44, 0, 91, 1, 39, 
    0,  3, 8, 38, 6, 52, 2, 97, 5, 22, 3, 12, 7, 36, 1, 29, 4, 10, 
    4, 81, 6, 57, 5, 10, 7,  8, 2, 37, 3,  3, 8, 42, 1,  2, 0,  9, 
    1, 35, 3, 66, 0, 79, 2, 46, 4, 68, 5, 92, 6, 81, 7, 96, 8, 62, 
    1, 54, 4, 57, 0, 61, 6, 24, 8, 56, 5, 69, 2, 92, 3, 15, 7, 53, 
    7, 54, 0, 56, 2, 81, 3, 27, 5, 62, 4, 70, 6, 48, 8, 53, 1, 38, 
    1, 17, 7, 92, 4, 86, 2, 90, 3, 40, 0, 66, 6, 96, 8, 26, 5, 11, 
    1, 85, 6,  3, 7, 94, 5, 19, 8, 41, 3, 75, 2, 51, 4, 21, 0, 40, 
    8, 96, 2, 97, 4,  7, 3, 34, 7, 63, 6, 55, 1, 73, 0,  4, 5, 41
  };
  const int q7817[] = {
    9, 9, // Number of jobs and machines
    3, 73, 5, 71, 7, 10, 4,  4, 1, 28, 0, 38, 6, 37, 2, 49, 8, 62, 
    3, 37, 8, 73, 7, 84, 2, 36, 5, 28, 4, 59, 0, 48, 1,  1, 6, 52, 
    5, 32, 2, 69, 4, 33, 3, 64, 6, 54, 8, 69, 0, 86, 1, 75, 7, 29, 
    1, 20, 0, 73, 7, 81, 8, 86, 6, 20, 2,  3, 5, 86, 3, 29, 4, 53, 
    6, 71, 1, 62, 8, 65, 3, 61, 0, 37, 5, 94, 2, 61, 7,  2, 4, 82, 
    0, 30, 4,  5, 6, 42, 8, 33, 2,  9, 1, 92, 7, 90, 5, 92, 3, 31, 
    3, 77, 0, 16, 8,  9, 1, 38, 7, 10, 2, 65, 4, 51, 6, 35, 5, 85, 
    1, 59, 8, 76, 0, 51, 5, 26, 2, 78, 6, 33, 4, 75, 3, 56, 7,  8, 
    4, 54, 7, 51, 6,  1, 1, 55, 3, 57, 2, 95, 5, 20, 0, 62, 8, 88
  };
  const int q7818[] = {
    9, 9, // Number of jobs and machines
    4, 97, 8, 94, 3, 42, 5, 98, 6, 52, 0, 72, 2, 56, 1, 66, 7, 79, 
    0, 97, 7, 10, 1, 84, 6, 77, 2, 76, 5, 99, 3, 83, 4, 29, 8, 84, 
    6, 77, 0, 64, 4, 57, 7, 10, 1, 81, 2,  2, 8, 94, 5, 75, 3, 10, 
    0, 79, 4, 33, 5, 22, 1, 80, 3, 24, 2, 96, 8, 50, 7, 62, 6,  3, 
    0, 39, 4, 24, 8, 72, 5, 88, 3, 12, 7,  8, 6, 45, 2, 47, 1, 12, 
    7, 90, 8,  2, 0, 14, 4, 65, 3, 36, 6, 20, 2, 55, 5, 93, 1, 66, 
    5, 55, 7, 92, 3, 68, 8, 56, 1, 43, 0, 64, 4, 19, 6, 65, 2, 11, 
    8, 26, 6, 63, 2,  8, 4, 46, 3,  8, 7, 77, 0, 82, 5, 41, 1, 19, 
    8, 63, 0,  9, 2, 85, 6, 47, 5, 53, 7, 19, 1, 41, 3, 67, 4, 79
  };
  const int q7819[] = {
    9, 9, // Number of jobs and machines
    8, 87, 5,  5, 4, 80, 6, 13, 0, 31, 7, 22, 1, 93, 2,  7, 3, 14, 
    8, 27, 2, 65, 1, 46, 6, 27, 3, 73, 5,  3, 0,  3, 7, 21, 4, 81, 
    1, 20, 4,  9, 5, 28, 0, 63, 8, 73, 6, 40, 3, 43, 7, 70, 2, 10, 
    4, 39, 7, 95, 2, 69, 3, 38, 0, 94, 6, 84, 5,  4, 8, 91, 1, 31, 
    7, 25, 1, 97, 5, 30, 0, 23, 6, 40, 2,  6, 8, 75, 3, 15, 4, 46, 
    5, 58, 1, 71, 6, 14, 8, 33, 2, 51, 3, 44, 4, 39, 7, 27, 0, 66, 
    6, 89, 4, 54, 1, 23, 7, 70, 2, 37, 3, 46, 8, 93, 0, 76, 5, 94, 
    7, 88, 5, 89, 8, 64, 3, 30, 0, 85, 2, 42, 1, 16, 4, 25, 6, 85, 
    3, 94, 0,  5, 7, 51, 4, 61, 8, 25, 6, 60, 2, 71, 5, 78, 1, 57
  };
  const int q7820[] = {
    9, 9, // Number of jobs and machines
    6, 67, 2, 32, 7, 36, 8, 84, 1, 92, 5, 49, 4, 48, 3, 18, 0, 43, 
    1, 49, 0,  1, 8, 53, 3,  8, 4, 49, 6, 27, 2, 27, 5, 99, 7, 44, 
    2, 28, 4, 47, 5, 91, 0, 61, 7, 52, 1, 29, 8, 16, 6, 86, 3, 25, 
    4, 18, 7, 78, 6, 70, 8, 42, 1, 83, 2, 55, 3, 44, 5, 76, 0, 34, 
    1, 59, 3, 93, 5, 62, 0, 54, 8, 48, 4, 21, 6, 82, 7, 33, 2, 90, 
    4, 43, 3, 93, 0, 17, 5, 59, 1, 68, 8, 91, 2,  6, 7, 65, 6, 69, 
    3,  3, 5, 43, 1,  8, 6, 93, 2, 60, 4, 11, 0, 37, 8, 11, 7, 69, 
    8, 94, 6, 87, 1, 83, 4, 81, 3, 81, 5, 77, 2, 65, 7, 74, 0, 14, 
    1, 87, 8, 65, 6, 16, 0, 82, 4, 34, 3, 57, 5, 38, 2, 25, 7, 94
  };
  const int q7821[] = {
    9, 9, // Number of jobs and machines
    1,  1, 5, 16, 2, 35, 4, 61, 7, 51, 8, 99, 3, 16, 0, 60, 6, 19, 
    1, 23, 6, 95, 7, 15, 0, 30, 4, 34, 5, 62, 2, 64, 3, 91, 8, 28, 
    3, 61, 2, 16, 5, 64, 7, 91, 8, 93, 1, 93, 6, 65, 4,  9, 0, 78, 
    1, 83, 6, 26, 0, 77, 8,  9, 5, 26, 4,  3, 2, 60, 3, 47, 7, 47, 
    2, 23, 1, 75, 0, 84, 6, 56, 7, 13, 3, 91, 4, 71, 8, 18, 5, 89, 
    1, 17, 3, 99, 8, 10, 5, 53, 7, 47, 6, 34, 4, 58, 2, 17, 0, 40, 
    5, 48, 3, 31, 8, 38, 2,  2, 0, 30, 1, 51, 4, 66, 6, 74, 7, 24, 
    4,  5, 3, 32, 5, 31, 6, 95, 1, 65, 2, 40, 7, 80, 0, 69, 8, 18, 
    8, 89, 0, 82, 4, 85, 5, 85, 7, 99, 3, 46, 2, 15, 6, 69, 1, 32
  };
  const int q7822[] = {
    9, 9, // Number of jobs and machines
    2, 85, 1, 47, 6, 65, 4, 95, 8, 77, 5, 95, 3, 83, 0, 44, 7, 16, 
    6, 75, 2, 25, 0, 56, 1,  8, 7, 56, 4, 41, 3, 32, 5, 66, 8, 74, 
    2, 49, 8, 66, 1, 45, 7, 41, 6, 87, 5, 71, 0, 24, 4, 95, 3, 87, 
    3, 12, 5, 25, 7, 85, 6, 53, 1, 78, 2, 38, 0, 81, 4, 46, 8, 85, 
    7, 10, 8,  8, 5, 84, 4, 30, 2, 40, 6, 46, 1, 91, 3, 40, 0, 81, 
    2, 74, 1, 85, 0, 24, 4, 57, 5,  2, 3, 96, 7, 99, 6, 65, 8, 68, 
    8, 51, 2, 30, 6, 80, 7, 64, 5, 42, 1, 21, 4, 19, 0, 55, 3, 34, 
    8, 41, 2,  5, 0, 61, 4, 41, 6, 24, 7, 42, 5, 86, 1, 49, 3, 79, 
    1, 87, 7, 85, 5, 30, 3,  7, 6, 12, 8, 89, 0, 91, 4, 23, 2, 53
  };
  const int q7823[] = {
    9, 9, // Number of jobs and machines
    5, 68, 1, 14, 0, 93, 6,  2, 7, 29, 4, 81, 2, 76, 8, 69, 3, 20, 
    7, 16, 1, 11, 2,  6, 3, 26, 6, 53, 4, 61, 8, 31, 0,  7, 5, 10, 
    5, 65, 0, 39, 3, 63, 7, 16, 6, 45, 1, 52, 4, 68, 8, 52, 2,  2, 
    0, 99, 8, 11, 3, 96, 7, 62, 5, 78, 2, 25, 6, 92, 4, 28, 1, 18, 
    2, 39, 0, 30, 3, 36, 6, 72, 8, 49, 5, 38, 4, 81, 1, 89, 7,  6, 
    5, 29, 6, 81, 3, 78, 2, 75, 4, 44, 8, 85, 0, 52, 1,  2, 7, 63, 
    7, 88, 2, 50, 8,  7, 0, 37, 4, 58, 6, 58, 3, 91, 5, 95, 1, 57, 
    3, 14, 1,  9, 8, 59, 5, 28, 7, 19, 2, 21, 0,  9, 4, 24, 6, 46, 
    5, 71, 7, 62, 2, 55, 6,  8, 1, 90, 4, 63, 8, 26, 3, 55, 0,  7
  };
  const int q7824[] = {
    9, 9, // Number of jobs and machines
    3, 35, 1, 15, 2, 21, 5, 75, 7, 98, 8,  4, 4, 54, 6, 58, 0, 91, 
    8, 82, 1, 17, 6, 36, 4, 34, 5, 42, 2, 59, 7,  1, 0, 50, 3, 47, 
    0, 90, 8, 92, 6, 83, 4, 14, 5, 75, 2, 32, 1,  2, 3, 23, 7, 32, 
    5, 51, 7, 34, 8, 27, 0, 94, 3, 55, 2, 21, 6, 32, 1, 61, 4, 91, 
    0, 44, 5, 80, 7, 95, 3, 80, 6, 89, 1, 78, 2, 62, 8, 46, 4, 76, 
    5, 96, 2, 11, 1, 40, 6, 87, 8,  4, 3, 44, 7, 68, 4,  6, 0, 20, 
    4, 72, 5, 16, 8,  1, 2, 94, 6, 90, 7,  6, 3, 12, 0, 84, 1, 23, 
    0, 28, 4, 72, 2, 54, 1, 70, 7, 84, 3, 16, 8, 88, 5, 56, 6, 41, 
    2, 22, 4,  4, 0, 74, 1, 35, 6, 39, 5, 97, 3, 66, 8, 98, 7,  6
  };
  const int q7825[] = {
    9, 9, // Number of jobs and machines
    4, 92, 5, 44, 7, 55, 3, 45, 6, 31, 1, 34, 8, 84, 0, 42, 2, 56, 
    8, 37, 4, 39, 1, 97, 5, 82, 2, 16, 7, 61, 6, 59, 3, 88, 0, 79, 
    5, 34, 4, 71, 2, 30, 0, 33, 8, 28, 6, 98, 1, 94, 3, 42, 7, 27, 
    5, 82, 0, 49, 8, 31, 7, 88, 1, 20, 6, 97, 4, 69, 2, 25, 3, 43, 
    3,  6, 7, 30, 2, 96, 4, 24, 6, 47, 8, 43, 1, 96, 0, 80, 5, 44, 
    4, 11, 5, 38, 6, 92, 8, 67, 1, 56, 7, 73, 3, 59, 2, 87, 0, 95, 
    0, 80, 3, 11, 5, 17, 6, 40, 4, 22, 1, 60, 2, 58, 8, 93, 7, 90, 
    2, 38, 5, 25, 0, 97, 3, 61, 4, 62, 6, 87, 1, 53, 7, 12, 8, 13, 
    1, 28, 3, 82, 8, 45, 0, 27, 6,  9, 2, 28, 7, 74, 5, 80, 4, 77
  };
  const int q7826[] = {
    9, 9, // Number of jobs and machines
    6, 86, 0, 74, 2, 59, 1, 86, 4, 72, 3, 61, 7, 20, 8, 18, 5, 37, 
    7, 72, 5, 39, 3, 98, 4,  3, 2, 72, 1, 97, 8, 99, 6, 86, 0, 29, 
    5, 78, 0, 77, 3, 12, 6, 83, 1, 76, 7, 72, 4, 99, 2, 15, 8, 86, 
    3, 42, 7, 88, 4, 50, 1, 37, 8, 64, 6, 85, 0, 49, 2, 39, 5, 67, 
    8, 11, 1, 62, 7, 53, 4, 96, 2, 99, 0, 39, 3, 29, 5, 80, 6, 30, 
    2, 93, 1, 17, 3, 33, 4, 10, 8, 70, 7, 75, 6, 55, 5, 74, 0, 75, 
    7, 35, 0, 72, 4, 50, 8, 96, 5, 33, 3, 92, 2, 14, 6, 41, 1,  7, 
    6, 78, 1, 78, 5, 27, 3, 57, 4, 79, 2, 72, 0, 60, 8, 40, 7, 31, 
    1, 39, 3, 38, 4, 30, 0, 31, 2, 75, 6, 93, 8, 12, 5, 31, 7, 19
  };
  const int q7827[] = {
    9, 9, // Number of jobs and machines
    4, 89, 3,  8, 2, 37, 6, 66, 7,  6, 8, 47, 1,  4, 5, 70, 0, 38, 
    0, 70, 5, 25, 4,  3, 8, 82, 6, 55, 2, 41, 1, 48, 3, 84, 7,  5, 
    5, 80, 2,  2, 0, 80, 7, 54, 1, 95, 4, 78, 3, 29, 6, 63, 8, 33, 
    2, 76, 1, 41, 4, 36, 6, 43, 3, 34, 8, 13, 5, 51, 7, 49, 0, 85, 
    7, 63, 3, 36, 4, 44, 0, 85, 5,  2, 6,  7, 2, 94, 1, 25, 8,  3, 
    0, 95, 1, 96, 2, 77, 8, 46, 6,  4, 3, 53, 7, 85, 5, 86, 4, 17, 
    5, 27, 3, 53, 6, 51, 0, 66, 4, 41, 8, 48, 7, 97, 2, 20, 1, 12, 
    4, 53, 1, 76, 0, 93, 2, 11, 6, 82, 8, 94, 7, 44, 3, 71, 5,  8, 
    3, 88, 1, 77, 5, 29, 4, 80, 2, 79, 7, 15, 8, 80, 0, 77, 6, 27
  };
  const int q7828[] = {
    9, 9, // Number of jobs and machines
    3,  4, 8, 78, 5, 44, 1,  3, 0, 79, 2, 12, 7, 81, 4, 97, 6, 36, 
    0, 73, 8, 39, 6, 45, 7, 92, 1, 38, 3,  1, 4, 39, 2, 29, 5, 91, 
    4, 92, 5, 80, 2, 79, 3, 70, 7, 22, 6, 77, 0, 64, 1, 39, 8,  5, 
    4,  1, 3, 12, 0, 57, 1, 45, 5, 95, 8, 91, 7, 56, 6, 32, 2, 66, 
    0, 78, 6, 55, 1, 85, 3, 75, 5, 83, 7, 14, 2, 18, 8, 53, 4, 77, 
    6, 14, 4, 56, 7, 22, 0, 81, 8, 28, 2, 42, 5, 67, 1, 28, 3, 44, 
    6, 66, 3, 32, 0, 56, 2, 59, 4, 86, 8, 82, 1, 90, 5, 98, 7, 52, 
    6, 99, 4, 17, 0, 15, 1, 98, 7, 80, 3, 30, 8, 29, 2, 55, 5,  2, 
    1, 46, 0, 11, 8, 58, 7, 60, 3, 46, 2, 88, 4, 40, 5, 51, 6, 68
  };
  const int q7829[] = {
    9, 9, // Number of jobs and machines
    7, 47, 5, 81, 0, 39, 8, 76, 1, 16, 4, 89, 3, 56, 6, 60, 2,  1, 
    0,  2, 2, 24, 7, 46, 3, 62, 6, 99, 1, 26, 4, 78, 5, 73, 8, 78, 
    6, 34, 1, 48, 8, 13, 3, 45, 0, 10, 5, 36, 4, 42, 2, 92, 7, 24, 
    1, 68, 7, 50, 4, 85, 6, 74, 3, 22, 5, 45, 8, 71, 0, 75, 2,  1, 
    5, 40, 2, 74, 6, 19, 8, 64, 0, 21, 7,  9, 3, 29, 1, 40, 4, 25, 
    3, 20, 5, 29, 0, 42, 7, 62, 1, 27, 2, 85, 4, 40, 6, 93, 8, 72, 
    4, 82, 0, 95, 5, 11, 1, 31, 3, 97, 2, 39, 7,  7, 8, 45, 6, 95, 
    5, 31, 6, 89, 1, 83, 3, 87, 4, 73, 8, 61, 2, 50, 7, 87, 0, 28, 
    7, 86, 8, 39, 0, 43, 6, 23, 5, 34, 1, 36, 4, 93, 3, 55, 2, 82
  };
  const int q7830[] = {
    9, 9, // Number of jobs and machines
    6,  7, 8, 16, 0, 79, 2, 51, 3, 52, 5, 40, 4, 78, 7, 84, 1, 32, 
    4, 60, 0, 53, 6, 22, 3, 41, 5, 55, 8, 39, 7, 15, 1, 70, 2, 25, 
    8, 26, 7, 55, 5, 36, 6, 56, 1, 15, 4, 87, 0, 61, 3, 10, 2, 30, 
    2, 74, 3,  1, 6, 61, 0, 30, 8, 63, 1, 23, 4, 21, 7, 75, 5, 86, 
    5, 52, 2, 16, 3, 51, 7, 51, 6, 52, 8, 35, 0, 21, 1, 31, 4, 31, 
    2, 77, 0, 84, 5, 95, 3, 43, 7, 96, 6, 42, 1, 98, 8, 77, 4, 76, 
    7, 40, 6, 32, 8,  7, 4, 36, 1, 74, 0, 46, 3, 64, 5, 63, 2, 19, 
    5, 37, 8, 69, 7, 81, 6, 27, 0, 19, 3, 28, 1,  9, 2, 19, 4, 62, 
    7, 48, 1, 63, 0, 25, 8, 55, 5, 61, 6, 11, 2, 83, 3, 64, 4,  6
  };
  const int q7831[] = {
    9, 9, // Number of jobs and machines
    4, 72, 0, 84, 6, 66, 7, 69, 1, 35, 5, 88, 2, 48, 3,  1, 8, 48, 
    0, 22, 8, 42, 7, 94, 6, 27, 2, 47, 4, 93, 1, 10, 5, 17, 3, 86, 
    1, 97, 8,  4, 0, 22, 5, 81, 2, 85, 4, 48, 3,  7, 6, 39, 7, 87, 
    2, 25, 5, 21, 0, 18, 7, 44, 6, 42, 8, 41, 3, 75, 4,  2, 1, 51, 
    5, 30, 6, 98, 0, 79, 3, 75, 2, 29, 8, 31, 1, 10, 7, 90, 4, 77, 
    7, 17, 0, 88, 8, 80, 4, 61, 6, 60, 3,  7, 5, 56, 2, 57, 1, 51, 
    0, 90, 8,  4, 2,  4, 7, 32, 6, 63, 1, 58, 3, 55, 5, 76, 4, 38, 
    2, 26, 7,  5, 1, 63, 3, 57, 6,  8, 5, 23, 0, 18, 4, 51, 8, 87, 
    7, 77, 2, 46, 5, 41, 3, 62, 0, 35, 1, 91, 6, 30, 4, 76, 8, 13
  };
  const int q7832[] = {
    9, 9, // Number of jobs and machines
    4, 17, 0, 33, 8, 82, 2, 98, 6, 68, 7, 18, 5, 77, 1, 30, 3, 88, 
    0, 73, 6, 24, 4,  7, 1, 39, 8, 70, 3, 13, 5,  7, 2, 60, 7, 73, 
    3, 26, 2,  4, 6, 43, 7, 73, 1,  7, 8,  4, 5, 66, 0, 38, 4, 97, 
    8, 97, 1, 78, 4, 20, 7, 21, 6, 24, 2, 31, 5, 23, 0, 90, 3, 27, 
    6, 32, 5, 13, 1, 76, 2, 97, 4, 88, 3, 46, 0, 21, 8, 54, 7, 35, 
    0, 14, 2, 32, 7, 34, 3, 61, 5, 84, 6, 16, 1, 88, 8, 40, 4, 47, 
    4, 88, 5, 50, 8, 67, 1, 68, 6, 76, 2, 17, 7, 35, 0, 18, 3, 15, 
    6, 29, 1, 86, 4, 92, 3, 44, 8, 74, 7, 92, 0, 47, 5, 59, 2, 27, 
    7, 21, 0, 23, 2, 68, 5, 38, 4, 64, 8, 55, 3, 90, 1, 28, 6, 68
  };
  const int q7833[] = {
    9, 9, // Number of jobs and machines
    6, 86, 3, 45, 4,  3, 5, 88, 0, 19, 7, 28, 1, 98, 2, 56, 8, 23, 
    6, 93, 4, 74, 7, 72, 1, 57, 3, 17, 8, 15, 5, 27, 0, 19, 2, 30, 
    0, 16, 2, 57, 8, 23, 5, 40, 1, 59, 6, 40, 4, 12, 3, 64, 7, 95, 
    3, 82, 6, 98, 7, 43, 2, 14, 0, 53, 5, 92, 1, 34, 4, 10, 8, 19, 
    8, 49, 2, 17, 6, 76, 5, 61, 7, 83, 3,  9, 0, 14, 1, 52, 4, 17, 
    5, 94, 1, 33, 4, 37, 3,  2, 0, 27, 7, 17, 8, 22, 2, 84, 6, 67, 
    1, 99, 5,  4, 8, 23, 4, 58, 7, 67, 0, 40, 2, 99, 6, 78, 3,  4, 
    4, 23, 8, 23, 1, 86, 7, 18, 5, 18, 0, 47, 3, 33, 6,  8, 2, 20, 
    6, 42, 7, 29, 1, 79, 4, 19, 3, 48, 5, 10, 0, 29, 8, 57, 2, 92
  };
  const int q7834[] = {
    9, 9, // Number of jobs and machines
    4, 43, 3, 57, 8, 59, 7, 76, 6, 91, 2, 72, 1, 50, 5, 35, 0, 27, 
    7, 29, 3, 81, 8, 64, 5, 60, 6, 50, 0, 71, 2, 76, 1,  5, 4, 61, 
    0, 16, 7, 43, 2, 39, 1, 25, 8, 45, 6, 94, 3,  5, 5, 51, 4, 30, 
    3, 25, 2, 70, 0, 30, 4, 16, 5, 66, 8, 91, 6, 98, 1, 43, 7, 72, 
    6, 34, 8, 72, 1, 39, 4, 71, 0,  9, 3, 53, 7, 26, 2, 54, 5, 46, 
    6, 35, 8, 99, 7,  8, 3, 65, 1, 83, 4, 37, 2, 71, 0,  7, 5, 79, 
    7, 82, 3, 95, 0, 76, 5, 52, 4, 57, 8, 84, 6, 74, 1, 61, 2, 80, 
    6, 19, 0, 97, 8, 27, 7, 96, 5, 26, 2, 69, 3, 71, 1, 13, 4, 51, 
    8, 87, 2, 38, 1, 53, 6, 68, 4, 95, 3, 38, 0, 96, 7, 68, 5, 77
  };
  const int q7835[] = {
    9, 9, // Number of jobs and machines
    7, 63, 8, 61, 4, 37, 5, 33, 3, 67, 6, 68, 0, 28, 1, 10, 2, 23, 
    6, 32, 7, 18, 4, 78, 2, 68, 1, 61, 0, 72, 8, 60, 3, 56, 5, 33, 
    2, 82, 4, 50, 6, 97, 1, 36, 0, 24, 3, 12, 5, 42, 7, 13, 8, 77, 
    7, 68, 2, 16, 8, 52, 1, 86, 4, 29, 3, 56, 6, 82, 5,  6, 0, 44, 
    7, 77, 2, 61, 6, 99, 1, 71, 3, 64, 0,  4, 5, 50, 8, 90, 4, 14, 
    6, 92, 1, 47, 5,  5, 2, 32, 4, 96, 8, 34, 3, 83, 0, 35, 7, 21, 
    3, 14, 2, 45, 7, 77, 5, 78, 6, 40, 4, 43, 0, 89, 8, 58, 1, 57, 
    6, 42, 0, 96, 4, 49, 3, 53, 1, 85, 5, 88, 2, 98, 7, 74, 8,  5, 
    7, 55, 5, 52, 6, 28, 1, 23, 4, 59, 0, 79, 2, 47, 8, 24, 3, 84
  };
  const int q7836[] = {
    9, 9, // Number of jobs and machines
    0, 88, 5, 57, 6, 26, 2, 22, 8, 19, 1,  3, 7,  7, 3, 32, 4, 80, 
    4, 41, 3,  3, 7,  9, 8, 83, 2, 46, 0, 90, 5, 64, 1,  2, 6, 94, 
    0, 85, 1, 65, 8, 96, 4, 51, 6, 82, 3, 73, 2, 98, 5, 87, 7, 83, 
    8, 31, 3, 23, 7, 31, 0, 46, 6, 17, 4,  9, 2, 63, 1, 40, 5, 82, 
    1, 10, 0, 57, 2,  7, 7, 97, 8, 49, 4, 28, 5, 84, 3, 16, 6, 78, 
    2, 98, 4, 82, 3, 95, 1, 79, 7,  5, 6, 29, 5, 19, 8, 11, 0, 61, 
    2, 99, 7, 28, 6, 59, 3,  5, 4, 38, 1, 85, 0, 68, 8, 32, 5, 97, 
    2, 72, 8, 69, 3, 94, 5, 10, 0, 49, 7, 96, 6, 80, 1, 35, 4, 44, 
    3, 89, 1, 57, 8, 44, 2, 15, 0, 86, 6, 14, 4, 75, 5,  5, 7, 18
  };
  const int q7837[] = {
    9, 9, // Number of jobs and machines
    7, 36, 4, 93, 3, 83, 2, 87, 1, 76, 0, 94, 5, 25, 8, 49, 6, 97, 
    7, 58, 6, 55, 3, 69, 5, 85, 8, 92, 0, 21, 4, 93, 1, 94, 2, 96, 
    6, 27, 4, 85, 2,  6, 0, 97, 8, 73, 1, 51, 7, 24, 5, 54, 3, 10, 
    7, 89, 3, 27, 6, 76, 0, 12, 4, 96, 8, 59, 1, 30, 2,  8, 5, 35, 
    4, 44, 8, 90, 3, 74, 6, 53, 7, 94, 5, 56, 2, 19, 1, 41, 0, 76, 
    2, 27, 3,  2, 6, 44, 7,  3, 4, 70, 8, 20, 1, 94, 0, 73, 5, 18, 
    7, 26, 0, 95, 8, 90, 1, 26, 2, 99, 6, 54, 4,  6, 5, 26, 3, 10, 
    7, 55, 4, 20, 8,  4, 5,  1, 3, 55, 0,  5, 6, 73, 1, 11, 2, 58, 
    1, 96, 7, 70, 6, 15, 5, 40, 3, 80, 4,  3, 2, 41, 0, 97, 8, 49
  };
  const int q7838[] = {
    9, 9, // Number of jobs and machines
    8, 64, 7, 69, 6,  7, 2, 44, 4, 52, 1, 78, 5,  4, 3, 84, 0, 40, 
    2, 96, 7, 64, 4, 48, 5, 33, 0, 12, 6, 24, 1, 54, 8,  4, 3, 98, 
    5, 88, 7, 21, 3, 28, 6, 71, 8, 59, 1, 31, 0,  7, 4, 28, 2, 46, 
    1, 52, 7, 40, 5, 66, 4, 51, 8, 87, 3, 75, 2, 70, 0, 50, 6, 40, 
    7, 21, 3, 91, 4, 57, 0, 43, 8, 98, 5, 12, 1, 30, 6, 80, 2, 60, 
    8, 81, 6, 92, 7, 31, 1, 64, 5,  6, 2, 82, 0, 78, 4, 95, 3, 71, 
    0, 89, 7, 44, 8, 77, 6, 30, 3, 33, 1, 85, 5, 72, 2,  2, 4, 36, 
    0,  4, 1, 52, 5, 53, 2, 20, 6, 42, 3, 11, 8, 38, 4, 57, 7, 53, 
    5, 57, 7, 86, 3, 59, 6,  9, 0, 19, 4, 36, 2, 85, 1, 68, 8, 61
  };
  const int q7839[] = {
    9, 9, // Number of jobs and machines
    5, 63, 6, 64, 7, 58, 0, 47, 2, 28, 4, 80, 8, 16, 1, 34, 3, 75, 
    7, 71, 0, 48, 8, 20, 4, 65, 2,  5, 6, 92, 1, 95, 5, 49, 3, 11, 
    0, 23, 8,  5, 4, 76, 5, 82, 6, 88, 2, 64, 7, 16, 3, 27, 1,  3, 
    7,  2, 3, 61, 5,  6, 6, 13, 1, 87, 4, 51, 8, 88, 0,  7, 2,  2, 
    1, 21, 2, 20, 5, 35, 0, 37, 3, 25, 6, 17, 4, 19, 8, 45, 7, 85, 
    6, 65, 1, 57, 4, 27, 5, 74, 2, 12, 8, 83, 3, 80, 0, 15, 7, 87, 
    2, 27, 1, 99, 6, 53, 8, 86, 5, 19, 4, 20, 7, 12, 3, 73, 0, 66, 
    3, 80, 7, 38, 1,  6, 5, 53, 8,  3, 0, 81, 4, 90, 2, 59, 6, 84, 
    3, 47, 1, 61, 8, 74, 4, 99, 0, 90, 7, 78, 5, 81, 2, 32, 6, 94
  };
  const int q7840[] = {
    9, 9, // Number of jobs and machines
    4, 86, 6, 24, 0, 46, 2, 32, 3, 50, 5, 31, 1, 36, 8, 81, 7, 95, 
    8, 39, 4, 59, 7, 69, 3, 65, 0, 14, 6, 11, 1, 40, 5, 43, 2,  6, 
    8, 13, 2, 34, 4, 67, 0, 32, 3, 20, 7, 35, 5,  8, 1, 84, 6, 23, 
    5, 77, 0, 78, 3, 88, 2, 95, 7, 90, 1, 64, 4, 68, 6, 39, 8, 99, 
    3, 81, 5,  7, 2, 53, 7, 11, 8, 35, 4,  1, 6,  9, 0,  9, 1, 65, 
    3, 64, 2, 49, 4, 29, 0, 57, 7, 12, 5, 30, 6, 74, 8, 56, 1,  1, 
    1, 83, 0, 41, 7, 65, 3, 94, 2, 66, 4, 57, 6, 14, 5, 17, 8, 40, 
    2, 19, 6, 59, 8, 42, 0,  5, 7, 89, 1, 40, 3, 19, 5, 31, 4, 66, 
    8, 56, 3, 30, 2, 61, 6, 15, 4, 92, 1, 65, 5, 39, 7, 98, 0, 97
  };
  const int q7841[] = {
    9, 9, // Number of jobs and machines
    0, 94, 3, 17, 7,  9, 5, 77, 2, 48, 8, 88, 1, 25, 6, 49, 4,  8, 
    6, 65, 4, 44, 2, 35, 1, 65, 8, 56, 0, 83, 5, 85, 3, 52, 7, 71, 
    5, 51, 6, 78, 3, 64, 7, 33, 4, 90, 8, 49, 2, 52, 0, 60, 1, 89, 
    1,  6, 5, 99, 0, 62, 7, 37, 4, 27, 8, 89, 2, 59, 3, 17, 6,  1, 
    1, 31, 7,  8, 0,  1, 3, 29, 2, 98, 8, 33, 6, 58, 4,  3, 5, 24, 
    6, 37, 0, 28, 3,  9, 7, 98, 1, 98, 4, 97, 2, 90, 5, 18, 8, 78, 
    5, 77, 2, 78, 0, 85, 6, 93, 7, 48, 8, 56, 4, 78, 3, 61, 1, 64, 
    5, 38, 4, 74, 6, 46, 8, 77, 2, 70, 0, 20, 7, 91, 3, 70, 1, 16, 
    4, 25, 7, 59, 0, 82, 6, 58, 5, 14, 2, 23, 1,  7, 3,  1, 8, 36
  };
  const int q7842[] = {
    9, 9, // Number of jobs and machines
    4, 28, 1,  5, 2, 86, 7, 34, 5, 66, 3,  9, 0,  7, 6, 49, 8, 89, 
    5, 52, 2, 42, 6, 20, 3, 78, 8, 53, 4, 65, 7, 24, 0, 84, 1, 17, 
    1, 35, 4, 41, 8, 88, 2, 42, 5, 55, 7, 15, 3, 84, 6, 40, 0, 83, 
    0, 50, 1, 88, 7,  3, 2, 98, 8, 88, 4, 70, 6, 93, 5, 96, 3, 16, 
    0, 56, 3, 47, 6, 66, 7, 44, 1, 84, 2, 69, 4, 37, 8, 22, 5, 21, 
    5, 85, 4,  4, 1, 47, 3, 94, 7, 30, 0, 64, 2, 42, 8, 27, 6, 59, 
    7, 99, 2, 76, 4, 70, 0,  2, 6, 88, 8, 54, 1, 88, 5, 45, 3, 18, 
    3, 20, 0, 98, 2,  1, 7, 86, 6, 67, 5, 86, 1, 57, 4, 13, 8, 42, 
    0, 30, 8, 75, 5,  9, 6, 28, 4, 25, 7, 76, 1, 50, 3, 85, 2, 25
  };
  const int q7843[] = {
    9, 9, // Number of jobs and machines
    0, 11, 1, 64, 4, 48, 5, 53, 6, 50, 2, 18, 3,  3, 7,  7, 8, 87, 
    4, 93, 1,  2, 7, 19, 2, 53, 8, 26, 3, 54, 6, 10, 0, 46, 5, 58, 
    3, 39, 8, 12, 6, 11, 0, 75, 2, 19, 1, 93, 5, 41, 4, 89, 7, 68, 
    8, 53, 7, 65, 1, 44, 5, 18, 2, 45, 3, 41, 0, 28, 4, 90, 6,  9, 
    4, 76, 1, 59, 3, 26, 7, 69, 5, 71, 2, 11, 0, 69, 6, 70, 8,  5, 
    0,  9, 4,  8, 5, 17, 2, 74, 7,  1, 1, 17, 3, 72, 8, 30, 6, 92, 
    3, 22, 1, 50, 5, 98, 2, 22, 8, 20, 7, 34, 0, 32, 4, 58, 6, 91, 
    1, 88, 4, 29, 7, 16, 8, 38, 3, 88, 2, 35, 5, 68, 0, 45, 6, 34, 
    0, 53, 1, 50, 8, 14, 5, 69, 6, 67, 7, 87, 4, 45, 3, 89, 2, 26
  };
  const int q7844[] = {
    9, 9, // Number of jobs and machines
    4, 50, 0, 83, 5, 51, 7,  8, 3, 80, 6, 85, 1, 75, 8,  7, 2, 82, 
    6, 42, 2, 27, 0, 97, 3, 47, 5, 66, 8, 80, 4, 52, 7, 61, 1, 47, 
    2, 85, 1, 58, 6,  9, 8, 71, 4, 17, 0, 87, 5,  6, 3, 20, 7, 18, 
    6, 92, 4, 17, 0,  3, 3, 49, 8, 10, 1,  7, 2, 97, 5, 99, 7, 10, 
    8, 96, 3, 37, 7, 10, 6, 51, 2, 93, 1, 86, 4, 26, 5, 93, 0, 30, 
    5, 97, 6, 28, 4, 12, 7, 91, 8, 10, 3, 85, 1, 33, 0, 58, 2, 88, 
    6, 93, 8, 64, 7, 60, 0, 12, 4, 78, 1, 79, 3,  9, 5, 53, 2, 27, 
    6,  4, 8, 68, 5, 36, 3, 19, 2, 37, 4,  6, 0, 51, 7, 19, 1, 96, 
    7, 11, 6, 62, 8, 10, 3, 29, 5, 28, 2, 19, 4, 23, 1, 49, 0,  8
  };
  const int q7845[] = {
    9, 9, // Number of jobs and machines
    4, 75, 1, 99, 3,  9, 0, 23, 5,  7, 6, 66, 7, 94, 8, 26, 2, 86, 
    4, 27, 6, 52, 2, 30, 7, 72, 0, 53, 8,  1, 3, 87, 5, 80, 1,  1, 
    3, 84, 7, 89, 2, 97, 6, 13, 0, 42, 5, 24, 1, 22, 4, 48, 8, 54, 
    4, 14, 2, 54, 8, 20, 3, 30, 6, 57, 5, 92, 0, 83, 1, 62, 7, 86, 
    1, 79, 8, 78, 7, 24, 3, 83, 2, 93, 6, 37, 4, 59, 5, 67, 0,  7, 
    3, 51, 1,  1, 5, 62, 2, 65, 8, 86, 6, 94, 7, 15, 0, 42, 4, 78, 
    7, 21, 8, 57, 6, 55, 0, 25, 3, 29, 5, 76, 1, 76, 2, 32, 4, 97, 
    4, 11, 0, 71, 1, 48, 3, 87, 6, 65, 8, 95, 7, 57, 2, 11, 5, 56, 
    0, 50, 2, 51, 7,  6, 5, 71, 8, 68, 4, 56, 1, 31, 3, 76, 6, 24
  };
  const int q7846[] = {
    9, 9, // Number of jobs and machines
    1, 87, 6, 11, 7, 21, 4,  8, 3, 35, 5, 93, 8, 54, 0, 50, 2, 52, 
    7, 35, 8, 66, 5, 59, 3, 27, 4, 91, 2, 35, 1, 66, 6, 60, 0,  8, 
    1, 12, 5, 36, 0,  2, 7, 61, 6, 69, 8, 26, 3, 30, 4,  6, 2,  6, 
    4, 92, 8, 44, 3, 98, 7, 47, 0, 80, 2, 41, 6, 71, 5, 75, 1, 50, 
    4, 46, 1, 25, 7, 83, 0, 36, 3,  6, 5,  3, 6, 22, 2, 12, 8, 85, 
    1, 50, 3, 47, 7, 97, 0, 45, 2, 34, 4, 58, 6, 65, 5, 58, 8, 83, 
    1, 34, 4, 34, 3, 60, 2, 30, 5, 51, 0, 48, 8, 20, 7, 34, 6, 46, 
    0, 17, 2, 71, 6, 47, 7,  6, 8, 40, 4, 98, 3, 44, 5, 70, 1, 28, 
    6,  2, 3, 82, 7, 95, 8,  5, 0, 74, 1,  3, 4, 59, 5, 50, 2, 13
  };
  const int q7847[] = {
    9, 9, // Number of jobs and machines
    1, 34, 3,  4, 5, 25, 2, 40, 7, 16, 8, 99, 4, 47, 0, 94, 6, 92, 
    0, 96, 3, 37, 4,  3, 5, 53, 2, 72, 7, 24, 6, 97, 1, 33, 8, 87, 
    1, 93, 4, 26, 8, 84, 6, 13, 3, 67, 5, 67, 7, 60, 0, 90, 2, 13, 
    7, 95, 0,  5, 8, 48, 3, 72, 5, 62, 4, 99, 1, 22, 6,  5, 2, 68, 
    6,  1, 3, 61, 4, 93, 5, 85, 2, 19, 1, 81, 0, 36, 8, 74, 7, 45, 
    7, 56, 2, 69, 5, 28, 3, 46, 6, 52, 4, 16, 8, 18, 1, 60, 0, 91, 
    3, 27, 1, 70, 2, 16, 6, 32, 0, 16, 8, 45, 4, 52, 5, 18, 7, 29, 
    2, 42, 7, 14, 0, 11, 3, 78, 6, 44, 8, 74, 1, 71, 4, 60, 5, 32, 
    7, 64, 8, 89, 6, 95, 5, 59, 4, 71, 0, 98, 3, 19, 1, 92, 2, 24
  };
  const int q7848[] = {
    9, 9, // Number of jobs and machines
    3, 80, 7, 97, 4, 38, 5, 90, 1, 24, 0, 30, 2, 95, 8, 56, 6, 10, 
    3, 86, 1, 22, 7, 85, 6, 89, 5, 29, 8, 74, 2, 58, 4, 44, 0, 98, 
    2, 63, 7, 78, 5,  1, 1, 66, 4, 92, 6, 52, 3,  3, 0, 68, 8, 76, 
    3, 85, 1, 36, 2, 13, 4, 34, 8, 88, 5, 28, 6, 91, 7, 57, 0, 60, 
    4,  2, 0, 25, 2, 31, 7, 47, 3, 91, 8, 13, 5, 82, 6,  3, 1, 73, 
    1, 51, 8, 83, 4, 81, 0, 50, 5, 76, 6, 65, 2, 53, 7,  4, 3, 23, 
    0, 68, 4, 13, 3, 68, 7, 93, 1, 26, 6, 95, 2, 27, 8, 39, 5, 31, 
    6, 55, 5, 59, 4, 60, 7, 79, 3, 73, 2, 88, 0, 74, 1, 85, 8, 59, 
    2, 88, 0, 27, 4, 70, 7, 22, 8, 83, 6, 42, 5, 35, 3, 67, 1, 46
  };
  const int q7849[] = {
    9, 9, // Number of jobs and machines
    7, 36, 2, 46, 3, 35, 6, 61, 8, 60, 1, 84, 5, 37, 4, 14, 0, 74, 
    1,  6, 2, 43, 6, 24, 7, 50, 5, 69, 8, 59, 3,  6, 4, 65, 0, 79, 
    0, 56, 1, 45, 2, 31, 5, 86, 4, 49, 7, 45, 8, 13, 3, 77, 6,  2, 
    2, 29, 3, 64, 8, 61, 4, 28, 7,  6, 0, 45, 1, 60, 5, 41, 6, 83, 
    7, 48, 3, 53, 8, 73, 0, 77, 2, 13, 1, 95, 6, 50, 5, 63, 4, 84, 
    0, 24, 3, 73, 6, 63, 8, 98, 5, 43, 4, 66, 7, 63, 2, 59, 1, 84, 
    7, 26, 3, 72, 1, 41, 5, 98, 4, 65, 8, 67, 2, 81, 6, 61, 0, 28, 
    6, 33, 3, 95, 2, 27, 1, 98, 0, 93, 8, 40, 5, 64, 7, 71, 4, 84, 
    1, 51, 3, 87, 2, 55, 8, 16, 5,  8, 0, 52, 4, 60, 7, 83, 6, 67
  };
  const int q7850[] = {
    9, 9, // Number of jobs and machines
    4, 34, 6, 25, 1, 46, 2, 97, 7, 21, 0, 65, 8, 83, 3, 91, 5, 15, 
    7,  2, 2, 26, 0, 64, 3, 14, 1,  7, 6, 15, 5, 58, 8,  9, 4, 49, 
    1, 33, 2,  7, 5,  4, 4, 31, 7, 74, 8, 94, 6, 44, 3, 44, 0, 89, 
    0, 45, 5, 73, 4, 83, 6, 91, 7, 67, 3, 23, 1, 12, 2, 55, 8, 42, 
    3, 89, 6, 23, 0, 55, 8, 18, 1,  2, 5, 41, 2, 68, 7, 18, 4, 42, 
    0, 62, 8, 66, 1, 17, 4, 46, 7, 77, 3, 50, 5, 15, 6, 44, 2, 63, 
    8, 24, 5, 98, 7, 60, 3, 75, 6, 70, 2, 33, 4, 49, 0, 94, 1, 21, 
    4, 35, 0, 27, 8, 25, 2, 14, 5, 39, 3, 58, 6, 83, 7, 90, 1, 37, 
    8, 56, 2, 56, 5, 34, 3, 53, 0, 77, 6, 24, 1,  2, 4, 90, 7, 10
  };
  const int q7851[] = {
    9, 9, // Number of jobs and machines
    6, 34, 0, 66, 7, 14, 5, 98, 4, 51, 8, 52, 3, 30, 2, 37, 1, 34, 
    4, 91, 8, 60, 6, 15, 2, 15, 0, 95, 7, 76, 5, 21, 3, 40, 1, 72, 
    1, 68, 8, 76, 4, 43, 6, 32, 7, 53, 3, 36, 5, 51, 2, 31, 0, 82, 
    2, 94, 4, 51, 6, 70, 1, 84, 7, 43, 3, 21, 5, 61, 0, 56, 8, 87, 
    4, 61, 5, 64, 1, 88, 6, 38, 3, 93, 0, 38, 7, 92, 2, 30, 8, 95, 
    0, 29, 3, 64, 7, 72, 1, 84, 6, 53, 8, 69, 4, 31, 5, 71, 2, 36, 
    2, 73, 4, 69, 1, 97, 5, 53, 7,  7, 8, 60, 3, 47, 6, 64, 0, 96, 
    7,  4, 1, 71, 8, 92, 3, 68, 2, 94, 4,  7, 6, 67, 0, 15, 5, 17, 
    6, 86, 3, 32, 0, 21, 5, 86, 8, 13, 1, 96, 7, 78, 2, 33, 4, 62
  };
  const int q7852[] = {
    9, 9, // Number of jobs and machines
    3, 49, 1, 34, 2, 79, 6, 78, 7, 42, 5, 25, 0, 47, 8, 53, 4,  4, 
    5, 15, 6,  2, 4, 65, 3, 21, 7, 80, 2, 36, 0, 70, 8, 19, 1, 20, 
    3, 46, 4, 18, 6, 52, 2, 91, 7, 42, 0, 25, 8, 20, 1, 58, 5, 30, 
    4, 26, 8, 60, 5, 85, 6, 10, 1, 83, 3, 75, 2, 53, 7, 60, 0, 56, 
    3,  5, 4, 20, 1, 46, 8, 29, 2, 89, 5, 97, 6, 41, 0, 10, 7, 13, 
    8,  4, 4, 17, 7, 58, 2, 15, 0, 49, 1, 89, 6, 90, 3, 17, 5, 80, 
    3, 98, 8, 46, 6, 47, 1, 49, 4, 73, 7, 37, 5, 85, 2, 97, 0, 58, 
    0, 56, 4, 35, 2, 31, 3, 89, 6, 63, 5, 99, 1, 66, 7, 47, 8, 17, 
    8, 44, 3, 85, 2, 17, 0, 93, 1, 59, 5, 91, 6, 24, 4, 86, 7, 17
  };
  const int q7853[] = {
    9, 9, // Number of jobs and machines
    8, 96, 1, 76, 0, 37, 3, 38, 6, 95, 2, 91, 7, 48, 4, 82, 5,  1, 
    6, 69, 3, 36, 8, 55, 2, 59, 4,  7, 5, 25, 7, 45, 1, 47, 0, 53, 
    6,  3, 7,  9, 1, 97, 0, 51, 8, 86, 2, 71, 5, 37, 3, 42, 4, 91, 
    2, 39, 7, 14, 5, 71, 3, 90, 6, 60, 0, 96, 8, 46, 4, 69, 1, 37, 
    4, 34, 8, 76, 7, 18, 0, 39, 1, 21, 5, 61, 3, 71, 6, 78, 2, 82, 
    3, 60, 5,  7, 4, 14, 1, 92, 0, 48, 8, 93, 6, 14, 7, 10, 2, 83, 
    8, 46, 1, 36, 5, 54, 3, 13, 6, 22, 0, 19, 2, 31, 4, 40, 7, 59, 
    8, 30, 2, 27, 3, 28, 6, 82, 5, 58, 0, 40, 4, 83, 1,  1, 7, 35, 
    2, 29, 1, 86, 7, 67, 5, 45, 4, 52, 3, 88, 6, 66, 8, 96, 0, 20
  };
  const int q7854[] = {
    9, 9, // Number of jobs and machines
    4, 19, 5, 64, 8, 11, 3, 95, 7, 34, 2, 17, 1,  2, 0,  1, 6, 69, 
    7, 45, 0, 96, 8, 86, 6, 11, 1, 21, 2, 85, 3, 52, 5, 45, 4, 89, 
    6,  6, 2, 35, 0, 75, 7, 84, 4, 42, 5, 89, 8, 97, 1,  6, 3, 35, 
    4, 76, 3,  4, 2, 38, 0, 99, 1, 14, 5, 73, 8, 65, 6, 35, 7, 43, 
    5, 71, 4, 75, 3, 36, 7, 43, 2, 13, 1, 69, 8, 11, 6, 57, 0, 94, 
    8, 11, 1, 32, 2, 64, 7, 97, 4,  5, 0, 96, 5, 92, 3, 41, 6, 40, 
    5, 38, 1, 46, 3, 55, 4, 42, 8, 31, 0, 87, 6, 68, 2, 22, 7, 16, 
    8, 69, 1, 35, 7, 91, 0, 38, 3, 60, 4, 65, 6, 49, 5, 98, 2, 63, 
    7, 33, 8, 87, 0, 80, 3, 67, 4, 85, 5, 57, 1, 56, 6,  9, 2, 58
  };
  const int q7855[] = {
    9, 9, // Number of jobs and machines
    3, 92, 2,  3, 7, 18, 6,  3, 4, 68, 1, 52, 5, 73, 8, 71, 0,  9, 
    7, 14, 3, 20, 1, 91, 8, 50, 4, 80, 6, 54, 2, 29, 5, 49, 0, 41, 
    2, 63, 0, 58, 4,  3, 3, 11, 1,  2, 5, 46, 8, 69, 6, 73, 7, 58, 
    5, 62, 1, 96, 7, 30, 2, 26, 6, 94, 3, 80, 0, 67, 4, 23, 8, 71, 
    5, 47, 7, 77, 3, 17, 8, 96, 6, 47, 0, 79, 2, 58, 4,  5, 1, 84, 
    7, 97, 0,  3, 8, 33, 6, 90, 2, 96, 5, 54, 3, 64, 4, 18, 1, 28, 
    0, 80, 4, 38, 6, 93, 2, 86, 3, 78, 1, 83, 8, 82, 5, 78, 7, 17, 
    7, 52, 0,  2, 1, 31, 2,  4, 5, 35, 8, 30, 6, 53, 3, 95, 4, 89, 
    1, 54, 3,  4, 2, 75, 4, 42, 7, 87, 8, 11, 5, 30, 0,  2, 6, 44
  };
  const int q7856[] = {
    9, 9, // Number of jobs and machines
    5, 74, 2, 44, 1, 98, 4, 80, 8, 96, 0, 73, 3, 25, 7, 82, 6, 80, 
    6, 46, 0, 77, 2, 21, 3, 63, 5,  5, 4, 87, 8, 46, 1, 78, 7, 15, 
    2, 80, 3, 86, 7, 40, 6, 99, 1, 99, 4, 75, 0,  1, 8, 32, 5, 60, 
    1, 36, 8,  7, 6, 64, 0, 38, 7, 72, 5, 49, 3, 36, 4, 89, 2, 40, 
    3, 12, 8, 62, 2,  2, 6, 37, 5, 93, 4,  6, 7,  4, 0, 46, 1, 30, 
    4, 89, 3, 47, 1, 88, 5, 70, 2, 73, 7, 88, 6, 33, 0, 20, 8, 82, 
    3, 99, 8, 70, 4, 18, 5,  5, 2, 51, 1, 40, 6, 76, 7,  2, 0, 96, 
    5, 44, 8, 30, 1, 64, 4, 34, 0, 88, 2, 21, 3, 43, 6, 81, 7, 57, 
    6, 39, 3, 10, 8, 70, 1, 14, 5, 67, 4, 55, 0,  7, 2, 27, 7, 89
  };
  const int q7857[] = {
    9, 9, // Number of jobs and machines
    6, 27, 0, 27, 8, 76, 4, 85, 5, 14, 7, 89, 2,  1, 1, 99, 3, 82, 
    5, 94, 8, 44, 2, 40, 6, 22, 0, 20, 1, 18, 3, 81, 4, 25, 7, 65, 
    4,  5, 1, 54, 8,  6, 5, 50, 3, 98, 0, 15, 2, 34, 7, 98, 6, 10, 
    8, 44, 7, 82, 4, 56, 6, 94, 2, 12, 3, 36, 1, 26, 5, 86, 0, 41, 
    4, 28, 3, 56, 0, 20, 5, 52, 1, 91, 7, 98, 6, 70, 8, 18, 2, 81, 
    8,  9, 4, 98, 3,  8, 0, 18, 1, 57, 2, 25, 7, 39, 5, 27, 6, 43, 
    3,  8, 7, 59, 5, 50, 8, 56, 2, 90, 0, 83, 4, 31, 6, 37, 1, 59, 
    3, 90, 7, 48, 6, 12, 0, 34, 1,  3, 4, 23, 8, 48, 5, 99, 2, 56, 
    1, 28, 5,  4, 7, 88, 8, 44, 3, 99, 0, 88, 2, 90, 4, 74, 6, 97
  };
  const int q7858[] = {
    9, 9, // Number of jobs and machines
    6, 42, 5, 76, 7, 67, 4, 11, 0, 50, 8, 28, 2, 35, 3, 18, 1, 12, 
    6, 37, 7, 93, 5, 75, 2, 48, 3, 93, 8, 43, 1, 42, 0, 11, 4, 35, 
    3, 64, 2, 30, 6, 37, 5, 96, 8, 51, 4, 91, 7,  9, 0, 72, 1, 45, 
    0, 96, 2, 30, 6, 68, 4, 27, 1, 13, 7, 45, 3, 27, 8, 38, 5, 32, 
    5, 36, 8,  5, 0,  6, 3, 48, 7,  6, 4, 57, 1, 19, 6, 44, 2,  4, 
    6, 60, 8, 55, 3, 82, 4, 70, 2, 13, 7, 44, 5, 43, 1, 19, 0,  2, 
    2, 92, 0,  9, 3, 69, 1, 37, 4, 27, 7, 53, 8, 71, 6, 64, 5, 20, 
    6, 83, 2, 44, 4, 90, 3, 26, 1, 77, 5, 28, 7, 94, 0, 94, 8, 32, 
    3, 86, 6, 43, 2, 27, 4, 93, 8, 71, 1, 62, 0, 94, 5, 91, 7, 60
  };
  const int q7859[] = {
    9, 9, // Number of jobs and machines
    4, 86, 0, 56, 1, 16, 6, 77, 8, 58, 7, 39, 3, 14, 2, 97, 5, 12, 
    4, 95, 8, 88, 2, 70, 0, 25, 5,  4, 1, 73, 3,  6, 6, 45, 7, 26, 
    4, 17, 7, 11, 3, 91, 8, 38, 1, 94, 0, 61, 2, 16, 6, 69, 5, 40, 
    8, 99, 5, 84, 0, 66, 6, 56, 7, 31, 4, 46, 3, 66, 1, 11, 2, 71, 
    0, 32, 8, 33, 7, 91, 5, 34, 4, 83, 1, 87, 6, 91, 3, 56, 2, 11, 
    3, 11, 0, 16, 5, 63, 8, 14, 4, 80, 6, 59, 2,  1, 1, 93, 7, 71, 
    2, 21, 4, 56, 7,  2, 8, 86, 6, 20, 0, 32, 3, 72, 1, 85, 5, 75, 
    0, 14, 3, 19, 4, 94, 2, 23, 5,  7, 1, 61, 7, 88, 8, 28, 6, 19, 
    2, 34, 3, 28, 4, 68, 5, 24, 8, 27, 6, 75, 0,  3, 1, 45, 7,  4
  };
  const int q7860[] = {
    9, 9, // Number of jobs and machines
    2, 39, 5, 72, 3, 71, 7, 46, 0, 20, 1, 49, 4, 40, 8, 96, 6, 35, 
    7, 97, 1, 64, 0, 43, 4, 38, 8, 81, 6, 85, 5, 11, 2, 72, 3,  3, 
    0, 15, 7, 90, 2,  3, 4, 33, 6, 35, 8, 63, 1, 66, 5, 54, 3, 67, 
    1, 63, 5,  3, 2, 35, 4, 42, 3,  2, 6,  9, 7,  5, 0, 97, 8, 58, 
    1, 42, 6, 87, 2, 27, 8, 34, 3, 69, 7, 72, 5, 77, 4, 83, 0, 64, 
    0, 58, 1, 87, 3, 85, 5, 49, 6, 21, 7, 95, 4, 45, 8, 83, 2, 35, 
    4, 54, 0, 63, 5, 49, 1, 56, 7, 86, 8, 81, 3, 30, 2, 26, 6, 25, 
    3, 26, 0, 87, 2, 78, 4, 96, 1, 23, 7, 11, 8, 55, 6,  7, 5, 71, 
    8, 28, 3, 80, 0, 86, 7, 37, 1, 23, 5, 34, 4, 44, 2, 92, 6, 82
  };
  const int q7861[] = {
    9, 9, // Number of jobs and machines
    3, 55, 8, 91, 0,  3, 5,  3, 6, 87, 7, 95, 2, 56, 1, 43, 4, 58, 
    3, 17, 2, 65, 4, 74, 7, 22, 0, 73, 8, 23, 5, 52, 1, 45, 6, 35, 
    5,  5, 1, 10, 8, 72, 6, 10, 2, 54, 7, 56, 3, 43, 4, 63, 0, 63, 
    4, 88, 6,  9, 8, 92, 3, 76, 1, 33, 0, 35, 2, 78, 5, 94, 7, 26, 
    5, 62, 2, 15, 7, 56, 4, 18, 0, 28, 3, 89, 6, 23, 8, 88, 1, 28, 
    8, 42, 7, 35, 6, 85, 4, 53, 2, 36, 0,  9, 3, 76, 5, 64, 1, 97, 
    6,  9, 2,  8, 1, 75, 8, 33, 4,  4, 5, 69, 7, 87, 3, 76, 0, 28, 
    4, 73, 8, 12, 0, 90, 6, 22, 3, 71, 7, 56, 5, 22, 1, 79, 2, 98, 
    6, 71, 5, 47, 3, 25, 0, 92, 7, 48, 4, 99, 1, 69, 8,  5, 2, 90
  };
  const int q7862[] = {
    9, 9, // Number of jobs and machines
    0, 12, 8, 28, 4, 33, 3, 34, 1, 45, 6, 69, 7, 93, 5, 59, 2, 70, 
    6, 20, 5, 38, 4, 73, 7,  6, 1, 36, 8, 34, 0, 45, 3, 27, 2, 32, 
    4, 69, 5, 13, 6, 14, 8, 46, 1, 18, 3, 89, 0, 68, 7,  8, 2,  3, 
    2, 40, 1, 54, 7, 17, 4, 97, 8, 81, 0, 13, 5, 55, 3, 90, 6,  8, 
    6, 38, 5, 21, 7, 31, 2, 94, 8, 27, 4,  3, 0, 67, 3, 13, 1, 86, 
    2, 15, 8, 78, 6, 28, 1, 48, 3, 13, 4, 80, 5, 47, 0, 82, 7, 20, 
    1, 81, 4, 26, 8, 31, 5, 95, 2, 10, 0, 17, 6, 66, 7,  1, 3, 14, 
    4, 40, 5, 75, 8, 80, 6, 56, 1, 41, 2, 16, 3, 35, 0, 57, 7, 83, 
    2, 80, 4, 67, 6, 80, 8, 50, 5, 96, 7, 58, 1, 92, 3, 97, 0, 95
  };
  const int q7863[] = {
    9, 9, // Number of jobs and machines
    5, 99, 0, 17, 8, 57, 3, 35, 4, 36, 2,  7, 6, 60, 1, 95, 7, 58, 
    8, 76, 7, 76, 2, 18, 1, 36, 5, 36, 4, 30, 0, 19, 6, 75, 3, 84, 
    0, 17, 7, 57, 5, 23, 6, 71, 1, 72, 8,  4, 4, 26, 3, 40, 2, 63, 
    5, 90, 7, 78, 0, 16, 4, 96, 6, 30, 8, 43, 2, 91, 3, 15, 1, 65, 
    0, 23, 2,  4, 5, 54, 3, 17, 1, 44, 6, 11, 4, 35, 8, 91, 7, 89, 
    6,  3, 7, 51, 2, 17, 1, 65, 3, 20, 4, 97, 5, 91, 8, 64, 0, 91, 
    4, 30, 5, 97, 1, 25, 2, 52, 8,  6, 6, 72, 3, 63, 7,  3, 0, 94, 
    1, 64, 6, 70, 0, 14, 8,  9, 4,  7, 2, 69, 5, 64, 3, 68, 7, 83, 
    0, 61, 3, 98, 7, 23, 5, 15, 2, 42, 4, 45, 8, 51, 6,  9, 1, 30
  };
  const int q7864[] = {
    9, 9, // Number of jobs and machines
    5, 76, 0, 89, 6, 56, 7, 86, 1, 40, 8, 49, 3,  5, 2, 90, 4, 61, 
    1,  1, 7, 41, 4, 71, 6,  9, 0, 21, 5, 77, 2,  9, 3, 79, 8, 45, 
    4, 32, 7, 24, 1, 11, 6, 85, 0,  8, 8, 41, 3, 93, 5, 15, 2, 99, 
    1, 17, 2, 34, 8, 94, 3, 17, 5, 43, 0, 96, 4, 97, 7,  6, 6, 85, 
    1, 74, 4, 51, 3, 15, 7, 96, 8, 27, 0, 28, 2, 99, 5, 49, 6, 16, 
    3, 13, 4, 63, 1, 18, 6, 57, 7, 86, 2,  5, 8, 11, 0, 84, 5, 22, 
    2, 73, 8, 23, 3, 90, 5, 39, 4, 54, 7, 23, 0, 77, 1, 97, 6, 60, 
    5, 80, 7, 21, 4, 14, 6, 83, 1, 73, 0, 28, 8, 28, 3, 90, 2, 82, 
    6, 91, 7, 63, 1, 75, 8, 46, 4,  6, 5, 63, 0, 58, 2, 66, 3, 31
  };
  const int q7865[] = {
    9, 9, // Number of jobs and machines
    0, 31, 1, 82, 4, 61, 2, 91, 5, 99, 7, 23, 6, 12, 3, 49, 8, 35, 
    5, 40, 4, 23, 8, 49, 2,  4, 6, 52, 0, 68, 1, 70, 3, 61, 7,  9, 
    5, 76, 4, 52, 7,  8, 1, 33, 2, 68, 3, 46, 0, 52, 6, 66, 8, 10, 
    0, 95, 4, 15, 1, 48, 3,  8, 5, 61, 7, 26, 2, 82, 8, 40, 6, 56, 
    7, 21, 4, 49, 0, 72, 8, 67, 3, 90, 6, 25, 1, 32, 5, 45, 2, 26, 
    0, 59, 7, 34, 5, 79, 8, 49, 6, 40, 4, 29, 1, 89, 2, 90, 3, 42, 
    3, 37, 7, 47, 6, 29, 0, 37, 2, 81, 4, 37, 5, 52, 8, 72, 1, 16, 
    8, 54, 3, 94, 1,  3, 0, 43, 2, 27, 4, 52, 5,  2, 6,  6, 7, 29, 
    6, 18, 4, 49, 3, 11, 7, 41, 8, 98, 2,  1, 5, 79, 0, 67, 1, 71
  };
  const int q7866[] = {
    9, 9, // Number of jobs and machines
    8, 14, 5, 34, 4,  4, 2, 21, 7, 97, 0, 98, 3, 98, 1, 38, 6, 83, 
    4,  1, 8, 67, 6, 39, 1, 92, 3, 13, 0, 57, 7, 12, 2, 40, 5, 49, 
    7, 68, 4, 84, 5, 31, 8, 26, 1, 38, 6, 94, 2, 14, 3, 94, 0, 90, 
    5, 37, 2,  9, 7, 52, 4, 40, 0, 63, 6, 75, 3, 99, 8, 66, 1, 77, 
    6, 61, 5,  8, 3, 60, 7, 62, 4, 37, 1, 25, 0, 41, 8, 22, 2, 13, 
    6,  8, 5, 21, 8, 31, 2, 69, 4, 51, 0, 59, 1, 89, 7, 75, 3, 27, 
    8, 85, 7, 30, 2, 26, 1, 59, 3, 45, 0, 35, 6, 88, 5, 10, 4, 89, 
    0, 42, 6, 93, 1, 60, 2, 24, 4, 50, 7, 54, 5, 55, 3, 80, 8, 11, 
    0, 98, 2, 12, 4, 70, 6, 65, 1, 79, 3, 81, 7,  6, 8, 10, 5, 44
  };
  const int q7867[] = {
    9, 9, // Number of jobs and machines
    6, 66, 8, 57, 2, 10, 7, 73, 1, 54, 0,  8, 5, 95, 3,  6, 4, 33, 
    2, 58, 0, 74, 4, 92, 6, 62, 3, 20, 8, 25, 5, 42, 1, 81, 7, 75, 
    0, 72, 1, 75, 6, 18, 4,  3, 8, 99, 3, 28, 7, 18, 2, 72, 5, 91, 
    3, 53, 0, 17, 8, 83, 2, 16, 6, 54, 1, 89, 5, 96, 7, 46, 4, 94, 
    2, 42, 8, 26, 6, 34, 5, 14, 1, 64, 4, 85, 7, 61, 3, 78, 0, 61, 
    4, 19, 7, 17, 8, 59, 2, 37, 0,  8, 3, 64, 1, 14, 5, 72, 6,  6, 
    4, 79, 7, 52, 6,  9, 0, 69, 5, 63, 1, 92, 8, 32, 3, 60, 2, 72, 
    6, 50, 4, 81, 3, 75, 8, 43, 2, 69, 1, 14, 7, 81, 0, 81, 5, 36, 
    2, 44, 7,  6, 6, 68, 5, 10, 1, 66, 0, 91, 4, 75, 3, 47, 8, 89
  };
  const int q7868[] = {
    9, 9, // Number of jobs and machines
    0, 10, 8, 11, 4, 12, 7, 83, 2, 48, 1, 93, 3,  8, 6, 66, 5, 47, 
    0, 52, 6, 53, 5, 71, 1, 61, 7, 27, 2, 36, 8, 64, 3,  8, 4, 38, 
    6, 77, 2, 53, 7, 58, 1, 81, 3,  2, 4, 65, 5, 38, 8, 84, 0, 69, 
    2, 10, 7, 96, 5, 97, 4, 95, 0, 63, 1, 96, 6, 51, 8, 42, 3, 76, 
    0, 22, 6, 13, 4, 79, 3, 20, 1, 58, 2, 82, 8, 39, 5, 55, 7, 74, 
    0, 22, 4, 81, 7,  2, 6, 91, 1, 60, 3, 98, 2, 94, 5, 38, 8, 93, 
    7, 31, 8, 89, 2, 24, 4, 51, 6,  5, 3, 67, 0, 63, 5, 37, 1, 63, 
    4, 13, 6, 12, 8, 90, 3,  3, 0, 48, 7, 96, 2,  7, 5, 29, 1, 77, 
    0, 41, 4, 57, 3, 37, 7, 57, 6, 87, 1, 97, 8, 79, 2, 52, 5, 68
  };
  const int q7869[] = {
    9, 9, // Number of jobs and machines
    1, 16, 6, 50, 5, 72, 2, 15, 7, 85, 8, 32, 3, 21, 0, 95, 4, 64, 
    8, 56, 4, 60, 3, 98, 2, 20, 5, 29, 6, 44, 7, 36, 0, 17, 1, 66, 
    6, 46, 2,  2, 5, 69, 0, 18, 8, 30, 4, 56, 1, 54, 3, 25, 7, 78, 
    4, 23, 8, 73, 1, 14, 5, 13, 7, 40, 3, 62, 0, 71, 2, 40, 6, 14, 
    5, 69, 0, 70, 7, 86, 2, 42, 1, 71, 3, 46, 8,  3, 4,  7, 6, 43, 
    1, 15, 4, 26, 3, 26, 2,  8, 6, 92, 7,  1, 8, 94, 0, 65, 5,  1, 
    8, 84, 7, 21, 1, 24, 0, 78, 6, 89, 4, 46, 5, 22, 2,  8, 3, 17, 
    6, 50, 8, 18, 5, 13, 0, 73, 3, 61, 2, 27, 4, 64, 7, 60, 1, 52, 
    5, 19, 8, 59, 3, 86, 4, 76, 1, 18, 6,  9, 7,  8, 0, 38, 2, 22
  };
  const int q7870[] = {
    9, 9, // Number of jobs and machines
    3, 56, 4, 47, 1, 73, 7, 35, 8, 83, 5, 89, 0, 32, 6, 42, 2, 18, 
    2, 88, 1, 34, 7, 69, 4, 22, 6, 90, 3, 94, 8, 45, 0, 19, 5, 59, 
    7, 49, 1,  4, 2, 50, 4, 27, 6, 47, 8, 59, 3, 73, 0, 43, 5, 61, 
    4, 54, 0, 98, 6, 77, 7, 95, 5, 34, 2, 15, 8, 25, 1, 74, 3, 93, 
    5, 20, 7, 91, 8, 49, 3, 36, 6, 50, 0, 70, 1, 42, 2, 50, 4, 15, 
    8,  5, 4, 87, 2, 85, 3, 99, 1, 69, 7, 69, 5, 77, 6,  2, 0, 15, 
    8, 42, 3,  4, 0, 56, 2, 44, 4, 47, 1, 37, 7, 64, 5, 61, 6, 22, 
    2, 55, 3, 79, 4, 87, 5, 11, 1, 23, 8, 33, 7, 18, 0, 55, 6,  6, 
    3, 38, 7, 20, 2, 39, 4, 83, 0, 43, 8, 20, 6, 52, 5, 38, 1, 58
  };
  const int q7871[] = {
    9, 9, // Number of jobs and machines
    1, 80, 4,  8, 7, 84, 3, 77, 6, 79, 0, 50, 8, 88, 2, 73, 5, 83, 
    2, 17, 8,  7, 3, 32, 1,  8, 5, 15, 4,  2, 7, 65, 6, 39, 0, 48, 
    2, 56, 0, 36, 6, 50, 4, 89, 3, 74, 8, 36, 7, 50, 1, 26, 5, 42, 
    0, 47, 1,  6, 5, 85, 4, 53, 2, 34, 3, 20, 6, 17, 7, 21, 8, 32, 
    4, 66, 7, 74, 0,  4, 8, 30, 3, 34, 5, 79, 1, 88, 6, 95, 2, 95, 
    7, 64, 4, 40, 5, 91, 8, 10, 1, 21, 0, 57, 6, 61, 2,  6, 3, 52, 
    4, 98, 0, 14, 2, 95, 6, 38, 3, 40, 7, 31, 1, 12, 8, 18, 5, 58, 
    3, 37, 0, 16, 6, 80, 2, 67, 4, 54, 7, 54, 8, 69, 5, 59, 1, 50, 
    1, 88, 5, 34, 3, 80, 6, 68, 2, 75, 7, 99, 8, 36, 4, 10, 0,  3
  };
  const int q7872[] = {
    9, 9, // Number of jobs and machines
    5, 29, 3, 31, 8, 10, 1, 29, 6, 25, 2, 28, 0, 72, 4, 68, 7, 15, 
    3, 77, 5, 72, 4,  7, 8,  2, 2, 61, 7, 14, 0, 80, 6, 59, 1, 43, 
    6, 11, 8, 45, 4, 88, 7, 63, 1, 65, 3, 64, 0, 90, 2, 13, 5,  6, 
    7, 86, 6, 39, 0, 60, 4, 83, 5, 25, 8, 67, 2, 58, 1, 39, 3, 31, 
    0, 42, 7, 77, 5, 34, 3, 53, 2, 28, 6, 21, 8, 52, 1, 87, 4, 65, 
    1, 72, 5, 39, 6, 88, 8, 11, 4, 11, 3, 30, 0, 19, 2, 21, 7, 58, 
    0,  7, 4, 48, 7, 68, 3,  2, 5,  3, 2, 95, 6, 68, 8, 76, 1, 58, 
    4, 83, 0, 51, 1,  9, 7, 76, 8,  4, 3, 40, 2, 17, 6, 69, 5, 60, 
    7, 49, 5, 93, 1, 94, 3, 30, 0,  9, 4, 40, 8, 43, 6, 49, 2, 69
  };
  const int q7873[] = {
    9, 9, // Number of jobs and machines
    3, 96, 1, 50, 2, 69, 8, 65, 0, 35, 6, 73, 4, 81, 7,  1, 5, 20, 
    3,  2, 8, 43, 4, 99, 1,  3, 5, 47, 0, 52, 2, 74, 6, 67, 7, 18, 
    0, 12, 6, 90, 7, 20, 5, 91, 1,  2, 8, 87, 3, 69, 4, 94, 2,  7, 
    6, 93, 7, 17, 0, 86, 8, 81, 4,  9, 1, 24, 2, 41, 5, 86, 3, 86, 
    5, 75, 2, 29, 7, 87, 0, 76, 4, 38, 8, 73, 3,  3, 1, 16, 6, 19, 
    3, 14, 6, 49, 7, 62, 8, 44, 1, 58, 5, 79, 4, 27, 2, 67, 0, 10, 
    2, 32, 7, 76, 0, 54, 5,  2, 1, 57, 8, 72, 3, 36, 4, 58, 6, 13, 
    5, 71, 2, 70, 3, 24, 6, 26, 4, 74, 8, 88, 7, 31, 1, 66, 0,  9, 
    8, 12, 5, 71, 4, 13, 1, 99, 7, 65, 3, 74, 2, 63, 0, 58, 6, 27
  };
  const int q7874[] = {
    9, 9, // Number of jobs and machines
    8, 86, 2, 49, 4, 45, 5,  9, 6, 68, 0, 32, 7, 10, 1, 96, 3, 83, 
    0, 64, 3, 75, 4, 94, 5, 47, 6, 90, 8, 21, 7, 93, 1, 50, 2,  7, 
    2, 44, 6, 20, 5, 73, 1, 61, 0, 56, 4, 89, 8, 20, 3, 16, 7, 35, 
    5, 34, 2, 26, 8, 60, 0, 48, 6, 45, 7, 48, 1, 26, 4, 90, 3, 49, 
    2,  7, 3, 24, 8, 47, 4, 86, 1, 11, 7,  4, 5, 78, 0, 97, 6, 53, 
    3, 95, 8, 45, 6, 25, 4, 83, 5, 46, 0, 63, 7,  6, 1, 29, 2, 75, 
    7, 61, 5, 41, 6, 90, 1, 42, 8, 31, 3, 96, 0, 88, 4, 79, 2, 33, 
    7, 15, 3, 36, 5, 26, 6, 55, 8, 44, 4, 39, 1,  8, 2, 30, 0, 66, 
    8,  5, 3, 53, 0, 83, 1, 68, 4,  6, 2, 51, 5, 64, 6, 68, 7, 88
  };
  const int q7875[] = {
    9, 9, // Number of jobs and machines
    2, 67, 5, 26, 1, 21, 7, 27, 4, 77, 0,  4, 3, 52, 6, 55, 8, 74, 
    4, 30, 7, 83, 1, 74, 5, 47, 6, 54, 3, 21, 2, 61, 0,  5, 8, 82, 
    8, 47, 1, 85, 4, 94, 7,  1, 3, 52, 0, 11, 5, 11, 2, 27, 6, 78, 
    5, 33, 2, 46, 3, 75, 4, 25, 8, 56, 6, 15, 1, 44, 0, 37, 7,  1, 
    5, 52, 0, 16, 2, 19, 3, 94, 4, 12, 8, 45, 1,  4, 7, 70, 6, 56, 
    2, 45, 3, 62, 7, 78, 0, 91, 5, 73, 4, 31, 1, 65, 8, 68, 6, 13, 
    6, 62, 2, 22, 0, 85, 3, 26, 7, 96, 5, 75, 4,  6, 1, 85, 8, 71, 
    6,  4, 3, 98, 0, 23, 4, 51, 2, 16, 8,  4, 7, 67, 5, 81, 1, 50, 
    2, 52, 4, 17, 5, 94, 7, 68, 1, 15, 0, 73, 6, 52, 3, 45, 8, 54
  };
  const int q7876[] = {
    9, 9, // Number of jobs and machines
    1, 37, 7, 13, 3, 32, 4, 27, 0, 48, 6, 14, 2, 72, 8, 97, 5,  4, 
    5, 52, 0, 46, 1, 33, 2, 84, 4, 38, 8, 15, 6, 95, 3, 58, 7, 80, 
    6, 63, 8, 23, 3, 69, 1, 70, 4, 80, 7, 56, 0,  1, 2, 33, 5, 12, 
    5, 37, 8, 74, 6, 32, 3, 42, 7,  8, 2, 18, 4, 19, 0, 56, 1, 18, 
    7, 64, 8,  7, 6,  8, 5, 52, 2, 45, 4, 60, 1, 62, 3, 97, 0, 90, 
    4,  4, 7, 45, 8, 48, 3, 56, 0, 66, 1, 33, 5, 77, 6, 60, 2,  4, 
    6, 39, 0, 90, 7, 44, 3, 98, 4, 70, 1, 50, 5, 45, 2, 13, 8, 18, 
    8, 58, 7, 21, 3, 69, 4, 75, 6, 31, 0, 11, 1, 20, 5, 53, 2, 48, 
    1, 27, 5,  1, 3, 28, 4, 29, 2, 41, 8, 47, 7, 77, 6, 12, 0, 19
  };
  const int q7877[] = {
    9, 9, // Number of jobs and machines
    2, 47, 4, 30, 3, 64, 8, 43, 5,  3, 0,  4, 1, 93, 6, 26, 7, 40, 
    5, 31, 0, 43, 4, 42, 3, 36, 7, 88, 6, 27, 2, 36, 8, 23, 1, 42, 
    2,  8, 1, 25, 6, 66, 7, 91, 0, 55, 3, 11, 4, 97, 8, 89, 5, 64, 
    0, 65, 5, 41, 6, 78, 4, 65, 8, 95, 2, 62, 7, 51, 3, 71, 1, 12, 
    7, 93, 6, 14, 1, 81, 8, 49, 5, 68, 2, 25, 3, 34, 0, 80, 4, 82, 
    8, 42, 7, 95, 2, 57, 4, 21, 1, 12, 0, 93, 6, 49, 5, 37, 3, 39, 
    1, 33, 3, 12, 7, 57, 2, 40, 6, 63, 4, 28, 0, 83, 8, 54, 5, 57, 
    4, 90, 1, 53, 6, 20, 3, 29, 0, 30, 8,  3, 2, 23, 7, 90, 5, 49, 
    4, 97, 1, 15, 2, 87, 6, 22, 8,  7, 0, 33, 5,  9, 3, 43, 7,  2
  };
  const int q7878[] = {
    9, 9, // Number of jobs and machines
    4, 40, 0, 57, 2, 27, 7, 83, 6, 81, 1, 93, 8,  3, 5, 53, 3, 71, 
    7, 83, 4, 20, 0, 61, 2, 43, 8,  8, 6, 30, 1, 38, 3, 14, 5, 39, 
    3, 14, 5, 14, 6,  1, 2, 74, 8, 49, 4, 48, 7, 43, 0, 47, 1, 32, 
    6, 83, 8, 83, 2, 77, 5, 41, 1, 55, 0, 19, 3, 40, 7, 57, 4, 71, 
    7, 33, 8, 22, 5, 72, 3, 60, 1, 44, 6, 39, 0, 57, 2, 13, 4, 21, 
    4, 93, 2, 72, 7, 81, 3,  2, 5,  5, 1, 79, 0, 11, 6, 42, 8,  6, 
    4, 94, 6, 98, 2, 59, 1, 99, 8, 76, 0,  6, 3, 30, 5, 89, 7, 10, 
    1, 93, 4, 58, 6, 61, 3, 26, 2, 81, 5, 78, 7, 35, 8, 41, 0, 58, 
    8, 91, 1, 59, 2, 46, 0, 95, 3, 28, 4, 53, 5, 38, 6, 38, 7,  5
  };
  const int q7879[] = {
    9, 9, // Number of jobs and machines
    3, 52, 1, 21, 4, 21, 7, 70, 2, 29, 5, 83, 6,  8, 0, 47, 8, 99, 
    5, 66, 6, 22, 7, 65, 1, 69, 2, 60, 0, 83, 3, 16, 4, 77, 8, 17, 
    8, 47, 3, 82, 6, 33, 5, 74, 2, 22, 0, 12, 4, 83, 7, 33, 1, 26, 
    1, 74, 8, 10, 5, 33, 7, 88, 6, 75, 2, 23, 4, 54, 0, 73, 3, 60, 
    3,  6, 4, 65, 8, 19, 5, 93, 7,  5, 0, 90, 1, 97, 2, 34, 6, 72, 
    1, 42, 2,  2, 8, 75, 5,  2, 7,  3, 3, 62, 0, 10, 6, 57, 4, 74, 
    2, 17, 8, 95, 6, 67, 1, 25, 5, 26, 0, 93, 4, 68, 7, 59, 3, 97, 
    0, 59, 5, 52, 6,  9, 2, 46, 8, 25, 7,  3, 1, 66, 4, 11, 3, 38, 
    4, 22, 0, 24, 3, 20, 5, 91, 8, 78, 7, 49, 1, 21, 2,  1, 6, 14
  };
  const int q7880[] = {
    9, 9, // Number of jobs and machines
    3, 35, 7, 47, 0, 17, 1, 47, 4, 57, 5, 74, 8, 89, 6, 83, 2, 71, 
    8, 87, 7, 48, 6, 70, 4, 62, 1, 75, 5, 49, 2, 11, 0,  5, 3, 42, 
    1, 20, 5, 82, 8,  4, 3, 77, 2, 16, 4,  3, 6, 63, 0, 34, 7, 24, 
    7, 63, 2, 83, 0,  7, 8, 61, 5, 67, 3, 11, 4, 42, 1, 79, 6, 12, 
    6, 72, 3, 52, 1, 21, 0, 67, 7, 84, 8, 93, 4, 97, 2,  5, 5, 97, 
    7,  4, 6, 44, 3, 73, 4, 82, 0, 14, 2, 33, 5, 41, 8, 16, 1, 75, 
    0, 40, 1, 69, 5, 67, 7, 89, 8, 69, 6, 10, 3, 50, 4, 90, 2, 61, 
    0, 33, 3, 70, 1, 15, 2, 75, 6, 90, 7, 37, 4, 56, 8, 48, 5, 70, 
    3, 38, 2, 48, 0, 73, 7, 69, 8,  8, 4, 68, 1, 13, 5, 11, 6, 27
  };
  const int q7881[] = {
    9, 9, // Number of jobs and machines
    2, 81, 1, 77, 3, 99, 4, 79, 0, 37, 7, 64, 6, 53, 5, 43, 8, 92, 
    3, 20, 1, 84, 5, 44, 8, 97, 2, 34, 4,  2, 6,  7, 7, 30, 0, 16, 
    0,  2, 7, 63, 5, 23, 6, 83, 3,  6, 4, 82, 1, 96, 8, 29, 2, 11, 
    7,  8, 3,  8, 0, 33, 2, 24, 8, 52, 1,  3, 6, 84, 5,  9, 4, 76, 
    5, 26, 8, 44, 2, 95, 0,  5, 6, 98, 3, 76, 4,  3, 1, 14, 7, 29, 
    0, 54, 4, 48, 3, 54, 7, 41, 8, 67, 1, 65, 5, 77, 2, 70, 6, 94, 
    4, 18, 6, 83, 2, 55, 7, 61, 1, 21, 3,  4, 5, 86, 0, 79, 8, 87, 
    8, 59, 4, 81, 3, 13, 0, 69, 1, 83, 5, 10, 7, 59, 6, 36, 2, 16, 
    2, 80, 4, 17, 1,  5, 6, 97, 5,  3, 8,  6, 0, 21, 7, 26, 3, 51
  };
  const int q7882[] = {
    9, 9, // Number of jobs and machines
    3, 25, 2,  7, 4, 54, 1, 56, 6, 23, 8, 48, 5, 64, 0, 50, 7, 60, 
    4, 75, 1,  1, 2, 68, 5, 13, 7, 36, 6, 85, 8, 64, 3, 94, 0, 21, 
    4, 51, 3, 41, 0, 96, 5, 84, 2, 97, 7, 11, 6, 40, 8, 73, 1, 77, 
    8,  8, 2,  2, 4, 12, 0, 68, 1, 55, 5, 46, 7, 89, 3, 90, 6,  2, 
    6, 22, 8, 82, 2, 51, 4, 64, 0, 95, 1, 84, 3, 51, 5, 22, 7, 45, 
    7, 40, 5,  9, 8, 33, 1, 18, 4, 37, 6, 94, 2, 52, 3, 52, 0, 40, 
    4, 90, 5, 27, 2,  9, 8, 15, 7, 33, 0, 27, 1, 97, 6, 98, 3, 92, 
    6, 85, 2, 51, 8,  4, 4, 19, 0, 24, 1, 10, 3, 66, 7,  4, 5,  7, 
    2, 62, 4, 25, 6, 96, 7, 48, 5,  9, 8, 56, 0, 89, 1, 42, 3, 13
  };
  const int q7883[] = {
    9, 9, // Number of jobs and machines
    8, 40, 5, 56, 6, 31, 2, 27, 3, 73, 4, 60, 7, 12, 1, 25, 0, 72, 
    8, 28, 1, 82, 5, 48, 3, 19, 7, 89, 2, 73, 4, 26, 0, 98, 6, 58, 
    7,  1, 8, 82, 1, 16, 3, 93, 0, 61, 4,  7, 2,  9, 5, 15, 6, 79, 
    0, 31, 2, 16, 1, 22, 6, 53, 3,  9, 8, 14, 4, 91, 5, 99, 7, 36, 
    2, 74, 4, 22, 0, 88, 1, 67, 3, 96, 6, 56, 7, 66, 8, 62, 5, 10, 
    6, 38, 0, 39, 5, 68, 1,  7, 8, 68, 3, 75, 4, 33, 7, 77, 2,  6, 
    5, 30, 8, 45, 7, 74, 2, 47, 6, 15, 1, 81, 4, 59, 0, 41, 3, 82, 
    0, 67, 4, 71, 1, 16, 2,  6, 7, 17, 8, 75, 3, 18, 5,  5, 6, 54, 
    3, 40, 6, 10, 8, 94, 1, 88, 5, 81, 7, 64, 0, 57, 4,  8, 2, 25
  };
  const int q7884[] = {
    9, 9, // Number of jobs and machines
    8,  4, 0, 54, 6, 23, 4,  1, 5, 32, 7, 40, 3, 62, 2, 70, 1, 93, 
    4, 59, 8, 43, 3, 99, 7, 48, 5, 98, 1, 61, 0, 24, 6, 60, 2, 69, 
    4,  2, 5, 14, 3, 87, 1,  8, 0, 28, 2, 31, 7, 68, 6, 58, 8, 65, 
    3, 82, 7, 57, 5, 67, 1, 99, 6, 73, 0, 97, 8, 49, 4,  8, 2, 96, 
    7, 81, 4, 64, 3, 32, 8, 75, 1, 50, 5, 45, 2, 86, 0, 72, 6, 94, 
    3, 26, 7, 12, 2, 94, 0,  1, 5, 87, 8, 82, 1, 92, 4,  1, 6, 57, 
    8, 65, 0, 26, 2, 90, 5,  6, 1, 93, 6, 47, 3, 48, 7, 90, 4, 85, 
    1, 17, 2, 80, 6, 52, 0, 78, 3, 66, 8, 94, 7, 19, 5, 81, 4, 20, 
    6, 73, 1, 93, 0, 59, 4, 56, 5, 38, 3, 35, 7,  6, 2, 81, 8, 60
  };
  const int q7885[] = {
    9, 9, // Number of jobs and machines
    1, 93, 0, 23, 5,  5, 6,  4, 4, 99, 7, 94, 8, 12, 3, 18, 2, 78, 
    1, 15, 3,  9, 4, 27, 8, 50, 7,  3, 2,  4, 5, 97, 0, 67, 6, 23, 
    0, 72, 6, 91, 2, 41, 5, 67, 3,  4, 8, 81, 4, 79, 7, 58, 1, 29, 
    4, 20, 3, 56, 7, 35, 0, 72, 8,  1, 5, 38, 1, 58, 6,  4, 2, 41, 
    1, 59, 2, 80, 4, 47, 0,  3, 8, 27, 3, 31, 6, 23, 7, 87, 5, 46, 
    4, 13, 1, 15, 8, 12, 5, 33, 3, 27, 2, 88, 6, 32, 0, 50, 7, 64, 
    0, 64, 3, 46, 5, 30, 8, 30, 1, 70, 6, 46, 4, 88, 7, 24, 2, 15, 
    1,  1, 0, 77, 7, 41, 3, 10, 6, 20, 4, 53, 5, 75, 2, 79, 8, 18, 
    8,  7, 6, 44, 2, 66, 4, 27, 7,  5, 5, 53, 0, 78, 1,  4, 3, 74
  };
  const int q7886[] = {
    9, 9, // Number of jobs and machines
    7,  5, 0, 42, 8, 59, 1,  1, 6, 20, 3, 85, 5, 41, 2, 82, 4, 67, 
    7, 51, 0, 51, 6, 32, 3, 99, 1,  3, 8, 38, 4, 69, 2, 74, 5, 66, 
    2, 58, 5, 51, 0, 22, 4, 17, 7, 98, 3, 37, 1, 31, 8, 86, 6, 26, 
    0, 76, 5, 66, 6, 53, 4, 42, 8, 66, 3, 42, 1, 12, 7, 56, 2, 91, 
    2, 36, 4, 57, 3, 46, 5, 55, 0, 85, 1, 14, 7, 16, 6, 56, 8, 70, 
    2, 59, 8, 15, 5, 98, 3, 79, 0, 47, 7, 37, 1, 17, 6, 32, 4, 10, 
    7, 70, 6,  9, 3, 78, 1, 78, 4, 70, 5, 60, 2, 29, 8, 35, 0, 82, 
    5, 82, 8, 43, 2, 12, 1, 93, 6, 83, 3, 12, 4, 26, 7, 57, 0, 79, 
    5, 37, 4, 67, 7, 88, 8, 55, 3, 53, 2, 88, 1, 31, 0, 94, 6, 82
  };
  const int q7887[] = {
    9, 9, // Number of jobs and machines
    4, 65, 7, 64, 3, 13, 6, 82, 0,  1, 2, 36, 8, 96, 1, 52, 5, 68, 
    0, 33, 8, 63, 7, 61, 3, 66, 6, 55, 1,  1, 4, 94, 2, 91, 5,  7, 
    0, 37, 3, 44, 6, 93, 8, 85, 7, 49, 2, 55, 4, 29, 5, 45, 1, 97, 
    1, 41, 4, 63, 5, 56, 8,  6, 6, 17, 0, 38, 2, 40, 3, 47, 7, 79, 
    2, 26, 4, 78, 8, 79, 7, 98, 6, 35, 0, 85, 1,  5, 3, 52, 5, 33, 
    0, 35, 6, 30, 1, 48, 8, 48, 7, 56, 3, 19, 2, 60, 4, 28, 5, 64, 
    1, 55, 3, 25, 4, 65, 0,  2, 7, 24, 6, 16, 2, 80, 8, 89, 5, 66, 
    7, 84, 2, 56, 4, 22, 5, 31, 6, 47, 8, 90, 1, 87, 3, 52, 0, 41, 
    8, 31, 0,  9, 4, 25, 6, 64, 7, 53, 2, 93, 3, 68, 5, 13, 1,  2
  };
  const int q7888[] = {
    9, 9, // Number of jobs and machines
    1, 10, 5, 32, 7, 98, 4,  3, 3, 44, 6, 65, 8, 55, 0, 22, 2, 46, 
    8, 54, 4, 88, 6, 86, 3,  4, 5, 66, 0, 11, 1, 79, 7,  6, 2, 10, 
    3, 58, 1, 13, 6, 67, 5, 71, 2, 69, 7, 67, 4, 74, 0, 31, 8, 86, 
    6, 27, 3, 88, 7, 73, 8, 26, 0, 18, 1, 94, 4, 12, 2, 16, 5, 87, 
    8, 72, 1, 50, 2, 17, 5,  5, 4,  1, 7, 75, 6,  8, 3, 11, 0, 97, 
    5, 26, 7, 62, 2,  7, 3, 64, 1, 77, 8, 46, 0, 75, 4,  7, 6, 81, 
    8, 69, 7, 34, 4,  5, 2, 78, 3, 43, 6, 95, 0, 40, 1, 15, 5, 95, 
    6,  5, 1, 67, 7, 99, 8, 68, 5, 21, 0, 12, 4, 96, 3, 77, 2, 40, 
    5, 37, 8, 85, 3,  7, 1, 57, 0, 66, 7, 79, 4, 75, 2, 58, 6, 75
  };
  const int q7889[] = {
    9, 9, // Number of jobs and machines
    7, 94, 4, 13, 8, 42, 6, 98, 0, 48, 5, 57, 1, 33, 3, 44, 2, 50, 
    7,  9, 4, 77, 2, 40, 5, 55, 6, 42, 0, 19, 3, 64, 8, 92, 1, 73, 
    1, 55, 8, 77, 3, 40, 7, 82, 4, 65, 0, 14, 5, 69, 2,  7, 6, 20, 
    7, 95, 6, 88, 3,  9, 1, 94, 0, 95, 5, 28, 8, 69, 2,  1, 4, 85, 
    4, 33, 0, 22, 8, 30, 3, 46, 5, 65, 1, 80, 2, 36, 6, 30, 7, 33, 
    3, 80, 0, 66, 8, 99, 6, 47, 5, 72, 2, 46, 1, 67, 4, 76, 7, 31, 
    4,  3, 5, 31, 2, 36, 0, 50, 1, 12, 8, 27, 7, 61, 6, 86, 3, 52, 
    3, 93, 0, 51, 2, 14, 4, 81, 1, 34, 6, 70, 8, 75, 7, 46, 5, 49, 
    2, 61, 7, 87, 1,  6, 4, 56, 0, 73, 8, 16, 5, 23, 3, 88, 6, 65
  };
  const int q7890[] = {
    9, 9, // Number of jobs and machines
    5, 22, 4, 21, 0, 80, 3,  8, 8, 89, 1, 66, 7, 71, 6, 28, 2, 55, 
    8, 17, 0, 25, 1, 22, 5,  6, 4, 60, 3, 33, 2, 73, 6, 30, 7, 14, 
    1, 40, 8, 90, 3, 50, 5, 84, 2, 28, 7, 11, 4, 99, 6, 32, 0, 15, 
    0, 39, 3, 19, 5, 88, 8, 27, 4, 12, 7, 99, 2, 62, 6, 31, 1, 12, 
    7, 60, 3, 93, 0, 93, 2, 75, 4,  8, 8,  4, 6,  6, 1, 64, 5, 41, 
    0, 41, 7, 64, 2, 64, 6, 86, 4, 96, 5, 51, 3, 23, 1, 37, 8, 92, 
    3, 72, 4, 20, 2, 39, 0, 56, 5, 91, 8, 68, 1, 68, 7, 50, 6, 97, 
    2, 93, 7, 83, 6,  5, 1, 22, 3, 13, 8, 28, 4, 18, 5, 65, 0, 64, 
    3, 48, 8, 58, 5, 12, 1, 82, 4, 45, 7, 22, 0, 69, 6, 66, 2,  5
  };
  const int q7891[] = {
    9, 9, // Number of jobs and machines
    5, 90, 8, 60, 7, 86, 3, 13, 4, 37, 0, 50, 6, 82, 1, 16, 2, 70, 
    2, 23, 4, 26, 3, 61, 8, 49, 0,  7, 1, 58, 5, 19, 6,  2, 7, 66, 
    0, 63, 8, 41, 1, 19, 2, 56, 4, 82, 5,  4, 3, 30, 7, 98, 6, 79, 
    4, 31, 7, 18, 1,  9, 3, 41, 6, 16, 2, 90, 8, 33, 0, 44, 5, 83, 
    0, 12, 2,  2, 3, 77, 4, 40, 8, 76, 5, 33, 6, 99, 1, 82, 7, 48, 
    3, 94, 0,  2, 6, 21, 8, 46, 1, 25, 5,  9, 2, 19, 4, 47, 7, 24, 
    7, 57, 5, 14, 8, 73, 3, 46, 0, 19, 2, 64, 1, 71, 6, 99, 4, 45, 
    0,  4, 6, 16, 7, 40, 5, 48, 2, 71, 3, 21, 4, 70, 1, 28, 8, 59, 
    5, 31, 6,  6, 2, 53, 0, 20, 7, 30, 4, 45, 8, 40, 3, 32, 1, 79
  };
  const int q7892[] = {
    9, 9, // Number of jobs and machines
    2, 80, 7, 36, 3, 48, 8, 30, 0, 83, 5, 31, 1, 30, 4, 75, 6, 10, 
    7,  8, 6,  6, 3, 29, 8, 93, 1, 65, 2, 22, 4,  4, 5, 32, 0, 91, 
    7, 68, 3, 24, 5, 52, 4, 17, 8, 73, 1, 98, 2, 68, 0, 85, 6, 25, 
    7, 14, 8, 57, 0, 54, 5, 60, 1, 54, 3,  1, 2, 94, 4, 24, 6, 56, 
    0, 88, 8, 99, 3, 82, 5, 94, 4, 41, 1,  8, 7, 87, 2, 72, 6, 92, 
    5, 28, 1, 98, 2, 16, 0, 88, 3, 80, 6, 71, 4, 66, 7, 10, 8, 24, 
    5, 17, 3, 19, 0, 95, 8, 54, 7, 47, 2, 87, 4, 74, 1, 72, 6, 72, 
    3, 52, 8, 36, 0, 80, 6, 41, 7, 54, 5, 10, 1, 82, 4, 86, 2, 50, 
    1, 91, 6,  2, 5, 93, 7, 23, 0, 82, 8,  9, 2, 64, 3,  8, 4, 81
  };
  const int q7893[] = {
    9, 9, // Number of jobs and machines
    6, 39, 1,  8, 7, 79, 4, 80, 2, 97, 0, 63, 8, 73, 3, 86, 5, 86, 
    8, 77, 5, 26, 6, 25, 7, 51, 4, 72, 2, 94, 1, 83, 3,  1, 0, 75, 
    0, 21, 7, 87, 4, 51, 6, 22, 1, 16, 5, 91, 2, 49, 8, 74, 3, 32, 
    2, 61, 8, 17, 1, 44, 3, 26, 5, 34, 7, 20, 4, 74, 6, 55, 0, 14, 
    3, 19, 7, 76, 8, 96, 5, 88, 0, 37, 2, 55, 4, 34, 6, 57, 1, 46, 
    8, 74, 0, 68, 5, 83, 2,  6, 4, 88, 6, 73, 1, 57, 3, 71, 7, 68, 
    6, 53, 1, 50, 3, 34, 8, 29, 7, 65, 5, 94, 4, 14, 2, 39, 0, 92, 
    8, 88, 2, 46, 1, 64, 7, 44, 5, 99, 3, 12, 6, 34, 0, 49, 4, 64, 
    5, 55, 0, 26, 8, 69, 3, 12, 7, 88, 6, 85, 1, 86, 4, 82, 2, 94
  };
  const int q7894[] = {
    9, 9, // Number of jobs and machines
    7, 12, 4, 15, 2, 14, 6,  9, 0, 47, 8, 52, 5, 92, 3, 20, 1, 19, 
    7, 30, 3,  4, 0, 87, 4, 64, 6, 96, 1, 39, 5, 90, 8, 82, 2, 91, 
    0, 26, 5, 84, 4, 35, 6, 57, 1, 33, 3, 99, 2, 36, 7, 81, 8, 52, 
    5, 24, 3, 82, 4,  5, 2, 49, 8, 60, 0, 37, 1, 61, 6, 42, 7, 77, 
    2, 90, 3, 74, 7, 46, 4, 74, 8, 37, 0, 49, 6, 58, 5, 64, 1, 40, 
    2, 16, 6, 30, 7, 17, 4, 52, 1, 80, 0, 25, 5, 91, 3, 75, 8, 69, 
    5, 76, 7, 12, 0, 14, 2, 45, 6, 95, 4, 96, 1, 29, 3, 73, 8, 64, 
    7, 32, 8, 52, 0, 71, 1, 91, 3, 65, 6, 89, 2, 84, 5, 99, 4, 31, 
    0, 95, 6, 38, 2, 43, 7,  2, 5, 25, 4,  1, 3, 42, 8, 79, 1, 82
  };
  const int q7895[] = {
    9, 9, // Number of jobs and machines
    0, 23, 4, 96, 7, 69, 2, 54, 5, 72, 3, 28, 6, 70, 1, 57, 8, 10, 
    5, 57, 2, 59, 4, 87, 8, 23, 0, 91, 7, 78, 6, 41, 1, 37, 3,  8, 
    5, 72, 1, 95, 6,  1, 7, 20, 4, 93, 3, 82, 2, 96, 0,  2, 8, 34, 
    3, 82, 1, 98, 2, 24, 4, 47, 8, 43, 7, 62, 5, 29, 6, 87, 0,  1, 
    8, 12, 6, 57, 0, 67, 4, 91, 7, 38, 1, 76, 2, 83, 5, 67, 3, 54, 
    4, 15, 0, 49, 8, 10, 5, 29, 6, 88, 7,  9, 3, 24, 1, 11, 2, 36, 
    5, 36, 6, 63, 3, 93, 4, 96, 0, 42, 8, 97, 7, 10, 2, 33, 1, 60, 
    5, 27, 1, 53, 0, 71, 3, 91, 6, 20, 4, 56, 8,  5, 7, 26, 2, 43, 
    3, 76, 5, 74, 2, 80, 1, 94, 8,  2, 7, 53, 0, 70, 6, 26, 4, 76
  };
  const int q7896[] = {
    9, 9, // Number of jobs and machines
    6, 90, 5, 66, 0, 46, 7, 19, 3,  3, 4, 68, 8, 43, 2, 72, 1, 90, 
    7,  7, 3, 16, 8, 79, 6, 86, 5, 94, 4, 22, 0,  9, 1, 61, 2, 78, 
    4, 89, 8, 92, 2, 68, 6, 25, 3,  3, 0, 68, 5, 48, 1, 67, 7, 37, 
    1, 23, 2,  8, 6, 11, 8, 29, 3, 53, 4, 14, 5, 93, 7, 16, 0, 71, 
    1, 89, 6, 54, 0, 24, 3, 32, 7,  6, 8, 62, 2, 71, 4, 54, 5, 63, 
    8, 85, 4, 21, 6, 85, 7, 73, 5, 89, 3,  9, 2, 24, 1, 77, 0, 91, 
    0, 12, 4, 94, 7, 89, 3, 33, 8, 13, 5, 38, 6, 65, 2, 47, 1, 12, 
    7,  8, 6, 52, 2, 91, 4, 69, 8, 38, 0, 82, 5, 21, 3, 87, 1, 51, 
    4, 40, 3, 23, 6, 62, 0, 30, 1, 19, 2, 76, 7, 45, 8, 96, 5, 43
  };
  const int q7897[] = {
    9, 9, // Number of jobs and machines
    1, 59, 7, 26, 3, 40, 2, 32, 4, 56, 6, 29, 0, 19, 5, 15, 8, 98, 
    8, 94, 0, 55, 5, 21, 4, 54, 3, 61, 7, 21, 6, 45, 2, 58, 1, 98, 
    7, 47, 0, 99, 8, 72, 3, 68, 5, 45, 2, 82, 1, 80, 6, 99, 4,  9, 
    3, 31, 8, 82, 2, 82, 7, 91, 5,  2, 6, 48, 0, 31, 4, 17, 1, 90, 
    8, 31, 3, 49, 5, 18, 6, 35, 1,  5, 4, 51, 2, 60, 0, 24, 7, 53, 
    0, 64, 7, 98, 3, 17, 6,  5, 8, 40, 2, 99, 5, 89, 1, 69, 4, 77, 
    7, 40, 5, 20, 6, 16, 4,  4, 8, 10, 1, 78, 2, 95, 0, 20, 3, 26, 
    0, 70, 5, 41, 1, 89, 6, 57, 7, 20, 8,  4, 3,  6, 2, 71, 4, 81, 
    3, 67, 4, 13, 0, 18, 1, 63, 7, 49, 2, 19, 8, 24, 5, 60, 6, 37
  };
  const int q7898[] = {
    9, 9, // Number of jobs and machines
    3,  7, 8, 87, 7, 35, 2, 93, 6, 99, 0, 53, 5, 52, 4, 10, 1, 28, 
    4, 24, 8, 32, 0, 70, 1, 89, 5, 78, 2, 67, 7, 73, 3, 56, 6, 74, 
    4, 50, 8, 50, 1, 18, 6, 64, 0, 40, 2, 13, 5, 37, 3, 66, 7, 15, 
    2, 90, 4,  5, 0, 40, 5, 18, 7, 12, 6, 75, 1, 28, 8, 14, 3, 93, 
    4, 48, 7, 63, 6, 69, 3, 31, 2, 90, 1,  3, 0, 74, 8, 17, 5, 17, 
    6, 44, 3,  5, 2, 94, 1,  3, 0, 12, 8, 29, 5, 16, 7, 90, 4,  2, 
    4, 21, 5, 44, 3, 26, 1, 69, 2, 95, 6, 77, 7, 51, 8, 56, 0,  1, 
    2, 80, 4, 52, 3, 27, 0, 54, 7, 14, 8, 44, 6, 72, 1, 42, 5, 27, 
    7, 18, 1,  1, 0, 73, 3, 78, 6, 33, 5, 94, 2, 79, 4, 54, 8, 61
  };
  const int q7899[] = {
    9, 9, // Number of jobs and machines
    4, 35, 8, 20, 5, 95, 1, 49, 7, 55, 6, 90, 0, 62, 3, 13, 2, 96, 
    7, 96, 6, 79, 8, 92, 1,  7, 2, 14, 5, 96, 0, 59, 3, 25, 4, 20, 
    6, 50, 2, 27, 0, 55, 3, 70, 8, 96, 4, 61, 5, 98, 1, 93, 7, 32, 
    3, 20, 6, 98, 5, 91, 4,  2, 0, 54, 1, 74, 2, 42, 7, 48, 8, 34, 
    8, 28, 1, 96, 0, 25, 5, 27, 3, 77, 2, 56, 4, 43, 7, 14, 6, 54, 
    8, 58, 4, 92, 3, 66, 6, 79, 7, 83, 2, 32, 5, 37, 0, 21, 1, 98, 
    0, 52, 8, 99, 3, 28, 4, 86, 5, 72, 1, 35, 6,  6, 7, 19, 2, 46, 
    6, 83, 7, 26, 1, 71, 3, 78, 4, 52, 8, 70, 0, 20, 2,  5, 5, 23, 
    3, 24, 0, 23, 5,  7, 8, 66, 2, 16, 4, 69, 7, 50, 6,  3, 1,  8
  };
  const int q7900[] = {
    9, 9, // Number of jobs and machines
    3, 81, 4, 86, 8, 84, 5, 46, 0, 99, 2,  4, 6, 21, 7, 70, 1, 40, 
    6, 30, 2, 38, 3, 78, 1, 71, 7, 17, 8, 58, 4, 91, 0, 12, 5,  3, 
    5, 32, 8, 59, 4, 82, 1,  4, 0, 10, 6, 36, 7, 17, 2, 12, 3, 40, 
    8, 19, 0, 19, 4, 18, 2, 57, 5, 33, 1, 68, 3, 86, 6, 43, 7, 30, 
    7, 74, 2, 30, 3,  5, 5,  1, 8, 86, 0, 61, 4, 19, 1, 35, 6, 88, 
    3, 78, 8, 37, 6, 99, 1, 26, 0,  6, 2, 55, 4, 72, 7, 37, 5, 46, 
    2, 67, 5, 77, 8, 41, 3, 74, 6, 33, 7, 93, 1,  2, 0, 29, 4, 25, 
    0, 53, 8,  8, 7, 80, 1, 12, 3, 18, 6, 15, 5, 32, 2, 24, 4, 70, 
    1, 22, 2, 98, 5, 23, 7,  7, 8, 86, 6, 49, 0, 83, 3,  4, 4, 82
  };
  const int q7901[] = {
    9, 9, // Number of jobs and machines
    0, 56, 2, 78, 6, 38, 4, 96, 3, 64, 7, 57, 8, 65, 5,  1, 1, 20, 
    1, 98, 3,  4, 6, 28, 5,  1, 2, 17, 7,  5, 4,  9, 0, 21, 8, 69, 
    6, 91, 1,  5, 7, 97, 0, 96, 2, 42, 5, 25, 4, 47, 8, 27, 3, 72, 
    5, 22, 2, 98, 8, 64, 1, 13, 4, 71, 6, 88, 7,  3, 3, 18, 0, 83, 
    1, 41, 2, 34, 6, 32, 7, 84, 5, 96, 3, 72, 8, 26, 0, 58, 4, 29, 
    1,  9, 6,  9, 8,  9, 3,  9, 0, 16, 4, 84, 5, 39, 7, 33, 2, 45, 
    3, 65, 5, 80, 2, 38, 7, 18, 4, 28, 6, 52, 0, 39, 8, 51, 1, 32, 
    2, 67, 8, 68, 1, 20, 3, 41, 4, 43, 0, 92, 7, 12, 5, 82, 6, 17, 
    1, 39, 3, 92, 0, 83, 8, 32, 7, 59, 6, 54, 4, 65, 5, 49, 2, 35
  };
  const int q7902[] = {
    9, 9, // Number of jobs and machines
    2, 66, 8, 73, 7, 58, 4, 29, 1, 26, 3, 85, 0, 60, 5, 56, 6, 45, 
    7, 26, 2, 44, 0, 19, 1, 89, 6, 31, 5, 90, 3, 97, 4, 32, 8, 21, 
    6, 52, 2, 74, 8, 37, 5, 77, 7, 28, 0, 90, 3, 96, 4, 84, 1, 89, 
    1, 71, 5, 82, 3, 40, 6, 32, 4, 14, 7, 65, 0, 91, 8, 89, 2, 14, 
    6, 66, 7, 16, 8, 86, 5, 87, 2, 16, 4, 31, 1, 42, 3, 89, 0, 64, 
    7, 17, 8, 69, 4, 52, 1, 26, 5, 94, 6, 51, 3, 27, 0, 91, 2, 47, 
    4, 65, 2, 76, 7, 88, 6, 96, 8, 93, 0, 28, 1, 37, 3, 62, 5, 47, 
    7,  7, 5, 43, 0, 65, 3, 21, 4, 10, 6, 68, 2, 61, 1, 67, 8, 67, 
    5, 48, 8,  1, 3, 12, 0, 29, 7, 49, 4, 27, 6, 44, 1, 31, 2, 20
  };
  const int q7903[] = {
    9, 9, // Number of jobs and machines
    8, 89, 4, 28, 3,  3, 7, 24, 6, 75, 5, 61, 1, 34, 0, 37, 2, 99, 
    2, 73, 1, 31, 5, 28, 8, 71, 3, 96, 6, 52, 0, 47, 4, 96, 7, 55, 
    1,  1, 2, 53, 0, 38, 3, 17, 5, 26, 8, 50, 6, 10, 4, 68, 7, 94, 
    8, 65, 5, 59, 4, 14, 6, 30, 0, 87, 2, 43, 3, 12, 1, 26, 7, 78, 
    2, 88, 1, 82, 8, 82, 6, 74, 0, 71, 5, 58, 7, 47, 3, 80, 4, 84, 
    6, 58, 5,  7, 4, 14, 8, 23, 1, 10, 7, 14, 3, 94, 0, 43, 2, 70, 
    0, 68, 6, 32, 8, 73, 5, 91, 3, 67, 1, 36, 2, 17, 4, 20, 7,  8, 
    0, 94, 7, 83, 2, 49, 1, 12, 8, 83, 5, 22, 6, 17, 4, 44, 3, 36, 
    4, 55, 3, 88, 8, 50, 2, 54, 6, 75, 5, 64, 7,  9, 1, 62, 0, 54
  };
  const int q7904[] = {
    9, 9, // Number of jobs and machines
    2, 15, 4, 92, 6, 26, 0, 69, 7, 27, 8, 56, 3, 84, 1, 64, 5, 57, 
    7, 76, 1, 12, 2, 90, 3, 68, 4, 36, 6, 90, 8, 61, 5, 21, 0, 82, 
    6, 81, 7, 70, 8, 49, 0, 18, 2, 20, 1,  9, 5, 68, 4, 32, 3, 65, 
    6, 98, 5, 53, 0, 39, 4, 81, 1, 38, 8, 31, 7, 41, 3, 78, 2, 77, 
    6, 14, 7, 30, 0, 66, 2,  5, 1, 42, 4, 42, 8, 48, 3, 86, 5, 61, 
    2, 99, 6, 19, 1, 26, 5, 96, 8,  5, 7, 72, 4, 84, 0, 62, 3, 57, 
    0,  6, 8, 40, 6, 11, 4, 63, 3, 16, 5, 98, 7, 21, 1, 49, 2, 44, 
    0, 49, 2, 97, 3, 93, 5, 28, 7, 54, 8, 82, 1, 60, 6, 70, 4, 50, 
    0, 29, 5, 90, 1, 50, 6, 45, 7, 76, 4,  8, 3, 14, 2, 51, 8, 22
  };
  const int q7905[] = {
    9, 9, // Number of jobs and machines
    0, 59, 1, 40, 5, 84, 3, 11, 8, 37, 7, 16, 4, 56, 2, 64, 6, 61, 
    2, 58, 0, 76, 7, 21, 3, 97, 1, 22, 4, 73, 8, 97, 6, 71, 5, 87, 
    1, 16, 4, 82, 8, 19, 7, 10, 0, 42, 2, 98, 5, 60, 6, 72, 3, 42, 
    3, 80, 4, 94, 1,  5, 8,  5, 0, 45, 5, 65, 2, 81, 6, 74, 7, 42, 
    8, 82, 0,  9, 6, 14, 2, 23, 7, 49, 5, 36, 3, 32, 1, 27, 4, 41, 
    0,  8, 7,  9, 4, 75, 2, 81, 3, 17, 1,  5, 8, 28, 5, 59, 6, 58, 
    8, 54, 6, 90, 2, 81, 5, 68, 4, 67, 0, 74, 3, 92, 7, 71, 1, 61, 
    8, 14, 7,  9, 1, 31, 0, 32, 5, 47, 2, 41, 6, 42, 4, 93, 3, 31, 
    3, 73, 1, 34, 6,  4, 5, 68, 8, 20, 4, 94, 7, 70, 2, 67, 0, 20
  };
  const int q7906[] = {
    9, 9, // Number of jobs and machines
    5,  9, 0, 23, 6,  6, 3, 17, 1, 31, 7, 36, 8, 54, 4, 52, 2, 60, 
    2, 96, 5,  5, 1, 36, 0, 98, 7, 68, 6, 39, 8, 21, 4, 36, 3, 12, 
    4, 55, 0, 94, 6, 68, 2, 48, 7, 99, 5, 51, 3, 25, 8, 65, 1, 56, 
    8, 52, 4,  5, 6, 78, 2, 63, 0, 48, 3, 53, 5, 43, 1, 59, 7, 55, 
    6, 89, 0, 95, 8, 12, 5, 57, 1, 32, 7, 59, 3, 77, 2, 29, 4, 43, 
    5, 34, 3, 74, 6, 78, 2,  9, 1, 63, 8, 19, 0, 51, 7, 41, 4, 28, 
    6, 99, 5, 36, 0, 98, 3, 81, 4, 92, 2, 42, 7, 67, 8, 11, 1, 81, 
    4, 16, 1, 92, 7, 20, 3, 35, 8, 70, 0, 46, 2, 72, 6, 77, 5, 67, 
    2, 59, 1, 50, 0, 42, 3, 15, 8, 85, 6, 64, 5, 82, 7, 65, 4, 95
  };
  const int q7907[] = {
    9, 9, // Number of jobs and machines
    3, 96, 8, 89, 2, 73, 4, 98, 5, 97, 1, 88, 0, 69, 7, 18, 6, 67, 
    1, 42, 4, 58, 6, 52, 0, 21, 3, 18, 2, 55, 8, 39, 5, 94, 7, 29, 
    6, 34, 3, 47, 5,  1, 8, 16, 0, 83, 2, 53, 1, 21, 4, 25, 7, 47, 
    1, 77, 8, 59, 2, 39, 7,  1, 4, 71, 3, 40, 5, 18, 6, 86, 0, 20, 
    5, 73, 6, 17, 2, 64, 0, 96, 8, 36, 1, 69, 4, 28, 7, 19, 3, 92, 
    3, 74, 4, 88, 0, 69, 7, 60, 6, 84, 2, 21, 8, 54, 1,  8, 5, 48, 
    3, 50, 5, 85, 1, 19, 7, 16, 8, 33, 4, 43, 2, 70, 6, 60, 0, 33, 
    4, 55, 3, 24, 5, 71, 8, 13, 6,  1, 7, 33, 0, 81, 2, 25, 1, 83, 
    3, 44, 7, 41, 1, 62, 4, 85, 5, 59, 6, 71, 0, 33, 2, 29, 8, 35
  };
  const int q7908[] = {
    9, 9, // Number of jobs and machines
    1, 61, 7, 70, 6, 70, 2, 29, 3, 57, 8, 21, 5, 74, 0, 22, 4, 23, 
    2, 18, 8, 40, 4, 77, 5, 77, 6, 73, 1, 78, 0, 21, 7, 79, 3,  4, 
    6, 74, 0, 89, 1, 96, 8, 44, 4, 36, 5, 44, 7, 16, 2, 52, 3, 97, 
    3, 61, 5, 83, 1, 31, 4, 83, 6, 70, 2,  5, 0, 44, 8, 71, 7, 54, 
    2, 12, 8, 72, 1, 25, 4,  8, 7,  5, 6, 11, 0, 69, 5, 46, 3, 99, 
    4, 66, 0, 47, 5, 66, 1, 28, 8, 92, 3, 12, 6, 70, 7, 34, 2, 90, 
    8, 19, 5, 42, 2, 98, 7, 96, 1, 21, 3, 73, 4, 14, 6, 18, 0, 70, 
    5, 13, 0, 18, 8, 48, 6, 65, 4, 71, 7, 22, 2, 79, 3, 97, 1, 54, 
    3, 45, 1, 83, 7, 94, 5,  7, 6, 80, 8, 61, 0, 66, 2, 23, 4, 93
  };
  const int q7909[] = {
    9, 9, // Number of jobs and machines
    6,  1, 3, 10, 0,  4, 7, 39, 5, 29, 4, 79, 8, 27, 1, 32, 2, 24, 
    4, 39, 3, 97, 6, 33, 0, 49, 5, 18, 1, 36, 7,  1, 8, 85, 2, 30, 
    1, 85, 7, 86, 8, 96, 6, 47, 0, 39, 3, 36, 5, 30, 4, 90, 2, 91, 
    6, 10, 4, 29, 8, 44, 3, 18, 7, 83, 2, 27, 1, 69, 5, 64, 0, 29, 
    0, 31, 5, 70, 4,  7, 1, 88, 3, 14, 7, 75, 8, 79, 6, 78, 2, 48, 
    5, 64, 8, 20, 7, 41, 0,  3, 6, 50, 1, 31, 4, 22, 3, 88, 2, 19, 
    1,  4, 3, 69, 8, 97, 6, 71, 5, 89, 2, 93, 4, 41, 0, 17, 7, 65, 
    1,  3, 4, 87, 6, 88, 5, 19, 0, 68, 8, 28, 3, 16, 2, 29, 7, 72, 
    3, 98, 0, 92, 1, 68, 8, 33, 2,  6, 6, 74, 4, 90, 7, 26, 5, 93
  };
  const int q7910[] = {
    9, 9, // Number of jobs and machines
    2, 83, 3, 47, 1, 50, 5, 30, 8, 97, 4, 49, 6,  9, 7, 11, 0, 28, 
    4, 70, 6, 71, 3, 88, 7, 53, 2, 36, 0, 49, 5, 12, 8, 30, 1, 12, 
    5,  9, 2, 97, 1,  6, 6, 49, 7,  9, 4,  7, 0, 67, 3, 87, 8, 90, 
    2, 67, 3, 46, 5, 78, 1, 16, 8, 77, 7, 10, 6, 17, 4, 52, 0, 17, 
    5, 14, 8, 12, 6, 34, 7,  3, 0, 46, 4, 52, 2, 55, 3, 26, 1, 90, 
    7,  7, 3, 94, 6, 68, 0, 10, 2, 47, 1, 29, 5, 21, 8, 91, 4, 42, 
    7, 12, 6, 33, 5, 85, 3, 65, 8, 16, 0, 79, 4, 19, 1,  2, 2, 48, 
    4, 16, 6, 38, 5, 18, 8, 84, 2, 96, 7, 51, 1,  4, 3, 18, 0, 20, 
    3, 80, 5, 46, 6, 37, 0, 40, 7, 40, 1, 44, 8, 89, 4, 79, 2, 39
  };
  const int q7911[] = {
    9, 9, // Number of jobs and machines
    3, 68, 8, 96, 0, 54, 6, 72, 4, 94, 5, 60, 7,  8, 2, 29, 1, 51, 
    5, 67, 1,  5, 0, 90, 4, 32, 6, 21, 8, 53, 2,  9, 3, 53, 7, 87, 
    3, 89, 7, 11, 5, 90, 6, 22, 8, 32, 4, 53, 2, 20, 1, 99, 0, 11, 
    0, 88, 6, 30, 3, 28, 5, 33, 2, 55, 4, 87, 7, 24, 1, 17, 8, 66, 
    0, 22, 1, 96, 6, 89, 4, 98, 8, 67, 5,  5, 7, 58, 3, 69, 2,  2, 
    2, 44, 0, 85, 7, 69, 6, 83, 1, 21, 3, 74, 5, 58, 4, 39, 8, 76, 
    8, 87, 4, 94, 3, 71, 7, 14, 2, 56, 5, 46, 6, 63, 0,  7, 1, 12, 
    8, 42, 5, 34, 6, 65, 2, 11, 1, 95, 7, 72, 3, 35, 4, 23, 0, 41, 
    0, 12, 2, 23, 5, 89, 4, 54, 3,  3, 8, 52, 6, 24, 7, 63, 1, 88
  };
  const int q7912[] = {
    9, 9, // Number of jobs and machines
    1, 71, 7, 50, 3, 21, 6, 61, 0, 46, 5, 37, 4, 36, 2, 29, 8, 26, 
    5, 55, 3, 79, 4,  5, 6, 72, 7, 54, 0, 62, 8,  5, 2, 24, 1, 84, 
    2, 53, 4, 32, 6, 52, 3,  4, 0, 48, 7,  2, 8, 98, 5, 94, 1,  4, 
    7, 50, 5, 49, 4, 74, 6, 27, 8,  5, 3, 24, 2, 36, 0, 81, 1, 52, 
    4, 45, 6,  1, 5,  6, 8, 22, 7, 63, 2, 41, 3, 67, 1,  2, 0, 25, 
    6, 71, 3, 63, 1, 22, 5, 31, 4, 93, 8, 47, 2, 84, 0, 83, 7, 96, 
    5, 83, 4,  5, 0,  9, 7, 14, 1, 35, 3, 79, 6, 42, 8, 63, 2, 56, 
    2,  9, 5, 35, 1, 80, 4, 34, 8, 88, 3, 89, 6, 26, 0, 26, 7, 48, 
    3, 91, 1, 30, 6, 54, 8, 65, 5, 79, 7, 92, 4, 16, 2, 26, 0, 34
  };
  const int q7913[] = {
    9, 9, // Number of jobs and machines
    4, 36, 0,  5, 2, 11, 8,  5, 6, 63, 7, 83, 1, 92, 3, 46, 5, 94, 
    0, 56, 5, 99, 6, 20, 3, 87, 7, 95, 1, 68, 8,  3, 4, 31, 2, 29, 
    3, 71, 4, 74, 5, 43, 8, 93, 2, 49, 6, 94, 1, 66, 0, 94, 7, 68, 
    4, 44, 2, 23, 1, 96, 5, 35, 0, 88, 3, 27, 6, 73, 8, 44, 7, 93, 
    2, 52, 0, 97, 4, 34, 3, 45, 1, 23, 6, 71, 5, 56, 8, 56, 7, 34, 
    7, 83, 1, 87, 2,  3, 3, 10, 5, 24, 0, 19, 8, 72, 6, 22, 4, 17, 
    2, 31, 4, 70, 7, 19, 6, 11, 3, 53, 8, 97, 0, 21, 1, 84, 5, 58, 
    4,  7, 3, 75, 0, 80, 6, 95, 8, 38, 5,  7, 7, 93, 1,  8, 2, 39, 
    8, 77, 0, 58, 5, 30, 6, 22, 1, 73, 4, 52, 7, 38, 3, 42, 2, 33
  };
  const int q7914[] = {
    9, 9, // Number of jobs and machines
    4, 25, 8,  1, 3, 81, 7, 56, 2, 91, 5, 79, 1, 88, 6,  9, 0, 17, 
    0, 57, 3, 57, 1, 11, 2, 29, 5, 71, 4, 54, 6,  5, 7, 99, 8, 22, 
    2, 96, 5, 43, 4, 35, 8, 32, 7, 82, 1, 94, 0, 33, 6, 96, 3, 27, 
    4, 83, 2, 23, 1, 42, 3, 85, 5, 64, 0, 58, 6, 86, 7, 30, 8, 67, 
    5, 28, 2, 80, 4, 43, 3, 31, 7, 23, 8, 46, 1,  4, 6, 20, 0, 95, 
    3,  6, 1, 75, 0,  6, 2, 16, 8, 64, 4, 54, 6, 12, 7,  1, 5, 85, 
    0, 61, 8, 69, 6,  5, 1, 71, 5,  9, 3, 26, 4, 26, 7, 53, 2, 49, 
    7, 33, 2, 87, 8, 29, 6, 71, 4, 25, 0, 48, 3, 54, 1, 16, 5, 86, 
    4, 72, 0, 27, 1, 47, 7, 90, 8, 34, 2, 13, 6,  4, 5, 25, 3, 56
  };
  const int q7915[] = {
    9, 9, // Number of jobs and machines
    7, 56, 5, 72, 8, 92, 2, 87, 6, 73, 4,  7, 1, 14, 3, 42, 0, 32, 
    4, 17, 8, 89, 2, 69, 0, 19, 1, 28, 6, 81, 7, 67, 3, 14, 5, 80, 
    0, 31, 1,  9, 5, 99, 7, 10, 8, 85, 6, 42, 2, 85, 4, 53, 3, 86, 
    6, 67, 8, 22, 0, 74, 4, 45, 1, 14, 5, 75, 2, 93, 7, 60, 3, 29, 
    6, 18, 0, 94, 1,  3, 8, 75, 3, 28, 2, 97, 7, 99, 4, 56, 5, 13, 
    7,  6, 6, 18, 8, 71, 1, 12, 2, 75, 4, 18, 0,  1, 3, 69, 5, 64, 
    1, 37, 6, 40, 5, 30, 2, 78, 7, 62, 3, 92, 0, 90, 4, 71, 8, 19, 
    8, 12, 5, 67, 4, 90, 6,  8, 2, 64, 0, 27, 1, 89, 7, 71, 3, 45, 
    4, 26, 6,  7, 2, 91, 0, 57, 5, 96, 3, 94, 7, 22, 8, 19, 1, 71
  };
  const int q7916[] = {
    9, 9, // Number of jobs and machines
    1, 46, 6, 41, 0, 11, 7, 45, 3, 53, 2, 66, 5, 55, 4, 86, 8, 55, 
    0, 34, 8, 15, 4, 48, 7, 62, 5, 56, 2, 86, 3, 13, 6, 44, 1, 91, 
    4, 74, 5, 43, 0, 78, 3, 51, 7, 59, 8, 57, 1,  7, 2, 49, 6, 73, 
    0, 58, 2, 39, 7, 53, 3, 80, 4, 47, 6, 23, 8, 93, 1, 50, 5, 59, 
    0, 97, 8, 60, 4, 37, 1, 65, 5, 71, 6, 84, 2,  1, 7, 49, 3, 56, 
    6, 48, 3, 93, 8, 93, 2, 38, 1, 36, 7, 20, 0, 43, 4, 54, 5, 83, 
    8, 90, 1, 62, 2, 33, 5, 40, 3, 33, 6, 14, 7,  3, 4, 90, 0,  1, 
    4, 27, 2, 49, 6, 66, 5, 36, 8, 47, 1,  3, 0, 87, 7, 90, 3, 19, 
    1, 24, 4,  1, 2, 31, 3, 24, 8, 79, 0,  2, 6, 12, 7, 82, 5, 80
  };
  const int q7917[] = {
    9, 9, // Number of jobs and machines
    5, 80, 1, 56, 2, 78, 6, 36, 0, 43, 3, 53, 7, 13, 4, 34, 8, 18, 
    5, 33, 6, 93, 0, 94, 1, 53, 4, 34, 3, 96, 8, 23, 7, 22, 2, 25, 
    3,  8, 0, 24, 7, 51, 1, 30, 5, 16, 2, 55, 6, 33, 8, 21, 4, 24, 
    2, 85, 3, 85, 5, 70, 0, 67, 4, 88, 1, 38, 7, 29, 8, 14, 6, 90, 
    3, 65, 1, 78, 6, 52, 0, 10, 4, 99, 5, 78, 2, 94, 8,  6, 7, 32, 
    4, 23, 0, 17, 2, 73, 7, 63, 5, 39, 8,  3, 6, 32, 3, 42, 1, 48, 
    5, 94, 3, 81, 6, 15, 8, 84, 2, 50, 4, 29, 0, 80, 7, 93, 1, 23, 
    8, 33, 5, 76, 0,  5, 6, 32, 7, 73, 3, 56, 1, 29, 4, 92, 2, 93, 
    4, 81, 0, 62, 6, 53, 3, 19, 1, 58, 7, 48, 2, 50, 8, 42, 5, 52
  };
  const int q7918[] = {
    9, 9, // Number of jobs and machines
    5, 46, 4, 58, 8, 19, 1, 65, 3, 37, 0, 83, 6, 67, 2, 39, 7, 26, 
    1, 59, 7,  5, 0, 10, 4, 95, 8,  3, 5, 88, 2,  7, 6, 47, 3, 91, 
    1, 82, 8, 33, 6, 20, 7, 58, 4, 56, 3, 28, 5, 91, 0,  5, 2, 88, 
    7, 88, 8, 60, 6, 89, 3, 38, 5, 77, 2, 27, 4, 20, 1, 94, 0, 23, 
    6, 11, 8, 96, 7, 27, 2, 73, 4, 17, 3, 94, 1, 89, 5, 97, 0, 61, 
    0, 79, 8, 33, 1, 97, 2, 12, 3, 16, 4, 10, 7, 57, 6, 66, 5,  5, 
    0, 53, 6, 35, 7, 46, 4,  2, 1,  4, 5, 35, 8, 56, 2,  3, 3, 95, 
    6, 39, 4, 43, 3, 77, 7,  7, 1, 33, 0, 14, 8, 48, 2, 82, 5, 57, 
    7, 33, 1, 21, 3, 21, 8, 45, 2, 35, 5, 76, 4, 27, 6, 54, 0, 78
  };
  const int q7919[] = {
    9, 9, // Number of jobs and machines
    1, 38, 2,  3, 3, 86, 6, 36, 8, 39, 5, 80, 7, 96, 4, 26, 0, 52, 
    7, 72, 8, 54, 4, 14, 1, 48, 2, 88, 5, 80, 6, 33, 0, 34, 3, 42, 
    7, 22, 0, 57, 6, 44, 4,  6, 5, 22, 8, 93, 1, 51, 2, 70, 3,  6, 
    4, 76, 5, 92, 3, 14, 6, 93, 8, 39, 7, 73, 2, 97, 1, 52, 0, 23, 
    0, 33, 8, 52, 1, 17, 2, 57, 5, 74, 4, 35, 7, 28, 6, 65, 3, 15, 
    0, 36, 1, 65, 7, 21, 4, 38, 8, 71, 3, 87, 6, 78, 2, 19, 5,  8, 
    4, 82, 1, 87, 3, 50, 6,  6, 8, 99, 7, 19, 2, 86, 0, 61, 5, 31, 
    5, 88, 3, 76, 0,  3, 1, 20, 6, 99, 7, 10, 8, 47, 2, 73, 4,  4, 
    0, 88, 7, 34, 5, 80, 2, 44, 3, 51, 4, 13, 1, 85, 6, 65, 8, 27
  };
  const int q7920[] = {
    9, 9, // Number of jobs and machines
    7, 11, 4, 61, 8, 11, 6, 86, 3, 22, 5, 64, 2, 14, 1,  3, 0,  1, 
    3, 51, 8, 10, 5, 21, 0, 27, 1,  4, 7, 33, 4, 88, 6, 38, 2, 11, 
    4, 93, 1, 77, 2, 55, 3, 71, 8, 47, 6, 24, 5,  6, 7, 13, 0, 81, 
    1, 58, 7, 75, 8, 16, 6, 89, 0, 33, 3, 97, 2, 51, 5, 65, 4, 73, 
    5, 88, 1, 94, 2, 60, 6, 66, 8,  9, 4, 39, 7, 29, 3, 79, 0,  6, 
    8, 43, 0, 90, 6, 41, 7,  1, 5, 33, 4, 29, 2, 35, 3, 96, 1, 97, 
    6, 67, 7, 10, 2, 86, 1, 76, 5, 49, 0, 39, 4, 91, 3, 28, 8, 19, 
    8, 16, 4, 97, 7, 41, 0, 56, 2, 93, 6, 71, 1, 38, 3, 95, 5,  9, 
    4, 63, 0, 56, 2, 23, 3, 90, 8, 66, 5, 29, 1, 26, 6, 77, 7, 60
  };
  const int q7921[] = {
    9, 9, // Number of jobs and machines
    3, 79, 0, 83, 7, 83, 4, 51, 5, 37, 2, 49, 6, 77, 1, 89, 8, 27, 
    5, 46, 2, 77, 4, 79, 0, 39, 1, 23, 8, 12, 7, 29, 3, 32, 6, 40, 
    2, 99, 4, 98, 1, 44, 0, 22, 8, 93, 3, 71, 5, 72, 7, 37, 6, 75, 
    5, 31, 8, 87, 2, 59, 7, 98, 1, 46, 0,  8, 3, 33, 4, 74, 6, 92, 
    6, 72, 2, 63, 8, 97, 5, 42, 0, 45, 1, 89, 7, 31, 3, 36, 4, 92, 
    5, 76, 6, 63, 3, 51, 8, 38, 0, 14, 4, 97, 1, 16, 2, 35, 7,  4, 
    2, 25, 5, 80, 6, 18, 1, 91, 7, 34, 8, 72, 4, 97, 0, 64, 3, 10, 
    5, 30, 2, 42, 4,  4, 8, 19, 0, 99, 1, 80, 6,  1, 3, 62, 7, 81, 
    0, 92, 5, 28, 1, 74, 4, 65, 6, 67, 7, 56, 3, 81, 8, 37, 2, 50
  };
  const int q7922[] = {
    9, 9, // Number of jobs and machines
    3, 60, 2, 28, 5, 83, 8, 46, 0, 32, 7, 33, 6, 98, 1, 16, 4, 22, 
    0, 23, 7, 65, 1, 70, 3,  7, 2, 79, 8, 50, 5, 12, 4, 19, 6, 18, 
    8, 24, 6,  6, 2, 66, 1, 44, 0, 72, 7, 39, 4, 15, 5,  1, 3, 23, 
    4, 57, 2, 43, 5, 72, 8, 75, 3, 78, 1, 43, 0, 93, 6, 59, 7,  1, 
    1, 41, 5, 38, 0,  7, 3, 20, 6, 61, 2, 18, 8, 55, 4, 64, 7, 93, 
    7, 99, 0, 46, 5,  5, 1, 24, 2,  3, 3,  4, 8, 65, 4, 82, 6,  2, 
    1, 52, 2, 27, 3, 83, 5, 91, 7, 84, 0, 63, 8, 67, 6, 67, 4, 64, 
    8, 18, 3, 73, 7,  5, 4, 79, 2, 26, 0,  8, 5, 91, 6, 18, 1, 93, 
    2, 67, 1, 43, 0, 40, 8, 37, 6, 60, 7, 25, 3, 95, 5, 86, 4, 76
  };
  const int q7923[] = {
    9, 9, // Number of jobs and machines
    6, 31, 2, 85, 5, 89, 7, 31, 1, 30, 3, 62, 8, 24, 0, 16, 4, 12, 
    6, 82, 7, 82, 0, 35, 4, 72, 8,  5, 1, 93, 2, 79, 3, 11, 5, 22, 
    4, 19, 5, 54, 7, 52, 8, 27, 6, 39, 1, 79, 0, 38, 3, 64, 2, 60, 
    3, 46, 6,  3, 7, 12, 5, 71, 4, 14, 2, 25, 8, 89, 0, 55, 1, 16, 
    1, 20, 4, 10, 8, 20, 5, 83, 6, 66, 3, 80, 0, 76, 2, 11, 7, 36, 
    2, 75, 6, 60, 4, 54, 8, 31, 5, 50, 0,  6, 3,  3, 7, 96, 1, 46, 
    1, 38, 8, 17, 7, 50, 6, 74, 2, 59, 5, 56, 3,  3, 4, 59, 0, 20, 
    1, 36, 2, 28, 0, 32, 4, 79, 7, 68, 5, 25, 3, 70, 8, 54, 6, 88, 
    6, 67, 7, 41, 3, 15, 0, 23, 5, 85, 1, 39, 8, 38, 4, 68, 2, 24
  };
  const int q7924[] = {
    9, 9, // Number of jobs and machines
    2, 53, 0, 10, 5, 44, 7, 56, 8, 91, 1, 79, 4, 56, 6, 16, 3, 41, 
    1, 91, 6, 50, 5, 47, 8, 42, 2, 20, 3,  2, 7, 10, 4, 16, 0, 80, 
    6, 14, 0, 62, 4, 14, 8, 49, 7, 67, 2,  6, 3, 32, 5, 55, 1,  3, 
    6, 91, 8, 26, 0, 38, 4, 47, 7, 59, 1, 74, 3, 87, 5, 38, 2,  3, 
    0, 48, 5, 52, 8, 38, 6, 31, 3, 45, 1,  9, 7, 96, 2, 37, 4, 28, 
    2, 17, 1, 52, 7, 79, 3,  5, 5, 22, 4, 66, 0, 60, 6,  4, 8, 89, 
    5, 83, 8, 79, 3, 93, 2, 40, 1, 67, 0, 81, 7, 68, 4, 95, 6, 59, 
    7, 73, 0, 57, 6,  8, 3, 68, 1, 81, 8, 50, 5,  3, 2, 82, 4, 98, 
    1, 90, 8, 89, 4, 48, 6, 88, 3, 53, 0, 49, 2, 49, 5, 74, 7,  2
  };
  const int q7925[] = {
    9, 9, // Number of jobs and machines
    2,  5, 8, 40, 6,  2, 4, 43, 7, 91, 5, 68, 1, 97, 3, 20, 0, 31, 
    1, 70, 6, 67, 0, 65, 8, 98, 7, 55, 5,  1, 2, 95, 4,  2, 3,  3, 
    6, 51, 8, 65, 3, 23, 2, 90, 7, 74, 5, 54, 4, 25, 1, 81, 0, 18, 
    1, 97, 5, 64, 4, 43, 8, 81, 2, 53, 3, 57, 7, 25, 0, 36, 6,  5, 
    2, 47, 8, 87, 6, 23, 0, 80, 3, 68, 7, 45, 1, 65, 4, 43, 5, 51, 
    1, 59, 4, 26, 6, 70, 2, 53, 0, 15, 3, 41, 8, 34, 5, 83, 7, 13, 
    3, 64, 0, 16, 7, 75, 2, 85, 4, 62, 6, 49, 5, 84, 8, 31, 1, 10, 
    7, 91, 1, 94, 8, 75, 5, 67, 3, 79, 2, 41, 0, 76, 4, 90, 6, 45, 
    6, 26, 1, 86, 4, 14, 8, 73, 5, 63, 7, 82, 3, 17, 2, 67, 0,  4
  };
  const int q7926[] = {
    9, 9, // Number of jobs and machines
    0, 28, 4, 14, 8, 95, 6, 77, 7, 24, 2, 38, 5, 15, 1, 48, 3, 49, 
    0, 26, 1, 14, 6, 64, 2, 75, 4, 39, 3, 83, 8, 36, 5, 27, 7, 53, 
    1, 35, 6, 47, 5, 82, 4, 47, 3, 29, 0, 68, 2, 50, 8, 77, 7, 49, 
    3, 41, 5, 31, 7, 81, 1,  1, 0, 29, 2, 23, 4, 49, 8, 62, 6, 31, 
    8, 78, 0, 60, 4, 19, 7, 65, 2, 96, 3,  5, 5, 93, 6, 61, 1, 98, 
    2, 37, 0, 82, 5,  6, 7, 46, 8, 31, 6, 90, 4, 22, 1, 58, 3, 80, 
    2, 86, 3, 26, 5,  8, 0, 16, 7, 86, 1, 74, 8, 47, 4, 19, 6,  6, 
    0, 29, 7, 42, 2, 92, 1, 16, 8, 11, 3,  9, 6,  1, 5, 96, 4, 57, 
    0, 85, 2, 91, 1, 66, 8,  7, 3,  5, 4, 82, 6, 95, 7, 63, 5, 86
  };
  const int q7927[] = {
    9, 9, // Number of jobs and machines
    3, 25, 5, 43, 7, 20, 4,  9, 0,  7, 8, 43, 6, 12, 1, 73, 2, 47, 
    7, 85, 3, 43, 4, 80, 0, 93, 5, 33, 1, 79, 2, 86, 8, 82, 6, 66, 
    1, 42, 5, 73, 3, 40, 2, 20, 4, 88, 7,  6, 0, 64, 6, 70, 8, 46, 
    3, 74, 0, 91, 5, 41, 2, 88, 6, 66, 4, 35, 7, 75, 8, 87, 1, 22, 
    5, 68, 2, 95, 6, 39, 8, 59, 1,  5, 0, 34, 7, 65, 4, 96, 3, 82, 
    0, 24, 1, 27, 3, 73, 6, 77, 8, 77, 2, 92, 7, 13, 4, 34, 5, 38, 
    8,  1, 2, 40, 1, 20, 5, 27, 7, 60, 6, 95, 4, 34, 3, 58, 0, 38, 
    7, 36, 2, 97, 3,  6, 0, 29, 1, 73, 8, 96, 5, 92, 6,  2, 4, 22, 
    0, 14, 5, 18, 7, 85, 4, 29, 6, 63, 2, 49, 3, 58, 1, 29, 8,  5
  };
  const int q7928[] = {
    9, 9, // Number of jobs and machines
    0, 83, 4, 55, 8, 21, 2, 54, 7, 90, 5, 12, 1,  5, 6, 13, 3, 65, 
    6, 59, 2, 53, 7,  8, 4, 85, 1, 90, 5, 61, 0, 78, 8, 63, 3, 55, 
    0, 24, 3, 84, 4, 80, 6, 48, 1,  3, 8, 33, 2, 59, 7, 31, 5, 85, 
    3, 33, 5, 74, 6, 43, 1, 44, 8, 79, 0, 44, 4, 62, 2, 58, 7,  8, 
    4, 37, 8, 92, 7, 96, 1, 33, 5, 56, 0, 95, 6, 59, 2, 19, 3, 47, 
    1, 25, 3, 46, 7, 16, 0, 62, 5, 59, 2, 81, 6, 55, 4,  1, 8, 20, 
    6, 78, 4, 71, 7,  6, 5, 53, 0, 17, 2, 59, 8, 87, 3, 43, 1, 60, 
    4, 24, 8, 38, 7, 41, 1,  1, 2, 18, 6, 94, 3, 98, 0, 26, 5, 24, 
    4, 19, 5, 32, 8, 63, 7,  8, 1, 30, 2, 56, 3, 82, 0, 86, 6, 63
  };
  const int q7929[] = {
    9, 9, // Number of jobs and machines
    1, 18, 8, 77, 6, 51, 2, 45, 5, 43, 4, 51, 7, 14, 3, 79, 0, 41, 
    2, 23, 1, 30, 8, 90, 4, 44, 0, 56, 5,  4, 3, 79, 7, 99, 6, 99, 
    8, 62, 4, 49, 5, 67, 2, 51, 7, 58, 0, 90, 1, 54, 6, 67, 3, 68, 
    4, 70, 5, 65, 7, 25, 0, 70, 3, 42, 2, 74, 6, 18, 1, 93, 8, 44, 
    0, 60, 8, 25, 3, 64, 7, 20, 2, 37, 4, 73, 1, 35, 5, 23, 6, 90, 
    8, 81, 1, 14, 6, 74, 3, 12, 2, 11, 4, 34, 7, 42, 0, 46, 5, 50, 
    4,  9, 8, 62, 7, 93, 1, 60, 2, 82, 3, 18, 6, 79, 5, 17, 0, 70, 
    6, 69, 3, 42, 7, 31, 1,  1, 0, 32, 4, 34, 2,  5, 8,  4, 5, 15, 
    4, 41, 7, 79, 8, 25, 2, 32, 3, 91, 6, 27, 5, 45, 1, 73, 0, 16
  };
  const int q7930[] = {
    9, 9, // Number of jobs and machines
    5, 56, 0,  1, 3, 24, 1, 55, 8, 91, 2, 42, 7, 94, 6, 81, 4, 68, 
    5, 84, 7, 78, 2, 95, 0, 94, 6, 62, 3, 11, 8, 21, 1, 67, 4, 13, 
    7, 36, 8, 53, 5,  2, 2, 79, 1, 79, 3, 39, 6,  1, 0, 96, 4, 46, 
    6, 27, 7, 23, 8, 13, 2, 92, 4, 73, 5, 87, 0, 98, 3, 87, 1, 55, 
    8, 64, 6, 50, 1, 75, 3,  8, 2, 98, 7, 55, 0, 49, 4, 11, 5, 25, 
    4, 43, 6, 80, 3, 77, 7,  8, 5, 34, 1, 86, 8, 45, 2, 75, 0, 54, 
    1,  8, 8, 56, 2, 26, 4,  6, 0, 11, 5, 38, 3,  9, 7, 88, 6, 56, 
    5, 76, 2, 19, 1, 78, 3, 40, 4, 30, 0, 79, 7, 52, 8, 29, 6, 95, 
    5, 73, 6,  9, 0, 76, 7, 39, 2, 97, 4,  8, 8, 62, 1, 24, 3, 43
  };
  const int q7931[] = {
    9, 9, // Number of jobs and machines
    4, 36, 0,  1, 6,  4, 2, 68, 3, 49, 8, 39, 1, 30, 5, 53, 7,  4, 
    4, 66, 5, 78, 3, 56, 0,  2, 8,  8, 7,  1, 6, 67, 2, 84, 1, 72, 
    4, 85, 7, 28, 5, 68, 1, 31, 3, 70, 2,  2, 6, 20, 8, 71, 0, 67, 
    6, 68, 5, 69, 3, 40, 8, 12, 7, 65, 1, 26, 0,  1, 4, 93, 2, 10, 
    3, 75, 5, 28, 6, 14, 4, 66, 1, 77, 2, 63, 7, 13, 8, 65, 0, 60, 
    3, 96, 5, 64, 2, 97, 1, 96, 8, 26, 0, 14, 4, 57, 7, 53, 6, 44, 
    6, 99, 8, 74, 0, 86, 1, 14, 5, 83, 3, 22, 7, 20, 2,  8, 4, 93, 
    5, 65, 6, 82, 7, 58, 8, 51, 0, 92, 1, 29, 3, 13, 4, 71, 2, 52, 
    0, 44, 4, 88, 7, 50, 8, 32, 5, 11, 2, 27, 3, 65, 6, 20, 1, 59
  };
  const int q7932[] = {
    9, 9, // Number of jobs and machines
    1, 16, 0,  9, 3, 41, 4, 38, 6, 68, 5, 67, 7, 67, 2, 82, 8, 76, 
    4, 63, 1,  7, 2, 86, 5, 28, 8,  8, 0, 43, 3, 91, 7, 15, 6, 48, 
    3, 31, 1,  5, 6,  3, 7, 34, 5, 80, 2, 16, 4, 13, 8, 62, 0, 82, 
    0, 77, 1, 79, 4, 31, 8, 88, 2, 77, 5, 74, 6, 73, 7, 90, 3, 27, 
    2, 80, 7, 40, 5, 21, 6, 55, 4, 10, 3, 13, 8, 94, 1, 47, 0, 64, 
    2, 47, 8, 41, 0,  1, 6, 30, 4, 52, 1, 76, 7,  2, 5, 12, 3, 57, 
    5, 34, 6, 89, 2, 33, 8, 59, 7, 30, 1, 42, 3, 97, 4, 44, 0, 75, 
    5, 81, 2, 76, 7, 51, 6, 56, 1, 18, 0, 39, 8, 53, 3, 48, 4, 76, 
    8, 58, 7, 42, 1, 38, 0, 34, 2, 37, 3, 38, 5, 42, 4,  9, 6, 62
  };
  const int q7933[] = {
    9, 9, // Number of jobs and machines
    2, 97, 0, 34, 1, 15, 3, 39, 8, 89, 6, 87, 5, 65, 4, 74, 7, 41, 
    3, 90, 0, 64, 5, 25, 8, 76, 6, 27, 4, 42, 1, 53, 2,  3, 7, 29, 
    1, 38, 5, 19, 8, 97, 4, 58, 2, 43, 0, 94, 6, 58, 3, 24, 7, 98, 
    0, 65, 2, 81, 5, 10, 8, 27, 6, 84, 1, 50, 4, 48, 7, 46, 3, 95, 
    8, 99, 0, 92, 5, 87, 3, 65, 6, 82, 7, 99, 4, 73, 1, 61, 2, 36, 
    7, 26, 6, 50, 5,  5, 0, 94, 8, 92, 4, 14, 1, 62, 2, 98, 3, 76, 
    6, 17, 1, 83, 8, 36, 0, 66, 4, 70, 3,  8, 7, 71, 2, 51, 5, 70, 
    7, 15, 3, 13, 5,  4, 2, 15, 4, 15, 8, 77, 0, 24, 1, 48, 6, 82, 
    8, 47, 4, 69, 1, 71, 3, 62, 6, 15, 0, 55, 7, 15, 5, 21, 2, 93
  };
  const int q7934[] = {
    9, 9, // Number of jobs and machines
    5, 27, 4, 24, 6, 74, 8, 38, 7, 92, 0, 88, 1, 93, 3,  5, 2, 83, 
    1, 52, 4, 39, 7, 39, 2, 43, 6, 50, 3, 29, 8, 10, 0, 33, 5, 88, 
    4, 82, 6, 13, 7, 95, 0, 88, 5, 38, 8, 43, 2, 86, 1, 31, 3, 96, 
    6, 98, 1, 58, 8, 74, 3, 70, 7, 54, 4, 44, 5, 61, 0, 55, 2, 57, 
    1, 28, 7, 96, 4, 23, 6, 12, 0, 82, 5, 18, 2, 33, 3, 84, 8, 46, 
    5, 75, 2, 18, 3, 35, 0, 70, 7, 18, 4, 48, 6, 74, 8, 57, 1, 83, 
    5, 27, 6, 51, 4, 64, 8, 47, 7, 82, 1, 27, 0, 27, 2, 40, 3, 29, 
    6, 82, 7,  6, 2, 79, 3, 93, 5, 19, 8, 52, 0, 36, 4,  7, 1, 85, 
    3, 18, 6, 99, 7, 75, 1, 65, 5, 61, 2, 49, 0, 30, 4, 44, 8, 80
  };
  const int q7935[] = {
    9, 9, // Number of jobs and machines
    7, 36, 6, 82, 3, 38, 2, 68, 1, 13, 4, 36, 0, 33, 5, 40, 8, 55, 
    1, 50, 8, 66, 7, 92, 0, 49, 4, 63, 5, 21, 6,  1, 2, 18, 3,  7, 
    0, 88, 7, 53, 2, 20, 1, 62, 8,  2, 3, 43, 4, 12, 6, 17, 5, 19, 
    0, 21, 5, 40, 7, 89, 6, 46, 8, 81, 1, 93, 2, 89, 3,  2, 4, 61, 
    1, 57, 0, 33, 3, 18, 6, 88, 5, 58, 7, 71, 4,  6, 8, 90, 2, 48, 
    5, 21, 3, 96, 7, 57, 8, 66, 0, 85, 1, 11, 4, 55, 2, 48, 6, 86, 
    6,  1, 2, 48, 0, 70, 3, 73, 4,  8, 8, 61, 7,  4, 1, 71, 5, 67, 
    5, 90, 3, 19, 2, 14, 1, 88, 6, 37, 7, 84, 4, 33, 0, 46, 8, 45, 
    3, 82, 0, 37, 2, 70, 1, 47, 6,  2, 4, 84, 7, 97, 8, 37, 5, 31
  };
  const int q7936[] = {
    9, 9, // Number of jobs and machines
    1, 75, 2, 26, 4, 38, 3, 31, 5, 21, 0, 15, 6, 78, 7,  6, 8, 55, 
    8, 12, 7, 34, 6, 94, 3, 56, 4, 98, 1, 60, 5, 82, 0, 40, 2, 83, 
    0, 18, 2, 72, 6, 88, 7, 20, 1, 15, 5, 48, 4, 12, 3, 97, 8,  6, 
    3, 67, 5, 64, 1, 58, 4, 26, 6, 27, 2, 16, 8, 61, 7, 99, 0, 53, 
    8, 47, 4, 25, 5, 52, 3, 48, 6, 26, 2, 63, 0, 26, 7, 19, 1, 70, 
    1, 22, 5, 95, 0, 92, 4, 73, 7, 65, 3,  2, 2, 41, 8, 46, 6, 76, 
    5, 38, 0, 75, 8, 49, 4, 87, 6,  9, 3, 92, 7, 25, 2, 58, 1, 42, 
    6, 36, 3, 80, 4, 15, 8,  1, 0, 46, 7, 16, 5, 23, 2, 57, 1,  9, 
    6,  1, 2, 31, 8, 81, 1, 18, 3, 91, 5, 81, 7, 80, 0, 29, 4, 57
  };
  const int q7937[] = {
    9, 9, // Number of jobs and machines
    7,  7, 4, 50, 5, 24, 2, 98, 0, 74, 6, 54, 3,  4, 1, 13, 8, 47, 
    8, 45, 0, 99, 2, 19, 6,  9, 7, 21, 5, 59, 3, 64, 4, 84, 1, 50, 
    6, 84, 8, 34, 1, 75, 0, 55, 3, 84, 4, 25, 7, 97, 5, 51, 2,  8, 
    7,  4, 5, 26, 6,  7, 4, 11, 2, 73, 1, 18, 3, 71, 0, 68, 8, 12, 
    5, 22, 3, 20, 0, 41, 7, 37, 2, 30, 1,  1, 6, 81, 8, 24, 4, 21, 
    2, 95, 6, 78, 7, 52, 3, 84, 0, 67, 4, 84, 8, 34, 5, 65, 1, 43, 
    5, 91, 0, 50, 7, 78, 8, 37, 6, 35, 3, 10, 2, 70, 4, 67, 1, 67, 
    3, 11, 8, 23, 4, 35, 0, 21, 6, 34, 1, 29, 2, 95, 7,  1, 5,  2, 
    8,  2, 2, 11, 4, 84, 3, 30, 0, 22, 1, 13, 7, 82, 5, 29, 6, 30
  };
  const int q7938[] = {
    9, 9, // Number of jobs and machines
    1, 34, 6, 76, 3, 14, 2, 29, 5, 67, 8, 79, 0, 10, 7, 92, 4, 22, 
    6, 33, 0, 36, 4, 56, 2, 69, 1, 80, 8, 74, 7, 21, 3, 52, 5,  9, 
    8,  9, 6, 86, 7, 24, 4, 77, 3, 83, 1,  1, 5, 13, 2, 85, 0, 57, 
    8,  3, 2,  1, 3, 89, 5, 74, 4, 86, 6, 63, 7, 46, 1, 15, 0, 95, 
    6, 51, 7, 74, 8, 73, 4, 72, 5, 30, 3,  2, 2, 48, 1,  7, 0, 66, 
    2, 35, 0,  9, 3, 53, 8, 49, 4,  5, 6, 72, 1, 99, 5, 30, 7, 57, 
    6,  2, 0, 77, 4,  7, 1, 75, 7, 35, 5, 36, 3, 78, 8, 41, 2,  6, 
    2, 73, 6, 24, 4, 47, 3, 98, 8, 14, 1, 31, 5, 56, 7, 30, 0, 16, 
    5, 16, 2, 67, 3, 82, 1, 78, 0, 41, 6, 86, 7, 16, 4, 22, 8,  8
  };
  const int q7939[] = {
    9, 9, // Number of jobs and machines
    5, 57, 6,  6, 1, 19, 7, 33, 2, 72, 3, 24, 0, 63, 8, 46, 4, 79, 
    2, 84, 6, 27, 3, 80, 0, 79, 5, 71, 8, 70, 4, 97, 1,  3, 7, 13, 
    6, 26, 1, 54, 5, 79, 2, 68, 4,  7, 8, 84, 0, 40, 7, 18, 3, 33, 
    1, 61, 6, 25, 2, 31, 8, 41, 7, 55, 4, 45, 0, 37, 5, 35, 3, 84, 
    2, 69, 3, 92, 4, 57, 5,  3, 8, 70, 0, 39, 7, 88, 6, 90, 1, 45, 
    8, 44, 0, 63, 2, 58, 5, 14, 1, 60, 4, 99, 3, 64, 7, 90, 6, 18, 
    7, 97, 1, 58, 2, 31, 6, 23, 5, 12, 0, 30, 3, 87, 8, 77, 4, 64, 
    6, 99, 5, 73, 8, 63, 0,  4, 2, 39, 3, 45, 1, 30, 4, 58, 7, 89, 
    6, 57, 8,  1, 5, 60, 2, 75, 1, 15, 0, 19, 4, 86, 7, 46, 3, 85
  };
  const int q7940[] = {
    9, 9, // Number of jobs and machines
    4, 83, 1, 38, 2, 57, 3, 51, 0, 85, 8,  1, 7, 90, 5, 84, 6, 80, 
    6, 51, 4,  5, 0, 26, 7, 11, 2, 50, 3, 92, 1, 14, 8, 52, 5, 35, 
    7, 82, 0, 95, 8, 83, 5, 92, 4, 98, 3, 87, 1, 22, 6, 95, 2, 57, 
    0, 23, 7, 15, 5, 17, 2,  9, 6, 58, 3, 57, 1, 15, 4, 61, 8, 97, 
    2, 78, 8, 84, 7, 24, 1, 31, 4, 23, 6, 36, 0, 64, 3, 55, 5, 37, 
    3, 23, 4, 55, 6, 38, 8, 65, 0, 44, 7, 36, 2, 41, 1, 70, 5, 16, 
    1, 61, 5, 27, 4, 60, 0, 24, 8, 76, 7, 13, 3, 47, 2, 78, 6, 72, 
    2, 12, 4, 51, 1, 29, 6, 87, 3,  4, 5, 16, 7, 24, 0, 25, 8, 99, 
    5,  5, 0, 24, 6,  3, 2, 23, 1, 32, 4, 49, 7, 18, 3, 66, 8,  8
  };
  const int q7941[] = {
    9, 9, // Number of jobs and machines
    0, 89, 1, 26, 5, 63, 2,  8, 6,  4, 8, 53, 3, 54, 7, 45, 4,  6, 
    7, 30, 4, 80, 1, 16, 0, 75, 5, 12, 8, 21, 2, 63, 6, 18, 3, 63, 
    1, 13, 2, 13, 4, 99, 0, 68, 7,  5, 6, 26, 5, 56, 3, 86, 8, 34, 
    3, 53, 0, 48, 2, 90, 4, 13, 6, 73, 1, 88, 7, 74, 8, 52, 5, 79, 
    1, 29, 4, 76, 8, 54, 7,  1, 2, 37, 0, 28, 3, 70, 5, 59, 6, 82, 
    3, 30, 7, 73, 2, 64, 8, 71, 6, 41, 4, 56, 5, 76, 1, 54, 0, 50, 
    2, 80, 8, 73, 1, 54, 0, 91, 7, 65, 5, 14, 4, 36, 6, 62, 3, 81, 
    3, 39, 1, 37, 7, 25, 2, 42, 0, 69, 4, 78, 6, 73, 5, 79, 8, 55, 
    6, 74, 1, 21, 3,  1, 2,  5, 7, 55, 0, 47, 8,  2, 4, 46, 5, 37
  };
  const int q7942[] = {
    9, 9, // Number of jobs and machines
    8, 16, 4, 44, 1, 61, 5, 73, 6, 25, 2, 13, 0, 80, 3, 73, 7, 57, 
    7, 36, 6,  3, 3, 40, 1, 72, 4, 73, 0, 79, 8, 44, 5, 38, 2, 72, 
    6,  9, 1, 66, 4, 69, 3, 24, 2, 86, 5, 65, 8, 29, 0, 99, 7, 94, 
    2, 28, 7, 42, 6, 86, 8, 85, 3, 32, 4,  8, 0, 39, 1, 52, 5, 60, 
    2, 42, 6, 10, 4, 30, 1, 33, 8, 22, 0, 38, 5, 72, 7, 81, 3, 91, 
    4, 79, 5,  1, 2, 89, 0, 84, 7, 58, 3, 66, 6, 57, 1, 83, 8, 86, 
    1, 82, 0, 29, 5, 88, 8, 42, 6, 39, 7,  4, 4, 40, 3, 23, 2, 57, 
    0, 64, 5, 69, 3, 79, 2, 92, 4, 41, 8, 29, 6, 87, 7, 65, 1, 54, 
    2, 89, 5, 80, 3, 95, 8, 91, 0, 79, 1, 99, 7, 82, 4, 65, 6, 69
  };
  const int q7943[] = {
    9, 9, // Number of jobs and machines
    3, 66, 0,  1, 5, 66, 6, 73, 2, 65, 8,  3, 4, 78, 1, 72, 7,  6, 
    7, 19, 8, 99, 0, 60, 1, 46, 4,  2, 6, 55, 5, 37, 2, 95, 3, 59, 
    4, 18, 2, 65, 7, 21, 5, 32, 8,  4, 0, 30, 1, 64, 6, 72, 3, 85, 
    8, 52, 4, 35, 3, 15, 2, 95, 7, 23, 0, 97, 5, 44, 1,  8, 6, 96, 
    8, 43, 4, 17, 7, 28, 3, 53, 2, 19, 0, 94, 5, 50, 6, 76, 1,  4, 
    3, 93, 8, 91, 1, 56, 6, 47, 7, 97, 0, 82, 5, 40, 2, 57, 4,  8, 
    4, 44, 6, 53, 2, 70, 8, 44, 5, 95, 7, 12, 3, 37, 0, 18, 1, 86, 
    7, 17, 0,  3, 5,  2, 6, 83, 1, 72, 4, 62, 2, 10, 8, 92, 3, 44, 
    8, 63, 1, 88, 6,  8, 7, 80, 0, 18, 2, 51, 3, 89, 4, 32, 5, 47
  };
  const int q7944[] = {
    9, 9, // Number of jobs and machines
    7, 93, 2, 72, 1, 17, 6, 92, 0, 63, 8, 73, 5, 26, 4, 53, 3, 49, 
    0, 47, 4,  4, 3, 93, 8, 34, 2, 27, 5, 98, 7, 54, 1, 20, 6, 44, 
    5, 14, 1, 25, 6, 87, 7, 66, 2, 98, 0, 97, 4, 84, 8, 80, 3, 36, 
    6, 54, 4, 89, 0, 61, 7, 94, 2, 31, 3, 38, 8, 14, 5,  3, 1, 68, 
    4, 68, 2, 66, 6, 35, 8, 71, 5, 62, 0, 75, 1,  2, 3, 61, 7, 57, 
    6, 50, 4, 45, 7, 24, 2, 44, 0, 45, 5, 80, 1, 31, 3, 14, 8, 54, 
    7, 18, 2, 41, 1, 42, 0, 76, 3, 13, 8, 66, 6, 77, 5, 26, 4, 55, 
    4, 58, 3, 81, 1, 83, 2,  1, 8, 58, 5, 71, 6, 59, 7, 64, 0, 33, 
    3, 81, 7, 19, 0, 86, 5, 59, 4, 89, 1, 48, 6, 96, 2, 90, 8, 20
  };
  const int q7945[] = {
    9, 9, // Number of jobs and machines
    7, 25, 1,  9, 4, 42, 2, 22, 8, 48, 3, 17, 6, 29, 0, 26, 5,  5, 
    5, 62, 6, 45, 7,  9, 8, 38, 2, 92, 0, 18, 3, 45, 4, 15, 1, 28, 
    0, 96, 6, 40, 7, 64, 8, 25, 2, 72, 5,  8, 1,  9, 3, 51, 4, 55, 
    6, 30, 5, 22, 0, 74, 7, 21, 1, 76, 4, 86, 8, 71, 2, 47, 3, 69, 
    2, 84, 8,  1, 7, 45, 6, 20, 0, 96, 4, 14, 3, 32, 1, 31, 5, 99, 
    3,  7, 1,  7, 2, 69, 8,  4, 6, 89, 7, 30, 5, 75, 0, 17, 4, 66, 
    7, 91, 1,  5, 2, 95, 8, 10, 6, 73, 0, 78, 5, 35, 4, 75, 3, 59, 
    4, 56, 0, 73, 2, 70, 1, 56, 5, 80, 3, 87, 6, 53, 8, 60, 7, 49, 
    8, 47, 2, 36, 0, 99, 6, 45, 1, 58, 4, 57, 5, 75, 3, 29, 7,  5
  };
  const int q7946[] = {
    9, 9, // Number of jobs and machines
    0, 65, 7, 42, 2, 80, 5, 36, 4, 83, 6, 64, 3, 42, 8, 61, 1,  3, 
    3, 25, 2, 91, 8, 22, 1, 10, 4,  7, 0, 61, 5, 53, 7,  3, 6, 53, 
    5, 94, 8, 94, 4, 60, 2, 63, 7, 13, 1, 17, 3, 99, 0, 27, 6, 22, 
    7, 26, 5, 33, 2, 49, 0, 60, 8, 62, 1, 57, 3, 55, 4, 26, 6, 62, 
    4, 32, 2,  5, 0, 85, 6, 24, 5,  9, 8, 22, 7, 73, 3,  9, 1, 54, 
    5, 63, 6,  1, 0,  8, 7, 54, 2, 62, 1, 44, 4, 64, 3, 66, 8, 43, 
    0, 52, 3, 81, 4, 46, 1, 56, 2, 11, 8, 93, 5, 42, 6,  9, 7, 17, 
    4, 26, 3, 83, 5, 18, 8, 61, 2,  6, 0, 87, 6, 24, 7, 47, 1, 71, 
    3, 87, 6, 29, 8, 24, 0, 80, 4, 27, 5, 95, 2, 74, 7, 80, 1, 60
  };
  const int q7947[] = {
    9, 9, // Number of jobs and machines
    7, 42, 6, 69, 5, 68, 0, 11, 3, 95, 2, 14, 1, 32, 4, 57, 8, 11, 
    8,  1, 4, 14, 0, 34, 3, 66, 5, 47, 6,  2, 1, 92, 2, 25, 7, 50, 
    1, 66, 6, 45, 2, 88, 7,  7, 5, 42, 3,  4, 0, 10, 4, 82, 8, 60, 
    5, 47, 6, 17, 2, 44, 1, 87, 8, 66, 4, 29, 0, 36, 7, 40, 3, 75, 
    4, 19, 5, 97, 2, 67, 3, 18, 6, 84, 7, 74, 1, 47, 8, 49, 0, 24, 
    4, 69, 8,  5, 2, 68, 1, 52, 7, 41, 0, 95, 5, 81, 3, 75, 6, 41, 
    4, 86, 5, 24, 8, 82, 2, 67, 6, 84, 7, 82, 0,  2, 1, 80, 3, 31, 
    7, 51, 4, 38, 3, 83, 0, 59, 5, 51, 2, 88, 8, 77, 6, 87, 1, 93, 
    6, 71, 5, 33, 2, 31, 8, 44, 7, 68, 1, 20, 4, 86, 0, 97, 3, 40
  };
  const int q7948[] = {
    9, 9, // Number of jobs and machines
    8, 15, 0, 33, 1, 61, 7, 33, 2,  8, 5, 64, 4, 59, 6, 49, 3, 60, 
    2, 54, 0, 49, 5, 58, 8, 95, 4, 22, 1, 39, 6, 79, 7,  3, 3, 75, 
    2, 92, 5, 49, 4, 88, 8, 40, 3, 57, 7,  3, 6, 32, 0, 84, 1, 90, 
    3, 99, 0, 80, 7, 49, 8, 25, 1, 79, 2, 32, 4, 23, 6, 99, 5, 92, 
    5, 85, 4, 89, 3, 43, 1, 39, 0, 79, 2, 50, 8, 34, 6, 16, 7, 72, 
    2, 26, 8,  1, 7, 18, 1, 97, 5, 74, 0, 12, 3, 29, 6, 88, 4, 97, 
    8, 29, 6, 78, 5, 87, 2, 72, 7, 60, 1, 25, 4,  3, 0, 49, 3, 52, 
    1, 12, 8,  2, 3, 93, 4, 25, 6, 82, 7, 62, 0,  6, 5, 36, 2, 12, 
    6, 71, 8,  5, 3, 82, 4, 57, 7, 45, 5,  5, 0, 32, 2, 83, 1, 97
  };
  const int q7949[] = {
    9, 9, // Number of jobs and machines
    4, 91, 5, 79, 8, 10, 2,  2, 6, 70, 0, 49, 3,  9, 1, 83, 7, 55, 
    2, 48, 7, 27, 5, 53, 6, 83, 3, 73, 0, 76, 4,  7, 1, 40, 8, 17, 
    2, 11, 5, 59, 1, 57, 3, 85, 6, 14, 4, 84, 7, 90, 0, 29, 8, 12, 
    0, 29, 7, 99, 2, 23, 6, 12, 1, 50, 8, 53, 5, 94, 3, 22, 4, 96, 
    8, 22, 7, 91, 0, 87, 6, 20, 5, 33, 2, 99, 4, 29, 3, 62, 1, 57, 
    4, 50, 3,  5, 5, 46, 6, 89, 0, 54, 1, 93, 2, 88, 7, 85, 8, 41, 
    1, 36, 7, 13, 5, 48, 0, 19, 3, 54, 4, 44, 2, 20, 8, 39, 6, 70, 
    1, 51, 0, 19, 2, 85, 6, 14, 4,  7, 8, 39, 7, 80, 5, 96, 3, 68, 
    5, 27, 3, 49, 6, 17, 4, 25, 1, 48, 7, 83, 8, 70, 0, 58, 2, 98
  };
  const int q7950[] = {
    9, 9, // Number of jobs and machines
    4, 75, 2, 22, 0, 15, 8, 95, 6, 71, 5, 70, 7, 94, 3, 43, 1, 77, 
    7, 49, 5, 13, 8,  8, 1, 38, 3, 25, 4, 76, 2, 48, 6,  8, 0, 41, 
    4, 97, 8, 20, 0, 26, 2, 88, 1, 52, 3, 22, 5, 40, 7, 39, 6,  8, 
    1, 39, 2, 42, 3, 25, 7,  4, 4, 47, 8, 68, 6, 51, 0, 18, 5, 13, 
    3, 34, 1, 32, 7, 69, 5, 61, 0, 71, 4, 88, 8,  6, 2, 29, 6, 97, 
    3, 56, 4, 74, 7,  6, 1, 30, 6,  9, 5, 82, 2, 74, 8, 49, 0, 36, 
    7, 53, 0, 73, 6, 84, 4, 39, 5, 53, 8, 58, 3,  8, 2, 99, 1, 70, 
    2, 79, 7, 43, 6, 37, 8, 45, 1, 62, 4,  8, 3, 55, 5, 33, 0, 91, 
    3, 67, 4, 37, 2, 91, 0, 71, 6, 74, 1, 63, 7, 35, 8, 36, 5, 49
  };
  const int q7951[] = {
    9, 9, // Number of jobs and machines
    1, 84, 2, 71, 4, 57, 8, 22, 7,  8, 3, 65, 5, 72, 6, 42, 0, 90, 
    3, 83, 7, 75, 1, 45, 0, 44, 5, 50, 6, 11, 4, 26, 8, 98, 2, 83, 
    1, 43, 6,  7, 4, 10, 7, 81, 2, 72, 0, 40, 3, 90, 5, 88, 8, 89, 
    7, 14, 5, 29, 4, 61, 3, 47, 8, 25, 2, 63, 0, 11, 1, 84, 6, 39, 
    4, 60, 7, 64, 6, 41, 1, 69, 0, 25, 2, 26, 3, 64, 8, 28, 5, 10, 
    8, 35, 2, 81, 0, 47, 6, 55, 7, 37, 4, 99, 5, 98, 1, 10, 3, 74, 
    4, 46, 7, 79, 1, 10, 0, 28, 6, 93, 8, 44, 3, 74, 2, 83, 5, 69, 
    8, 61, 7, 56, 3, 11, 1, 32, 6, 24, 5, 39, 0, 90, 4, 98, 2, 68, 
    6, 56, 2, 48, 5,  4, 8, 92, 1, 86, 0, 42, 7, 43, 3, 53, 4, 67
  };
  const int q7952[] = {
    9, 9, // Number of jobs and machines
    8, 20, 4, 41, 0, 23, 6, 18, 2, 96, 7, 25, 3, 50, 5, 31, 1, 46, 
    2,  7, 7, 27, 3, 80, 8, 58, 5, 39, 0, 65, 4, 28, 1, 23, 6, 30, 
    3, 29, 4, 81, 7, 33, 0, 77, 6, 50, 5, 75, 2, 97, 8, 88, 1, 60, 
    8, 42, 6, 41, 5, 70, 1, 72, 4, 11, 3, 66, 2, 36, 7, 85, 0, 48, 
    1, 28, 4, 88, 7, 15, 5, 77, 8, 84, 2, 28, 0, 60, 6, 80, 3, 95, 
    5, 29, 7, 73, 0, 39, 6, 48, 8, 53, 2, 20, 1, 22, 3, 88, 4, 12, 
    0, 72, 2, 95, 3, 21, 6, 75, 8, 82, 1, 56, 4, 96, 7, 24, 5, 72, 
    5, 95, 7, 51, 6, 58, 8, 62, 1, 54, 4, 36, 2, 49, 3, 12, 0, 28, 
    0,  4, 6, 13, 7, 49, 8, 68, 2, 57, 3, 61, 5, 35, 4, 85, 1, 16
  };
  const int q7953[] = {
    9, 9, // Number of jobs and machines
    1, 63, 8, 28, 4,  5, 0, 81, 2, 28, 3, 82, 7, 40, 6, 88, 5, 66, 
    7,  6, 1, 59, 8, 35, 4, 20, 3, 14, 2, 11, 0, 45, 5, 50, 6, 23, 
    6, 79, 8, 85, 2, 49, 0, 33, 7, 71, 5, 95, 1,  5, 4, 38, 3, 13, 
    3, 23, 4, 24, 7,  4, 0, 29, 6, 21, 5, 28, 2, 69, 1, 58, 8, 68, 
    1, 23, 4, 10, 7, 49, 3, 11, 6,  2, 0,  5, 5, 68, 8,  2, 2, 38, 
    3, 37, 7, 66, 4, 76, 0, 18, 6, 73, 2, 92, 5, 86, 1, 73, 8, 21, 
    0, 51, 6, 46, 1, 18, 8, 79, 7, 75, 5, 76, 4, 98, 2,  6, 3, 60, 
    3, 99, 6, 25, 4, 88, 2,  9, 5,  9, 1, 34, 7, 81, 8, 62, 0, 33, 
    8, 14, 4,  7, 1, 14, 6, 80, 2, 42, 5, 99, 3, 18, 7, 70, 0, 48
  };
  const int q7954[] = {
    9, 9, // Number of jobs and machines
    3, 33, 5, 48, 2, 48, 4, 13, 6, 77, 8, 46, 0, 85, 1,  4, 7, 47, 
    3, 42, 8, 71, 7, 55, 6, 52, 2, 56, 0,  5, 4, 43, 1, 49, 5, 87, 
    3, 16, 6, 12, 0, 10, 8, 96, 1,  5, 2, 34, 4, 21, 5, 70, 7, 85, 
    1, 69, 2, 38, 8, 94, 3,  7, 7, 20, 6, 33, 4, 50, 5, 66, 0, 90, 
    3, 16, 4, 89, 2, 45, 0, 10, 7, 48, 6, 90, 8, 33, 1, 69, 5, 90, 
    2, 15, 7, 23, 3, 64, 0, 39, 8, 46, 4, 46, 5, 57, 6, 89, 1, 15, 
    1, 88, 8, 25, 0, 91, 6,  5, 2, 49, 4, 41, 5, 31, 3, 99, 7,  4, 
    2, 82, 6, 47, 4, 70, 8, 49, 1, 93, 0,  6, 3, 32, 7, 12, 5, 69, 
    1, 91, 2, 21, 3, 58, 7, 39, 8, 14, 5, 91, 4, 62, 6,  3, 0, 44
  };
  const int q7955[] = {
    9, 9, // Number of jobs and machines
    1, 63, 8, 36, 2, 30, 0, 97, 5, 24, 4, 75, 6, 39, 7,  8, 3, 21, 
    2, 92, 0,  5, 8, 94, 7, 26, 1, 33, 4, 65, 5, 82, 6, 18, 3, 93, 
    8, 89, 3, 45, 6, 66, 2, 81, 5, 42, 1,  1, 4, 37, 7,  9, 0, 89, 
    4, 87, 2, 62, 3, 18, 1, 43, 8,  7, 6, 45, 7, 69, 0, 75, 5, 32, 
    8, 61, 5, 22, 3, 82, 1, 52, 6, 90, 7, 56, 4, 50, 0, 64, 2, 57, 
    8, 25, 1, 78, 6, 68, 5, 75, 7, 21, 4, 89, 3,  5, 2, 34, 0, 93, 
    5, 36, 0, 23, 4, 43, 7, 10, 3, 23, 2, 66, 1, 80, 8, 24, 6, 69, 
    7, 16, 4, 79, 0, 33, 2,  8, 8, 78, 1, 71, 5, 76, 6, 62, 3, 18, 
    6, 60, 4, 41, 5, 31, 3, 92, 1, 78, 0, 21, 7, 75, 8, 91, 2, 85
  };
  const int q7956[] = {
    9, 9, // Number of jobs and machines
    8, 57, 5, 35, 1, 27, 4,  7, 2, 39, 7, 47, 0, 73, 3, 61, 6, 35, 
    0, 37, 5, 93, 7, 34, 1, 76, 4, 43, 8,  6, 6, 91, 2, 27, 3,  9, 
    2, 89, 8, 47, 4, 21, 0, 42, 1, 89, 7, 94, 6, 90, 3, 30, 5, 41, 
    8, 45, 4, 92, 6, 89, 2, 83, 0, 95, 1,  7, 7, 57, 3, 53, 5, 38, 
    4, 55, 7, 24, 0, 45, 8, 70, 2, 62, 3, 92, 5, 99, 6, 83, 1, 99, 
    4, 55, 7, 98, 2, 33, 3, 86, 5, 93, 6, 44, 1, 46, 8, 36, 0,  2, 
    2, 21, 1, 82, 3, 64, 8, 45, 0, 50, 5, 99, 7,  4, 6, 28, 4, 94, 
    5, 11, 1, 73, 7, 12, 8, 31, 0, 93, 4, 46, 3,  9, 6, 20, 2, 86, 
    2, 72, 7,  6, 3, 38, 4, 98, 6,  6, 5, 85, 8,  9, 1, 36, 0, 76
  };
  const int q7957[] = {
    9, 9, // Number of jobs and machines
    0, 51, 6, 44, 3, 86, 1, 75, 2, 28, 7, 39, 4,  7, 8, 60, 5, 47, 
    5, 92, 3, 94, 6, 71, 4, 20, 2,  1, 7, 18, 8, 55, 0, 62, 1, 13, 
    7, 56, 8, 11, 3,  9, 6, 50, 5, 14, 1, 83, 4, 29, 0, 84, 2, 59, 
    8, 51, 0, 94, 5, 75, 7, 43, 6, 56, 4, 16, 3, 71, 1, 96, 2, 60, 
    2, 29, 4, 67, 7, 11, 5, 94, 0, 38, 1, 24, 8, 33, 3, 47, 6, 21, 
    8, 84, 5,  3, 6,  1, 3,  2, 1, 69, 4, 29, 7, 32, 2, 51, 0, 90, 
    3, 20, 2, 36, 6, 65, 1, 36, 7, 22, 4, 66, 8,  6, 0, 70, 5, 84, 
    6, 91, 3, 48, 7, 62, 8, 14, 1, 43, 4, 90, 0, 60, 2, 20, 5,  8, 
    7, 73, 3, 44, 6, 44, 8, 27, 2, 30, 4, 81, 5, 36, 1, 70, 0, 57
  };
  const int q7958[] = {
    9, 9, // Number of jobs and machines
    4,  2, 7, 12, 5, 50, 6, 51, 3, 67, 1, 71, 8,  2, 2, 36, 0, 61, 
    1, 16, 3, 28, 4, 44, 5, 94, 6, 43, 7, 36, 2, 57, 0, 26, 8, 53, 
    5, 57, 3, 36, 7, 49, 0, 62, 8, 73, 2, 96, 6, 55, 4, 54, 1, 78, 
    5, 32, 0, 42, 4, 85, 3, 29, 2, 21, 7, 47, 8,  3, 6, 41, 1, 98, 
    8, 64, 1, 74, 7, 73, 4, 25, 5, 34, 2, 90, 0, 40, 3, 71, 6,  4, 
    2, 22, 8, 37, 5, 50, 1, 86, 0, 71, 6, 35, 3, 52, 4, 86, 7, 47, 
    0, 13, 4, 14, 8, 66, 5, 73, 6, 59, 2, 53, 1, 83, 3, 74, 7, 78, 
    1,  2, 3, 48, 4, 28, 5, 91, 6, 47, 8, 77, 0, 36, 2,  2, 7,  1, 
    4, 26, 2, 49, 0,  5, 5, 86, 1, 54, 8, 58, 7, 71, 6, 22, 3, 73
  };
  const int q7959[] = {
    9, 9, // Number of jobs and machines
    6, 43, 3,  2, 4, 46, 1, 43, 5, 78, 7, 37, 2, 60, 0, 99, 8, 92, 
    0, 64, 4, 85, 6,  9, 8, 12, 7, 24, 5, 29, 1, 86, 2, 91, 3, 65, 
    1, 91, 0, 79, 2,  3, 6, 41, 4, 28, 3, 78, 5, 35, 8, 48, 7, 56, 
    8, 37, 1,  3, 0, 31, 7, 22, 3,  2, 4, 18, 2, 85, 6,  4, 5, 96, 
    5, 62, 6, 72, 8, 31, 3, 27, 1, 35, 2, 80, 0, 83, 7, 21, 4, 67, 
    8, 82, 4, 52, 7, 96, 0, 56, 3, 91, 6, 58, 1, 20, 2, 48, 5, 31, 
    1, 23, 5, 28, 3, 34, 7, 58, 6, 59, 0, 36, 2, 55, 4, 54, 8, 14, 
    2,  7, 3, 30, 1, 92, 8, 84, 6, 84, 4, 46, 7, 96, 5, 63, 0, 43, 
    6, 22, 4, 91, 2, 18, 8, 86, 1, 70, 0, 75, 3, 24, 7, 50, 5, 70
  };
  const int q7960[] = {
    9, 9, // Number of jobs and machines
    1, 57, 2, 34, 8, 28, 6, 73, 4, 58, 7, 12, 5, 83, 0, 17, 3, 24, 
    5, 10, 6, 98, 1, 38, 0, 95, 2, 24, 3, 87, 7, 68, 4, 93, 8,  8, 
    7, 18, 6,  6, 5, 53, 1, 92, 3, 58, 0, 83, 2, 96, 8, 81, 4, 56, 
    2, 71, 6, 39, 5, 32, 8, 49, 7,  3, 1, 99, 0, 95, 3, 67, 4, 98, 
    1,  2, 0, 23, 4, 69, 5, 18, 2,  9, 7,  3, 6, 77, 8,  7, 3, 11, 
    2, 83, 8, 59, 7, 31, 5, 34, 3, 92, 1, 26, 4, 33, 0, 75, 6,  4, 
    8, 64, 4, 63, 3, 94, 7, 44, 0, 87, 2, 19, 5, 30, 1, 60, 6, 70, 
    0, 25, 7, 20, 3, 51, 4, 36, 1, 41, 5,  7, 6, 53, 2, 86, 8, 73, 
    0, 13, 1, 11, 2, 37, 8, 66, 4, 21, 5, 71, 3, 56, 7, 10, 6, 82
  };
  const int q7961[] = {
    9, 9, // Number of jobs and machines
    4, 59, 7,  2, 6, 68, 3, 67, 8, 42, 1, 34, 5, 37, 2, 36, 0, 42, 
    0, 19, 3, 77, 4, 29, 1, 72, 7, 22, 2, 99, 6, 85, 5, 38, 8, 11, 
    4,  3, 1, 68, 7, 68, 6,  4, 0, 12, 8, 52, 2, 66, 5, 99, 3, 51, 
    0,  8, 6, 73, 5, 23, 8, 22, 7, 44, 4, 30, 3, 87, 1, 55, 2, 38, 
    1,  8, 0, 20, 4, 83, 5, 71, 3, 75, 7, 65, 6, 87, 8, 41, 2, 11, 
    1, 60, 7, 17, 8, 56, 4, 58, 2, 21, 6, 96, 5, 70, 0, 72, 3, 68, 
    2,  2, 1,  8, 4, 66, 8, 63, 6, 54, 3, 31, 5, 69, 7, 77, 0, 81, 
    4, 46, 2, 14, 5, 94, 7, 49, 6, 86, 1, 65, 0, 18, 3, 65, 8, 21, 
    8, 33, 1, 90, 7, 74, 5, 92, 2, 92, 3, 24, 4,  2, 6, 68, 0, 72
  };
  const int q7962[] = {
    9, 9, // Number of jobs and machines
    6, 66, 4, 42, 5, 29, 8, 61, 3,  5, 0, 17, 7, 99, 2, 72, 1, 51, 
    7, 59, 0, 95, 5, 53, 3, 27, 1, 72, 2, 68, 4, 79, 8, 91, 6, 24, 
    1, 17, 3, 87, 8, 12, 0, 70, 2, 92, 6, 16, 5, 88, 4, 88, 7, 59, 
    0, 14, 7, 12, 8, 35, 2, 84, 4, 21, 3, 46, 6,  1, 1, 78, 5, 30, 
    5, 58, 7, 28, 8, 59, 0, 65, 1, 42, 3, 56, 2, 87, 4, 31, 6, 34, 
    4, 44, 1, 36, 2, 20, 8, 53, 6, 31, 5,  6, 0, 26, 3, 15, 7, 51, 
    4, 78, 5, 30, 1, 51, 0, 19, 3, 25, 8,  1, 6, 41, 7, 27, 2, 52, 
    6, 46, 3, 78, 5, 11, 8, 82, 1, 53, 2, 81, 0, 55, 4, 56, 7, 91, 
    0, 10, 8,  6, 5, 10, 2, 69, 1, 95, 4, 72, 7, 77, 6, 87, 3, 82
  };
  const int q7963[] = {
    9, 9, // Number of jobs and machines
    6, 67, 0,  3, 5, 41, 7,  1, 4, 55, 8, 27, 3, 30, 2, 60, 1, 98, 
    3,  7, 7, 92, 0, 52, 4, 15, 6, 62, 2, 61, 8,  3, 1, 11, 5, 56, 
    3,  7, 4, 72, 1, 13, 7, 61, 6, 18, 0, 22, 2, 79, 5, 89, 8, 67, 
    6, 52, 2,  1, 3, 73, 7, 40, 0,  3, 1, 96, 4, 38, 5, 27, 8, 23, 
    1, 74, 2, 59, 7,  2, 8,  1, 0,  9, 5, 73, 3, 70, 6, 21, 4, 91, 
    2, 70, 3, 22, 7, 39, 5, 44, 1, 13, 4,  5, 0, 76, 8, 13, 6, 64, 
    4, 69, 6, 48, 5,  3, 7, 35, 2, 97, 1, 20, 3,  3, 8, 60, 0, 79, 
    7, 92, 5, 10, 8, 45, 6, 16, 2, 62, 3, 26, 0,  6, 4, 78, 1, 93, 
    7, 89, 3, 32, 5,  4, 6, 89, 1, 28, 2, 78, 0, 41, 4, 50, 8, 35
  };
  const int q7964[] = {
    9, 9, // Number of jobs and machines
    4, 62, 2, 71, 6,  9, 8, 31, 7, 86, 3, 45, 0, 30, 5, 31, 1, 58, 
    3, 18, 7, 18, 1,  1, 2, 26, 6, 90, 4, 93, 0, 65, 5, 34, 8, 41, 
    3, 18, 1, 81, 5, 16, 8, 67, 2, 64, 7, 65, 4, 12, 6, 51, 0, 55, 
    0, 50, 3, 40, 1, 47, 2, 74, 8, 47, 6,  2, 7, 65, 4, 81, 5, 59, 
    3, 46, 8, 76, 5, 71, 4, 66, 7, 94, 1,  2, 0, 85, 2, 84, 6, 32, 
    3, 86, 0, 86, 6, 82, 8, 66, 1, 41, 5, 83, 4, 51, 2, 46, 7, 94, 
    7, 86, 5, 46, 8, 78, 4, 84, 1, 43, 3, 52, 0, 28, 6, 94, 2, 65, 
    8, 79, 7, 91, 0, 54, 2, 33, 4, 72, 5,  6, 3, 75, 1, 56, 6, 15, 
    7, 78, 0, 78, 3, 26, 8, 49, 6, 74, 2, 30, 4, 72, 1, 23, 5, 13
  };
  const int q7965[] = {
    9, 9, // Number of jobs and machines
    2, 53, 0, 17, 5, 38, 4, 79, 6, 88, 1, 92, 3, 80, 7, 45, 8, 11, 
    2, 83, 7, 30, 8, 63, 3, 10, 1, 89, 6, 17, 0, 38, 4, 76, 5, 76, 
    2, 65, 7, 99, 4, 93, 5, 57, 0, 11, 1, 66, 8, 52, 3,  9, 6, 61, 
    1, 63, 3,  4, 5, 88, 7, 16, 4, 45, 6, 40, 8, 85, 0, 25, 2, 43, 
    5, 44, 3, 80, 8,  8, 1, 99, 2, 97, 0, 79, 7, 80, 4, 58, 6,  2, 
    8, 62, 2,  1, 0, 46, 4, 56, 7, 68, 6, 94, 3, 38, 5,  5, 1, 71, 
    3, 18, 2, 44, 1, 75, 4, 84, 5, 35, 8, 73, 0, 13, 7, 50, 6, 42, 
    7, 74, 5, 92, 8, 54, 4, 20, 1, 14, 6, 51, 2,  3, 3, 66, 0, 72, 
    4, 29, 3, 94, 2, 77, 7, 61, 6, 68, 5, 53, 1, 77, 0, 11, 8,  1
  };
  const int q7966[] = {
    9, 9, // Number of jobs and machines
    0, 99, 3, 54, 6, 21, 5, 51, 7, 52, 2, 10, 1, 19, 8, 58, 4, 93, 
    4, 14, 8, 26, 3, 23, 2, 38, 0, 18, 6,  9, 1,  1, 5,  1, 7, 79, 
    8, 47, 1, 54, 7, 81, 3, 23, 2, 48, 4, 42, 5, 43, 6, 11, 0, 22, 
    4, 27, 1, 71, 5, 25, 3, 23, 2, 62, 6, 47, 0,  7, 8, 78, 7, 21, 
    2, 96, 6, 28, 8, 11, 4, 34, 0, 34, 5, 70, 7, 34, 3, 56, 1, 19, 
    4, 88, 7, 51, 2, 53, 1,  9, 0, 33, 8, 43, 5, 29, 6, 39, 3, 92, 
    1, 73, 7, 89, 6, 97, 8, 53, 3, 27, 4, 13, 0, 10, 5, 29, 2, 51, 
    7, 50, 4, 21, 0, 13, 8, 37, 2, 39, 6,  2, 5, 45, 3, 16, 1, 31, 
    1, 89, 0, 10, 6, 97, 8, 40, 2, 60, 4, 46, 3, 57, 5, 40, 7, 10
  };
  const int q7967[] = {
    9, 9, // Number of jobs and machines
    3, 77, 6, 65, 2, 76, 8, 88, 0, 45, 5, 85, 4, 85, 1, 70, 7, 49, 
    0, 98, 8, 82, 3, 93, 4, 43, 2,  2, 1, 78, 6, 78, 7, 40, 5, 87, 
    7, 43, 1, 37, 2, 38, 6, 15, 3, 64, 0, 73, 5, 54, 8, 92, 4, 45, 
    2, 10, 5, 78, 3, 95, 1,  7, 6,  3, 7, 94, 4, 11, 8, 12, 0, 22, 
    7, 39, 0, 37, 5, 53, 8, 29, 6, 36, 3, 11, 1, 90, 2, 31, 4, 91, 
    0, 79, 7, 97, 8, 70, 3, 10, 6,  7, 1, 72, 4, 32, 5, 29, 2,  4, 
    0, 58, 5, 16, 2, 17, 8,  6, 3, 65, 6, 73, 1,  8, 4, 33, 7, 30, 
    1, 11, 0, 49, 5, 22, 8, 89, 2, 17, 3, 38, 4, 27, 7, 73, 6,  4, 
    5, 63, 4, 51, 3, 65, 2, 86, 0,  4, 1, 31, 6, 13, 8, 91, 7, 76
  };
  const int q7968[] = {
    9, 9, // Number of jobs and machines
    4, 88, 0,  1, 6, 19, 3, 59, 8, 68, 7, 82, 1, 96, 5, 22, 2, 73, 
    5, 47, 0, 70, 6, 15, 1, 39, 3, 23, 2,  7, 8, 83, 4, 69, 7, 96, 
    4,  5, 1, 70, 6, 38, 0, 85, 7,  9, 8, 38, 3, 93, 5, 23, 2, 46, 
    0, 89, 6, 44, 4, 48, 3, 40, 7, 55, 5, 30, 8, 93, 2, 93, 1, 73, 
    6,  6, 0,  3, 7, 24, 5, 56, 1, 27, 4, 36, 3, 54, 2, 15, 8, 57, 
    3, 39, 7, 97, 2, 88, 1, 90, 8, 34, 0, 59, 5, 75, 6, 58, 4, 59, 
    1, 80, 4, 11, 6, 13, 3, 11, 0, 60, 8, 42, 5, 63, 2, 65, 7, 18, 
    2, 17, 5, 87, 4, 32, 8, 74, 0, 73, 6, 46, 1, 79, 3,  5, 7, 86, 
    4, 26, 2, 33, 6, 28, 5, 55, 1, 48, 3, 13, 7, 24, 0, 93, 8,  8
  };
  const int q7969[] = {
    9, 9, // Number of jobs and machines
    1, 34, 3, 54, 4, 27, 7, 20, 2, 32, 5, 34, 0, 88, 8, 21, 6, 47, 
    1, 17, 5, 50, 7, 17, 0, 73, 2, 30, 3, 36, 6, 36, 8, 93, 4, 66, 
    2, 91, 7, 63, 8,  7, 1, 24, 5, 85, 0, 98, 4, 49, 3, 73, 6, 70, 
    0, 29, 1, 35, 5,  2, 6,  9, 4,  5, 7,  3, 8, 17, 2, 96, 3, 44, 
    7, 73, 0, 56, 8, 65, 4, 89, 2, 80, 1, 29, 6, 22, 5, 10, 3, 39, 
    4, 72, 5, 66, 7, 55, 0, 31, 1, 15, 2, 98, 6, 23, 8, 38, 3, 84, 
    0, 16, 6, 61, 3, 87, 1, 48, 4, 46, 7, 18, 5, 44, 2, 29, 8, 69, 
    8, 12, 5, 68, 2, 22, 4, 52, 7,  3, 6, 38, 0, 31, 1, 90, 3, 94, 
    4, 22, 0,  9, 3, 59, 8, 96, 2,  4, 1, 27, 6,  3, 7, 25, 5, 11
  };
  const int q7970[] = {
    9, 9, // Number of jobs and machines
    2, 70, 8, 44, 4, 70, 5, 98, 0, 49, 7, 83, 1, 30, 6, 57, 3, 51, 
    3, 35, 7, 18, 6, 15, 0, 14, 4, 88, 5, 85, 1, 77, 8, 78, 2, 12, 
    7, 99, 5, 42, 4, 73, 3, 56, 8, 30, 1, 55, 0,  1, 2,  2, 6, 44, 
    1, 85, 2, 67, 3, 81, 4, 20, 0, 69, 8, 18, 5, 81, 6,  2, 7, 91, 
    1, 32, 3, 13, 2, 24, 6, 32, 8, 18, 7, 69, 5, 21, 4, 98, 0, 74, 
    8, 57, 1, 94, 3, 18, 6, 90, 2, 30, 7, 99, 4, 98, 0, 74, 5, 42, 
    0, 60, 6, 92, 1, 98, 8, 46, 3, 76, 5, 70, 4, 18, 7, 41, 2, 90, 
    0, 42, 6, 43, 3, 15, 7, 47, 2, 65, 5, 21, 8, 27, 1, 22, 4, 30, 
    1, 33, 3, 84, 8, 19, 0, 33, 2, 79, 5, 11, 4, 40, 7, 18, 6, 25
  };
  const int q7971[] = {
    9, 9, // Number of jobs and machines
    2, 28, 1, 24, 3, 26, 4,  5, 8,  9, 5,  8, 0, 26, 6, 14, 7, 12, 
    2, 72, 8, 59, 4, 95, 6, 12, 5, 23, 1, 13, 0, 88, 7, 18, 3, 42, 
    0, 95, 2, 28, 1, 84, 6, 31, 4, 92, 7, 93, 8, 77, 5, 80, 3, 35, 
    5, 63, 0, 51, 3, 46, 7, 98, 2, 30, 4, 20, 8,  7, 1, 21, 6, 44, 
    0, 62, 1, 77, 4, 31, 2, 96, 3, 52, 5, 31, 8,  8, 6, 10, 7, 60, 
    3, 48, 6, 25, 8, 45, 2, 23, 4, 22, 1, 76, 7, 71, 0, 66, 5, 34, 
    7, 78, 5, 87, 0, 74, 1, 12, 6, 77, 3, 42, 2, 47, 8, 45, 4, 97, 
    7, 63, 2,  8, 0, 49, 4, 54, 5, 86, 3, 98, 1, 24, 6, 19, 8, 80, 
    8, 99, 3, 40, 1, 68, 2, 94, 4, 33, 7, 64, 6, 39, 5, 99, 0, 29
  };
  const int q7972[] = {
    9, 9, // Number of jobs and machines
    1, 48, 3, 82, 7, 50, 8, 86, 6, 89, 0,  8, 4, 67, 5, 23, 2, 28, 
    2, 84, 5, 58, 8, 25, 7, 48, 0, 87, 1, 23, 3, 22, 6,  4, 4, 15, 
    2,  1, 1, 83, 0, 41, 6, 69, 5, 61, 7, 71, 4, 10, 8,  2, 3, 14, 
    7, 27, 2, 70, 1, 42, 4, 37, 8, 37, 5, 75, 0, 14, 3, 31, 6, 10, 
    0, 59, 4, 84, 3, 31, 6, 78, 7,  7, 5, 34, 8, 78, 1,  9, 2, 41, 
    1, 94, 2, 68, 7,  1, 6, 81, 0, 62, 5,  8, 8,  4, 4, 93, 3, 43, 
    2, 40, 0, 30, 7, 78, 5, 91, 1, 86, 4, 55, 8, 82, 6, 87, 3, 87, 
    6, 22, 3,  9, 2, 81, 8, 42, 0, 90, 7, 50, 4, 31, 5, 94, 1, 29, 
    2, 17, 1, 45, 8, 49, 5, 62, 7, 46, 0, 16, 3, 74, 6, 79, 4,  8
  };
  const int q7973[] = {
    9, 9, // Number of jobs and machines
    0, 36, 6, 61, 7,  9, 5, 73, 3, 76, 4, 59, 2, 16, 1, 74, 8, 44, 
    3, 31, 8, 65, 0, 57, 1, 47, 5, 73, 6, 18, 2,  7, 7,  7, 4, 98, 
    4, 69, 0,  1, 6,  7, 1, 75, 7, 88, 2, 73, 8, 61, 5, 83, 3, 74, 
    7, 78, 5, 16, 4, 25, 3, 28, 8, 23, 2, 44, 6, 41, 1, 69, 0, 71, 
    7, 19, 1, 54, 4, 34, 8, 32, 0, 22, 3, 50, 6, 96, 5, 45, 2, 50, 
    2, 73, 0, 55, 6, 14, 1, 32, 7, 81, 4, 15, 8, 19, 5, 24, 3,  6, 
    6, 96, 2, 99, 0, 36, 8, 62, 3, 26, 1, 26, 5, 36, 4, 88, 7, 43, 
    7, 29, 4, 50, 6, 79, 2, 93, 5, 60, 0, 99, 3, 98, 8, 30, 1, 15, 
    4, 27, 0, 54, 8, 97, 6, 34, 2, 85, 5,  5, 3, 24, 7, 73, 1, 10
  };
  const int q7974[] = {
    9, 9, // Number of jobs and machines
    8,  7, 4, 14, 2, 47, 3, 97, 6, 87, 0, 68, 5, 51, 1, 67, 7, 95, 
    6, 35, 7, 15, 2, 45, 5, 22, 0, 84, 3, 25, 1, 26, 4,  5, 8, 59, 
    5, 58, 6, 52, 1, 74, 4, 27, 0, 99, 8, 61, 3,  9, 7, 10, 2, 59, 
    0, 16, 1, 73, 8, 51, 7, 97, 5, 28, 6, 71, 3, 49, 2, 21, 4, 50, 
    2,  9, 3, 50, 6, 37, 1, 49, 5, 43, 7, 57, 4, 66, 0, 98, 8, 71, 
    7, 37, 0, 87, 4, 19, 6, 42, 5, 44, 3, 93, 8, 10, 2, 42, 1, 49, 
    8, 93, 4, 44, 6, 36, 2,  8, 5, 70, 3, 33, 7,  6, 0, 10, 1, 28, 
    6, 24, 0, 22, 1, 68, 8, 46, 7, 98, 5, 38, 4, 52, 2, 48, 3, 76, 
    2,  5, 0, 68, 6, 93, 1, 52, 3, 26, 4, 46, 5, 89, 8,  4, 7, 33
  };
  const int q7975[] = {
    9, 9, // Number of jobs and machines
    8, 24, 5,  4, 0, 96, 1, 95, 4, 24, 6, 20, 7, 45, 2, 57, 3, 79, 
    0, 57, 5, 57, 2, 36, 1, 73, 7, 11, 3, 92, 4, 23, 8, 86, 6, 44, 
    7, 98, 2, 27, 4, 65, 3, 86, 8, 78, 5, 45, 0,  4, 1, 70, 6,  1, 
    8, 93, 4, 23, 2, 20, 3, 91, 7, 75, 6, 26, 0, 13, 1, 71, 5, 41, 
    8, 46, 0, 11, 2,  7, 6, 86, 4, 76, 1, 64, 7, 31, 5, 97, 3, 36, 
    4, 31, 6, 55, 2, 32, 7, 41, 0, 64, 1, 43, 8, 25, 3, 55, 5, 26, 
    5, 52, 2, 51, 0, 97, 4, 19, 7, 24, 6, 62, 1, 80, 8, 48, 3, 65, 
    8, 31, 3, 52, 7, 79, 0, 16, 2,  3, 5, 52, 4, 56, 1, 35, 6, 84, 
    8, 90, 1, 89, 3, 76, 6,  7, 2,  8, 5, 43, 7, 65, 4, 91, 0, 80
  };
  const int q7976[] = {
    9, 9, // Number of jobs and machines
    2, 95, 8, 21, 4, 10, 5, 37, 6, 89, 7, 91, 1, 63, 3, 52, 0, 16, 
    1, 77, 2, 36, 6, 13, 5, 79, 4, 63, 0, 34, 8, 64, 3, 19, 7, 21, 
    4, 33, 1, 80, 2, 79, 7, 67, 6, 17, 8, 94, 3,  7, 0, 49, 5, 55, 
    1, 83, 5, 73, 8, 88, 3, 65, 4, 74, 2, 86, 7,  9, 6, 39, 0, 72, 
    5, 68, 8, 18, 2, 65, 7, 97, 6, 93, 4,  4, 3, 95, 0, 98, 1, 10, 
    0, 90, 6,  3, 8, 21, 3, 58, 2, 28, 1, 67, 4, 96, 7, 55, 5,  3, 
    8, 44, 1, 32, 2, 61, 3, 44, 0,  9, 4, 56, 6, 75, 7, 26, 5, 26, 
    0, 71, 1, 45, 8, 19, 3, 45, 2, 20, 6, 60, 5, 70, 4, 89, 7, 19, 
    0, 70, 4, 60, 5, 61, 7, 36, 6, 81, 1, 37, 2, 97, 3, 92, 8, 84
  };
  const int q7977[] = {
    9, 9, // Number of jobs and machines
    3,  8, 8, 84, 2, 56, 0, 89, 6, 28, 1,  6, 7, 36, 5,  7, 4, 96, 
    3, 29, 0, 48, 7, 59, 8, 83, 1, 50, 5, 95, 6, 31, 2, 94, 4, 98, 
    1, 27, 8, 56, 2, 55, 6, 78, 5, 19, 7, 66, 3,  3, 4, 80, 0, 57, 
    2, 32, 0, 29, 4, 21, 6, 44, 1, 33, 3, 30, 7, 55, 8, 87, 5, 26, 
    2, 77, 4, 25, 7, 40, 3, 24, 1,  1, 5, 31, 0, 42, 6, 77, 8, 93, 
    3, 17, 6, 44, 1, 58, 8,  9, 7, 28, 0, 68, 5, 62, 2, 75, 4, 78, 
    3, 59, 0, 75, 4, 32, 1, 65, 5, 66, 7, 83, 8, 87, 2, 84, 6, 23, 
    5, 49, 1, 93, 3, 70, 6,  2, 0, 39, 8, 98, 2, 81, 4, 61, 7, 38, 
    4,  8, 0, 65, 6, 65, 7, 28, 3, 69, 8, 63, 1,  4, 2, 75, 5, 66
  };
  const int q7978[] = {
    9, 9, // Number of jobs and machines
    8, 77, 5, 48, 0, 20, 2, 77, 3, 45, 1, 19, 7, 22, 6, 71, 4, 32, 
    0, 44, 2, 33, 8, 83, 7, 69, 6, 47, 5, 32, 3, 16, 1, 41, 4, 64, 
    1, 32, 8, 22, 5, 87, 2,  4, 6, 83, 4, 90, 3, 51, 7, 71, 0, 25, 
    3, 51, 8, 72, 7, 77, 5, 57, 2, 99, 4, 70, 1, 84, 0, 74, 6, 82, 
    7, 79, 2, 67, 3, 73, 5, 20, 6, 22, 0, 31, 1, 19, 8, 67, 4, 77, 
    6, 22, 5, 73, 8, 85, 2, 18, 1, 65, 3,  6, 7, 53, 0, 75, 4, 73, 
    7, 13, 5, 90, 2, 39, 4, 39, 6, 25, 8, 35, 0, 24, 3, 62, 1, 24, 
    7, 53, 4, 29, 0, 47, 2,  6, 1, 37, 6, 86, 5, 13, 3, 54, 8, 43, 
    4, 65, 3, 30, 0, 38, 7, 85, 8, 35, 1,  6, 6, 35, 5,  2, 2, 92
  };
  const int q7979[] = {
    9, 9, // Number of jobs and machines
    4, 65, 1, 23, 7, 58, 2, 78, 3, 23, 5, 66, 6, 15, 0,  4, 8, 97, 
    7, 65, 2, 49, 4, 28, 0, 21, 3, 78, 1, 16, 8, 74, 5, 40, 6, 66, 
    1, 68, 2, 36, 8, 99, 4, 38, 3, 47, 5, 59, 7, 11, 0, 96, 6, 56, 
    3, 71, 4,  7, 1, 57, 0, 26, 5, 68, 7, 95, 2, 52, 8, 33, 6, 83, 
    2, 78, 3, 43, 1, 20, 6, 16, 4, 53, 0, 67, 7,  1, 8, 86, 5, 51, 
    1, 24, 6,  9, 0,  5, 7, 98, 5, 59, 4, 29, 8, 47, 3, 83, 2, 67, 
    7, 73, 4, 67, 6, 93, 1, 21, 3, 68, 5, 63, 8, 17, 0, 36, 2, 18, 
    5, 73, 1, 32, 0, 44, 8, 44, 6, 58, 7, 28, 4, 70, 2, 29, 3, 11, 
    7, 85, 0, 63, 3, 11, 8, 44, 4, 71, 5, 82, 6, 98, 2, 44, 1,  5
  };
  const int q7980[] = {
    9, 9, // Number of jobs and machines
    7, 11, 2, 43, 0, 81, 5, 40, 4, 82, 1, 94, 3, 30, 6, 43, 8, 13, 
    7, 54, 6,  6, 2, 13, 0, 63, 1, 17, 3, 29, 8, 55, 4, 76, 5, 69, 
    7, 37, 2, 40, 0, 15, 1, 28, 6, 63, 3, 73, 8, 41, 4,  6, 5, 68, 
    5, 30, 0, 38, 6,  1, 1, 73, 4, 96, 7, 21, 8, 74, 2, 53, 3, 70, 
    4, 45, 3, 10, 7, 57, 5, 16, 2, 24, 6, 24, 1, 13, 0, 51, 8,  9, 
    4, 87, 0, 37, 3, 47, 8, 81, 2, 25, 1, 46, 7, 46, 6,  2, 5, 61, 
    2, 69, 4, 25, 1, 69, 6,  9, 0, 70, 3, 47, 7, 41, 5, 13, 8, 25, 
    3, 32, 5, 81, 4, 31, 6, 25, 7, 94, 1, 71, 2, 91, 8,  5, 0, 18, 
    3, 44, 4, 70, 7, 11, 6, 78, 5, 58, 8, 89, 1,  8, 0, 32, 2, 44
  };
  const int q7981[] = {
    9, 9, // Number of jobs and machines
    3, 26, 5, 17, 1, 81, 8, 42, 2, 66, 6, 32, 7, 15, 4, 58, 0, 54, 
    6, 67, 2, 34, 7, 55, 4, 23, 1, 99, 5, 28, 0, 40, 3, 13, 8, 88, 
    3, 92, 7, 57, 5, 69, 2, 74, 6, 82, 1, 25, 8, 95, 0, 50, 4, 30, 
    2,  4, 7, 84, 3, 64, 8, 76, 0, 75, 5, 42, 1, 15, 4,  5, 6, 28, 
    6, 34, 1, 81, 7, 58, 4, 76, 5, 96, 2,  2, 0, 74, 8, 19, 3, 26, 
    3, 38, 5, 58, 8, 31, 2, 40, 7, 38, 0, 19, 1, 80, 4, 67, 6, 40, 
    0, 79, 2, 71, 8, 40, 1, 31, 5, 11, 6, 49, 7, 21, 3, 62, 4, 55, 
    8, 13, 3, 66, 1, 11, 6, 97, 7, 69, 2, 73, 5, 57, 4, 99, 0, 86, 
    3, 30, 4, 26, 1, 21, 0, 17, 2, 98, 8, 25, 7, 67, 5, 19, 6, 41
  };
  const int q7982[] = {
    9, 9, // Number of jobs and machines
    1, 25, 5, 42, 0,  8, 4, 77, 3, 23, 8, 40, 6, 20, 2, 19, 7, 42, 
    5, 31, 7, 77, 1, 32, 8, 90, 6, 27, 4, 37, 3, 51, 2, 16, 0, 52, 
    3, 29, 5,  8, 1, 32, 6,  6, 4, 60, 7, 44, 8, 35, 2, 51, 0, 46, 
    0,  6, 2, 15, 5, 75, 3, 81, 6, 46, 8,  1, 4, 26, 7, 95, 1, 45, 
    6, 55, 0, 89, 2, 54, 3, 33, 4, 85, 5,  8, 8, 58, 7, 80, 1, 71, 
    4, 61, 8, 40, 7, 39, 2, 12, 6, 52, 3, 54, 1, 20, 0, 44, 5, 17, 
    3, 66, 6, 28, 4, 94, 1, 14, 5, 58, 2, 81, 7, 81, 0, 49, 8, 81, 
    4, 77, 8, 27, 2, 18, 1, 72, 5, 32, 3, 79, 0, 43, 7, 77, 6, 34, 
    1, 62, 3, 42, 0, 96, 8, 12, 4, 31, 6, 49, 2, 31, 5, 75, 7,  8
  };
  const int q7983[] = {
    9, 9, // Number of jobs and machines
    3, 60, 8, 28, 1, 90, 0, 14, 2, 76, 6, 27, 5,  7, 4, 51, 7, 80, 
    3, 39, 6, 76, 0, 40, 1, 29, 5, 81, 8, 70, 2, 26, 4, 55, 7, 11, 
    6, 56, 0, 13, 5, 62, 1, 28, 2, 93, 7, 74, 8, 86, 4, 65, 3, 53, 
    7, 15, 5, 66, 4, 34, 2, 59, 3, 89, 6, 83, 8, 80, 0, 58, 1,  4, 
    3, 81, 2, 52, 0, 49, 4, 67, 8,  5, 5, 53, 1, 90, 7, 38, 6, 58, 
    7, 37, 4, 37, 6, 63, 2, 63, 5, 45, 3, 21, 8, 15, 1, 28, 0, 88, 
    1, 95, 0, 66, 7, 72, 3, 38, 2, 38, 6, 45, 5, 13, 4, 18, 8, 34, 
    8, 79, 1, 68, 4, 85, 2, 27, 5, 85, 7,  8, 3, 99, 6, 81, 0, 70, 
    5, 99, 6, 62, 1, 48, 4, 71, 2, 94, 0, 50, 8, 90, 7, 10, 3, 71
  };
  const int q7984[] = {
    9, 9, // Number of jobs and machines
    7, 69, 1, 69, 0, 52, 6, 48, 2, 16, 4, 99, 5, 42, 8, 21, 3, 90, 
    3,  8, 1, 71, 7,  9, 0, 23, 6, 62, 2, 45, 8, 46, 5, 50, 4, 42, 
    6, 98, 5, 83, 8, 45, 2, 34, 0, 30, 3, 15, 1, 18, 7, 87, 4, 90, 
    1, 38, 7, 79, 2, 90, 4, 51, 3, 58, 0,  8, 6, 66, 8, 28, 5,  5, 
    2, 61, 7, 44, 3, 40, 4, 25, 6, 59, 8, 94, 5, 49, 1, 28, 0, 79, 
    2, 60, 3, 44, 4, 68, 7, 38, 8, 12, 6, 91, 0, 58, 1, 84, 5, 76, 
    4, 85, 7,  8, 8, 17, 5, 10, 1, 14, 2, 32, 0, 19, 3, 37, 6,  6, 
    8, 19, 0,  5, 2, 61, 4, 38, 7, 30, 3, 89, 5, 90, 6, 94, 1,  9, 
    1, 86, 6, 98, 5, 38, 8, 15, 0, 24, 7, 80, 2, 98, 3, 65, 4, 48
  };
  const int q7985[] = {
    9, 9, // Number of jobs and machines
    2, 55, 4, 17, 7, 53, 1, 30, 8, 19, 0, 32, 5, 13, 6, 77, 3, 55, 
    7, 31, 1, 30, 3, 81, 2, 54, 5, 96, 8, 32, 4, 35, 6, 77, 0, 98, 
    3, 79, 2, 50, 0, 96, 4, 41, 8, 86, 6, 56, 7, 49, 5, 95, 1, 15, 
    3, 31, 6, 38, 2, 52, 4, 93, 7, 64, 0, 76, 5,  5, 8,  7, 1, 54, 
    1, 61, 4, 20, 5, 62, 2, 55, 3, 17, 8, 22, 6, 34, 0, 39, 7, 67, 
    7, 60, 4, 12, 5, 37, 3, 47, 8, 39, 1, 66, 0, 28, 6, 47, 2,  8, 
    8, 53, 2, 20, 0, 13, 7, 67, 1, 30, 5, 91, 3, 48, 6, 19, 4, 65, 
    5, 54, 3, 67, 6, 14, 1, 69, 7, 68, 0, 34, 4, 65, 8, 39, 2, 50, 
    6, 48, 2, 42, 8, 43, 7, 17, 5, 10, 3, 33, 4, 47, 1, 22, 0, 24
  };
  const int q7986[] = {
    9, 9, // Number of jobs and machines
    3, 92, 8, 48, 7,  3, 5,  3, 2, 40, 4, 39, 1, 54, 6, 34, 0, 26, 
    4, 64, 3, 40, 5, 42, 8, 35, 1,  5, 2, 33, 7,  6, 6, 17, 0, 36, 
    1, 24, 6, 27, 5,  5, 4, 21, 2, 75, 8, 28, 0, 82, 7,  1, 3, 93, 
    6, 69, 7, 83, 0, 40, 1, 69, 3, 93, 5,  7, 4, 97, 2, 55, 8, 13, 
    1, 37, 6, 40, 3, 79, 5, 48, 0, 57, 2, 22, 8, 12, 4, 51, 7, 20, 
    8, 66, 5, 61, 3, 20, 7, 75, 4, 53, 0, 13, 1, 47, 6,  5, 2, 92, 
    6, 25, 3, 30, 0, 39, 7, 49, 8, 44, 5, 42, 2, 15, 1, 29, 4, 99, 
    5, 76, 7, 84, 6, 33, 0, 38, 1, 18, 4, 82, 8, 64, 3, 92, 2, 14, 
    7,  9, 2, 43, 5, 64, 4, 58, 8, 71, 6, 44, 1, 99, 0, 35, 3, 17
  };
  const int q7987[] = {
    9, 9, // Number of jobs and machines
    4, 86, 1, 83, 8, 13, 2, 63, 5, 30, 3, 42, 7, 27, 0, 96, 6, 92, 
    7, 78, 4, 66, 1, 53, 0, 16, 8, 46, 3, 33, 5, 87, 6, 94, 2, 12, 
    5, 51, 2, 22, 6, 34, 1, 31, 0, 37, 8, 76, 4, 32, 3, 46, 7,  5, 
    2, 68, 4, 75, 7, 67, 5, 88, 1, 82, 3, 38, 8, 78, 6, 66, 0, 78, 
    3, 91, 7, 13, 8, 87, 6, 38, 5, 20, 4, 56, 0, 43, 2, 97, 1,  8, 
    7, 38, 5, 69, 4, 95, 6, 83, 1, 88, 3,  9, 8, 72, 2, 84, 0, 20, 
    0, 98, 1, 83, 8, 27, 7, 60, 5, 97, 6, 81, 2, 72, 4, 96, 3,  5, 
    8, 45, 1, 75, 0, 52, 3, 61, 7, 34, 6,  2, 5, 69, 2, 76, 4, 42, 
    8, 27, 2,  9, 0, 85, 6, 70, 3,  4, 5, 58, 4, 28, 1, 14, 7, 94
  };
  const int q7988[] = {
    9, 9, // Number of jobs and machines
    0, 35, 4, 42, 7, 94, 5, 61, 2, 20, 6,  4, 3,  8, 1, 86, 8, 58, 
    6, 34, 4, 31, 2, 77, 8, 74, 7,  1, 5, 75, 1, 90, 3, 28, 0, 96, 
    1, 72, 5, 89, 4, 54, 8, 48, 0, 48, 3, 78, 2,  4, 7, 65, 6, 51, 
    2, 89, 8, 53, 6, 14, 1,  9, 3, 78, 5, 51, 0, 95, 7, 29, 4, 18, 
    3, 91, 0, 99, 4, 85, 5, 88, 2, 82, 8, 68, 7, 59, 1, 13, 6, 59, 
    6, 32, 1, 41, 0, 92, 4, 53, 2, 37, 5, 79, 3,  8, 8, 63, 7, 16, 
    5, 57, 1, 88, 7, 25, 4, 16, 3, 91, 2, 38, 0, 67, 6, 36, 8,  2, 
    8, 93, 1, 59, 5, 19, 2, 97, 6, 17, 7, 71, 3, 66, 0,  3, 4, 44, 
    2,  3, 7, 94, 0, 43, 3, 68, 4, 46, 6, 69, 8, 64, 1,  1, 5, 46
  };
  const int q7989[] = {
    9, 9, // Number of jobs and machines
    2, 59, 7, 60, 8, 87, 5, 35, 4, 91, 6, 69, 0, 96, 1, 97, 3, 95, 
    2, 92, 0, 23, 7,  2, 4, 63, 8, 32, 5, 75, 3, 27, 1, 49, 6, 21, 
    4, 23, 1, 89, 6, 46, 8, 76, 2, 53, 7,  8, 0, 11, 5, 12, 3, 61, 
    1, 24, 4, 81, 6, 41, 8,  7, 7, 75, 0, 20, 2, 26, 3,  5, 5,  4, 
    6, 79, 5, 74, 4, 97, 7, 58, 1, 97, 8, 72, 0, 30, 3, 45, 2, 67, 
    0, 89, 3, 57, 8, 87, 4, 45, 2, 55, 6,  8, 7, 61, 1,  4, 5,  7, 
    5, 68, 1, 48, 3, 87, 0, 24, 8, 54, 2, 91, 6, 48, 7, 67, 4, 48, 
    8, 94, 6, 63, 5, 94, 1, 15, 7, 55, 4, 36, 0, 72, 3, 72, 2, 85, 
    2,  1, 7, 30, 4, 13, 8, 27, 3, 89, 6, 83, 0, 46, 5, 60, 1, 96
  };
  const int q7990[] = {
    9, 9, // Number of jobs and machines
    1, 84, 6, 88, 8, 60, 7,  2, 0, 14, 3,  1, 5, 24, 4, 90, 2, 67, 
    8, 77, 2, 68, 5, 84, 0, 52, 3, 95, 7, 10, 6, 14, 1, 82, 4, 36, 
    5, 10, 1, 26, 3, 73, 2, 86, 6, 25, 0, 18, 8,  2, 4, 67, 7,  8, 
    7, 57, 5, 10, 0, 85, 3, 48, 6, 71, 8, 25, 1, 20, 2, 60, 4, 85, 
    0, 36, 2, 31, 1, 69, 8,  2, 6,  2, 3, 50, 5, 12, 7, 37, 4, 28, 
    8, 88, 6, 91, 3, 45, 7, 29, 2,  4, 0, 18, 5, 64, 4,  7, 1, 54, 
    4, 94, 8, 78, 6, 79, 3,  2, 1, 58, 0,  7, 5, 67, 2, 17, 7, 97, 
    0, 90, 7, 35, 3, 93, 1,  3, 4, 16, 2, 27, 6, 20, 5, 92, 8, 65, 
    2, 72, 8, 22, 3, 26, 1, 59, 0, 65, 7, 44, 4, 74, 6, 62, 5, 49
  };
  const int q7991[] = {
    9, 9, // Number of jobs and machines
    3, 35, 1, 46, 0, 23, 8, 49, 2, 58, 5, 71, 6, 54, 7, 33, 4, 12, 
    1, 96, 4, 30, 7, 90, 0, 92, 3, 84, 8, 48, 6, 74, 5, 31, 2,  5, 
    8, 49, 0, 61, 2, 66, 7, 93, 1, 12, 3, 63, 4, 66, 6, 10, 5, 12, 
    2, 11, 5, 43, 4, 62, 1, 17, 8, 24, 6, 20, 7, 16, 0, 43, 3, 81, 
    4,  9, 1, 49, 6, 65, 5,  8, 0, 23, 2, 71, 7, 55, 8, 82, 3, 98, 
    4, 25, 1, 86, 6, 15, 0, 88, 7, 99, 3, 19, 8, 62, 5, 57, 2, 67, 
    8, 77, 2,  7, 1, 34, 7,  9, 5, 97, 0, 23, 4, 10, 6, 71, 3, 75, 
    0, 60, 3, 98, 4, 70, 7, 71, 6, 73, 2, 48, 1, 25, 5, 31, 8, 42, 
    5, 23, 8, 48, 0, 58, 3, 75, 6, 74, 2, 20, 4, 36, 7, 79, 1, 45
  };
  const int q7992[] = {
    9, 9, // Number of jobs and machines
    1, 99, 2, 91, 5, 37, 7, 88, 0, 30, 4, 51, 8, 32, 6, 86, 3, 98, 
    4, 25, 5, 13, 8,  9, 1, 47, 6, 76, 3, 31, 0, 74, 7, 57, 2, 24, 
    5,  7, 8, 98, 3, 78, 2, 95, 7, 91, 0, 22, 4, 97, 1, 25, 6, 26, 
    5, 17, 3, 84, 6, 94, 7,  2, 4, 91, 1, 12, 0, 77, 8,  7, 2, 28, 
    6, 60, 5, 15, 2, 61, 3, 13, 4, 36, 1, 36, 0, 66, 7, 76, 8, 64, 
    0, 28, 4, 89, 3, 35, 8, 25, 6, 18, 1,  6, 2, 90, 7, 65, 5, 75, 
    2, 92, 6, 55, 1, 51, 7,  7, 5, 92, 8, 51, 0, 21, 4, 48, 3, 36, 
    6, 77, 7, 59, 4, 55, 1, 70, 3, 61, 2, 72, 8, 82, 0, 86, 5,  5, 
    5, 18, 7, 61, 8, 15, 2, 17, 0, 86, 3, 67, 4, 13, 6, 12, 1,  1
  };
  const int q7993[] = {
    9, 9, // Number of jobs and machines
    3, 43, 8, 35, 7,  9, 1, 63, 6, 12, 0, 27, 2, 56, 5, 39, 4, 27, 
    6, 74, 8, 45, 0, 20, 2, 35, 1, 31, 4, 15, 7, 51, 3, 69, 5, 36, 
    2, 94, 0, 19, 6, 63, 7, 13, 5, 26, 8, 58, 4, 61, 3, 71, 1, 46, 
    6, 26, 3, 69, 5, 48, 8, 41, 7,  6, 4, 62, 1, 30, 2, 20, 0, 14, 
    8, 82, 1,  9, 7, 98, 2, 35, 4, 10, 0, 52, 5, 84, 3, 69, 6, 77, 
    6, 53, 4, 40, 2, 40, 7, 82, 3,  2, 1, 42, 5, 86, 8, 19, 0, 16, 
    1, 45, 0, 65, 3, 20, 7, 23, 4, 60, 8, 57, 6, 21, 5, 15, 2, 11, 
    7, 23, 6, 22, 8, 62, 5, 43, 0,  5, 4, 46, 2, 58, 3,  3, 1, 54, 
    6, 39, 4, 63, 1, 50, 3, 40, 5, 26, 7, 22, 8, 42, 2, 48, 0, 57
  };
  const int q7994[] = {
    9, 9, // Number of jobs and machines
    3, 53, 4, 18, 5, 60, 6, 96, 2, 17, 0, 40, 8, 25, 1, 91, 7, 70, 
    6, 31, 5, 97, 0,  3, 2, 69, 1, 81, 4, 11, 3, 17, 8, 39, 7, 42, 
    6, 44, 7, 74, 2, 91, 5,  4, 1,  7, 4,  6, 8, 17, 3, 26, 0, 41, 
    7, 65, 6, 84, 5, 82, 3, 70, 4,  2, 8, 69, 2, 38, 0, 68, 1, 45, 
    7,  3, 0, 80, 8, 96, 6, 22, 4, 12, 1, 26, 2, 77, 5, 51, 3, 19, 
    6, 76, 2, 24, 8, 77, 4, 33, 1, 93, 0, 92, 7, 97, 5, 62, 3, 15, 
    4,  9, 3, 52, 2, 72, 0, 34, 6, 42, 7, 26, 1, 57, 5, 75, 8, 84, 
    3, 93, 2,  8, 8, 84, 1, 47, 7, 87, 4, 58, 6, 68, 0,  4, 5, 33, 
    2, 53, 5, 46, 1, 20, 4, 81, 6, 95, 8, 41, 7, 60, 0, 65, 3, 54
  };
  const int q7995[] = {
    9, 9, // Number of jobs and machines
    3, 16, 2,  1, 7, 12, 5, 57, 6, 16, 0, 44, 4, 99, 8, 39, 1, 91, 
    4, 81, 1, 78, 5,  2, 8, 64, 7, 59, 6, 30, 3, 24, 2, 54, 0, 62, 
    4, 26, 3, 26, 8, 64, 1, 77, 7, 35, 6, 88, 2, 63, 5, 57, 0, 23, 
    2, 55, 0, 45, 4, 29, 3,  3, 1, 99, 6, 70, 7, 73, 8, 12, 5, 20, 
    6, 65, 1,  3, 4, 13, 5, 52, 8, 54, 7, 99, 3, 13, 0, 94, 2, 56, 
    1, 17, 8, 79, 3, 26, 4, 36, 6, 37, 5,  6, 0, 98, 2, 39, 7, 61, 
    5,  8, 2, 19, 8, 72, 0,  9, 4, 76, 1, 41, 6, 17, 7, 40, 3, 75, 
    4, 26, 0, 80, 8, 63, 5, 11, 6,  3, 2, 50, 7, 14, 3, 95, 1, 83, 
    1, 91, 8, 44, 2, 31, 0, 19, 4, 52, 7, 56, 3,  3, 6, 93, 5, 41
  };
  const int q7996[] = {
    9, 9, // Number of jobs and machines
    1, 97, 7, 43, 6, 87, 8, 42, 2,  5, 3, 58, 0, 34, 4, 48, 5, 24, 
    8, 78, 0, 94, 6, 70, 1, 20, 7, 62, 2, 78, 3, 92, 4, 28, 5, 68, 
    5, 48, 6, 69, 1, 64, 4, 27, 7, 74, 3, 82, 8, 96, 0,  7, 2,  1, 
    3, 46, 5, 56, 8, 90, 0, 33, 6, 67, 2, 81, 4, 14, 1, 30, 7, 90, 
    5, 55, 8, 88, 2, 55, 6, 56, 1, 86, 4, 46, 0, 11, 3, 62, 7, 35, 
    4, 96, 1,  7, 0, 86, 3, 33, 5, 55, 8, 77, 2, 27, 7, 77, 6, 25, 
    8, 39, 0, 35, 3, 51, 2,  6, 4, 81, 5, 17, 6, 82, 7, 17, 1,  6, 
    1, 49, 7, 70, 8, 13, 3, 99, 0, 29, 2, 22, 4, 85, 6, 16, 5, 67, 
    3, 45, 1, 15, 4, 77, 7,  9, 6, 40, 0,  5, 5, 49, 2, 75, 8, 52
  };
  const int q7997[] = {
    9, 9, // Number of jobs and machines
    7, 49, 6, 24, 3, 35, 0, 90, 1, 21, 2, 48, 4, 95, 8, 38, 5, 96, 
    6,  6, 8, 75, 2, 94, 5, 56, 0, 11, 4, 90, 7, 87, 3, 53, 1,  1, 
    5, 21, 0, 35, 1, 90, 8, 21, 7, 29, 2, 26, 3, 10, 6, 18, 4, 45, 
    0, 53, 3, 83, 6, 95, 8, 13, 1, 14, 7, 83, 2, 27, 4, 30, 5,  6, 
    2, 44, 5,  5, 6, 45, 0, 57, 1, 88, 4, 12, 3, 74, 7, 72, 8, 57, 
    3, 73, 8, 42, 5, 46, 4,  4, 2, 83, 7, 17, 0, 37, 1,  9, 6, 75, 
    2, 67, 1,  1, 5, 95, 8, 73, 4, 58, 3, 61, 7, 59, 0, 90, 6, 12, 
    8, 60, 1, 69, 7,  6, 2, 76, 0, 71, 5, 86, 6, 50, 4, 64, 3, 47, 
    7, 94, 2, 36, 8, 92, 6, 62, 1,  8, 0, 69, 4, 81, 5, 12, 3, 19
  };
  const int q7998[] = {
    9, 9, // Number of jobs and machines
    6, 78, 2, 12, 7, 33, 1, 97, 5, 21, 4, 30, 3, 49, 8, 10, 0, 56, 
    7, 44, 8, 38, 6, 49, 4, 22, 1, 63, 2, 97, 0, 86, 3, 66, 5, 73, 
    1,  1, 3, 87, 7, 16, 2, 58, 6, 32, 4, 63, 5, 45, 0, 27, 8, 77, 
    1, 85, 0, 88, 6, 62, 5, 39, 8, 16, 4, 50, 3, 69, 2, 50, 7, 16, 
    4, 47, 5, 65, 8, 78, 7, 21, 6, 82, 2, 96, 1, 87, 0,  7, 3, 30, 
    0,  2, 1, 40, 8, 11, 5, 48, 4, 19, 6, 28, 7, 51, 2, 71, 3, 57, 
    3, 27, 2, 19, 1, 70, 8, 74, 4, 46, 6, 36, 5, 36, 0,  8, 7, 58, 
    6, 28, 8, 99, 1, 62, 2, 99, 0, 36, 3, 41, 5,  1, 4, 13, 7, 82, 
    0, 20, 4, 35, 3, 92, 8, 78, 1, 61, 6, 39, 7, 32, 5, 71, 2, 82
  };
  const int q7999[] = {
    9, 9, // Number of jobs and machines
    8, 41, 0, 48, 7, 61, 2, 49, 6, 33, 3, 10, 5,  6, 4, 32, 1,  6, 
    2, 21, 6, 48, 4,  3, 1,  8, 8, 69, 7, 30, 3, 37, 5, 36, 0, 13, 
    8, 72, 4, 52, 7, 45, 3, 93, 1, 54, 6, 12, 2, 57, 0,  4, 5, 47, 
    3, 60, 1, 12, 0, 81, 5, 47, 4, 80, 7, 44, 6, 78, 8, 27, 2, 73, 
    7, 56, 6, 31, 5, 16, 4, 84, 8, 20, 0, 34, 2, 47, 1,  2, 3, 92, 
    3,  8, 4, 11, 0, 15, 7, 23, 8, 91, 6, 36, 1, 49, 5, 25, 2, 51, 
    8, 35, 1, 82, 6, 46, 4, 65, 5, 20, 0, 91, 7, 93, 3, 18, 2, 69, 
    7, 52, 0, 43, 5, 69, 1, 46, 4, 69, 2, 55, 3, 34, 8, 70, 6, 32, 
    3, 88, 8,  1, 4,  2, 6, 21, 5,  3, 1, 19, 2, 14, 0, 65, 7, 99
  };
  const int q8000[] = {
    9, 9, // Number of jobs and machines
    4,  3, 5, 50, 2,  1, 8, 82, 6, 87, 0, 26, 3, 59, 7, 22, 1, 44, 
    1, 81, 2, 36, 6, 70, 7, 91, 3, 50, 5, 26, 0, 37, 8, 27, 4, 32, 
    7, 63, 6, 62, 4, 73, 2, 38, 1, 12, 8,  9, 0, 77, 5,  9, 3, 76, 
    5, 60, 1, 66, 4, 12, 3, 83, 7, 19, 6, 83, 2,  6, 8, 43, 0, 36, 
    4, 61, 0, 26, 7, 72, 8, 83, 2, 32, 5, 18, 1, 65, 6, 77, 3, 85, 
    2, 52, 4, 23, 8, 11, 1, 70, 0, 36, 7, 16, 5, 23, 6, 27, 3, 35, 
    6, 89, 8, 65, 2,  8, 5, 64, 4, 83, 7, 96, 0, 76, 1, 66, 3, 29, 
    6, 40, 3, 36, 1, 25, 4, 58, 0, 84, 5,  9, 8, 47, 2, 70, 7, 32, 
    5, 84, 7, 38, 0,  7, 4, 17, 3, 65, 1, 73, 8, 90, 2, 74, 6, 38
  };
  const int q8001[] = {
    9, 9, // Number of jobs and machines
    6, 90, 7, 30, 0, 45, 5, 87, 8, 12, 2, 26, 4, 97, 1, 44, 3, 50, 
    5, 10, 1, 32, 7, 92, 2, 98, 0, 88, 8, 68, 3,  3, 4, 71, 6, 13, 
    6, 11, 0, 87, 5, 18, 8, 80, 4, 44, 3, 87, 2, 10, 7, 44, 1, 65, 
    8, 29, 5, 94, 6,  8, 0, 37, 3, 12, 4, 33, 7, 28, 1, 13, 2, 63, 
    5, 20, 3, 99, 0, 52, 4, 99, 8, 66, 1, 41, 6, 19, 7, 47, 2, 73, 
    4, 70, 2, 45, 6, 42, 1, 74, 5, 47, 3, 28, 8, 93, 0, 16, 7, 38, 
    0, 94, 6, 96, 7, 36, 2,  2, 4, 50, 8, 92, 3,  1, 5, 49, 1, 44, 
    7, 29, 5, 93, 8, 78, 1, 32, 2, 19, 6, 19, 3, 96, 4, 73, 0, 62, 
    3,  8, 1, 89, 6, 93, 0, 67, 4, 60, 5, 74, 2,  4, 8, 34, 7, 57
  };
  const int q8002[] = {
    9, 9, // Number of jobs and machines
    8, 22, 5, 46, 7, 37, 0, 96, 6, 11, 4, 90, 2, 91, 3, 14, 1,  9, 
    5, 39, 1, 51, 2, 19, 8, 49, 4,  6, 0, 47, 7, 83, 3, 34, 6, 37, 
    2, 78, 5, 60, 3, 76, 1, 64, 4, 13, 6, 32, 8, 46, 7, 71, 0, 84, 
    2, 71, 3, 17, 4, 32, 5, 85, 7, 85, 0, 13, 8, 24, 1, 37, 6, 32, 
    6,  6, 0, 61, 8, 65, 3, 78, 1, 36, 7, 55, 5, 97, 4, 44, 2, 63, 
    8, 27, 2, 48, 5, 49, 6, 52, 1, 35, 0, 31, 7, 65, 4, 98, 3, 52, 
    3, 26, 8, 95, 6, 68, 5, 88, 4, 99, 7, 39, 1, 21, 2, 40, 0, 75, 
    5, 72, 0, 42, 2, 15, 4, 68, 3, 70, 1, 27, 7, 25, 8,  9, 6, 15, 
    5, 30, 7, 88, 2, 51, 0, 61, 8, 38, 1, 54, 6, 12, 4, 66, 3,  4
  };
  const int q8003[] = {
    9, 9, // Number of jobs and machines
    1, 65, 5, 46, 2, 83, 4, 80, 6, 35, 0,  4, 3, 73, 8, 91, 7, 82, 
    6, 95, 2, 48, 1, 95, 5, 38, 4, 91, 8, 90, 7,  4, 0, 59, 3, 92, 
    4, 96, 6, 54, 2, 43, 0, 22, 1, 88, 8, 78, 7, 88, 5, 52, 3, 63, 
    3, 27, 8, 78, 2, 49, 0, 69, 6, 50, 5, 39, 1, 92, 7,  7, 4, 78, 
    0, 43, 3, 45, 5, 35, 6,  1, 8, 69, 7, 42, 1, 83, 4, 38, 2, 17, 
    3, 45, 1, 95, 4, 74, 8, 24, 2, 96, 7, 12, 6, 41, 0, 30, 5, 31, 
    3, 50, 7, 90, 2, 71, 0, 32, 4, 19, 6, 28, 5, 40, 8, 24, 1, 59, 
    6, 97, 0, 45, 2, 74, 5, 42, 8, 74, 4, 93, 7, 55, 1, 81, 3, 22, 
    6, 61, 7, 67, 1, 65, 5, 38, 8, 93, 0, 99, 4, 16, 2, 95, 3,  6
  };
  const int q8004[] = {
    9, 9, // Number of jobs and machines
    2, 68, 7, 10, 4, 98, 3, 75, 1,  1, 0, 60, 8, 40, 5, 41, 6, 25, 
    3, 37, 7, 74, 4, 21, 6, 21, 2, 73, 0, 22, 5,  7, 1, 47, 8, 49, 
    2, 38, 8, 24, 5, 30, 0, 46, 7,  5, 4, 84, 3,  6, 6, 32, 1,  3, 
    0, 49, 7, 64, 4,  8, 8, 41, 2, 60, 3, 16, 5, 23, 1,  7, 6, 34, 
    7, 76, 4, 20, 6, 47, 1, 58, 0, 16, 2, 95, 5,  2, 8,  3, 3, 47, 
    0, 68, 8, 57, 7, 55, 6, 10, 2, 26, 4, 86, 5, 10, 3, 18, 1, 17, 
    8, 65, 7, 55, 6, 88, 5, 34, 1,  4, 3, 81, 2,  8, 4, 18, 0, 61, 
    1, 62, 6, 41, 2, 64, 3, 92, 7, 42, 8, 19, 0, 20, 5, 48, 4, 63, 
    6, 94, 1, 18, 8, 12, 0, 69, 7, 87, 3, 13, 5,  7, 4, 48, 2, 79
  };
  const int q8005[] = {
    9, 9, // Number of jobs and machines
    1, 89, 2, 79, 4, 42, 5, 82, 6, 19, 0, 85, 7, 97, 8,  2, 3, 86, 
    7, 12, 8, 62, 5, 20, 0, 26, 6,  6, 3, 34, 2, 26, 4, 68, 1, 70, 
    5, 53, 7, 47, 4, 58, 2, 27, 0, 73, 8, 85, 3, 23, 6, 73, 1, 10, 
    8, 49, 6, 64, 1, 23, 4, 11, 7, 31, 0, 73, 5, 72, 2, 11, 3, 45, 
    5, 31, 7, 74, 1, 89, 6, 97, 4, 51, 0, 19, 8, 19, 3, 29, 2,  6, 
    2, 25, 4, 24, 0, 61, 6,  8, 5, 12, 3, 44, 8, 24, 7, 25, 1, 43, 
    0, 14, 3, 10, 8, 14, 6, 81, 4, 41, 5, 82, 2, 80, 1, 61, 7, 64, 
    6, 29, 1, 27, 7, 48, 3,  3, 2, 54, 4, 95, 0,  8, 8, 80, 5, 82, 
    2, 85, 8, 95, 0, 69, 1, 99, 6, 23, 3, 88, 5, 42, 4, 35, 7, 73
  };
  const int q8006[] = {
    9, 9, // Number of jobs and machines
    5, 92, 2, 34, 6, 98, 0, 18, 7, 46, 8, 72, 1, 74, 3,  1, 4, 93, 
    8, 23, 3, 28, 7, 97, 4, 42, 6, 81, 5, 36, 2, 71, 0, 19, 1, 15, 
    3, 94, 0, 63, 5, 47, 1, 14, 7, 49, 6,  5, 8,  7, 4, 77, 2, 56, 
    1, 53, 6, 87, 5, 25, 3, 20, 4, 15, 2, 97, 7, 46, 0, 34, 8, 91, 
    4, 64, 0, 44, 1,  4, 8, 83, 3,  8, 7, 56, 5, 91, 2, 93, 6, 12, 
    3,  5, 1, 52, 4, 87, 8, 82, 7, 75, 5, 52, 2,  8, 6, 63, 0, 33, 
    2, 55, 8, 87, 1, 52, 6, 21, 5, 20, 4,  1, 0, 68, 7, 29, 3, 38, 
    4, 57, 6, 53, 3, 78, 5,  6, 1, 38, 8, 88, 7, 69, 0, 35, 2, 94, 
    2, 90, 5, 53, 6, 28, 7, 19, 0, 24, 8, 25, 1, 83, 4, 93, 3, 47
  };
  const int q8007[] = {
    9, 9, // Number of jobs and machines
    2, 33, 4,  2, 1, 19, 6, 86, 7, 25, 8, 66, 0, 69, 5, 85, 3, 75, 
    4, 18, 7, 69, 6, 49, 0, 94, 8, 35, 1, 38, 3, 70, 2, 19, 5, 89, 
    0, 97, 7, 63, 3, 65, 8, 15, 5, 46, 2, 96, 1, 11, 6, 61, 4, 24, 
    6, 20, 0, 21, 8, 76, 1,  6, 3, 61, 4, 31, 2,  5, 5, 62, 7, 66, 
    7, 18, 5, 37, 0,  1, 1, 72, 6, 95, 2,  8, 3, 80, 8, 62, 4, 16, 
    1, 28, 5, 81, 8, 60, 7, 63, 0, 65, 3, 42, 6, 23, 4, 34, 2, 61, 
    8, 54, 6, 50, 1, 66, 7, 16, 3, 27, 2, 77, 4, 31, 5, 58, 0, 45, 
    1, 44, 5, 65, 3, 75, 2, 95, 0, 77, 6, 79, 4, 58, 8, 68, 7, 26, 
    8, 81, 3, 40, 0, 57, 6, 61, 5, 33, 4, 99, 7, 15, 1, 29, 2, 71
  };
  const int q8008[] = {
    9, 9, // Number of jobs and machines
    1, 50, 5, 14, 4, 57, 2,  7, 8, 73, 0,  3, 3, 26, 6, 32, 7, 58, 
    1, 66, 5,  7, 0, 89, 4,  1, 6, 50, 8, 98, 3, 33, 2, 64, 7, 31, 
    0, 36, 2, 73, 1, 87, 7, 35, 4, 49, 3, 13, 8, 35, 5, 18, 6, 32, 
    8, 87, 4, 85, 0, 37, 5, 46, 3, 42, 6, 37, 7, 54, 2, 45, 1, 35, 
    3, 43, 7, 14, 8, 18, 0, 84, 6, 64, 1, 34, 2, 20, 5, 50, 4, 90, 
    4, 67, 8, 36, 3, 97, 7, 13, 1, 63, 5, 76, 6, 29, 2, 15, 0,  7, 
    7, 64, 8, 95, 4, 96, 6, 92, 0, 85, 3, 18, 5, 15, 1, 63, 2, 35, 
    1, 13, 8, 20, 2, 45, 0, 73, 7, 18, 3, 38, 5, 52, 6, 64, 4, 32, 
    0, 23, 8, 80, 5, 10, 7,  2, 2, 98, 6, 43, 1, 93, 4, 91, 3, 52
  };
  const int q8009[] = {
    9, 9, // Number of jobs and machines
    6, 92, 7, 65, 1,  2, 5, 11, 0, 16, 3,  2, 8, 26, 4, 49, 2, 14, 
    7, 28, 6, 32, 5, 82, 3, 88, 8,  2, 4, 63, 1, 73, 2, 13, 0, 14, 
    4, 97, 2, 18, 6, 39, 7, 35, 3, 89, 0, 42, 1, 14, 5,  5, 8, 29, 
    6, 92, 2, 66, 4, 89, 3, 33, 5, 23, 1, 71, 8, 10, 0, 85, 7, 53, 
    3, 32, 0, 16, 5, 18, 2, 28, 8, 66, 6, 37, 1, 63, 7, 70, 4, 64, 
    7, 81, 6, 72, 4, 25, 3, 26, 8, 23, 2, 88, 0, 32, 5, 76, 1, 33, 
    5, 73, 7, 88, 6, 16, 1, 51, 8, 19, 0, 98, 4, 30, 2, 52, 3, 52, 
    8, 11, 2, 33, 3,  5, 4, 27, 0, 27, 1, 35, 5, 44, 6, 99, 7, 49, 
    8, 46, 7, 96, 1, 59, 3, 97, 2, 54, 5, 35, 0, 31, 6, 93, 4, 16
  };
  const int q8010[] = {
    9, 9, // Number of jobs and machines
    1, 53, 2, 78, 7, 71, 5,  1, 4, 58, 3, 38, 6,  4, 0, 67, 8,  1, 
    7, 75, 0, 64, 3, 81, 6, 38, 4, 86, 1, 27, 5, 37, 8, 10, 2, 65, 
    3,  1, 2, 34, 8, 89, 4, 71, 5,  8, 7, 53, 1, 10, 6, 31, 0, 46, 
    4, 52, 5,  6, 3, 36, 6, 87, 0, 16, 8, 21, 1, 10, 2, 47, 7, 45, 
    1, 97, 4, 63, 2, 59, 3, 27, 5, 35, 8, 17, 6,  7, 0, 94, 7, 66, 
    0, 14, 6, 75, 4, 92, 1, 38, 7, 43, 2,  2, 5, 51, 8, 87, 3, 16, 
    7, 63, 1, 74, 5, 90, 3, 50, 0, 77, 4, 89, 6, 24, 8, 40, 2, 55, 
    8, 60, 2, 32, 0, 55, 6, 38, 7, 67, 3, 59, 1, 49, 4, 75, 5, 32, 
    5, 52, 0, 16, 7, 92, 2, 64, 3, 65, 1, 30, 6, 27, 4, 13, 8, 88
  };
  const int q8011[] = {
    9, 9, // Number of jobs and machines
    1, 53, 6, 31, 4, 79, 0, 48, 7, 58, 8, 68, 5, 32, 2, 37, 3, 65, 
    8, 70, 6, 77, 0, 25, 1, 38, 2, 75, 7, 21, 3, 35, 4, 25, 5, 87, 
    0, 89, 8, 93, 2, 80, 3, 90, 4, 44, 6, 89, 7, 15, 1, 20, 5, 51, 
    4, 21, 2, 44, 1, 34, 3, 31, 7, 72, 0, 18, 6, 32, 8, 61, 5, 74, 
    0, 96, 2, 31, 3, 88, 5, 56, 1, 70, 8, 65, 7, 53, 6, 91, 4, 19, 
    2, 19, 4, 54, 1, 61, 3, 50, 0, 67, 8, 18, 6, 67, 5, 28, 7, 83, 
    5, 53, 2, 82, 4, 89, 8, 31, 7, 61, 1, 35, 0, 94, 6, 44, 3, 81, 
    4,  7, 1, 35, 6, 63, 7, 84, 8,  7, 0, 44, 3, 11, 2, 60, 5, 26, 
    7, 76, 8, 41, 5, 29, 3, 11, 6,  5, 2, 66, 4, 30, 0, 76, 1, 85
  };
  const int q8012[] = {
    9, 9, // Number of jobs and machines
    1, 18, 8, 46, 4, 34, 7, 38, 5, 14, 0, 82, 3, 60, 6, 66, 2, 58, 
    4, 44, 2, 59, 7, 95, 0, 54, 1, 33, 5, 85, 8, 97, 6, 27, 3, 57, 
    7, 84, 8, 22, 6, 51, 5, 20, 3, 82, 4, 50, 2, 79, 1, 91, 0, 50, 
    3, 92, 0, 19, 2, 19, 7, 77, 1, 36, 8, 71, 5, 97, 6, 36, 4, 72, 
    1, 48, 5, 18, 7, 11, 3, 77, 8, 19, 2, 29, 4, 65, 6, 56, 0, 88, 
    1, 11, 7, 41, 8, 93, 4, 10, 0, 39, 2, 92, 5, 25, 6, 92, 3, 93, 
    6, 15, 3, 42, 7, 93, 1, 39, 8, 73, 5, 44, 2, 67, 0,  4, 4, 13, 
    0, 80, 6, 26, 1, 57, 3, 99, 5, 87, 7, 38, 8, 52, 4, 99, 2, 50, 
    5, 51, 7, 61, 3, 61, 1, 21, 0, 22, 4, 95, 6, 80, 2, 47, 8, 82
  };
  const int q8013[] = {
    9, 9, // Number of jobs and machines
    3, 85, 2, 38, 1, 98, 8, 95, 6, 74, 5,  3, 7, 11, 4, 98, 0, 38, 
    2, 80, 8, 11, 4, 49, 5, 87, 1, 19, 3, 11, 7, 77, 0, 38, 6, 72, 
    0, 87, 6, 41, 1, 88, 8, 60, 5, 94, 4, 84, 3, 28, 2, 97, 7, 70, 
    5, 86, 2, 57, 8, 20, 1, 73, 3, 37, 0, 56, 6, 30, 7,  1, 4, 65, 
    3, 31, 8, 70, 0,  8, 2, 13, 6, 88, 1, 40, 7, 55, 4, 26, 5, 56, 
    7, 32, 5, 55, 3, 93, 2, 25, 8, 97, 4, 56, 0, 84, 6, 38, 1, 42, 
    8, 19, 1, 64, 4, 13, 2, 75, 5, 86, 7, 47, 0, 20, 3, 82, 6, 85, 
    5, 40, 6, 14, 1, 69, 4, 76, 7, 68, 8, 93, 2, 20, 3, 20, 0, 14, 
    0, 54, 6, 89, 3, 77, 8, 97, 1, 77, 4, 13, 5,  2, 7, 91, 2, 50
  };
  const int q8014[] = {
    9, 9, // Number of jobs and machines
    6, 45, 0, 71, 1, 42, 7, 21, 8, 56, 2, 71, 3, 19, 4,  7, 5, 96, 
    4, 72, 1, 71, 7, 33, 0, 55, 8, 82, 2, 87, 3, 66, 5, 93, 6, 13, 
    7, 81, 2, 79, 5, 73, 6, 94, 8, 14, 0, 73, 4, 80, 3, 61, 1, 20, 
    5, 11, 6, 78, 2, 58, 8, 73, 1, 48, 3, 84, 4, 64, 7, 97, 0, 95, 
    4, 42, 5, 65, 8,  2, 2, 45, 0, 24, 1, 37, 3, 39, 7, 41, 6, 55, 
    7, 51, 5, 70, 2, 67, 1, 97, 8, 63, 0, 59, 6, 52, 4, 53, 3, 67, 
    0, 99, 2, 16, 7, 18, 3, 91, 1, 88, 4, 14, 5, 38, 6, 34, 8, 54, 
    5, 84, 8, 17, 7, 16, 4, 68, 1, 96, 2, 51, 3, 24, 0,  6, 6, 43, 
    3, 43, 1, 14, 2, 95, 4, 72, 6, 55, 0, 20, 8, 74, 7, 78, 5, 53
  };
  const int q8015[] = {
    9, 9, // Number of jobs and machines
    4, 63, 3,  5, 6, 91, 7, 18, 1, 24, 5, 20, 2, 83, 8,  3, 0, 56, 
    0, 47, 6, 32, 3, 75, 4, 19, 2, 60, 5, 74, 8, 59, 7, 76, 1, 46, 
    7, 18, 3,  7, 4,  7, 1, 51, 0, 45, 2, 65, 5, 88, 8, 10, 6, 71, 
    4, 35, 6, 16, 0, 84, 8, 41, 5, 83, 3, 26, 2, 15, 1, 11, 7, 48, 
    3,  3, 8, 68, 0, 70, 2, 40, 6, 25, 7, 10, 4, 82, 5, 38, 1, 35, 
    8, 74, 1, 92, 2, 73, 5, 82, 4, 18, 0,  1, 6, 79, 3, 82, 7, 16, 
    3, 79, 0, 68, 7, 88, 5, 50, 6, 20, 1, 19, 2, 31, 8, 58, 4,  4, 
    0, 66, 5, 58, 4, 22, 8, 42, 2, 10, 6, 17, 3, 76, 1, 64, 7, 32, 
    7, 78, 5, 93, 2, 39, 0, 11, 8, 12, 4,  4, 1, 18, 6, 77, 3, 69
  };
  const int q8016[] = {
    9, 9, // Number of jobs and machines
    8, 97, 2, 82, 7, 45, 0, 95, 6, 19, 3, 58, 4, 15, 5, 32, 1, 53, 
    1, 24, 7, 87, 4, 31, 0, 48, 6, 41, 2,  7, 8, 96, 5, 66, 3, 21, 
    3, 14, 0, 98, 8, 33, 6, 29, 7, 84, 2, 93, 5, 22, 4, 53, 1, 27, 
    2, 27, 1, 25, 7, 95, 0, 72, 5, 91, 8, 11, 6, 43, 3, 43, 4, 85, 
    0, 75, 4,  4, 5,  7, 7, 68, 8, 28, 1, 89, 2, 79, 6,  1, 3, 32, 
    7, 51, 5, 50, 0, 71, 2, 99, 3, 73, 8, 18, 4, 47, 6, 89, 1, 11, 
    5,  3, 7, 35, 0, 90, 1,  4, 8, 75, 4,  8, 6, 96, 3, 21, 2, 50, 
    8, 96, 1, 81, 6, 41, 5, 70, 2, 64, 4, 76, 0, 53, 7,  6, 3, 17, 
    1, 12, 7, 12, 4, 63, 8, 85, 0, 68, 3, 52, 6, 84, 2, 40, 5, 56
  };
  const int q8017[] = {
    9, 9, // Number of jobs and machines
    1, 54, 5, 55, 7, 57, 2, 23, 8, 59, 3, 12, 0, 58, 4, 92, 6, 98, 
    6,  4, 3, 54, 5, 42, 4, 35, 2, 64, 7, 71, 1, 83, 8, 38, 0, 64, 
    7, 42, 2, 95, 1, 19, 4, 84, 6, 70, 3, 78, 0, 40, 5,  9, 8, 60, 
    0, 29, 2, 33, 4, 90, 7,  9, 1, 27, 5, 35, 8, 42, 3, 25, 6, 19, 
    2, 16, 4, 67, 7, 69, 3, 49, 0,  5, 6, 66, 1,  7, 8, 33, 5, 22, 
    6, 10, 1, 27, 5, 98, 0, 27, 3, 29, 4, 31, 2, 19, 8, 43, 7, 52, 
    8, 55, 5, 54, 1, 21, 2, 38, 4, 86, 7, 48, 6, 44, 0, 38, 3, 35, 
    4, 43, 3, 11, 0, 12, 1, 75, 7, 79, 5, 59, 6, 81, 8, 54, 2,  2, 
    7, 81, 4, 72, 0, 43, 6, 74, 5,  5, 3, 63, 8, 85, 1, 11, 2,  9
  };
  const int q8018[] = {
    9, 9, // Number of jobs and machines
    1, 35, 4, 48, 8, 82, 5, 39, 6, 68, 0,  1, 2, 97, 7, 17, 3, 95, 
    5, 25, 8, 64, 4, 25, 3, 60, 6, 46, 1,  2, 2, 31, 0, 84, 7, 88, 
    0, 95, 7, 78, 5, 57, 4, 54, 6, 76, 3, 47, 2, 61, 8, 90, 1, 88, 
    4, 77, 8, 54, 6, 27, 0,  5, 2, 51, 3, 30, 7, 55, 5,  9, 1, 70, 
    0, 41, 8, 71, 1, 28, 2, 95, 7, 52, 6, 90, 5, 15, 4, 57, 3, 58, 
    0, 45, 4, 85, 1, 65, 7, 34, 2, 52, 3, 38, 5, 42, 8, 69, 6, 11, 
    1, 28, 8, 97, 2, 71, 4, 30, 6, 41, 7, 12, 3, 68, 0, 75, 5,  4, 
    0, 83, 1,  8, 3, 85, 2, 78, 8, 40, 7, 25, 6, 27, 4, 75, 5, 55, 
    4, 38, 6, 44, 7, 66, 8, 47, 5, 57, 0, 16, 1, 88, 2, 15, 3,  8
  };
  const int q8019[] = {
    9, 9, // Number of jobs and machines
    0, 19, 3, 90, 7, 86, 2,  4, 4, 83, 8, 88, 5, 43, 1, 59, 6, 86, 
    5, 10, 3, 37, 2, 33, 8,  2, 7, 50, 1, 25, 6, 57, 4,  8, 0, 10, 
    7, 39, 2,  1, 1, 59, 6, 90, 3, 18, 0, 85, 4, 33, 8, 83, 5, 67, 
    2, 43, 0, 56, 8, 16, 7, 97, 6, 66, 3, 88, 5, 23, 4,  2, 1, 10, 
    0, 88, 6, 35, 3, 87, 4, 51, 2,  1, 8, 42, 7, 30, 5, 32, 1, 10, 
    4, 65, 1, 36, 0, 82, 3, 29, 7, 48, 2, 26, 8, 51, 5,  3, 6, 18, 
    7, 30, 3, 19, 5, 57, 1, 67, 6, 15, 8, 78, 0, 88, 2, 42, 4, 26, 
    3, 52, 5, 27, 2, 65, 7, 28, 6, 87, 8, 50, 1, 85, 4, 10, 0, 64, 
    4, 38, 2, 72, 3, 72, 5, 89, 0, 92, 1, 58, 8, 90, 6,  1, 7, 10
  };
  const int q8020[] = {
    9, 9, // Number of jobs and machines
    2, 64, 7, 93, 4, 52, 5, 64, 6, 33, 3, 54, 1, 95, 0, 17, 8, 13, 
    3,  4, 8, 51, 2, 15, 5, 49, 7, 41, 6, 89, 0, 71, 4, 96, 1, 66, 
    3, 55, 0, 95, 4, 78, 7, 93, 8, 50, 1, 82, 5, 67, 2, 26, 6, 50, 
    0,  5, 1, 74, 6, 92, 7, 47, 5, 15, 2, 97, 8, 98, 4, 60, 3, 86, 
    8, 52, 0, 15, 1, 72, 7,  8, 4, 25, 5, 78, 6, 99, 3,  9, 2, 95, 
    6, 98, 5,  7, 7, 29, 4, 38, 1, 36, 0, 94, 8, 57, 3, 87, 2, 71, 
    7, 69, 8, 36, 1, 71, 3, 94, 5,  3, 0, 40, 6, 72, 4, 59, 2, 96, 
    0, 58, 5, 78, 8,  9, 6,  8, 1, 16, 2, 23, 7, 61, 4, 67, 3, 52, 
    7, 48, 4, 84, 6, 26, 8, 14, 5, 98, 0,  7, 3, 35, 2, 73, 1, 44
  };
  const int q8021[] = {
    9, 9, // Number of jobs and machines
    5,  2, 0, 86, 3, 67, 7, 57, 4, 75, 6, 10, 8, 65, 2, 22, 1, 69, 
    1,  6, 8, 99, 5, 79, 7,  6, 3, 28, 2, 70, 6, 46, 0, 67, 4, 98, 
    0, 84, 7, 27, 3, 30, 8, 11, 6, 84, 1, 73, 5, 55, 2, 13, 4, 89, 
    6, 51, 7, 69, 0, 37, 1, 41, 8, 33, 5, 66, 2, 50, 4, 44, 3, 86, 
    5, 81, 0, 90, 4, 36, 2, 26, 3,  7, 6, 40, 7, 85, 1, 45, 8, 31, 
    5, 62, 8, 83, 4, 88, 7, 16, 3, 64, 0, 17, 6, 65, 2,  4, 1, 68, 
    6, 76, 4, 63, 2, 75, 3,  2, 5, 43, 8, 31, 1, 43, 0, 77, 7, 72, 
    7, 50, 3, 82, 5, 91, 4, 88, 8, 65, 0, 87, 1, 20, 2,  1, 6, 73, 
    1, 76, 0, 44, 7, 21, 8, 80, 5, 69, 2, 30, 4, 42, 3, 87, 6, 41
  };
  const int q8022[] = {
    9, 9, // Number of jobs and machines
    1, 97, 4, 60, 2, 95, 3, 58, 7, 89, 6, 76, 0, 50, 8, 45, 5, 24, 
    3, 72, 0,  7, 2, 87, 8, 17, 7, 77, 6, 68, 5, 84, 1, 46, 4, 64, 
    8, 59, 2, 70, 0, 10, 4, 16, 1,  3, 3, 95, 7, 19, 5, 32, 6, 61, 
    5, 21, 6, 15, 3, 39, 2,  3, 1, 97, 4, 12, 8, 13, 0, 39, 7, 94, 
    5, 61, 7, 92, 6, 86, 0, 69, 3, 96, 4, 24, 2, 61, 8, 65, 1, 32, 
    3, 68, 2, 16, 5, 52, 1, 92, 7, 89, 8, 87, 4, 72, 6, 93, 0, 63, 
    7, 13, 8,  5, 2, 79, 4,  3, 0, 74, 5, 46, 1, 64, 6, 44, 3, 15, 
    4, 89, 5, 64, 3, 69, 2, 67, 1, 16, 6, 88, 7, 86, 8, 88, 0, 75, 
    8,  3, 3,  9, 6, 93, 7, 83, 2, 40, 0, 15, 5, 28, 4, 48, 1, 54
  };
  const int q8023[] = {
    9, 9, // Number of jobs and machines
    1, 50, 5,  6, 4, 47, 2, 16, 8, 44, 7, 82, 3, 87, 6, 37, 0, 16, 
    6, 69, 7,  5, 8, 68, 4, 36, 0, 41, 2, 15, 5, 31, 1, 91, 3, 13, 
    0, 35, 2, 27, 8, 71, 4, 55, 5, 75, 1, 77, 7, 57, 3,  7, 6, 25, 
    0, 73, 7, 25, 1, 13, 3, 41, 4, 57, 2, 57, 5, 93, 8,  2, 6, 24, 
    8, 66, 5, 45, 0, 42, 1, 81, 4, 22, 7, 41, 3, 47, 6, 90, 2, 95, 
    6, 12, 2, 46, 1, 98, 7, 25, 4, 31, 8, 90, 3, 51, 5, 75, 0, 37, 
    1, 65, 8, 64, 5, 21, 7, 19, 4, 89, 3,  5, 6, 76, 0, 46, 2, 59, 
    1,  8, 8, 13, 3, 26, 7, 82, 4, 41, 5, 37, 0, 88, 2, 94, 6, 98, 
    2, 68, 1, 35, 4, 39, 8, 16, 6, 15, 3, 53, 5, 62, 0, 18, 7, 60
  };
  const int q8024[] = {
    9, 9, // Number of jobs and machines
    8, 88, 1,  3, 2, 53, 0, 36, 6, 61, 7, 82, 4,  5, 5, 25, 3, 98, 
    7, 22, 6, 87, 3, 79, 4, 85, 5, 31, 2, 33, 0, 85, 8, 75, 1,  6, 
    8, 85, 6, 75, 7, 55, 3, 87, 4, 78, 5, 22, 2, 79, 1, 29, 0, 15, 
    0, 16, 7,  6, 5, 23, 8, 67, 1, 78, 2, 19, 6, 75, 3, 42, 4, 44, 
    1, 67, 7, 79, 3, 88, 8, 40, 2, 53, 6, 52, 0, 34, 4, 66, 5, 14, 
    7, 26, 0, 78, 4, 69, 8, 56, 1, 52, 5, 99, 3, 17, 2, 79, 6, 83, 
    0, 62, 4, 72, 6, 96, 8, 39, 1, 77, 3, 38, 5, 10, 7, 67, 2, 64, 
    0, 93, 6,  8, 8, 53, 3, 12, 4, 78, 1, 69, 5, 77, 7, 68, 2, 33, 
    8, 45, 0, 39, 7, 31, 5, 75, 6, 90, 1, 16, 3, 28, 2, 26, 4, 25
  };
  const int q8025[] = {
    9, 9, // Number of jobs and machines
    2, 65, 1, 86, 7, 52, 3,  2, 6, 98, 4, 45, 5, 33, 0, 66, 8, 98, 
    7, 84, 3, 37, 5, 16, 0,  5, 8, 72, 6, 90, 4, 57, 2, 54, 1, 83, 
    6, 70, 2, 61, 8, 32, 5, 17, 4, 92, 3, 31, 7,  9, 1, 19, 0, 55, 
    8, 71, 4, 21, 7, 50, 1, 59, 6, 46, 2, 74, 5, 16, 0, 64, 3, 15, 
    6,  5, 0, 98, 2, 49, 1, 14, 8, 92, 7, 78, 4, 66, 5, 92, 3, 12, 
    2, 59, 7, 78, 3,  7, 6, 13, 5, 33, 0,  2, 1,  1, 8, 59, 4, 71, 
    1, 14, 8, 65, 2, 20, 4, 69, 0, 30, 3, 25, 5, 35, 7, 70, 6, 78, 
    7, 40, 6, 44, 1, 86, 3, 35, 2,  9, 5, 85, 4, 81, 8, 34, 0, 82, 
    2, 33, 4, 94, 0,  4, 3, 91, 5, 86, 8, 50, 7, 47, 1, 77, 6, 61
  };
  const int q8026[] = {
    9, 9, // Number of jobs and machines
    5,  5, 4, 56, 7, 50, 2, 27, 1, 40, 0, 34, 6, 55, 3, 51, 8, 44, 
    1, 89, 4,  3, 5, 10, 6, 81, 2, 92, 7, 36, 3, 23, 0, 28, 8, 67, 
    0,  1, 8, 54, 3, 63, 1,  4, 5, 22, 4,  6, 2,  9, 7, 24, 6, 18, 
    7, 44, 0, 92, 6, 87, 4, 50, 5, 66, 2,  7, 8, 37, 3, 54, 1, 26, 
    7, 82, 1,  3, 4, 12, 0, 78, 5, 95, 3, 51, 2, 65, 8,  9, 6, 82, 
    0, 97, 8, 56, 4, 93, 3, 89, 2, 73, 7, 15, 1,  3, 5, 83, 6, 53, 
    1, 57, 8, 75, 3,  5, 4, 93, 5, 52, 7, 62, 2, 24, 6, 40, 0,  5, 
    4, 89, 6, 62, 7, 98, 8, 72, 5, 23, 2, 42, 3, 14, 0, 27, 1,  7, 
    0, 97, 2, 96, 5, 73, 8, 76, 3, 17, 7, 48, 1, 29, 4, 43, 6,  8
  };
  const int q8027[] = {
    9, 9, // Number of jobs and machines
    6, 57, 2, 26, 5, 34, 1,  6, 4,  2, 7, 40, 8, 15, 0, 10, 3, 49, 
    5,  7, 7, 59, 3, 83, 1, 57, 0, 62, 2,  7, 6, 40, 4, 12, 8, 44, 
    4, 28, 2,  2, 7, 91, 0, 76, 5, 30, 8, 99, 6, 89, 3, 70, 1, 50, 
    7, 67, 3, 31, 0, 13, 4, 87, 2,  3, 6,  2, 5, 22, 8, 12, 1, 69, 
    6, 92, 0, 69, 8, 21, 7, 88, 5,  9, 1, 17, 2, 64, 4, 54, 3, 85, 
    8,  2, 4, 93, 2, 74, 0, 81, 1, 98, 3, 26, 7,  7, 6, 36, 5, 96, 
    2, 48, 6, 36, 1, 37, 7, 76, 8, 92, 0, 35, 4,  7, 3, 87, 5,  3, 
    0, 55, 2, 71, 1, 56, 6,  1, 4, 63, 8, 83, 7, 47, 3, 86, 5, 86, 
    1, 14, 2, 57, 4, 68, 5, 47, 3, 92, 6, 55, 7, 48, 8, 88, 0, 53
  };
  const int q8028[] = {
    9, 9, // Number of jobs and machines
    8, 33, 2, 55, 0, 90, 6,  7, 4,  7, 3, 68, 7, 96, 5, 75, 1, 47, 
    7, 57, 4, 31, 2, 95, 5, 32, 1, 47, 0, 71, 6, 77, 8, 49, 3, 54, 
    2, 75, 1, 42, 3, 17, 6, 17, 5, 20, 0, 83, 4, 71, 7, 44, 8, 68, 
    5, 55, 3, 50, 1, 80, 6, 90, 0, 59, 7,  6, 4, 47, 2,  7, 8, 47, 
    2, 54, 5, 48, 6, 58, 4, 53, 8, 33, 7, 91, 1,  9, 3, 49, 0, 22, 
    5, 34, 1, 73, 7, 26, 0, 94, 3, 99, 4, 47, 6, 17, 2, 10, 8, 68, 
    8,  8, 2, 13, 5, 32, 3, 58, 6, 78, 1, 28, 4, 57, 7, 74, 0, 75, 
    8, 96, 4,  8, 5, 21, 6, 67, 7, 32, 0, 45, 2,  1, 1, 28, 3, 35, 
    5, 91, 4,  4, 7, 77, 0, 69, 6, 84, 3, 99, 1, 36, 2, 40, 8, 14
  };
  const int q8029[] = {
    9, 9, // Number of jobs and machines
    6,  1, 8, 68, 1, 95, 3, 17, 2,  9, 4,  7, 7, 31, 0, 37, 5, 80, 
    2, 94, 0, 54, 5, 56, 1, 45, 8, 55, 7, 44, 3, 22, 6, 92, 4, 78, 
    1, 92, 4, 15, 6, 43, 5, 26, 8, 12, 7, 88, 0, 78, 3, 99, 2,  8, 
    0, 25, 3, 59, 7, 59, 1, 59, 4, 78, 2, 69, 5, 22, 8, 68, 6, 99, 
    6, 47, 2, 42, 8, 24, 4, 14, 5, 84, 1, 20, 0, 66, 7,  4, 3, 18, 
    7, 76, 0, 95, 4,  4, 2, 43, 6,  5, 8, 68, 1, 86, 5, 50, 3, 96, 
    7,  1, 6, 81, 4, 86, 2, 85, 8, 87, 5, 57, 1, 97, 0, 91, 3,  8, 
    5, 22, 4,  7, 2, 53, 1, 10, 8, 52, 7, 90, 6, 97, 0,  8, 3, 32, 
    0, 84, 1, 86, 4, 70, 6, 36, 5, 96, 2, 85, 3, 37, 8, 34, 7, 53
  };
  const int q8030[] = {
    9, 9, // Number of jobs and machines
    3, 83, 1,  1, 6, 29, 8, 86, 5, 22, 4, 14, 0, 49, 7, 12, 2, 12, 
    1, 98, 6, 81, 7,  2, 3, 82, 4, 55, 0, 49, 8,  5, 5, 93, 2, 20, 
    0, 96, 8, 58, 4, 97, 6, 27, 5, 91, 1, 28, 3, 96, 7, 28, 2, 88, 
    3, 17, 0, 30, 6, 96, 7, 95, 2, 70, 1, 97, 4, 52, 5, 33, 8, 89, 
    5, 47, 8, 55, 3, 78, 2, 79, 4, 20, 0, 64, 1, 12, 7, 42, 6, 10, 
    6, 53, 8, 80, 7, 90, 0, 24, 5, 31, 4, 65, 3, 35, 2, 68, 1, 48, 
    8, 12, 2, 22, 6, 15, 1, 10, 4, 27, 5, 41, 0, 41, 3, 98, 7, 99, 
    5, 50, 3, 61, 8, 23, 1, 57, 0, 87, 7,  3, 4, 96, 6, 26, 2, 71, 
    4, 40, 0, 38, 2, 54, 8, 38, 7, 57, 6, 25, 3, 32, 1, 64, 5, 25
  };
  const int q8031[] = {
    9, 9, // Number of jobs and machines
    6, 78, 8, 88, 5, 47, 0, 80, 1, 12, 3, 79, 4, 36, 7, 32, 2, 93, 
    3, 73, 0, 86, 2, 32, 1, 84, 7,  8, 8, 76, 6, 45, 5, 64, 4, 81, 
    8,  1, 5, 40, 2, 84, 1, 97, 0, 25, 7, 88, 6, 65, 3, 76, 4, 56, 
    4, 62, 1, 37, 5, 88, 3,  7, 8, 92, 2, 63, 0, 35, 6, 67, 7, 78, 
    7, 31, 2, 45, 8, 93, 0, 91, 6, 96, 4, 62, 5, 61, 1, 56, 3, 30, 
    6, 18, 7,  6, 3, 23, 2, 90, 1, 33, 8,  1, 5, 32, 0,  3, 4, 23, 
    0, 88, 6, 12, 2, 62, 3, 97, 8, 80, 4, 23, 7, 14, 5, 53, 1, 95, 
    0, 10, 1, 98, 5, 92, 6, 50, 2,  9, 3, 21, 7, 22, 4, 66, 8, 61, 
    7, 78, 0, 30, 8, 39, 5, 74, 2, 73, 3, 30, 1, 44, 6,  4, 4, 66
  };
  const int q8032[] = {
    9, 9, // Number of jobs and machines
    6,  4, 1, 78, 4, 41, 2, 21, 0, 46, 3, 43, 5, 64, 7, 12, 8, 54, 
    8, 75, 7, 57, 3, 54, 4, 30, 6, 48, 5, 79, 2, 16, 0,  9, 1, 76, 
    3, 30, 0, 95, 2,  5, 1, 73, 4, 50, 5, 33, 8, 57, 7, 77, 6, 28, 
    1, 80, 6, 71, 4, 71, 2, 44, 7, 72, 0, 56, 8,  9, 5,  2, 3, 43, 
    7, 29, 1,  4, 2, 77, 5, 21, 0, 91, 6, 79, 4, 74, 3, 62, 8, 51, 
    3, 57, 6, 48, 5, 36, 8, 21, 2, 58, 0, 57, 7, 28, 4, 44, 1, 82, 
    2, 41, 5, 92, 1,  5, 8, 80, 4, 40, 6, 22, 0, 10, 3, 19, 7, 53, 
    5, 58, 0, 27, 1, 93, 4, 13, 6, 80, 3, 54, 7, 48, 8, 75, 2, 84, 
    5, 24, 7, 25, 8, 52, 0, 59, 3, 73, 6, 26, 4, 63, 1, 61, 2, 42
  };
  const int q8033[] = {
    9, 9, // Number of jobs and machines
    4, 31, 3, 50, 1, 69, 8, 66, 6, 34, 7, 68, 2, 38, 5, 54, 0, 15, 
    1, 81, 2, 39, 0, 97, 3, 24, 4, 42, 5, 26, 7, 55, 6, 65, 8,  4, 
    6, 94, 7,  8, 1, 67, 5, 34, 4, 28, 3, 49, 2, 77, 0, 11, 8, 93, 
    1, 26, 7, 75, 2, 99, 0, 34, 4, 92, 8, 44, 6, 36, 5, 24, 3, 58, 
    7, 22, 6, 91, 3, 56, 0, 25, 1, 75, 4, 84, 8, 30, 5, 44, 2, 57, 
    3, 36, 6, 88, 5, 85, 0, 47, 1, 45, 4,  7, 7, 75, 8, 82, 2, 32, 
    0, 38, 6, 31, 2, 93, 5,  8, 7, 76, 8, 75, 4,  3, 1, 99, 3, 83, 
    2, 41, 5, 14, 8, 33, 3, 26, 0, 88, 6, 20, 1, 79, 4, 12, 7, 74, 
    3, 84, 2, 37, 0, 95, 7,  7, 5,  7, 6, 26, 1,  1, 8, 40, 4, 68
  };
  const int q8034[] = {
    9, 9, // Number of jobs and machines
    1, 63, 4, 13, 2, 75, 7, 52, 3,  7, 0, 90, 8, 11, 5, 50, 6, 46, 
    3, 59, 0, 71, 1,  5, 6, 72, 7, 70, 2, 40, 8, 46, 5, 71, 4, 80, 
    1, 41, 4, 96, 0, 62, 6, 29, 3,  8, 5, 36, 8, 40, 7, 45, 2, 94, 
    3, 85, 7, 34, 0,  6, 5,  5, 2, 26, 8, 85, 1,  1, 6, 33, 4, 76, 
    8, 38, 5, 86, 2, 82, 7, 12, 4, 20, 3, 66, 6, 95, 1, 93, 0, 39, 
    3, 28, 5, 77, 6,  4, 2, 46, 0, 10, 1, 50, 4, 41, 8, 41, 7, 75, 
    4, 65, 3, 48, 6, 90, 7, 65, 1, 93, 8, 90, 5, 66, 0, 12, 2, 59, 
    8, 38, 5, 21, 1,  9, 0, 11, 3, 66, 6, 71, 2, 24, 4, 35, 7, 34, 
    5, 11, 1, 58, 2, 56, 8, 42, 4, 38, 7,  7, 0, 41, 6, 14, 3,  4
  };
  const int q8035[] = {
    9, 9, // Number of jobs and machines
    1, 75, 7, 10, 6, 66, 3, 42, 0, 62, 8,  8, 5, 24, 2, 39, 4, 38, 
    8, 64, 3, 50, 0, 60, 1, 81, 5, 81, 7, 78, 4, 47, 2, 91, 6, 53, 
    2, 58, 4, 96, 8,  6, 3, 23, 7, 52, 5, 58, 0, 20, 6, 39, 1,  7, 
    5,  8, 2, 70, 0, 91, 6, 81, 1, 42, 8, 24, 4, 50, 3, 69, 7, 51, 
    1, 77, 7, 56, 5, 86, 6, 95, 3, 46, 0, 21, 2,  6, 8, 89, 4, 28, 
    2, 78, 8, 66, 0, 48, 7, 73, 4, 20, 3, 97, 5, 77, 6, 73, 1, 96, 
    8, 53, 0, 84, 6, 91, 2, 57, 1, 70, 4,  2, 7, 24, 3, 89, 5, 91, 
    0, 13, 8, 19, 4,  2, 1, 89, 2, 24, 7, 22, 3, 77, 5, 38, 6, 17, 
    5, 76, 4, 39, 3, 50, 0, 98, 2,  3, 7, 34, 6, 74, 8, 88, 1, 63
  };
  const int q8036[] = {
    9, 9, // Number of jobs and machines
    5, 32, 8, 30, 7, 31, 3, 57, 2, 95, 1, 33, 6, 87, 4, 61, 0, 69, 
    7, 79, 4, 36, 2,  4, 6, 80, 8, 31, 1, 38, 0, 27, 5, 57, 3, 69, 
    8, 73, 7, 20, 6, 27, 0, 29, 1, 71, 5, 58, 3, 69, 2, 66, 4, 82, 
    2, 37, 8, 37, 4, 79, 0, 81, 6, 15, 7, 36, 5, 44, 1, 95, 3, 98, 
    8, 68, 0, 38, 2, 73, 4, 52, 3, 59, 5, 53, 6, 56, 1, 49, 7,  4, 
    0, 98, 2, 59, 7, 90, 6, 44, 4, 43, 3, 82, 5, 28, 8, 88, 1, 16, 
    2, 17, 5, 14, 1, 80, 6, 75, 0, 47, 4,  8, 7,  6, 3, 39, 8, 48, 
    1,  5, 6, 38, 0, 94, 8, 61, 7, 74, 3,  5, 4, 44, 2, 94, 5, 18, 
    8, 37, 5, 59, 2, 51, 1, 23, 4, 41, 3, 77, 0, 79, 7, 82, 6, 70
  };
  const int q8037[] = {
    9, 9, // Number of jobs and machines
    8, 71, 5, 62, 7,  3, 1, 49, 4, 98, 2, 99, 0, 79, 3, 39, 6,  6, 
    5, 98, 4, 42, 3, 32, 7, 46, 6, 89, 1,  3, 8, 36, 0, 58, 2, 64, 
    5, 61, 3, 98, 0, 44, 6, 19, 7, 60, 8,  7, 4, 19, 1, 84, 2, 65, 
    4, 97, 8, 39, 7, 27, 0, 78, 5, 74, 3,  8, 2, 90, 1, 24, 6, 98, 
    0, 85, 5, 22, 6, 19, 2, 72, 7,  7, 3, 71, 1, 71, 8, 14, 4, 61, 
    7, 89, 3,  5, 2, 89, 6, 81, 8, 96, 5, 88, 1, 71, 0, 45, 4, 56, 
    2, 92, 0, 99, 4, 51, 5,  5, 6,  2, 7, 76, 8, 42, 1, 62, 3, 18, 
    0, 15, 2, 32, 7, 73, 4, 28, 5, 34, 3, 94, 6, 37, 1,  3, 8, 51, 
    6, 28, 5, 73, 2, 99, 8,  8, 4, 32, 3, 34, 1, 51, 7, 75, 0, 86
  };
  const int q8038[] = {
    9, 9, // Number of jobs and machines
    2, 52, 3,  3, 6, 68, 0, 69, 4, 91, 5, 87, 8,  2, 7,  4, 1, 34, 
    3, 72, 2, 73, 7, 43, 8, 24, 1, 55, 6, 84, 5, 29, 0,  6, 4, 85, 
    5, 53, 4, 92, 1, 87, 3, 54, 0, 54, 7, 85, 2, 11, 8, 67, 6, 33, 
    8, 13, 0, 58, 5, 26, 3, 39, 2, 58, 6, 40, 1, 44, 4, 80, 7, 68, 
    6, 74, 3, 39, 7, 53, 1, 59, 8, 39, 4,  5, 0, 20, 5, 28, 2, 71, 
    1,  2, 4,  7, 3, 69, 0, 82, 8, 88, 5, 91, 7, 46, 6,  2, 2, 34, 
    6, 49, 1, 81, 2, 79, 4, 66, 3, 67, 5, 81, 7, 54, 8, 45, 0, 17, 
    0, 39, 5, 33, 8, 74, 4, 39, 3, 31, 1, 59, 6, 58, 7, 13, 2,  9, 
    2, 96, 1,  7, 5, 42, 8,  8, 7, 87, 3, 37, 6, 77, 0, 47, 4, 89
  };
  const int q8039[] = {
    9, 9, // Number of jobs and machines
    7, 55, 5,  5, 2, 31, 4, 71, 3, 82, 6, 44, 8, 79, 0, 12, 1, 51, 
    3, 10, 4, 67, 6, 32, 5, 81, 7, 10, 2, 57, 0, 50, 8, 14, 1, 94, 
    1, 25, 8, 32, 2, 83, 3, 65, 6, 23, 5, 82, 7, 53, 4, 99, 0,  6, 
    3, 67, 2, 44, 6, 68, 4, 36, 0, 73, 1, 32, 5,  3, 7, 93, 8, 46, 
    2, 65, 5, 21, 4, 34, 3, 64, 0, 90, 8, 47, 6, 87, 7, 59, 1, 50, 
    5, 83, 7, 79, 3, 42, 0, 13, 2, 30, 8, 19, 6, 14, 4, 15, 1, 69, 
    0, 31, 1, 40, 7, 86, 4, 17, 6, 41, 5, 10, 2, 46, 3, 26, 8, 93, 
    0, 91, 4, 92, 1, 31, 5, 22, 7,  3, 6, 28, 8, 74, 2, 32, 3, 90, 
    3, 48, 2,  4, 8, 32, 4, 73, 5, 40, 1, 59, 6, 17, 7, 78, 0, 58
  };
  const int q8040[] = {
    9, 9, // Number of jobs and machines
    0, 57, 2, 62, 4, 10, 8, 19, 5, 62, 1, 92, 3, 60, 7, 40, 6, 80, 
    6, 43, 4, 29, 8,  4, 3, 33, 5, 53, 1, 25, 7, 40, 2, 74, 0, 99, 
    5, 15, 4, 19, 2, 24, 6, 92, 3, 24, 1, 72, 8,  9, 0, 17, 7, 13, 
    6, 97, 0,  1, 5, 30, 1,  6, 2, 48, 8, 63, 7, 49, 4, 87, 3, 82, 
    1, 72, 3, 17, 5, 88, 0, 43, 2, 80, 4, 39, 6, 37, 7, 10, 8, 88, 
    7, 57, 5,  8, 4, 73, 3, 21, 8, 82, 6, 16, 2, 64, 0, 87, 1, 51, 
    5, 86, 2, 62, 3, 24, 1, 46, 0, 47, 6, 96, 4,  6, 8, 46, 7, 57, 
    0, 34, 8, 56, 5, 15, 2, 32, 3, 99, 7, 20, 4, 18, 1, 14, 6, 43, 
    2,  2, 5, 59, 6, 69, 1, 94, 0, 21, 7, 31, 8,  6, 4, 18, 3, 83
  };
  const int q8041[] = {
    9, 9, // Number of jobs and machines
    3, 73, 2, 75, 1, 53, 5, 17, 8, 69, 7, 15, 0, 21, 6, 68, 4, 49, 
    2, 26, 8, 10, 4, 80, 1, 57, 3, 94, 5,  9, 0, 66, 7, 64, 6, 23, 
    5, 27, 1, 60, 3, 60, 6, 69, 0,  5, 7, 73, 2, 74, 8, 41, 4, 26, 
    8,  6, 0,  1, 4,  8, 1, 37, 6, 35, 7, 61, 2, 36, 5, 63, 3, 32, 
    8, 23, 6,  9, 1, 85, 4, 53, 0, 30, 5, 46, 2, 55, 3, 12, 7, 25, 
    6, 46, 4, 20, 5,  5, 2, 78, 3, 50, 7, 58, 8, 22, 1, 73, 0, 87, 
    6,  6, 8, 36, 5, 35, 4, 25, 7, 18, 3, 94, 2, 60, 0, 38, 1, 33, 
    1, 71, 8, 80, 2,  7, 6, 78, 3, 60, 7, 42, 4, 57, 5, 37, 0,  2, 
    2, 77, 0, 86, 4, 51, 8, 11, 5, 86, 1, 68, 7, 58, 6, 43, 3, 88
  };
  const int q8042[] = {
    9, 9, // Number of jobs and machines
    4, 96, 3, 19, 8, 26, 1, 19, 5, 39, 7, 15, 0, 87, 2, 48, 6, 35, 
    7, 73, 0, 15, 3, 27, 1, 19, 2,  9, 8, 64, 6, 55, 5, 15, 4, 60, 
    7, 30, 3, 55, 1, 86, 6, 71, 2, 15, 8, 15, 5, 92, 4, 84, 0,  3, 
    0, 30, 3, 54, 6, 30, 7, 57, 8, 34, 4, 16, 1, 38, 2, 44, 5, 23, 
    0, 30, 3, 69, 5, 55, 2, 97, 4, 47, 8, 32, 6, 46, 7, 44, 1, 54, 
    1, 40, 7, 87, 4, 24, 2, 24, 8, 82, 0, 28, 3, 82, 6, 80, 5, 71, 
    1, 13, 0, 11, 5, 10, 4, 62, 3, 37, 2, 68, 8,  7, 7,  2, 6,  7, 
    5, 73, 7, 54, 0, 63, 1, 59, 3, 34, 6, 40, 4, 58, 2, 47, 8, 26, 
    0, 55, 4, 87, 1,  7, 7, 76, 2, 99, 5,  4, 3, 15, 8,  2, 6, 39
  };
  const int q8043[] = {
    9, 9, // Number of jobs and machines
    1, 89, 4, 71, 3, 11, 7, 23, 2, 53, 8, 55, 5, 94, 0, 77, 6, 29, 
    3, 68, 4, 75, 5, 68, 1, 50, 8, 31, 6, 96, 2, 10, 7, 33, 0, 88, 
    5, 23, 4, 27, 1, 51, 6,  2, 2, 57, 7, 91, 8,  2, 0, 82, 3, 84, 
    3, 78, 2, 79, 5, 80, 4, 67, 7, 70, 6, 93, 0, 63, 8, 23, 1, 62, 
    7,  5, 6, 70, 0, 92, 3,  5, 2, 68, 1, 49, 4, 91, 8, 90, 5, 96, 
    0, 75, 6,  8, 8, 85, 5, 63, 7, 53, 2, 25, 4, 89, 1, 50, 3, 96, 
    0, 40, 7, 15, 1,  5, 3, 16, 5, 14, 8, 44, 4, 21, 2, 23, 6, 79, 
    8, 99, 5,  8, 1, 69, 6, 56, 3, 58, 7, 27, 2, 22, 4, 99, 0, 38, 
    7, 61, 3, 31, 1, 81, 6, 79, 0,  9, 8, 53, 2, 49, 5, 51, 4, 88
  };
  const int q8044[] = {
    9, 9, // Number of jobs and machines
    3, 16, 8, 58, 5, 51, 1, 58, 2, 32, 4, 87, 0, 36, 6, 25, 7, 21, 
    7, 87, 0, 73, 4, 24, 3, 43, 6, 84, 8, 63, 1, 45, 2, 80, 5, 15, 
    7, 78, 0, 34, 4, 36, 8, 45, 3, 79, 5, 91, 6, 21, 1, 48, 2, 65, 
    4, 38, 7, 18, 2, 78, 8,  9, 3, 91, 6,  8, 5, 42, 0, 93, 1, 46, 
    7, 14, 8,  7, 6, 60, 1, 40, 5, 10, 3, 63, 4, 51, 2, 68, 0, 29, 
    0, 51, 2, 69, 6, 18, 7, 97, 1,  6, 8, 26, 3, 74, 5, 97, 4, 18, 
    1,  1, 2, 27, 3, 88, 7, 43, 4, 20, 6, 81, 5, 72, 0,  3, 8, 95, 
    8, 66, 3, 10, 0, 95, 5, 29, 6, 69, 2, 31, 4, 58, 7, 70, 1, 22, 
    7, 13, 6, 64, 0, 89, 1, 97, 4, 43, 3, 46, 2, 80, 8,  3, 5, 74
  };
  const int q8045[] = {
    9, 9, // Number of jobs and machines
    2, 61, 7, 33, 8, 30, 3, 11, 5, 28, 0, 87, 1, 48, 4, 63, 6, 23, 
    3, 57, 5, 44, 8, 14, 6, 97, 1, 14, 0,  7, 4, 72, 2, 51, 7, 13, 
    5, 21, 3, 18, 1, 20, 6, 98, 0, 37, 4, 48, 8,  3, 7, 23, 2, 31, 
    0, 93, 5,  9, 6, 90, 2, 91, 4, 77, 7, 83, 3, 88, 8, 39, 1, 84, 
    8, 25, 3, 75, 0, 33, 5, 59, 4, 88, 6, 51, 7, 54, 2, 57, 1, 62, 
    2, 78, 6, 71, 5,  6, 3, 86, 0, 58, 1, 15, 4, 39, 7, 39, 8, 61, 
    4, 57, 7, 71, 5, 78, 6, 91, 8, 66, 1, 79, 3, 93, 0, 74, 2, 51, 
    0, 97, 8, 25, 5, 44, 6, 84, 1, 34, 4,  8, 7, 61, 2, 43, 3, 63, 
    3, 21, 0, 25, 6, 77, 5, 87, 4, 59, 2, 17, 7, 66, 1, 21, 8, 21
  };
  const int q8046[] = {
    9, 9, // Number of jobs and machines
    6, 53, 2, 20, 0, 22, 3, 39, 1, 34, 8, 85, 4, 77, 5, 83, 7, 69, 
    3, 59, 8, 72, 2, 15, 5, 92, 0, 88, 7,  7, 6, 30, 1, 25, 4, 71, 
    1, 29, 5, 58, 6, 11, 0, 56, 8, 56, 2, 12, 3, 10, 4, 10, 7,  2, 
    2, 41, 1,  7, 4, 93, 3, 11, 8,  2, 7, 34, 6,  2, 5, 27, 0,  4, 
    8, 39, 4, 33, 5, 56, 3, 60, 7, 58, 0, 45, 6, 23, 1, 83, 2,  2, 
    1, 97, 8, 38, 5, 39, 6, 22, 2, 18, 3, 71, 4, 94, 7,  9, 0, 89, 
    5, 88, 0, 78, 1, 88, 3, 71, 2,  1, 4, 84, 7,  3, 6, 22, 8, 52, 
    0, 83, 7, 36, 3, 24, 2, 25, 4, 90, 6, 58, 1, 58, 8, 74, 5,  5, 
    7, 55, 5, 42, 3, 79, 2, 46, 4, 53, 0, 17, 6, 70, 8, 59, 1, 11
  };
  const int q8047[] = {
    9, 9, // Number of jobs and machines
    1, 67, 4, 16, 0, 78, 8, 93, 2, 57, 7, 29, 6, 82, 5, 68, 3, 67, 
    4, 72, 7, 63, 3, 98, 1, 39, 2, 96, 8, 42, 0, 10, 5, 96, 6, 93, 
    4, 90, 0, 38, 2, 23, 6, 54, 3, 25, 8, 81, 7, 99, 1, 44, 5, 62, 
    2, 42, 4, 95, 0, 19, 7, 90, 6, 97, 5,  7, 3, 82, 8, 77, 1, 43, 
    3,  8, 5,  6, 2, 31, 6, 61, 8, 18, 4, 64, 0, 45, 7, 47, 1, 61, 
    5, 42, 2, 81, 7, 65, 8, 82, 3,  6, 1, 25, 6, 81, 0, 24, 4, 33, 
    3, 24, 8, 89, 4, 32, 2, 73, 7, 69, 5, 12, 1, 91, 0, 57, 6, 32, 
    0,  5, 5,  3, 8, 63, 2, 64, 1, 45, 3, 39, 7, 24, 6, 31, 4, 45, 
    1, 20, 2, 10, 5, 10, 4, 46, 0, 10, 6,  7, 8, 23, 3, 58, 7, 24
  };
  const int q8048[] = {
    9, 9, // Number of jobs and machines
    0, 55, 8,  5, 2, 32, 5, 81, 7,  3, 6, 11, 4, 25, 1, 63, 3, 96, 
    8, 40, 5, 75, 0, 97, 1, 27, 3, 79, 4, 43, 6, 21, 7, 66, 2, 70, 
    8, 34, 5, 83, 4, 42, 2, 83, 0, 89, 7,  6, 1, 34, 3, 99, 6, 82, 
    2, 51, 1, 83, 4, 31, 6, 23, 5, 69, 7, 56, 0, 77, 8,  1, 3, 55, 
    2, 75, 5, 34, 0, 98, 4, 26, 3, 39, 1, 64, 6, 69, 8,  1, 7, 58, 
    1, 51, 0, 14, 4, 99, 6, 98, 8, 32, 2, 49, 7, 90, 3,  2, 5, 94, 
    1,  9, 5, 85, 8, 41, 4, 84, 3, 18, 7, 24, 6, 36, 2,  6, 0, 19, 
    3, 77, 4, 40, 8, 64, 6, 36, 5, 11, 0, 34, 1, 37, 2, 33, 7, 60, 
    4, 75, 6,  5, 8, 53, 0, 39, 3, 58, 5, 26, 7, 82, 1, 25, 2, 74
  };
  const int q8049[] = {
    9, 9, // Number of jobs and machines
    8, 19, 6, 76, 2, 95, 4,  2, 3, 75, 1, 65, 7, 58, 5, 77, 0, 21, 
    6, 92, 7, 81, 0, 35, 1, 93, 5, 93, 4, 13, 3,  6, 2, 69, 8, 91, 
    0, 12, 6,  6, 8, 45, 7, 17, 5,  3, 4, 91, 1, 92, 3, 36, 2, 51, 
    6, 16, 8, 56, 5, 85, 2, 17, 0, 49, 1, 88, 4, 31, 7, 63, 3, 46, 
    4,  2, 1, 88, 0, 10, 8, 28, 5, 46, 2,  8, 7, 37, 6, 12, 3, 56, 
    4, 97, 7, 73, 1, 19, 3, 39, 6,  1, 2, 44, 8, 25, 5, 60, 0, 31, 
    8, 83, 4, 14, 0, 26, 2, 29, 6, 16, 7, 23, 5, 65, 1, 39, 3, 37, 
    7, 72, 1, 78, 3, 82, 8, 87, 4,  1, 5, 80, 0, 27, 6, 94, 2, 74, 
    4, 59, 6, 32, 3, 65, 7, 78, 0, 16, 2, 74, 1, 48, 8, 15, 5, 16
  };
  const int q8050[] = {
    9, 9, // Number of jobs and machines
    2, 39, 0, 70, 5, 95, 3, 49, 6, 80, 4,  5, 7, 99, 1, 32, 8, 84, 
    8, 29, 3, 34, 4, 29, 0, 75, 2,  5, 1, 86, 7, 34, 5, 26, 6, 77, 
    1, 44, 6, 42, 7, 68, 8, 35, 2, 63, 0, 95, 5, 40, 4, 23, 3, 56, 
    2, 90, 5, 16, 8, 96, 1, 29, 4, 36, 6, 87, 7, 43, 0, 75, 3, 53, 
    5, 87, 0, 94, 1, 34, 3, 25, 2, 54, 6, 86, 7, 53, 4, 79, 8,  5, 
    7, 68, 6, 26, 3, 45, 4, 21, 5, 64, 0, 12, 8, 97, 2,  8, 1, 84, 
    7, 95, 4,  7, 1, 13, 8, 77, 3, 79, 0, 46, 2, 15, 6, 19, 5, 44, 
    7, 73, 8, 60, 1, 22, 5, 76, 0, 16, 2, 25, 4, 52, 3, 48, 6, 66, 
    6, 71, 5, 85, 0, 39, 7, 84, 1, 74, 8, 51, 2, 38, 4, 59, 3, 72
  };
  const int q8051[] = {
    9, 9, // Number of jobs and machines
    3,  5, 5, 52, 2, 54, 8, 69, 4, 74, 1, 17, 7, 20, 0, 53, 6, 56, 
    1, 76, 5, 90, 7, 43, 4, 30, 6, 33, 8, 43, 3, 54, 2, 70, 0, 27, 
    2, 39, 0,  6, 7, 34, 6, 30, 8, 59, 3, 18, 5, 60, 4, 36, 1, 12, 
    2, 54, 5, 87, 4, 83, 7, 55, 6, 42, 0, 66, 1, 70, 8, 28, 3, 17, 
    7, 55, 8, 56, 0, 90, 1, 97, 5, 26, 3, 52, 6, 97, 2, 52, 4, 91, 
    0, 42, 8, 72, 2, 84, 7, 65, 1, 14, 3,  6, 5, 66, 6, 14, 4, 83, 
    6, 22, 4, 88, 8, 24, 2, 97, 3,  3, 0,  7, 1,  7, 5, 11, 7,  3, 
    3,  3, 6, 61, 8, 51, 1, 79, 2, 85, 4, 96, 7, 34, 0, 57, 5, 91, 
    4, 40, 5, 92, 8, 73, 7, 33, 6, 72, 2, 69, 0, 52, 1, 89, 3, 94
  };
  const int q8052[] = {
    9, 9, // Number of jobs and machines
    6, 22, 7, 28, 0, 42, 3, 53, 5, 89, 1, 94, 4, 19, 2, 67, 8, 26, 
    1, 14, 2, 64, 0,  5, 8, 11, 7, 78, 4, 85, 5, 45, 3, 50, 6, 79, 
    7, 51, 2,  3, 3, 62, 8, 94, 0, 70, 5, 13, 6, 28, 4, 63, 1,  2, 
    6, 54, 7, 95, 4,  7, 1, 92, 2, 16, 8, 49, 3, 76, 5, 65, 0, 13, 
    4, 50, 7, 82, 8, 30, 0, 13, 2, 18, 6, 58, 1, 22, 5, 91, 3, 65, 
    0, 88, 8, 20, 3,  5, 2, 63, 4, 27, 1, 58, 5, 13, 7, 62, 6, 60, 
    0, 36, 2, 64, 4,  2, 5,  6, 8, 73, 1, 84, 6, 54, 3, 41, 7, 55, 
    6, 84, 4, 89, 1, 89, 3, 73, 7, 64, 5, 95, 8, 28, 2, 19, 0, 62, 
    2, 96, 1, 14, 0, 76, 7, 59, 6, 50, 8, 97, 3, 92, 4, 92, 5, 62
  };
  const int q8053[] = {
    9, 9, // Number of jobs and machines
    7, 70, 8, 63, 1, 89, 6, 25, 0,  9, 2, 87, 3, 23, 4, 80, 5,  2, 
    6, 55, 1,  7, 0, 32, 2, 99, 5, 22, 8, 71, 7, 49, 3,  2, 4, 85, 
    6, 74, 4, 38, 0, 45, 8, 39, 7, 41, 5, 30, 3,  5, 1, 50, 2, 96, 
    0, 24, 4, 15, 6,  4, 7, 83, 1, 74, 5, 91, 3,  9, 8, 31, 2, 28, 
    8, 25, 4, 35, 7, 14, 1, 84, 2,  2, 0,  9, 6, 54, 5, 88, 3, 14, 
    3, 20, 2, 38, 0, 52, 4, 66, 6, 40, 1, 64, 7, 47, 5, 16, 8, 75, 
    7, 81, 2, 82, 1, 62, 5, 60, 3, 77, 6, 48, 8, 39, 0, 88, 4, 26, 
    2, 96, 1, 25, 5, 68, 4,  8, 7, 49, 0, 70, 8, 83, 3, 59, 6,  1, 
    2, 60, 6, 86, 0, 80, 3, 24, 1, 11, 4, 78, 8, 46, 5, 99, 7, 73
  };
  const int q8054[] = {
    9, 9, // Number of jobs and machines
    8, 40, 3, 99, 1, 32, 6, 45, 7, 36, 0, 32, 5, 65, 4, 83, 2, 82, 
    7, 88, 1, 63, 4, 34, 6, 77, 8, 42, 2, 17, 3, 49, 0, 19, 5, 87, 
    7, 25, 6, 75, 8, 42, 0, 50, 2, 73, 1, 21, 3, 56, 4, 99, 5, 64, 
    8, 99, 0, 34, 1, 24, 6, 84, 5, 60, 3, 11, 7, 56, 4, 80, 2, 38, 
    2, 14, 6, 99, 3, 83, 4, 83, 5, 77, 0, 69, 8, 47, 1, 63, 7, 81, 
    3, 70, 1, 79, 4, 78, 5, 86, 2, 14, 7, 54, 8, 67, 0, 98, 6, 56, 
    5, 72, 0, 85, 7, 35, 4, 83, 3, 22, 8, 47, 1, 96, 2, 92, 6, 14, 
    8, 36, 5, 20, 0, 81, 3, 11, 6, 68, 4, 11, 1, 61, 7, 31, 2, 19, 
    6, 13, 7, 55, 1, 22, 2, 97, 4, 27, 8, 48, 0, 79, 3, 82, 5, 22
  };
  const int q8055[] = {
    9, 9, // Number of jobs and machines
    1, 86, 3, 24, 0, 98, 6, 48, 5, 60, 2, 50, 4, 91, 8, 26, 7, 37, 
    3, 83, 0, 61, 8, 44, 5, 86, 2, 21, 1, 28, 7, 49, 6, 81, 4, 84, 
    7, 67, 2, 86, 0, 86, 8, 27, 4, 34, 5, 76, 1, 39, 3, 32, 6, 19, 
    3, 99, 5, 14, 0, 15, 8,  4, 1, 25, 4, 73, 7, 19, 6, 80, 2, 72, 
    1, 53, 6, 66, 5, 55, 8, 92, 2, 74, 0, 52, 4, 83, 7,  8, 3, 57, 
    3, 52, 2,  1, 8, 94, 4, 61, 1, 24, 5, 97, 6, 86, 0, 86, 7, 35, 
    1, 82, 8, 94, 5, 93, 3, 93, 4, 60, 0, 55, 2, 81, 6, 32, 7,  9, 
    1, 18, 6, 51, 5, 80, 8, 71, 3, 34, 7, 72, 4, 36, 0, 89, 2,  4, 
    7, 41, 6, 54, 3, 49, 5, 33, 8, 58, 0, 51, 1, 87, 4,  9, 2, 43
  };
  const int q8056[] = {
    9, 9, // Number of jobs and machines
    6,  3, 4, 54, 3, 65, 5, 11, 7, 19, 0, 79, 1, 78, 8,  8, 2, 53, 
    6, 13, 5, 36, 7, 79, 0, 75, 3, 26, 2, 57, 4, 56, 8, 31, 1, 60, 
    5, 51, 1, 27, 6, 15, 2, 15, 4, 17, 0, 99, 3, 81, 8, 74, 7, 11, 
    4, 68, 3, 28, 5, 98, 6, 81, 1, 67, 8, 83, 0, 77, 7, 96, 2, 50, 
    1,  1, 4, 77, 5, 47, 8, 54, 6, 23, 2, 22, 0, 59, 3, 40, 7,  5, 
    5, 86, 0, 35, 1, 48, 8, 70, 6, 69, 2, 67, 4, 23, 7, 30, 3, 51, 
    2, 61, 0, 11, 3, 81, 7, 67, 1,  5, 8, 95, 6, 34, 4, 81, 5, 60, 
    5, 14, 7, 32, 3, 41, 1, 83, 0, 89, 8, 88, 6, 92, 2, 50, 4, 78, 
    1, 89, 2, 52, 0, 55, 6, 61, 7, 46, 4, 67, 3, 48, 8, 39, 5, 10
  };
  const int q8057[] = {
    9, 9, // Number of jobs and machines
    0, 17, 2, 51, 6, 26, 8, 43, 7, 99, 5,  5, 3, 87, 4, 67, 1, 47, 
    3,  3, 1, 83, 8, 47, 5, 77, 7, 10, 2, 46, 4, 38, 6, 27, 0, 23, 
    4, 64, 5, 61, 6, 94, 3, 90, 8, 40, 7, 54, 1, 57, 2,  5, 0,  6, 
    5, 67, 4, 64, 8, 59, 3, 30, 1, 57, 0, 35, 2, 67, 7, 86, 6, 58, 
    6, 77, 1, 83, 7, 73, 8, 47, 0, 29, 4,  7, 3, 70, 2, 23, 5, 80, 
    7, 52, 8, 18, 5, 33, 6, 44, 1,  9, 3, 13, 0, 80, 4, 37, 2, 12, 
    1, 39, 3, 66, 4, 56, 8, 65, 5, 25, 0, 29, 2, 79, 7, 32, 6, 87, 
    8, 80, 0, 51, 3, 59, 1, 57, 6, 15, 4, 51, 5, 93, 7, 13, 2, 36, 
    3, 48, 5,  1, 0, 29, 8, 18, 1, 18, 4, 32, 2, 20, 6,  2, 7, 82
  };
  const int q8058[] = {
    9, 9, // Number of jobs and machines
    2, 76, 3, 76, 0, 18, 8, 95, 5, 85, 1, 46, 4, 64, 6, 93, 7, 43, 
    0, 20, 8, 49, 6, 21, 3, 21, 2, 38, 5, 20, 7, 65, 4, 52, 1, 50, 
    6, 58, 0, 94, 7, 92, 3,  7, 1, 90, 4, 89, 8, 50, 2, 60, 5, 20, 
    0, 55, 8, 46, 5, 38, 4, 99, 3, 61, 6, 12, 1, 27, 7, 83, 2, 57, 
    8,  1, 2, 90, 4, 94, 0, 84, 5, 56, 3,  8, 1, 24, 6, 45, 7, 17, 
    2, 61, 6, 81, 1, 67, 8, 29, 3, 48, 7, 65, 4, 64, 0, 34, 5, 98, 
    0, 68, 3, 25, 5,  2, 7,  4, 4, 77, 8, 14, 1, 74, 6, 64, 2, 79, 
    8, 50, 2, 22, 0, 48, 1, 30, 5, 13, 6, 83, 4, 71, 7, 10, 3, 43, 
    8, 97, 5, 90, 1,  8, 4, 28, 2, 68, 7, 83, 6, 56, 3, 18, 0, 95
  };
  const int q8059[] = {
    9, 9, // Number of jobs and machines
    1, 71, 3, 78, 5, 90, 7, 28, 0, 14, 8, 79, 2, 94, 6, 42, 4, 59, 
    0, 35, 8, 78, 3, 14, 7, 86, 1, 68, 2, 45, 5, 74, 4, 15, 6, 87, 
    8, 94, 0, 52, 7,  8, 3, 17, 4, 21, 2, 14, 1, 39, 6, 27, 5, 78, 
    6, 35, 7, 86, 8, 94, 3, 73, 1, 63, 5, 80, 4, 83, 2, 39, 0, 19, 
    6, 46, 5, 66, 1, 14, 0, 10, 2, 21, 8, 14, 7, 91, 3, 45, 4, 91, 
    2, 10, 3, 14, 5, 14, 6, 23, 4, 24, 0, 43, 7, 47, 8, 39, 1, 64, 
    4, 94, 1, 97, 8, 72, 6, 99, 7, 55, 5,  9, 0, 67, 3,  4, 2, 51, 
    3, 82, 0, 22, 8, 77, 6, 73, 7, 41, 5, 18, 1, 15, 4, 96, 2, 32, 
    6, 56, 0, 14, 2, 74, 5,  8, 8, 70, 4,  5, 3, 16, 7,  2, 1, 12
  };
  const int q8060[] = {
    9, 9, // Number of jobs and machines
    1, 37, 7, 71, 3, 63, 6, 45, 0,  1, 5,  9, 4, 14, 8, 27, 2, 52, 
    8, 89, 0, 90, 3, 20, 4, 29, 5, 85, 2, 55, 6, 30, 1, 81, 7,  4, 
    4, 85, 5, 78, 7, 32, 8, 29, 3, 33, 0, 29, 2, 15, 1, 36, 6, 94, 
    3, 24, 0, 46, 7, 75, 1,  3, 6,  2, 5, 89, 4, 99, 8, 24, 2, 94, 
    0, 43, 2, 18, 6, 74, 8, 41, 5, 37, 1,  5, 7, 20, 3, 69, 4, 43, 
    8, 82, 6, 37, 5, 13, 3, 61, 4, 87, 7, 83, 2, 76, 1, 22, 0, 78, 
    3, 53, 0, 54, 2, 89, 6, 60, 5, 93, 8, 77, 4, 96, 7, 85, 1, 72, 
    4, 64, 8, 23, 0, 33, 7, 72, 6, 80, 5, 64, 1,  4, 3, 97, 2, 21, 
    0, 35, 3, 34, 5, 94, 1, 97, 6, 50, 4, 98, 8, 32, 7,  8, 2, 96
  };
  const int q8061[] = {
    9, 9, // Number of jobs and machines
    2, 98, 8, 79, 7, 11, 3,  8, 6, 62, 0, 91, 1, 85, 5, 27, 4, 54, 
    0, 20, 5, 46, 4, 69, 7, 32, 1, 51, 2, 48, 3, 81, 8,  8, 6, 71, 
    5, 30, 2, 22, 3, 58, 4, 30, 6, 54, 0, 84, 8, 45, 1, 92, 7, 82, 
    6, 71, 7, 44, 1, 35, 5, 27, 4,  5, 2, 24, 0, 38, 3, 30, 8, 64, 
    4, 23, 0, 76, 1, 86, 6, 24, 7, 90, 3,  8, 5, 65, 2, 25, 8, 35, 
    0,  9, 6,  4, 1, 32, 4, 71, 3, 76, 7, 62, 5, 73, 8, 59, 2, 99, 
    3, 96, 6, 49, 2, 26, 4, 13, 5, 45, 1, 78, 7, 59, 0, 68, 8, 74, 
    3, 57, 4, 98, 0, 88, 2, 41, 5, 80, 8, 53, 1, 44, 6,  2, 7, 51, 
    4, 57, 7, 33, 1, 97, 3, 23, 0, 83, 6, 45, 8, 25, 2, 61, 5, 49
  };
  const int q8062[] = {
    9, 9, // Number of jobs and machines
    6, 95, 1, 95, 4, 72, 7, 84, 8, 69, 3, 50, 5,  9, 2, 43, 0, 75, 
    1, 17, 4, 49, 8, 90, 6, 93, 0, 50, 2, 75, 3, 41, 5, 55, 7, 16, 
    7, 67, 8,  3, 3, 75, 6, 99, 5, 47, 4, 68, 2, 86, 0, 61, 1, 23, 
    2, 49, 8, 68, 6, 94, 7, 32, 3, 58, 5, 38, 4, 13, 1, 38, 0, 46, 
    6, 82, 0, 11, 4, 37, 2, 79, 8, 28, 5, 50, 1, 89, 7, 91, 3, 47, 
    8, 73, 3, 31, 0, 13, 6, 92, 4, 90, 1, 86, 7, 20, 5, 66, 2, 45, 
    1, 63, 3, 79, 7, 62, 4, 52, 2, 70, 8, 21, 5, 40, 0,  2, 6, 58, 
    7, 70, 4, 60, 0, 23, 2, 99, 5, 38, 3, 14, 8, 14, 1, 75, 6, 58, 
    5, 91, 2, 82, 8, 42, 1, 58, 6, 80, 4, 71, 0, 65, 7, 36, 3, 53
  };
  const int q8063[] = {
    9, 9, // Number of jobs and machines
    1, 39, 6, 94, 5, 32, 2, 90, 3, 36, 8, 97, 0, 12, 4, 61, 7, 84, 
    5, 79, 3, 23, 1, 86, 4, 56, 8, 65, 0, 28, 7, 49, 2, 83, 6, 49, 
    3,  8, 5, 34, 1, 92, 0, 33, 6, 15, 7, 35, 8, 34, 2,  5, 4, 54, 
    0, 20, 6, 96, 4, 75, 3, 95, 7, 24, 2, 16, 5, 48, 8, 61, 1, 62, 
    8, 69, 6, 78, 5, 93, 2, 61, 7, 67, 3, 18, 1, 75, 0, 84, 4, 44, 
    5, 93, 1, 85, 0, 34, 2, 73, 4, 41, 8, 20, 3,  7, 6, 18, 7, 71, 
    6, 70, 2, 12, 1, 40, 0, 45, 7, 14, 3, 89, 5, 91, 8, 85, 4,  7, 
    4, 38, 8, 62, 6, 87, 3, 62, 0, 16, 7, 71, 1, 41, 5,  7, 2, 24, 
    5, 67, 4, 30, 0,  8, 7, 90, 1, 66, 3, 64, 2, 34, 8, 59, 6, 78
  };
  const int q8064[] = {
    9, 9, // Number of jobs and machines
    6, 67, 8, 58, 7, 44, 5, 11, 1, 64, 3, 77, 2, 54, 4, 26, 0, 60, 
    2, 79, 6, 35, 4, 39, 0, 66, 3, 97, 5, 33, 7, 95, 1, 72, 8, 84, 
    0, 90, 1, 15, 2, 32, 4, 12, 3, 18, 5, 52, 6, 67, 7, 97, 8, 77, 
    3, 30, 4, 35, 5,  3, 0, 22, 2, 70, 7, 81, 8, 67, 1, 74, 6, 91, 
    2, 44, 7, 38, 8, 57, 5, 62, 4, 23, 0, 10, 1, 31, 6, 55, 3, 84, 
    3, 39, 7,  6, 2,  1, 0, 38, 1, 85, 4, 39, 6, 79, 8, 74, 5, 94, 
    8, 71, 1, 32, 4, 79, 7, 80, 3, 56, 6, 35, 5, 88, 0, 59, 2, 29, 
    7, 36, 1, 79, 2, 18, 6,  3, 5, 83, 8,  1, 3, 88, 4, 48, 0,  3, 
    3, 38, 7, 11, 4, 73, 2, 76, 6,  2, 8, 61, 1, 64, 0, 76, 5, 91
  };
  const int q8065[] = {
    9, 9, // Number of jobs and machines
    3, 46, 1, 40, 2, 51, 8, 56, 4, 67, 5, 57, 0, 88, 6,  1, 7, 39, 
    4,  6, 1, 86, 3, 70, 8, 80, 0, 77, 6, 76, 5, 65, 7, 86, 2,  3, 
    5, 40, 8, 79, 4, 90, 6, 76, 2, 97, 1, 17, 7, 20, 3, 24, 0, 41, 
    7, 62, 2, 47, 6, 61, 8, 19, 0, 12, 4, 35, 3, 13, 5, 85, 1, 31, 
    3, 53, 4, 13, 2, 18, 8, 73, 0,  1, 5, 64, 7, 79, 6, 79, 1, 26, 
    3, 42, 7, 58, 4, 91, 1, 36, 6, 17, 2, 44, 8,  4, 0, 22, 5, 38, 
    1, 54, 3, 66, 8, 12, 2, 25, 0, 88, 6, 64, 7, 26, 4, 26, 5, 45, 
    7, 65, 2, 54, 4, 78, 0, 61, 6, 13, 8, 62, 1, 84, 5, 24, 3, 70, 
    1, 59, 7, 36, 5,  2, 0, 19, 2, 83, 8, 76, 6,  8, 3, 38, 4,  8
  };
  const int q8066[] = {
    9, 9, // Number of jobs and machines
    2, 51, 1, 31, 8,  8, 4, 27, 7, 11, 0, 77, 6, 17, 3, 26, 5,  6, 
    4, 94, 7, 70, 0, 82, 3, 64, 2, 44, 8, 14, 6,  4, 5, 54, 1,  8, 
    1, 59, 5, 25, 4, 50, 0, 35, 8,  7, 2, 44, 3, 85, 7, 93, 6, 26, 
    3, 89, 0, 60, 1,  6, 2, 40, 8,  6, 7, 26, 6,  8, 4, 23, 5, 44, 
    1, 29, 8, 91, 0, 72, 7, 92, 2,  8, 3, 66, 6, 57, 5, 61, 4, 52, 
    2, 93, 5, 25, 3, 48, 1, 38, 8, 25, 4, 76, 6, 10, 7, 87, 0,  5, 
    2,  8, 3,  8, 6, 27, 1, 44, 7, 24, 4, 90, 5, 39, 8, 12, 0, 85, 
    2, 79, 1, 64, 0, 99, 8,  1, 7, 17, 6, 52, 5, 10, 3,  1, 4, 67, 
    3,  8, 6, 83, 1, 55, 0, 46, 8, 43, 2, 37, 4, 18, 5, 30, 7, 59
  };
  const int q8067[] = {
    9, 9, // Number of jobs and machines
    7, 93, 6, 35, 8, 65, 3, 41, 1, 83, 4, 37, 2, 21, 0, 68, 5, 23, 
    1, 58, 3, 18, 6, 58, 0, 82, 5, 41, 7, 61, 2, 78, 4, 76, 8, 53, 
    7, 51, 0, 23, 6, 67, 1, 88, 4, 41, 8, 49, 5, 31, 2, 34, 3, 16, 
    5, 13, 8, 26, 7, 48, 2, 85, 4, 26, 3, 68, 0, 14, 1, 27, 6, 46, 
    7,  5, 2, 61, 3, 69, 8, 45, 0, 50, 4,  9, 5, 25, 6, 70, 1, 41, 
    4, 26, 3, 43, 0, 35, 7, 39, 6, 79, 8, 12, 5, 55, 1, 42, 2, 33, 
    8,  8, 5, 69, 6, 66, 4, 31, 7, 36, 2, 55, 3, 11, 1, 56, 0, 85, 
    2, 57, 1, 88, 3, 58, 6, 66, 0, 45, 7,  7, 8, 75, 4, 76, 5, 11, 
    4,  5, 5, 26, 2, 16, 6,  3, 7, 93, 3, 45, 1, 89, 8, 45, 0, 93
  };
  const int q8068[] = {
    9, 9, // Number of jobs and machines
    2, 20, 7, 76, 8, 91, 0, 68, 5, 63, 4, 72, 6,  3, 3, 81, 1, 38, 
    0, 52, 4, 10, 1, 91, 8, 42, 7, 68, 3, 51, 5, 92, 6, 35, 2, 27, 
    7, 13, 6, 25, 2, 24, 8, 28, 3, 75, 0, 97, 5, 75, 4, 32, 1,  5, 
    8, 86, 4, 54, 3, 51, 5, 53, 6, 85, 2, 46, 7, 66, 0, 87, 1, 98, 
    2,  1, 4, 28, 5, 79, 0,  8, 7,  3, 8, 52, 1, 31, 6, 16, 3, 16, 
    3, 20, 4, 17, 6, 19, 0, 11, 2,  8, 5, 21, 1, 86, 7, 13, 8,  7, 
    4, 26, 7, 36, 6, 77, 5, 13, 3, 44, 0, 46, 8, 10, 1, 32, 2, 17, 
    8, 56, 6, 90, 3, 87, 1, 85, 4, 67, 7, 13, 2, 31, 5, 96, 0, 60, 
    8, 17, 0, 17, 6, 72, 1, 57, 2, 37, 7, 91, 4, 65, 5, 48, 3, 60
  };
  const int q8069[] = {
    9, 9, // Number of jobs and machines
    1, 52, 3, 34, 2, 53, 7, 15, 8, 43, 5, 57, 6, 93, 4,  9, 0, 54, 
    8, 83, 0,  4, 6, 85, 4,  6, 3,  3, 1,  7, 5, 94, 2, 60, 7, 13, 
    7, 72, 8, 12, 3, 98, 5, 83, 0,  4, 2, 79, 4, 64, 1, 44, 6, 18, 
    2, 53, 5, 49, 4,  1, 1, 11, 0, 18, 3, 91, 7, 18, 8, 80, 6, 85, 
    5, 21, 3,  5, 8, 84, 1, 96, 4, 13, 0, 25, 6, 43, 7, 67, 2, 78, 
    8, 56, 2, 87, 3, 98, 0, 79, 7, 50, 6, 81, 4, 58, 1, 27, 5, 35, 
    5, 23, 6, 38, 8, 70, 1, 11, 3, 29, 7, 38, 2, 43, 4, 45, 0, 92, 
    3, 85, 2, 76, 8, 16, 0, 88, 1, 49, 5, 74, 7, 90, 4, 96, 6, 58, 
    5, 10, 0, 42, 1, 99, 6, 96, 8, 93, 7, 22, 3, 71, 2, 20, 4, 70
  };
  const int q8070[] = {
    9, 9, // Number of jobs and machines
    2, 51, 1, 24, 5, 24, 3, 66, 4, 45, 6, 37, 8, 60, 7, 68, 0, 18, 
    8, 23, 7, 97, 0, 52, 2, 81, 1, 40, 4, 78, 6, 69, 3, 93, 5, 53, 
    8, 22, 6, 32, 4, 12, 0, 18, 1, 24, 7, 26, 2, 69, 5, 83, 3,  7, 
    3, 38, 4, 87, 6, 70, 7, 86, 5, 80, 1, 31, 0, 82, 2, 37, 8, 44, 
    2, 52, 1, 93, 7, 28, 5, 60, 8,  9, 3, 27, 6, 99, 4, 10, 0, 51, 
    2, 85, 7, 95, 4, 20, 3,  8, 6, 71, 0, 70, 1, 99, 8, 91, 5, 38, 
    6, 15, 8, 64, 7, 76, 2, 61, 0, 25, 3, 33, 5, 32, 1, 55, 4, 70, 
    8, 25, 4, 82, 3, 28, 2, 90, 7, 61, 5,  3, 0, 27, 1, 35, 6, 58, 
    1, 49, 5, 70, 7, 76, 6, 16, 3,  3, 8, 56, 4, 59, 0, 63, 2, 48
  };
  const int q8071[] = {
    9, 9, // Number of jobs and machines
    1,  2, 8, 65, 3, 92, 6, 79, 5, 28, 2, 47, 0, 34, 4, 52, 7, 10, 
    5, 76, 4, 81, 8, 29, 1, 78, 0, 24, 3,  6, 6, 40, 2, 72, 7, 79, 
    6, 58, 4, 85, 7, 98, 0, 40, 5, 22, 3, 95, 1, 83, 2, 92, 8, 92, 
    1, 38, 4, 39, 5, 51, 6, 89, 7, 27, 3, 60, 0, 77, 8, 58, 2, 88, 
    5, 88, 3, 65, 0, 90, 4, 72, 8, 47, 7, 27, 1, 29, 6, 16, 2, 86, 
    2, 51, 3, 14, 0, 23, 4, 74, 5, 93, 7, 46, 1, 58, 6, 47, 8, 94, 
    7, 34, 1, 12, 4,  8, 8, 93, 2, 55, 5, 92, 3, 32, 0, 58, 6, 32, 
    7, 95, 3, 46, 2, 33, 0, 84, 5, 90, 1,  2, 6, 39, 8, 51, 4,  9, 
    5, 50, 6, 61, 1, 94, 0, 74, 8, 88, 3, 34, 7, 68, 4, 93, 2, 41
  };
  const int q8072[] = {
    9, 9, // Number of jobs and machines
    4, 27, 1, 21, 2, 61, 6, 68, 5, 51, 3, 29, 7, 62, 0, 18, 8,  2, 
    4, 15, 8, 43, 6, 36, 1,  9, 5, 67, 0, 19, 3, 98, 7, 13, 2, 94, 
    3, 84, 5,  9, 7, 77, 8, 55, 0, 43, 4, 53, 2, 82, 1, 54, 6, 59, 
    3,  2, 8, 22, 7,  9, 1, 28, 0, 61, 2, 24, 6, 65, 4, 46, 5, 76, 
    4, 56, 8, 22, 3, 82, 2, 43, 1, 69, 5, 30, 0, 18, 6, 68, 7, 85, 
    4, 67, 6,  8, 5, 68, 7,  6, 8, 88, 1, 52, 2, 17, 0,  3, 3, 46, 
    3, 64, 6, 99, 0, 55, 4, 84, 8, 45, 5,  2, 1, 96, 2, 64, 7,  8, 
    3, 34, 1, 30, 0, 78, 8,  3, 2,  2, 5, 10, 7, 78, 6, 56, 4, 52, 
    4, 81, 0, 28, 2, 18, 5, 43, 1, 51, 6, 76, 8,  6, 3, 24, 7, 69
  };
  const int q8073[] = {
    9, 9, // Number of jobs and machines
    5, 64, 2, 22, 0, 25, 4, 20, 3, 89, 8, 92, 6,  7, 1, 89, 7, 58, 
    4, 98, 1, 31, 8, 90, 6, 25, 5, 63, 0, 70, 2, 68, 3, 90, 7, 63, 
    2, 20, 7, 90, 6, 28, 0, 27, 8, 49, 4, 84, 1, 69, 3, 75, 5, 29, 
    8, 34, 1, 10, 4, 44, 0, 18, 7, 11, 6, 93, 5, 62, 3, 70, 2, 70, 
    7,  2, 2, 29, 0, 86, 5, 44, 8, 39, 1, 54, 4, 15, 3, 48, 6, 18, 
    8, 34, 6, 15, 2, 86, 0, 75, 7, 98, 3, 47, 5, 41, 1, 78, 4, 47, 
    8, 21, 4, 52, 3, 68, 5, 84, 6, 70, 0, 64, 7, 86, 1, 42, 2, 96, 
    3, 10, 2, 19, 0, 83, 6, 15, 8, 87, 5, 74, 7, 85, 4, 52, 1, 80, 
    1, 66, 7, 96, 4, 38, 6, 53, 0, 17, 8, 55, 3, 26, 5, 30, 2, 77
  };
  const int q8074[] = {
    9, 9, // Number of jobs and machines
    0, 92, 3, 39, 8, 57, 5, 76, 7,  6, 4, 22, 2, 33, 6, 42, 1, 97, 
    8, 84, 6, 30, 4, 44, 1, 64, 2, 77, 5, 46, 0, 32, 7, 49, 3,  1, 
    7, 26, 4, 88, 2, 80, 8, 77, 6, 93, 5, 34, 0, 53, 1, 99, 3, 52, 
    0, 12, 5, 69, 2, 92, 8,  4, 3, 37, 6, 76, 1, 73, 7, 66, 4, 48, 
    7, 85, 5, 88, 3, 25, 1, 94, 0, 49, 8, 76, 6, 58, 2, 53, 4, 49, 
    0, 41, 6, 80, 7, 89, 2, 43, 3, 40, 4, 49, 5, 61, 1, 95, 8, 29, 
    2, 52, 8, 80, 6, 10, 0, 40, 3, 36, 4, 36, 5, 65, 1, 60, 7, 13, 
    0, 45, 3, 98, 5, 73, 1,  9, 2, 37, 4, 23, 6, 22, 8, 60, 7, 85, 
    8, 38, 2,  9, 7,  5, 3, 93, 5, 86, 6, 12, 4, 68, 0, 85, 1, 64
  };
  const int q8075[] = {
    9, 9, // Number of jobs and machines
    5, 51, 8, 89, 0, 52, 2, 16, 4, 83, 1, 14, 6, 42, 3, 61, 7, 75, 
    6, 32, 8, 76, 2, 17, 5, 82, 7, 10, 0, 37, 3, 13, 1, 67, 4, 21, 
    0, 59, 1, 79, 8, 61, 3, 44, 7, 73, 6, 31, 2, 74, 4, 39, 5, 51, 
    6,  9, 8, 96, 0, 66, 7, 82, 2,  9, 1, 19, 4, 57, 3, 56, 5, 60, 
    6,  9, 0, 13, 7, 25, 8, 96, 4, 40, 3,  3, 2,  7, 5, 83, 1,  1, 
    1, 47, 3, 30, 4, 52, 6, 17, 7, 97, 8, 22, 5, 24, 0, 11, 2, 56, 
    6, 49, 7, 87, 4, 51, 5,  9, 2, 73, 0, 84, 3,  4, 1, 92, 8, 50, 
    3, 68, 6, 89, 5, 34, 2, 65, 0, 41, 7, 15, 1, 43, 4, 89, 8, 96, 
    8, 45, 7, 68, 5, 68, 3, 80, 1, 41, 6, 75, 4, 67, 2, 69, 0, 20
  };
  const int q8076[] = {
    9, 9, // Number of jobs and machines
    5, 33, 7, 49, 3, 86, 8, 50, 6, 81, 0, 28, 4, 91, 1, 15, 2, 64, 
    4, 55, 2, 59, 3,  9, 8, 91, 7, 86, 1, 61, 0, 94, 6, 47, 5, 61, 
    0, 19, 6, 12, 5, 88, 1, 14, 3, 75, 2, 32, 4, 47, 7, 60, 8, 41, 
    8, 54, 1,  3, 0, 28, 7, 45, 2, 76, 5, 42, 4, 46, 3, 62, 6, 88, 
    0, 88, 6, 82, 8, 67, 1, 69, 7, 98, 2, 10, 5,  2, 3, 24, 4, 77, 
    5, 68, 2, 94, 3, 24, 7, 68, 4, 69, 6, 80, 0, 32, 1, 37, 8, 83, 
    0, 95, 7, 66, 1, 47, 8, 77, 3,  7, 6, 30, 5, 68, 2, 16, 4, 72, 
    6, 47, 7, 98, 4, 55, 3, 69, 1, 13, 8, 29, 2, 97, 5, 73, 0, 33, 
    5, 94, 1, 96, 8, 21, 2, 62, 7,  6, 3, 66, 4, 26, 0, 29, 6, 23
  };
  const int q8077[] = {
    9, 9, // Number of jobs and machines
    2, 73, 7, 87, 0, 64, 6, 62, 1, 75, 3, 47, 5, 14, 8,  7, 4, 95, 
    3,  8, 0, 74, 6, 25, 7, 34, 2, 18, 8, 71, 4, 68, 5, 35, 1, 26, 
    6, 33, 8, 78, 5, 15, 0, 27, 1, 52, 2,  2, 7,  8, 3, 35, 4, 53, 
    6, 21, 0, 49, 8, 50, 3, 32, 5, 11, 2, 75, 4, 73, 7, 28, 1, 45, 
    0, 29, 8, 78, 6, 44, 4, 40, 2, 11, 1, 31, 5, 28, 7, 98, 3, 62, 
    1, 24, 8, 18, 4, 19, 6, 86, 2, 87, 7, 37, 5, 40, 3, 23, 0,  6, 
    2, 82, 5, 99, 1, 24, 0, 56, 4, 43, 7, 71, 6, 29, 3, 57, 8, 37, 
    8, 93, 1, 48, 5, 51, 2, 52, 0, 80, 7,  2, 3, 93, 4, 76, 6, 60, 
    0, 85, 6, 68, 5, 16, 8, 44, 4, 55, 1, 56, 2, 32, 3, 20, 7, 99
  };
  const int q8078[] = {
    9, 9, // Number of jobs and machines
    5, 51, 7, 36, 2, 45, 3, 90, 8, 31, 6, 88, 4, 30, 1, 86, 0, 53, 
    7, 14, 1, 49, 2, 36, 6, 31, 4, 29, 8, 86, 3, 99, 5, 57, 0, 91, 
    6, 81, 7, 48, 2, 54, 8, 46, 0, 88, 5, 52, 1, 56, 3, 75, 4, 42, 
    6,  5, 3, 47, 5, 47, 4, 79, 7, 27, 0, 48, 2, 84, 8, 29, 1, 48, 
    5, 60, 7, 90, 6, 95, 4,  5, 2, 43, 0, 19, 1, 69, 3, 56, 8, 24, 
    4, 93, 0,  7, 8, 72, 1, 45, 3, 75, 2, 67, 7, 16, 6, 42, 5, 79, 
    3, 44, 6, 67, 5, 39, 4, 94, 1, 59, 0, 51, 8, 70, 7, 25, 2, 40, 
    3, 30, 8,  2, 6, 91, 1, 16, 4, 84, 2,  3, 5, 68, 7, 43, 0, 19, 
    3, 36, 7, 13, 2, 40, 4, 38, 8, 29, 1, 16, 6, 11, 0, 56, 5, 12
  };
  const int q8079[] = {
    9, 9, // Number of jobs and machines
    2, 89, 8, 19, 4, 37, 3, 37, 0, 41, 5, 17, 7, 86, 1, 60, 6, 33, 
    4, 19, 3, 67, 2, 86, 5, 19, 0, 75, 6, 73, 7, 72, 8,  3, 1, 69, 
    2, 57, 1, 63, 3, 65, 7,  1, 6, 51, 5, 84, 0, 85, 4, 32, 8, 37, 
    5, 82, 3, 34, 0, 69, 1, 76, 6, 67, 8, 86, 4, 30, 7, 29, 2, 43, 
    0,  5, 5, 57, 6, 51, 8,  9, 1, 69, 7,  3, 4, 73, 2, 46, 3,  6, 
    1, 15, 6, 22, 5, 51, 0,  4, 7, 80, 4, 98, 2, 61, 8, 74, 3, 32, 
    6, 80, 5, 42, 3, 29, 0, 18, 8,  7, 4, 42, 2, 64, 1, 30, 7, 27, 
    8, 85, 7, 90, 2, 73, 5, 19, 1, 61, 0, 38, 4, 73, 6, 50, 3, 58, 
    0, 48, 1,  9, 4, 11, 5, 90, 7, 84, 3, 96, 6, 27, 2, 32, 8,  4
  };
  const int q8080[] = {
    9, 9, // Number of jobs and machines
    1, 53, 7, 56, 3, 35, 0, 19, 2, 23, 6, 51, 8, 87, 5, 77, 4, 69, 
    3, 86, 1, 70, 2, 99, 7, 98, 6,  2, 5, 57, 8, 48, 0,  2, 4, 61, 
    5, 75, 3, 82, 7, 86, 2, 66, 1, 20, 0, 41, 8, 15, 4, 44, 6, 65, 
    8, 17, 6, 73, 0, 54, 1, 96, 7, 65, 2, 40, 4, 59, 5, 22, 3, 67, 
    7, 30, 0, 43, 6, 13, 4, 20, 2, 35, 3, 30, 5, 64, 8, 63, 1, 40, 
    0, 57, 8, 81, 7, 60, 5, 29, 3, 20, 4, 32, 6, 17, 2, 84, 1, 73, 
    6, 47, 4, 12, 1, 25, 0, 67, 2, 73, 3, 51, 8,  4, 7, 59, 5, 29, 
    1, 50, 8, 58, 4, 94, 0,  8, 7, 23, 5, 58, 6, 78, 3, 87, 2, 84, 
    8, 34, 1, 57, 7, 31, 4, 20, 6, 91, 3,  2, 5, 11, 2, 55, 0, 45
  };
  const int q8081[] = {
    9, 9, // Number of jobs and machines
    4, 69, 2, 91, 8, 70, 0, 61, 1, 46, 6, 88, 7,  6, 5, 62, 3, 36, 
    2, 60, 1, 40, 3, 59, 8, 54, 4, 68, 5, 54, 0, 13, 7, 88, 6, 96, 
    3, 95, 7, 94, 0, 76, 8, 52, 1, 39, 5, 84, 2, 49, 6, 59, 4, 38, 
    8, 10, 3, 52, 7, 73, 4, 27, 2, 20, 0, 28, 6, 34, 1, 75, 5, 90, 
    7, 37, 3,  2, 5, 31, 8, 90, 6, 41, 2, 82, 0, 40, 4, 63, 1, 22, 
    0, 88, 3, 17, 1, 68, 5,  7, 2, 80, 4, 59, 7, 78, 6, 53, 8, 87, 
    6, 45, 4, 29, 2, 38, 3, 65, 7, 99, 0, 88, 5, 38, 8, 41, 1, 40, 
    0,  4, 6, 90, 3, 55, 5, 94, 2, 20, 4, 44, 1, 12, 7,  2, 8, 58, 
    8, 15, 3, 36, 0, 97, 4, 21, 5, 23, 2, 19, 6,  4, 7, 73, 1, 76
  };
  const int q8082[] = {
    9, 9, // Number of jobs and machines
    8, 54, 5, 46, 7, 15, 1, 22, 2, 23, 0, 45, 6, 81, 4, 35, 3, 83, 
    2, 43, 0, 81, 1, 69, 5, 72, 6, 46, 3, 92, 8, 40, 7, 33, 4,  6, 
    0, 21, 3, 78, 6, 87, 5, 27, 4, 14, 2, 52, 1, 35, 7, 38, 8, 72, 
    2, 69, 0, 14, 8, 91, 4, 63, 3, 45, 7, 47, 6, 62, 5, 59, 1, 42, 
    2, 60, 0, 16, 4, 93, 6, 44, 3, 56, 1, 26, 7, 32, 8, 22, 5, 59, 
    0, 90, 6, 82, 5, 28, 3, 67, 2, 44, 4, 62, 7, 23, 1, 19, 8, 56, 
    0, 22, 4,  9, 6, 82, 1, 71, 3, 95, 2, 65, 8, 96, 5, 24, 7, 72, 
    0, 82, 2, 51, 1, 78, 3, 79, 8, 82, 5, 51, 7, 77, 6, 95, 4, 37, 
    7, 40, 8, 73, 1, 94, 6, 51, 4,  4, 5, 79, 0, 96, 3,  2, 2, 98
  };
  const int q8083[] = {
    9, 9, // Number of jobs and machines
    6,  1, 8, 63, 1, 39, 0, 57, 3, 58, 2, 13, 7, 90, 5, 18, 4, 45, 
    1, 52, 7, 20, 4, 83, 5, 91, 6, 73, 0, 40, 3,  4, 8, 45, 2, 21, 
    6, 96, 7, 26, 8, 89, 0, 36, 2, 28, 1, 12, 5, 21, 3,  1, 4, 88, 
    0, 52, 5, 58, 8,  9, 4, 92, 3, 12, 1, 84, 2, 41, 7, 45, 6, 85, 
    5, 29, 1, 82, 6, 50, 3, 72, 2, 21, 0, 29, 4, 27, 7, 67, 8, 73, 
    0, 45, 6, 66, 8, 64, 3, 27, 2, 39, 7, 40, 1, 15, 4, 35, 5,  8, 
    6, 66, 0, 15, 7, 94, 8, 17, 2, 42, 3, 22, 1, 33, 4, 98, 5, 87, 
    1, 71, 0, 10, 4, 96, 6, 24, 2, 68, 8, 32, 3, 81, 5, 19, 7, 35, 
    4, 26, 2, 17, 0, 61, 7, 15, 5, 95, 1, 35, 3, 19, 6, 74, 8,  3
  };
  const int q8084[] = {
    9, 9, // Number of jobs and machines
    5, 23, 2, 43, 8, 70, 4, 62, 3, 63, 6, 46, 0,  1, 7, 42, 1, 79, 
    3, 89, 5,  2, 4, 76, 2,  9, 6, 45, 0, 94, 8, 99, 1, 65, 7, 67, 
    4, 94, 1, 53, 7, 21, 3, 97, 0, 68, 2, 42, 5, 37, 8, 14, 6, 18, 
    2, 72, 3,  3, 7, 37, 1, 70, 6, 57, 8, 24, 4, 27, 0, 97, 5, 49, 
    3, 90, 1, 16, 0, 48, 4, 33, 8, 82, 7, 34, 5, 69, 2, 95, 6, 45, 
    1, 14, 6, 39, 3, 45, 4, 23, 0, 28, 2, 50, 5, 45, 8, 31, 7, 10, 
    5, 97, 7, 63, 1, 16, 4, 90, 2, 89, 3, 68, 8, 70, 6, 32, 0, 12, 
    8, 26, 3,  1, 4, 63, 0, 79, 5, 58, 6, 92, 7,  4, 1, 90, 2, 96, 
    2, 27, 3, 40, 0, 10, 8, 74, 6, 42, 4, 24, 1, 58, 5, 65, 7, 23
  };
  const int q8085[] = {
    9, 9, // Number of jobs and machines
    2, 81, 7,  3, 8, 99, 1, 37, 0, 71, 4, 64, 6, 46, 3, 34, 5, 69, 
    8, 64, 2, 89, 7, 36, 4, 88, 3, 36, 1, 29, 6, 43, 5, 20, 0, 88, 
    6, 35, 0, 92, 8, 47, 1, 84, 3, 96, 5, 35, 7, 53, 2, 70, 4, 47, 
    2, 30, 6,  9, 0, 91, 8, 81, 7, 17, 5, 69, 3, 55, 4, 19, 1, 97, 
    0, 51, 8, 56, 5, 81, 7, 38, 2, 25, 4, 75, 3, 56, 1, 93, 6, 55, 
    3, 20, 6, 95, 5, 38, 1, 74, 7, 22, 8, 97, 0, 55, 2, 21, 4,  9, 
    6, 36, 7, 74, 1, 34, 2, 27, 5, 73, 8, 32, 4, 52, 3, 59, 0, 16, 
    7, 71, 1, 42, 6, 90, 3, 86, 4, 30, 8, 50, 5,  1, 2, 91, 0, 67, 
    0, 15, 8, 28, 5, 49, 1, 20, 4, 40, 3, 94, 2, 80, 6,  4, 7, 72
  };
  const int q8086[] = {
    9, 9, // Number of jobs and machines
    2, 22, 6, 26, 8, 31, 3, 21, 5, 34, 7, 49, 1, 74, 4, 66, 0, 21, 
    8, 81, 4, 16, 7, 57, 2, 92, 5, 48, 1,  8, 0, 83, 6, 44, 3, 11, 
    2,  5, 1, 96, 5, 88, 8, 84, 3, 68, 7, 15, 4, 98, 0, 45, 6, 18, 
    6, 51, 7,  2, 0, 76, 1, 17, 8, 43, 3, 90, 5, 96, 2, 20, 4, 77, 
    0,  3, 7,  8, 1, 32, 4, 68, 6, 25, 8, 26, 5, 31, 2, 94, 3,  2, 
    2, 16, 6, 82, 5, 46, 1, 56, 4, 64, 3, 50, 8, 50, 0,  1, 7, 56, 
    1, 54, 7, 20, 0, 83, 4, 63, 6, 54, 5, 69, 8, 72, 2, 28, 3, 26, 
    4, 20, 6, 11, 7, 41, 1, 79, 8, 75, 0, 87, 2, 31, 5, 36, 3,  9, 
    5, 80, 8, 15, 4, 20, 7, 18, 1, 81, 0, 67, 2, 35, 3, 19, 6, 66
  };
  const int q8087[] = {
    9, 9, // Number of jobs and machines
    8, 95, 5,  7, 0, 52, 1, 74, 3, 40, 2, 79, 6, 47, 7, 59, 4,  8, 
    0, 95, 1, 83, 7, 78, 5, 46, 4, 57, 6, 16, 3,  9, 2, 41, 8, 21, 
    4, 17, 7, 98, 6, 66, 0, 18, 8, 57, 3, 98, 2, 88, 1, 41, 5, 69, 
    2, 73, 5, 38, 6, 74, 3, 64, 1, 46, 0, 42, 4,  3, 8, 24, 7, 96, 
    2, 48, 6, 10, 4,  2, 5, 71, 1, 68, 7, 90, 0, 81, 3,  7, 8, 92, 
    8, 74, 2, 23, 7, 56, 6, 35, 5,  2, 4, 33, 1,  9, 0, 26, 3, 32, 
    1, 97, 8, 19, 3, 83, 6, 14, 5, 27, 0, 93, 2, 10, 4, 24, 7, 38, 
    7, 31, 6, 31, 4, 81, 0, 39, 3, 28, 1, 53, 8, 10, 2,  4, 5, 91, 
    8, 68, 0,  2, 2, 17, 7, 51, 4, 66, 5,  6, 3, 54, 6,  7, 1, 45
  };
  const int q8088[] = {
    9, 9, // Number of jobs and machines
    4,  9, 6, 56, 1, 85, 7, 18, 5, 94, 2, 40, 0, 88, 8, 26, 3, 32, 
    5, 17, 4, 27, 3, 16, 7, 16, 6, 24, 1, 21, 2, 42, 0, 93, 8, 31, 
    1,  8, 8,  1, 2, 78, 3, 40, 5, 46, 7, 22, 4, 87, 6, 81, 0, 89, 
    6, 80, 8, 63, 4, 21, 2, 18, 5, 44, 7, 76, 1,  6, 0, 63, 3, 83, 
    0, 66, 3, 45, 1,  2, 6,  6, 2, 63, 7, 86, 4, 61, 8, 39, 5, 65, 
    1, 47, 4, 59, 6, 25, 7, 80, 8, 17, 0, 55, 5, 40, 2, 26, 3, 80, 
    5, 47, 3, 54, 0, 22, 4, 91, 1, 97, 2, 64, 6, 42, 7, 42, 8,  3, 
    4, 92, 5, 71, 6, 15, 7, 89, 1, 22, 2, 44, 0, 40, 3, 25, 8, 83, 
    7, 98, 0, 90, 4, 55, 3, 93, 5, 99, 8, 14, 1, 97, 2, 76, 6, 63
  };
  const int q8089[] = {
    9, 9, // Number of jobs and machines
    4, 25, 0,  4, 1, 40, 5, 23, 2, 15, 8, 15, 7,  2, 3, 49, 6,  6, 
    2, 92, 8, 10, 7, 93, 6, 37, 5, 84, 1, 86, 0, 66, 4, 40, 3, 51, 
    1, 62, 6, 72, 2, 44, 0, 21, 5, 23, 3, 26, 7, 22, 8, 86, 4, 53, 
    8, 93, 3, 75, 7, 69, 6, 50, 0, 14, 5, 69, 2, 30, 1, 10, 4, 56, 
    3,  5, 5, 44, 8, 99, 7,  1, 2,  7, 4, 67, 1, 80, 0, 65, 6, 80, 
    0, 36, 7, 26, 2,  9, 5, 87, 3, 78, 6, 87, 4, 34, 8, 18, 1, 54, 
    3, 13, 5, 88, 4, 26, 8, 77, 7, 83, 6, 26, 0, 52, 2, 89, 1, 59, 
    1, 24, 6, 31, 7, 82, 2,  8, 3, 21, 5, 81, 0, 49, 8, 16, 4, 61, 
    1,  9, 2, 39, 6, 52, 0, 33, 7, 12, 5, 28, 8, 59, 4, 69, 3, 80
  };
  const int q8090[] = {
    9, 9, // Number of jobs and machines
    3, 77, 1, 95, 5, 55, 8, 16, 7, 72, 4, 56, 2, 51, 6, 57, 0, 47, 
    8, 15, 7, 98, 4, 57, 5,  2, 0, 55, 1, 57, 3, 42, 6,  5, 2, 38, 
    6, 73, 5,  1, 7, 14, 4, 12, 3, 20, 8,  9, 0, 57, 1, 32, 2, 48, 
    8, 54, 7, 40, 2, 42, 4, 30, 3, 92, 6, 50, 5, 79, 1, 64, 0, 19, 
    2, 38, 8,  1, 1, 76, 6,  5, 4, 75, 5, 61, 7, 61, 0, 34, 3, 54, 
    5,  7, 6, 72, 0, 65, 3, 76, 1, 28, 7, 26, 2, 27, 8, 53, 4, 49, 
    7, 96, 5, 29, 0, 29, 2, 24, 8,  3, 1, 22, 6, 78, 3, 75, 4,  9, 
    0, 81, 1,  3, 8, 90, 7, 27, 6, 40, 5, 26, 4, 11, 2, 39, 3, 13, 
    3, 47, 6, 44, 8,  1, 5, 47, 7, 70, 0, 72, 2, 21, 1, 89, 4, 27
  };
  const int q8091[] = {
    9, 9, // Number of jobs and machines
    6, 20, 7, 60, 8, 12, 4, 22, 2, 96, 5, 57, 3, 59, 0, 90, 1, 70, 
    5, 49, 8, 31, 1, 42, 6, 83, 2, 78, 0, 21, 3,  8, 7, 39, 4, 27, 
    0, 10, 2, 35, 8, 54, 7, 64, 3, 94, 6, 75, 5, 13, 4, 67, 1, 91, 
    8,  1, 5, 61, 1, 49, 6,  8, 4, 88, 3, 36, 0, 60, 7, 32, 2, 23, 
    8, 16, 2, 44, 1, 54, 4, 41, 3, 89, 0,  2, 5, 17, 6, 90, 7, 28, 
    2, 52, 7, 46, 1, 91, 3, 28, 4,  9, 5, 18, 6,  8, 8, 78, 0, 36, 
    5, 32, 7, 94, 4, 81, 8, 84, 2, 47, 6, 73, 1, 93, 0, 10, 3, 28, 
    7, 33, 3, 97, 8, 28, 0, 55, 5, 32, 4, 22, 2, 49, 6, 67, 1, 89, 
    1,  5, 5, 29, 2, 94, 3, 80, 6, 83, 4, 80, 8, 69, 7, 49, 0, 92
  };
  const int q8092[] = {
    9, 9, // Number of jobs and machines
    7, 23, 4, 59, 6, 54, 8, 21, 2, 37, 0,  3, 5, 25, 1, 67, 3, 73, 
    5, 36, 8, 11, 1, 37, 4, 88, 3, 23, 6, 29, 7, 66, 0, 14, 2, 31, 
    6, 21, 1,  9, 4, 97, 5, 95, 2, 57, 7, 41, 3, 13, 8, 22, 0, 35, 
    3, 19, 6, 22, 5, 69, 7, 54, 8, 89, 1, 59, 2, 41, 0,  2, 4,  3, 
    7, 56, 2, 20, 3, 87, 4, 37, 8, 93, 0, 84, 1, 51, 6,  9, 5,  6, 
    4,  6, 8,  1, 2, 66, 7, 86, 6, 95, 5, 51, 1, 29, 0, 16, 3, 97, 
    3,  2, 4,  6, 1, 90, 5, 51, 7, 23, 6, 38, 8, 24, 0, 73, 2,  6, 
    2,  8, 5, 95, 6,  9, 4, 41, 1, 17, 8, 16, 0, 81, 3,  1, 7, 39, 
    4, 48, 3, 91, 1, 93, 7, 58, 2, 11, 8, 12, 0,  7, 6, 65, 5, 24
  };
  const int q8093[] = {
    9, 9, // Number of jobs and machines
    3,  8, 0, 11, 8,  3, 2, 28, 7, 68, 1, 42, 5, 65, 4, 23, 6, 72, 
    5, 40, 0, 97, 3, 88, 8, 92, 6, 67, 4, 37, 2, 78, 7, 66, 1, 28, 
    5, 26, 0, 76, 7, 98, 3, 65, 2, 76, 6, 68, 1, 47, 4, 52, 8, 70, 
    6, 88, 5, 86, 2, 79, 8, 49, 0, 88, 1, 58, 4, 49, 3,  2, 7, 53, 
    4, 99, 0, 56, 2, 17, 5, 75, 1, 73, 7, 70, 6, 52, 3, 43, 8, 45, 
    0, 55, 6, 32, 2, 15, 1, 15, 3, 35, 8, 33, 5, 13, 4,  5, 7, 69, 
    4, 78, 5, 91, 7,  8, 2, 71, 6, 58, 0, 15, 8, 94, 3, 60, 1, 38, 
    6, 62, 5, 44, 3, 73, 0, 51, 2, 85, 8, 56, 4, 99, 7,  4, 1, 25, 
    0, 74, 3, 39, 1, 72, 8, 88, 2, 29, 7, 68, 4, 43, 5, 44, 6,  7
  };
  const int q8094[] = {
    9, 9, // Number of jobs and machines
    0, 58, 5, 93, 2, 47, 1, 56, 6, 29, 3,  3, 8, 92, 7, 18, 4, 65, 
    2, 34, 3, 36, 6, 90, 1, 81, 7, 58, 0, 98, 5, 45, 4, 89, 8, 94, 
    5, 57, 2, 70, 6, 62, 4, 60, 7, 99, 8, 31, 3, 68, 1, 77, 0, 72, 
    5, 86, 4, 58, 7, 28, 1, 34, 2, 94, 8, 90, 3,  2, 6, 11, 0, 26, 
    8, 93, 4, 60, 6,  8, 0, 57, 3, 50, 1, 82, 2, 75, 5, 44, 7, 64, 
    2, 29, 6, 91, 0, 31, 3,  5, 8, 98, 1, 62, 4, 29, 5, 71, 7, 49, 
    1,  4, 2, 23, 6, 89, 4, 39, 7, 34, 3,  6, 0, 46, 5, 89, 8, 90, 
    3, 54, 4, 37, 0, 57, 8, 94, 1, 28, 2, 53, 6, 21, 5, 63, 7, 97, 
    8, 24, 3, 83, 1, 88, 2, 53, 5, 30, 4, 24, 0, 20, 6, 14, 7, 29
  };
  const int q8095[] = {
    9, 9, // Number of jobs and machines
    3, 72, 1, 13, 7,  7, 2, 69, 8, 50, 0, 71, 5, 51, 6, 49, 4, 79, 
    1, 53, 0, 36, 7, 14, 3, 94, 2, 48, 6, 21, 8, 78, 5,  8, 4, 90, 
    6, 50, 2, 25, 7,  6, 4, 21, 0, 15, 1, 42, 5, 15, 8, 22, 3, 14, 
    1, 55, 2,  3, 6, 80, 8, 54, 3, 29, 4, 90, 0,  5, 7, 22, 5, 19, 
    4, 87, 3, 29, 8, 98, 0,  7, 5, 88, 7, 58, 1, 90, 6,  2, 2, 27, 
    2, 56, 8,  9, 0, 65, 6, 60, 7, 70, 3, 33, 4,  6, 5, 26, 1, 95, 
    1, 63, 2, 75, 5,  5, 3, 93, 0, 39, 8,  7, 6, 65, 4, 45, 7, 80, 
    2, 26, 8,  8, 4, 88, 5, 20, 7, 45, 3, 20, 6,  1, 1, 91, 0, 67, 
    5,  2, 3, 20, 1, 64, 4, 68, 8, 35, 6, 56, 7, 49, 0, 72, 2, 23
  };
  const int q8096[] = {
    9, 9, // Number of jobs and machines
    5, 46, 8, 57, 6, 48, 0, 52, 7, 67, 1, 82, 4, 97, 3, 88, 2, 98, 
    3, 47, 2, 79, 8,  2, 5, 69, 4, 22, 1, 22, 7, 29, 0, 95, 6, 44, 
    2,  6, 7, 49, 5, 16, 3, 36, 1, 15, 4,  8, 8, 65, 0, 26, 6, 85, 
    1, 75, 3, 71, 4, 83, 8, 62, 2, 62, 5, 17, 6, 80, 0, 67, 7, 62, 
    2, 74, 0, 96, 7, 50, 1, 54, 3,  2, 5, 73, 8, 12, 4, 10, 6, 17, 
    1,  8, 5, 15, 2, 55, 0, 95, 7, 98, 8,  2, 3, 78, 6, 31, 4, 87, 
    1, 39, 3, 58, 8, 12, 2, 24, 7, 77, 0, 51, 6,  6, 4,  2, 5, 79, 
    8, 38, 1, 97, 5, 57, 2, 93, 6,  2, 7, 82, 3, 55, 4, 70, 0, 53, 
    4, 65, 5, 24, 3, 82, 0, 28, 8, 94, 7, 92, 6, 80, 1, 73, 2, 18
  };
  const int q8097[] = {
    9, 9, // Number of jobs and machines
    3, 96, 2, 42, 8, 11, 7, 54, 5, 20, 4,  1, 1, 78, 0, 84, 6, 82, 
    5, 39, 2, 74, 3, 53, 0, 21, 8, 80, 4, 11, 6, 98, 7, 55, 1, 97, 
    0, 22, 5, 28, 3, 67, 2,  4, 7, 99, 1, 70, 6, 97, 8, 67, 4, 24, 
    0, 23, 3, 80, 5, 31, 1, 49, 6,  1, 7, 74, 2, 49, 4, 12, 8, 56, 
    2, 20, 8, 86, 4, 30, 3, 57, 0, 63, 5, 21, 1, 21, 7, 77, 6, 92, 
    0, 63, 3, 18, 8, 83, 6,  1, 4, 10, 7, 66, 5, 13, 1, 49, 2, 13, 
    4, 91, 7, 20, 1, 53, 5,  9, 6, 17, 8,  6, 0, 86, 3, 13, 2, 26, 
    5, 17, 2, 45, 0, 31, 4, 53, 1, 90, 7,  6, 3, 18, 6, 15, 8, 81, 
    7, 42, 2, 14, 3, 32, 4, 56, 5, 20, 1, 82, 0, 89, 6, 34, 8, 31
  };
  const int q8098[] = {
    9, 9, // Number of jobs and machines
    8, 75, 4, 24, 2, 58, 1, 32, 7, 13, 0, 68, 6, 88, 5, 80, 3, 10, 
    0, 55, 6, 47, 8,  4, 5,  9, 2, 17, 1, 88, 4, 14, 7, 64, 3, 18, 
    4, 33, 7, 29, 6, 35, 0, 52, 8, 63, 2, 36, 1, 26, 3, 92, 5, 61, 
    4, 68, 8, 88, 3, 67, 7, 85, 1, 67, 5, 96, 6, 79, 0, 40, 2, 53, 
    0, 52, 8, 20, 7, 88, 4, 90, 3, 64, 5, 60, 2, 75, 1, 26, 6, 48, 
    7, 77, 4, 73, 5, 72, 6, 53, 2, 69, 0, 77, 3, 62, 8, 56, 1, 17, 
    6, 14, 4, 71, 0, 37, 3, 10, 8, 52, 5, 61, 1, 33, 7, 99, 2, 10, 
    3, 49, 8,  3, 6, 62, 2, 63, 1, 93, 0, 82, 7, 45, 5, 95, 4, 58, 
    7, 18, 1, 29, 6, 54, 3, 48, 4, 58, 2, 76, 8, 53, 5, 68, 0,  7
  };
  const int q8099[] = {
    9, 9, // Number of jobs and machines
    1, 45, 4, 84, 5, 42, 6, 99, 0, 27, 7, 10, 3, 49, 2, 49, 8, 36, 
    6,  2, 7, 39, 0, 36, 3, 25, 4, 87, 8, 73, 5, 91, 2, 26, 1,  7, 
    1, 92, 5, 45, 0, 69, 7, 13, 4, 66, 6,  8, 2, 29, 3, 92, 8, 32, 
    0, 14, 1,  5, 2, 67, 4, 94, 3, 12, 6, 13, 7, 11, 5,  4, 8, 63, 
    2, 26, 0, 38, 6, 80, 3, 29, 4, 57, 5, 22, 1, 41, 7,  9, 8, 38, 
    5, 78, 2, 90, 1, 22, 4, 43, 7, 26, 8, 58, 0, 61, 6, 38, 3, 72, 
    8, 93, 2, 79, 4, 76, 7, 21, 0, 28, 3, 49, 5, 16, 6, 18, 1, 74, 
    8, 17, 7, 58, 0, 57, 1, 65, 2, 11, 4, 36, 6, 38, 5, 60, 3, 72, 
    1, 83, 8, 37, 5, 49, 3, 74, 0, 21, 4, 50, 6, 82, 2, 12, 7, 84
  };
  const int q8100[] = {
    9, 9, // Number of jobs and machines
    8,  1, 0, 18, 2,  5, 4, 45, 5, 92, 3, 67, 1,  8, 7, 86, 6, 39, 
    5, 35, 4, 16, 1, 37, 0, 47, 3, 19, 8, 11, 2,  3, 6, 35, 7, 42, 
    3, 19, 7, 92, 8, 82, 0, 59, 2, 76, 6, 85, 1, 33, 5,  7, 4,  4, 
    2, 42, 6, 13, 1, 63, 3, 54, 0, 61, 8, 93, 4, 88, 5, 84, 7, 48, 
    1, 91, 0, 80, 8, 19, 4, 31, 2, 78, 7, 46, 3, 62, 6, 51, 5, 86, 
    3, 46, 7, 49, 5,  7, 6, 76, 4, 58, 0, 22, 8, 92, 1, 90, 2,  9, 
    1, 19, 5, 31, 7, 56, 0, 97, 8, 72, 2, 12, 6, 76, 3, 21, 4, 29, 
    0, 44, 3, 12, 1, 13, 8, 32, 4, 64, 2, 75, 5, 62, 6, 73, 7, 91, 
    2, 26, 8, 67, 5, 45, 1, 98, 3, 63, 0, 27, 7, 76, 4, 67, 6, 55
  };
  const int q8101[] = {
    9, 9, // Number of jobs and machines
    2, 98, 8,  6, 1, 54, 0, 65, 6, 92, 5, 78, 3, 26, 7, 12, 4, 30, 
    6, 47, 4, 86, 1, 17, 5, 68, 8,  7, 7, 43, 3, 81, 0, 69, 2,  6, 
    5, 44, 6, 88, 8, 58, 1, 84, 0, 57, 7, 65, 3, 87, 4, 99, 2,  6, 
    6, 89, 7, 98, 2, 47, 0, 78, 1, 31, 3,  9, 5, 88, 4,  8, 8, 41, 
    8, 47, 4, 13, 3, 29, 2, 47, 0, 99, 6, 84, 7, 45, 5, 88, 1, 69, 
    6, 14, 1, 23, 8, 51, 3, 21, 4, 82, 5,  5, 0, 61, 2, 86, 7, 98, 
    7, 74, 6,  1, 2, 67, 0, 56, 1, 41, 3, 90, 4, 42, 8, 22, 5, 70, 
    0, 50, 2, 42, 6, 70, 7, 54, 8, 38, 4, 15, 1, 43, 5, 96, 3, 63, 
    1, 21, 8, 15, 7, 40, 0, 40, 3, 16, 4, 96, 5, 23, 2, 10, 6,  5
  };
  const int q8102[] = {
    9, 9, // Number of jobs and machines
    0, 70, 4, 68, 5, 69, 3, 58, 1, 61, 6,  7, 8, 82, 7, 80, 2, 33, 
    0, 25, 4, 45, 7, 80, 1, 63, 5, 37, 8, 54, 3, 64, 6, 68, 2, 35, 
    2, 65, 0, 65, 3, 13, 1, 97, 6, 89, 4, 54, 7, 21, 5, 15, 8,  7, 
    0, 15, 1, 84, 6, 83, 5, 73, 4, 60, 8,  9, 3, 14, 7,  5, 2, 63, 
    1, 99, 7, 95, 8, 31, 6, 86, 5, 26, 0, 52, 3, 66, 2, 50, 4, 51, 
    1, 89, 8, 45, 2, 97, 3, 40, 0, 27, 7, 23, 6, 39, 5, 95, 4, 65, 
    2, 42, 7, 58, 4, 62, 5, 12, 3, 72, 0, 56, 1, 72, 6, 71, 8, 35, 
    5, 82, 2, 17, 6, 33, 3, 77, 1, 95, 8, 78, 0, 31, 4, 98, 7,  5, 
    1, 89, 6, 57, 3, 44, 5, 68, 7, 46, 4, 32, 0, 12, 8, 53, 2, 57
  };
  const int q8103[] = {
    9, 9, // Number of jobs and machines
    7, 19, 4,  2, 8, 23, 5, 16, 6, 74, 1,  7, 3, 34, 2, 95, 0, 50, 
    5, 54, 4, 44, 0, 44, 6, 73, 7, 24, 2, 25, 8, 94, 3, 52, 1, 86, 
    1, 38, 7, 16, 0, 73, 2,  1, 4, 52, 6, 49, 5, 67, 3, 42, 8, 55, 
    3, 78, 5, 42, 2, 10, 1,  7, 7, 98, 4, 83, 6, 50, 8, 47, 0, 18, 
    8, 79, 4, 86, 2, 54, 0,  9, 6, 61, 1,  7, 3, 77, 7, 68, 5, 85, 
    6, 65, 4, 86, 7, 58, 1, 14, 8, 45, 5, 94, 2, 26, 3, 64, 0,  9, 
    4, 78, 5, 43, 1,  5, 3, 33, 6, 80, 2, 42, 7, 56, 8, 91, 0, 29, 
    6, 54, 1,  2, 7, 95, 8, 42, 2, 79, 3, 84, 0, 38, 5,  5, 4, 52, 
    3, 62, 7, 39, 0, 42, 5, 49, 2, 51, 8, 20, 4, 49, 6, 31, 1,  4
  };
  const int q8104[] = {
    9, 9, // Number of jobs and machines
    2, 59, 6, 45, 7, 57, 1, 94, 4,  5, 8, 31, 3, 61, 0, 85, 5, 86, 
    2, 74, 0, 48, 8, 23, 7, 95, 6, 46, 4, 26, 3, 80, 5, 49, 1, 58, 
    8,  6, 3,  8, 6,  6, 1, 68, 7, 61, 4, 23, 5, 75, 0, 67, 2, 79, 
    6, 79, 2,  5, 8, 55, 3, 98, 7, 86, 4, 16, 0, 99, 1, 17, 5,  5, 
    0, 28, 8, 18, 5, 58, 2, 52, 4, 87, 7,  8, 6, 45, 3, 39, 1, 36, 
    5, 48, 4, 86, 1,  4, 0, 59, 3, 57, 2, 97, 7, 99, 6, 56, 8, 81, 
    1, 20, 8,  7, 6, 37, 0, 45, 2,  5, 4, 89, 5, 96, 3, 59, 7, 99, 
    6, 93, 5, 15, 0, 67, 7, 98, 8, 24, 4, 17, 3, 58, 1, 40, 2, 50, 
    0, 63, 3, 32, 8, 27, 6, 54, 5, 33, 4, 40, 7, 46, 2, 54, 1, 61
  };
  const int q8105[] = {
    9, 9, // Number of jobs and machines
    0, 75, 4, 84, 3, 63, 5, 55, 1, 31, 8, 80, 6, 53, 7, 61, 2, 31, 
    0, 58, 4,  7, 8,  3, 7, 77, 6, 94, 5, 12, 1, 66, 3, 32, 2, 73, 
    1,  2, 8, 77, 2, 79, 3, 23, 6, 98, 5, 10, 4, 61, 7, 38, 0, 54, 
    0, 50, 1,  1, 3, 82, 8, 55, 7, 65, 5, 67, 2,  5, 6, 41, 4, 52, 
    3, 73, 6,  9, 7, 52, 8, 50, 5, 93, 1, 54, 0, 14, 4,  4, 2, 63, 
    5, 57, 8, 17, 0, 97, 2, 88, 3, 25, 4,  2, 1, 20, 6,  9, 7, 95, 
    0, 12, 5, 47, 3, 53, 1, 54, 7, 12, 8, 32, 2, 43, 4, 10, 6, 33, 
    3, 34, 5, 76, 7, 84, 2,  8, 8, 70, 0, 33, 6, 50, 4, 95, 1, 41, 
    6, 65, 1, 20, 5, 90, 2, 91, 8,  7, 3, 84, 7, 75, 0, 88, 4, 34
  };
  const int q8106[] = {
    9, 9, // Number of jobs and machines
    3, 11, 2, 66, 7, 61, 0, 43, 8, 12, 6, 95, 5, 46, 1,  7, 4, 34, 
    8, 39, 1, 84, 6, 60, 7, 30, 4, 42, 3, 90, 0, 65, 2, 48, 5, 65, 
    2, 15, 3, 57, 6, 29, 8, 92, 5, 70, 1, 15, 0, 10, 4, 16, 7, 74, 
    4,  3, 2, 78, 7, 63, 6, 37, 5, 51, 8, 53, 0, 31, 3, 54, 1, 19, 
    0, 28, 4, 33, 1, 42, 6, 16, 3,  7, 7, 97, 8, 95, 2, 88, 5, 73, 
    8, 94, 1, 88, 2, 17, 0, 47, 5, 11, 7, 58, 6, 75, 4, 43, 3, 75, 
    2, 91, 8, 27, 4,  8, 3, 62, 5, 19, 7, 31, 6, 63, 1, 97, 0, 57, 
    3, 83, 6, 56, 5,  8, 7, 51, 0,  3, 1,  6, 4, 33, 2, 38, 8, 64, 
    4, 98, 2, 51, 3,  9, 0, 60, 8, 91, 6, 35, 7, 77, 1, 32, 5, 83
  };
  const int q8107[] = {
    9, 9, // Number of jobs and machines
    7, 32, 5, 64, 4, 42, 1, 26, 0, 82, 8, 80, 6, 61, 2, 31, 3, 95, 
    4, 81, 1, 87, 7, 11, 0,  3, 3, 48, 5,  2, 8, 87, 2, 36, 6, 32, 
    2, 17, 8, 51, 1, 35, 0, 49, 3, 37, 7, 42, 4, 24, 6, 30, 5, 51, 
    2, 39, 0, 91, 4, 58, 1, 86, 7, 98, 8, 18, 3, 13, 6, 79, 5, 52, 
    6, 64, 3, 58, 1, 75, 8,  5, 2, 75, 7, 13, 0, 54, 4, 69, 5,  8, 
    8, 70, 6, 35, 5, 87, 7, 43, 2, 99, 0, 80, 1,  3, 3,  9, 4, 23, 
    8, 49, 4, 97, 6,  6, 2, 34, 1, 16, 3, 80, 0, 86, 5, 89, 7, 84, 
    1, 11, 0, 72, 5, 42, 6, 56, 4, 83, 2, 42, 8, 16, 3, 25, 7, 28, 
    4, 46, 6, 71, 3, 14, 5, 20, 8, 90, 1, 51, 7, 88, 0, 79, 2, 27
  };
  const int q8108[] = {
    9, 9, // Number of jobs and machines
    0, 89, 7, 45, 5, 14, 3, 73, 6, 62, 4, 73, 1, 43, 2, 29, 8, 28, 
    8, 25, 2,  4, 5, 72, 6,  5, 0, 38, 7, 44, 3, 24, 4, 89, 1, 77, 
    2, 22, 0, 52, 6, 31, 5, 42, 3, 46, 1, 16, 7, 54, 8, 58, 4, 62, 
    7, 18, 1,  4, 0, 41, 8, 17, 4, 36, 5, 82, 3, 64, 2, 52, 6, 89, 
    1, 47, 6, 71, 5, 79, 4, 48, 0, 17, 7, 16, 3, 56, 2, 86, 8, 50, 
    2, 31, 0, 79, 8, 64, 3,  7, 7, 52, 6, 82, 1, 79, 5, 80, 4, 77, 
    2, 47, 5, 15, 7, 35, 3, 28, 6, 94, 4, 12, 8, 92, 0, 52, 1, 90, 
    3, 44, 4, 99, 8, 11, 1, 19, 7, 34, 0, 45, 2, 13, 5, 68, 6, 71, 
    5, 80, 0, 15, 3, 15, 8, 95, 7, 78, 6, 95, 4, 33, 1, 56, 2, 68
  };
  const int q8109[] = {
    9, 9, // Number of jobs and machines
    2, 42, 5, 32, 7, 89, 6, 50, 8, 57, 3, 12, 0, 41, 4, 38, 1, 15, 
    5, 42, 0, 97, 7, 81, 3, 77, 6, 70, 1, 13, 2, 81, 4, 22, 8,  1, 
    7, 21, 4, 22, 6, 17, 3, 86, 5, 91, 0, 31, 1, 16, 8, 83, 2, 56, 
    7, 62, 4, 44, 6, 28, 5,  9, 3, 71, 2, 51, 8, 46, 0, 75, 1, 87, 
    3, 82, 7, 13, 0, 38, 2, 75, 6, 20, 5, 15, 8, 96, 4, 93, 1, 83, 
    4, 27, 8, 27, 0, 62, 7, 93, 6,  4, 5, 26, 3, 66, 1, 87, 2, 35, 
    2, 14, 8,  1, 6, 13, 5, 92, 3, 49, 4, 68, 7, 31, 1, 53, 0, 72, 
    2, 40, 1, 24, 0, 20, 6, 35, 7, 42, 5, 74, 4, 75, 8, 70, 3, 43, 
    1, 92, 5, 39, 4, 10, 3, 60, 0, 44, 6, 94, 2, 57, 8, 33, 7, 68
  };
  const int q8110[] = {
    9, 9, // Number of jobs and machines
    5, 37, 6,  4, 8, 55, 0, 51, 4, 34, 2, 38, 1, 78, 7, 99, 3, 47, 
    7,  8, 4, 99, 6, 94, 3, 96, 0, 35, 5, 57, 1, 56, 2, 82, 8, 32, 
    2, 47, 7,  3, 8, 46, 5, 39, 1, 94, 0, 63, 4, 23, 6, 46, 3, 96, 
    1, 96, 5, 41, 7, 59, 8, 57, 2, 68, 4, 65, 3, 95, 0, 84, 6, 24, 
    7, 97, 3, 75, 2, 85, 4, 93, 8, 80, 1, 12, 5, 53, 6, 35, 0, 13, 
    0, 32, 7, 65, 8, 56, 5,  3, 3, 63, 4, 73, 1, 73, 6, 75, 2, 48, 
    8, 76, 5, 85, 2, 36, 0, 10, 4, 38, 3, 90, 1, 58, 6, 30, 7, 67, 
    1, 11, 5, 87, 6, 63, 7, 35, 0, 88, 4, 61, 2, 86, 8, 64, 3, 64, 
    4, 51, 7, 91, 5, 36, 6, 43, 8, 70, 2, 55, 3, 28, 1, 36, 0, 22
  };
  const int q8111[] = {
    9, 9, // Number of jobs and machines
    6,  2, 1, 43, 4, 12, 8, 61, 0, 59, 7, 12, 3, 80, 2, 94, 5, 82, 
    1,  6, 6, 54, 4, 44, 8, 28, 0, 34, 3, 62, 7, 48, 2, 53, 5, 61, 
    8, 18, 0, 49, 7, 89, 4, 44, 1, 63, 6, 89, 5, 78, 3, 18, 2, 45, 
    8, 90, 5, 80, 2, 21, 6, 99, 1,  3, 0, 64, 3, 72, 7, 54, 4, 99, 
    2, 81, 7, 75, 8, 50, 6, 52, 1, 33, 4, 35, 5, 73, 0, 55, 3, 59, 
    6, 23, 8, 69, 5, 85, 2, 10, 4, 34, 0, 69, 7, 59, 3, 88, 1, 41, 
    0, 99, 1, 41, 8, 48, 5, 52, 2, 91, 6,  5, 3, 21, 4, 91, 7, 52, 
    6,  6, 2, 91, 4, 35, 7, 60, 0, 56, 5,  4, 8, 41, 3, 91, 1, 91, 
    0,  1, 2, 55, 5, 11, 1, 13, 7, 25, 4, 52, 6, 55, 8, 34, 3, 65
  };
  const int q8112[] = {
    9, 9, // Number of jobs and machines
    3,  4, 4,  6, 2, 87, 5, 73, 6, 80, 7, 99, 1, 81, 0, 51, 8, 61, 
    5, 14, 6, 34, 4, 46, 7, 80, 0, 79, 3, 88, 2, 58, 8, 87, 1, 21, 
    5, 72, 6, 79, 7, 70, 8, 88, 1, 82, 0, 24, 2, 47, 3, 77, 4, 32, 
    5, 69, 0, 96, 6, 30, 8, 84, 4, 49, 7, 98, 1, 38, 3, 56, 2, 66, 
    3,  9, 8, 80, 4,  8, 1,  2, 5, 53, 0, 78, 2, 27, 6, 10, 7, 21, 
    6, 12, 5, 48, 1, 24, 2,  1, 4, 76, 7, 16, 3, 33, 8, 51, 0, 37, 
    5, 57, 6, 32, 1, 90, 3, 62, 2, 10, 8, 88, 4, 78, 0, 48, 7, 62, 
    1, 89, 0, 87, 8, 59, 3, 14, 7,  6, 2, 53, 5,  9, 6, 48, 4, 64, 
    7, 80, 8, 63, 4, 27, 1, 10, 6, 40, 5, 13, 0, 49, 3, 50, 2, 72
  };
  const int q8113[] = {
    9, 9, // Number of jobs and machines
    5, 33, 0, 19, 2, 83, 8, 18, 6, 35, 7, 51, 4, 39, 1, 94, 3, 54, 
    0, 11, 7, 44, 6, 66, 4, 40, 5,  5, 3,  2, 2, 41, 1, 13, 8, 11, 
    8, 22, 6, 49, 3, 86, 5, 64, 2,  2, 0, 75, 1, 86, 4, 37, 7, 18, 
    6,  2, 3, 27, 2, 92, 8, 77, 0, 30, 4, 44, 5, 92, 1, 43, 7, 82, 
    6, 89, 0, 25, 5,  5, 4, 23, 8, 31, 7, 36, 2, 62, 1, 10, 3, 42, 
    2, 91, 5, 10, 3,  2, 0, 19, 4, 41, 7, 78, 8, 89, 1, 71, 6, 25, 
    2, 54, 7, 92, 6, 63, 1, 30, 0, 36, 5, 33, 3, 37, 8, 33, 4, 31, 
    2, 26, 5, 98, 0, 85, 6, 40, 1, 26, 3, 75, 7, 12, 8, 33, 4, 13, 
    0, 57, 4, 41, 6,  1, 7, 30, 5, 30, 2, 16, 8, 72, 3, 53, 1, 96
  };
  const int q8114[] = {
    9, 9, // Number of jobs and machines
    7, 92, 5, 15, 3, 66, 2,  1, 8,  1, 1, 63, 4, 72, 0, 74, 6, 20, 
    8, 17, 1, 43, 4, 32, 7, 52, 0, 92, 5, 32, 3, 98, 6, 71, 2, 65, 
    8, 82, 4, 59, 7, 70, 5,  3, 3, 54, 2, 81, 0, 69, 1, 60, 6, 58, 
    4, 21, 8, 55, 5,  5, 7, 88, 1, 87, 6, 57, 2, 76, 0, 20, 3, 53, 
    7, 94, 8, 70, 0, 28, 2, 81, 6, 66, 5, 11, 3, 91, 4,  8, 1, 30, 
    1,  5, 2, 48, 0, 88, 4, 26, 6, 96, 7, 79, 3, 78, 5, 48, 8, 65, 
    4, 56, 8, 51, 5, 70, 7, 66, 1,  1, 3, 53, 6,  8, 0, 23, 2, 25, 
    0, 26, 8, 32, 3, 85, 5, 96, 1, 27, 4, 50, 7, 88, 6, 25, 2, 18, 
    1, 50, 3,  4, 4, 91, 7, 88, 8, 30, 2, 96, 6,  5, 0, 24, 5, 48
  };
  const int q8115[] = {
    9, 9, // Number of jobs and machines
    6, 40, 4, 81, 3,  1, 5, 28, 0, 84, 2, 73, 7, 42, 8, 67, 1, 29, 
    8, 87, 2, 63, 0, 46, 7, 88, 1, 76, 4, 22, 5, 86, 6, 18, 3, 88, 
    5, 17, 4, 73, 7, 57, 8, 53, 2, 80, 6, 17, 1, 10, 3, 14, 0, 90, 
    2, 81, 4, 94, 3,  7, 0,  8, 1, 48, 5, 77, 6,  9, 7, 28, 8, 96, 
    7, 80, 2, 82, 1, 45, 3, 38, 0, 18, 4, 15, 6,  8, 8, 22, 5,  1, 
    3, 46, 7, 37, 8, 70, 4, 22, 1, 57, 5, 52, 2, 32, 0, 23, 6, 14, 
    5, 44, 2, 13, 4, 43, 0, 93, 7, 78, 3,  6, 8, 78, 1, 45, 6, 56, 
    7, 46, 8, 79, 0, 41, 6, 53, 2, 22, 4, 53, 5, 95, 1, 28, 3, 33, 
    4, 87, 7, 73, 0, 76, 1, 14, 6, 31, 5, 44, 3, 34, 2, 36, 8, 25
  };
  const int q8116[] = {
    9, 9, // Number of jobs and machines
    5, 83, 7, 67, 1, 56, 2,  3, 6, 79, 4,  6, 3, 35, 8, 70, 0, 15, 
    3, 38, 0, 94, 4, 20, 7, 60, 8, 37, 5, 49, 1, 32, 2, 84, 6, 93, 
    1, 77, 4, 72, 7, 22, 3, 74, 5, 18, 2, 92, 8, 66, 6, 89, 0, 64, 
    2, 77, 8, 20, 0, 16, 7, 98, 4, 88, 6, 49, 1, 64, 5, 12, 3, 72, 
    8,  7, 6, 79, 1, 87, 2, 98, 4, 39, 7, 32, 5, 42, 0, 12, 3, 24, 
    6, 65, 4, 22, 5, 20, 3, 73, 8, 32, 0, 58, 7, 20, 2, 47, 1,  1, 
    8, 17, 0, 31, 5, 59, 2, 18, 6, 15, 1, 59, 3, 31, 4, 92, 7, 47, 
    7, 79, 1, 63, 4, 50, 2, 57, 3, 77, 5, 18, 0, 39, 6,  3, 8, 99, 
    4, 71, 6, 28, 5, 57, 3, 57, 8, 84, 1, 98, 0, 76, 2, 45, 7,  7
  };
  const int q8117[] = {
    9, 9, // Number of jobs and machines
    6,  1, 0, 66, 2, 69, 8, 75, 3, 76, 5, 91, 7, 43, 1, 66, 4, 95, 
    4, 51, 1, 53, 7, 57, 8, 55, 6, 37, 5, 18, 2,  9, 3, 93, 0, 81, 
    5, 45, 4, 36, 8,  6, 2, 61, 7, 97, 1, 85, 6,  7, 3, 78, 0,  4, 
    6, 74, 2, 40, 5, 91, 4, 26, 0, 82, 7, 96, 3, 18, 8, 50, 1, 58, 
    7, 88, 5, 37, 6, 93, 8,  1, 2, 61, 1, 93, 4, 81, 3, 87, 0, 45, 
    7, 45, 3, 27, 0,  3, 5, 92, 4, 79, 8, 26, 1, 25, 6, 87, 2, 18, 
    4, 27, 1, 37, 2, 34, 3, 46, 7, 45, 6, 39, 0, 30, 5, 57, 8, 67, 
    0, 85, 6,  9, 1, 99, 7, 57, 4, 76, 2, 46, 8, 45, 5, 12, 3, 37, 
    1, 59, 4, 45, 8,  9, 7, 45, 0, 58, 6, 64, 3, 72, 5, 11, 2, 19
  };
  const int q8118[] = {
    9, 9, // Number of jobs and machines
    3, 48, 0, 54, 2, 51, 6, 69, 5, 80, 7, 47, 4, 22, 8, 12, 1, 11, 
    5, 93, 8, 21, 2, 12, 7, 43, 1, 89, 0, 31, 4,  7, 3, 35, 6, 90, 
    8, 63, 1, 19, 0, 54, 7, 42, 6,  5, 3, 38, 2, 92, 4, 33, 5, 23, 
    0, 14, 4, 60, 3, 13, 8, 24, 2, 86, 1, 58, 5, 46, 7, 53, 6, 15, 
    3, 69, 6, 25, 0, 41, 2, 62, 5, 67, 8, 61, 1, 47, 7,  8, 4, 52, 
    1, 32, 5, 62, 2, 42, 3, 95, 4, 31, 8, 28, 7, 21, 0, 59, 6, 69, 
    0, 32, 4, 13, 5, 86, 7, 54, 8, 76, 2,  6, 6, 47, 1, 75, 3, 21, 
    2, 69, 3,  6, 0, 85, 5, 92, 1, 78, 7, 54, 6, 24, 8, 28, 4, 66, 
    5,  7, 8, 18, 2, 21, 7, 43, 4, 68, 3, 73, 1, 90, 6, 75, 0, 96
  };
  const int q8119[] = {
    9, 9, // Number of jobs and machines
    6, 51, 5, 14, 1, 93, 2, 89, 8,  9, 7, 16, 4, 12, 3, 74, 0, 63, 
    0, 99, 4, 90, 8, 40, 3, 80, 6, 74, 2,  4, 7, 48, 5, 13, 1, 10, 
    5, 42, 8,  9, 1, 96, 6, 17, 7,  7, 2, 22, 4,  3, 0, 19, 3, 85, 
    4, 98, 8, 75, 6, 49, 0, 15, 2, 83, 7, 95, 1, 30, 3, 52, 5, 51, 
    8, 55, 0, 28, 5, 72, 3, 74, 6, 50, 7, 62, 4, 29, 2, 34, 1, 67, 
    3, 19, 8, 81, 0, 74, 1, 13, 6, 36, 7, 29, 5, 71, 2,  6, 4, 49, 
    2, 25, 6, 67, 3, 67, 8, 44, 1, 92, 7, 86, 5, 48, 0, 15, 4, 46, 
    6, 76, 3, 87, 4, 42, 1, 72, 5, 81, 8, 38, 0,  9, 2,  6, 7, 31, 
    7, 77, 2,  2, 3, 57, 8,  7, 4, 82, 6, 34, 5, 56, 0,  2, 1, 57
  };
  const int q8120[] = {
    9, 9, // Number of jobs and machines
    6, 14, 4,  7, 0, 12, 5, 16, 7, 43, 1, 18, 8, 13, 2, 90, 3, 42, 
    0, 20, 4, 91, 7, 98, 3, 77, 2, 75, 6, 22, 5, 69, 1, 28, 8, 94, 
    7, 38, 2, 94, 5, 74, 8, 90, 0, 78, 1, 12, 3, 21, 4, 49, 6, 47, 
    0, 22, 6, 83, 1, 66, 4, 83, 8, 16, 7, 78, 3, 20, 2, 45, 5, 61, 
    1, 68, 8, 37, 4, 92, 2, 86, 3, 77, 0,  9, 7, 62, 5, 84, 6, 84, 
    8, 69, 6,  2, 5, 11, 3, 13, 1, 92, 2, 56, 0, 16, 7, 69, 4, 12, 
    2, 87, 7,  4, 8, 61, 4, 51, 1, 11, 0, 89, 6, 81, 3, 59, 5, 12, 
    7, 54, 6, 49, 5, 69, 4, 69, 0, 12, 2, 95, 1, 58, 8, 90, 3, 72, 
    5, 33, 4, 53, 2, 84, 6,  1, 0, 13, 7, 76, 1, 55, 8, 19, 3, 12
  };
  const int q8121[] = {
    9, 9, // Number of jobs and machines
    3, 45, 4, 68, 6,  6, 0, 91, 2, 23, 5,  1, 8,  4, 1,  3, 7, 78, 
    8, 27, 0, 38, 2, 51, 3, 30, 5,  5, 1, 68, 7, 27, 6, 41, 4, 63, 
    4, 18, 3, 99, 2, 33, 5, 26, 6, 87, 1, 14, 7, 21, 0, 59, 8, 19, 
    1, 54, 0,  4, 5,  8, 8, 83, 7, 82, 6,  6, 4, 42, 3, 59, 2,  5, 
    1, 12, 3, 54, 4, 74, 7, 79, 8, 58, 0, 45, 6, 37, 2, 62, 5,  3, 
    4, 49, 2, 60, 3, 25, 5, 97, 7,  5, 8, 57, 1, 71, 0, 80, 6, 85, 
    7, 92, 2, 74, 4, 88, 6, 34, 1, 63, 8, 32, 5, 25, 3, 82, 0, 95, 
    4, 43, 0, 51, 2, 80, 1, 95, 6, 27, 8, 35, 5, 81, 7, 98, 3, 29, 
    0, 16, 3, 49, 5, 41, 1, 98, 4, 61, 8, 46, 7, 11, 6, 58, 2,  7
  };
  const int q8122[] = {
    9, 9, // Number of jobs and machines
    6,  3, 1, 63, 4, 59, 8, 44, 0, 11, 3, 41, 5, 63, 7, 75, 2, 75, 
    8, 38, 5, 98, 7,  5, 2, 23, 3, 97, 4, 78, 6, 83, 0, 14, 1, 94, 
    5, 89, 2, 44, 0, 75, 8, 94, 7, 41, 6, 39, 4, 26, 3, 23, 1, 85, 
    6, 63, 8, 91, 1, 99, 7, 68, 2, 80, 4, 51, 0,  1, 3, 75, 5, 76, 
    2, 41, 3, 16, 6,  5, 0, 94, 8, 91, 7, 54, 5, 52, 1, 93, 4, 24, 
    2, 49, 5, 48, 3, 43, 4, 49, 1, 20, 6, 18, 8, 23, 0, 24, 7, 24, 
    5, 66, 6, 65, 2, 62, 3, 29, 8, 47, 1, 14, 7, 74, 4, 54, 0, 21, 
    3, 24, 0, 62, 1, 16, 8, 55, 7, 72, 2, 30, 4, 63, 5, 52, 6, 16, 
    8, 41, 7, 63, 1, 56, 0, 67, 6,  4, 2, 99, 4, 32, 3, 46, 5, 58
  };
  const int q8123[] = {
    9, 9, // Number of jobs and machines
    2, 38, 8,  8, 6, 90, 1, 75, 5, 17, 7, 76, 4, 88, 0, 63, 3, 87, 
    6, 17, 1, 47, 7, 96, 8, 59, 2, 93, 4, 91, 5, 15, 3, 69, 0, 40, 
    1, 66, 3, 31, 5, 18, 2, 41, 8, 61, 4, 86, 6, 85, 0, 24, 7, 35, 
    6, 95, 8, 58, 7,  5, 2, 79, 5, 29, 0, 92, 4, 39, 1, 41, 3, 76, 
    1, 84, 6, 20, 5, 98, 2,  4, 4, 70, 7, 46, 8, 16, 0, 95, 3, 31, 
    2, 10, 7, 40, 0, 61, 5,  5, 3, 69, 6, 42, 4, 73, 8, 63, 1, 35, 
    2, 47, 6, 29, 1, 20, 4, 34, 3, 59, 7, 19, 8, 22, 0, 60, 5,  8, 
    8, 93, 4, 18, 2, 78, 7, 37, 5,  8, 6,  9, 3, 51, 1, 94, 0, 81, 
    5, 18, 4, 82, 2, 45, 0, 96, 8, 91, 1, 50, 7, 92, 6, 29, 3,  8
  };
  const int q8124[] = {
    9, 9, // Number of jobs and machines
    4, 91, 8, 55, 2, 81, 5, 40, 6, 56, 7, 30, 1, 93, 0, 43, 3, 30, 
    4, 97, 0, 98, 6, 37, 1, 43, 2, 23, 5, 67, 3, 95, 7, 29, 8,  3, 
    0, 87, 2, 33, 1, 94, 3, 32, 6, 87, 4, 59, 7, 86, 8, 14, 5, 91, 
    3, 86, 2, 86, 4, 69, 6,  9, 0, 22, 5, 25, 1,  3, 8, 47, 7, 44, 
    0, 73, 4, 25, 5, 44, 3, 50, 1, 18, 8, 11, 7, 32, 6, 69, 2, 51, 
    2, 95, 8, 20, 6, 22, 3, 38, 1,  5, 0, 51, 5, 79, 4,  2, 7, 58, 
    5,  5, 3, 44, 0, 25, 4, 12, 7, 33, 6,  5, 2, 79, 1, 79, 8, 87, 
    2, 54, 5, 91, 7, 22, 1, 50, 6,  9, 4,  4, 8, 56, 3, 12, 0, 15, 
    3, 41, 7,  4, 4, 85, 5, 48, 8, 10, 6, 44, 1, 18, 2, 99, 0, 12
  };
  const int q8125[] = {
    9, 9, // Number of jobs and machines
    2, 33, 3, 19, 8, 52, 4,  9, 6, 10, 7, 26, 1, 41, 0, 63, 5, 79, 
    7, 49, 4, 91, 6, 48, 2, 75, 3, 96, 0, 47, 8, 19, 5, 87, 1, 63, 
    6, 15, 1, 91, 8, 74, 3, 30, 4, 17, 7,  4, 5, 59, 0, 74, 2, 12, 
    6, 87, 3, 97, 8, 89, 4, 69, 1, 25, 2, 15, 7,  1, 5, 38, 0, 69, 
    6, 85, 0,  1, 2, 40, 3, 31, 1, 99, 5, 37, 7, 17, 4, 13, 8, 28, 
    0, 96, 3, 14, 1, 46, 4, 46, 6, 18, 5, 96, 2, 29, 7, 29, 8, 72, 
    8, 67, 2, 78, 0,  4, 4, 39, 7, 19, 6, 86, 3, 44, 5, 91, 1, 40, 
    7, 91, 4, 12, 5, 93, 2, 57, 6,  8, 3, 42, 0, 12, 1, 33, 8, 31, 
    7, 19, 2,  2, 0, 17, 5, 59, 6, 71, 1, 47, 3, 88, 4, 48, 8, 49
  };
  const int q8126[] = {
    9, 9, // Number of jobs and machines
    2, 73, 0, 35, 6, 91, 7, 83, 4, 70, 5, 76, 1, 83, 8, 35, 3, 65, 
    2, 41, 0, 29, 7, 51, 6,  5, 3, 45, 1, 77, 4, 90, 8, 78, 5, 35, 
    0, 68, 8, 82, 7, 55, 1, 37, 3, 50, 2, 33, 5, 58, 4, 40, 6, 97, 
    5,  3, 7, 85, 2, 66, 8, 11, 4, 88, 0, 96, 1, 96, 3, 92, 6, 64, 
    2, 71, 5, 60, 3, 56, 6, 46, 8, 38, 7,  6, 0, 17, 4, 20, 1, 80, 
    2, 69, 0, 75, 1, 98, 6, 32, 7, 40, 5, 53, 3,  6, 8, 43, 4, 18, 
    1, 22, 3, 75, 5, 50, 7, 44, 6, 65, 0, 77, 2, 10, 8, 59, 4, 99, 
    6, 30, 2, 82, 5, 15, 1, 56, 4, 14, 7, 45, 3, 89, 8, 60, 0, 17, 
    8, 53, 1,  3, 6, 23, 2, 35, 5, 17, 3, 22, 7,  6, 0, 87, 4, 84
  };
  const int q8127[] = {
    9, 9, // Number of jobs and machines
    2, 17, 4, 56, 7, 78, 0, 78, 8, 60, 6, 52, 1, 71, 3, 89, 5, 62, 
    7, 26, 2, 27, 5, 15, 4, 14, 1, 32, 6, 73, 8, 63, 0, 45, 3, 27, 
    5, 50, 7, 86, 2, 94, 3, 76, 8, 50, 4, 68, 0, 73, 6, 70, 1, 25, 
    3, 24, 4, 76, 0, 67, 8, 87, 7, 51, 2, 43, 1, 64, 5, 56, 6, 68, 
    4, 32, 8, 75, 0, 74, 2, 93, 1,  5, 5, 52, 3, 87, 7, 53, 6, 15, 
    5, 18, 8, 91, 3, 46, 1, 48, 2, 82, 0, 13, 7, 95, 6,  1, 4,  9, 
    3, 98, 4, 80, 1, 25, 6, 74, 0, 51, 7, 27, 5, 47, 2, 97, 8, 88, 
    4, 80, 1, 26, 0, 67, 7, 69, 3, 35, 2,  9, 5, 22, 8, 97, 6, 38, 
    6,  1, 1, 27, 4, 92, 2, 41, 5, 84, 8, 59, 7, 25, 3, 59, 0, 91
  };
  const int q8128[] = {
    9, 9, // Number of jobs and machines
    3, 85, 7, 43, 1, 94, 4, 38, 2, 13, 6, 53, 8, 19, 5, 69, 0, 13, 
    2, 69, 0, 83, 8, 68, 4, 90, 3, 16, 5, 56, 6, 46, 7,  3, 1, 23, 
    3, 25, 1,  2, 6, 51, 0, 75, 2, 89, 5, 28, 8, 39, 4, 59, 7,  2, 
    6, 14, 0, 85, 5, 23, 1, 33, 8, 96, 4, 15, 3, 67, 2, 27, 7, 46, 
    4, 26, 5, 32, 6, 30, 0, 53, 3, 17, 1, 51, 7, 36, 2, 77, 8, 81, 
    8, 84, 1, 21, 3, 39, 7, 50, 6, 11, 0, 76, 5, 69, 2,  8, 4, 79, 
    4, 45, 2, 34, 6, 48, 7, 90, 5, 92, 3,  9, 1,  7, 0,  1, 8, 92, 
    3, 76, 4, 14, 8, 46, 1, 43, 0, 48, 5,  4, 6, 17, 7, 72, 2, 74, 
    2, 90, 6, 86, 1,  9, 8, 69, 0, 36, 5, 69, 3, 24, 7, 25, 4, 48
  };
  const int q8129[] = {
    9, 9, // Number of jobs and machines
    0, 32, 6, 36, 1, 17, 8, 52, 2, 46, 7, 95, 5, 97, 3, 56, 4, 49, 
    4, 92, 7, 61, 5, 54, 1, 85, 6, 55, 0, 73, 2, 83, 8, 19, 3, 47, 
    3, 60, 2, 27, 8,  1, 6, 11, 5,  3, 0, 37, 7, 27, 4, 85, 1, 92, 
    8, 79, 1, 84, 6, 35, 4, 77, 5, 79, 0, 30, 7, 13, 3, 43, 2, 36, 
    4, 72, 3, 30, 1, 49, 6, 22, 5, 65, 7, 27, 8,  2, 2, 43, 0, 80, 
    0, 83, 6, 93, 3, 78, 8,  8, 4, 60, 7, 12, 1, 91, 2, 43, 5, 66, 
    0, 81, 6, 50, 7, 91, 3, 34, 5, 78, 1, 41, 4, 91, 2, 30, 8, 31, 
    4, 37, 0, 56, 3, 55, 5,  5, 8, 68, 1, 80, 6, 26, 2,  5, 7, 71, 
    4, 85, 8, 89, 7,  4, 1, 57, 0, 95, 6, 58, 3, 18, 5, 15, 2, 10
  };
  const int q8130[] = {
    9, 9, // Number of jobs and machines
    1, 46, 4, 79, 6, 95, 0, 54, 3, 11, 8, 26, 2, 60, 7, 79, 5, 37, 
    1, 56, 7, 84, 4, 55, 0, 26, 3, 46, 8, 73, 5, 27, 2, 21, 6, 64, 
    5,  3, 6, 31, 2, 62, 8, 90, 7, 73, 1, 44, 4, 46, 3, 56, 0, 32, 
    8, 46, 2, 10, 1, 10, 4, 55, 7, 96, 0, 17, 6, 24, 5, 64, 3, 32, 
    2, 86, 1,  5, 0, 76, 5, 86, 3, 98, 4, 20, 7, 58, 8, 71, 6, 29, 
    5, 22, 0, 95, 2, 96, 8, 91, 4, 18, 6, 88, 1, 93, 3, 15, 7, 26, 
    2, 43, 6, 20, 5, 76, 1, 81, 7, 13, 3, 20, 8, 89, 4, 96, 0, 64, 
    4, 33, 6, 13, 7, 66, 8, 52, 1, 68, 0, 67, 3, 91, 5, 62, 2, 70, 
    3, 95, 2, 52, 8, 69, 1, 39, 0, 40, 4, 16, 7, 99, 5, 51, 6, 65
  };
  const int q8131[] = {
    9, 9, // Number of jobs and machines
    8,  4, 0, 98, 7, 51, 5, 54, 6, 30, 3, 28, 2, 88, 1, 10, 4, 14, 
    4, 17, 7, 85, 0, 75, 8, 73, 6, 77, 2, 88, 3, 64, 5, 33, 1, 21, 
    6, 34, 7, 87, 5, 17, 0, 37, 8, 21, 3, 55, 2, 40, 1, 20, 4,  5, 
    0, 26, 6, 79, 2, 22, 4, 43, 5, 30, 8, 42, 3, 62, 7, 80, 1,  4, 
    0, 55, 4, 51, 8, 37, 7, 76, 3, 17, 2, 37, 1, 58, 5, 12, 6, 88, 
    7, 65, 3, 18, 4, 12, 0, 22, 1, 20, 2, 17, 5, 25, 8, 24, 6, 99, 
    2, 99, 3, 31, 5, 98, 8, 96, 7, 51, 4,  6, 1, 31, 0,  2, 6, 18, 
    8, 55, 1, 23, 5, 64, 7, 18, 0, 89, 6, 90, 2, 86, 4, 91, 3, 67, 
    6, 21, 7, 24, 8, 28, 2, 51, 4, 96, 1, 84, 3,  5, 0, 43, 5,  3
  };
  const int q8132[] = {
    9, 9, // Number of jobs and machines
    2, 65, 5, 65, 4, 71, 1, 81, 0, 43, 8, 30, 6, 39, 7, 49, 3, 86, 
    8, 43, 7, 29, 3, 93, 0, 64, 6,  6, 1, 47, 4,  7, 5, 84, 2,  6, 
    6, 96, 0, 77, 1, 80, 8,  6, 3, 76, 4, 83, 7, 33, 5, 70, 2,  9, 
    4,  7, 5, 77, 1, 93, 6, 91, 0, 82, 7,  5, 8, 25, 3, 91, 2, 91, 
    0, 36, 2, 29, 6, 44, 7, 71, 8, 55, 4, 78, 5, 34, 3, 78, 1, 27, 
    6, 57, 4, 76, 5, 59, 0,  4, 7,  5, 1, 72, 8, 50, 3,  5, 2, 13, 
    0, 18, 5, 74, 8, 26, 1, 25, 4, 40, 2, 87, 7,  2, 3, 41, 6, 48, 
    4,  5, 7, 69, 8, 44, 3, 48, 6, 54, 1, 30, 2, 84, 5, 69, 0, 17, 
    3, 45, 6, 16, 8,  2, 0, 66, 7, 14, 4, 15, 2, 97, 5, 59, 1, 25
  };
  const int q8133[] = {
    9, 9, // Number of jobs and machines
    0, 97, 8, 41, 6, 14, 4, 71, 1,  4, 5, 32, 3, 96, 7, 94, 2,  1, 
    3, 17, 7, 95, 0, 36, 5, 54, 4, 23, 6,  9, 1, 11, 8, 75, 2, 84, 
    0, 16, 7, 15, 6, 71, 2, 13, 1, 99, 8, 86, 3, 47, 5, 48, 4, 34, 
    3, 27, 8, 25, 6, 91, 7, 77, 4,  2, 0,  6, 5, 71, 1, 54, 2, 87, 
    2, 14, 8, 56, 3, 63, 1, 27, 0, 45, 4, 63, 7, 59, 6, 76, 5,  8, 
    2, 14, 7, 39, 1, 66, 6, 22, 5, 95, 4, 15, 0, 99, 3, 64, 8,  3, 
    1, 27, 4, 60, 8, 69, 3, 72, 5, 20, 0, 49, 7, 78, 6, 79, 2, 23, 
    1, 41, 4, 22, 6, 15, 8, 99, 2, 21, 0, 78, 7, 43, 5, 97, 3, 39, 
    6, 66, 4,  7, 8, 55, 7, 25, 3, 86, 0, 45, 5,  4, 1, 60, 2, 76
  };
  const int q8134[] = {
    9, 9, // Number of jobs and machines
    6,  4, 2, 34, 4, 74, 8, 74, 0, 78, 7, 92, 3, 32, 1, 44, 5, 38, 
    0, 74, 2, 46, 1, 29, 7, 45, 4, 62, 8, 20, 5, 87, 3, 27, 6, 70, 
    3,  9, 0, 57, 8, 96, 1, 10, 5, 21, 4, 83, 7, 28, 6,  6, 2, 95, 
    3, 83, 5, 89, 0, 22, 2, 75, 1, 16, 8, 91, 4, 13, 6, 65, 7, 68, 
    8, 75, 2, 72, 5, 65, 1, 55, 7, 49, 0, 20, 4, 68, 6, 80, 3, 21, 
    2, 18, 3, 10, 0, 25, 4, 78, 6, 10, 5, 16, 7, 54, 1, 28, 8, 14, 
    8, 39, 3, 63, 0, 31, 7, 43, 1, 53, 5, 12, 6,  1, 4, 82, 2, 15, 
    8, 90, 2, 89, 6, 24, 3, 95, 4, 19, 1, 17, 7, 20, 0,  2, 5, 49, 
    5, 12, 2, 66, 1,  6, 3, 59, 4,  5, 0, 18, 7, 95, 6, 33, 8, 78
  };
  const int q8135[] = {
    9, 9, // Number of jobs and machines
    1, 85, 0, 45, 7, 35, 6, 60, 2,  9, 5, 37, 3,  3, 4, 32, 8, 46, 
    0, 21, 4, 43, 7, 61, 1, 47, 8, 93, 3, 80, 6, 88, 5, 39, 2, 41, 
    4, 46, 1, 19, 3, 17, 0, 84, 6, 65, 2, 53, 7,  4, 5, 13, 8,  6, 
    3, 64, 0, 98, 7, 10, 2, 13, 8,  8, 1, 96, 6, 74, 5,  4, 4,  6, 
    4, 44, 3, 97, 8, 21, 0, 20, 7, 49, 5, 15, 1, 10, 6, 80, 2, 40, 
    2, 25, 6, 92, 1,  6, 7, 49, 8, 26, 0, 98, 3, 87, 5, 18, 4, 84, 
    3, 64, 7, 56, 6, 42, 0, 19, 1, 48, 5, 49, 2, 56, 8, 27, 4, 92, 
    6, 44, 7, 99, 3, 62, 8, 48, 2, 92, 1, 13, 5, 23, 0, 40, 4, 80, 
    6, 14, 8, 97, 5, 27, 1, 63, 0,  3, 7, 35, 2, 51, 4, 36, 3, 39
  };
  const int q8136[] = {
    9, 9, // Number of jobs and machines
    8, 52, 1,  4, 2, 43, 6, 61, 7, 89, 0,  3, 5,  4, 3, 73, 4,  3, 
    8, 62, 3, 45, 2, 47, 5, 83, 0, 63, 1, 10, 7, 78, 4, 82, 6, 51, 
    6, 43, 3, 98, 7, 31, 2,  2, 4, 71, 1, 50, 8, 19, 0,  3, 5,  8, 
    6, 29, 7,  4, 5, 73, 3, 52, 4, 53, 2, 34, 8, 32, 0, 56, 1, 65, 
    2, 81, 4, 90, 6, 36, 8, 38, 1, 98, 5,  6, 3, 59, 7, 99, 0, 69, 
    6,  2, 1, 87, 4, 79, 2,  4, 5, 59, 8, 19, 3, 76, 0, 38, 7, 74, 
    5,  6, 0, 21, 4,  3, 3, 55, 2, 26, 6, 37, 8, 25, 1, 93, 7, 19, 
    6, 43, 7, 15, 2, 60, 5, 10, 0, 14, 3,  2, 4, 70, 1, 95, 8,  3, 
    8, 83, 3, 40, 1, 42, 0, 20, 6, 76, 2, 56, 5, 41, 4,  7, 7, 45
  };
  const int q8137[] = {
    9, 9, // Number of jobs and machines
    2, 63, 5, 66, 4, 62, 8, 48, 6, 79, 0, 62, 3, 28, 7, 64, 1, 84, 
    0, 84, 7, 79, 2, 23, 5, 29, 4, 28, 3, 86, 6, 41, 1, 97, 8, 46, 
    1, 60, 3, 88, 4, 71, 7, 32, 6, 91, 8,  6, 5,  1, 0, 85, 2,  4, 
    4, 32, 6, 98, 3,  7, 2, 55, 5, 81, 7, 51, 1, 59, 8, 53, 0, 46, 
    2, 16, 1, 16, 0, 27, 7,  8, 5, 12, 3, 19, 8, 68, 6, 22, 4, 54, 
    1, 42, 4, 78, 7, 41, 2, 35, 0, 19, 6, 62, 5, 88, 3, 96, 8, 42, 
    3, 74, 0, 66, 6, 33, 8, 61, 1,  5, 4, 69, 5, 52, 2, 19, 7, 54, 
    0, 64, 2, 87, 1, 39, 6, 16, 4, 51, 8, 73, 5, 92, 7,  3, 3, 61, 
    3, 73, 2,  2, 5, 60, 4,  9, 7, 51, 1, 91, 6, 15, 0, 95, 8, 19
  };
  const int q8138[] = {
    9, 9, // Number of jobs and machines
    3, 28, 7, 46, 6, 70, 8, 83, 2, 86, 1, 58, 0, 59, 5, 63, 4, 11, 
    1, 89, 4, 72, 8, 37, 3,  7, 2, 72, 7, 34, 5, 60, 6,  9, 0, 63, 
    3,  3, 7, 32, 4, 64, 1, 87, 0, 12, 2,  7, 5, 61, 8, 78, 6, 61, 
    1, 79, 3, 61, 5, 82, 2, 33, 4, 76, 7, 94, 8, 62, 0, 38, 6, 18, 
    0, 35, 2, 53, 6, 98, 5, 22, 1, 10, 3,  2, 4, 43, 8, 18, 7, 21, 
    0, 74, 7, 21, 6, 65, 1, 83, 4,  3, 8, 55, 2, 25, 5, 42, 3, 73, 
    6, 62, 5,  1, 7, 35, 0, 39, 3, 32, 4, 12, 8, 68, 1, 35, 2, 58, 
    6,  7, 8,  4, 4, 35, 1, 25, 7, 75, 3, 58, 0, 82, 5, 16, 2, 63, 
    1, 53, 0, 86, 2,  5, 5, 55, 7, 79, 8, 67, 4, 60, 6, 21, 3,  1
  };
  const int q8139[] = {
    9, 9, // Number of jobs and machines
    4, 67, 2, 48, 5, 99, 8, 24, 0, 97, 7, 91, 1, 96, 6, 66, 3, 26, 
    1, 39, 4, 86, 0, 24, 6,  3, 3, 74, 8, 18, 7, 75, 5, 43, 2, 61, 
    5, 21, 1, 36, 6, 62, 7, 17, 4, 77, 3, 40, 8, 14, 2, 25, 0, 11, 
    2, 33, 6, 95, 5, 82, 0, 16, 7, 87, 3, 12, 1,  7, 8, 78, 4, 87, 
    2, 44, 7, 60, 0,  4, 3, 11, 1, 98, 5, 50, 6, 58, 8, 53, 4, 48, 
    5, 45, 6, 19, 4, 32, 7, 80, 2, 86, 3, 86, 0, 93, 8, 72, 1, 17, 
    8, 91, 2, 54, 5, 65, 1, 93, 6, 35, 7, 42, 3, 26, 0, 75, 4, 83, 
    2, 87, 1, 93, 6, 23, 8, 15, 7, 28, 0,  8, 3, 93, 4, 65, 5, 79, 
    0, 39, 5, 58, 6,  3, 1, 43, 8, 10, 2, 62, 7, 67, 4, 91, 3, 82
  };
  const int q8140[] = {
    9, 9, // Number of jobs and machines
    4, 68, 7, 45, 2, 59, 0, 49, 3, 80, 5, 65, 1, 23, 8, 20, 6, 42, 
    1, 18, 3, 60, 5, 17, 7, 56, 2, 65, 4, 74, 6,  1, 8, 85, 0, 56, 
    2, 20, 3, 45, 8, 14, 0, 75, 7, 82, 6, 39, 1, 65, 4, 94, 5, 62, 
    1, 57, 7, 42, 2, 86, 6, 86, 3, 17, 4,  7, 8, 34, 5, 49, 0, 48, 
    8, 99, 7, 34, 4, 73, 1, 82, 0, 94, 2, 52, 5, 27, 3,  8, 6, 37, 
    6, 44, 2,  7, 4, 41, 1, 89, 5, 73, 7, 62, 3,  8, 8, 69, 0, 99, 
    0, 74, 7, 84, 3, 78, 1, 65, 6, 90, 8, 90, 2, 56, 5, 91, 4, 18, 
    0, 68, 7,  3, 2, 62, 4, 88, 5, 85, 1, 22, 3, 78, 6, 95, 8, 77, 
    3, 40, 1, 26, 4, 13, 6, 69, 7, 80, 0, 81, 5, 47, 2, 72, 8, 45
  };
  const int q8141[] = {
    9, 9, // Number of jobs and machines
    4, 51, 2, 44, 8, 50, 0, 15, 7, 48, 3, 15, 6, 24, 5, 41, 1, 81, 
    3, 34, 6, 14, 2, 57, 7, 98, 1, 19, 4, 14, 0, 16, 5, 37, 8, 61, 
    8, 47, 5, 86, 7, 87, 4, 33, 1, 16, 3, 71, 6, 41, 0, 10, 2, 51, 
    3, 40, 2, 14, 5, 39, 0,  8, 6, 15, 1, 10, 4, 91, 8, 35, 7, 92, 
    0, 40, 6, 34, 3, 66, 5,  6, 7, 45, 2, 48, 8, 37, 4, 46, 1, 72, 
    2, 23, 1, 89, 4, 57, 8, 23, 0, 73, 7, 73, 3, 79, 5, 78, 6, 24, 
    3, 37, 7, 53, 6, 56, 2, 84, 1, 73, 0, 48, 4, 31, 5, 42, 8, 32, 
    5, 16, 8, 26, 0, 61, 6, 58, 2, 41, 3, 41, 7, 24, 1, 64, 4, 63, 
    5, 26, 4,  9, 1, 22, 6, 50, 8, 46, 7, 16, 0, 77, 3, 84, 2, 15
  };
  const int q8142[] = {
    9, 9, // Number of jobs and machines
    6, 91, 0, 24, 4, 86, 5, 18, 8, 33, 3, 48, 7, 35, 1, 10, 2, 55, 
    6, 84, 4, 77, 8, 40, 7, 91, 5, 32, 2, 83, 0,  6, 3, 33, 1, 10, 
    5, 14, 2, 36, 0, 58, 6, 10, 8, 61, 7, 30, 3, 25, 1, 74, 4, 12, 
    0, 63, 2, 90, 8, 64, 1,  4, 5, 18, 4, 48, 7, 86, 6,  6, 3, 79, 
    8,  5, 4, 67, 5, 66, 2, 92, 7, 44, 1, 18, 0, 77, 6, 53, 3, 89, 
    2,  8, 0,  1, 8, 98, 3, 69, 4, 96, 1, 35, 6, 49, 7, 52, 5,  6, 
    5, 22, 8, 36, 0, 58, 7, 22, 6, 19, 3, 51, 1, 11, 2, 28, 4,  4, 
    5, 62, 0, 86, 6, 13, 7, 95, 2, 14, 4, 70, 8, 28, 3, 99, 1, 11, 
    5, 73, 2, 75, 7, 70, 0, 78, 3, 46, 4, 86, 6, 67, 1, 31, 8, 36
  };
  const int q8143[] = {
    9, 9, // Number of jobs and machines
    4, 24, 0, 78, 8, 62, 7, 57, 3, 29, 2, 13, 1, 16, 5, 20, 6, 29, 
    8, 78, 2, 17, 1, 75, 6, 80, 7, 74, 3, 19, 5, 79, 4, 18, 0, 33, 
    5, 82, 0, 64, 6,  6, 3, 25, 7, 13, 4,  9, 8, 48, 2, 77, 1, 11, 
    6, 29, 7, 71, 3, 85, 5, 12, 0,  6, 2, 36, 8, 43, 1, 75, 4,  6, 
    0, 16, 2, 45, 3, 79, 8, 27, 7, 35, 4, 39, 5, 68, 6, 45, 1, 23, 
    1, 21, 3, 12, 0, 91, 6, 35, 4, 66, 2, 50, 5, 66, 8,  5, 7, 96, 
    4, 23, 8, 68, 0, 29, 3, 31, 7, 14, 2, 53, 1, 42, 6, 21, 5, 35, 
    1,  5, 8, 65, 3, 78, 7, 74, 2, 84, 5, 33, 0, 70, 6, 51, 4, 56, 
    2, 33, 6, 91, 7, 35, 1,  9, 0, 53, 4, 88, 3, 79, 8, 29, 5, 47
  };
  const int q8144[] = {
    9, 9, // Number of jobs and machines
    7, 14, 4, 50, 2, 16, 1,  9, 6, 54, 3, 56, 0,  3, 5, 14, 8, 12, 
    3, 47, 4, 39, 6, 11, 2, 27, 1, 36, 7, 91, 5, 59, 0, 65, 8, 14, 
    8, 93, 0, 37, 2, 49, 4, 44, 1, 19, 6, 50, 5, 72, 3, 67, 7, 58, 
    6, 52, 8, 71, 3, 50, 0, 82, 5, 34, 2, 91, 4, 30, 1, 41, 7, 59, 
    4, 81, 3, 55, 8, 32, 0, 77, 1, 82, 6, 36, 5,  3, 7, 16, 2,  3, 
    0, 27, 5, 98, 8, 25, 4, 32, 2, 84, 3, 55, 1, 82, 7, 35, 6, 54, 
    5, 82, 1, 20, 2, 98, 8, 78, 4, 42, 0, 68, 7, 84, 3, 29, 6, 13, 
    7, 15, 6, 16, 3,  7, 4, 85, 2, 22, 8, 18, 1, 49, 5, 38, 0, 48, 
    4, 64, 3, 71, 6, 12, 8, 34, 2, 32, 1, 83, 0, 54, 5, 86, 7, 80
  };
  const int q8145[] = {
    9, 9, // Number of jobs and machines
    1, 39, 4, 93, 8, 51, 0, 24, 2, 25, 3, 29, 7, 35, 6,  3, 5, 35, 
    5, 40, 3, 87, 0, 77, 8, 70, 7, 71, 2, 13, 4, 89, 1, 48, 6, 79, 
    7,  6, 4, 20, 6, 69, 5, 17, 1, 12, 3, 35, 2, 85, 0, 34, 8, 28, 
    3, 29, 0, 31, 6, 16, 1, 13, 7, 91, 2, 99, 5, 93, 8, 76, 4, 19, 
    2, 27, 5, 83, 3, 63, 7,  9, 6, 42, 0,  7, 4, 18, 1, 20, 8, 45, 
    3, 96, 8, 55, 5, 25, 0,  1, 1, 91, 6, 31, 7, 54, 4, 33, 2, 32, 
    4, 30, 6, 25, 7, 78, 3, 37, 1, 23, 8, 47, 2, 10, 0, 23, 5, 92, 
    5, 55, 1, 11, 6, 29, 2, 36, 0, 59, 4, 19, 7, 12, 3, 94, 8, 43, 
    2, 46, 0, 96, 7, 55, 8, 36, 6,  1, 3, 77, 4,  4, 1, 59, 5, 29
  };
  const int q8146[] = {
    9, 9, // Number of jobs and machines
    2, 17, 5, 52, 1, 32, 0, 34, 7, 20, 6, 26, 4, 83, 8, 79, 3, 17, 
    4, 96, 2, 18, 5, 18, 3, 91, 8, 45, 1,  8, 0,  1, 7,  3, 6, 29, 
    3, 66, 5, 83, 7, 65, 0, 30, 4, 57, 8, 81, 2, 88, 6,  2, 1, 48, 
    2, 31, 1, 45, 5, 21, 4, 38, 7, 94, 6, 93, 0, 42, 3, 10, 8, 55, 
    4, 19, 7, 95, 8, 67, 2, 14, 0, 51, 1, 16, 5, 63, 3, 12, 6,  7, 
    6, 61, 2, 35, 0, 79, 8,  1, 7, 98, 4, 22, 3, 78, 1, 98, 5, 71, 
    0, 42, 5, 36, 8, 99, 6, 93, 1, 38, 7, 76, 4, 88, 2, 29, 3, 45, 
    0, 33, 6, 30, 4, 65, 8, 52, 5, 33, 2, 79, 7, 88, 3, 26, 1, 90, 
    2, 84, 7, 68, 4, 50, 8,  9, 0, 32, 1, 18, 6, 83, 5,  6, 3, 38
  };
  const int q8147[] = {
    9, 9, // Number of jobs and machines
    5, 40, 6, 30, 8, 15, 2, 81, 3, 83, 1, 62, 7, 98, 0, 51, 4, 37, 
    3, 83, 0, 53, 5, 17, 1, 22, 7, 62, 2, 14, 8, 89, 4, 61, 6,  4, 
    8, 95, 3, 25, 7, 78, 0, 87, 5, 98, 1, 89, 4, 42, 2, 13, 6, 53, 
    0, 57, 8, 55, 2, 24, 7, 14, 4, 73, 3, 89, 1, 46, 5, 62, 6, 73, 
    5, 47, 8,  9, 1, 97, 3, 42, 2, 88, 6,  2, 4, 79, 0, 85, 7, 52, 
    5, 53, 3, 75, 7, 80, 4, 74, 8, 51, 1, 12, 0, 14, 2, 45, 6, 62, 
    7, 58, 5, 17, 6,  6, 8, 21, 1,  9, 0, 89, 2, 25, 4, 34, 3, 43, 
    5,  6, 7, 24, 8, 36, 1, 36, 4, 72, 3, 54, 6, 88, 2, 41, 0, 78, 
    0, 36, 8, 94, 2, 17, 3, 34, 1, 86, 7,  8, 4, 96, 5, 81, 6, 46
  };
  const int q8148[] = {
    9, 9, // Number of jobs and machines
    5, 15, 2,  4, 7, 57, 0, 71, 8, 28, 1, 90, 3, 92, 6, 81, 4, 17, 
    2, 25, 1, 19, 0, 90, 4, 96, 7, 81, 8, 40, 5, 62, 6, 28, 3, 42, 
    3, 23, 5, 25, 7,  4, 2, 65, 8, 87, 6, 55, 1, 38, 0,  5, 4, 26, 
    8, 37, 2, 75, 3, 30, 7,  6, 1, 10, 5, 48, 6, 27, 0, 10, 4, 51, 
    8, 26, 7, 46, 0, 73, 1, 78, 6, 52, 2, 65, 3, 49, 4, 48, 5, 42, 
    1, 56, 2, 12, 0, 82, 4, 52, 5, 45, 8, 80, 3, 59, 6,  4, 7, 58, 
    2, 17, 3, 77, 8, 27, 0,  5, 7, 77, 5, 13, 4, 47, 6, 50, 1, 14, 
    4, 42, 0, 46, 1, 33, 5, 67, 6, 96, 2,  6, 3, 26, 8, 93, 7,  2, 
    8, 49, 5, 83, 6, 43, 7, 37, 4, 89, 0, 81, 1, 25, 2, 90, 3,  5
  };
  const int q8149[] = {
    9, 9, // Number of jobs and machines
    7, 66, 5, 82, 6, 51, 1, 30, 8, 48, 2, 89, 4, 82, 3, 43, 0, 87, 
    0, 83, 3,  7, 6, 95, 4, 70, 1, 80, 7, 80, 2, 27, 5, 39, 8, 46, 
    6, 67, 1, 48, 2, 59, 5, 66, 0, 30, 8, 86, 3, 95, 4, 82, 7, 25, 
    1, 54, 6, 33, 3, 28, 2, 80, 7,  9, 0, 60, 4, 65, 8, 65, 5, 81, 
    1, 17, 5,  5, 0, 63, 3, 63, 8, 23, 2, 30, 4, 66, 7,  4, 6, 78, 
    1, 55, 2, 23, 5, 64, 7, 82, 0, 54, 6, 43, 8, 29, 3, 42, 4, 27, 
    8, 41, 3, 68, 2, 52, 6, 16, 1, 23, 7, 53, 5, 76, 4,  3, 0, 42, 
    3,  4, 4, 30, 0, 80, 6, 19, 5, 58, 8,  1, 7, 93, 2, 33, 1, 51, 
    6, 73, 4, 69, 0, 24, 7,  1, 5, 27, 1, 26, 2, 93, 8, 24, 3, 67
  };
  const int q8150[] = {
    9, 9, // Number of jobs and machines
    8, 88, 6, 15, 0, 25, 1, 33, 2, 41, 5, 41, 7, 79, 4, 97, 3, 13, 
    7, 42, 8, 97, 0,  8, 3, 37, 6, 10, 5, 85, 4, 26, 2,  7, 1, 71, 
    0, 58, 6, 31, 4, 28, 3, 46, 1, 87, 5, 75, 2, 65, 8, 63, 7, 52, 
    5, 86, 2, 46, 8, 13, 1,  1, 3, 46, 6, 78, 7, 46, 4, 11, 0, 67, 
    2, 88, 8, 39, 0, 22, 4, 72, 7, 30, 5,  6, 3, 87, 6, 81, 1, 33, 
    4,  9, 3, 39, 8, 82, 1, 40, 7, 62, 2, 59, 5, 78, 0, 99, 6, 91, 
    7, 46, 3, 56, 8, 39, 0,  3, 5, 74, 2, 64, 1, 54, 6, 32, 4, 43, 
    0, 31, 3, 81, 8, 15, 7, 93, 2, 64, 5, 79, 4, 86, 1, 92, 6, 34, 
    2, 10, 8, 27, 5, 55, 0, 66, 1, 84, 3, 32, 4, 65, 6, 69, 7, 81
  };
  const int q8151[] = {
    9, 9, // Number of jobs and machines
    4, 63, 1, 36, 3, 13, 2, 71, 0, 84, 7, 53, 6, 83, 5, 54, 8, 19, 
    3, 60, 5, 78, 6, 12, 2, 78, 0, 95, 8, 73, 1, 86, 4, 62, 7, 58, 
    8, 30, 2, 59, 0,  8, 7, 71, 1, 25, 3, 77, 5, 94, 6, 83, 4, 88, 
    6, 61, 0, 95, 7, 45, 5, 84, 3, 64, 8, 97, 4,  4, 2, 25, 1, 62, 
    4, 64, 2, 10, 5, 44, 8, 85, 0, 18, 3, 22, 6, 77, 7, 96, 1,  8, 
    5, 72, 1, 47, 7, 12, 4,  4, 6, 24, 8, 10, 2,  1, 3, 22, 0, 78, 
    2, 19, 5, 28, 1, 49, 4, 56, 6, 33, 7, 93, 8,  6, 3, 84, 0, 48, 
    5, 68, 1, 37, 0,  8, 4, 70, 3,  9, 6, 62, 8, 64, 7, 19, 2, 19, 
    6, 93, 4,  4, 1, 97, 3, 14, 7, 71, 2, 42, 0, 35, 5,  5, 8,  2
  };
  const int q8152[] = {
    9, 9, // Number of jobs and machines
    4, 88, 6, 55, 2, 93, 0, 20, 3, 74, 1, 41, 5, 10, 7, 62, 8, 20, 
    1, 37, 3, 33, 0, 48, 5, 99, 8,  5, 4, 91, 2, 48, 6, 33, 7, 75, 
    6, 19, 2, 35, 5, 55, 7, 24, 4, 80, 8, 60, 0, 70, 3, 93, 1, 25, 
    2, 10, 1, 35, 0, 52, 8, 74, 5, 81, 4, 18, 7, 40, 6, 80, 3, 27, 
    8, 79, 7, 60, 2, 94, 4,  6, 3, 27, 5, 66, 6, 29, 0, 50, 1,  5, 
    8, 80, 0, 87, 2, 51, 6, 45, 4, 90, 1,  3, 3,  4, 7, 37, 5, 11, 
    0,  6, 5,  9, 1, 68, 4, 18, 2,  8, 6, 75, 7, 68, 8, 27, 3, 24, 
    5, 93, 3, 17, 8, 30, 4, 64, 0, 98, 1, 81, 2, 51, 6, 89, 7, 77, 
    5, 69, 0, 61, 7, 71, 3, 22, 6, 96, 8,  2, 1, 26, 4, 45, 2, 43
  };
  const int q8153[] = {
    9, 9, // Number of jobs and machines
    0, 75, 2,  2, 5, 33, 1, 47, 4,  6, 3, 93, 8,  9, 6,  3, 7, 36, 
    0, 20, 2, 61, 8, 21, 3, 37, 4, 10, 1, 93, 7, 29, 6, 60, 5, 81, 
    2, 48, 7, 27, 3, 21, 1, 20, 6,  2, 4,  6, 0, 90, 5, 79, 8,  6, 
    3, 88, 0, 46, 6, 42, 8, 12, 7, 69, 1, 12, 4, 28, 2, 87, 5, 23, 
    1,  4, 3, 75, 8, 87, 5, 98, 2, 94, 4, 19, 7,  7, 6, 24, 0, 63, 
    6, 74, 2, 98, 0, 38, 5, 13, 1, 94, 4, 69, 3, 99, 8, 64, 7, 13, 
    2, 74, 7, 27, 0, 83, 5, 25, 1, 47, 6, 23, 4, 51, 8, 22, 3, 60, 
    6, 28, 2, 78, 5, 15, 4, 62, 7, 49, 0, 86, 1, 90, 8, 77, 3,  5, 
    2, 68, 8, 53, 0, 21, 6, 10, 3, 40, 4, 86, 1,  4, 5, 50, 7, 12
  };
  const int q8154[] = {
    9, 9, // Number of jobs and machines
    2, 27, 1, 49, 6, 64, 0,  5, 4, 18, 7, 95, 3,  7, 5, 82, 8, 61, 
    2, 70, 6, 61, 7, 80, 0, 34, 8,  5, 3, 59, 5, 25, 4, 84, 1, 52, 
    2, 14, 1, 48, 8, 88, 3, 35, 0, 87, 5, 33, 6, 83, 7, 48, 4, 48, 
    5, 12, 6, 98, 8, 54, 2, 69, 3, 51, 4, 78, 1, 22, 0, 24, 7,  8, 
    2, 55, 8, 59, 5, 78, 6, 93, 4, 12, 3, 51, 0, 15, 7, 12, 1, 34, 
    8, 65, 5, 68, 7, 12, 3, 43, 0, 84, 2, 64, 6,  4, 1, 31, 4, 15, 
    0,  3, 8, 49, 4,  6, 3, 87, 2, 23, 5, 41, 6, 85, 7, 18, 1, 93, 
    4, 51, 3, 55, 2, 45, 1, 68, 8, 90, 5, 92, 6, 23, 7, 98, 0, 35, 
    1, 53, 8, 21, 2,  8, 5, 65, 6, 43, 4, 22, 7, 51, 3, 96, 0,  9
  };
  const int q8155[] = {
    9, 9, // Number of jobs and machines
    1, 46, 6, 18, 3, 80, 7,  9, 5, 49, 4, 12, 0, 93, 2, 50, 8, 95, 
    3, 42, 8,  2, 1, 75, 4, 27, 7, 75, 6, 42, 0, 45, 2, 76, 5, 14, 
    5, 49, 2, 43, 0, 70, 6, 22, 3,  9, 8, 33, 7, 18, 1, 30, 4, 49, 
    4, 53, 3, 59, 7, 75, 2,  1, 6, 28, 0, 68, 1, 66, 8, 49, 5, 14, 
    5, 75, 4, 88, 0, 91, 1, 79, 6, 54, 3,  9, 2, 97, 7, 35, 8, 45, 
    1, 72, 6, 16, 8, 32, 5, 22, 7, 38, 2, 98, 3,  4, 0, 82, 4, 33, 
    0, 88, 4, 94, 7, 83, 5, 90, 2, 67, 8, 72, 6, 86, 1, 52, 3, 68, 
    5, 28, 0, 13, 8, 62, 1, 83, 2, 87, 7, 75, 6, 35, 3, 28, 4, 36, 
    0, 16, 5, 54, 7,  6, 4,  6, 8,  8, 3, 23, 6, 10, 2, 89, 1, 87
  };
  const int q8156[] = {
    9, 9, // Number of jobs and machines
    8, 22, 0,  4, 7, 17, 1, 65, 4, 61, 2, 91, 6, 72, 3, 52, 5, 76, 
    4, 51, 1, 46, 2, 96, 3, 95, 7, 85, 5, 61, 8, 39, 0, 42, 6, 84, 
    5,  7, 6, 16, 0, 79, 4, 36, 3, 70, 1, 91, 7, 91, 2, 35, 8, 33, 
    6, 58, 8,  9, 1,  8, 2, 56, 0, 70, 3, 86, 4, 42, 5, 13, 7, 48, 
    1, 90, 7, 64, 5, 52, 0, 17, 4, 26, 3, 89, 6, 54, 2, 19, 8, 58, 
    2, 11, 0, 50, 3,  6, 7,  3, 6, 91, 1, 52, 8, 91, 5, 16, 4, 85, 
    8, 66, 0, 33, 4, 32, 2, 79, 5, 56, 3, 94, 1,  3, 6, 53, 7, 47, 
    3, 86, 6, 97, 7, 19, 5, 65, 8, 21, 0, 30, 2, 75, 1, 51, 4, 88, 
    4, 45, 6,  5, 3, 79, 7,  9, 0, 38, 5, 33, 8, 80, 2, 89, 1, 72
  };
  const int q8157[] = {
    9, 9, // Number of jobs and machines
    1,  2, 4, 29, 0, 33, 6, 18, 2, 87, 7, 66, 3, 23, 8,  7, 5, 50, 
    3, 71, 1, 79, 6, 42, 7,  3, 8, 20, 4, 16, 2, 63, 0,  7, 5, 56, 
    6, 50, 8, 76, 2, 84, 4, 38, 0, 70, 5, 62, 1, 25, 7, 84, 3, 74, 
    8,  6, 5, 89, 2, 61, 4, 95, 6, 15, 7, 10, 1, 28, 3, 42, 0, 76, 
    0, 61, 4, 83, 1, 98, 8, 89, 7, 51, 2,  3, 3, 11, 6,  2, 5, 80, 
    3, 41, 1, 24, 2, 60, 8, 25, 4, 33, 7, 35, 0, 74, 6, 61, 5, 80, 
    3, 27, 7, 23, 8, 66, 0, 97, 6, 42, 2, 61, 1, 38, 4, 44, 5, 32, 
    0, 11, 7, 63, 5, 30, 6, 16, 1, 66, 8, 74, 4, 33, 2, 85, 3, 57, 
    1, 72, 8, 69, 3, 27, 5,  9, 6, 38, 2, 77, 7, 72, 4, 51, 0, 44
  };
  const int q8158[] = {
    9, 9, // Number of jobs and machines
    6, 53, 2, 85, 0, 15, 4, 84, 1, 21, 7, 77, 3, 72, 5, 21, 8, 78, 
    6, 13, 7, 31, 3, 77, 2, 88, 0,  1, 5, 33, 4, 42, 8, 44, 1,  4, 
    3, 68, 6, 47, 2, 60, 7, 61, 8, 87, 0, 52, 4, 70, 5, 71, 1, 10, 
    8, 23, 7, 71, 6, 94, 3, 67, 5, 58, 0, 53, 4, 13, 2, 28, 1, 26, 
    8, 75, 1, 12, 6, 38, 4, 89, 5, 92, 7, 97, 2, 91, 3, 63, 0, 26, 
    3, 79, 5, 48, 4, 48, 0, 90, 2, 94, 8, 71, 1, 61, 6, 61, 7, 49, 
    0, 95, 3, 95, 4, 33, 8, 32, 1, 34, 6, 78, 2, 74, 5, 94, 7, 74, 
    5, 43, 6,  3, 4, 52, 3, 79, 0, 71, 1,  6, 8,  3, 2, 77, 7,  5, 
    4, 15, 2, 26, 3, 12, 6, 17, 1, 64, 5, 33, 7, 52, 0, 52, 8,  4
  };
  const int q8159[] = {
    9, 9, // Number of jobs and machines
    7, 62, 5, 73, 3, 76, 1, 51, 2,  1, 6, 81, 8, 20, 0,  5, 4, 52, 
    2, 45, 6, 56, 4, 34, 8, 23, 5, 95, 7, 17, 3, 46, 0, 86, 1, 44, 
    8, 98, 5, 20, 2,  3, 1, 31, 7, 70, 0, 29, 4, 39, 3, 48, 6, 87, 
    3, 96, 8, 62, 1, 45, 7, 62, 0, 64, 5, 25, 4, 17, 2, 22, 6, 62, 
    4, 81, 5, 83, 8, 90, 6, 92, 1, 98, 2, 96, 7,  5, 3, 64, 0, 12, 
    1, 98, 2, 84, 4, 99, 6, 44, 7, 62, 0, 49, 8, 92, 5,  3, 3,  8, 
    1, 21, 8,  6, 6, 63, 2, 31, 0, 31, 3, 45, 5, 53, 7, 19, 4, 87, 
    2, 38, 0, 78, 5, 22, 6, 12, 8, 89, 3, 19, 1, 76, 4, 60, 7, 30, 
    0, 90, 1, 40, 8, 58, 6, 64, 4, 65, 5, 59, 7, 86, 3,  8, 2, 88
  };
  const int q8160[] = {
    9, 9, // Number of jobs and machines
    5, 30, 1, 43, 2, 23, 0, 76, 4, 84, 6, 36, 7, 95, 8, 67, 3, 66, 
    7, 40, 8,  4, 6, 17, 2, 52, 3, 36, 5, 83, 4, 22, 1, 51, 0, 13, 
    4, 64, 7, 58, 3, 47, 6, 85, 1, 87, 5,  4, 0, 97, 8,  7, 2, 69, 
    0, 73, 8, 60, 5, 83, 2, 56, 1, 41, 6, 26, 7,  1, 4, 50, 3, 88, 
    4, 82, 6, 76, 7, 30, 0, 46, 2, 44, 8, 41, 3, 85, 1, 29, 5, 37, 
    2, 94, 5, 99, 8, 58, 6, 20, 0, 66, 7,  8, 3, 43, 4, 24, 1, 14, 
    7, 74, 6, 29, 3,  7, 1,  4, 8, 90, 2, 36, 4, 29, 5, 15, 0, 73, 
    7, 14, 1, 62, 0, 70, 8, 27, 2, 66, 4, 42, 3, 67, 6,  4, 5, 12, 
    7, 63, 0,  4, 1, 32, 4, 77, 3, 50, 8, 47, 5, 62, 2, 27, 6, 30
  };
  const int q8161[] = {
    9, 9, // Number of jobs and machines
    4, 74, 2, 85, 6, 37, 1, 10, 3,  1, 7, 23, 0, 55, 8, 21, 5, 67, 
    7, 25, 3, 60, 0, 61, 5, 35, 4, 36, 1, 12, 6, 89, 2, 79, 8, 58, 
    4, 18, 2, 48, 6, 41, 5, 51, 0,  8, 1, 32, 7, 98, 3, 17, 8, 80, 
    7,  7, 4, 62, 5, 70, 2, 91, 0, 61, 6, 63, 8, 48, 3, 56, 1, 93, 
    2, 11, 6, 16, 7, 22, 5, 46, 8, 27, 4, 48, 1, 32, 0,  4, 3, 48, 
    1,  9, 2, 98, 7, 31, 3, 54, 4, 15, 5, 53, 8, 39, 6, 25, 0, 30, 
    5, 33, 4, 88, 6,  5, 0,  7, 2, 56, 7,  5, 1, 79, 8, 62, 3, 53, 
    8, 62, 0, 24, 7, 74, 6, 27, 3, 64, 5, 74, 1, 49, 2, 23, 4, 15, 
    1, 98, 3, 66, 5, 44, 8, 99, 4, 44, 2, 99, 7, 41, 6, 86, 0, 25
  };
  const int q8162[] = {
    9, 9, // Number of jobs and machines
    5, 39, 6, 60, 0, 27, 1, 26, 8, 58, 4, 75, 3,  7, 2, 68, 7, 66, 
    1, 67, 2, 83, 4, 56, 8, 10, 6, 81, 5,  6, 0, 73, 3, 24, 7, 68, 
    1, 86, 8, 18, 7, 21, 2, 46, 4, 43, 3, 49, 0, 43, 6, 15, 5, 69, 
    1, 62, 2, 84, 7, 40, 0, 37, 6, 36, 3, 34, 4, 91, 5, 73, 8, 26, 
    4, 80, 6, 19, 7, 95, 3, 54, 2, 78, 0, 99, 8, 56, 5, 56, 1, 86, 
    4, 94, 6, 12, 8, 12, 7, 94, 2, 47, 1, 78, 5, 17, 3, 82, 0, 69, 
    4, 39, 6, 41, 3, 93, 0, 14, 1, 47, 2, 60, 5, 31, 7, 47, 8, 74, 
    5, 87, 6, 41, 4, 43, 1, 27, 7, 91, 3, 35, 0, 34, 2, 41, 8,  8, 
    4, 19, 8, 58, 5, 11, 7, 83, 3, 94, 2, 24, 0, 75, 1, 94, 6,  1
  };
  const int q8163[] = {
    9, 9, // Number of jobs and machines
    7, 65, 8, 68, 2, 11, 1, 61, 6, 43, 0, 49, 4, 85, 3, 43, 5, 53, 
    3,  9, 6, 24, 1, 11, 4, 97, 0, 94, 8, 31, 7, 40, 5, 88, 2, 41, 
    5, 84, 1, 77, 3, 64, 0, 22, 2, 13, 7, 20, 6, 75, 8, 40, 4, 44, 
    0, 97, 7,  8, 4, 59, 1,  2, 3, 78, 5, 43, 8, 94, 6, 68, 2, 28, 
    4,  7, 2, 28, 8, 20, 0, 29, 5, 41, 7, 86, 6, 61, 3, 39, 1, 43, 
    3, 37, 6, 11, 4, 17, 0, 89, 5, 28, 8, 83, 2, 53, 7, 19, 1,  2, 
    3, 55, 8, 64, 7, 49, 5,  6, 6, 47, 2, 31, 0, 50, 4, 34, 1, 37, 
    2, 70, 5, 95, 4, 12, 1, 84, 3, 31, 6, 35, 0, 95, 8, 36, 7, 36, 
    8, 18, 4, 44, 7, 75, 3, 96, 1, 75, 6, 58, 0, 99, 5,  4, 2, 95
  };
  const int q8164[] = {
    9, 9, // Number of jobs and machines
    4, 83, 6, 48, 0, 94, 5, 69, 8, 86, 1, 90, 3, 99, 7, 72, 2,  7, 
    4, 56, 6, 53, 5, 55, 0,  3, 2,  5, 3, 51, 8, 20, 1, 94, 7, 76, 
    8, 78, 6, 14, 1,  7, 4, 96, 7,  4, 2, 58, 0, 15, 3, 94, 5, 44, 
    1, 91, 2, 47, 8, 95, 7, 74, 6, 40, 4, 28, 3, 34, 0, 67, 5, 64, 
    7, 45, 3, 79, 0, 79, 1, 79, 5, 23, 6, 20, 8, 76, 2, 39, 4, 84, 
    0, 16, 2, 63, 5, 47, 7,  8, 1,  1, 4, 52, 6, 60, 8,  9, 3, 93, 
    4, 81, 1, 22, 2, 66, 6, 65, 0, 73, 7, 24, 5, 26, 3, 11, 8, 11, 
    6,  7, 1, 54, 8, 73, 7, 49, 2, 90, 4,  1, 5, 99, 3, 55, 0, 66, 
    7, 96, 2,  2, 3,  5, 8, 50, 1, 86, 5, 79, 0, 29, 4, 99, 6, 98
  };
  const int q8165[] = {
    9, 9, // Number of jobs and machines
    6, 81, 4,  7, 0, 19, 8, 39, 7,  3, 2, 98, 3, 49, 5, 68, 1, 54, 
    1, 82, 8, 21, 0, 78, 4, 48, 2, 57, 5, 18, 3, 20, 6, 64, 7, 87, 
    6, 24, 2, 90, 4, 44, 8, 76, 0, 27, 5, 63, 7, 36, 1, 17, 3, 83, 
    4, 29, 6, 15, 3, 78, 2, 72, 8, 52, 5, 78, 7, 31, 0, 15, 1, 14, 
    3, 89, 6, 66, 5, 65, 1, 26, 7, 12, 4,  2, 2, 92, 8, 22, 0, 53, 
    5, 38, 8, 66, 0, 33, 2, 96, 3, 93, 7, 86, 1, 98, 4, 15, 6, 26, 
    5, 13, 1, 76, 3, 83, 2, 16, 6, 15, 4, 64, 7, 24, 0, 65, 8, 32, 
    1, 75, 5, 30, 3, 89, 2, 38, 4, 93, 8, 30, 0,  6, 6,  9, 7, 81, 
    1, 80, 4, 99, 6, 50, 7, 18, 3, 16, 2, 61, 5, 18, 8, 42, 0, 62
  };
  const int q8166[] = {
    9, 9, // Number of jobs and machines
    1, 16, 2, 64, 7, 39, 3, 80, 4, 74, 0, 36, 5, 53, 6, 23, 8, 32, 
    1, 31, 3, 94, 7, 31, 5, 57, 6, 73, 4, 11, 0, 95, 2,  6, 8, 20, 
    3, 92, 1, 12, 0, 23, 7, 46, 2, 29, 6, 58, 8, 49, 4, 90, 5, 58, 
    4, 42, 0, 14, 8, 98, 5, 73, 6, 15, 7, 97, 1, 68, 3, 34, 2, 78, 
    6, 40, 7, 94, 1, 11, 8, 47, 0,  3, 5, 70, 4, 25, 2, 64, 3, 27, 
    1, 92, 0, 33, 7, 54, 6, 18, 4, 83, 8, 63, 3, 47, 5,  4, 2,  4, 
    3, 79, 2, 35, 6, 83, 8, 55, 0, 85, 7, 20, 1, 25, 5, 14, 4, 36, 
    6, 28, 1, 93, 3, 59, 5, 27, 8, 58, 4, 62, 7, 63, 0, 36, 2, 78, 
    5, 64, 1, 51, 7, 74, 8, 87, 2, 51, 3, 45, 0, 48, 4, 82, 6,  5
  };
  const int q8167[] = {
    9, 9, // Number of jobs and machines
    8, 49, 4, 56, 3, 51, 6, 59, 2,  6, 5, 51, 1, 97, 0, 94, 7, 67, 
    3, 30, 2, 69, 0, 84, 7, 63, 5, 98, 1, 82, 8, 52, 6, 55, 4, 95, 
    8, 22, 6, 14, 2, 13, 0,  9, 1, 69, 7, 87, 4, 90, 5, 98, 3,  3, 
    5, 16, 0, 58, 1,  7, 7, 90, 3, 44, 4, 55, 6, 38, 2, 42, 8, 26, 
    1, 86, 5, 58, 4, 75, 8, 36, 3,  1, 2, 68, 7, 83, 6, 19, 0, 91, 
    3,  9, 8, 40, 6, 82, 1, 96, 0, 79, 4, 34, 5,  9, 7, 78, 2, 71, 
    5, 84, 1, 77, 0, 95, 7, 92, 3, 56, 2, 71, 6, 85, 4, 91, 8,  7, 
    5, 22, 8, 41, 4, 83, 0, 76, 7, 90, 1, 69, 6, 63, 3, 71, 2, 60, 
    3, 61, 1, 63, 2, 67, 7, 43, 4, 19, 5, 45, 8, 10, 6, 40, 0,  7
  };
  const int q8168[] = {
    9, 9, // Number of jobs and machines
    7, 11, 4, 55, 5, 76, 3, 96, 8, 73, 6, 17, 0, 96, 2, 68, 1, 52, 
    5, 15, 0, 93, 4, 21, 6, 98, 2, 53, 1, 50, 3, 32, 7, 28, 8, 43, 
    8, 24, 3, 16, 4, 75, 2,  7, 6, 91, 5, 35, 1, 42, 7,  3, 0, 74, 
    2, 93, 0,  6, 4, 28, 1, 32, 5, 22, 3, 67, 8, 85, 6, 80, 7,  7, 
    5, 83, 3, 12, 7, 12, 2, 15, 0, 73, 1, 15, 8, 28, 4, 54, 6, 15, 
    5, 10, 7, 99, 3, 85, 6, 56, 1, 77, 4, 76, 0, 31, 2, 73, 8, 86, 
    7, 71, 6, 23, 1, 87, 5, 24, 2, 70, 0, 27, 4, 54, 3, 49, 8, 67, 
    7, 81, 5, 16, 1, 66, 6, 65, 2, 68, 3, 30, 0, 38, 4, 86, 8, 22, 
    3, 20, 8, 93, 7, 13, 5, 14, 2, 86, 4, 86, 6, 11, 1,  6, 0, 59
  };
  const int q8169[] = {
    9, 9, // Number of jobs and machines
    3,  5, 2, 88, 4, 26, 7, 64, 0, 13, 6, 16, 1, 29, 5, 78, 8, 24, 
    0, 85, 5, 65, 8, 21, 4, 44, 3, 99, 1, 67, 6, 26, 2, 67, 7, 69, 
    3, 83, 5,  4, 8, 59, 0, 29, 6, 33, 2, 12, 1, 78, 4, 87, 7, 22, 
    5, 86, 7, 50, 8, 79, 4, 52, 1, 22, 6, 76, 0, 45, 3, 61, 2, 46, 
    1, 27, 0, 60, 2, 85, 7, 42, 4, 48, 5,  9, 3, 90, 6,  5, 8, 74, 
    4, 15, 5, 31, 6, 39, 2, 36, 0, 65, 3, 88, 8, 73, 7, 56, 1, 66, 
    3, 95, 1, 90, 5,  5, 8, 64, 6, 76, 0, 45, 2, 13, 4,  6, 7, 73, 
    8, 18, 3, 41, 7, 46, 0, 55, 1, 94, 6, 59, 4, 50, 2, 97, 5,  2, 
    5, 75, 4, 19, 3, 15, 7, 54, 6,  6, 2, 55, 0, 99, 1, 41, 8, 47
  };
  const int q8170[] = {
    9, 9, // Number of jobs and machines
    4, 48, 1, 25, 6, 61, 0, 91, 3, 46, 5, 13, 7, 59, 2, 99, 8, 93, 
    0, 99, 2, 19, 8, 66, 3, 90, 7, 53, 1, 16, 6, 40, 4, 10, 5, 98, 
    4, 50, 0, 69, 1, 51, 7, 33, 5, 17, 3, 37, 8, 64, 2, 34, 6, 68, 
    4, 83, 6, 32, 8, 44, 0, 28, 5, 88, 1, 27, 2, 97, 3,  8, 7, 37, 
    1, 25, 8, 48, 6, 72, 3, 13, 0, 47, 7, 66, 5, 83, 2, 73, 4,  1, 
    5, 53, 1, 68, 7, 20, 0, 71, 2, 98, 4, 38, 8,  3, 6, 12, 3, 74, 
    3, 16, 6, 18, 4, 89, 7, 18, 0, 91, 8, 75, 1, 13, 5, 91, 2,  8, 
    3, 59, 4, 19, 6, 47, 1, 34, 8,  5, 5, 23, 2, 71, 0, 99, 7, 61, 
    3,  9, 5,  2, 1, 42, 2, 44, 0, 40, 8, 18, 4, 93, 6, 58, 7, 15
  };
  const int q8171[] = {
    9, 9, // Number of jobs and machines
    6,  1, 4, 71, 7, 40, 5, 57, 0, 43, 1, 69, 3, 36, 2, 92, 8, 27, 
    1, 39, 3, 54, 2,  1, 8, 98, 5,  3, 4, 25, 6, 77, 7, 80, 0, 89, 
    2, 37, 8, 89, 7, 88, 0, 59, 3, 24, 5, 16, 4, 69, 1, 37, 6,  2, 
    6, 32, 5, 60, 0, 48, 3, 25, 7, 12, 1, 22, 2, 79, 4, 18, 8,  7, 
    7, 19, 0, 74, 2, 60, 6, 32, 8, 27, 4,  6, 1, 73, 5, 78, 3, 88, 
    0, 23, 4, 38, 1, 84, 7, 45, 8, 17, 5, 95, 6, 24, 2, 42, 3, 97, 
    5, 60, 2, 44, 6, 28, 7, 86, 0, 31, 1, 45, 8, 17, 4, 72, 3, 36, 
    3,  5, 8, 57, 1,  7, 5, 22, 2, 45, 7,  3, 4, 40, 6, 48, 0, 69, 
    4,  9, 7, 39, 0, 71, 2, 74, 3, 11, 1, 11, 5, 58, 6, 96, 8, 87
  };
  const int q8172[] = {
    9, 9, // Number of jobs and machines
    3,  9, 6, 92, 4, 16, 5, 66, 8, 32, 1, 91, 2, 17, 7, 65, 0,  5, 
    2, 25, 5, 74, 6, 82, 4, 29, 8, 42, 7, 43, 3, 69, 0, 16, 1, 15, 
    4, 86, 6, 77, 7, 80, 1, 46, 2, 29, 0, 11, 5, 33, 3, 63, 8, 16, 
    8, 62, 1, 20, 3, 44, 2, 75, 0, 34, 6, 60, 5, 67, 7,  4, 4, 85, 
    2, 48, 6, 82, 0, 32, 1, 61, 4, 40, 5, 32, 8, 69, 7, 20, 3, 62, 
    6, 62, 1, 30, 0, 21, 2, 62, 8, 89, 3, 28, 5, 38, 4, 10, 7, 15, 
    8, 25, 2, 50, 3, 93, 5, 75, 6,  3, 0, 58, 1, 98, 4, 45, 7, 49, 
    4,  3, 3, 30, 0,  6, 7, 36, 5, 37, 2, 75, 6, 77, 1, 14, 8, 74, 
    2, 84, 7, 48, 4, 18, 1, 30, 5, 83, 6, 51, 3, 84, 8, 97, 0, 19
  };
  const int q8173[] = {
    9, 9, // Number of jobs and machines
    8, 61, 6, 29, 0, 46, 7, 34, 4,  2, 2, 65, 5, 20, 1, 16, 3, 45, 
    1, 49, 5, 23, 6, 42, 2, 91, 0, 97, 3,  7, 4, 50, 8, 80, 7, 63, 
    0,  9, 1, 28, 2, 79, 4, 19, 5, 62, 3, 34, 7, 96, 8, 77, 6, 31, 
    5, 92, 6, 31, 1, 23, 0,  9, 4, 12, 8, 28, 7, 14, 2, 47, 3,  7, 
    7, 33, 2,  1, 4, 61, 3, 97, 5, 71, 6, 44, 8, 77, 1, 91, 0, 88, 
    2, 41, 1, 93, 0, 67, 6, 52, 7, 97, 8, 47, 5, 11, 4, 31, 3, 90, 
    3, 52, 7, 88, 0, 66, 6, 59, 8, 96, 5, 20, 2, 81, 1, 24, 4, 12, 
    1, 43, 8, 64, 5, 30, 2, 21, 4, 66, 6,  7, 7, 14, 3, 61, 0, 52, 
    5, 77, 3, 70, 8, 31, 0, 90, 4, 90, 7, 36, 6, 93, 2, 27, 1, 75
  };
  const int q8174[] = {
    9, 9, // Number of jobs and machines
    8, 97, 6, 25, 7, 95, 1, 71, 3, 54, 4, 26, 0, 45, 5, 96, 2, 36, 
    8, 65, 4, 49, 1, 93, 7, 22, 6, 11, 3, 99, 2, 55, 5, 49, 0, 72, 
    5, 37, 8, 24, 6, 81, 7, 38, 0, 54, 4, 94, 3, 49, 2, 98, 1, 58, 
    5, 42, 3, 25, 0, 24, 6, 72, 7,  5, 1, 12, 8, 23, 4, 36, 2, 56, 
    7, 23, 5, 17, 4,  4, 8, 40, 1, 35, 2, 19, 3, 93, 0, 25, 6, 47, 
    5,  9, 3, 77, 1, 56, 6,  9, 2,  5, 0, 49, 8, 66, 4, 62, 7, 87, 
    0, 37, 3, 67, 4, 71, 5, 48, 2, 95, 1, 75, 8, 40, 6, 52, 7, 12, 
    4,  8, 6, 20, 1, 46, 3, 67, 7,  5, 0, 98, 8, 32, 5, 51, 2, 81, 
    5, 25, 1, 47, 4, 96, 8, 20, 7, 96, 2, 92, 6, 39, 3, 79, 0, 80
  };
  const int q8175[] = {
    9, 9, // Number of jobs and machines
    3, 19, 7, 97, 8, 24, 5, 43, 1, 86, 0,  5, 4, 79, 2, 90, 6, 87, 
    6, 52, 7, 32, 3,  2, 0, 16, 2, 71, 5, 24, 1, 44, 4, 85, 8, 95, 
    5, 51, 6, 14, 2,  9, 3, 31, 8, 28, 1, 54, 4, 44, 0, 67, 7, 46, 
    2, 97, 3, 10, 8, 63, 5, 99, 6, 68, 0, 24, 7, 48, 1, 72, 4, 74, 
    3, 70, 5, 15, 4,  3, 1, 45, 8, 69, 6, 71, 0, 90, 7, 23, 2, 39, 
    4, 43, 2, 35, 1, 32, 3, 22, 8, 94, 6, 20, 7, 72, 0, 21, 5,  6, 
    1, 69, 8, 72, 3, 16, 0, 67, 4,  6, 2, 40, 7, 92, 5, 44, 6, 41, 
    3, 46, 5, 19, 7, 24, 2, 42, 4,  9, 6, 31, 8, 21, 1, 83, 0, 41, 
    1, 24, 2, 19, 6, 59, 5, 33, 3, 48, 8, 62, 4, 51, 0, 91, 7, 89
  };
  const int q8176[] = {
    9, 9, // Number of jobs and machines
    2, 25, 4, 67, 3, 46, 6, 37, 0, 83, 1, 95, 5, 90, 8, 83, 7, 48, 
    6, 75, 0,  5, 3,  3, 7, 59, 5, 63, 2, 29, 8, 96, 4, 86, 1,  9, 
    3, 15, 0, 26, 1, 33, 4, 47, 6, 69, 7,  7, 8, 11, 5, 12, 2, 44, 
    7, 24, 4, 36, 3, 95, 8, 75, 5, 75, 0, 46, 2,  7, 1, 11, 6, 87, 
    1, 71, 4, 16, 5, 26, 0, 45, 6, 29, 2, 80, 8, 82, 3, 17, 7, 66, 
    7, 34, 4, 98, 1, 37, 6, 36, 5, 77, 2, 20, 8, 98, 0, 66, 3, 51, 
    1, 35, 5, 17, 3, 58, 7, 93, 2,  4, 8, 92, 0, 37, 6, 53, 4, 32, 
    8, 26, 0, 36, 2, 47, 5, 15, 7,  2, 1, 22, 6, 95, 4, 60, 3, 92, 
    2, 23, 8, 60, 5, 40, 6, 67, 1, 84, 0, 95, 4, 83, 7, 47, 3, 30
  };
  const int q8177[] = {
    9, 9, // Number of jobs and machines
    6,  8, 8, 55, 5, 86, 2, 44, 1, 75, 7, 22, 3, 69, 0, 40, 4, 84, 
    2, 56, 1, 71, 8, 97, 4, 62, 3,  3, 5, 16, 6, 80, 0, 87, 7,  7, 
    2, 62, 3, 93, 6, 36, 7, 86, 4, 19, 0, 90, 8, 43, 1, 24, 5,  8, 
    5, 10, 7, 88, 6, 91, 4, 77, 0, 84, 1, 84, 3, 68, 2, 10, 8, 60, 
    3, 31, 8, 92, 4, 60, 5, 92, 0, 50, 1, 54, 6, 50, 7,  1, 2, 28, 
    7, 63, 6, 40, 1, 45, 4, 48, 8,  2, 5,  4, 3, 35, 0, 39, 2, 21, 
    3, 63, 8, 41, 0, 29, 2, 64, 4, 31, 5, 26, 6, 46, 7, 34, 1, 17, 
    4, 63, 1, 61, 5, 31, 0, 32, 3, 57, 7,  8, 6, 98, 2, 61, 8, 13, 
    5,  4, 3, 16, 1, 15, 2, 20, 0, 57, 8, 91, 4, 64, 7, 55, 6, 33
  };
  const int q8178[] = {
    9, 9, // Number of jobs and machines
    4, 50, 6, 68, 0,  3, 2, 19, 7, 31, 5, 31, 1, 68, 8,  6, 3, 62, 
    1,  2, 7, 42, 5, 98, 6,  6, 4, 74, 0, 13, 3, 39, 2, 48, 8, 84, 
    0, 96, 8,  2, 4, 85, 7, 14, 6, 75, 5, 72, 1, 49, 3,  1, 2, 19, 
    0, 97, 3, 27, 5, 29, 7, 21, 8, 61, 1, 81, 2, 59, 6,  5, 4, 86, 
    8, 59, 3, 37, 0, 60, 1, 53, 7, 87, 5, 48, 4, 98, 6,  4, 2, 26, 
    1, 44, 5, 28, 2,  5, 7, 89, 4, 16, 6, 48, 3, 21, 8, 79, 0,  7, 
    3, 92, 6, 65, 8, 91, 5, 12, 7, 61, 2, 15, 4, 14, 1, 79, 0, 23, 
    6, 82, 3,  4, 8, 52, 2, 43, 0, 49, 1, 98, 4, 75, 7, 68, 5, 27, 
    1, 95, 5, 17, 3, 71, 6, 11, 8, 90, 0, 28, 2, 74, 7, 67, 4, 27
  };
  const int q8179[] = {
    9, 9, // Number of jobs and machines
    6, 32, 1, 43, 5, 97, 0, 84, 7, 29, 8, 64, 2, 41, 4, 31, 3, 70, 
    5, 17, 6,  3, 8, 24, 1, 72, 0, 78, 3, 17, 7, 25, 4, 68, 2, 54, 
    8, 29, 1, 43, 7, 11, 3, 95, 5, 69, 6, 73, 0, 87, 4, 17, 2, 99, 
    4, 63, 0, 31, 1, 44, 7, 29, 8, 41, 3, 70, 6, 61, 5, 54, 2, 42, 
    0, 88, 8,  3, 4, 53, 7,  4, 6, 31, 5, 93, 1, 20, 3, 26, 2, 61, 
    8, 24, 1, 37, 4, 26, 0, 72, 3, 53, 5, 85, 6, 42, 7, 49, 2, 48, 
    2,  1, 5, 67, 3, 68, 7, 21, 0, 40, 1, 67, 4, 91, 6, 92, 8, 31, 
    4, 26, 6, 87, 8, 21, 5, 60, 1, 50, 7, 48, 3, 84, 0,  9, 2, 21, 
    1,  6, 8, 80, 6,  1, 3, 50, 2, 74, 7, 82, 0, 82, 4, 63, 5, 29
  };
  const int q8180[] = {
    9, 9, // Number of jobs and machines
    0,  6, 3, 17, 6, 16, 4, 36, 2, 73, 8, 83, 1, 60, 7, 32, 5, 67, 
    4, 89, 1, 36, 8, 25, 2, 31, 6, 96, 7, 15, 3, 77, 5, 89, 0, 56, 
    8, 36, 2, 36, 6, 12, 0, 19, 1, 13, 5, 11, 4, 57, 3, 19, 7, 14, 
    8, 46, 5, 81, 1, 67, 7, 53, 3, 52, 2, 33, 0, 57, 6, 33, 4, 54, 
    0, 73, 1, 83, 2, 83, 3, 41, 4, 78, 6, 20, 5, 91, 8, 67, 7, 63, 
    3, 18, 5, 53, 0, 77, 7, 85, 1, 68, 2, 91, 6, 42, 8, 61, 4, 20, 
    6, 63, 4, 39, 8, 62, 5, 44, 2, 10, 1, 61, 3, 65, 7, 18, 0, 78, 
    5, 26, 4, 59, 7, 84, 1, 77, 6, 37, 2, 17, 0, 90, 8, 67, 3, 35, 
    3, 15, 8, 95, 6,  4, 7, 13, 0, 61, 2, 81, 1, 34, 4, 52, 5, 83
  };
  const int q8181[] = {
    9, 9, // Number of jobs and machines
    2, 57, 6, 12, 3, 92, 5, 58, 7, 60, 0, 16, 1,  6, 8, 84, 4, 57, 
    7, 76, 4, 37, 6, 68, 3, 98, 2, 87, 0, 25, 5, 71, 8,  4, 1, 65, 
    6, 57, 7,  5, 3, 32, 2, 55, 8, 70, 4, 70, 5, 24, 0, 59, 1, 57, 
    6, 20, 2, 85, 4,  4, 7, 96, 3, 94, 5, 95, 1, 56, 8, 70, 0, 13, 
    8,  1, 6, 69, 4, 93, 1, 58, 7, 23, 0, 75, 2, 35, 3, 86, 5, 11, 
    7, 98, 8, 36, 4, 12, 6,  5, 1, 87, 0, 86, 3, 14, 2, 22, 5, 36, 
    2, 30, 7, 47, 0, 20, 6, 26, 8, 49, 1, 51, 5, 31, 4, 39, 3, 89, 
    7, 41, 0, 80, 5, 83, 8, 80, 6, 35, 4, 79, 3, 38, 2, 60, 1, 79, 
    5, 85, 7, 19, 3, 85, 2, 40, 1,  6, 6, 77, 8, 56, 4, 43, 0, 73
  };
  const int q8182[] = {
    9, 9, // Number of jobs and machines
    4, 23, 1, 81, 6, 10, 8,  5, 5, 34, 0,  5, 3, 53, 2, 44, 7, 61, 
    0,  1, 3, 59, 8,  3, 2, 12, 1, 28, 7, 23, 5, 87, 6, 71, 4, 18, 
    2,  9, 5, 96, 3, 27, 0,  8, 8, 48, 1,  3, 4,  9, 6, 59, 7, 10, 
    2, 53, 0, 22, 5, 93, 7, 62, 4, 42, 3, 52, 1, 98, 8, 89, 6, 62, 
    2, 71, 0, 26, 6, 31, 5, 49, 1, 65, 7, 14, 4, 66, 8, 83, 3, 80, 
    8, 66, 1, 27, 2, 12, 5, 12, 0, 28, 4, 42, 3, 25, 6, 53, 7, 98, 
    7,  1, 5, 23, 6, 54, 4, 90, 8, 91, 3, 70, 1, 48, 2, 97, 0,  9, 
    7,  1, 2, 96, 0,  8, 6, 35, 3, 70, 8, 47, 5,  4, 4, 83, 1, 75, 
    0, 58, 3,  3, 7, 61, 1,  7, 4, 37, 6, 40, 8,  2, 5, 38, 2, 85
  };
  const int q8183[] = {
    9, 9, // Number of jobs and machines
    3, 71, 8, 31, 4, 81, 0, 50, 2, 59, 6,  6, 1, 82, 5, 24, 7, 26, 
    8, 27, 4, 66, 6, 25, 0,  6, 2, 41, 5, 43, 1, 42, 3, 91, 7, 96, 
    7, 72, 8, 24, 1, 77, 5, 53, 4, 36, 2, 65, 0, 78, 6, 26, 3, 52, 
    6, 30, 5, 73, 8, 27, 4, 27, 7, 64, 3, 34, 1, 89, 2, 57, 0, 77, 
    3, 53, 7, 69, 2, 24, 6, 85, 1, 97, 5, 63, 4, 31, 8, 24, 0, 45, 
    6, 48, 0, 66, 5, 91, 3, 26, 2, 44, 1, 43, 4, 20, 7, 90, 8, 11, 
    0, 10, 7, 35, 4, 60, 1, 35, 3, 42, 6, 25, 2, 80, 8, 24, 5, 86, 
    3, 96, 8, 99, 7, 43, 0, 31, 1, 77, 5, 42, 6,  7, 4, 23, 2, 56, 
    0, 69, 6, 89, 8, 57, 4, 90, 1, 56, 5, 93, 2, 19, 7, 18, 3, 15
  };
  const int q8184[] = {
    9, 9, // Number of jobs and machines
    1, 30, 7, 33, 2, 77, 4,  1, 6, 93, 0, 41, 3, 30, 5, 15, 8, 77, 
    1, 55, 5, 90, 2, 44, 4, 20, 7, 76, 3, 50, 0, 15, 8, 73, 6,  4, 
    1, 50, 7, 10, 3, 53, 6, 26, 8, 72, 4, 46, 5, 12, 2,  8, 0, 96, 
    8, 42, 6, 61, 2,  8, 5, 73, 3, 46, 7,  1, 1, 70, 4, 67, 0, 40, 
    2,  1, 3, 94, 0, 93, 8,  5, 1, 40, 5, 32, 7, 36, 6, 59, 4, 67, 
    0, 12, 7, 95, 1, 79, 3, 19, 4,  1, 6, 39, 2, 57, 5, 22, 8, 26, 
    0, 30, 5, 51, 3, 33, 1, 86, 4, 91, 2, 38, 6, 87, 7,  8, 8, 63, 
    4, 73, 8, 76, 2, 57, 5,  2, 7, 28, 1,  1, 0, 33, 6, 29, 3, 94, 
    0, 24, 8, 13, 7, 95, 2, 88, 1, 68, 3, 21, 4, 17, 5, 43, 6, 16
  };
  const int q8185[] = {
    9, 9, // Number of jobs and machines
    4, 84, 2, 88, 8,  2, 3, 69, 7, 86, 0,  2, 5, 36, 1,  4, 6, 47, 
    0, 74, 7, 53, 3, 96, 6, 30, 5, 93, 1, 23, 4, 19, 8, 64, 2, 56, 
    3, 40, 2, 71, 5, 73, 0, 57, 8, 31, 7, 78, 6, 69, 1, 19, 4, 44, 
    1, 27, 8,  7, 3, 53, 6, 71, 7, 28, 5, 11, 4, 26, 0, 49, 2, 95, 
    1, 35, 3, 46, 8, 39, 0, 74, 4, 84, 2, 74, 5, 39, 6, 12, 7, 49, 
    7, 53, 3, 83, 4, 87, 0, 92, 5, 43, 1, 13, 2, 28, 6, 78, 8, 66, 
    6, 59, 3, 61, 7, 48, 1, 98, 2, 42, 8,  7, 5, 65, 4, 99, 0, 18, 
    2, 60, 0, 73, 5, 60, 4, 91, 1, 62, 3,  4, 6, 74, 8, 49, 7, 86, 
    8, 85, 0, 39, 5, 68, 6, 10, 3, 96, 2, 61, 1, 90, 4, 34, 7, 47
  };
  const int q8186[] = {
    9, 9, // Number of jobs and machines
    3, 92, 7, 84, 8, 53, 2, 24, 4, 50, 1, 37, 5,  8, 0, 20, 6, 93, 
    2, 20, 0, 21, 1, 41, 8, 45, 3, 97, 7, 99, 5, 19, 4, 59, 6, 41, 
    7, 21, 1, 62, 8, 56, 3, 47, 6, 96, 2, 18, 5, 60, 0, 36, 4, 61, 
    7, 61, 4, 90, 3, 56, 1, 88, 2,  4, 5, 35, 0,  7, 8, 24, 6, 81, 
    5, 70, 6, 95, 3, 45, 2, 96, 8, 15, 1, 68, 0,  2, 7, 98, 4, 33, 
    5, 62, 3, 84, 6, 34, 4, 38, 2,  7, 7, 26, 1, 67, 8, 25, 0, 86, 
    7, 85, 1, 16, 4, 52, 2,  7, 6, 91, 3, 17, 5,  5, 0, 15, 8, 20, 
    7, 63, 1, 84, 4, 19, 8, 69, 2, 40, 3, 98, 5, 24, 6, 74, 0, 78, 
    7, 39, 1,  5, 3, 94, 5, 35, 0, 74, 2, 55, 4, 95, 8, 10, 6, 35
  };
  const int q8187[] = {
    9, 9, // Number of jobs and machines
    7, 37, 3, 61, 5, 97, 0, 42, 4, 74, 8, 88, 2, 45, 1, 94, 6, 18, 
    1, 59, 4, 97, 8, 32, 7, 63, 2, 25, 6, 31, 3, 15, 0, 68, 5, 96, 
    5, 60, 3, 33, 0, 20, 2, 69, 4, 75, 7, 84, 8, 85, 1, 55, 6, 45, 
    0, 65, 5, 44, 1, 73, 2, 76, 3, 99, 4, 61, 7, 99, 6,  2, 8, 48, 
    6,  7, 3, 67, 1,  8, 2, 26, 7, 47, 0, 58, 4, 14, 8, 12, 5, 66, 
    3, 60, 1, 62, 2, 47, 0, 57, 8,  1, 4, 56, 5, 56, 7, 17, 6, 25, 
    5, 14, 2, 72, 3, 11, 1, 52, 8, 59, 0, 60, 4, 69, 7, 64, 6, 34, 
    2, 47, 5, 42, 0, 86, 1, 76, 6, 38, 7, 32, 8, 77, 4, 34, 3, 14, 
    8, 13, 2, 39, 7, 63, 5, 41, 0,  1, 6, 93, 1, 32, 3, 32, 4, 76
  };
  const int q8188[] = {
    9, 9, // Number of jobs and machines
    7,  2, 4,  3, 3, 77, 2, 10, 0, 59, 8, 80, 5, 52, 6, 43, 1, 95, 
    8, 38, 1, 69, 2, 42, 0, 74, 7, 20, 5,  4, 6, 90, 4,  5, 3,  7, 
    1, 98, 4, 89, 0, 53, 5, 50, 6, 85, 2, 35, 7, 53, 3, 38, 8, 20, 
    0, 15, 7, 42, 8,  1, 3, 30, 1, 87, 4, 97, 2, 61, 6, 68, 5,  9, 
    5,  1, 2, 87, 7, 35, 4, 65, 6, 93, 1, 85, 0, 49, 3, 53, 8, 27, 
    6,  8, 3, 37, 0, 42, 2, 73, 1, 75, 5, 80, 8, 47, 4, 40, 7, 92, 
    2, 31, 4, 41, 8, 66, 7, 33, 3, 91, 1, 29, 0, 21, 5, 39, 6, 86, 
    2, 68, 8, 57, 0, 46, 5,  1, 4, 53, 3, 89, 6, 71, 1, 54, 7, 72, 
    1, 96, 0, 31, 6, 23, 5, 60, 3, 10, 4, 71, 8, 27, 2, 95, 7, 83
  };
  const int q8189[] = {
    9, 9, // Number of jobs and machines
    4, 93, 3, 49, 0, 55, 7, 79, 8, 84, 5, 97, 1, 39, 2, 60, 6,  2, 
    8, 95, 5, 89, 4, 30, 3, 69, 2, 77, 7, 77, 6, 69, 0, 83, 1, 16, 
    2, 51, 3, 58, 8, 16, 1, 96, 6, 84, 4, 30, 0, 81, 7, 63, 5, 29, 
    3, 45, 4, 85, 8, 23, 6, 25, 1, 92, 5, 61, 0, 72, 2, 51, 7, 35, 
    5, 25, 8, 87, 3, 34, 4, 84, 7, 28, 2, 97, 0, 71, 1, 88, 6, 24, 
    8, 89, 3, 20, 6, 74, 1, 11, 2, 35, 5, 85, 4, 89, 7, 40, 0,  5, 
    5, 46, 6, 60, 0, 46, 2, 41, 1, 66, 8, 30, 7, 55, 4, 14, 3, 93, 
    7, 65, 3, 86, 8, 71, 5, 76, 1, 41, 0, 45, 2, 48, 6, 13, 4, 86, 
    1,  4, 0,  4, 3, 33, 2, 83, 7, 48, 5,  1, 4, 87, 6, 37, 8, 41
  };
  const int q8190[] = {
    9, 9, // Number of jobs and machines
    6, 48, 1, 16, 0, 98, 2, 23, 8, 13, 4, 49, 5, 36, 3, 84, 7, 36, 
    4, 24, 0, 37, 7, 76, 5, 65, 2, 62, 1, 40, 3, 27, 6, 68, 8, 70, 
    6,  5, 1, 35, 7, 44, 5, 80, 3, 40, 4, 39, 0, 67, 8, 69, 2, 52, 
    6, 37, 0, 70, 8, 61, 1, 48, 2,  1, 7, 61, 4, 76, 3, 97, 5, 82, 
    5, 26, 3,  3, 0, 51, 4, 63, 2, 85, 8, 70, 1, 41, 7, 84, 6, 47, 
    7, 62, 1, 80, 2, 80, 3, 54, 5, 25, 0, 94, 4, 58, 6, 73, 8, 89, 
    6, 15, 0, 88, 2, 16, 3,  6, 7, 17, 8, 36, 5, 92, 1, 26, 4, 91, 
    8, 56, 5, 96, 7, 96, 0, 51, 3, 63, 1, 99, 4, 80, 6,  9, 2, 71, 
    0, 10, 5, 38, 6, 98, 2, 40, 4,  1, 7, 51, 1, 41, 8, 62, 3, 18
  };
  const int q8191[] = {
    9, 9, // Number of jobs and machines
    6, 65, 3, 71, 0, 98, 1, 49, 5, 18, 2, 20, 7, 46, 4, 93, 8, 44, 
    5, 77, 8, 45, 1, 71, 0, 87, 3, 38, 4, 79, 7, 76, 2, 28, 6, 87, 
    8,  7, 1, 90, 2, 38, 3, 51, 0, 38, 5, 69, 4, 61, 6, 69, 7, 35, 
    3, 95, 1, 46, 0, 73, 6,  5, 2, 16, 4, 14, 7, 95, 8, 67, 5, 35, 
    3, 41, 8, 24, 2, 42, 5, 42, 4, 91, 0, 20, 7,  3, 1, 71, 6, 92, 
    7,  1, 5, 54, 2, 32, 4, 35, 3, 35, 6, 34, 8, 30, 0,  2, 1, 61, 
    5, 59, 0, 42, 2, 15, 3, 16, 7, 93, 1, 81, 8, 49, 4, 30, 6, 81, 
    4, 54, 8, 57, 0, 40, 6, 91, 7, 33, 1, 47, 5, 39, 3, 86, 2, 25, 
    3, 76, 8, 59, 6, 72, 2, 50, 5, 54, 4, 21, 7, 13, 0, 54, 1, 72
  };
  const int q8192[] = {
    9, 9, // Number of jobs and machines
    1, 56, 4, 29, 8, 78, 0, 83, 6, 56, 2, 54, 3, 14, 5, 42, 7, 36, 
    1, 51, 0, 99, 5, 90, 2,  1, 7, 79, 3, 27, 8, 62, 4, 43, 6, 64, 
    0, 10, 1, 75, 2, 20, 3, 56, 7, 46, 4, 73, 5, 98, 6, 98, 8, 86, 
    3, 22, 6, 96, 7, 78, 0, 12, 8, 65, 5, 59, 1, 16, 4,  4, 2, 31, 
    4, 92, 1, 98, 6, 55, 8, 95, 5, 33, 7, 42, 0, 44, 3, 95, 2, 29, 
    5, 77, 3, 62, 2,  1, 6, 29, 4, 28, 8, 74, 7, 61, 0, 69, 1, 14, 
    4, 67, 1, 35, 0, 61, 2, 23, 6, 51, 7,  4, 8, 66, 5, 60, 3, 81, 
    5, 31, 2, 43, 1, 95, 4, 32, 3, 90, 6, 96, 8, 56, 0, 92, 7, 96, 
    0, 26, 2, 21, 8, 28, 6, 24, 4, 35, 7, 42, 1, 61, 5, 84, 3, 37
  };
  const int q8193[] = {
    9, 9, // Number of jobs and machines
    3, 37, 1, 97, 4, 58, 2, 59, 6, 71, 8, 22, 7, 23, 0, 16, 5, 37, 
    7, 84, 6, 93, 4, 99, 5, 75, 0, 89, 8, 78, 3, 56, 2, 86, 1, 33, 
    5, 47, 8,  7, 4, 34, 3, 88, 0, 82, 1, 25, 7, 27, 6, 29, 2, 87, 
    3, 22, 1, 63, 8,  8, 7, 49, 0, 99, 2, 71, 4, 95, 5, 25, 6, 44, 
    1, 48, 3, 51, 4, 28, 8, 69, 6, 64, 0,  7, 7, 26, 2,  1, 5, 83, 
    7, 98, 0, 71, 2, 37, 5, 28, 8, 15, 1, 23, 4, 34, 6, 69, 3, 11, 
    8, 92, 4, 29, 5, 14, 7, 28, 0, 89, 2, 53, 6, 42, 3, 47, 1, 74, 
    0,  8, 1, 42, 6, 81, 4, 24, 3, 79, 7, 76, 5, 61, 2, 91, 8, 64, 
    0, 91, 2, 15, 8, 89, 1, 77, 6, 13, 5, 60, 7, 82, 4, 54, 3, 99
  };
  const int q8194[] = {
    9, 9, // Number of jobs and machines
    4, 60, 3, 54, 0, 89, 8, 55, 6,  6, 1, 23, 7, 39, 5, 21, 2, 72, 
    4, 88, 3, 44, 5, 52, 0,  5, 6, 98, 8, 55, 2, 74, 1, 19, 7, 87, 
    5, 31, 1,  2, 7, 97, 6, 77, 0, 77, 8, 90, 3, 96, 2, 54, 4, 11, 
    8, 60, 6, 69, 0, 84, 1, 47, 2, 27, 3, 17, 5, 29, 4, 80, 7, 27, 
    8, 87, 5, 16, 4, 98, 0,  9, 3, 41, 6, 93, 2, 20, 1, 33, 7, 23, 
    5, 87, 1, 72, 2, 36, 6, 32, 8, 66, 3, 31, 4, 94, 7, 53, 0, 12, 
    1, 20, 0, 64, 8, 85, 2, 49, 5,  4, 6, 15, 4, 51, 7, 69, 3, 64, 
    0, 33, 4, 77, 6, 89, 5, 77, 7, 31, 1, 58, 2, 65, 3, 54, 8, 47, 
    7, 53, 2, 18, 8, 81, 0, 86, 5, 60, 4, 23, 1, 69, 6, 76, 3, 81
  };
  const int q8195[] = {
    9, 9, // Number of jobs and machines
    0, 82, 8, 56, 2, 38, 7, 26, 6, 57, 4, 37, 3, 56, 5, 68, 1, 16, 
    7, 86, 0,  2, 6, 59, 4, 21, 8,  7, 3, 78, 5, 18, 2, 40, 1, 26, 
    3, 16, 2, 20, 4,  8, 8, 88, 5, 75, 0, 38, 7, 92, 6, 68, 1, 95, 
    6, 67, 2, 44, 4, 51, 3, 62, 7, 42, 0,  1, 5, 36, 1, 58, 8, 54, 
    5, 12, 2, 70, 0, 17, 1, 58, 7, 25, 4, 44, 8, 73, 3, 30, 6, 98, 
    0, 61, 1, 40, 7, 99, 2, 98, 3, 80, 5, 41, 6, 51, 8, 19, 4, 19, 
    6,  9, 4, 44, 8, 51, 5,  5, 3, 97, 0, 73, 1, 89, 7, 88, 2, 72, 
    0, 42, 4, 95, 8, 11, 5, 35, 3, 20, 1, 98, 2, 21, 6, 24, 7, 97, 
    3, 12, 5, 97, 6, 63, 2, 93, 1, 50, 7, 20, 8, 57, 4, 62, 0, 91
  };
  const int q8196[] = {
    9, 9, // Number of jobs and machines
    8, 11, 0, 22, 2, 43, 4, 71, 6, 53, 3, 25, 5, 12, 7, 90, 1, 18, 
    6, 33, 4, 60, 1, 65, 0,  4, 7, 58, 5, 32, 3, 91, 2, 70, 8, 26, 
    1, 10, 6, 89, 5, 87, 2, 24, 3, 37, 8, 95, 7, 22, 0,  8, 4, 42, 
    3, 44, 8, 98, 7, 75, 5, 15, 2, 27, 4, 21, 0, 70, 6,  5, 1, 58, 
    3, 88, 1, 69, 5, 68, 0,  2, 6, 40, 2, 10, 4,  4, 7, 58, 8, 20, 
    3, 71, 1, 17, 6, 48, 0, 12, 7,  4, 4, 88, 5, 45, 2, 73, 8,  7, 
    4, 82, 8,  5, 3, 42, 5, 11, 0, 86, 6, 55, 2, 35, 7, 45, 1, 60, 
    5, 96, 4, 76, 7, 75, 1, 98, 2,  7, 6, 56, 8, 48, 0, 75, 3, 67, 
    8, 85, 5, 33, 4, 77, 1, 28, 3, 53, 2, 25, 6, 17, 0, 10, 7, 15
  };
  const int q8197[] = {
    9, 9, // Number of jobs and machines
    7, 82, 5, 78, 1, 77, 3, 41, 6, 74, 0, 88, 8,  1, 4, 41, 2, 67, 
    1, 87, 5, 28, 7,  5, 3, 45, 2, 66, 8, 40, 6, 67, 0, 95, 4, 62, 
    3, 14, 4, 36, 8, 30, 7, 71, 5, 24, 0, 87, 2, 45, 6, 70, 1, 99, 
    5, 38, 7, 89, 1, 88, 4,  3, 2, 73, 3, 92, 6, 28, 0, 42, 8, 65, 
    6, 94, 7, 36, 5, 24, 1, 40, 3, 48, 8, 62, 0, 34, 4, 84, 2, 86, 
    7, 14, 2, 46, 5, 61, 6, 41, 1, 54, 0,  3, 8, 73, 4, 39, 3, 52, 
    0, 72, 6, 52, 1, 59, 7,  9, 3, 85, 5, 84, 4, 20, 8, 71, 2, 51, 
    7, 59, 5, 15, 4, 90, 8, 95, 6, 57, 1, 98, 2, 37, 3, 38, 0, 37, 
    6, 12, 1, 93, 3, 31, 0, 17, 7, 22, 8, 48, 5, 79, 4, 15, 2, 53
  };
  const int q8198[] = {
    9, 9, // Number of jobs and machines
    7, 29, 8, 63, 3, 87, 6, 16, 0, 35, 4, 35, 1, 84, 2, 70, 5, 57, 
    2, 66, 8, 47, 0, 79, 5, 96, 3, 66, 4, 83, 1, 18, 7, 39, 6, 44, 
    0, 40, 1, 67, 5, 46, 6, 49, 8, 27, 2, 27, 4, 55, 3, 61, 7, 67, 
    4, 13, 6, 41, 5, 75, 0, 47, 8, 79, 1, 47, 2, 98, 7, 72, 3, 82, 
    3, 98, 1, 41, 5, 83, 0, 29, 6, 52, 2, 81, 8, 55, 7, 13, 4, 13, 
    8, 74, 3, 26, 2, 42, 7, 67, 4, 56, 0, 69, 1, 22, 6, 59, 5, 21, 
    8, 94, 7, 64, 3,  1, 2, 98, 0, 65, 6, 45, 5, 20, 4, 18, 1, 36, 
    3, 54, 6, 70, 2, 59, 1, 78, 5, 50, 7, 90, 4,  5, 0, 79, 8, 79, 
    4, 74, 7, 74, 0, 70, 1, 44, 2, 94, 8, 24, 5, 36, 6, 85, 3, 82
  };
  const int q8199[] = {
    9, 9, // Number of jobs and machines
    4, 46, 5, 60, 1, 67, 2,  3, 6, 69, 3, 75, 0,  4, 8, 11, 7, 73, 
    6, 61, 3, 38, 7, 62, 2, 56, 5, 39, 8, 40, 1, 80, 0, 87, 4, 48, 
    4, 28, 1, 27, 6, 31, 7, 35, 3, 10, 2, 22, 5, 19, 8, 20, 0, 45, 
    8, 38, 0, 23, 3, 86, 7,  3, 6, 49, 2, 74, 4, 36, 1, 75, 5, 80, 
    4, 45, 7, 95, 1, 31, 0, 89, 5, 34, 2, 34, 8, 11, 6, 93, 3, 58, 
    8, 32, 2, 84, 0, 34, 5, 73, 3, 72, 4, 59, 6, 63, 7, 98, 1,  5, 
    2, 75, 8, 37, 1, 21, 4, 71, 3, 15, 0,  4, 5, 67, 7, 86, 6, 49, 
    1, 27, 6, 23, 3, 85, 0, 93, 8, 27, 2, 80, 5, 31, 7, 62, 4, 77, 
    5, 12, 0, 35, 8,  8, 1, 23, 2, 56, 6, 84, 4, 87, 7, 98, 3, 55
  };
  const int q8200[] = {
    9, 9, // Number of jobs and machines
    7, 34, 3, 66, 1, 37, 8, 56, 5, 70, 0, 68, 2, 69, 6, 31, 4, 12, 
    6, 48, 5, 77, 4, 80, 7, 32, 2, 41, 8, 20, 0, 70, 3, 58, 1, 22, 
    5, 13, 8, 91, 2, 95, 4, 10, 7,  9, 0, 44, 6, 50, 1, 19, 3, 53, 
    2, 78, 0, 31, 4,  6, 8, 57, 3, 43, 6,  5, 1, 51, 7, 16, 5, 17, 
    5,  1, 2, 49, 3, 95, 4, 32, 7, 97, 0, 19, 8, 54, 1,  6, 6, 26, 
    2, 24, 4, 47, 6, 45, 0, 63, 1, 22, 8, 78, 3, 51, 5, 91, 7, 63, 
    7, 40, 1, 89, 5, 46, 6, 87, 8, 29, 0, 62, 4, 36, 3, 70, 2, 25, 
    4, 21, 3, 49, 5, 36, 6, 20, 8, 96, 0, 90, 7, 39, 2,  1, 1, 77, 
    3, 40, 8, 94, 7, 22, 2, 81, 6, 23, 1, 33, 4, 45, 0, 33, 5, 72
  };
  const int q8201[] = {
    9, 9, // Number of jobs and machines
    3,  4, 2, 29, 7, 56, 6, 41, 4, 48, 5, 56, 8, 43, 1, 15, 0, 47, 
    4, 60, 7, 32, 8, 97, 3, 95, 0, 62, 2, 47, 1, 16, 5, 32, 6,  2, 
    7, 68, 8, 46, 4,  2, 0, 27, 1, 14, 6, 33, 5, 79, 3, 35, 2, 43, 
    3, 55, 1, 94, 7,  7, 4, 57, 5, 76, 8, 38, 6, 77, 0, 22, 2, 65, 
    4, 37, 7,  8, 2, 45, 3, 70, 5, 54, 0, 12, 1, 71, 8,  5, 6, 66, 
    2, 66, 7, 61, 1,  5, 0, 80, 8, 59, 5, 83, 4, 90, 6, 13, 3, 43, 
    8, 57, 3, 64, 0, 46, 1, 25, 5, 65, 4, 92, 7, 98, 2, 17, 6, 99, 
    5, 52, 8, 46, 6, 68, 1, 15, 3, 74, 4, 20, 2, 81, 0, 79, 7, 89, 
    3, 66, 4, 96, 1, 78, 5, 54, 2, 70, 6, 33, 7, 52, 0, 85, 8, 13
  };
  const int q8202[] = {
    9, 9, // Number of jobs and machines
    6, 64, 3, 72, 1,  3, 0, 56, 7, 84, 2, 50, 4, 52, 8, 62, 5, 32, 
    1, 84, 7,  5, 5, 86, 4, 48, 6, 49, 8, 21, 0,  1, 3, 89, 2, 88, 
    6, 79, 3, 77, 1, 14, 4, 92, 0, 70, 8, 28, 5, 33, 7, 11, 2, 87, 
    5, 40, 3, 66, 4, 90, 6, 42, 1, 26, 7, 31, 2, 14, 8, 55, 0, 11, 
    2, 19, 8, 94, 0, 48, 4, 31, 1, 42, 5, 59, 6,  2, 7, 79, 3, 54, 
    7,  5, 8, 26, 1,  9, 3, 13, 0, 27, 5, 93, 4,  7, 6, 42, 2,  2, 
    1, 58, 3, 49, 4, 51, 5, 89, 8, 38, 2, 55, 0, 81, 6, 93, 7, 88, 
    6, 43, 8, 80, 4, 77, 1, 95, 7, 49, 2, 47, 3, 76, 0, 63, 5, 45, 
    6, 10, 2, 56, 1, 31, 8, 38, 5, 25, 0, 62, 3, 11, 7,  2, 4, 55
  };
  const int q8203[] = {
    9, 9, // Number of jobs and machines
    5, 31, 6, 75, 1, 59, 4, 27, 2, 14, 3, 81, 0,  3, 8, 92, 7, 21, 
    7, 59, 3, 38, 2, 88, 6, 24, 0, 84, 5, 59, 8, 45, 4, 83, 1, 96, 
    1, 80, 0, 55, 5, 86, 6, 91, 8, 45, 7, 34, 4, 32, 3, 33, 2, 68, 
    5, 99, 8, 42, 6, 98, 3, 21, 1, 52, 4, 90, 7, 29, 2,  6, 0, 32, 
    4, 42, 6, 57, 8, 24, 1, 42, 0, 43, 3, 94, 7, 84, 2,  8, 5, 60, 
    7, 39, 5, 62, 4, 41, 3, 96, 6, 86, 0, 91, 1, 39, 2, 10, 8, 35, 
    0,  7, 4, 45, 6, 57, 8, 59, 1, 68, 3, 21, 7, 16, 2, 41, 5, 29, 
    0, 74, 3, 91, 4, 39, 2, 67, 6,  1, 5, 13, 8, 10, 7, 52, 1, 94, 
    2, 30, 4, 81, 0, 94, 1,  3, 6, 92, 5, 88, 7, 62, 8, 32, 3, 79
  };
  const int q8204[] = {
    9, 9, // Number of jobs and machines
    3, 11, 7,  1, 6, 45, 4, 84, 1, 11, 8, 52, 0,  7, 2, 83, 5, 89, 
    1, 64, 0, 85, 8, 40, 3, 78, 7, 33, 4, 48, 2, 17, 5, 10, 6,  6, 
    6, 18, 3, 76, 2, 84, 4, 46, 1, 70, 8, 54, 5, 57, 0, 19, 7, 71, 
    0, 62, 6, 20, 2, 90, 1, 31, 5, 90, 7, 85, 8, 80, 3, 76, 4,  7, 
    3, 40, 6, 70, 4, 88, 1, 65, 2, 32, 5, 83, 0, 94, 7, 66, 8, 98, 
    6, 21, 0, 86, 4, 65, 5, 53, 8, 99, 7, 44, 2, 94, 1, 70, 3, 61, 
    3, 10, 0, 36, 1, 12, 6, 11, 2, 65, 8, 12, 7, 50, 4, 72, 5, 56, 
    2, 99, 8, 46, 0, 85, 1, 87, 7, 20, 5, 50, 6, 24, 3,  1, 4, 26, 
    3, 31, 6, 61, 0, 72, 1, 49, 8, 26, 4, 24, 5, 97, 7, 66, 2, 47
  };
  const int q8205[] = {
    9, 9, // Number of jobs and machines
    2, 69, 6, 78, 1, 15, 8, 50, 7, 77, 5, 48, 0, 68, 3, 62, 4, 58, 
    3, 60, 4, 31, 8,  3, 0, 39, 6, 57, 7, 19, 1, 61, 2, 55, 5, 46, 
    8, 86, 2, 26, 5, 22, 6, 53, 7, 46, 0, 11, 4,  6, 3, 54, 1, 80, 
    8, 40, 7, 23, 5, 59, 2,  4, 6, 74, 1, 61, 0, 69, 4, 37, 3, 44, 
    5, 69, 2, 65, 8, 50, 3,  8, 7, 65, 4, 67, 1, 73, 6, 32, 0,  6, 
    7, 56, 1, 53, 3, 21, 5, 42, 0,  9, 2,  4, 6, 91, 4, 89, 8, 29, 
    6, 50, 4, 18, 2, 86, 7, 82, 8, 41, 0, 44, 5, 98, 3, 10, 1, 29, 
    7, 78, 2, 70, 1, 76, 4, 62, 6, 76, 5, 78, 0, 89, 8, 26, 3, 15, 
    8, 20, 3, 88, 2, 81, 4, 18, 6, 93, 5, 71, 7, 61, 0, 57, 1, 63
  };
  const int q8206[] = {
    9, 9, // Number of jobs and machines
    8, 72, 6, 82, 5, 37, 4, 82, 7, 63, 3, 21, 1, 26, 2, 21, 0, 94, 
    1, 75, 4, 49, 8,  9, 6, 76, 7, 25, 0, 31, 5, 24, 2, 23, 3, 89, 
    2, 10, 1, 84, 3, 26, 8, 53, 4, 96, 6, 56, 0, 10, 7,  1, 5, 87, 
    7, 50, 6, 48, 1, 60, 0, 54, 5, 40, 4, 42, 3, 49, 2, 13, 8, 67, 
    5, 13, 0, 37, 1, 25, 6, 13, 7, 31, 2, 36, 4, 47, 3, 58, 8, 49, 
    5,  3, 7, 38, 6, 21, 0, 92, 8, 51, 1,  3, 3, 99, 2, 30, 4, 62, 
    6, 85, 0, 34, 8, 64, 3, 12, 2, 54, 5, 62, 1,  6, 4, 37, 7, 29, 
    1, 77, 0, 33, 3, 56, 8, 13, 6, 29, 4, 13, 7,  1, 5, 86, 2, 77, 
    5, 18, 8, 94, 4, 67, 0, 81, 6, 98, 2, 91, 7, 84, 1, 59, 3, 19
  };
  const int q8207[] = {
    9, 9, // Number of jobs and machines
    8, 76, 7,  5, 1, 33, 4, 48, 2, 15, 0, 80, 6, 28, 5, 18, 3, 55, 
    2, 72, 7, 52, 8, 22, 5, 84, 6, 24, 3, 23, 0, 50, 4, 65, 1, 99, 
    2, 66, 4, 95, 7, 78, 6, 80, 0, 34, 3, 18, 5, 34, 1, 74, 8, 61, 
    0, 19, 3,  1, 8, 78, 7, 67, 5, 79, 6, 97, 1, 35, 2, 78, 4, 26, 
    5, 70, 6, 87, 3, 33, 7, 49, 4, 57, 8, 38, 0, 86, 1, 73, 2, 60, 
    6, 39, 1,  4, 5, 83, 3, 12, 2,  4, 7, 32, 0, 51, 8, 16, 4, 57, 
    2, 60, 5, 33, 3, 35, 6, 63, 0, 40, 7,  4, 8, 81, 1, 43, 4, 49, 
    6, 14, 1, 71, 2, 62, 3, 75, 4, 10, 7, 33, 8, 63, 0, 57, 5, 37, 
    6,  7, 7, 81, 3,  2, 4, 78, 8, 77, 5, 95, 2, 51, 0, 97, 1, 56
  };
  const int q8208[] = {
    9, 9, // Number of jobs and machines
    4, 11, 0, 13, 8, 56, 2, 42, 3,  5, 7, 18, 6, 38, 5,  6, 1, 51, 
    0, 52, 5, 19, 4,  1, 1, 61, 2, 99, 6, 62, 7, 22, 3, 81, 8, 49, 
    2, 48, 1, 59, 5, 97, 4, 67, 8, 55, 6, 69, 3, 43, 0, 46, 7, 46, 
    3, 49, 2, 95, 8, 96, 1, 68, 6, 21, 4, 13, 7, 99, 0, 43, 5, 54, 
    6, 86, 2, 15, 8, 80, 4, 55, 1, 52, 3, 83, 5,  4, 7, 36, 0, 17, 
    2, 75, 8, 41, 4, 95, 0, 49, 3, 73, 1, 24, 5, 34, 7, 11, 6, 22, 
    7, 40, 0, 26, 3, 63, 8,  3, 6, 52, 5, 30, 1, 59, 2, 71, 4, 48, 
    2, 96, 7, 36, 8,  6, 4, 84, 0, 40, 5, 58, 3, 33, 6, 46, 1, 70, 
    8, 87, 4, 39, 1,  5, 3, 26, 5, 15, 7, 19, 2, 97, 0, 35, 6, 96
  };
  const int q8209[] = {
    9, 9, // Number of jobs and machines
    7, 52, 1, 87, 4, 51, 6, 85, 3, 30, 5, 98, 0, 14, 8, 12, 2, 84, 
    6, 40, 5, 56, 0, 38, 4, 88, 2, 76, 8, 92, 1, 44, 7, 15, 3,  9, 
    7,  1, 4,  2, 0, 96, 2, 94, 5, 19, 8,  6, 6, 20, 3, 40, 1, 80, 
    1, 21, 5, 56, 2,  7, 8, 99, 4, 75, 0, 35, 6, 77, 7, 11, 3,  4, 
    4,  9, 3, 93, 1,  5, 2, 52, 0, 69, 5, 23, 6, 65, 8, 87, 7,  2, 
    4, 16, 2, 79, 0, 27, 3, 67, 5,  2, 1, 46, 8, 44, 6, 48, 7, 94, 
    7, 60, 2, 92, 5, 33, 0,  5, 6, 72, 4, 23, 8, 15, 3,  4, 1, 50, 
    0, 69, 3, 30, 4, 71, 7, 91, 8, 65, 2, 89, 5, 33, 1, 79, 6, 98, 
    0, 62, 1, 71, 4, 14, 3, 16, 5, 67, 2,  8, 7, 67, 8, 99, 6, 40
  };
  const int q8210[] = {
    9, 9, // Number of jobs and machines
    0, 65, 1, 69, 3, 31, 7, 43, 2, 72, 5, 42, 8, 72, 6, 56, 4, 93, 
    7, 69, 5, 77, 6,  2, 2,  7, 1, 72, 0, 61, 8, 69, 4, 67, 3, 92, 
    0, 41, 1, 78, 5, 67, 6, 92, 2, 35, 4, 83, 8, 30, 3, 93, 7, 59, 
    6, 27, 3, 67, 7, 29, 5, 44, 1, 12, 4, 23, 2,  3, 8, 82, 0, 97, 
    1, 74, 8,  2, 2,  3, 7, 84, 0, 84, 4,  5, 5, 38, 6, 90, 3, 59, 
    8, 69, 6, 78, 2, 87, 3,  3, 7, 55, 0, 77, 4, 63, 1, 66, 5, 96, 
    0,  7, 2, 70, 1, 64, 3, 74, 6, 25, 4, 64, 5, 90, 8, 32, 7, 48, 
    2, 78, 1, 54, 3, 69, 5, 42, 0, 76, 7, 17, 6, 76, 8, 33, 4, 19, 
    5, 39, 1, 65, 4, 23, 8, 75, 7, 19, 6, 13, 3, 23, 0, 14, 2, 75
  };
  const int q8211[] = {
    9, 9, // Number of jobs and machines
    0, 46, 5, 62, 8, 61, 7, 71, 6, 23, 3, 71, 1, 73, 4,  5, 2, 32, 
    7, 83, 5, 74, 0,  6, 3, 55, 1, 79, 2, 98, 4, 23, 6, 73, 8, 38, 
    0, 92, 2, 63, 7, 67, 8, 88, 4, 21, 5, 69, 6, 65, 3,  9, 1, 14, 
    7, 19, 1, 53, 5, 50, 6,  3, 4, 57, 0, 73, 3, 45, 2, 43, 8, 45, 
    2, 12, 1, 52, 6, 79, 7, 88, 8,  9, 3, 36, 4, 99, 0, 28, 5, 85, 
    0, 26, 4, 60, 6,  7, 7, 26, 8, 36, 5, 82, 2, 82, 3, 50, 1,  5, 
    1, 87, 5, 17, 8, 35, 2, 17, 4, 59, 6, 41, 7, 99, 0, 18, 3, 96, 
    6, 20, 4,  3, 1, 41, 7, 49, 8, 84, 5, 74, 3,  7, 2, 45, 0, 70, 
    6, 84, 4,  2, 1, 92, 5, 39, 2, 68, 7, 38, 0, 23, 3,  4, 8, 93
  };
  const int q8212[] = {
    9, 9, // Number of jobs and machines
    0, 44, 4, 33, 2, 60, 7, 74, 5, 83, 6,  6, 1, 60, 8,  9, 3, 61, 
    5, 66, 7, 29, 2, 10, 8, 11, 1, 98, 4, 17, 3,  7, 6, 78, 0, 83, 
    2, 66, 1, 70, 5, 91, 6, 82, 8, 27, 4, 22, 0,  3, 3, 73, 7, 88, 
    5, 88, 4, 79, 8, 10, 7, 36, 1, 70, 6, 14, 2, 26, 0, 63, 3, 96, 
    8, 95, 2, 31, 7, 49, 0, 77, 1, 86, 5, 24, 3, 91, 6, 17, 4, 13, 
    0, 16, 6, 36, 4, 32, 1, 42, 7, 66, 3, 88, 8, 39, 2, 52, 5, 14, 
    1,  2, 3,  7, 2, 86, 6, 80, 7, 28, 4, 92, 0, 52, 8, 12, 5, 60, 
    0, 98, 1, 69, 4, 66, 7, 76, 2, 12, 5, 46, 8, 52, 6, 39, 3, 82, 
    4, 53, 6,  7, 3, 23, 0, 74, 7, 71, 5, 13, 1, 96, 2, 91, 8, 67
  };
  const int q8213[] = {
    9, 9, // Number of jobs and machines
    8, 38, 1, 24, 4, 65, 5, 65, 0, 46, 3, 39, 2, 19, 6, 26, 7, 56, 
    2, 13, 7, 56, 4, 50, 5, 83, 0, 44, 6, 39, 8, 53, 3, 44, 1, 78, 
    2, 40, 7, 48, 5, 46, 0, 55, 1, 62, 4, 56, 3, 98, 6,  1, 8, 10, 
    1, 66, 4, 40, 8,  7, 0, 22, 3, 34, 6, 78, 7,  7, 5, 50, 2, 66, 
    0, 83, 5, 29, 4, 52, 2, 14, 1, 18, 3, 24, 6, 99, 7, 87, 8, 28, 
    0, 79, 2, 70, 5, 47, 3, 46, 4, 28, 1, 52, 6, 65, 8,  4, 7, 69, 
    1, 35, 8, 90, 5, 49, 0, 43, 3, 89, 4, 30, 7, 98, 6, 89, 2, 33, 
    6, 30, 3, 29, 4,  8, 0, 58, 7, 93, 5, 26, 1, 54, 2, 74, 8, 20, 
    3,  4, 0, 34, 8, 66, 7, 12, 4, 45, 1, 34, 6, 63, 2, 78, 5, 44
  };
  const int q8214[] = {
    9, 9, // Number of jobs and machines
    5, 39, 4, 59, 2, 21, 0, 40, 8, 50, 3, 84, 6, 91, 1,  2, 7, 11, 
    8, 73, 4, 73, 3, 12, 6, 98, 7, 25, 0, 91, 1, 68, 5, 32, 2, 53, 
    6, 59, 8,  2, 3,  9, 2, 49, 4, 60, 7, 43, 0,  2, 1, 42, 5, 60, 
    4,  8, 0, 52, 6, 26, 2, 56, 8, 80, 1, 82, 3, 60, 5, 57, 7, 12, 
    7, 43, 5, 50, 0,  1, 4, 86, 2, 43, 3, 92, 6, 20, 8, 85, 1, 41, 
    2,  5, 5,  1, 8, 38, 3, 56, 7, 56, 6, 29, 0,  4, 4, 45, 1, 69, 
    6, 63, 7, 87, 8, 77, 1,  3, 2, 22, 5, 52, 0, 88, 3, 83, 4, 24, 
    2, 16, 7, 27, 5, 35, 0, 53, 4, 33, 8, 64, 6, 46, 1, 76, 3,  6, 
    8, 33, 4, 48, 5, 39, 1, 24, 7, 85, 6, 44, 0, 36, 3, 85, 2, 79
  };
  const int q8215[] = {
    9, 9, // Number of jobs and machines
    6, 89, 3,  1, 0,  9, 4, 33, 1, 58, 7, 32, 5,  3, 2, 77, 8,  1, 
    5, 58, 7, 20, 8, 77, 0,  5, 2, 88, 1, 69, 4, 52, 3,  3, 6, 35, 
    1, 75, 8, 67, 2, 72, 3, 80, 4, 10, 0, 62, 6,  4, 7, 93, 5, 33, 
    8, 43, 5, 16, 2,  3, 1, 92, 3,  4, 0, 66, 4, 58, 7, 22, 6, 86, 
    1, 56, 8, 10, 5, 73, 0, 82, 3, 52, 6, 84, 4, 68, 7, 39, 2,  5, 
    4, 48, 5,  8, 6, 77, 7, 23, 8, 60, 3, 92, 0, 52, 1,  9, 2,  3, 
    8, 66, 1, 32, 5, 29, 7, 64, 4, 67, 0, 38, 2, 48, 6, 74, 3, 92, 
    0, 90, 3, 43, 7, 44, 1, 61, 8, 64, 4, 46, 2, 53, 5, 62, 6, 35, 
    2, 10, 0, 18, 6, 22, 8, 10, 7, 79, 5, 66, 3, 72, 1, 40, 4,  7
  };
  const int q8216[] = {
    9, 9, // Number of jobs and machines
    6, 31, 1, 28, 8, 43, 5, 24, 2, 66, 4, 89, 0, 28, 7, 96, 3, 93, 
    4, 10, 5, 16, 6, 70, 0,  7, 3, 81, 8, 99, 1, 96, 7,  4, 2,  6, 
    8, 57, 3, 53, 6, 45, 7, 93, 5, 32, 2, 65, 0, 89, 1, 56, 4, 74, 
    6, 34, 4, 98, 0, 38, 2, 65, 5, 61, 3, 24, 7, 95, 8,  5, 1, 90, 
    8, 21, 4, 42, 5, 62, 0, 28, 6, 16, 7, 77, 2, 17, 3, 72, 1, 92, 
    5, 85, 6,  5, 4, 45, 3, 74, 2, 36, 0, 77, 1, 55, 7, 97, 8, 99, 
    4, 78, 5, 56, 6, 66, 1, 69, 3, 67, 2, 14, 0, 80, 8, 44, 7, 33, 
    7, 26, 5, 16, 1, 30, 3, 50, 2, 88, 6, 41, 0, 52, 4, 50, 8, 26, 
    8, 79, 3, 63, 0, 60, 5,  7, 4, 43, 6, 72, 7, 68, 1,  5, 2, 51
  };
  const int q8217[] = {
    9, 9, // Number of jobs and machines
    5,  6, 0, 14, 6, 60, 3, 91, 1, 55, 8, 99, 4, 28, 2, 92, 7, 32, 
    7, 41, 6, 30, 8, 73, 4, 37, 2, 30, 0, 75, 3, 97, 1, 27, 5, 76, 
    5,  2, 3, 89, 2, 52, 4, 31, 0,  8, 6, 66, 7, 25, 8,  6, 1, 40, 
    0, 14, 4, 95, 8, 38, 6, 13, 3, 75, 5, 41, 2, 70, 1, 65, 7, 15, 
    8, 26, 3, 64, 1, 61, 2, 81, 5, 12, 4,  9, 7, 18, 0, 62, 6, 54, 
    0, 68, 3, 32, 7, 50, 4, 44, 1, 36, 6, 21, 2, 10, 8, 29, 5, 69, 
    1, 78, 3, 32, 8, 82, 4, 30, 5, 54, 2, 34, 7, 11, 0, 14, 6, 70, 
    2, 93, 4, 77, 1, 56, 6, 55, 3, 80, 7, 69, 8, 50, 5, 94, 0, 44, 
    2, 22, 3, 88, 1, 44, 0, 93, 4, 34, 5, 69, 7, 52, 6, 18, 8, 19
  };
  const int q8218[] = {
    9, 9, // Number of jobs and machines
    6,  7, 2, 47, 7, 38, 0, 42, 5, 85, 8, 36, 4, 14, 1, 48, 3, 82, 
    2, 92, 5, 69, 6, 13, 3, 57, 8, 18, 1, 99, 0, 53, 4,  9, 7, 16, 
    7, 15, 4, 67, 6, 36, 1, 37, 5, 50, 8,  6, 3, 49, 0, 60, 2, 91, 
    6, 39, 7, 12, 8, 47, 2,  8, 5, 15, 3, 10, 1, 65, 4, 77, 0, 88, 
    5, 47, 1,  7, 3, 41, 7, 21, 8, 48, 6, 63, 2, 73, 0, 70, 4, 46, 
    6, 49, 4, 78, 1, 20, 8, 83, 2, 48, 0, 82, 7, 56, 5, 70, 3, 35, 
    3, 51, 8, 65, 1, 84, 2, 37, 7, 85, 5, 43, 4, 16, 6, 83, 0,  1, 
    4, 39, 3, 20, 1, 30, 7, 44, 2, 85, 0, 27, 6, 78, 8, 62, 5, 93, 
    5, 91, 6, 39, 8,  9, 7, 14, 2,  9, 4, 80, 1, 30, 3, 91, 0, 16
  };
  const int q8219[] = {
    9, 9, // Number of jobs and machines
    7, 22, 0, 35, 4, 11, 2,  8, 1, 42, 5, 90, 3, 90, 6, 10, 8,  2, 
    8, 22, 3, 85, 5, 77, 0, 10, 6, 57, 7, 74, 1, 49, 2, 52, 4, 48, 
    2, 10, 3, 32, 4, 11, 6, 78, 0, 38, 1, 43, 7,  1, 8, 95, 5, 57, 
    7, 57, 3, 71, 4, 54, 2, 98, 8, 68, 6, 30, 0, 28, 1,  3, 5,  6, 
    4, 83, 0, 17, 5, 64, 3, 29, 7, 14, 8, 12, 2, 63, 6, 19, 1, 39, 
    4, 56, 0, 88, 3, 33, 5, 34, 2, 74, 6, 69, 7, 48, 8, 74, 1, 15, 
    5, 14, 4, 49, 6, 69, 1, 79, 2, 19, 7, 79, 8, 29, 0, 41, 3, 27, 
    3, 21, 8, 22, 5, 98, 4, 46, 7, 73, 6, 28, 1,  7, 2, 28, 0, 32, 
    0, 61, 7, 16, 1, 19, 2,  3, 3, 91, 5, 94, 8, 26, 4, 92, 6, 36
  };
  const int q8220[] = {
    9, 9, // Number of jobs and machines
    3, 51, 8, 16, 7, 58, 1, 73, 5, 66, 2, 17, 6, 62, 0, 24, 4, 72, 
    7, 99, 5, 59, 8, 60, 0, 70, 2, 15, 3, 28, 1,  2, 6, 91, 4, 19, 
    1,  8, 3, 22, 5, 43, 0, 21, 4, 16, 2, 22, 6, 47, 7, 40, 8, 58, 
    2, 82, 6, 32, 3,  9, 8, 27, 1, 95, 4, 17, 7, 85, 0, 60, 5, 21, 
    3, 59, 5, 22, 4, 75, 0, 42, 1,  1, 2, 50, 7, 70, 8, 59, 6, 73, 
    3, 53, 5, 53, 4, 54, 2, 69, 0, 31, 1, 96, 7, 85, 8, 67, 6, 53, 
    5, 30, 8, 69, 2, 15, 3, 53, 6, 89, 4, 84, 0, 76, 1,  1, 7, 46, 
    8, 12, 3, 25, 7, 85, 0, 63, 4, 37, 5, 21, 6, 48, 1, 83, 2, 42, 
    5, 60, 8, 32, 7,  2, 3, 65, 4, 59, 6, 58, 0, 12, 1, 55, 2, 36
  };
  const int q8221[] = {
    9, 9, // Number of jobs and machines
    3, 59, 6, 35, 2, 47, 4, 47, 5, 53, 7, 90, 1, 88, 8, 92, 0, 95, 
    0, 99, 3, 62, 2, 96, 1, 37, 4, 43, 7, 40, 6, 95, 5, 62, 8, 18, 
    8, 75, 6, 12, 7, 12, 3, 72, 5, 95, 0, 60, 2, 55, 4, 97, 1, 11, 
    4, 46, 3, 16, 6, 11, 5, 15, 8, 56, 2, 49, 7,  7, 0, 52, 1, 71, 
    2, 22, 5, 31, 8, 50, 4, 87, 3, 76, 1, 52, 6, 28, 7, 46, 0, 20, 
    2,  1, 4, 93, 1, 82, 5, 69, 7, 98, 6, 95, 8, 80, 3, 53, 0, 15, 
    4, 19, 7, 34, 5, 71, 1, 92, 2, 75, 8, 52, 3, 29, 0, 10, 6, 32, 
    3,  5, 7, 60, 8, 62, 0,  6, 4, 80, 6, 85, 1, 60, 2, 70, 5, 72, 
    4, 84, 2, 58, 5, 26, 3, 52, 7, 39, 1, 53, 6,  2, 8, 66, 0, 13
  };
  const int q8222[] = {
    9, 9, // Number of jobs and machines
    7, 44, 4,  8, 2, 15, 5, 47, 1, 33, 8, 70, 6, 65, 0, 94, 3, 71, 
    6, 91, 4, 79, 5, 92, 3, 83, 0, 23, 1, 91, 7, 90, 2, 55, 8, 50, 
    0, 43, 4, 79, 6, 39, 1, 60, 2, 65, 3, 33, 7, 33, 5, 87, 8, 63, 
    5, 25, 8, 26, 3, 98, 7, 62, 6, 43, 4, 62, 1, 20, 2, 54, 0,  4, 
    3, 61, 2, 62, 5, 55, 7, 46, 0,  9, 1, 88, 6, 88, 8, 14, 4, 26, 
    8, 61, 0, 28, 7, 67, 6, 89, 3, 31, 4, 82, 2,  9, 5, 35, 1, 63, 
    1, 79, 6, 93, 7, 66, 4, 68, 0, 29, 3, 30, 5, 61, 2, 38, 8, 72, 
    1, 51, 7, 98, 2,  3, 6, 81, 5, 34, 3, 56, 4, 96, 0, 27, 8, 96, 
    8, 62, 7, 59, 6,  7, 5,  4, 2, 52, 1, 42, 4, 29, 0, 73, 3, 92
  };
  const int q8223[] = {
    9, 9, // Number of jobs and machines
    0, 17, 1, 36, 4, 56, 2, 77, 7, 62, 3, 69, 5, 25, 6, 52, 8, 59, 
    8,  3, 4, 14, 3, 80, 6, 95, 0, 40, 1, 70, 5, 44, 7, 33, 2, 72, 
    2, 51, 1, 60, 3, 82, 4, 39, 0, 85, 8,  3, 5, 32, 6,  4, 7, 23, 
    8, 72, 1, 37, 2, 12, 7, 64, 0, 90, 4, 47, 5, 67, 6, 51, 3, 16, 
    3, 40, 7, 63, 6, 20, 1, 41, 0, 12, 8, 43, 4, 40, 2, 77, 5, 20, 
    0, 84, 3, 90, 2, 24, 5, 79, 8, 60, 6,  5, 1, 45, 7, 20, 4,  6, 
    5, 22, 2,  1, 7, 23, 1,  1, 8,  2, 6, 36, 4, 72, 0, 82, 3,  1, 
    6, 83, 7,  5, 8, 37, 1, 86, 5, 34, 0, 88, 2, 43, 3, 10, 4, 14, 
    2, 57, 0,  9, 4, 67, 7, 82, 5,  4, 3, 84, 1, 77, 6, 50, 8, 75
  };
  const int q8224[] = {
    9, 9, // Number of jobs and machines
    4, 15, 3,  1, 1, 17, 6, 67, 8,  5, 5, 74, 0, 41, 2, 62, 7,  2, 
    7, 60, 2, 97, 1, 76, 4, 92, 8, 44, 0, 91, 3, 80, 6, 46, 5, 85, 
    4, 37, 0, 77, 6, 62, 3, 20, 5, 66, 1, 50, 8, 49, 7,  1, 2, 50, 
    0, 92, 2, 90, 6, 29, 8, 95, 1, 99, 5, 95, 3, 12, 4,  7, 7,  6, 
    6, 22, 5, 83, 8, 59, 2, 30, 3, 40, 7, 81, 4, 85, 1, 45, 0, 70, 
    6, 43, 7, 95, 1, 92, 5, 90, 0, 96, 8, 77, 2,  9, 4,  8, 3, 57, 
    6,  1, 0, 98, 8, 82, 5,  6, 3, 59, 2, 67, 7, 95, 4, 15, 1, 94, 
    7, 81, 5, 35, 8, 67, 4,  3, 3, 17, 2, 43, 1, 80, 6, 71, 0, 34, 
    8, 69, 1,  4, 7, 39, 6, 73, 0, 86, 4, 33, 2, 91, 3, 70, 5, 54
  };
  const int q8225[] = {
    9, 9, // Number of jobs and machines
    3, 51, 1, 86, 8,  6, 6, 31, 5, 11, 2, 28, 7, 18, 4, 36, 0, 36, 
    3, 12, 1, 95, 2, 60, 7, 45, 6,  3, 4, 68, 8, 96, 0, 55, 5, 90, 
    1, 92, 4,  7, 7, 73, 6, 43, 2, 15, 3, 47, 5, 65, 0, 72, 8, 15, 
    8, 30, 5, 39, 3, 39, 2, 27, 6, 16, 7, 75, 4, 59, 1, 27, 0, 76, 
    2, 27, 3, 58, 4, 81, 8, 15, 5, 43, 6, 47, 1, 87, 0, 45, 7, 55, 
    8, 74, 3, 28, 4, 11, 0, 87, 6, 14, 5, 73, 2, 95, 1, 85, 7, 18, 
    0, 48, 5, 94, 1, 51, 6, 11, 2, 13, 3, 81, 4, 91, 7, 24, 8, 26, 
    1, 46, 2, 37, 5, 22, 0, 18, 3, 36, 4, 95, 7, 98, 6, 51, 8,  9, 
    7, 39, 1, 23, 8, 48, 0, 22, 6, 77, 2, 60, 4, 36, 3, 40, 5, 24
  };
  const int q8226[] = {
    9, 9, // Number of jobs and machines
    8, 37, 2, 82, 4, 90, 5, 56, 0, 41, 7, 52, 6, 26, 1, 70, 3, 30, 
    4, 81, 7,  9, 6, 65, 3, 45, 0, 80, 8,  2, 2, 16, 1, 16, 5, 52, 
    6, 52, 4, 37, 0, 20, 5, 87, 1, 32, 2, 89, 3, 96, 7, 11, 8, 60, 
    5, 64, 3, 81, 0, 31, 1, 82, 7, 13, 6, 56, 8, 89, 2, 29, 4, 76, 
    2, 88, 5, 79, 0, 18, 3, 21, 7, 53, 4, 53, 8, 67, 1,  5, 6, 70, 
    0, 20, 5, 73, 4, 87, 1, 70, 6, 13, 7, 99, 8, 64, 3, 78, 2, 41, 
    6, 92, 2, 86, 3, 79, 1, 10, 7, 13, 4,  4, 8, 41, 5, 64, 0, 49, 
    8, 29, 1, 84, 0, 50, 4, 63, 5, 92, 3, 82, 6, 71, 2, 60, 7,  6, 
    1, 11, 6, 97, 5, 48, 0, 88, 4, 17, 8, 46, 2, 57, 7, 19, 3, 53
  };
  const int q8227[] = {
    9, 9, // Number of jobs and machines
    4, 22, 2, 50, 3, 81, 1, 30, 8, 41, 7, 29, 0, 40, 5, 30, 6, 77, 
    2,  6, 0, 92, 7, 33, 6, 26, 4, 76, 5, 25, 8, 39, 3, 47, 1, 24, 
    5, 91, 1, 31, 0,  3, 7, 63, 3, 16, 8, 57, 6, 36, 2,  5, 4,  9, 
    6, 37, 8, 68, 5, 88, 7, 97, 2, 83, 3, 38, 4, 78, 1, 49, 0,  4, 
    0, 15, 3, 73, 2, 19, 6, 20, 4, 16, 5, 25, 7, 48, 1, 83, 8, 14, 
    8, 43, 3, 21, 7, 97, 2, 58, 0, 38, 6,  3, 1, 74, 5, 75, 4, 80, 
    1,  1, 6, 57, 0, 56, 2, 24, 8, 83, 5, 41, 7, 78, 4, 85, 3, 16, 
    6, 21, 3, 59, 0, 44, 4, 88, 5, 27, 7, 63, 2, 87, 1, 92, 8, 76, 
    6, 19, 4, 94, 5, 93, 8, 86, 2, 57, 3,  7, 0, 26, 1, 13, 7, 36
  };
  const int q8228[] = {
    9, 9, // Number of jobs and machines
    7, 96, 0, 71, 8, 78, 3, 46, 1, 45, 6, 56, 5, 42, 4, 87, 2, 90, 
    2, 62, 6, 88, 3, 41, 5, 47, 1, 13, 7, 44, 0, 20, 8, 11, 4, 62, 
    2, 12, 5, 57, 7, 62, 1, 45, 6,  9, 0, 53, 4, 99, 8, 25, 3, 76, 
    7, 50, 2, 51, 8, 93, 0, 34, 5, 72, 3, 46, 1, 91, 4, 49, 6, 57, 
    1, 63, 3, 85, 2, 81, 7, 79, 0, 23, 8, 83, 5, 19, 4, 36, 6, 92, 
    7, 51, 3, 81, 6, 31, 2, 76, 4, 61, 0, 18, 5, 21, 8, 28, 1, 62, 
    1, 53, 2, 62, 7, 47, 6, 43, 3,  9, 4,  4, 0, 52, 5, 83, 8, 19, 
    4, 46, 5, 64, 8, 69, 7, 91, 6, 42, 2, 62, 0, 10, 3, 84, 1, 26, 
    7, 96, 2, 27, 4, 32, 5, 61, 1, 74, 6, 21, 3, 88, 0, 60, 8, 75
  };
  const int q8229[] = {
    9, 9, // Number of jobs and machines
    8, 47, 4, 42, 6, 38, 1, 28, 2, 66, 7, 59, 0,  9, 3, 22, 5, 78, 
    4, 39, 8,  3, 5, 64, 7, 82, 0, 90, 1, 81, 2, 55, 3, 85, 6, 98, 
    7, 11, 3, 59, 4, 62, 2, 91, 8, 86, 0, 71, 6, 31, 1,  4, 5, 67, 
    4, 37, 0, 89, 8,  5, 3,  3, 6, 73, 7, 40, 5, 63, 2, 44, 1, 14, 
    7, 20, 1, 60, 5, 72, 8, 56, 3, 46, 0, 58, 6, 39, 4, 48, 2, 29, 
    5, 67, 6, 31, 8, 21, 7, 30, 2, 42, 0, 55, 1, 47, 3, 81, 4, 66, 
    0, 50, 8, 94, 5, 35, 6, 96, 4, 46, 7, 65, 1, 48, 2, 89, 3, 33, 
    8, 91, 7,  5, 0, 27, 5, 76, 1, 91, 2, 99, 4, 78, 6, 36, 3, 44, 
    7, 64, 3, 91, 1, 85, 6, 54, 5, 26, 2, 35, 0, 59, 4, 25, 8, 56
  };
  const int q8230[] = {
    9, 9, // Number of jobs and machines
    2, 83, 0, 21, 7, 74, 3, 70, 8, 91, 1, 22, 4, 15, 5, 60, 6, 32, 
    0, 14, 7, 34, 8, 42, 6, 96, 2, 80, 4, 30, 3, 66, 1,  3, 5, 33, 
    6, 53, 4, 51, 7,  4, 8, 46, 5,  2, 2, 94, 1, 15, 0, 53, 3, 46, 
    0, 48, 3, 64, 2, 13, 8, 28, 6, 95, 7, 62, 4, 98, 1, 62, 5, 92, 
    0, 19, 8, 26, 6, 14, 7, 82, 4, 56, 2, 79, 3, 46, 5, 67, 1,  2, 
    7, 24, 0, 81, 8, 58, 2, 49, 5, 71, 4, 57, 3, 74, 1, 49, 6, 51, 
    4, 10, 3, 95, 1, 38, 7, 67, 0, 47, 5, 77, 6, 57, 2, 27, 8,  9, 
    7, 29, 5,  8, 1, 47, 0, 87, 8, 65, 6, 59, 3, 28, 4, 55, 2, 95, 
    4, 57, 6, 61, 0, 43, 2, 64, 8, 35, 7, 89, 1, 39, 3,  7, 5, 11
  };
  const int q8231[] = {
    9, 9, // Number of jobs and machines
    6, 64, 3, 85, 1, 88, 5, 22, 4, 82, 2, 72, 7, 83, 0, 61, 8, 33, 
    5, 84, 4, 13, 8, 26, 7, 50, 2, 63, 3, 67, 1, 89, 0, 16, 6, 33, 
    8, 91, 4, 56, 0, 28, 6, 65, 2, 39, 5, 25, 1,  9, 3, 53, 7, 89, 
    2, 75, 6, 62, 8, 76, 0, 33, 3, 50, 4, 65, 5, 74, 1, 80, 7,  6, 
    5, 51, 7, 42, 2, 33, 1, 82, 0, 74, 4, 27, 6, 88, 8, 47, 3, 57, 
    3, 59, 2, 24, 7, 89, 5,  6, 1, 63, 0, 54, 8, 87, 4, 82, 6, 90, 
    5, 32, 2, 89, 0, 54, 8, 65, 3, 51, 7, 11, 6, 61, 1, 23, 4, 87, 
    8, 33, 3, 12, 7, 24, 1, 99, 4, 68, 2, 15, 6, 96, 0, 73, 5, 76, 
    1,  5, 0, 26, 7, 38, 5, 26, 3,  3, 6,  4, 8, 33, 4, 64, 2, 60
  };
  const int q8232[] = {
    9, 9, // Number of jobs and machines
    1, 95, 7, 26, 2, 45, 8, 44, 5, 45, 0, 79, 3, 80, 4, 38, 6, 71, 
    1, 53, 4, 66, 8, 51, 6, 35, 7, 67, 2, 23, 3, 98, 0, 88, 5, 22, 
    4, 88, 0, 94, 2, 62, 1, 94, 5, 26, 3, 26, 6, 25, 7, 39, 8, 57, 
    6, 50, 3, 84, 1, 45, 7, 24, 2, 50, 8, 99, 5, 62, 0, 24, 4, 17, 
    6, 43, 8,  3, 7,  2, 5, 99, 3, 58, 0, 17, 2,  9, 4, 17, 1,  6, 
    5, 33, 2, 38, 3, 63, 6, 12, 0, 66, 1, 50, 8, 97, 7, 85, 4, 77, 
    6, 93, 3, 64, 4, 90, 5, 39, 8, 38, 2,  5, 1, 49, 7, 83, 0, 70, 
    0, 23, 7, 44, 2,  4, 3, 97, 6, 60, 8, 67, 1, 82, 5, 58, 4, 21, 
    3,  8, 7, 39, 0, 37, 4, 84, 6, 64, 1, 46, 8, 99, 2, 82, 5, 67
  };
  const int q8233[] = {
    9, 9, // Number of jobs and machines
    8, 47, 1, 92, 3, 13, 2, 91, 5, 17, 7, 21, 4, 62, 6, 79, 0, 92, 
    5, 74, 6, 24, 4, 50, 8, 31, 7, 18, 1, 17, 2, 84, 0, 98, 3, 53, 
    7, 97, 1, 15, 6, 42, 8, 50, 3, 44, 5, 47, 0,  1, 2, 65, 4, 25, 
    7, 98, 4, 74, 5, 39, 2, 17, 0, 47, 3, 77, 6, 17, 1, 31, 8, 80, 
    2, 61, 0, 52, 3, 68, 8, 92, 7, 84, 6,  9, 5, 50, 1, 96, 4, 39, 
    6, 65, 5, 23, 3,  4, 0, 22, 2, 86, 8, 83, 4, 78, 1, 97, 7, 17, 
    1,  3, 7, 21, 2, 62, 3, 86, 0, 18, 8, 91, 4, 34, 5, 57, 6, 51, 
    5, 85, 2, 62, 6, 74, 0, 45, 1, 83, 4, 80, 3, 64, 8, 47, 7, 80, 
    5, 22, 1, 31, 3, 77, 2, 24, 6,  1, 4, 47, 8, 46, 0, 23, 7,  6
  };
  const int q8234[] = {
    9, 9, // Number of jobs and machines
    3, 12, 1, 31, 4, 42, 6, 71, 8, 99, 0,  9, 7,  4, 2, 96, 5, 13, 
    4, 16, 5,  1, 3, 55, 8, 40, 1, 26, 2, 83, 0, 36, 7, 60, 6,  2, 
    0, 34, 6, 23, 1, 69, 7, 52, 3, 85, 2, 90, 4, 70, 5, 28, 8, 19, 
    5, 56, 4, 19, 2, 67, 8, 25, 6, 32, 0, 16, 1, 42, 7, 64, 3, 97, 
    7, 61, 3, 35, 5, 34, 1, 22, 6, 35, 8,  9, 4, 13, 0, 29, 2, 68, 
    1, 76, 8, 32, 0, 63, 7, 66, 5, 74, 4, 82, 2, 84, 3, 24, 6,  6, 
    4, 73, 7, 75, 0, 32, 2, 49, 3, 10, 1, 28, 8, 21, 6, 61, 5, 29, 
    1, 73, 3, 31, 0,  5, 8, 50, 5, 30, 2, 39, 7, 49, 6, 82, 4, 61, 
    5, 54, 6, 50, 1, 48, 4, 68, 0, 35, 8, 96, 2, 54, 3, 76, 7, 23
  };
  const int q8235[] = {
    9, 9, // Number of jobs and machines
    0, 58, 3, 93, 8, 55, 7, 87, 2, 75, 6, 47, 1, 95, 5, 40, 4, 53, 
    1,  5, 4, 52, 5, 46, 3, 66, 6, 15, 8, 93, 2, 34, 0, 23, 7, 27, 
    1, 64, 2, 18, 5, 25, 3,  6, 8, 56, 4, 58, 7, 82, 0, 10, 6, 57, 
    7,  4, 5, 20, 2, 72, 8,  7, 1, 53, 3, 32, 6, 35, 0, 28, 4, 73, 
    1, 98, 8, 40, 2, 25, 0, 89, 4, 32, 6, 65, 3, 75, 5, 23, 7, 12, 
    8, 22, 5, 29, 3, 13, 4, 17, 6, 99, 2, 47, 1, 83, 0, 18, 7, 87, 
    0, 12, 1, 25, 2, 91, 8, 91, 6, 80, 7, 61, 5, 17, 4, 65, 3, 42, 
    1, 85, 3, 97, 6, 20, 5, 24, 8, 76, 0, 90, 2, 60, 7, 50, 4, 34, 
    3, 23, 1, 85, 2, 49, 4, 86, 7, 77, 0, 25, 6, 36, 8,  2, 5, 23
  };
  const int q8236[] = {
    9, 9, // Number of jobs and machines
    1, 12, 8, 27, 2, 62, 4,  4, 7, 86, 3, 39, 6, 22, 0, 88, 5, 43, 
    5, 66, 6,  5, 7, 13, 3, 64, 8, 74, 1, 88, 2, 69, 0, 88, 4, 51, 
    2, 23, 1, 26, 0, 77, 7, 40, 4, 45, 3, 58, 5,  2, 6,  8, 8, 41, 
    7, 84, 5, 78, 0, 30, 1,  3, 4,  2, 6, 66, 2, 49, 3, 29, 8, 47, 
    6, 85, 4, 51, 0,  2, 1, 40, 2,  2, 8, 80, 3, 57, 7, 58, 5, 20, 
    5,  8, 3, 47, 6, 29, 2, 42, 8, 10, 7, 35, 0, 63, 4, 37, 1, 46, 
    0, 78, 1, 14, 8, 18, 6, 97, 7, 11, 2, 82, 5, 70, 4, 60, 3, 34, 
    1,  5, 2, 17, 4, 93, 0, 36, 5, 45, 7, 38, 6, 65, 8, 47, 3, 22, 
    0, 36, 4, 72, 8, 37, 5, 62, 2,  7, 1, 92, 7, 33, 6, 57, 3, 26
  };
  const int q8237[] = {
    9, 9, // Number of jobs and machines
    1,  1, 7, 32, 4, 56, 8, 74, 3, 29, 5, 72, 2, 41, 0, 12, 6, 55, 
    8, 31, 0, 43, 7, 21, 1, 66, 5, 51, 3, 69, 6, 77, 2, 60, 4, 12, 
    4, 26, 6, 81, 0, 94, 1, 95, 7, 97, 3, 84, 5, 45, 2, 41, 8, 87, 
    6, 61, 0, 76, 1, 21, 8, 35, 7, 99, 4, 36, 2, 56, 3, 73, 5, 93, 
    6, 98, 7, 22, 1, 67, 5, 67, 0, 89, 2, 34, 8, 94, 4, 58, 3,  5, 
    2, 21, 4, 96, 0, 51, 6, 15, 1, 77, 7,  5, 5, 71, 3, 87, 8, 59, 
    6, 44, 1, 52, 3,  8, 2,  3, 0, 32, 4, 79, 8, 99, 5,  2, 7, 12, 
    4, 79, 5,  5, 8, 56, 7, 26, 1, 48, 0, 97, 2, 42, 6, 26, 3, 73, 
    3, 14, 1, 38, 7, 76, 8, 70, 6, 10, 4, 48, 2, 17, 5, 76, 0, 69
  };
  const int q8238[] = {
    9, 9, // Number of jobs and machines
    1, 53, 0, 85, 2, 19, 3, 63, 5, 76, 7, 13, 6, 32, 8, 43, 4, 14, 
    2, 83, 0, 17, 1, 60, 3, 41, 5,  5, 7, 74, 8, 52, 4,  3, 6, 47, 
    1, 25, 7, 48, 6, 53, 4, 13, 5, 98, 8, 62, 3, 89, 2, 40, 0, 68, 
    6, 49, 0, 42, 3, 85, 2, 81, 5, 34, 4, 68, 1, 78, 8, 18, 7, 61, 
    0, 48, 7, 40, 2, 90, 4, 83, 3, 36, 5, 48, 8, 31, 6, 96, 1, 13, 
    5, 31, 6, 62, 0, 48, 7, 72, 3,  6, 8, 86, 4, 48, 2,  4, 1, 44, 
    0, 90, 7, 97, 3, 29, 5, 80, 1,  6, 8, 35, 6, 48, 2,  8, 4, 96, 
    6, 29, 2, 95, 8, 21, 1, 83, 7, 13, 0, 54, 5, 13, 3, 87, 4, 36, 
    7, 89, 0,  9, 3, 39, 6, 64, 4, 94, 5, 82, 2, 21, 1, 88, 8, 50
  };
  const int q8239[] = {
    9, 9, // Number of jobs and machines
    5, 31, 4, 46, 7, 41, 2, 33, 0, 36, 6, 46, 1, 66, 3, 10, 8, 58, 
    3, 44, 6, 53, 5, 14, 2, 50, 0, 50, 1,  4, 4, 12, 8, 61, 7, 53, 
    2, 96, 7, 59, 4, 68, 6,  3, 5, 90, 1, 15, 8, 85, 3, 95, 0,  8, 
    4, 36, 7, 49, 0,  4, 1, 20, 8, 59, 2, 35, 5, 83, 6, 29, 3, 98, 
    7, 35, 0, 51, 3, 66, 5, 15, 4, 73, 8,  1, 2, 54, 6, 50, 1, 45, 
    6, 19, 0, 25, 1, 33, 4, 12, 3, 11, 2, 55, 5, 41, 8, 37, 7, 66, 
    2, 24, 8,  8, 4, 34, 3,  6, 0,  2, 1, 32, 7,  6, 5, 81, 6, 83, 
    0, 68, 4, 34, 8, 86, 3, 25, 6, 49, 7, 29, 5, 99, 1, 78, 2, 36, 
    2,  7, 4, 24, 3, 79, 8,  1, 0, 44, 5,  5, 7, 39, 6, 56, 1, 64
  };
  const int q8240[] = {
    9, 9, // Number of jobs and machines
    2, 59, 7, 87, 4, 46, 3, 76, 1, 69, 8, 96, 6, 41, 5, 75, 0, 44, 
    3, 51, 1, 39, 0, 59, 7, 47, 6, 69, 4, 88, 8, 58, 5, 35, 2, 45, 
    3, 84, 2, 22, 5, 20, 0, 37, 1, 58, 4, 70, 8, 29, 7, 49, 6, 14, 
    6, 73, 3, 14, 7, 89, 2, 30, 0,  3, 8, 62, 5,  8, 4, 76, 1, 51, 
    4, 84, 3, 33, 7, 66, 8, 19, 1, 35, 6, 68, 5,  3, 0, 61, 2, 36, 
    4, 77, 2, 59, 8, 41, 7, 25, 0, 18, 6, 65, 5, 13, 1, 97, 3, 67, 
    3,  5, 5, 50, 6, 44, 7, 37, 2, 91, 4, 85, 1, 18, 0, 55, 8, 87, 
    3, 68, 8, 94, 1,  5, 6,  9, 4, 18, 0, 28, 2, 33, 5, 23, 7, 49, 
    5, 57, 7, 14, 4, 93, 0, 32, 3, 82, 8, 40, 6, 61, 2,  3, 1, 13
  };
  const int q8241[] = {
    9, 9, // Number of jobs and machines
    3, 89, 7,  2, 2, 41, 4,  8, 5, 13, 0, 37, 1, 46, 8, 70, 6, 71, 
    8, 32, 4, 36, 1, 61, 3, 27, 0, 51, 6, 20, 7, 54, 5,  2, 2, 55, 
    4, 25, 6, 47, 1, 10, 3, 52, 8, 17, 7, 52, 2, 22, 5, 38, 0, 13, 
    4, 11, 5, 65, 7, 89, 0, 52, 1, 20, 6, 45, 8, 83, 2, 29, 3,  1, 
    8, 45, 7, 67, 6, 84, 0, 73, 4, 45, 1, 57, 2, 86, 5, 24, 3, 96, 
    0, 75, 5,  4, 6, 99, 8, 89, 1, 93, 7, 31, 4, 73, 3, 59, 2, 83, 
    6, 30, 2, 42, 4, 64, 0, 38, 3, 87, 7, 75, 5, 22, 1, 39, 8, 55, 
    4, 97, 6,  2, 7, 78, 2, 79, 8, 77, 1, 94, 0, 96, 3,  9, 5, 11, 
    8, 77, 2, 79, 3, 52, 5, 33, 6, 66, 4, 12, 0,  4, 1, 34, 7, 28
  };
  const int q8242[] = {
    9, 9, // Number of jobs and machines
    2, 43, 6, 98, 8, 61, 5, 35, 0,  4, 4, 51, 3,  6, 7, 82, 1, 90, 
    4, 93, 3, 42, 6, 45, 7, 96, 1, 21, 8, 78, 2, 54, 5, 75, 0, 41, 
    2, 81, 1,  5, 5, 35, 4, 73, 8,  1, 7, 79, 0, 68, 6, 56, 3, 38, 
    2, 85, 0, 98, 6,  1, 7, 45, 4, 86, 5, 31, 3, 52, 8, 18, 1,  1, 
    5, 23, 0, 10, 8, 86, 1, 20, 7, 92, 6, 66, 4, 58, 2, 39, 3, 75, 
    3, 18, 0, 28, 4, 51, 2, 72, 8,  9, 6, 99, 5, 52, 7, 12, 1,  9, 
    4, 80, 8, 35, 7, 70, 2, 96, 3, 51, 1, 86, 5, 55, 0,  8, 6, 19, 
    3, 25, 5, 76, 2, 34, 7, 75, 0, 76, 1, 84, 6, 32, 8, 53, 4, 70, 
    2, 97, 5, 33, 3, 16, 0, 88, 7,  2, 6, 12, 1, 51, 4, 64, 8, 99
  };
  const int q8243[] = {
    9, 9, // Number of jobs and machines
    7, 80, 6, 40, 4, 16, 8, 98, 3, 14, 2, 88, 5,  6, 0, 86, 1, 63, 
    0, 60, 8, 61, 4, 86, 5, 86, 7, 99, 6, 73, 1, 47, 2, 34, 3, 40, 
    4, 85, 3, 75, 6, 58, 7, 96, 5, 27, 1, 80, 0, 81, 8, 15, 2, 82, 
    1, 93, 8, 31, 2, 69, 3, 85, 4, 73, 7, 80, 0, 99, 5, 32, 6, 63, 
    4, 79, 3, 75, 6, 47, 2, 15, 1, 55, 7, 27, 0, 81, 5, 44, 8, 21, 
    4, 79, 8, 99, 6, 80, 0, 24, 7, 40, 2, 17, 5, 81, 1, 65, 3, 95, 
    0, 74, 8, 13, 2, 86, 3, 17, 7, 95, 6, 27, 1, 12, 4, 75, 5, 35, 
    1, 76, 0, 45, 3, 50, 8, 65, 5, 66, 4, 93, 2, 10, 6, 45, 7,  9, 
    7,  3, 6, 84, 5, 22, 4, 14, 8, 87, 3, 96, 2,  9, 0, 41, 1, 93
  };
  const int q8244[] = {
    9, 9, // Number of jobs and machines
    6, 22, 5, 87, 3, 14, 7, 89, 2, 58, 1, 51, 4,  5, 0, 29, 8, 56, 
    6,  1, 3,  5, 4, 22, 1, 68, 8, 61, 0,  8, 7,  6, 5, 50, 2, 14, 
    0, 92, 5, 31, 2, 49, 7, 22, 1, 23, 8, 90, 3, 53, 4, 67, 6, 84, 
    3, 85, 1, 24, 5, 55, 0, 42, 8, 11, 4, 19, 6, 33, 7, 92, 2, 79, 
    4, 24, 1,  4, 2, 46, 8, 16, 0, 28, 3, 27, 6, 46, 7, 34, 5, 83, 
    5, 93, 6, 60, 4, 80, 8, 32, 0, 78, 7, 48, 2, 62, 1, 11, 3, 74, 
    6, 51, 4, 96, 7, 95, 2, 41, 8, 23, 3, 23, 1, 73, 5, 88, 0, 17, 
    6, 54, 4, 31, 3, 49, 1, 45, 8, 86, 2, 31, 0, 59, 5, 77, 7, 12, 
    7, 98, 3, 64, 8, 56, 5, 46, 1, 29, 6, 40, 4, 29, 0, 59, 2,  8
  };
  const int q8245[] = {
    9, 9, // Number of jobs and machines
    5, 15, 8, 61, 7, 65, 4, 31, 3, 92, 6,  6, 0, 81, 1, 12, 2, 68, 
    7, 53, 6,  3, 3, 49, 2, 32, 5, 15, 0, 89, 1, 74, 4, 21, 8, 63, 
    8, 79, 2, 95, 3, 16, 0, 10, 5, 81, 1, 65, 4,  8, 7, 82, 6, 52, 
    3,  5, 4, 24, 5, 18, 7, 71, 1, 20, 2, 67, 8, 50, 0, 68, 6, 55, 
    6, 67, 0, 36, 1, 56, 8, 13, 5, 75, 3, 17, 2, 65, 4, 18, 7, 43, 
    7, 46, 1, 10, 8,  7, 3, 34, 4, 32, 6, 33, 0, 61, 5, 72, 2, 34, 
    3,  2, 1, 56, 4, 50, 2, 94, 0, 10, 7, 36, 6, 63, 5, 67, 8, 73, 
    1, 44, 2, 59, 5, 85, 4,  9, 6, 37, 8, 80, 3, 90, 7, 88, 0, 14, 
    8,  7, 1, 46, 4, 73, 3, 10, 0, 89, 7,  4, 2, 17, 5, 15, 6, 97
  };
  const int q8246[] = {
    9, 9, // Number of jobs and machines
    4, 33, 1, 45, 7, 43, 5, 51, 0, 62, 8, 33, 3, 73, 6, 96, 2, 26, 
    5, 94, 7, 32, 8, 69, 3, 79, 0, 94, 2, 48, 6, 21, 4, 43, 1, 92, 
    3, 25, 4, 16, 5, 18, 6, 19, 8, 80, 2, 45, 7, 92, 1,  9, 0, 12, 
    7, 78, 2, 85, 0,  5, 3, 63, 6, 33, 5, 26, 4, 32, 8, 16, 1, 43, 
    0, 76, 2, 46, 8, 49, 3, 91, 5, 50, 1, 99, 4, 96, 7, 10, 6, 76, 
    0, 93, 5, 45, 7, 66, 3, 13, 1, 41, 8, 26, 4, 13, 2, 16, 6, 88, 
    7, 11, 0, 89, 1, 14, 2, 96, 6,  3, 4, 98, 5, 32, 8, 32, 3, 18, 
    0, 43, 5, 92, 1, 83, 8, 61, 2, 47, 4,  5, 7, 39, 6, 58, 3, 14, 
    8, 99, 1, 50, 0, 29, 4, 79, 3, 26, 2, 96, 5, 95, 7, 62, 6, 94
  };
  const int q8247[] = {
    9, 9, // Number of jobs and machines
    5, 60, 7, 54, 8, 88, 6, 63, 4, 98, 0, 37, 3, 53, 1, 15, 2, 91, 
    8,  3, 6, 86, 3,  2, 2, 30, 4, 66, 0, 39, 7, 64, 5, 95, 1, 58, 
    1, 60, 6, 86, 7, 30, 5, 23, 0, 52, 3, 85, 4, 87, 2, 46, 8, 52, 
    5, 45, 6, 98, 3,  4, 8, 19, 7, 20, 0, 11, 4, 92, 2, 47, 1, 99, 
    1, 89, 2, 71, 7, 81, 4, 69, 3, 90, 8,  8, 5, 95, 6, 98, 0, 65, 
    0,  2, 5,  1, 2, 36, 6, 91, 3, 56, 1, 10, 7, 35, 4, 25, 8,  6, 
    7, 74, 1, 63, 4, 79, 2,  9, 3, 43, 5, 81, 8, 79, 6, 93, 0, 13, 
    7, 93, 5, 69, 4, 39, 1, 19, 8, 59, 2, 47, 3, 16, 6, 28, 0, 23, 
    0, 47, 2, 97, 1, 33, 4, 32, 6, 59, 7, 93, 8, 64, 5, 84, 3, 55
  };
  const int q8248[] = {
    9, 9, // Number of jobs and machines
    6, 58, 7, 76, 4, 49, 1, 88, 0, 77, 2, 74, 3, 40, 8, 65, 5, 58, 
    6, 34, 2, 21, 0, 57, 7, 57, 5, 18, 4, 17, 3, 14, 8, 11, 1, 53, 
    1, 86, 8, 45, 0, 90, 3, 29, 4, 15, 2, 25, 6, 20, 5, 16, 7,  5, 
    4, 39, 3, 69, 1, 44, 7, 64, 8, 38, 6, 23, 0, 79, 5, 55, 2,  3, 
    7,  2, 8, 79, 6, 39, 2, 82, 0, 14, 1, 74, 4, 94, 5, 53, 3, 47, 
    2, 51, 5, 19, 1, 19, 0, 12, 8,  7, 7, 12, 6, 58, 4, 13, 3, 16, 
    4, 92, 7, 17, 2, 54, 3, 51, 1, 48, 5, 44, 6, 77, 8,  9, 0, 17, 
    4, 21, 8, 69, 5, 17, 0,  2, 3, 58, 2, 83, 1, 75, 7, 56, 6, 47, 
    2,  8, 7, 80, 0, 15, 6, 27, 5, 63, 8, 28, 1, 54, 3, 67, 4, 54
  };
  const int q8249[] = {
    9, 9, // Number of jobs and machines
    5, 95, 2, 85, 7, 88, 0, 35, 8, 73, 4, 74, 3, 41, 6, 18, 1,  2, 
    1, 17, 3, 52, 0, 68, 2,  6, 8, 41, 5, 97, 4, 10, 6, 19, 7, 67, 
    1, 15, 7, 20, 0, 85, 3, 41, 8, 46, 5, 29, 4, 99, 2, 82, 6, 79, 
    7, 27, 0,  5, 2, 19, 1, 77, 3, 17, 5, 97, 6, 58, 4, 67, 8, 84, 
    3, 57, 5, 39, 7, 77, 0, 21, 1, 74, 4, 94, 2, 97, 8, 97, 6, 24, 
    5, 76, 0, 93, 2, 76, 4,  7, 1, 68, 6, 20, 3, 53, 7, 61, 8, 92, 
    7,  2, 6, 68, 8, 64, 1,  9, 4, 97, 2, 69, 3, 10, 0, 71, 5, 66, 
    4, 19, 6, 49, 0, 86, 7, 34, 5, 56, 1, 37, 8, 28, 2, 28, 3, 76, 
    5, 25, 3, 97, 1, 53, 0, 96, 7, 84, 8, 91, 4, 80, 2, 55, 6, 31
  };
  const int q8250[] = {
    9, 9, // Number of jobs and machines
    4, 19, 1, 91, 2,  8, 6, 86, 7, 91, 8, 28, 5,  9, 3, 45, 0, 41, 
    5,  7, 2, 86, 7, 56, 0, 21, 1, 77, 4, 52, 6, 38, 8, 23, 3, 64, 
    3, 13, 4, 14, 5, 75, 0, 95, 7,  9, 8, 23, 2, 96, 1, 72, 6, 12, 
    2, 13, 1, 48, 3, 28, 8, 13, 7, 56, 6, 30, 0, 78, 4, 18, 5, 11, 
    1, 20, 3, 51, 4, 11, 5, 84, 8, 44, 6, 53, 7, 75, 2, 78, 0, 76, 
    4, 98, 8, 43, 1, 88, 6, 64, 3, 46, 0, 36, 7, 59, 2, 10, 5, 96, 
    1, 97, 7, 32, 2, 68, 5, 50, 3, 76, 8, 38, 6, 10, 4, 43, 0, 76, 
    3, 72, 1, 29, 6, 56, 0, 23, 8, 78, 5, 77, 7, 80, 2, 60, 4, 56, 
    1, 78, 5,  8, 3, 38, 8,  5, 0, 69, 7, 30, 4, 45, 2, 57, 6,  7
  };
  const int q8251[] = {
    9, 9, // Number of jobs and machines
    1, 73, 2, 60, 0, 77, 6, 71, 4, 23, 5, 34, 7, 48, 3, 30, 8, 99, 
    7, 95, 5, 43, 4, 37, 2,  9, 6, 53, 8, 32, 3, 70, 1, 60, 0, 90, 
    2, 68, 0, 35, 8, 78, 4, 55, 6, 66, 7, 77, 3, 31, 5, 84, 1, 87, 
    0, 34, 1, 96, 7, 34, 8, 92, 2, 31, 4, 70, 6, 30, 3, 39, 5, 87, 
    3, 31, 5,  7, 8, 41, 1, 97, 7, 71, 4, 51, 0,  4, 6, 24, 2, 11, 
    1, 86, 4, 32, 7, 42, 5, 12, 3,  2, 2, 12, 0, 69, 6, 89, 8, 64, 
    3, 76, 7, 83, 0, 26, 2,  3, 4, 15, 1, 44, 5, 89, 6, 74, 8, 85, 
    7, 90, 8, 47, 4, 16, 5, 83, 0, 44, 2, 17, 1, 79, 3, 78, 6, 25, 
    4, 12, 3, 73, 6, 87, 5, 92, 8, 60, 1, 25, 2,  5, 7, 25, 0, 53
  };
  const int q8252[] = {
    9, 9, // Number of jobs and machines
    4, 12, 7, 93, 1, 65, 8, 19, 2, 54, 0, 57, 3, 74, 5, 72, 6, 94, 
    4, 70, 2, 24, 3, 74, 7, 26, 5, 28, 8, 67, 6, 69, 0, 67, 1, 57, 
    7, 33, 0, 17, 8, 52, 4, 38, 5, 73, 2, 47, 6, 97, 1, 30, 3, 65, 
    3, 13, 2, 93, 6,  3, 0, 90, 8, 52, 5, 89, 1, 61, 7, 67, 4, 47, 
    7, 63, 0, 62, 8, 40, 3, 25, 6, 59, 1, 32, 5, 53, 4, 14, 2,  3, 
    7, 21, 6,  7, 4, 46, 1, 83, 8, 32, 0, 36, 2, 50, 5, 58, 3, 48, 
    0, 19, 2, 79, 5, 10, 4, 96, 1, 87, 3, 36, 7, 94, 8, 22, 6, 12, 
    0, 55, 5, 52, 2, 77, 6, 67, 3, 88, 1, 56, 7, 57, 8, 76, 4, 71, 
    7, 31, 6, 18, 1, 74, 5, 90, 4, 84, 8, 97, 3,  6, 2, 33, 0, 34
  };
  const int q8253[] = {
    9, 9, // Number of jobs and machines
    1, 95, 8, 20, 2, 58, 0, 10, 6, 61, 5, 12, 7, 10, 3, 33, 4, 36, 
    1, 35, 8, 83, 0, 37, 6, 24, 3, 82, 5, 79, 7, 13, 2, 63, 4, 23, 
    7,  6, 3, 79, 2, 55, 8, 64, 1, 60, 0, 88, 5, 72, 6, 74, 4, 94, 
    5, 14, 8, 23, 2, 49, 1, 20, 6, 67, 7, 68, 0, 65, 4, 54, 3, 80, 
    0, 67, 1,  9, 8, 82, 7,  3, 4, 26, 6, 92, 2, 90, 5, 39, 3, 96, 
    6, 61, 7, 16, 1, 30, 0, 56, 5, 65, 2, 67, 8,  9, 3,  3, 4, 89, 
    0, 33, 3, 38, 7, 14, 5, 35, 8, 54, 4, 55, 2, 35, 1, 59, 6, 75, 
    2, 59, 0, 31, 7, 11, 8, 49, 4, 20, 3, 27, 5, 40, 6, 90, 1, 67, 
    6, 64, 3, 13, 8, 92, 2, 36, 1, 86, 5, 37, 4, 73, 7, 27, 0, 38
  };
  const int q8254[] = {
    9, 9, // Number of jobs and machines
    1, 15, 4, 53, 0, 96, 2, 89, 5, 16, 7, 68, 3, 55, 6, 78, 8,  7, 
    3, 44, 4, 19, 1, 53, 5, 76, 6,  8, 7, 79, 8, 22, 2, 23, 0, 18, 
    4, 94, 8, 43, 6, 91, 3, 55, 7, 98, 5, 43, 0, 61, 1, 89, 2, 10, 
    1, 13, 8, 72, 2, 68, 3, 47, 7, 57, 5, 85, 0,  4, 6, 55, 4, 36, 
    1, 53, 3, 93, 2, 52, 4, 46, 0, 38, 7, 39, 6,  3, 5, 56, 8, 92, 
    3, 29, 2, 94, 0, 57, 8, 68, 5, 31, 7,  2, 6,  4, 1, 61, 4,  8, 
    4, 80, 8, 98, 3, 14, 6, 79, 0, 66, 2, 69, 7, 70, 1, 70, 5,  8, 
    2, 50, 5, 57, 1, 17, 0, 50, 3, 39, 4, 95, 6,  3, 8, 57, 7, 13, 
    7, 62, 1, 82, 5, 22, 8, 23, 4,  1, 6, 52, 2, 31, 0, 19, 3, 24
  };
  const int q8255[] = {
    9, 9, // Number of jobs and machines
    5, 72, 3, 28, 0, 24, 8, 46, 4, 81, 7, 95, 1, 53, 2, 51, 6, 20, 
    8, 10, 1, 78, 0, 11, 6, 66, 7, 96, 3, 12, 2,  9, 4, 44, 5, 99, 
    7, 57, 0, 70, 5, 15, 6, 47, 4, 82, 1, 67, 2, 27, 8, 22, 3, 57, 
    4, 50, 5, 35, 6, 20, 0, 77, 1, 31, 8, 36, 7, 70, 2, 41, 3, 36, 
    6, 91, 8, 49, 7, 49, 2, 55, 1, 95, 5, 32, 3, 38, 0, 72, 4, 27, 
    0, 89, 4, 29, 1, 24, 6, 35, 7, 94, 3, 95, 2,  1, 8, 81, 5, 79, 
    1, 10, 3, 43, 5, 33, 8, 27, 4, 31, 2, 19, 0, 50, 7, 41, 6, 35, 
    1, 93, 2, 49, 7, 24, 6, 53, 0, 94, 4,  5, 5, 45, 8, 89, 3, 78, 
    2, 30, 5, 57, 4, 37, 6, 80, 7, 59, 3, 45, 0, 28, 1, 41, 8, 49
  };
  const int q8256[] = {
    9, 9, // Number of jobs and machines
    4, 85, 3, 48, 0, 92, 2,  6, 6, 68, 7, 70, 5, 17, 8,  4, 1, 45, 
    5, 66, 7, 77, 6, 11, 8, 41, 3, 51, 0, 92, 4, 24, 2, 54, 1, 15, 
    0, 67, 4, 37, 6,  7, 1, 26, 5,  1, 3, 57, 7, 57, 8, 44, 2, 53, 
    5, 30, 1, 43, 2, 81, 7, 80, 0, 68, 6, 44, 8, 31, 3, 10, 4, 69, 
    2, 34, 0, 51, 1, 86, 8, 29, 3, 97, 4, 72, 7, 22, 5, 87, 6, 46, 
    3, 69, 8, 37, 4, 75, 7, 78, 1, 75, 5,  1, 6, 64, 0, 33, 2, 71, 
    4, 28, 1,  2, 7, 18, 3, 17, 8,  1, 2, 85, 5, 48, 0, 74, 6, 46, 
    2, 57, 6, 87, 0, 92, 7, 28, 1, 81, 8, 77, 3, 69, 4, 18, 5, 39, 
    4, 43, 7, 72, 3, 86, 1, 36, 8, 65, 2, 31, 5, 78, 6, 98, 0, 35
  };
  const int q8257[] = {
    9, 9, // Number of jobs and machines
    7, 69, 1, 94, 8, 31, 4, 33, 5, 97, 2, 47, 0, 60, 3, 27, 6, 12, 
    1, 36, 7, 94, 8,  7, 4, 23, 5, 59, 6, 69, 3, 59, 0, 24, 2, 54, 
    4,  4, 0, 40, 3, 79, 2, 35, 1,  3, 8, 75, 7, 67, 5, 41, 6, 13, 
    0, 61, 7, 69, 6, 56, 2, 15, 8, 44, 3, 40, 5, 26, 4, 28, 1, 69, 
    5, 74, 8, 71, 6, 55, 1, 14, 2, 17, 3, 35, 0, 38, 7,  5, 4, 92, 
    8, 83, 3, 42, 5, 53, 7, 28, 1, 57, 4, 38, 6, 47, 0, 92, 2, 27, 
    6, 82, 7, 74, 3, 24, 1, 71, 5, 66, 0, 36, 8, 90, 4, 31, 2, 79, 
    7, 93, 4, 47, 6, 77, 3, 55, 2, 94, 8, 90, 5, 66, 1, 90, 0, 24, 
    8, 59, 6,  1, 1,  8, 5, 23, 2, 36, 7, 85, 3, 55, 4, 36, 0, 67
  };
  const int q8258[] = {
    9, 9, // Number of jobs and machines
    5, 92, 3, 24, 7, 30, 8, 11, 0, 99, 2, 83, 6, 93, 1, 22, 4, 84, 
    3, 58, 0, 80, 8, 80, 6, 13, 2, 83, 7, 41, 5, 36, 4, 67, 1,  8, 
    8, 77, 2, 97, 7, 71, 5, 55, 4,  1, 0, 51, 1, 60, 6, 36, 3, 56, 
    4, 14, 5, 31, 3, 67, 0, 72, 1, 63, 6, 92, 2,  3, 8, 47, 7, 65, 
    8, 86, 2, 92, 0, 39, 1, 14, 5, 58, 6,  4, 7, 68, 3, 88, 4,  9, 
    0, 14, 3,  1, 6, 63, 1, 77, 2, 20, 7, 33, 5, 24, 4, 27, 8, 36, 
    2, 32, 7,  5, 6,  9, 8, 24, 3, 46, 4, 53, 5, 44, 1, 52, 0, 56, 
    5, 63, 6, 56, 7, 40, 1, 24, 3, 51, 0, 80, 8, 87, 4, 18, 2, 20, 
    3, 97, 0, 40, 1, 42, 4, 35, 6, 58, 8, 26, 2, 72, 5, 97, 7, 24
  };
  const int q8259[] = {
    9, 9, // Number of jobs and machines
    3,  9, 8, 66, 0, 74, 6, 23, 5, 48, 7, 58, 2, 19, 4, 10, 1, 80, 
    2, 47, 5, 35, 3, 76, 7,  3, 6, 60, 4, 16, 8, 63, 0, 61, 1, 26, 
    3, 99, 0, 36, 7, 75, 1, 38, 8, 41, 2, 23, 5, 97, 6, 12, 4,  6, 
    6, 54, 4, 28, 3, 68, 8, 92, 1, 40, 5, 78, 2, 65, 0, 13, 7, 34, 
    3, 35, 1,  1, 7, 56, 5, 58, 0, 94, 4, 11, 6, 59, 8, 67, 2, 19, 
    2, 42, 7, 93, 1, 36, 0, 50, 4, 34, 8, 75, 5, 86, 3, 55, 6, 24, 
    7, 53, 0, 95, 5, 51, 4, 63, 2, 77, 1, 97, 8, 76, 3, 26, 6, 71, 
    1, 25, 5, 35, 6, 23, 8, 62, 2, 54, 0, 46, 4, 70, 3, 82, 7, 34, 
    3, 31, 6, 79, 0, 97, 4,  7, 5, 36, 2, 99, 8, 36, 7, 13, 1, 91
  };
  const int q8260[] = {
    9, 9, // Number of jobs and machines
    8, 18, 0, 10, 6, 12, 5, 47, 4, 44, 2, 30, 3, 60, 7, 37, 1, 93, 
    6, 31, 0, 45, 2, 49, 8, 71, 3, 58, 5, 33, 7, 74, 1,  3, 4, 42, 
    6, 94, 3, 33, 2, 19, 8,  9, 4, 59, 5, 93, 7, 99, 1, 65, 0, 33, 
    6, 34, 3, 74, 0, 29, 8,  5, 1, 14, 4,  1, 7, 80, 2,  8, 5, 95, 
    5, 72, 1,  8, 8, 42, 3, 88, 6,  7, 7, 41, 4, 80, 0, 79, 2, 73, 
    8, 84, 7, 42, 0, 41, 1, 57, 5, 47, 2, 47, 3, 70, 6, 50, 4, 73, 
    3, 53, 8, 95, 7, 55, 2, 58, 4, 61, 6, 52, 0, 76, 5, 93, 1, 46, 
    6,  7, 8, 54, 3, 32, 1, 88, 4, 24, 2, 40, 5, 83, 7, 44, 0, 70, 
    5, 78, 3,  3, 4, 54, 6, 69, 8, 29, 0, 18, 1, 57, 7, 75, 2, 28
  };
  const int q8261[] = {
    9, 9, // Number of jobs and machines
    4, 59, 5, 16, 6, 68, 1, 49, 0, 37, 7, 93, 8,  6, 2, 74, 3, 42, 
    2, 77, 4,  2, 7, 47, 6, 51, 5, 99, 0, 20, 8, 59, 3, 97, 1, 68, 
    6, 44, 7, 14, 5, 87, 4, 86, 2, 28, 3, 90, 1, 38, 8, 11, 0, 78, 
    6, 39, 4,  2, 2, 53, 7,  3, 1,  1, 8, 61, 5,  9, 0,  8, 3, 33, 
    7, 24, 2, 40, 8, 35, 4, 62, 1, 62, 0,  3, 3, 98, 5, 42, 6, 13, 
    5, 36, 7, 70, 0, 67, 6, 81, 3, 99, 2, 65, 4, 95, 1, 88, 8, 76, 
    6, 39, 1, 58, 5, 24, 0, 83, 4, 16, 2, 61, 8, 51, 3, 44, 7, 60, 
    3, 78, 0, 73, 4, 54, 8, 92, 6, 78, 2, 48, 1, 72, 5, 10, 7, 76, 
    6, 40, 8, 76, 2, 71, 1, 86, 4, 12, 5, 41, 0,  2, 7, 91, 3, 37
  };
  const int q8262[] = {
    9, 9, // Number of jobs and machines
    2,  2, 5, 63, 8, 19, 3, 57, 7, 52, 1, 80, 0, 16, 4, 58, 6, 80, 
    1, 69, 0, 77, 7, 48, 4, 43, 3, 72, 2, 84, 6, 50, 5, 99, 8, 27, 
    3, 40, 1, 39, 8, 17, 5, 32, 0, 58, 7, 11, 6, 79, 2, 82, 4, 37, 
    1, 31, 2,  3, 8, 74, 4, 75, 0, 30, 7, 33, 5, 92, 6, 90, 3, 85, 
    7, 19, 4, 96, 0, 92, 2, 18, 1, 11, 3, 20, 6, 92, 8, 26, 5, 98, 
    1, 29, 4, 34, 2, 42, 6, 81, 8, 33, 0, 96, 7, 90, 5, 73, 3,  2, 
    7, 97, 6, 18, 4, 38, 5, 68, 1, 33, 3, 37, 2, 50, 8, 58, 0,  2, 
    3,  2, 8, 37, 1,  8, 5,  6, 2, 40, 7, 40, 6,  5, 0, 86, 4, 99, 
    1,  8, 3,  3, 5, 98, 2, 71, 0, 77, 6, 59, 8, 68, 4, 17, 7, 37
  };
  const int q8263[] = {
    9, 9, // Number of jobs and machines
    7, 34, 4, 43, 3, 96, 1, 60, 8, 82, 5, 37, 6, 86, 0, 37, 2, 37, 
    5, 31, 4, 97, 7, 19, 0, 60, 1, 62, 8, 98, 3, 68, 2, 41, 6, 30, 
    3, 14, 5, 19, 8, 76, 1, 79, 0, 73, 7, 15, 6, 23, 2, 65, 4, 73, 
    7, 78, 5, 62, 1, 24, 6, 63, 0, 12, 3, 14, 8, 20, 4, 10, 2, 58, 
    1, 31, 5,  4, 4, 39, 8, 23, 0, 46, 3, 65, 2, 66, 6, 88, 7, 68, 
    1, 68, 0, 74, 2, 47, 7, 96, 3, 94, 8, 15, 4, 17, 5, 28, 6, 88, 
    5, 27, 0, 60, 7, 21, 1, 32, 2, 76, 3, 82, 6, 80, 4, 18, 8, 58, 
    2, 40, 5, 23, 6, 27, 3, 77, 4, 24, 7, 37, 0, 99, 8, 44, 1, 62, 
    1, 90, 3, 43, 8, 19, 6, 51, 2, 99, 0, 93, 4, 76, 5, 56, 7, 68
  };
  const int q8264[] = {
    9, 9, // Number of jobs and machines
    0, 22, 8, 86, 2, 98, 5, 77, 1,  8, 7, 36, 4, 54, 6, 54, 3, 38, 
    5, 91, 2, 85, 3, 47, 1, 18, 8, 59, 6, 76, 0,  9, 4, 87, 7, 85, 
    5, 17, 6, 36, 8,  3, 1, 33, 7, 58, 2, 75, 3, 30, 4, 10, 0, 10, 
    6,  6, 2, 45, 7, 86, 0, 66, 4, 46, 5, 77, 3, 90, 8, 84, 1, 96, 
    5, 75, 7, 47, 3, 39, 2, 53, 4, 36, 8, 49, 6, 81, 0, 73, 1, 20, 
    4, 22, 8, 97, 6, 40, 5,  5, 1, 71, 2, 65, 0, 15, 3,  7, 7, 60, 
    1,  5, 5, 31, 0, 74, 4, 34, 7, 24, 2, 99, 3, 50, 6, 83, 8,  2, 
    1,  8, 5, 18, 0, 96, 6, 72, 3, 83, 2, 16, 7, 82, 4, 80, 8, 11, 
    7, 43, 6, 83, 4, 56, 1, 73, 8, 80, 3, 84, 5, 92, 0, 12, 2, 39
  };
  const int q8265[] = {
    9, 9, // Number of jobs and machines
    0, 39, 5, 52, 8, 13, 7, 54, 1, 72, 6, 25, 3, 47, 2, 22, 4, 57, 
    4, 11, 7, 55, 3, 90, 0, 99, 1, 28, 8,  5, 2,  6, 5, 18, 6, 73, 
    1, 88, 8, 16, 4, 74, 5, 83, 3, 92, 2,  6, 0, 47, 6, 79, 7, 96, 
    1,  7, 8,  1, 0, 20, 3, 79, 5, 74, 4, 59, 2, 69, 6, 81, 7, 64, 
    8, 55, 7, 23, 2, 85, 3, 41, 5, 96, 0,  1, 4, 97, 6, 86, 1, 19, 
    2, 20, 1, 52, 0, 52, 3, 48, 7, 95, 5, 13, 4, 58, 8, 20, 6,  9, 
    5, 11, 1, 89, 0,  6, 2,  1, 4, 71, 3,  3, 8, 59, 7, 63, 6, 54, 
    6, 82, 1, 58, 3, 42, 5, 47, 2, 34, 4, 89, 7, 43, 0, 91, 8, 26, 
    1, 70, 8, 26, 2, 86, 0, 70, 5, 32, 6, 13, 7, 74, 3, 11, 4, 96
  };
  const int q8266[] = {
    9, 9, // Number of jobs and machines
    5, 99, 8, 27, 2, 66, 4, 76, 3, 82, 7, 29, 6, 22, 0, 91, 1, 17, 
    8, 95, 1, 61, 7, 78, 4, 87, 3,  8, 6, 58, 5, 63, 0, 46, 2, 36, 
    0, 73, 2, 97, 6, 59, 3, 44, 4, 54, 8, 64, 5, 25, 1, 17, 7, 45, 
    1, 33, 0, 85, 8,  4, 7, 18, 6, 91, 3, 64, 4, 73, 5, 54, 2, 12, 
    1, 58, 0, 84, 4, 25, 7, 58, 6, 28, 8,  2, 2, 70, 3, 13, 5, 89, 
    6, 90, 7,  8, 8,  6, 3, 59, 5, 56, 4, 35, 2, 54, 1, 31, 0, 19, 
    8, 21, 0, 43, 5, 79, 6, 89, 1, 18, 3, 62, 2,  3, 7, 28, 4, 43, 
    8, 64, 4, 38, 2, 42, 6, 23, 5, 26, 7, 78, 0, 70, 3, 10, 1, 74, 
    2, 58, 3, 16, 5, 66, 8, 35, 7,  4, 6, 85, 0, 13, 4, 80, 1, 39
  };
  const int q8267[] = {
    9, 9, // Number of jobs and machines
    8, 27, 5, 66, 2, 74, 0, 28, 6, 55, 4, 12, 1, 26, 3, 54, 7, 28, 
    4, 48, 5, 31, 2, 73, 8, 74, 6, 76, 0,  9, 3, 98, 7,  2, 1, 35, 
    7, 64, 6, 93, 5, 58, 1, 61, 2, 74, 8, 55, 4,  2, 0, 89, 3, 14, 
    1, 21, 6, 12, 3, 32, 2, 82, 4, 45, 7, 15, 8, 34, 0,  9, 5, 61, 
    6, 43, 5,  3, 3, 30, 0, 99, 2, 75, 1, 77, 7, 70, 4, 78, 8, 61, 
    7, 68, 2, 12, 3, 82, 5, 15, 0, 59, 8, 33, 1, 81, 4, 13, 6, 74, 
    0, 52, 7, 10, 2, 87, 5, 62, 8, 84, 3, 14, 6, 84, 4, 93, 1, 99, 
    5, 40, 4, 50, 8, 10, 7, 71, 1, 35, 2, 70, 6, 28, 0, 25, 3, 72, 
    8, 21, 2, 14, 5,  4, 4, 57, 7, 62, 0, 44, 1, 91, 3,  2, 6, 38
  };
  const int q8268[] = {
    9, 9, // Number of jobs and machines
    5, 32, 4, 64, 6, 30, 3, 27, 1, 26, 2, 70, 0, 73, 8, 83, 7, 97, 
    7, 41, 1, 61, 0, 99, 6, 82, 2, 95, 4, 53, 8, 27, 3, 59, 5, 98, 
    3,  2, 4, 20, 2, 25, 0, 73, 6, 53, 5, 72, 8, 68, 1, 55, 7, 72, 
    1, 28, 6, 68, 5, 18, 3, 60, 0, 92, 8, 13, 7, 12, 2, 66, 4, 40, 
    7, 68, 5, 15, 0, 88, 4, 83, 3, 33, 1, 13, 8, 95, 6, 32, 2, 74, 
    1,  8, 8, 53, 0,  5, 5, 92, 4, 70, 7, 20, 3, 53, 2, 70, 6, 74, 
    2, 74, 4, 66, 7, 46, 1, 62, 8, 41, 5,  9, 0, 50, 3, 61, 6,  3, 
    5, 98, 7, 10, 0, 91, 2, 41, 1, 92, 8, 49, 3, 95, 6,  5, 4, 45, 
    1, 75, 7, 37, 3, 77, 6, 32, 4, 73, 0, 34, 2,  6, 8, 76, 5, 44
  };
  const int q8269[] = {
    9, 9, // Number of jobs and machines
    8, 76, 2, 25, 7, 22, 4,  5, 6, 21, 3, 57, 0, 54, 1,  5, 5, 39, 
    6, 67, 5, 69, 7, 46, 0, 86, 3, 67, 1, 88, 2, 18, 8, 51, 4, 66, 
    1, 29, 2, 42, 3, 28, 0, 55, 8, 30, 5, 86, 6, 30, 7, 26, 4, 41, 
    3,  1, 1, 47, 8, 96, 2, 38, 5, 29, 7, 48, 4, 88, 0, 15, 6, 81, 
    1,  7, 8, 33, 2, 22, 3, 66, 5, 69, 4, 47, 7, 38, 6, 43, 0, 51, 
    5, 58, 8, 36, 6,  1, 0, 33, 3, 18, 2, 89, 7, 77, 4, 49, 1,  1, 
    7, 14, 6, 53, 1, 80, 3, 99, 0,  3, 2, 22, 5, 25, 4, 33, 8, 94, 
    5, 72, 6, 89, 7, 13, 0, 97, 8, 93, 1, 13, 4,  2, 2, 21, 3, 53, 
    7, 13, 1, 19, 6, 31, 2, 62, 3, 18, 8, 26, 5, 47, 4, 85, 0,  6
  };
  const int q8270[] = {
    9, 9, // Number of jobs and machines
    5, 34, 4, 37, 7, 36, 1,  3, 6, 83, 3, 78, 8, 45, 2, 49, 0, 42, 
    1,  2, 3, 52, 4, 92, 6, 24, 2, 54, 7, 50, 8, 93, 0, 24, 5, 96, 
    1, 12, 8, 80, 2, 84, 6, 69, 7, 17, 4, 74, 5, 38, 3, 92, 0, 85, 
    6, 44, 1, 29, 2, 49, 0, 31, 3, 56, 7, 39, 4, 35, 8, 50, 5, 70, 
    4, 29, 3, 42, 1, 89, 8, 60, 5, 49, 0, 79, 2, 32, 6, 41, 7, 98, 
    1, 68, 3, 19, 4, 42, 0,  6, 5, 36, 6, 38, 2, 74, 8, 10, 7, 29, 
    1, 55, 7, 89, 5, 77, 0, 79, 3, 58, 6, 57, 8, 79, 4, 83, 2, 22, 
    4, 78, 8, 60, 2, 93, 3, 63, 6, 91, 0,  1, 7, 52, 1, 48, 5,  5, 
    6, 42, 8, 13, 3,  5, 1,  5, 4, 16, 7, 65, 2, 54, 5, 45, 0,  7
  };
  const int q8271[] = {
    9, 9, // Number of jobs and machines
    7, 59, 8, 86, 5, 33, 0, 25, 6, 74, 1, 73, 2, 26, 4,  4, 3, 22, 
    7, 23, 2, 57, 0,  6, 4, 81, 3, 74, 1, 82, 5, 85, 8, 51, 6, 24, 
    5, 38, 6, 95, 1,  8, 2, 61, 7, 75, 4, 65, 3,  4, 8, 39, 0, 52, 
    2, 36, 0, 54, 5, 53, 7, 61, 4, 57, 1, 13, 6, 40, 8, 23, 3, 20, 
    8, 17, 7, 99, 1, 94, 5, 34, 4, 63, 2, 32, 3, 15, 6, 62, 0, 82, 
    3, 93, 4,  3, 6, 48, 2, 90, 0, 97, 7, 65, 8, 28, 1, 69, 5, 14, 
    7, 32, 4, 76, 6, 98, 5, 52, 3, 35, 0,  3, 1, 98, 2, 88, 8, 60, 
    0, 49, 2, 53, 8, 82, 6, 56, 3, 60, 4, 98, 7, 67, 5, 56, 1, 72, 
    7,  8, 2, 86, 1, 68, 4,  8, 0, 53, 5, 82, 8, 93, 6, 66, 3, 52
  };
  const int q8272[] = {
    9, 9, // Number of jobs and machines
    3, 53, 8, 22, 6, 55, 1, 79, 5, 43, 2, 64, 0, 22, 7,  7, 4, 24, 
    0, 38, 8, 32, 3, 10, 4, 81, 6, 51, 7, 42, 5, 69, 1, 41, 2, 39, 
    2, 45, 0, 87, 3, 21, 6, 39, 4, 43, 5, 30, 7, 82, 8, 83, 1,  1, 
    7, 22, 0, 80, 2, 11, 4, 42, 3, 59, 5, 96, 6, 20, 8,  3, 1, 31, 
    4, 37, 2, 39, 7,  5, 3, 28, 1, 97, 6, 59, 0, 98, 5, 41, 8,  6, 
    5, 14, 4, 96, 3, 13, 1, 59, 0, 49, 2,  3, 8, 19, 7, 22, 6, 62, 
    3, 21, 2, 26, 6, 46, 4, 85, 7, 27, 5,  8, 8, 74, 0, 77, 1, 21, 
    8, 35, 5, 88, 4, 42, 1, 18, 3, 81, 0, 40, 6, 36, 7, 19, 2, 35, 
    3, 67, 5, 48, 8,  7, 6, 28, 0, 18, 7, 26, 4, 18, 1, 56, 2,  9
  };
  const int q8273[] = {
    9, 9, // Number of jobs and machines
    2, 78, 4, 67, 8, 78, 1, 92, 0, 14, 7, 13, 3, 23, 6, 10, 5, 89, 
    8, 26, 7, 63, 1, 36, 5, 40, 0, 64, 3, 99, 6, 57, 2, 88, 4, 84, 
    7, 50, 4, 57, 3, 68, 1, 21, 5, 20, 6, 37, 8, 63, 2,  1, 0, 72, 
    6, 99, 4, 61, 0, 51, 1,  2, 7, 52, 5, 42, 3, 15, 2, 32, 8, 57, 
    2, 76, 5, 10, 6, 90, 0, 72, 3, 67, 1, 75, 8, 98, 7, 19, 4, 76, 
    7, 37, 1,  1, 2, 57, 8, 22, 3, 88, 5, 89, 4, 92, 0, 53, 6, 54, 
    1,  1, 5,  9, 6, 38, 3, 86, 0, 93, 7, 23, 4, 16, 2, 38, 8, 60, 
    0, 94, 1, 76, 6,  3, 4, 27, 2, 44, 5, 13, 8, 66, 3, 18, 7, 86, 
    1, 13, 0, 74, 5, 74, 4,  5, 6, 78, 2, 40, 7, 31, 3,  6, 8, 43
  };
  const int q8274[] = {
    9, 9, // Number of jobs and machines
    3, 61, 7, 94, 8, 36, 0, 13, 2, 63, 5, 79, 1,  3, 6, 53, 4, 92, 
    1, 13, 6, 22, 8, 84, 3, 20, 4, 89, 0, 41, 2, 75, 5, 18, 7, 67, 
    5, 88, 2, 59, 3, 69, 6, 54, 4, 46, 7, 17, 0, 28, 8, 43, 1, 29, 
    2, 11, 1, 39, 6, 29, 5, 56, 8, 24, 3, 15, 7, 54, 4, 77, 0,  1, 
    2, 13, 7, 29, 5, 69, 1,  7, 0, 50, 6, 61, 4, 94, 8, 42, 3, 95, 
    2, 19, 5, 86, 7, 13, 1, 69, 4,  2, 0, 40, 3, 62, 8, 43, 6, 99, 
    8, 12, 1, 85, 6, 63, 5, 78, 2, 82, 7, 66, 4, 59, 3, 72, 0, 45, 
    1, 39, 7, 90, 0, 15, 5, 66, 2, 68, 6, 14, 4, 13, 3, 49, 8, 93, 
    6, 11, 8, 71, 1,  2, 4,  8, 7, 98, 2, 31, 3, 82, 0, 47, 5,  1
  };
  const int q8275[] = {
    9, 9, // Number of jobs and machines
    7,  7, 3, 38, 6, 65, 2, 51, 4, 70, 1, 17, 8, 30, 5, 76, 0, 45, 
    2,  1, 3, 28, 1, 10, 0, 90, 5,  3, 7, 39, 8, 52, 4, 96, 6, 84, 
    2, 75, 4, 52, 7, 57, 3, 62, 6, 53, 0, 23, 1, 18, 8, 78, 5, 53, 
    4, 37, 3, 38, 5,  3, 6, 80, 7,  2, 8, 34, 0, 38, 2, 21, 1, 18, 
    4, 93, 2, 63, 6, 72, 3, 63, 0, 16, 8,  3, 1, 34, 5, 76, 7, 30, 
    0, 27, 7, 81, 3,  5, 4, 67, 2, 92, 1, 85, 8, 66, 5, 57, 6, 68, 
    8, 12, 0, 49, 2, 64, 5, 22, 1, 62, 3,  5, 4, 28, 7, 87, 6, 91, 
    8, 38, 7, 55, 2, 31, 4, 15, 1, 13, 6, 33, 0,  7, 5, 92, 3, 60, 
    8, 85, 5, 45, 3, 59, 0, 54, 4, 55, 2, 49, 6, 87, 1, 41, 7, 99
  };
  const int q8276[] = {
    9, 9, // Number of jobs and machines
    5, 33, 1, 45, 3, 40, 6, 21, 8, 42, 4, 54, 2, 17, 7, 68, 0, 31, 
    5, 65, 0, 68, 8, 95, 3, 47, 7, 55, 2, 29, 6, 85, 4, 17, 1, 18, 
    8, 50, 6, 75, 5, 70, 2, 20, 4,  7, 3,  9, 1, 72, 0, 57, 7, 90, 
    2, 82, 4, 29, 1, 14, 8, 11, 7, 81, 3, 17, 0, 92, 6, 33, 5, 24, 
    5, 92, 2, 72, 7,  4, 6,  8, 8, 72, 3, 82, 1, 98, 0, 77, 4, 91, 
    5, 47, 8, 32, 7, 46, 2, 69, 0, 62, 6, 28, 1, 12, 4, 97, 3, 56, 
    2, 28, 3, 16, 7, 62, 4, 27, 1, 30, 5, 50, 8, 91, 0, 30, 6, 42, 
    6, 57, 0, 28, 3,  4, 2, 96, 8, 54, 1, 20, 7, 50, 4, 50, 5, 77, 
    3, 50, 4, 95, 0,  8, 8,  3, 7, 80, 5, 64, 1, 19, 6, 44, 2, 74
  };
  const int q8277[] = {
    9, 9, // Number of jobs and machines
    8, 89, 5, 46, 7,  9, 0, 40, 4, 32, 6, 88, 2, 92, 3, 98, 1, 44, 
    4, 43, 3, 36, 6, 90, 2, 19, 7, 88, 8, 13, 1, 70, 5, 88, 0, 89, 
    1, 51, 3, 94, 4, 90, 2, 35, 8, 39, 0, 68, 5, 88, 6, 17, 7,  6, 
    5, 52, 2, 48, 1, 16, 7, 45, 0, 23, 6, 56, 3, 12, 8, 41, 4, 43, 
    5, 20, 0, 73, 3, 41, 4, 70, 7, 63, 2, 46, 1,  3, 8, 52, 6, 23, 
    0, 87, 7, 50, 3, 65, 5, 12, 1, 89, 8,  5, 4, 21, 2, 56, 6, 57, 
    7, 19, 5, 63, 1, 49, 2, 87, 3, 60, 8, 64, 0, 63, 6, 45, 4, 97, 
    4,  8, 2, 86, 0, 97, 3, 51, 6,  9, 7, 78, 8, 71, 5, 38, 1, 13, 
    2, 34, 6,  8, 1, 63, 5, 86, 0, 73, 3, 36, 7, 17, 4, 20, 8, 35
  };
  const int q8278[] = {
    9, 9, // Number of jobs and machines
    5, 64, 1, 45, 4, 53, 6, 40, 3, 23, 7, 48, 0, 56, 2, 46, 8, 12, 
    5, 11, 1, 82, 7, 85, 4, 38, 8, 85, 0, 91, 2, 37, 6, 84, 3, 18, 
    7, 20, 2, 63, 0, 86, 4, 71, 3, 88, 8, 31, 5, 71, 6, 76, 1, 66, 
    1, 44, 8, 86, 3, 95, 2, 87, 5, 55, 4, 21, 7, 85, 6, 64, 0, 44, 
    0, 86, 2, 41, 5, 58, 4, 91, 3,  1, 8, 30, 1, 58, 6, 86, 7,  7, 
    4, 58, 0, 67, 5, 19, 6, 64, 3, 71, 8, 60, 2, 44, 1, 21, 7, 28, 
    1, 68, 4, 26, 7, 18, 6, 36, 3, 77, 8, 75, 0, 20, 2, 32, 5, 86, 
    3, 48, 2,  3, 7, 48, 4, 57, 6, 27, 8, 31, 5, 25, 0, 55, 1, 16, 
    5, 47, 6, 19, 8, 32, 1, 12, 7, 14, 2, 27, 0,  8, 4, 48, 3, 76
  };
  const int q8279[] = {
    9, 9, // Number of jobs and machines
    2, 19, 6, 40, 4, 99, 8, 55, 1, 31, 3, 79, 0, 12, 5, 54, 7, 66, 
    4, 16, 6, 98, 7, 90, 2, 18, 1, 79, 0, 82, 8, 70, 5, 14, 3, 52, 
    6, 55, 8, 70, 3, 27, 1, 55, 2, 68, 0, 28, 7, 28, 4, 96, 5, 96, 
    8, 17, 4, 99, 1, 62, 0, 38, 2, 51, 7, 26, 6, 43, 3, 30, 5, 44, 
    4, 70, 3, 97, 6, 40, 0, 53, 1, 43, 2, 17, 8, 34, 5, 73, 7, 55, 
    7, 69, 1, 50, 2, 74, 4, 65, 3, 14, 5, 37, 8, 88, 0, 61, 6, 76, 
    0, 60, 6, 60, 7, 60, 1, 86, 8,  4, 3, 28, 2,  9, 5, 52, 4, 56, 
    5, 11, 1, 41, 8, 72, 2, 29, 3, 62, 0, 19, 4, 65, 7, 84, 6, 98, 
    6, 31, 5, 77, 2, 93, 7, 64, 8, 97, 0, 69, 4, 14, 1, 96, 3, 35
  };
  const int q8280[] = {
    9, 9, // Number of jobs and machines
    4, 97, 1, 40, 0, 36, 5, 70, 3, 36, 6, 94, 2, 11, 8, 33, 7, 65, 
    8, 69, 1, 85, 3, 27, 6, 96, 4, 72, 7,  4, 5, 14, 2, 12, 0, 73, 
    5,  1, 1, 80, 8, 75, 7, 56, 6, 14, 2, 80, 4, 50, 3, 49, 0, 28, 
    3,  1, 7, 55, 0, 77, 5, 38, 6, 46, 4, 46, 2, 45, 8, 72, 1, 31, 
    4, 78, 8, 41, 0, 48, 5, 28, 1,  6, 3, 17, 7, 83, 2, 56, 6, 15, 
    3, 33, 6, 36, 1, 12, 4, 28, 0, 72, 5, 63, 2, 39, 7, 61, 8, 34, 
    4, 73, 0, 46, 2, 76, 3, 58, 6, 94, 5, 45, 7,  9, 8, 21, 1, 31, 
    7, 28, 3, 97, 0, 77, 1, 63, 4, 97, 6, 17, 5, 88, 2, 27, 8, 31, 
    4, 90, 5, 27, 7, 53, 2, 12, 0, 81, 6, 80, 3, 74, 1, 67, 8, 19
  };
  const int q8281[] = {
    9, 9, // Number of jobs and machines
    7, 69, 5, 91, 4, 39, 6, 48, 0, 96, 8, 48, 1, 81, 3, 80, 2, 88, 
    8, 44, 3, 60, 6, 11, 7, 72, 0, 68, 4, 21, 2, 88, 5, 96, 1, 14, 
    1, 32, 0, 56, 2, 32, 4, 19, 3, 45, 5, 94, 6, 84, 8, 24, 7, 27, 
    1, 85, 4, 19, 3, 73, 5, 26, 7, 90, 2, 75, 6, 16, 0, 40, 8, 81, 
    4, 40, 0, 35, 3, 84, 2, 91, 5, 69, 7, 62, 6, 53, 1, 59, 8, 88, 
    7, 13, 3, 63, 5, 92, 8, 30, 2, 87, 4, 83, 6, 15, 0, 22, 1, 17, 
    2, 44, 8, 54, 1, 58, 7,  8, 6, 39, 3, 94, 0, 75, 4, 43, 5, 63, 
    0, 28, 7, 98, 8, 54, 1, 64, 2, 15, 4, 46, 6, 42, 5, 84, 3, 33, 
    4, 67, 7, 71, 2, 51, 1, 90, 5,  2, 3, 86, 6, 48, 8,  9, 0, 69
  };
  const int q8282[] = {
    9, 9, // Number of jobs and machines
    7, 51, 5, 93, 6, 53, 1, 20, 2, 79, 8,  7, 4, 58, 0, 72, 3, 73, 
    0, 43, 8, 22, 7, 86, 1, 79, 3,  9, 5, 85, 4, 21, 2, 59, 6, 30, 
    1, 26, 0,  5, 2, 43, 8, 67, 7, 23, 6, 84, 5, 30, 4, 32, 3, 49, 
    3, 58, 0, 55, 5, 62, 8, 92, 7, 63, 4, 94, 6, 91, 2, 92, 1, 28, 
    4, 75, 5, 35, 3, 45, 1, 88, 8, 88, 2, 80, 7,  5, 0, 45, 6, 44, 
    8, 65, 1, 84, 6,  5, 3, 47, 0, 99, 7, 85, 2, 94, 4, 29, 5, 66, 
    2, 52, 3, 41, 5, 30, 0, 58, 1,  8, 4, 96, 8, 68, 6, 31, 7, 42, 
    1, 65, 0, 58, 7, 57, 5, 78, 3, 25, 8,  2, 6, 11, 4, 18, 2, 87, 
    8, 35, 5, 46, 2, 55, 1,  2, 7,  8, 3, 85, 4, 46, 0, 58, 6, 51
  };
  const int q8283[] = {
    9, 9, // Number of jobs and machines
    8, 14, 7, 53, 0, 63, 6, 13, 4, 28, 3, 57, 5, 61, 1, 74, 2,  9, 
    7, 93, 6,  3, 3,  1, 5, 60, 4, 47, 1, 32, 2, 59, 0, 51, 8, 89, 
    8, 14, 5, 67, 1, 37, 4, 29, 7, 91, 3, 24, 0, 81, 2, 99, 6, 54, 
    7, 74, 4, 81, 5,  9, 8, 89, 1, 52, 6,  2, 3, 85, 2, 24, 0, 59, 
    3, 90, 2, 77, 0, 11, 6, 36, 8, 87, 5, 78, 7, 65, 4, 60, 1, 93, 
    4, 88, 0, 68, 5, 10, 3, 38, 1, 20, 8, 96, 2, 37, 6, 86, 7,  2, 
    4, 89, 6, 28, 8, 70, 0, 68, 2, 64, 7, 58, 3, 69, 5, 38, 1, 41, 
    0, 68, 4, 84, 2, 32, 1, 11, 8,  1, 3, 54, 6, 90, 5, 73, 7, 59, 
    4, 61, 3, 49, 8, 54, 7, 86, 2, 33, 1, 54, 5, 59, 0,  9, 6,  5
  };
  const int q8284[] = {
    9, 9, // Number of jobs and machines
    0, 89, 6, 35, 4, 40, 1, 86, 8, 90, 7, 78, 2, 55, 5, 10, 3, 49, 
    0, 19, 2, 87, 4, 92, 8, 55, 3, 98, 6, 29, 5, 16, 1, 87, 7, 93, 
    0, 34, 6, 18, 2, 91, 4, 19, 8, 32, 7, 19, 5, 92, 3, 96, 1, 16, 
    4, 93, 6, 23, 7, 33, 1, 38, 5, 33, 3,  5, 0, 82, 2, 53, 8, 82, 
    2, 45, 5, 65, 7, 52, 8, 68, 4, 91, 0, 40, 1, 45, 6,  6, 3, 45, 
    1, 34, 5, 58, 3, 35, 0, 46, 6, 93, 8, 97, 4, 20, 2, 20, 7, 78, 
    8, 18, 2, 51, 0, 87, 1, 48, 4, 39, 5, 89, 3, 94, 7, 52, 6, 72, 
    8,  9, 3, 91, 5, 44, 6, 90, 4, 69, 1, 98, 7, 16, 0, 32, 2, 67, 
    8, 75, 3, 32, 4, 93, 2, 58, 0, 52, 6, 88, 7, 90, 1, 48, 5,  2
  };
  const int q8285[] = {
    9, 9, // Number of jobs and machines
    4, 99, 2, 83, 6, 52, 8, 37, 7, 55, 3, 66, 5, 48, 0, 40, 1, 53, 
    1, 25, 5, 11, 3, 68, 7, 19, 4, 65, 0, 18, 6, 22, 8, 19, 2, 24, 
    8, 90, 6, 18, 2, 84, 0, 48, 4, 93, 7, 98, 3, 26, 1, 36, 5, 73, 
    4, 25, 3, 44, 1, 75, 6, 56, 2, 36, 7,  7, 0, 83, 8, 80, 5, 46, 
    2, 73, 5, 94, 1, 83, 4, 67, 3, 78, 7,  5, 0, 14, 8, 10, 6, 79, 
    6, 58, 7, 22, 3, 45, 8, 12, 2,  3, 0, 47, 4, 66, 5, 40, 1, 49, 
    2, 57, 3,  7, 6, 66, 1, 51, 8, 75, 7, 54, 0, 19, 4, 55, 5, 69, 
    4, 46, 1, 83, 8, 87, 6, 84, 7, 86, 3,  3, 2, 72, 5, 59, 0, 32, 
    6, 93, 2,  4, 5,  1, 3, 65, 4, 30, 8, 27, 1, 36, 7, 67, 0, 66
  };
  const int q8286[] = {
    9, 9, // Number of jobs and machines
    5, 71, 8, 73, 6, 12, 2, 62, 0, 95, 3, 19, 1, 12, 7, 32, 4, 58, 
    5, 72, 8, 84, 0,  7, 4, 45, 6, 32, 2, 19, 1, 30, 3, 84, 7, 40, 
    6, 12, 1, 46, 7, 27, 3,  9, 5, 68, 0, 64, 8, 16, 4, 82, 2, 85, 
    0, 49, 1, 39, 4, 36, 8, 96, 2, 17, 6, 69, 3, 11, 5, 43, 7, 92, 
    5, 53, 1, 70, 8, 17, 7, 41, 4,  3, 3, 68, 6, 95, 0, 63, 2, 66, 
    8, 37, 6, 33, 5, 99, 7, 81, 3, 81, 0, 69, 2, 24, 1, 49, 4, 74, 
    1, 58, 0, 17, 8, 39, 5, 34, 7, 54, 2, 75, 4,  2, 6, 83, 3, 77, 
    7, 38, 5, 56, 3, 61, 2, 33, 8, 70, 0,  8, 6, 87, 1, 69, 4, 57, 
    3, 32, 0, 68, 2, 60, 6, 27, 1, 94, 7, 54, 8,  6, 5, 53, 4, 15
  };
  const int q8287[] = {
    9, 9, // Number of jobs and machines
    5, 14, 6, 36, 0, 69, 2, 16, 7, 14, 4,  1, 1, 55, 3, 53, 8, 27, 
    4, 68, 3, 61, 8, 12, 1, 18, 7, 11, 0, 91, 2, 11, 5, 48, 6, 45, 
    0, 99, 7, 22, 4, 29, 6,  3, 8, 77, 2, 28, 5, 64, 3, 20, 1, 55, 
    4, 18, 2, 30, 5, 92, 1, 76, 3, 71, 7, 63, 8, 86, 6, 93, 0, 37, 
    8, 90, 6, 75, 5, 74, 3, 93, 4, 25, 2, 22, 1, 59, 0, 26, 7, 21, 
    3, 45, 1, 19, 0, 43, 4, 89, 7, 81, 8, 79, 2, 55, 5, 83, 6, 71, 
    0, 99, 3,  6, 2, 87, 4,  3, 6,  7, 8, 84, 5, 83, 7, 56, 1,  6, 
    1, 22, 0, 15, 7,  5, 4, 36, 2, 40, 8, 35, 6, 53, 3,  1, 5, 61, 
    5, 89, 8,  6, 6, 96, 1, 85, 0, 59, 7, 11, 3, 23, 2, 19, 4, 52
  };
  const int q8288[] = {
    9, 9, // Number of jobs and machines
    0, 17, 6, 89, 3, 45, 5, 21, 2, 30, 8, 92, 7, 27, 4, 90, 1, 17, 
    0, 54, 7, 73, 5, 94, 3, 63, 4, 84, 8, 44, 2, 77, 1,  2, 6,  6, 
    0, 43, 2, 29, 8, 38, 6, 21, 4, 97, 1, 77, 7, 73, 5, 15, 3, 23, 
    1, 19, 5, 15, 3, 80, 6, 93, 0, 25, 8, 54, 7, 20, 4, 87, 2, 36, 
    3, 63, 0, 17, 4, 79, 7, 37, 5, 60, 6, 28, 1, 20, 8, 24, 2, 39, 
    1,  9, 2, 58, 6, 93, 7, 95, 4, 43, 5, 83, 0, 79, 8, 22, 3, 63, 
    7,  9, 2, 55, 4, 29, 1, 30, 6, 17, 0, 15, 5, 32, 8,  6, 3,  4, 
    8, 58, 6, 46, 7, 88, 2, 82, 3, 36, 0, 13, 5, 62, 4, 61, 1, 54, 
    5,  3, 7, 92, 6, 72, 0, 66, 4, 48, 8,  7, 1, 18, 2, 10, 3, 38
  };
  const int q8289[] = {
    9, 9, // Number of jobs and machines
    8, 73, 3, 72, 6,  6, 5, 15, 2, 15, 7, 83, 1, 20, 0, 85, 4,  3, 
    6,  7, 0, 62, 7, 57, 1, 48, 5, 89, 3, 27, 8, 12, 2, 88, 4, 81, 
    7, 72, 6,  3, 0, 68, 2, 47, 3, 32, 1, 87, 8, 76, 5, 34, 4, 30, 
    6, 93, 3, 61, 5, 41, 8, 66, 2, 41, 1, 91, 0, 22, 7, 37, 4, 61, 
    7, 53, 3, 34, 4, 67, 2, 88, 8, 20, 0, 98, 6, 56, 5, 31, 1, 77, 
    6, 70, 7,  5, 0, 76, 4, 63, 8,  9, 5, 62, 2, 83, 1, 87, 3, 53, 
    7, 23, 6, 20, 5,  7, 3, 23, 8, 59, 1, 47, 2, 85, 4, 40, 0, 78, 
    6, 16, 2,  1, 3,  3, 8, 37, 5, 27, 0, 59, 7, 53, 4, 84, 1, 81, 
    5,  7, 8, 68, 2, 64, 6, 69, 7, 99, 1, 53, 4, 85, 0, 98, 3, 27
  };
  const int q8290[] = {
    9, 9, // Number of jobs and machines
    0, 35, 2, 52, 5, 59, 7, 85, 4, 36, 1,  2, 3, 70, 6, 33, 8, 94, 
    3,  8, 0, 48, 2, 45, 7, 65, 5, 41, 4, 47, 6, 41, 8, 68, 1, 52, 
    8, 45, 1, 50, 0, 17, 7, 96, 5, 99, 3, 71, 2, 56, 6, 24, 4, 43, 
    5, 37, 8, 65, 1, 17, 2,  9, 4, 20, 0, 95, 6,  8, 7, 74, 3, 47, 
    6, 58, 2, 20, 1, 58, 8, 43, 5, 26, 4, 46, 7, 29, 0, 22, 3, 54, 
    6, 49, 5,  9, 2, 15, 4, 49, 1, 21, 0, 85, 8, 48, 3,  4, 7, 42, 
    1, 79, 0, 22, 5, 89, 6, 58, 3, 85, 4, 38, 2, 95, 8, 13, 7, 93, 
    3, 97, 0, 40, 8, 88, 5, 52, 7, 39, 6, 76, 2, 18, 1, 27, 4, 86, 
    3, 81, 1, 30, 4,  2, 2, 18, 7, 97, 8, 33, 0, 51, 5, 41, 6, 33
  };
  const int q8291[] = {
    9, 9, // Number of jobs and machines
    2, 58, 1, 90, 4, 48, 8, 10, 7,  4, 0, 88, 3, 92, 5, 19, 6, 14, 
    0, 10, 3, 22, 1, 90, 2, 94, 8, 67, 6, 91, 4, 11, 5, 16, 7, 99, 
    2, 74, 3, 35, 1, 40, 6, 73, 4,  4, 7, 94, 0, 33, 8, 60, 5, 12, 
    3, 46, 4, 86, 8, 28, 2,  6, 0,  5, 5, 77, 7, 16, 6, 54, 1, 71, 
    6, 75, 2, 47, 8, 79, 3, 14, 4, 25, 7, 93, 0, 51, 1, 45, 5, 90, 
    8,  4, 2, 40, 6, 72, 0, 36, 4, 95, 5, 77, 7, 65, 3, 41, 1, 30, 
    3, 39, 5, 67, 7, 52, 6, 52, 0, 88, 8, 32, 4, 19, 2,  5, 1, 97, 
    4, 44, 8, 48, 2, 70, 1, 78, 7, 34, 5, 24, 3, 24, 0, 29, 6, 18, 
    4, 36, 0, 64, 6, 73, 5, 46, 2, 96, 1, 97, 7, 78, 3, 12, 8, 48
  };
  const int q8292[] = {
    9, 9, // Number of jobs and machines
    6, 43, 3, 94, 1, 98, 4, 80, 5, 81, 2, 31, 0, 76, 7,  2, 8, 47, 
    7, 62, 8, 42, 3, 37, 4, 65, 5, 92, 0, 79, 1, 67, 6, 20, 2, 78, 
    7, 46, 1, 76, 5, 59, 2, 95, 6, 29, 4, 98, 3, 30, 8, 97, 0, 52, 
    2, 12, 3, 36, 5, 24, 1, 61, 6, 89, 7, 86, 0, 37, 8, 57, 4, 40, 
    5,  3, 8,  2, 0, 30, 7, 52, 2,  9, 6, 64, 1, 13, 3, 14, 4,  9, 
    1, 47, 2, 54, 8, 72, 6, 15, 0, 96, 4, 96, 5, 55, 3, 12, 7, 19, 
    7, 76, 3,  1, 0, 30, 5, 56, 6, 45, 4, 78, 1, 42, 2, 96, 8, 62, 
    3, 41, 7, 88, 0, 82, 6, 94, 8, 89, 1, 69, 5,  7, 2, 17, 4, 89, 
    3, 34, 6, 69, 5, 63, 1, 57, 4, 57, 7, 51, 8, 20, 2, 54, 0, 29
  };
  const int q8293[] = {
    9, 9, // Number of jobs and machines
    3,  2, 0, 27, 2, 60, 5, 62, 7, 98, 1, 10, 6, 78, 8, 56, 4, 12, 
    7, 40, 3, 92, 2, 64, 6, 70, 1, 86, 8, 56, 4, 25, 0, 66, 5, 34, 
    6, 14, 1, 78, 3, 58, 5,  8, 7, 82, 4, 96, 0, 35, 8, 73, 2, 36, 
    1, 90, 3, 56, 4, 73, 8, 21, 7,  9, 5, 41, 0, 80, 2, 13, 6, 71, 
    8, 12, 2, 61, 3, 51, 4, 63, 5, 88, 7, 15, 0, 19, 1, 22, 6,  2, 
    3,  1, 1, 58, 7,  7, 6, 45, 0, 34, 4, 28, 8, 30, 5,  3, 2, 57, 
    0, 61, 4, 67, 2, 71, 7, 48, 6, 77, 5, 18, 1, 83, 3, 91, 8,  6, 
    1, 56, 3, 58, 5, 61, 2, 46, 8, 12, 6, 12, 4, 93, 0, 48, 7, 90, 
    0, 43, 4, 34, 1, 87, 5, 23, 8, 58, 7, 96, 6, 52, 2, 17, 3, 29
  };
  const int q8294[] = {
    9, 9, // Number of jobs and machines
    3, 26, 1, 64, 7, 32, 5, 97, 2, 62, 8, 91, 6, 55, 4, 14, 0, 29, 
    1, 32, 3, 50, 5, 91, 8, 15, 2, 27, 6, 15, 7, 71, 0, 22, 4, 10, 
    0, 80, 8, 32, 1, 99, 7, 29, 3, 86, 5, 81, 4, 13, 6,  9, 2, 13, 
    0, 48, 1, 22, 5, 99, 2, 67, 8, 32, 4, 75, 3, 22, 7, 85, 6, 21, 
    1, 83, 4, 84, 8, 48, 2, 27, 6, 66, 0, 12, 3, 21, 7, 84, 5, 59, 
    5, 61, 2, 95, 1,  7, 4, 68, 0, 61, 3, 87, 7, 93, 6, 65, 8,  8, 
    8, 58, 0, 30, 7, 59, 4, 99, 3, 34, 5, 46, 6, 97, 2, 34, 1, 55, 
    2, 84, 0, 43, 3, 25, 8, 98, 1, 81, 7, 58, 5, 67, 4, 75, 6, 71, 
    0, 52, 1, 89, 7, 24, 3, 37, 4, 93, 5, 42, 2, 29, 8, 14, 6, 92
  };
  const int q8295[] = {
    9, 9, // Number of jobs and machines
    7, 69, 1, 97, 3,  1, 2, 92, 6, 21, 0, 20, 5, 90, 8, 40, 4, 41, 
    8, 50, 2, 55, 5, 64, 4, 91, 6, 26, 7, 31, 0, 79, 1, 81, 3, 52, 
    2, 17, 1, 66, 6, 21, 0, 25, 7, 23, 5,  6, 8, 94, 4, 53, 3,  9, 
    1,  1, 2, 96, 0, 84, 3, 72, 6, 68, 4, 54, 5,  1, 8, 85, 7, 61, 
    3, 82, 4, 48, 1, 73, 0, 84, 6, 30, 8, 28, 7, 84, 5, 97, 2, 23, 
    7, 16, 8, 94, 6,  9, 4, 98, 3, 95, 1, 94, 2, 25, 0, 51, 5, 79, 
    0, 51, 7, 20, 8, 59, 5, 68, 3, 55, 1, 65, 6, 61, 4, 54, 2, 85, 
    7, 86, 8, 80, 5, 17, 2, 86, 3,  5, 0, 87, 6, 61, 4,  6, 1, 51, 
    6, 60, 5, 72, 4, 16, 1, 10, 3, 94, 2, 48, 0,  9, 8, 98, 7, 74
  };
  const int q8296[] = {
    9, 9, // Number of jobs and machines
    5, 29, 4, 10, 2, 62, 7, 44, 1, 27, 6, 36, 0, 87, 8, 25, 3, 13, 
    4,  1, 6, 16, 5, 79, 3, 18, 7, 79, 2, 84, 8, 91, 0, 84, 1,  3, 
    7, 21, 4, 57, 2, 49, 8, 20, 5, 10, 3, 72, 1, 31, 6,  9, 0, 96, 
    5, 22, 8, 82, 2, 20, 7, 28, 3, 62, 6, 30, 0, 23, 1, 89, 4, 76, 
    4, 37, 5, 98, 1, 73, 7, 53, 3, 31, 2,  9, 8, 18, 0, 60, 6, 87, 
    4,  5, 7,  9, 0, 95, 5, 65, 1, 23, 8, 73, 6, 33, 2, 42, 3, 94, 
    1, 74, 5, 34, 8, 73, 6,  4, 4, 39, 2, 25, 7, 34, 0, 56, 3, 89, 
    0,  8, 5, 23, 4, 44, 7, 34, 6, 99, 2, 20, 3, 26, 8, 16, 1, 80, 
    1, 50, 4, 19, 7, 99, 5,  7, 6, 75, 3, 35, 2, 28, 8, 22, 0, 53
  };
  const int q8297[] = {
    9, 9, // Number of jobs and machines
    2, 78, 8, 20, 6, 70, 7,  8, 0,  2, 4, 49, 3, 79, 1, 39, 5, 76, 
    7, 96, 1, 53, 3, 33, 0, 41, 2, 40, 5, 88, 6,  5, 8, 78, 4,  8, 
    1, 83, 5, 70, 6, 36, 2, 21, 4, 46, 8, 55, 0,  5, 7,  8, 3, 15, 
    6, 42, 4, 96, 8, 31, 1, 58, 5, 81, 0, 15, 7, 14, 3, 73, 2, 60, 
    4, 17, 7, 74, 8, 80, 5,  3, 1, 46, 6, 18, 3, 58, 0, 79, 2, 77, 
    2,  1, 1, 85, 4, 89, 7, 47, 5,  9, 6, 72, 3, 67, 8,  1, 0,  1, 
    5, 49, 4,  5, 1, 91, 3, 97, 0, 60, 8, 49, 7, 54, 6, 34, 2,  6, 
    5, 19, 3, 71, 8, 78, 7, 76, 2, 94, 4, 73, 1, 23, 6, 77, 0, 56, 
    5, 54, 1, 38, 3,  9, 2, 13, 4, 95, 0, 15, 7, 51, 6, 41, 8, 39
  };
  const int q8298[] = {
    9, 9, // Number of jobs and machines
    2, 69, 7, 63, 4, 29, 6, 16, 1, 69, 3, 48, 0, 10, 8,  2, 5, 56, 
    4, 30, 2, 20, 8, 37, 0, 64, 7, 55, 3, 55, 6, 26, 5, 55, 1, 96, 
    2, 63, 7, 39, 1, 41, 0, 76, 8, 98, 4, 90, 5, 36, 6, 13, 3, 11, 
    6, 63, 8, 99, 5, 85, 0, 96, 7, 23, 4, 81, 3, 72, 1, 75, 2, 97, 
    0, 64, 1, 71, 7, 33, 5, 92, 2, 25, 3, 68, 6, 18, 8, 73, 4, 95, 
    2, 11, 5, 66, 4, 85, 8, 97, 1, 37, 0, 61, 6, 72, 3,  4, 7, 10, 
    6, 24, 0,  5, 5, 62, 7,  6, 4, 77, 3, 93, 8, 75, 1, 42, 2, 91, 
    2, 97, 6, 48, 5, 67, 3, 32, 4, 44, 1, 76, 0, 34, 7, 79, 8, 91, 
    1,  2, 4,  5, 0, 77, 5, 68, 8, 77, 3, 95, 7, 47, 2, 75, 6,  9
  };
  const int q8299[] = {
    9, 9, // Number of jobs and machines
    1, 38, 7,  9, 8, 85, 3, 43, 6, 87, 2,  8, 4, 41, 5, 66, 0, 60, 
    2, 41, 5, 43, 6, 31, 3, 11, 1, 29, 4, 86, 8,  4, 0, 26, 7, 39, 
    4, 32, 2, 94, 6, 38, 1, 83, 5, 46, 7,  8, 8, 50, 3, 66, 0,  8, 
    0,  2, 3, 83, 6, 67, 7, 23, 2, 66, 4, 30, 1, 28, 8, 23, 5, 47, 
    3, 11, 6, 47, 0, 27, 7, 96, 5, 46, 1,  4, 4,  2, 8, 78, 2, 43, 
    0, 90, 6, 22, 4, 94, 7, 35, 5, 36, 3, 13, 2, 16, 8,  4, 1, 12, 
    5, 40, 0, 41, 7, 93, 6, 88, 1, 77, 4, 10, 2, 82, 3, 78, 8, 86, 
    8, 98, 5,  8, 4, 33, 7, 14, 3,  1, 0, 64, 2, 57, 1, 96, 6, 97, 
    7, 21, 8, 53, 2, 96, 0, 66, 3, 62, 4, 69, 6, 78, 5, 95, 1, 32
  };
  const int q8300[] = {
    9, 9, // Number of jobs and machines
    5, 49, 1, 12, 0, 91, 3, 92, 7, 11, 6, 52, 8, 79, 2, 90, 4, 82, 
    7, 88, 5, 38, 0, 55, 3, 90, 6,  7, 2, 70, 8, 80, 4, 44, 1,  5, 
    3, 72, 8, 85, 5, 83, 7, 90, 0, 38, 4, 56, 2, 24, 6, 17, 1, 16, 
    3,  3, 5, 59, 4, 50, 7, 90, 2, 61, 0, 28, 8, 41, 6, 59, 1, 69, 
    7, 78, 2,  4, 0,  6, 3, 75, 1, 44, 6, 85, 5, 14, 8, 44, 4, 99, 
    2, 37, 0, 14, 3, 45, 1, 95, 6, 65, 8,  8, 4, 13, 5, 83, 7, 44, 
    7, 97, 4, 17, 2, 26, 6, 44, 0, 69, 5, 79, 1,  2, 3, 20, 8, 54, 
    7, 45, 1, 74, 8, 63, 5, 93, 6, 31, 0,  2, 3, 60, 2, 41, 4, 37, 
    4, 39, 1, 63, 6, 99, 0, 72, 8, 35, 7, 45, 5, 49, 2,  5, 3, 40
  };
  const int q8301[] = {
    9, 9, // Number of jobs and machines
    7, 16, 8, 67, 3, 53, 1, 61, 2, 61, 4, 19, 5, 17, 6, 16, 0, 10, 
    7, 92, 8, 59, 3, 20, 0, 18, 1, 15, 2, 61, 4, 32, 6, 19, 5, 89, 
    3, 79, 0, 55, 1,  5, 4, 31, 2, 48, 6, 15, 5, 87, 8, 13, 7, 52, 
    5, 79, 3, 31, 7, 21, 8, 38, 1, 49, 4, 95, 0, 23, 6, 60, 2,  9, 
    6,  7, 4, 10, 8, 73, 7, 60, 0,  1, 2,  8, 5, 83, 3, 20, 1, 86, 
    0, 80, 3, 95, 8, 50, 6, 78, 1,  9, 5,  7, 7, 89, 4, 41, 2, 17, 
    3, 94, 7, 11, 0, 18, 8,  3, 5, 62, 6, 12, 1, 78, 2, 70, 4, 20, 
    7, 39, 1, 76, 0, 52, 8, 39, 5, 28, 4, 18, 3, 47, 6, 12, 2,  8, 
    7, 34, 8, 26, 3, 81, 2, 77, 4, 76, 1, 17, 6, 21, 0,  6, 5, 58
  };
  const int q8302[] = {
    9, 9, // Number of jobs and machines
    8, 23, 2, 89, 3, 74, 4, 13, 0, 73, 7, 14, 1, 60, 5, 47, 6, 68, 
    0, 36, 7, 26, 1, 34, 8, 14, 6, 98, 2, 25, 5, 50, 3, 83, 4, 77, 
    2, 77, 3, 25, 5, 70, 4, 48, 1, 78, 7, 52, 0,  9, 8, 79, 6, 80, 
    5, 39, 7, 81, 1, 66, 2, 27, 4,  6, 0,  4, 8, 77, 6, 95, 3, 92, 
    2, 64, 7, 42, 1,  7, 3, 29, 4, 42, 8, 64, 6, 44, 0, 88, 5,  2, 
    8, 91, 2, 81, 3, 71, 7,  8, 0, 18, 4, 26, 5, 28, 6, 15, 1, 35, 
    0, 45, 8, 34, 4, 50, 7, 83, 6, 46, 2, 68, 5,  5, 1, 81, 3, 76, 
    3, 72, 8, 46, 0, 53, 7, 62, 1, 22, 6, 52, 4, 33, 5, 17, 2, 75, 
    1, 85, 8, 99, 5, 73, 7, 20, 3, 71, 4, 94, 2, 47, 0, 41, 6, 80
  };
  const int q8303[] = {
    9, 9, // Number of jobs and machines
    8, 39, 2, 48, 7, 91, 4, 74, 0, 24, 5, 89, 1, 11, 6,  7, 3, 64, 
    2, 28, 7,  7, 1,  7, 8, 51, 3, 92, 5, 39, 0, 33, 4, 77, 6, 51, 
    3,  1, 8, 86, 6, 47, 2, 31, 5, 47, 4, 29, 0,  1, 1, 92, 7, 28, 
    8, 42, 1, 90, 6, 59, 3, 67, 0, 78, 5, 50, 7, 98, 4,  4, 2, 62, 
    8, 73, 1, 79, 2, 34, 4, 24, 3, 22, 6, 42, 0, 12, 7, 27, 5, 48, 
    6, 33, 2, 64, 5, 49, 1, 49, 7, 59, 0, 26, 4, 25, 3, 21, 8, 63, 
    5, 64, 6, 34, 7, 36, 8, 95, 0, 50, 3, 30, 2, 27, 1, 74, 4, 13, 
    0, 93, 3, 79, 5, 12, 2, 35, 6,  2, 1, 68, 4, 96, 7, 90, 8, 99, 
    3, 32, 2, 61, 8, 33, 4, 13, 1, 99, 7, 99, 6, 89, 5, 95, 0, 33
  };
  const int q8304[] = {
    9, 9, // Number of jobs and machines
    6, 91, 8, 92, 1, 99, 3, 37, 5, 31, 7, 66, 4, 43, 0, 47, 2, 63, 
    5, 92, 3, 23, 2, 41, 7, 72, 1, 61, 8, 68, 4, 62, 0, 93, 6, 36, 
    4, 27, 0, 11, 2, 48, 3, 92, 8, 37, 7, 10, 6, 33, 1, 57, 5, 87, 
    4, 61, 6, 71, 2, 75, 1, 87, 7, 40, 8, 63, 5, 55, 0, 86, 3, 96, 
    6, 29, 1, 98, 8, 31, 0, 85, 4, 17, 3, 69, 5, 94, 7, 69, 2, 33, 
    4, 74, 2, 27, 0, 22, 1, 31, 6, 24, 3, 58, 7, 63, 8, 26, 5, 80, 
    6, 20, 5, 67, 0, 95, 2,  6, 8, 65, 4, 75, 3, 33, 7, 54, 1,  8, 
    0, 72, 6, 93, 7, 33, 5,  8, 2, 95, 3, 17, 4, 19, 1, 71, 8, 91, 
    6,  3, 7, 20, 8, 20, 2, 93, 4, 77, 0, 37, 5,  9, 3, 57, 1, 21
  };
  const int q8305[] = {
    9, 9, // Number of jobs and machines
    8, 27, 4, 27, 3, 17, 6, 62, 0, 76, 2, 89, 5, 21, 7, 16, 1, 15, 
    1, 30, 4, 61, 6, 83, 5, 34, 2, 20, 8, 98, 0,  5, 3, 29, 7, 36, 
    8, 36, 0, 83, 5, 75, 1,  9, 7, 65, 4, 65, 2, 27, 6, 42, 3, 41, 
    4, 41, 7, 24, 3, 10, 1, 69, 8,  7, 2, 31, 5, 67, 0, 37, 6, 49, 
    0, 47, 4, 74, 2, 65, 7, 82, 3, 11, 8, 30, 6, 51, 5, 46, 1, 32, 
    1, 63, 6, 75, 2, 68, 0, 78, 7, 31, 8, 22, 3, 35, 5, 86, 4, 56, 
    0, 99, 2, 52, 7, 60, 8,  3, 5, 22, 1, 26, 4, 47, 3, 10, 6, 39, 
    0, 49, 1, 91, 8, 94, 7, 56, 4, 30, 3, 29, 5, 16, 2, 10, 6, 70, 
    4, 66, 0, 57, 2, 58, 5, 83, 7, 78, 3, 98, 1, 31, 8, 95, 6, 34
  };
  const int q8306[] = {
    9, 9, // Number of jobs and machines
    5, 28, 8, 86, 7, 78, 1, 65, 6, 30, 3, 24, 4,  6, 0, 39, 2, 94, 
    6, 48, 0, 51, 4, 26, 1, 22, 5, 74, 2, 88, 3, 77, 7, 72, 8, 92, 
    3, 61, 5, 32, 0, 38, 4, 27, 1,  3, 8, 57, 2, 54, 7, 16, 6, 37, 
    2, 15, 3, 96, 7, 56, 0,  6, 6, 70, 8, 73, 5, 84, 1, 38, 4, 47, 
    5, 79, 1, 16, 4, 47, 7, 23, 0, 56, 3, 65, 6,  4, 2, 22, 8, 40, 
    8, 25, 4, 99, 0, 38, 1, 37, 7, 74, 5, 98, 6, 35, 3, 49, 2, 23, 
    7, 88, 4, 77, 0,  1, 3, 56, 1, 99, 2, 21, 5, 81, 6, 76, 8, 57, 
    1, 14, 6, 24, 7, 29, 8, 63, 3, 33, 5, 35, 4, 63, 2, 26, 0, 76, 
    7,  7, 3, 73, 4, 94, 1, 92, 2, 47, 5, 68, 8, 86, 0, 71, 6, 34
  };
  const int q8307[] = {
    9, 9, // Number of jobs and machines
    0, 75, 7, 42, 2, 57, 8, 34, 5, 78, 3, 49, 1, 72, 4, 59, 6, 77, 
    3, 56, 5, 18, 8, 70, 0, 63, 7, 64, 4, 53, 6, 26, 1, 28, 2, 50, 
    7, 84, 1, 44, 0, 83, 3,  2, 5, 46, 8, 49, 6, 93, 4, 26, 2, 76, 
    8,  1, 3, 25, 2, 84, 5, 33, 7,  3, 4, 29, 6, 89, 0, 97, 1, 35, 
    1, 26, 2, 30, 3, 81, 0, 78, 5, 46, 8,  4, 7, 68, 4, 24, 6, 98, 
    5, 32, 2, 21, 4, 98, 0, 30, 3,  1, 6, 43, 1, 71, 8, 92, 7,  8, 
    4, 87, 2, 12, 6, 74, 1, 68, 8, 39, 0, 23, 5, 42, 3, 84, 7, 89, 
    8,  1, 6, 54, 4, 81, 2, 97, 0, 40, 3, 96, 5, 60, 1, 24, 7,  8, 
    4, 66, 2, 16, 5, 35, 3, 18, 8, 63, 1, 89, 7, 52, 0, 44, 6, 46
  };
  const int q8308[] = {
    9, 9, // Number of jobs and machines
    8, 98, 1, 88, 2, 85, 7, 18, 3, 42, 6, 95, 4, 24, 5, 43, 0, 66, 
    3, 77, 1, 84, 6, 87, 7, 39, 2, 51, 8, 97, 5, 24, 0, 88, 4, 67, 
    5, 53, 3, 64, 7, 21, 2, 17, 4, 96, 8, 93, 6, 69, 0,  6, 1, 56, 
    3, 20, 8, 57, 1, 56, 5, 35, 0, 69, 6, 87, 7, 14, 2, 12, 4,  3, 
    0, 65, 6, 39, 8, 72, 2,  3, 1, 94, 3, 84, 4, 32, 5, 32, 7, 67, 
    4, 45, 3, 33, 6, 39, 7, 53, 2, 21, 1, 60, 8, 62, 0, 49, 5, 90, 
    3,  3, 0, 20, 6, 16, 1,  4, 2,  7, 8, 30, 7, 64, 5, 12, 4, 80, 
    4, 82, 5, 15, 0, 14, 3, 76, 7, 21, 1, 12, 8, 15, 2, 89, 6, 64, 
    1, 92, 7, 14, 2, 53, 6, 71, 3, 20, 4, 88, 8, 12, 0, 89, 5, 30
  };
  const int q8309[] = {
    9, 9, // Number of jobs and machines
    6, 66, 4, 65, 7,  7, 3, 86, 5, 23, 8,  6, 0, 93, 2, 13, 1,  6, 
    5, 20, 8, 52, 6, 31, 7, 49, 2, 33, 0, 93, 1, 49, 4, 73, 3, 11, 
    7,  9, 4, 88, 0, 38, 6, 17, 5, 66, 3,  9, 1,  3, 2, 70, 8, 95, 
    8, 83, 2, 63, 6, 10, 3, 15, 0, 37, 1, 30, 5,  6, 4, 10, 7, 69, 
    2, 78, 4, 90, 3, 73, 5, 76, 6, 98, 8, 28, 7, 69, 0, 60, 1, 19, 
    5, 97, 3, 18, 1, 41, 6, 80, 0, 93, 8, 38, 7, 31, 4, 18, 2,  6, 
    4, 22, 1, 41, 3, 38, 7, 40, 0, 91, 5, 49, 6, 61, 2, 94, 8, 21, 
    5, 44, 2, 35, 4, 52, 6, 72, 0, 57, 3, 43, 7, 93, 8, 93, 1, 91, 
    2, 63, 8, 96, 6, 17, 5, 92, 1, 56, 4, 82, 3, 39, 0, 98, 7, 84
  };
  const int q8310[] = {
    9, 9, // Number of jobs and machines
    1, 36, 4, 97, 7, 22, 5, 44, 0,  9, 3, 46, 6, 17, 8, 10, 2, 91, 
    0, 11, 8, 37, 4, 36, 5, 54, 3, 34, 7, 80, 6,  9, 1, 43, 2, 62, 
    5, 49, 4, 26, 3, 17, 8, 20, 0, 62, 7, 10, 1,  7, 6,  1, 2, 57, 
    3, 37, 5,  4, 8, 66, 2, 32, 6, 46, 4, 56, 0, 53, 1, 49, 7,  7, 
    5, 28, 4, 22, 8, 41, 3, 84, 2, 50, 1, 73, 0, 55, 6, 10, 7,  6, 
    2, 97, 6, 77, 4, 80, 5, 19, 7, 85, 0, 66, 8, 26, 1, 49, 3, 76, 
    1, 61, 0, 40, 4, 70, 7, 40, 2, 19, 5, 28, 8, 81, 6, 17, 3, 99, 
    2, 92, 0, 59, 1, 71, 7, 44, 5, 78, 3, 39, 6, 48, 8, 77, 4, 92, 
    1, 75, 0, 97, 7, 59, 4, 61, 3, 90, 8, 85, 5, 98, 2, 84, 6, 35
  };
  const int q8311[] = {
    9, 9, // Number of jobs and machines
    6, 39, 2, 53, 5,  2, 3, 23, 4, 31, 8, 43, 1,  6, 0, 22, 7, 73, 
    4, 61, 5, 16, 7, 16, 8, 48, 3, 45, 6,  5, 2, 48, 1, 50, 0, 64, 
    2, 36, 0, 96, 7, 78, 3, 44, 8, 88, 5, 10, 1, 46, 4, 13, 6, 71, 
    4, 82, 3, 67, 1, 96, 0, 14, 8, 84, 5, 54, 6, 73, 7, 11, 2, 35, 
    8, 65, 5, 60, 2, 90, 6, 99, 7, 60, 1, 98, 4, 49, 3, 96, 0, 74, 
    3, 53, 5, 60, 4, 78, 0, 52, 2, 23, 8,  5, 1, 40, 7, 57, 6,  3, 
    8, 55, 0, 90, 1, 76, 6, 36, 5, 54, 4, 40, 3, 43, 2, 24, 7, 50, 
    7, 72, 3,  6, 1, 75, 4,  9, 6, 93, 2, 70, 5, 84, 0, 40, 8, 56, 
    3, 96, 8, 47, 2, 94, 6, 32, 1, 28, 4, 50, 0, 29, 7,  1, 5,  4
  };
  const int q8312[] = {
    9, 9, // Number of jobs and machines
    5, 89, 8, 90, 3, 15, 7, 83, 1, 69, 2, 87, 6, 28, 4, 63, 0, 54, 
    7, 33, 5, 46, 8,  1, 6, 81, 1, 64, 0, 37, 4, 85, 3, 82, 2, 42, 
    4,  1, 8, 27, 6, 80, 7, 15, 2, 22, 0, 70, 3, 98, 1,  8, 5, 35, 
    7, 89, 4,  8, 5, 54, 2, 26, 8, 74, 1, 80, 0, 58, 6, 80, 3, 13, 
    3, 47, 5, 63, 2, 72, 8, 65, 4, 16, 1, 71, 6, 52, 7, 35, 0, 73, 
    3, 85, 0, 90, 2, 64, 1, 32, 7, 77, 5,  1, 8, 19, 6, 46, 4, 71, 
    6, 73, 3,  6, 5, 31, 1, 65, 8, 88, 7,  7, 2, 31, 4, 77, 0, 72, 
    4, 26, 5, 79, 2, 87, 6, 88, 1, 76, 7, 65, 0, 39, 3,  4, 8, 93, 
    3, 87, 5, 30, 6, 29, 8, 71, 1, 10, 7,  6, 4,  3, 2, 89, 0, 88
  };
  const int q8313[] = {
    9, 9, // Number of jobs and machines
    8, 98, 1, 14, 2, 22, 4, 59, 6, 57, 0, 67, 7, 46, 5, 51, 3, 42, 
    8, 35, 4,  9, 2, 40, 5, 21, 6, 51, 7, 85, 0, 76, 3, 63, 1, 41, 
    2, 58, 3, 43, 4,  9, 8, 76, 7,  3, 5, 44, 6,  2, 0, 27, 1, 22, 
    5, 86, 4, 94, 2, 86, 0, 85, 6, 67, 3,  9, 1, 39, 7, 55, 8, 86, 
    5, 99, 6, 71, 4, 17, 0, 28, 1, 74, 3, 63, 7, 23, 8, 37, 2, 37, 
    7,  9, 0, 21, 5, 15, 1, 76, 3, 48, 6, 82, 2, 97, 8, 89, 4, 43, 
    2, 57, 7, 11, 6, 92, 8, 65, 1, 91, 5, 43, 0, 15, 3, 43, 4, 94, 
    0, 89, 4, 96, 7, 38, 1, 88, 6, 50, 8, 35, 5, 99, 2, 87, 3, 85, 
    4, 55, 5, 66, 3, 83, 0, 72, 1, 66, 8, 55, 7, 75, 6, 85, 2, 99
  };
  const int q8314[] = {
    9, 9, // Number of jobs and machines
    0, 96, 8,  9, 5,  9, 2, 40, 6, 85, 1, 72, 4, 53, 3, 35, 7, 68, 
    1, 46, 8, 44, 0, 75, 3, 97, 5, 16, 4, 46, 6, 70, 2, 81, 7, 69, 
    1,  6, 3, 27, 2, 54, 4,  7, 0, 35, 8, 44, 7, 19, 6, 25, 5, 71, 
    3, 25, 4, 24, 2, 96, 6, 92, 8, 95, 7, 47, 5, 51, 1, 88, 0, 87, 
    8, 84, 4, 69, 3, 44, 5,  6, 2,  4, 1, 25, 7, 66, 0, 27, 6, 19, 
    2, 28, 4, 28, 5, 85, 6, 39, 1, 45, 8, 72, 7, 59, 0, 41, 3, 93, 
    6, 77, 8, 95, 0, 29, 1, 16, 4,  6, 5, 98, 3, 32, 2, 66, 7, 28, 
    3, 38, 1, 79, 4,  8, 7,  6, 2, 50, 6, 34, 5, 96, 8, 73, 0, 60, 
    2, 11, 0, 62, 4, 59, 6, 77, 1, 75, 8, 58, 5, 17, 7, 12, 3, 21
  };
  const int q8315[] = {
    9, 9, // Number of jobs and machines
    8, 43, 5,  4, 3, 39, 2,  2, 6, 68, 0, 89, 1,  7, 7, 42, 4, 68, 
    4, 32, 1, 77, 5, 24, 7, 17, 0, 59, 8, 94, 3, 18, 2, 85, 6, 19, 
    3, 75, 2, 98, 7, 59, 0, 29, 4, 90, 6, 67, 5, 55, 1, 46, 8, 24, 
    0, 70, 1, 75, 3, 79, 2, 85, 4, 95, 8, 43, 6, 29, 5, 98, 7, 62, 
    3, 82, 4, 62, 6, 95, 2, 54, 5, 81, 0, 27, 8, 16, 1, 80, 7, 10, 
    4, 55, 5, 85, 6, 21, 1, 42, 0, 75, 3, 60, 2, 46, 7, 10, 8, 60, 
    4, 83, 8, 16, 2, 30, 7, 70, 3, 23, 6, 31, 1, 85, 0, 78, 5, 17, 
    7, 82, 8, 23, 4, 28, 1, 33, 2, 46, 3,  9, 6, 55, 0, 84, 5, 21, 
    4, 98, 7, 73, 8, 14, 6, 15, 0, 92, 2, 53, 3, 39, 5, 71, 1, 92
  };
  const int q8316[] = {
    9, 9, // Number of jobs and machines
    0, 12, 8, 44, 2, 19, 1, 53, 6, 96, 7, 39, 5, 36, 3, 96, 4, 34, 
    4, 84, 1, 60, 2, 24, 0, 11, 8, 44, 3, 40, 6, 65, 7, 26, 5, 59, 
    1, 82, 0,  7, 6, 77, 8, 33, 4, 24, 2, 65, 3, 61, 7, 46, 5, 59, 
    8, 34, 5, 27, 7, 90, 0, 21, 3, 52, 4, 68, 6,  3, 1, 55, 2, 48, 
    4, 72, 7, 58, 3, 41, 6, 45, 8, 74, 1,  9, 0,  8, 2, 17, 5,  2, 
    2, 84, 0, 89, 6, 70, 1, 38, 5, 77, 3, 39, 4, 42, 7, 62, 8, 25, 
    3, 85, 8, 11, 7, 43, 0, 27, 6, 26, 5, 49, 4, 31, 1, 89, 2, 79, 
    8, 73, 5, 63, 0, 12, 3, 32, 4, 87, 1, 31, 6, 57, 7,  2, 2, 66, 
    5, 55, 7, 39, 4, 87, 8, 56, 1, 26, 0, 57, 2,  7, 3, 89, 6, 13
  };
  const int q8317[] = {
    9, 9, // Number of jobs and machines
    4, 88, 5, 46, 0, 34, 1, 45, 8, 22, 6, 96, 3, 74, 7, 12, 2, 78, 
    1, 65, 6, 35, 2, 24, 7, 77, 3,  9, 5, 25, 0, 27, 8, 83, 4, 26, 
    1, 27, 6, 21, 5, 65, 7, 13, 4, 49, 2, 28, 0, 97, 3, 74, 8, 61, 
    8, 40, 3, 53, 5, 15, 4, 11, 2,  6, 1, 17, 0, 62, 7, 92, 6,  3, 
    8, 69, 1, 43, 0, 48, 3, 32, 2, 23, 6, 33, 4, 41, 7, 32, 5,  4, 
    6, 81, 7, 64, 1, 27, 8, 26, 2, 57, 5, 78, 4, 78, 0, 18, 3, 74, 
    7, 71, 1, 70, 2, 89, 3, 69, 0, 46, 8, 36, 4, 45, 5, 65, 6, 74, 
    8, 26, 3, 12, 0, 26, 2, 40, 5, 69, 7, 53, 6, 69, 1, 91, 4, 53, 
    0,  5, 7, 91, 1, 26, 6, 35, 5, 73, 8, 58, 3,  7, 4, 47, 2, 58
  };
  const int q8318[] = {
    9, 9, // Number of jobs and machines
    3, 77, 2, 64, 7, 22, 1, 36, 0,  1, 5, 86, 8, 40, 6, 79, 4, 47, 
    1,  6, 3, 87, 6, 50, 5, 64, 8, 78, 0, 64, 2, 61, 7, 36, 4, 48, 
    4, 44, 3, 56, 0,  9, 8, 14, 2, 46, 1, 19, 5, 74, 7, 81, 6, 37, 
    8, 88, 1, 95, 3, 23, 7,  9, 4, 49, 2, 54, 6, 45, 0, 16, 5, 95, 
    7, 35, 6, 38, 1, 14, 0, 92, 8, 60, 2, 37, 3, 18, 4, 58, 5,  1, 
    6, 11, 7, 99, 1,  3, 8, 34, 5,  8, 0, 83, 3, 79, 2, 80, 4, 26, 
    4, 60, 0, 37, 2, 42, 7, 54, 5, 43, 6,  7, 3, 62, 1, 95, 8, 22, 
    8, 23, 4, 53, 1, 44, 0, 97, 6, 23, 7, 86, 5, 88, 2, 89, 3, 89, 
    4, 38, 2, 86, 0, 96, 7, 74, 6, 95, 3, 31, 1, 54, 8, 85, 5, 95
  };
  const int q8319[] = {
    9, 9, // Number of jobs and machines
    7, 76, 8, 72, 2, 97, 4, 38, 5,  9, 6, 34, 1, 34, 0, 57, 3, 19, 
    4, 71, 1, 81, 7,  1, 5, 36, 6, 66, 2,  9, 3, 98, 0, 54, 8, 89, 
    5,  9, 8, 55, 6, 25, 7, 13, 0, 64, 3, 33, 4, 44, 2, 28, 1, 53, 
    7,  2, 2, 74, 6, 93, 3, 77, 1, 76, 5, 38, 8, 28, 0, 74, 4, 10, 
    2, 43, 1,  5, 6, 74, 4, 66, 7, 73, 0, 65, 3,  9, 5, 83, 8, 79, 
    3, 88, 7, 82, 2, 73, 6, 64, 8, 18, 1, 61, 0, 65, 4,  7, 5, 81, 
    5, 97, 0, 82, 6, 27, 3, 33, 4, 71, 8, 48, 7, 24, 2, 58, 1, 32, 
    0, 26, 8, 18, 6,  6, 2, 69, 7, 12, 1, 70, 4, 31, 5, 68, 3, 17, 
    6, 72, 7, 18, 3, 95, 0, 66, 2, 80, 4, 88, 5, 86, 1, 83, 8, 62
  };
  const int q8320[] = {
    9, 9, // Number of jobs and machines
    0, 76, 5, 36, 6, 72, 8, 17, 3, 43, 1, 66, 4, 41, 2, 62, 7, 61, 
    2, 95, 8, 54, 7, 78, 4, 97, 0, 43, 3, 32, 6, 17, 5, 70, 1, 42, 
    2, 29, 7, 66, 0, 65, 6, 41, 3, 54, 1, 98, 8, 14, 5,  9, 4, 46, 
    8, 91, 7, 22, 5, 15, 3, 96, 1, 37, 2,  6, 6, 83, 0, 85, 4, 21, 
    8, 90, 3, 69, 4, 75, 6, 58, 7, 82, 2,  5, 1, 11, 0, 31, 5, 66, 
    2, 10, 1, 36, 5, 42, 8, 32, 0, 51, 7, 15, 6, 46, 3, 60, 4, 31, 
    4, 62, 8, 31, 7, 61, 6, 77, 2, 34, 1, 74, 3, 98, 5,  4, 0, 89, 
    2, 76, 4,  3, 0,  4, 3,  8, 8, 13, 5, 47, 6,  9, 1, 19, 7, 62, 
    3, 50, 2, 47, 7, 79, 5, 68, 6, 90, 4, 52, 0, 89, 8, 32, 1, 42
  };
  const int q8321[] = {
    9, 9, // Number of jobs and machines
    8, 57, 5, 84, 6,  9, 4, 61, 2, 21, 1, 85, 7, 75, 3, 74, 0, 46, 
    2, 50, 7, 99, 1, 98, 0, 86, 5, 25, 4, 82, 6, 83, 8,  2, 3, 18, 
    0, 26, 8, 57, 4,  5, 5, 83, 6, 96, 1, 70, 2,  1, 7, 61, 3, 74, 
    5, 29, 7, 92, 6, 22, 3, 88, 0, 88, 1, 89, 2,  1, 4,  2, 8, 48, 
    4, 67, 2, 29, 1, 46, 3, 51, 5, 52, 6, 11, 7, 97, 0, 41, 8, 90, 
    4, 22, 5, 82, 6, 19, 3, 63, 1, 38, 2, 54, 8, 85, 0, 41, 7, 26, 
    5, 38, 4,  4, 0, 60, 8, 99, 2,  4, 7, 95, 6, 44, 1, 50, 3, 59, 
    2, 11, 0, 28, 5, 63, 8, 24, 7, 15, 4, 20, 3, 19, 6,  1, 1, 45, 
    2, 15, 5, 31, 8, 87, 3, 55, 1, 73, 7, 69, 0, 28, 6,  4, 4, 97
  };
  const int q8322[] = {
    9, 9, // Number of jobs and machines
    1, 21, 4, 99, 7, 82, 5, 95, 3, 47, 2, 98, 0,  6, 8, 71, 6, 87, 
    8, 61, 0, 98, 2, 14, 7, 71, 1, 54, 3, 99, 5, 82, 6, 54, 4, 34, 
    1, 22, 2, 55, 8, 55, 5, 40, 3, 47, 0, 50, 7, 20, 6, 14, 4, 61, 
    1, 43, 3, 43, 7, 77, 6, 90, 4, 10, 2, 96, 0,  8, 8, 74, 5, 73, 
    8, 51, 6, 29, 7, 35, 0, 17, 1, 40, 5, 21, 2, 21, 4, 39, 3, 56, 
    4, 34, 5, 78, 2, 71, 1, 14, 6, 65, 3, 13, 8, 90, 7, 34, 0, 41, 
    3, 24, 7,  8, 2, 71, 1,  6, 4, 12, 6, 46, 8,  1, 5, 62, 0, 20, 
    6, 66, 8, 85, 4, 51, 5, 59, 3, 11, 0, 53, 7, 42, 1, 26, 2, 33, 
    8, 34, 2, 66, 1, 64, 4, 55, 6, 99, 3, 65, 0, 16, 5,  1, 7, 54
  };
  const int q8323[] = {
    9, 9, // Number of jobs and machines
    0, 88, 3, 80, 1, 14, 7, 76, 6, 15, 8, 45, 2, 14, 5, 68, 4, 18, 
    4, 18, 5, 21, 6, 54, 0, 98, 1, 17, 7,  5, 8, 56, 3, 64, 2, 75, 
    3,  7, 8, 49, 5, 20, 6, 69, 0, 68, 2, 75, 1, 84, 4, 30, 7, 79, 
    6, 29, 1,  4, 4, 38, 3, 17, 8, 87, 5, 77, 0, 54, 7, 53, 2, 15, 
    5, 74, 1, 88, 6, 26, 8, 21, 2, 35, 4, 23, 3, 14, 0, 81, 7,  5, 
    7, 77, 4, 44, 0, 46, 5, 33, 1, 32, 6, 40, 3, 79, 2, 12, 8, 93, 
    5, 35, 3, 21, 1, 72, 8, 22, 0, 37, 4,  1, 6, 97, 7, 49, 2, 19, 
    4, 10, 0, 69, 1, 75, 7, 88, 3, 77, 6,  7, 8, 55, 5, 84, 2, 55, 
    6, 73, 2, 82, 1, 64, 0, 52, 4, 39, 5, 12, 7, 95, 8, 35, 3, 12
  };
  const int q8324[] = {
    9, 9, // Number of jobs and machines
    8, 63, 4, 97, 1, 23, 3, 85, 0, 21, 7, 15, 5, 71, 2, 19, 6, 80, 
    3, 73, 4,  5, 8, 14, 6,  5, 7, 73, 0, 75, 5, 71, 1, 27, 2, 62, 
    8, 27, 0, 55, 3, 33, 5, 51, 2, 49, 4, 70, 7,  6, 1, 92, 6, 11, 
    3, 74, 2, 11, 0, 64, 7, 68, 4, 26, 1, 59, 8, 51, 6, 47, 5, 45, 
    4, 19, 0, 92, 5, 48, 7, 96, 8, 84, 3, 53, 6, 94, 2, 96, 1, 89, 
    5, 27, 0, 14, 2, 53, 8, 26, 1, 65, 3, 20, 7, 97, 4, 38, 6, 83, 
    4,  6, 8, 21, 2, 11, 7, 82, 3, 12, 5,  6, 0, 59, 1, 53, 6, 73, 
    4, 87, 0, 27, 2,  3, 6, 21, 8, 62, 7, 40, 1, 13, 5,  6, 3, 70, 
    5, 26, 1, 96, 0, 58, 8, 15, 7, 97, 2, 94, 3, 80, 4, 87, 6, 43
  };
  const int q8325[] = {
    9, 9, // Number of jobs and machines
    3, 15, 5, 35, 1, 81, 2, 38, 8, 15, 0, 66, 4, 48, 6, 30, 7, 95, 
    7, 94, 4, 65, 0, 90, 1,  6, 8, 51, 3, 55, 6, 49, 5,  5, 2, 67, 
    4, 94, 0, 78, 8, 53, 2, 22, 1, 39, 3, 74, 7, 63, 6, 49, 5, 41, 
    2, 68, 8, 25, 4, 44, 1, 37, 6, 59, 7, 87, 0, 13, 5, 40, 3, 69, 
    3, 73, 1, 87, 7, 95, 4, 51, 0, 95, 8, 73, 5, 71, 6, 44, 2, 59, 
    1, 82, 3, 39, 4, 10, 2, 58, 8, 58, 6, 13, 7, 10, 0, 17, 5, 74, 
    0, 15, 7,  6, 1, 62, 5, 45, 8, 47, 4, 16, 2, 65, 6, 55, 3, 44, 
    4, 30, 5, 54, 3, 88, 7,  5, 0, 24, 1,  3, 6, 75, 8, 68, 2, 31, 
    5, 84, 7,  9, 1, 82, 8, 33, 3, 30, 6,  1, 2, 27, 4, 19, 0, 17
  };
  const int q8326[] = {
    9, 9, // Number of jobs and machines
    6, 35, 0, 95, 2, 64, 8, 28, 7,  2, 3, 83, 1, 57, 4, 77, 5, 97, 
    8, 95, 7, 37, 1, 47, 5, 92, 0, 65, 2, 16, 6,  8, 4, 30, 3,  5, 
    2, 33, 4, 81, 3, 32, 7, 99, 8, 21, 1, 29, 0, 94, 6, 40, 5, 57, 
    5, 42, 2, 57, 6, 14, 1, 27, 8, 43, 7,  8, 3, 20, 0,  9, 4, 72, 
    1,  9, 5, 25, 7, 11, 3, 13, 8,  3, 0,  4, 6, 38, 4, 16, 2, 57, 
    6, 24, 7, 21, 0, 62, 3, 66, 5, 69, 1, 42, 4, 71, 2, 92, 8, 68, 
    7, 58, 6,  7, 0, 22, 2, 47, 8,  6, 5, 76, 1, 28, 3, 49, 4, 11, 
    8, 67, 3, 87, 6, 33, 4, 41, 2, 65, 1, 38, 5, 70, 7, 75, 0, 68, 
    4, 40, 0, 72, 3,  6, 2, 64, 5, 22, 6, 38, 8, 71, 1, 53, 7, 42
  };
  const int q8327[] = {
    9, 9, // Number of jobs and machines
    7, 94, 0, 24, 1, 60, 8, 52, 6, 43, 2,  2, 4, 29, 3, 18, 5, 42, 
    0, 99, 4, 92, 3, 29, 7, 50, 6, 89, 8, 88, 2, 35, 1, 70, 5, 89, 
    6, 88, 8, 72, 3, 52, 7, 62, 2, 94, 0, 30, 1, 72, 5, 24, 4, 89, 
    3, 39, 2,  6, 7, 18, 6, 82, 5, 27, 4, 47, 1, 95, 0, 87, 8, 30, 
    2, 76, 1,  4, 3, 50, 0, 84, 5, 60, 7, 90, 8, 54, 6, 31, 4, 80, 
    6, 41, 7,  4, 5, 88, 8, 86, 1, 97, 2, 64, 4, 53, 0, 16, 3,  7, 
    7, 72, 1, 52, 0, 16, 4, 43, 6, 98, 3,  3, 5, 19, 8, 24, 2, 39, 
    4, 43, 0, 60, 6, 69, 7, 87, 5, 29, 1, 78, 2, 91, 3, 39, 8, 95, 
    3, 20, 7, 63, 5, 31, 2, 66, 0, 13, 1, 71, 6, 17, 8, 77, 4, 86
  };
  const int q8328[] = {
    9, 9, // Number of jobs and machines
    2, 30, 1, 16, 6, 77, 3, 78, 0, 35, 8, 29, 5, 93, 7, 95, 4, 89, 
    8, 91, 7, 61, 6,  7, 5, 21, 1, 42, 0, 97, 3, 36, 4, 33, 2, 65, 
    4, 36, 1, 32, 2, 94, 7, 79, 0, 26, 8, 26, 6, 39, 3, 82, 5, 13, 
    3, 24, 2, 47, 0,  5, 8, 45, 1, 57, 5,  1, 4, 72, 6, 15, 7, 87, 
    2, 59, 3,  3, 0, 77, 8, 41, 7, 76, 4,  7, 6, 77, 1, 40, 5, 69, 
    8, 76, 5, 62, 1, 23, 6,  8, 3, 64, 7, 44, 0, 54, 4, 90, 2, 27, 
    2, 71, 3,  3, 1, 91, 0,  9, 7, 56, 8, 59, 5, 11, 4, 48, 6, 74, 
    8, 30, 2, 90, 7, 21, 5, 33, 6, 16, 4, 35, 0,  3, 1, 97, 3, 65, 
    5, 59, 7, 27, 1,  9, 4, 49, 0, 54, 2, 68, 8, 62, 6, 29, 3, 42
  };
  const int q8329[] = {
    9, 9, // Number of jobs and machines
    6, 42, 7,  1, 4, 88, 2, 51, 3, 24, 8, 55, 1,  1, 5, 41, 0, 53, 
    8, 12, 0, 10, 7, 90, 1, 65, 4, 91, 6, 41, 5, 15, 2, 89, 3, 72, 
    8, 64, 2, 95, 7, 19, 5,  4, 6, 10, 0, 94, 4, 26, 3, 38, 1, 49, 
    5, 85, 8, 68, 2, 19, 1, 98, 7, 65, 4, 55, 3, 98, 6, 96, 0, 15, 
    2, 56, 0, 48, 7, 45, 5, 59, 6, 25, 8, 81, 4, 65, 1, 54, 3, 22, 
    5,  9, 7, 58, 2, 26, 3, 92, 8, 44, 1, 98, 4, 64, 0, 48, 6, 94, 
    4, 48, 8,  2, 7, 24, 2,  5, 5, 23, 0, 68, 1,  1, 6, 43, 3, 61, 
    4,  2, 0, 57, 2, 29, 8, 67, 7, 98, 1, 29, 6, 11, 5, 54, 3, 74, 
    0, 68, 8,  1, 6, 61, 2, 87, 1, 99, 7, 14, 5, 23, 3, 74, 4, 35
  };
  const int q8330[] = {
    9, 9, // Number of jobs and machines
    8, 43, 2, 96, 7, 91, 6, 45, 3,  4, 0, 94, 1, 92, 5, 60, 4, 32, 
    2, 57, 1, 22, 7, 91, 8, 31, 4,  2, 3, 63, 0, 25, 5, 58, 6, 72, 
    5, 74, 1, 52, 0, 94, 8, 54, 3, 90, 6, 81, 4, 17, 7, 73, 2, 66, 
    1, 69, 5, 36, 6, 32, 2, 21, 0, 72, 8, 83, 7, 37, 4, 38, 3, 19, 
    1, 93, 2,  7, 4, 35, 5, 42, 0, 95, 6, 63, 3, 97, 8, 79, 7, 43, 
    4, 46, 3, 65, 7, 96, 8, 48, 1,  6, 6, 45, 2, 84, 0, 66, 5,  2, 
    1, 68, 6, 23, 7, 75, 0, 78, 3, 66, 4, 79, 5, 79, 8, 35, 2, 60, 
    7, 42, 5, 80, 6, 35, 4, 55, 3, 76, 8, 36, 2, 71, 0, 67, 1, 22, 
    5, 78, 7, 58, 2,  9, 3, 93, 4, 59, 8, 82, 6, 26, 1, 88, 0, 91
  };
  const int q8331[] = {
    9, 9, // Number of jobs and machines
    6, 48, 7, 85, 3, 23, 0, 73, 4, 73, 1, 23, 5, 37, 2,  8, 8, 48, 
    8, 35, 2, 62, 7, 64, 3, 55, 6, 60, 4, 27, 1, 88, 5, 24, 0, 24, 
    1, 12, 7, 99, 4, 72, 0, 53, 3, 79, 6, 64, 8, 39, 5, 97, 2, 95, 
    3, 61, 0, 19, 2, 95, 6, 73, 4, 33, 7, 18, 1, 24, 5,  2, 8, 26, 
    0, 77, 7, 93, 8, 77, 6, 28, 1, 27, 2, 13, 5, 17, 4, 32, 3, 59, 
    7, 87, 8, 30, 6, 33, 4,  2, 5, 31, 2, 88, 1, 47, 3, 24, 0, 31, 
    4, 48, 1, 96, 5, 77, 0,  6, 6,  7, 2, 21, 7, 13, 8, 18, 3, 44, 
    7, 72, 6, 85, 0, 83, 4, 42, 5, 28, 2, 24, 8, 33, 3, 42, 1,  1, 
    6, 14, 5, 91, 1, 25, 4, 50, 0, 33, 7, 11, 2, 28, 8, 30, 3, 48
  };
  const int q8332[] = {
    9, 9, // Number of jobs and machines
    6, 39, 4, 18, 8,  8, 7, 53, 2, 54, 1, 46, 0, 41, 3, 59, 5, 62, 
    4, 36, 8, 49, 3, 50, 6, 19, 0, 85, 1, 94, 5, 46, 7, 54, 2, 26, 
    2, 93, 0, 10, 3,  2, 6, 87, 8, 32, 1, 62, 5, 32, 4, 65, 7, 73, 
    1, 90, 3, 80, 2, 54, 0, 64, 6, 96, 5, 51, 4, 10, 8, 22, 7, 81, 
    2, 47, 0, 85, 3, 69, 6, 68, 1, 70, 4, 64, 5, 21, 8, 37, 7, 83, 
    6, 84, 5, 62, 8, 23, 1, 71, 4, 91, 0, 38, 2, 93, 7, 79, 3, 39, 
    1, 74, 4,  4, 5, 31, 7, 44, 2, 90, 0, 27, 6, 20, 8, 72, 3, 68, 
    7, 39, 0, 99, 5, 85, 8,  2, 2,  8, 3, 50, 6, 36, 4, 57, 1, 95, 
    6, 50, 1, 60, 4, 62, 0, 65, 7, 23, 3, 36, 2, 68, 8, 53, 5, 78
  };
  const int q8333[] = {
    9, 9, // Number of jobs and machines
    6,  6, 7, 93, 1, 53, 0, 53, 3, 26, 4, 35, 5, 16, 8,  2, 2, 63, 
    6, 12, 8, 85, 0, 88, 2, 60, 4, 20, 1, 47, 7, 59, 5, 77, 3, 81, 
    5, 68, 2, 90, 0, 87, 8, 36, 1,  8, 4, 47, 6,  6, 3, 79, 7, 36, 
    7, 48, 6, 33, 3, 77, 0, 98, 2, 66, 8, 21, 4, 12, 5, 76, 1, 99, 
    5, 90, 2, 32, 4,  5, 3, 33, 7, 58, 1,  4, 6, 78, 0, 13, 8, 97, 
    7, 61, 2, 74, 8, 59, 5,  7, 1, 11, 4, 20, 6, 40, 3, 84, 0, 34, 
    1, 90, 2, 81, 0, 86, 7, 71, 6, 65, 5, 78, 4,  5, 3, 24, 8,  2, 
    6, 23, 5, 90, 3, 83, 2, 60, 0, 70, 4, 98, 7, 36, 1, 41, 8,  4, 
    0, 50, 8,  5, 6, 20, 3,  1, 7, 10, 2,  5, 5, 55, 1, 52, 4, 80
  };
  const int q8334[] = {
    9, 9, // Number of jobs and machines
    4, 72, 7, 77, 3, 31, 2, 82, 6, 27, 1, 83, 5, 66, 8, 29, 0, 33, 
    6, 38, 2, 37, 8, 81, 7, 51, 5, 99, 0, 91, 1,  4, 3,  6, 4, 21, 
    6, 17, 7, 94, 1, 43, 0, 96, 2, 47, 3, 32, 8, 17, 5, 87, 4, 99, 
    4,  9, 3, 35, 8, 47, 0, 75, 7, 96, 6, 48, 5, 63, 1, 22, 2, 25, 
    7, 83, 8, 88, 1, 12, 6, 44, 0, 70, 3, 76, 5,  1, 2, 99, 4, 60, 
    7, 38, 5, 75, 3, 80, 4, 81, 0, 65, 8, 41, 1, 83, 2,  4, 6, 89, 
    4, 34, 0, 36, 7, 94, 5, 89, 6, 45, 8, 18, 2, 27, 1, 94, 3, 83, 
    7, 82, 6, 68, 4, 18, 5, 58, 0, 92, 3,  9, 1, 29, 2, 12, 8, 45, 
    3, 24, 7, 18, 0, 93, 5, 68, 1, 70, 2, 99, 4, 12, 6, 73, 8, 61
  };
  const int q8335[] = {
    9, 9, // Number of jobs and machines
    6, 16, 4, 68, 5,  3, 8, 96, 2, 63, 0, 66, 3, 55, 1, 49, 7, 22, 
    8, 72, 3, 36, 0, 72, 1, 50, 4, 77, 2, 39, 5, 25, 7, 43, 6, 66, 
    1, 24, 2, 78, 4, 93, 8, 23, 7, 88, 5, 97, 6, 30, 0, 49, 3, 83, 
    5, 58, 0, 36, 2, 25, 8, 47, 1, 89, 7, 41, 3, 39, 6, 71, 4, 95, 
    2, 23, 4, 13, 1, 39, 5, 67, 6, 12, 0, 61, 3, 13, 7, 21, 8, 26, 
    7, 87, 1,  1, 4, 52, 5, 17, 6, 18, 2, 14, 3, 13, 8, 47, 0, 35, 
    6, 30, 7, 80, 0,  6, 5, 11, 8,  3, 2, 47, 4, 44, 3, 25, 1, 82, 
    7, 47, 5, 80, 8, 66, 0, 62, 6, 61, 3, 77, 2, 31, 1,  1, 4, 78, 
    5, 13, 8, 39, 6, 25, 2, 59, 3, 84, 1, 88, 7,  7, 0,  5, 4, 57
  };
  const int q8336[] = {
    9, 9, // Number of jobs and machines
    8, 53, 5, 29, 3, 83, 4, 32, 2, 51, 7, 92, 1,  9, 0, 43, 6, 61, 
    5, 22, 8, 44, 2, 55, 6,  8, 3, 85, 4, 25, 7, 66, 1, 60, 0, 80, 
    4, 57, 3, 89, 1,  6, 2, 25, 6,  6, 7, 28, 0,  3, 5, 35, 8, 60, 
    4, 41, 0, 89, 6, 16, 5, 72, 7, 94, 3, 99, 2, 67, 8,  7, 1, 55, 
    3, 98, 7, 46, 8, 22, 0, 16, 6, 94, 5, 23, 4, 98, 1, 35, 2, 31, 
    8, 92, 2, 22, 6, 55, 3, 93, 5, 13, 1, 81, 0, 72, 4, 55, 7, 37, 
    7, 17, 2, 12, 6, 68, 1, 47, 8, 76, 0, 79, 4,  8, 3, 55, 5, 70, 
    4, 59, 7, 41, 8, 65, 6, 15, 0, 36, 5, 46, 1, 40, 2, 63, 3, 17, 
    7, 47, 4, 66, 3, 34, 1, 93, 2, 30, 5, 43, 0, 37, 6, 89, 8, 62
  };
  const int q8337[] = {
    9, 9, // Number of jobs and machines
    2, 23, 5, 66, 7,  3, 0,  6, 4, 75, 3, 76, 8, 40, 6, 25, 1, 17, 
    0, 73, 7, 62, 3, 62, 6, 70, 1, 86, 4, 47, 8, 23, 2, 29, 5, 46, 
    1, 54, 7, 48, 3, 46, 2, 54, 6, 83, 8, 26, 4, 41, 0, 12, 5, 76, 
    8, 45, 0, 40, 2,  4, 5, 14, 4, 34, 1, 93, 6,  2, 3, 63, 7, 57, 
    1,  2, 0, 75, 7, 46, 4, 63, 3, 39, 6, 87, 2, 59, 8, 58, 5, 51, 
    1, 97, 0,  2, 4,  3, 2, 81, 6, 31, 8, 97, 5, 22, 3, 82, 7, 46, 
    2, 56, 3, 61, 8, 94, 7, 46, 4, 66, 1, 27, 0, 31, 6, 63, 5, 60, 
    4, 84, 3, 28, 1, 52, 8, 11, 2, 41, 6, 83, 0, 41, 7, 31, 5, 90, 
    5, 99, 0, 32, 2, 91, 4, 79, 8, 63, 1, 35, 6, 95, 7, 77, 3, 41
  };
  const int q8338[] = {
    9, 9, // Number of jobs and machines
    8, 26, 0, 37, 5, 24, 7, 14, 6, 75, 3, 79, 2, 13, 4, 98, 1, 86, 
    0, 16, 4, 49, 5,  4, 6, 57, 7, 12, 8, 16, 3, 13, 2, 74, 1,  2, 
    8, 88, 7, 52, 1, 18, 2, 94, 5, 14, 0, 36, 6, 41, 4, 45, 3, 92, 
    7, 38, 3, 49, 6, 37, 4, 56, 1, 69, 2, 44, 8, 76, 0, 76, 5, 42, 
    3, 57, 4,  8, 0, 39, 2, 98, 1, 12, 7, 83, 6, 70, 8, 30, 5, 49, 
    6, 10, 8, 14, 3, 76, 7, 55, 4, 25, 0, 58, 1, 98, 5, 22, 2,  2, 
    2, 90, 0, 87, 1,  7, 7, 47, 4, 68, 6, 48, 3, 68, 5, 24, 8, 96, 
    2, 28, 0, 43, 4, 34, 8, 93, 6, 97, 7, 11, 1, 18, 3, 64, 5, 39, 
    2, 73, 4, 57, 8, 61, 3, 74, 0, 53, 7, 62, 6, 26, 5, 97, 1, 47
  };
  const int q8339[] = {
    9, 9, // Number of jobs and machines
    0,  7, 6, 95, 8, 23, 4, 18, 5, 89, 3, 11, 2, 57, 1, 88, 7, 24, 
    8,  2, 4, 38, 6, 99, 0, 72, 2, 78, 7, 51, 5, 63, 1, 86, 3, 48, 
    6, 91, 4, 61, 1, 50, 3,  6, 8,  7, 0, 75, 2, 91, 7, 29, 5, 55, 
    6, 73, 2, 74, 5,  1, 0, 80, 3, 27, 1, 46, 4, 61, 8, 28, 7, 52, 
    0, 58, 4, 24, 2, 42, 6, 79, 1, 87, 5, 29, 3, 46, 7, 10, 8, 53, 
    8, 39, 1, 75, 0, 28, 4, 21, 2, 72, 6, 98, 3, 18, 5, 70, 7, 68, 
    5, 66, 8, 14, 6, 46, 3, 76, 4, 55, 2, 51, 7, 89, 1, 93, 0, 98, 
    0,  8, 4,  1, 1, 18, 8, 81, 2, 23, 5, 26, 3, 74, 7, 98, 6, 13, 
    0, 31, 7, 99, 5,  6, 8, 35, 2, 71, 4, 46, 6,  1, 3, 54, 1, 39
  };
  const int q8340[] = {
    9, 9, // Number of jobs and machines
    1, 54, 8, 63, 2, 92, 6, 33, 5, 18, 4,  9, 3, 97, 7, 12, 0, 61, 
    4, 36, 5, 20, 1, 27, 0,  8, 3, 59, 2, 99, 6, 66, 7, 98, 8, 34, 
    2, 26, 7,  5, 3, 91, 1, 10, 8, 71, 4,  2, 6, 91, 5, 34, 0, 72, 
    8, 40, 7, 69, 0, 89, 5, 54, 1, 33, 6, 10, 4, 34, 3, 79, 2,  5, 
    8,  5, 7, 68, 0, 34, 2, 74, 3, 99, 5, 60, 6, 13, 4, 77, 1, 30, 
    4, 24, 0, 81, 6, 82, 5,  5, 8, 52, 7, 32, 3, 42, 2, 33, 1, 64, 
    7, 99, 5, 55, 4, 27, 2, 50, 1, 17, 3, 86, 6, 49, 8, 34, 0, 75, 
    7, 76, 4, 27, 3, 91, 1, 40, 8, 85, 2, 95, 6, 90, 0, 27, 5, 18, 
    5, 85, 0, 24, 7, 22, 3, 83, 2, 76, 6, 86, 4, 95, 1, 38, 8, 46
  };
  const int q8341[] = {
    9, 9, // Number of jobs and machines
    5, 30, 3, 62, 4, 83, 7, 93, 0, 90, 8, 54, 1, 48, 2, 36, 6, 67, 
    4, 98, 0, 23, 1, 54, 8, 52, 7, 38, 5, 47, 3, 70, 6, 96, 2, 87, 
    4, 87, 0, 38, 8,  3, 5, 30, 7, 90, 6, 70, 3, 62, 2, 19, 1, 55, 
    3, 98, 2, 28, 7, 97, 1, 93, 5, 43, 0,  6, 8, 55, 6, 97, 4, 33, 
    8, 32, 3, 77, 2, 62, 0, 87, 4, 66, 5,  2, 7, 82, 6, 24, 1, 69, 
    8,  8, 1, 89, 0, 43, 7, 73, 6, 71, 3, 12, 5, 23, 2, 98, 4, 29, 
    4, 39, 0, 88, 5, 65, 2, 57, 3, 29, 6, 53, 8, 84, 1, 10, 7, 27, 
    4, 25, 7, 64, 2, 14, 3, 85, 0, 42, 5, 54, 8, 35, 1, 41, 6, 21, 
    3, 53, 5, 85, 0, 64, 6, 97, 7, 98, 1, 82, 2, 79, 8,  1, 4, 89
  };
  const int q8342[] = {
    9, 9, // Number of jobs and machines
    6, 53, 1, 62, 5, 82, 0, 13, 4, 18, 7, 58, 2, 87, 3, 90, 8, 87, 
    7, 90, 2, 71, 1, 64, 5, 62, 8, 60, 6, 60, 0, 77, 3, 61, 4, 33, 
    2,  8, 6, 80, 4, 81, 1, 29, 5, 77, 8, 81, 0, 28, 7, 58, 3, 67, 
    6, 74, 0, 55, 3, 28, 5, 78, 2, 10, 8, 48, 4, 84, 1, 47, 7, 41, 
    2, 63, 8, 22, 4, 39, 0, 21, 5, 72, 7, 61, 6, 95, 1, 33, 3, 83, 
    5, 16, 4, 88, 8, 14, 7, 92, 6, 61, 1, 81, 3, 97, 0, 95, 2, 49, 
    1, 29, 2, 82, 4, 67, 0, 90, 3, 72, 5, 31, 6, 68, 8, 16, 7, 23, 
    2,  8, 7, 23, 6, 39, 3, 64, 8,  3, 1, 25, 5, 44, 4, 87, 0, 84, 
    3, 46, 8, 35, 5, 94, 6,  1, 1, 51, 0, 64, 4, 96, 2, 89, 7, 72
  };
  const int q8343[] = {
    9, 9, // Number of jobs and machines
    0, 47, 6, 68, 7, 74, 1, 77, 4, 36, 5, 96, 8,  7, 3, 90, 2, 50, 
    3, 66, 5, 82, 6, 55, 8, 38, 0, 87, 4, 23, 2,  1, 1, 48, 7, 83, 
    5, 14, 8, 25, 6, 54, 2, 44, 0, 18, 4, 97, 7,  6, 3, 59, 1, 79, 
    5, 62, 3, 79, 6, 71, 7, 76, 8, 67, 1, 64, 4, 54, 0, 98, 2, 75, 
    0, 47, 3, 83, 4, 89, 2, 55, 6,  8, 7,  8, 5, 92, 8, 59, 1, 43, 
    3, 91, 0, 25, 1, 75, 2, 34, 4, 40, 8,  2, 5, 22, 6, 76, 7, 41, 
    6, 73, 1, 85, 3,  8, 2, 27, 0, 98, 4, 95, 7, 67, 5, 21, 8, 53, 
    3, 71, 5, 88, 0, 25, 1, 32, 4,  3, 7, 82, 6, 59, 2, 94, 8,  4, 
    1, 17, 7, 10, 3, 68, 0, 30, 5, 80, 6, 57, 2, 77, 8, 78, 4, 45
  };
  const int q8344[] = {
    9, 9, // Number of jobs and machines
    2, 36, 5, 86, 3, 83, 6, 78, 7, 59, 0, 22, 1, 99, 4, 51, 8, 25, 
    2, 49, 8, 28, 5, 70, 3, 39, 7,  9, 1, 90, 4, 17, 6, 46, 0, 96, 
    8, 59, 7,  8, 1, 80, 2, 63, 3, 87, 5, 29, 0, 99, 6, 37, 4, 46, 
    3, 71, 2, 97, 4, 68, 6, 92, 1, 87, 8, 99, 5, 34, 0, 68, 7, 92, 
    2, 93, 1, 62, 5, 50, 4, 50, 8, 25, 7, 29, 3, 69, 6, 80, 0, 62, 
    4, 28, 5, 59, 1,  8, 2, 11, 3,  3, 6, 58, 7, 53, 0, 78, 8, 47, 
    5, 85, 7, 92, 3, 63, 6, 79, 4, 71, 1, 62, 2, 89, 0, 92, 8, 62, 
    2, 60, 1, 55, 7, 75, 8, 93, 0,  1, 5, 42, 4, 10, 6,  6, 3,  4, 
    5, 16, 1, 29, 6, 80, 7, 99, 2,  4, 3, 40, 8, 17, 4, 20, 0, 89
  };
  const int q8345[] = {
    9, 9, // Number of jobs and machines
    4, 21, 3, 43, 1, 59, 5, 50, 8, 65, 6, 30, 0, 93, 2, 65, 7, 58, 
    6, 90, 3, 24, 7, 44, 0, 74, 8,  9, 4, 87, 2, 85, 5, 93, 1, 73, 
    5, 61, 0, 92, 6, 59, 3, 86, 8, 15, 2, 32, 4, 17, 7, 55, 1, 73, 
    1, 87, 3, 70, 4, 58, 6, 70, 2, 63, 5, 86, 0, 86, 8, 32, 7, 36, 
    2, 55, 8, 10, 7, 81, 6,  6, 4, 85, 5,  3, 1, 95, 0, 16, 3, 15, 
    2, 41, 6, 74, 3, 50, 1, 74, 0, 97, 5, 28, 8, 80, 4, 75, 7,  7, 
    5,  2, 2, 53, 7, 94, 1, 64, 4,  8, 8, 71, 6, 29, 0, 82, 3, 99, 
    5, 99, 0, 20, 8,  6, 6, 85, 2, 29, 1, 56, 4, 34, 7, 67, 3, 71, 
    6, 93, 0, 74, 3, 68, 2, 57, 8, 22, 1, 79, 7, 40, 4, 46, 5, 57
  };
  const int q8346[] = {
    9, 9, // Number of jobs and machines
    4, 26, 3,  1, 8, 55, 6, 43, 0, 82, 1, 38, 2, 23, 5, 82, 7, 58, 
    7, 82, 6, 37, 5, 98, 4, 63, 2, 48, 0, 88, 3, 21, 8, 85, 1, 90, 
    0, 19, 8,  6, 3,  3, 4, 85, 5, 23, 6, 20, 2, 11, 7, 62, 1, 29, 
    8, 85, 0, 49, 7, 91, 2, 57, 3, 99, 1, 28, 6,  9, 5,  5, 4, 40, 
    3,  5, 4, 22, 1, 45, 7, 59, 0,  5, 5, 27, 2, 11, 6, 93, 8, 88, 
    7, 77, 2, 95, 1, 66, 4, 43, 0, 49, 6, 67, 5, 48, 8, 29, 3, 63, 
    3, 59, 8, 82, 7, 85, 2, 90, 0, 70, 5, 63, 4, 40, 1, 76, 6,  3, 
    6, 34, 1, 86, 4, 37, 2, 26, 3, 58, 7,  2, 5,  3, 0, 99, 8, 66, 
    2, 84, 5, 65, 7, 37, 0, 97, 6, 79, 8, 42, 3, 15, 1, 88, 4, 53
  };
  const int q8347[] = {
    9, 9, // Number of jobs and machines
    2, 81, 8, 87, 3,  9, 6,  6, 0, 20, 1, 50, 7, 92, 4, 25, 5, 59, 
    7, 50, 3, 38, 8, 83, 6, 86, 1, 60, 5, 97, 2, 27, 4, 33, 0, 61, 
    6, 63, 8, 82, 7, 30, 2, 95, 4, 67, 5, 32, 0, 57, 3, 32, 1, 27, 
    4, 59, 1, 52, 8, 64, 0, 48, 7, 29, 5, 43, 3, 99, 6, 80, 2, 61, 
    7, 82, 5, 89, 4, 30, 6, 14, 8, 46, 3, 77, 2, 25, 0, 26, 1,  6, 
    4, 40, 1, 47, 5, 59, 7, 96, 8, 22, 0, 27, 2, 97, 3, 23, 6, 43, 
    2, 20, 3, 15, 5, 90, 4, 97, 6, 91, 7, 10, 1, 65, 8, 65, 0, 87, 
    8, 95, 1, 96, 7, 48, 2, 43, 3, 51, 5, 94, 4,  8, 0, 53, 6, 91, 
    6, 47, 1, 99, 2, 31, 8, 97, 4, 30, 7, 31, 5, 92, 3, 73, 0, 84
  };
  const int q8348[] = {
    9, 9, // Number of jobs and machines
    2, 14, 0, 18, 4,  6, 5, 86, 8, 27, 7, 26, 3, 41, 1, 50, 6, 21, 
    0, 66, 6, 79, 5, 82, 2, 72, 1, 80, 8, 94, 4, 62, 3, 45, 7,  2, 
    5, 22, 7, 41, 2, 96, 0, 77, 4, 63, 6, 45, 8, 85, 1, 15, 3, 41, 
    8, 40, 0, 14, 6, 10, 5, 82, 7, 34, 1, 21, 2,  5, 4, 10, 3, 86, 
    4, 35, 2, 30, 3, 15, 7, 13, 6, 18, 1, 27, 0, 33, 8, 29, 5,  4, 
    6, 57, 4, 93, 7, 34, 0, 74, 1, 85, 5, 23, 3, 23, 2, 37, 8, 97, 
    2, 36, 8, 84, 5, 43, 3, 43, 7, 41, 6, 39, 4, 29, 1, 94, 0,  7, 
    1, 16, 7, 50, 2, 87, 8, 23, 4, 14, 5, 60, 0, 15, 6, 65, 3, 36, 
    6, 34, 8, 74, 3, 88, 1,  5, 7, 36, 5, 68, 4, 71, 0, 34, 2, 41
  };
  const int q8349[] = {
    9, 9, // Number of jobs and machines
    6, 21, 1, 42, 4, 93, 3, 70, 0, 73, 8, 15, 2,  9, 7, 79, 5, 32, 
    4, 97, 5, 96, 8, 19, 0, 74, 6, 97, 2, 66, 1, 78, 3, 84, 7, 42, 
    4, 86, 5, 25, 1, 67, 6, 98, 7, 73, 3, 13, 8, 50, 2, 87, 0, 83, 
    1, 27, 8, 43, 2, 81, 6, 10, 4, 86, 0, 74, 5, 94, 3, 42, 7, 31, 
    0, 41, 4, 10, 1, 76, 5, 83, 6, 64, 8, 29, 7, 77, 2, 75, 3, 75, 
    8, 15, 0, 53, 4, 89, 3, 30, 6,  2, 1, 38, 5, 24, 2, 27, 7, 88, 
    6, 17, 5, 93, 1, 91, 3, 39, 4, 85, 0, 45, 7, 41, 2, 17, 8, 94, 
    4, 67, 3, 84, 5, 33, 2,  9, 0, 38, 8, 31, 1, 89, 6, 63, 7, 10, 
    7, 99, 8, 90, 2, 62, 3, 38, 1, 65, 0, 63, 4, 96, 6,  7, 5, 63
  };
  const int q8350[] = {
    9, 9, // Number of jobs and machines
    2, 67, 4, 38, 1, 95, 3, 89, 0, 49, 7, 51, 5, 83, 6, 51, 8, 74, 
    4, 77, 1, 96, 7, 71, 5, 11, 3, 85, 6, 97, 8, 81, 0, 80, 2, 67, 
    2, 99, 4,  8, 1, 96, 3, 44, 8, 26, 6,  5, 5, 70, 7, 12, 0, 16, 
    7, 87, 6, 66, 1, 68, 0, 74, 5, 22, 4, 79, 3, 82, 2, 39, 8, 74, 
    0,  2, 8, 57, 5, 29, 1, 96, 4, 57, 6, 85, 2,  1, 7, 99, 3, 90, 
    8,  9, 0, 27, 6, 45, 2, 79, 1, 83, 5, 50, 4, 11, 7, 81, 3, 14, 
    8, 82, 4, 72, 7, 57, 1, 73, 6, 25, 3,  1, 0,  5, 2, 12, 5, 47, 
    8, 71, 5,  1, 1, 99, 4, 26, 3, 16, 0, 74, 6, 85, 2, 59, 7, 69, 
    4, 91, 3, 31, 0, 87, 2, 42, 1, 13, 8, 44, 6, 10, 7,  4, 5, 54
  };
  const int q8351[] = {
    9, 9, // Number of jobs and machines
    7, 11, 1, 12, 5, 17, 3,  7, 2, 83, 8, 65, 6, 89, 4, 23, 0, 62, 
    6, 93, 1, 73, 5, 72, 0, 67, 7, 36, 2, 82, 4, 60, 3, 59, 8, 54, 
    4, 94, 6, 20, 8, 34, 1, 43, 0, 15, 7, 12, 5, 59, 3, 20, 2, 20, 
    7,  7, 2,  7, 5, 47, 6, 56, 0, 23, 1, 27, 4, 19, 3, 61, 8, 53, 
    5, 38, 3, 87, 8, 19, 2,  8, 6,  8, 1, 80, 0, 71, 4, 15, 7, 47, 
    3, 10, 2, 48, 6, 88, 7, 78, 8, 30, 0, 11, 4, 14, 5, 91, 1, 64, 
    5, 63, 3,  7, 2, 75, 7, 86, 6, 94, 0, 52, 4,  8, 1,  1, 8, 34, 
    3, 60, 7, 67, 5, 24, 2, 18, 8,  9, 6, 13, 4, 29, 0, 58, 1, 91, 
    5, 82, 0, 78, 2, 96, 7, 32, 3, 62, 1, 43, 8, 64, 4, 97, 6, 18
  };
  const int q8352[] = {
    9, 9, // Number of jobs and machines
    7, 68, 6,  5, 5, 64, 3, 58, 2, 45, 0, 24, 1,  9, 4, 88, 8,  2, 
    5, 59, 2, 55, 3, 21, 1, 64, 6, 95, 7, 99, 0, 26, 4, 62, 8, 92, 
    0, 23, 2, 10, 4,  9, 1, 27, 7, 85, 6, 27, 8, 32, 3, 28, 5, 73, 
    6, 38, 2, 61, 5, 56, 3, 51, 8, 24, 1, 68, 4, 36, 0, 95, 7, 15, 
    7, 22, 1, 44, 5, 28, 2,  6, 3, 10, 4, 95, 8, 85, 0, 54, 6, 27, 
    3, 60, 4, 49, 8, 76, 6,  4, 2, 95, 1, 30, 0, 78, 7, 68, 5, 19, 
    4, 21, 5, 46, 7, 11, 2,  3, 1, 78, 8, 31, 6, 86, 3, 92, 0, 82, 
    2, 18, 3, 51, 4, 19, 1, 86, 5, 98, 8, 36, 0, 41, 6, 62, 7, 60, 
    0, 25, 8, 47, 3, 10, 4, 96, 6,  9, 2, 80, 7, 91, 5, 14, 1,  3
  };
  const int q8353[] = {
    9, 9, // Number of jobs and machines
    5, 85, 0, 90, 1, 31, 8, 82, 7, 20, 6, 18, 2,  1, 4, 15, 3, 56, 
    2, 53, 4, 45, 5, 68, 0, 66, 6, 64, 1, 56, 7, 61, 3, 34, 8, 80, 
    3, 19, 8, 32, 5, 13, 7, 74, 6, 21, 4, 59, 1, 38, 2, 68, 0, 11, 
    5, 66, 0, 98, 4, 55, 8, 23, 6, 58, 2,  6, 1, 92, 3, 77, 7, 62, 
    7, 84, 2, 10, 1, 23, 4, 69, 0, 68, 3, 78, 5, 78, 6,  2, 8, 19, 
    6, 92, 2, 14, 7, 53, 5, 66, 0, 33, 1, 25, 3, 48, 8,  9, 4, 51, 
    2, 63, 4, 42, 1, 49, 5, 64, 8, 73, 6,  3, 3, 22, 7, 77, 0, 36, 
    2, 13, 5, 34, 3, 56, 6, 61, 4, 73, 0, 77, 8, 70, 1, 76, 7, 61, 
    1, 27, 0, 91, 6, 93, 3, 48, 5, 12, 8, 24, 4, 33, 2, 84, 7, 82
  };
  const int q8354[] = {
    9, 9, // Number of jobs and machines
    3, 54, 0, 69, 1, 45, 2, 61, 8, 86, 7, 16, 4, 59, 6, 62, 5, 61, 
    5, 50, 2, 36, 7, 70, 0, 91, 3, 98, 1, 83, 4, 56, 6, 59, 8, 27, 
    8, 84, 4, 48, 6, 47, 5, 45, 2, 41, 7, 95, 3,  5, 0, 47, 1, 72, 
    0, 56, 6, 83, 8, 86, 3, 42, 1, 13, 7, 84, 2, 24, 5, 73, 4, 74, 
    4, 69, 8, 68, 5, 86, 6, 61, 1, 57, 2, 26, 0,  9, 7, 19, 3, 36, 
    0, 59, 8, 72, 6, 80, 4, 56, 7, 54, 1,  1, 2, 19, 5, 94, 3, 33, 
    7,  9, 5, 19, 2, 42, 0, 49, 8, 17, 3, 10, 4,  6, 6, 11, 1, 29, 
    3, 25, 0, 64, 5, 30, 8, 92, 4, 11, 2, 73, 7,  9, 1, 98, 6, 62, 
    7,  5, 2, 99, 5, 65, 8, 15, 1,  2, 6, 69, 4, 93, 3,  6, 0, 42
  };
  const int q8355[] = {
    9, 9, // Number of jobs and machines
    5, 70, 2, 22, 7, 20, 1, 57, 6, 77, 3,  2, 4, 61, 8, 28, 0, 83, 
    0, 16, 3, 37, 5, 62, 2, 55, 8, 53, 6, 92, 7, 91, 4, 91, 1, 32, 
    3, 80, 5, 43, 6, 67, 8, 25, 2, 35, 7, 76, 0, 11, 4, 13, 1, 28, 
    8, 11, 0, 72, 3, 75, 5, 54, 1, 49, 6, 37, 4, 88, 7, 40, 2, 73, 
    0, 63, 8, 70, 6, 61, 5, 39, 1, 47, 4, 60, 7, 24, 3, 74, 2, 87, 
    2,  2, 1, 76, 8, 64, 4, 66, 7, 77, 5, 43, 3, 61, 0, 12, 6, 98, 
    0, 68, 4,  3, 5, 91, 6, 88, 2, 63, 1, 68, 7, 44, 8, 88, 3, 20, 
    3,  2, 2, 86, 1, 63, 5, 44, 6, 43, 4, 63, 8, 62, 0, 80, 7,  4, 
    0, 83, 4, 14, 3, 49, 5, 52, 2, 75, 7, 40, 6,  4, 1, 29, 8, 55
  };
  const int q8356[] = {
    9, 9, // Number of jobs and machines
    2, 87, 7, 44, 8, 54, 6, 73, 0, 33, 4, 22, 3, 60, 1, 33, 5, 84, 
    4, 92, 7,  9, 5, 25, 0, 37, 8, 25, 6, 64, 1, 49, 2,  1, 3, 25, 
    4, 99, 3, 33, 6, 59, 0, 10, 7,  3, 2, 67, 8, 61, 5, 43, 1, 35, 
    7, 31, 4, 24, 8, 47, 6, 13, 2, 32, 5, 25, 3, 88, 0, 10, 1, 49, 
    4, 18, 7, 13, 2, 56, 0, 92, 5,  9, 3, 70, 8, 46, 1, 50, 6, 17, 
    7, 35, 1, 41, 0, 91, 8, 19, 4, 81, 6, 61, 3, 78, 5, 93, 2, 74, 
    5, 10, 7, 84, 4, 63, 6, 31, 3, 94, 8, 53, 1, 14, 0, 53, 2, 61, 
    6, 63, 7, 96, 3, 37, 2, 28, 5, 22, 4, 55, 1, 69, 0, 40, 8, 62, 
    0, 44, 5, 10, 2, 90, 7, 87, 4, 36, 6, 91, 8, 31, 1, 79, 3, 78
  };
  const int q8357[] = {
    9, 9, // Number of jobs and machines
    3, 88, 6, 62, 2, 11, 0, 93, 4, 87, 1, 79, 7,  9, 5, 83, 8, 20, 
    7, 11, 2, 99, 0, 88, 5, 85, 1, 80, 6, 45, 8, 49, 4, 15, 3, 31, 
    5, 93, 1, 47, 3, 82, 8, 68, 7, 90, 0, 95, 2, 49, 4, 88, 6, 89, 
    0, 57, 4, 31, 3, 36, 5, 27, 1, 54, 8, 65, 2, 18, 7, 41, 6,  9, 
    8, 58, 2, 16, 5, 33, 7, 91, 3,  4, 6, 61, 4, 63, 1, 82, 0, 44, 
    6, 84, 0, 51, 8, 63, 4, 69, 3,  7, 1, 47, 5, 18, 2, 66, 7, 96, 
    2, 15, 0, 15, 5, 59, 4, 83, 1, 94, 6, 53, 8, 32, 3, 66, 7, 77, 
    5, 96, 7, 79, 8, 85, 0, 61, 1, 83, 4,  6, 6, 58, 2, 72, 3, 63, 
    4, 82, 7, 28, 8, 94, 1, 11, 0, 84, 6, 51, 2, 23, 5,  9, 3,  2
  };
  const int q8358[] = {
    9, 9, // Number of jobs and machines
    5, 60, 3, 84, 6, 57, 7, 26, 4, 19, 8, 74, 0,  4, 1, 54, 2, 56, 
    7, 66, 4, 38, 6, 39, 3, 51, 0, 68, 5, 22, 8, 27, 2, 18, 1,  2, 
    3, 84, 4, 90, 2, 59, 6, 10, 7, 42, 1,  5, 5, 37, 8, 88, 0, 71, 
    0, 46, 5, 60, 4, 12, 3, 64, 7, 14, 8, 70, 1, 46, 6, 74, 2, 79, 
    7, 95, 8, 30, 0, 65, 2, 66, 1, 62, 5, 40, 6, 39, 3,  5, 4, 27, 
    6, 50, 1, 42, 0, 87, 2, 43, 8,  5, 3, 36, 5, 79, 4, 39, 7, 58, 
    1,  3, 8, 94, 2, 17, 6,  5, 5, 39, 7, 32, 3,  3, 0, 63, 4, 87, 
    6, 14, 1, 13, 5, 76, 7, 65, 4, 36, 0, 72, 3, 29, 2, 47, 8, 43, 
    1, 73, 3,  7, 0, 80, 7, 65, 2, 19, 8, 82, 5, 30, 4, 45, 6, 38
  };
  const int q8359[] = {
    9, 9, // Number of jobs and machines
    5, 85, 6, 33, 4, 79, 2, 75, 0, 40, 8, 59, 3,  9, 1, 63, 7, 95, 
    7, 12, 4, 52, 0, 24, 2, 84, 1, 72, 8, 58, 3, 65, 5, 76, 6, 78, 
    0, 20, 3, 73, 4, 57, 2,  5, 7, 39, 6, 75, 1, 14, 8, 40, 5, 30, 
    6, 65, 5, 35, 3, 43, 4, 40, 8, 52, 1, 52, 2, 60, 7, 87, 0, 51, 
    6, 29, 3, 36, 1, 61, 8, 62, 2, 28, 4, 25, 5, 80, 0, 49, 7, 69, 
    0, 46, 2, 90, 1, 77, 6, 64, 4, 70, 5, 79, 7, 19, 3, 44, 8, 11, 
    2, 32, 4, 35, 3,  7, 5, 49, 1, 47, 8, 91, 7, 82, 6,  1, 0, 91, 
    1, 71, 3,  2, 0, 23, 2, 64, 4, 91, 6, 71, 5, 13, 7, 65, 8, 46, 
    5, 54, 8, 83, 7, 24, 3, 86, 1, 28, 6, 80, 4, 34, 2, 45, 0, 49
  };
  const int q8360[] = {
    9, 9, // Number of jobs and machines
    4, 39, 6, 52, 8, 60, 5, 46, 2, 13, 3, 50, 0, 57, 1, 90, 7, 38, 
    8, 24, 7, 51, 3, 70, 1, 29, 0, 28, 5, 89, 2, 59, 4, 49, 6, 36, 
    7, 69, 8, 76, 3, 85, 5, 34, 0, 19, 1, 30, 2, 40, 6, 96, 4, 36, 
    8, 95, 7, 72, 4, 80, 5, 51, 2, 97, 3, 70, 1, 30, 0, 18, 6, 82, 
    7, 10, 1, 48, 4, 32, 8, 46, 0, 25, 3, 14, 6, 13, 5, 68, 2, 15, 
    4, 88, 7, 97, 2, 26, 6, 36, 8, 14, 5, 53, 0, 32, 1, 86, 3, 60, 
    7, 39, 1, 25, 4, 23, 2, 13, 8, 71, 6, 16, 0, 58, 5, 28, 3, 46, 
    0, 93, 2, 64, 8, 41, 1, 98, 3, 80, 5, 47, 4, 31, 6, 72, 7, 44, 
    0,  5, 4, 80, 3,  8, 1, 22, 5, 50, 8, 56, 2, 17, 7, 37, 6, 61
  };
  const int q8361[] = {
    9, 9, // Number of jobs and machines
    6, 96, 4, 99, 7, 96, 0, 30, 3, 46, 2, 53, 1, 55, 5, 48, 8,  7, 
    7, 11, 4, 85, 1, 96, 3, 13, 0,  2, 2, 88, 8, 12, 6, 14, 5, 53, 
    6, 31, 3, 47, 4, 35, 0, 17, 5, 71, 8, 42, 2, 85, 7, 97, 1, 11, 
    5, 15, 7, 70, 1, 12, 0, 77, 8, 43, 3, 23, 2, 11, 6, 48, 4, 59, 
    7, 40, 5, 92, 3, 79, 1, 23, 4, 45, 2,  2, 6, 88, 0, 89, 8,  4, 
    2, 56, 5, 91, 0, 71, 3, 17, 7,  6, 6, 46, 4, 52, 1, 75, 8, 95, 
    4, 65, 2, 73, 3, 60, 8, 83, 6,  1, 1, 83, 0,  4, 5, 30, 7, 47, 
    4, 71, 8, 74, 5, 14, 0, 46, 6,  2, 3, 57, 1, 45, 2, 44, 7, 59, 
    5, 19, 0, 28, 2, 62, 4, 64, 3, 47, 6,  6, 1, 11, 7, 85, 8, 99
  };
  const int q8362[] = {
    9, 9, // Number of jobs and machines
    6, 79, 5, 29, 0, 32, 8, 83, 4,  8, 3, 33, 2, 41, 1, 46, 7, 89, 
    2, 39, 8, 55, 4, 23, 7, 17, 5,  6, 3, 28, 0, 33, 6, 62, 1, 99, 
    7, 16, 5, 28, 6, 45, 1, 96, 8, 86, 2, 25, 0, 25, 3, 17, 4, 88, 
    3, 16, 1, 89, 7, 50, 8, 58, 5, 23, 2,  3, 4, 21, 6, 90, 0, 14, 
    0, 67, 3, 92, 2, 31, 6, 70, 5, 75, 8,  2, 4, 48, 1,  6, 7, 47, 
    8, 74, 1, 33, 2, 31, 4, 47, 3, 19, 0, 46, 7, 67, 6, 34, 5, 75, 
    2, 80, 4, 42, 3, 18, 1, 30, 5, 16, 6, 87, 7, 24, 0, 47, 8, 72, 
    7, 37, 2, 14, 1, 92, 0, 98, 5, 32, 8, 34, 3, 73, 6, 74, 4, 51, 
    5,  4, 1, 44, 3, 16, 4, 84, 2, 56, 6, 71, 8, 41, 0, 60, 7, 65
  };
  const int q8363[] = {
    9, 9, // Number of jobs and machines
    3, 59, 4, 10, 7, 79, 5, 75, 0, 19, 2, 31, 6, 88, 8, 18, 1, 65, 
    7, 71, 2,  2, 5, 66, 6, 38, 0, 95, 4,  7, 8, 99, 3, 61, 1, 45, 
    4,  5, 1, 58, 2, 83, 5, 65, 3, 47, 0, 97, 8, 70, 6, 45, 7,  1, 
    1, 34, 7, 96, 5, 42, 6, 32, 0, 81, 2, 97, 8, 86, 4, 99, 3, 77, 
    6, 74, 5, 58, 4, 17, 3, 68, 7, 12, 2, 75, 8, 96, 0, 25, 1,  7, 
    2, 43, 6, 61, 3,  7, 1, 87, 7, 12, 8, 42, 5, 16, 4,  5, 0, 95, 
    1, 49, 2, 76, 6, 91, 4, 44, 3, 40, 5, 49, 0, 13, 8, 73, 7, 88, 
    6,  6, 0, 98, 7, 25, 3, 51, 1, 97, 8, 28, 2, 70, 4, 35, 5, 30, 
    2, 65, 8, 62, 7, 57, 0, 93, 4, 48, 3, 97, 5, 73, 1, 79, 6, 80
  };
  const int q8364[] = {
    9, 9, // Number of jobs and machines
    7, 20, 1, 73, 6, 30, 5, 70, 3, 67, 2, 15, 0, 59, 4,  5, 8, 49, 
    8, 35, 1, 56, 0,  6, 4, 40, 3, 72, 2, 33, 7, 64, 6, 43, 5,  7, 
    1, 90, 2, 72, 4, 76, 7, 47, 3, 68, 0,  6, 5, 62, 8, 98, 6, 89, 
    4,  3, 0, 34, 3,  2, 2, 57, 1, 92, 8, 89, 6, 66, 7, 11, 5, 26, 
    1, 72, 0, 22, 6, 35, 4, 47, 2, 39, 7, 13, 5, 59, 3, 40, 8, 48, 
    1, 95, 3, 20, 4, 74, 5, 63, 0, 35, 8, 59, 6, 40, 2,  7, 7, 66, 
    1, 75, 7, 86, 2, 18, 8, 39, 5, 13, 6, 59, 4, 54, 0, 34, 3, 18, 
    2, 62, 3, 52, 5,  6, 1, 24, 0, 94, 4, 28, 7, 90, 8, 23, 6, 47, 
    7, 36, 3, 60, 5, 44, 4, 34, 2, 15, 0, 12, 6, 42, 8, 92, 1, 77
  };
  const int q8365[] = {
    9, 9, // Number of jobs and machines
    2,  3, 7, 99, 8, 69, 3, 44, 4, 22, 6, 78, 0, 83, 5, 83, 1, 51, 
    5, 92, 7, 21, 3,  2, 0,  6, 4, 66, 6, 40, 2, 49, 8, 82, 1, 42, 
    8, 39, 0, 16, 1, 26, 6, 45, 3, 89, 5, 61, 2, 98, 4, 88, 7, 55, 
    4, 68, 2, 98, 1, 74, 6, 63, 5, 61, 0, 40, 8, 89, 7, 57, 3, 82, 
    4, 34, 6, 89, 8, 34, 3, 40, 7, 69, 1, 72, 0, 99, 5, 73, 2, 32, 
    3, 88, 8, 17, 0, 84, 7, 81, 2, 31, 1, 70, 6, 82, 5, 57, 4, 40, 
    4,  1, 2, 19, 7,  6, 3, 50, 5, 46, 6, 79, 1, 68, 8, 22, 0, 75, 
    1,  5, 4, 36, 5, 84, 7, 76, 6, 15, 2, 40, 3, 35, 0, 99, 8, 53, 
    3, 53, 7, 71, 1, 82, 5, 80, 4, 72, 0, 31, 2, 11, 8,  4, 6, 33
  };
  const int q8366[] = {
    9, 9, // Number of jobs and machines
    7, 46, 1, 50, 3, 67, 8, 37, 5, 78, 2, 85, 0, 97, 4, 59, 6, 93, 
    8, 40, 5,  9, 4, 51, 3, 78, 0, 76, 7, 45, 6, 90, 2, 80, 1, 69, 
    7, 34, 1, 18, 4, 33, 2, 51, 3, 91, 0, 64, 8, 57, 5, 72, 6,  8, 
    8, 81, 7, 27, 3,  7, 5, 92, 1,  3, 6, 74, 4,  3, 2,  2, 0,  9, 
    2, 63, 4, 22, 8, 79, 0, 58, 6, 76, 1, 65, 3,  9, 5, 15, 7, 23, 
    1, 82, 0,  3, 5, 42, 4, 87, 2,  2, 3, 43, 6, 34, 7, 15, 8,  9, 
    5, 50, 4, 15, 2, 60, 7, 99, 0, 61, 1, 71, 3, 65, 8, 13, 6,  1, 
    4, 83, 6, 52, 2, 53, 0, 50, 3,  8, 8, 57, 1, 87, 7, 35, 5,  7, 
    5, 52, 3, 28, 0, 56, 4, 58, 7, 84, 6, 95, 8, 69, 1, 97, 2, 17
  };
  const int q8367[] = {
    9, 9, // Number of jobs and machines
    1, 47, 8, 50, 5, 28, 7, 32, 4, 77, 3, 89, 6, 16, 0, 12, 2, 92, 
    0, 29, 6, 42, 7, 34, 4, 18, 2, 39, 5, 62, 1, 68, 8, 60, 3, 65, 
    2, 83, 7, 88, 1, 44, 0, 71, 8,  2, 4, 22, 6, 84, 5, 85, 3, 91, 
    2, 60, 3, 15, 0, 16, 8, 19, 6, 96, 5, 82, 1, 25, 7, 50, 4, 52, 
    6, 33, 4, 25, 8, 89, 5, 91, 3, 61, 1, 46, 2, 80, 7, 19, 0, 65, 
    3, 57, 8, 93, 6, 58, 2, 39, 1, 35, 4, 27, 5, 42, 7, 41, 0, 84, 
    2, 39, 6, 34, 5, 92, 7, 89, 3, 57, 0, 84, 8,  4, 1, 56, 4, 45, 
    1, 56, 6, 89, 0, 91, 3, 11, 5, 91, 8, 41, 2, 99, 4, 71, 7, 16, 
    3, 79, 8, 19, 7, 45, 0, 47, 6, 31, 5, 66, 1, 80, 2, 45, 4, 60
  };
  const int q8368[] = {
    9, 9, // Number of jobs and machines
    3, 85, 5, 85, 1, 82, 6, 53, 2, 98, 8, 40, 7, 39, 4, 36, 0, 45, 
    4, 36, 3, 17, 0,  4, 1, 48, 7, 37, 8, 83, 5, 27, 2, 60, 6, 78, 
    0,  8, 2,  2, 3, 89, 5, 12, 1,  2, 4, 35, 8, 72, 6, 12, 7, 78, 
    6, 40, 1, 58, 3, 50, 7, 96, 0, 76, 5, 13, 4, 97, 8, 11, 2, 17, 
    4, 73, 6, 16, 5, 63, 7, 53, 8, 67, 0, 56, 1, 96, 2, 73, 3, 91, 
    5, 31, 7, 63, 3, 40, 1, 23, 8, 11, 6, 91, 2, 60, 0, 50, 4, 97, 
    1, 99, 4, 68, 7, 44, 5, 18, 0,  6, 8, 71, 3, 12, 2,  4, 6, 74, 
    6, 93, 1,  4, 0, 15, 4, 79, 7, 12, 3, 59, 8, 46, 5, 20, 2, 96, 
    7, 20, 2, 33, 5, 19, 0, 86, 4, 17, 1,  5, 8, 71, 3, 33, 6,  6
  };
  const int q8369[] = {
    9, 9, // Number of jobs and machines
    6, 65, 2, 47, 1, 51, 7, 33, 3, 58, 8, 33, 5, 29, 4,  5, 0, 99, 
    0, 48, 3, 32, 7, 21, 2, 95, 5, 98, 4, 79, 1,  6, 8, 52, 6, 89, 
    0, 94, 6, 65, 5, 39, 4,  7, 7, 21, 3, 77, 2, 19, 1, 36, 8, 67, 
    8, 19, 7, 10, 5, 20, 1, 40, 3,  7, 2, 23, 0, 30, 4, 14, 6, 33, 
    0, 33, 3, 74, 8, 32, 4, 86, 7, 72, 5, 28, 1, 16, 2, 49, 6, 94, 
    0, 27, 8,  1, 1,  7, 2, 27, 3, 70, 6, 73, 4,  1, 5, 59, 7, 27, 
    6, 20, 4, 89, 5, 98, 2, 54, 7, 89, 8, 46, 1, 74, 3, 74, 0, 80, 
    8, 70, 7, 78, 6, 66, 2, 63, 4, 12, 1, 68, 0, 82, 5, 64, 3, 75, 
    7, 45, 0, 76, 8, 58, 6,  4, 3, 59, 5, 81, 1, 86, 4, 23, 2, 70
  };
  const int q8370[] = {
    9, 9, // Number of jobs and machines
    7, 30, 6, 46, 5, 17, 8, 61, 2, 41, 4, 19, 0, 48, 1, 17, 3, 37, 
    4, 51, 5, 60, 3, 64, 6, 75, 1,  8, 7, 98, 2, 61, 0, 63, 8, 66, 
    3, 59, 2, 33, 7, 35, 1, 20, 4, 67, 6, 79, 8, 48, 5,  7, 0, 23, 
    7, 35, 0,  6, 6, 69, 4, 95, 2, 72, 1, 43, 5, 59, 3, 11, 8, 93, 
    8, 29, 3, 98, 7, 57, 1, 22, 6, 67, 5, 87, 0, 45, 4, 41, 2, 34, 
    1,  3, 4, 19, 6, 84, 5, 67, 2, 23, 8, 31, 7, 63, 3, 91, 0, 38, 
    3, 40, 8, 99, 4, 56, 6, 85, 5,  5, 0, 22, 7, 53, 2, 70, 1, 32, 
    0, 37, 2, 58, 6, 62, 3, 51, 5,  1, 7, 82, 4, 97, 1, 81, 8, 48, 
    7, 78, 5,  9, 2, 13, 8, 82, 4, 23, 3, 61, 6, 86, 0, 98, 1, 69
  };
  const int q8371[] = {
    9, 9, // Number of jobs and machines
    7, 65, 0, 67, 3, 19, 5, 89, 6, 25, 4, 46, 2, 12, 1, 68, 8, 69, 
    5, 84, 0, 83, 1, 68, 4, 26, 3, 72, 6, 43, 7, 65, 8, 23, 2, 99, 
    8, 41, 1, 37, 6,  1, 4, 46, 0, 89, 2, 86, 3, 55, 5, 69, 7, 87, 
    1, 96, 8, 45, 7, 61, 3, 45, 4, 75, 5, 68, 6, 18, 0, 59, 2, 10, 
    4, 77, 1, 64, 6, 16, 8, 51, 3, 67, 0, 39, 2, 99, 5, 67, 7, 49, 
    3, 80, 4, 15, 7, 48, 0, 45, 2,  6, 8, 45, 6, 55, 1, 54, 5, 22, 
    1, 21, 7, 97, 4, 39, 0, 37, 8, 18, 3, 63, 5,  7, 6, 94, 2,  9, 
    2, 81, 5, 16, 8,  8, 1, 41, 7, 26, 4, 58, 3, 64, 0, 48, 6, 39, 
    1, 83, 8, 58, 4, 92, 3, 51, 2, 24, 7, 63, 5, 65, 6, 25, 0, 33
  };
  const int q8372[] = {
    9, 9, // Number of jobs and machines
    3, 21, 8, 84, 4, 13, 1, 51, 6, 17, 7, 69, 5, 36, 0,  1, 2, 95, 
    8, 53, 0, 48, 7,  3, 4, 36, 5, 94, 1, 66, 3,  4, 6,  8, 2, 63, 
    1, 13, 3, 11, 2, 59, 6, 44, 8, 78, 4, 36, 5, 36, 0, 61, 7, 48, 
    2, 94, 0, 21, 4, 36, 7, 60, 6, 68, 5, 50, 1, 95, 8, 53, 3, 32, 
    1, 32, 5,  3, 8, 72, 0,  9, 7, 93, 2, 42, 6, 53, 4, 52, 3, 51, 
    0, 78, 5,  1, 2, 49, 1, 18, 3, 85, 8, 35, 6, 12, 4, 28, 7, 47, 
    4, 67, 1,  1, 0, 23, 7, 43, 2, 58, 5,  2, 8, 77, 6, 90, 3,  4, 
    8, 76, 5, 50, 0, 62, 7, 53, 2, 43, 4, 13, 3, 61, 1, 34, 6, 58, 
    8, 12, 5, 75, 3,  1, 1, 84, 6, 20, 7, 18, 2, 79, 0, 25, 4, 33
  };
  const int q8373[] = {
    9, 9, // Number of jobs and machines
    5, 30, 3, 62, 0, 76, 7, 11, 8, 94, 6, 53, 4, 29, 2, 21, 1, 89, 
    7, 53, 2, 28, 3, 31, 6, 30, 5, 22, 8,  8, 4, 55, 0, 58, 1, 11, 
    6, 73, 5, 99, 4, 35, 7, 97, 1, 28, 8, 95, 3, 32, 0, 42, 2, 17, 
    2,  2, 7, 33, 0, 74, 8, 83, 1,  9, 4, 77, 5, 77, 3, 73, 6, 37, 
    2,  8, 0, 59, 1, 96, 4, 43, 7, 30, 3, 66, 5, 15, 6, 56, 8,  5, 
    0, 18, 5, 75, 4, 41, 7, 94, 6,  1, 1, 13, 3, 92, 8, 67, 2, 47, 
    0, 27, 6, 99, 3, 97, 5, 51, 7, 62, 1,  8, 2, 45, 4, 36, 8,  3, 
    4, 12, 8, 13, 6, 17, 5, 85, 1, 44, 2,  2, 7, 45, 3, 86, 0,  6, 
    8, 47, 2,  4, 0, 85, 3, 66, 4, 44, 5, 75, 1,  2, 7, 81, 6, 26
  };
  const int q8374[] = {
    9, 9, // Number of jobs and machines
    8, 31, 7,  6, 3, 58, 5, 75, 0, 57, 4, 75, 2, 15, 1, 86, 6, 30, 
    3, 35, 5, 95, 7, 42, 1, 53, 6, 37, 8, 27, 2,  4, 0, 19, 4, 79, 
    8, 49, 0, 17, 2, 27, 5, 43, 6, 56, 3, 98, 7, 48, 4, 66, 1, 11, 
    8,  3, 3, 54, 2, 24, 5, 18, 4,  5, 0, 67, 6, 15, 1, 77, 7, 44, 
    4, 60, 3, 33, 1, 75, 7, 74, 6, 88, 8, 16, 5, 53, 2, 25, 0, 59, 
    5, 62, 6, 61, 8, 12, 4, 80, 0, 83, 2, 54, 1, 18, 3, 13, 7,  4, 
    6, 37, 7, 26, 4, 22, 5, 26, 0, 12, 3, 80, 1, 11, 2, 42, 8, 59, 
    1, 59, 7, 95, 8, 97, 4, 95, 2, 66, 3, 88, 0, 19, 6, 94, 5, 99, 
    3, 56, 2, 70, 4, 61, 7, 55, 5, 58, 6, 87, 8, 60, 0, 43, 1, 95
  };
  const int q8375[] = {
    9, 9, // Number of jobs and machines
    5, 10, 6, 35, 3, 78, 1,  8, 4, 17, 8, 32, 0, 65, 2, 75, 7, 15, 
    0, 91, 5, 28, 1, 34, 7,  3, 6, 36, 3, 80, 4, 40, 8, 75, 2, 97, 
    0, 56, 3, 78, 6, 80, 1, 97, 5, 42, 2, 65, 8, 94, 7, 90, 4, 93, 
    5, 94, 4, 25, 8, 21, 3, 44, 7,  7, 2, 87, 0, 33, 6, 65, 1, 36, 
    5, 68, 2, 20, 0, 63, 8, 50, 1,  6, 6, 91, 3, 82, 4, 49, 7, 18, 
    4, 25, 3, 79, 0, 39, 7, 42, 5, 78, 8, 50, 6, 10, 1, 46, 2, 14, 
    5, 28, 7, 42, 1, 73, 3, 80, 4, 21, 2,  8, 0, 68, 8, 56, 6, 12, 
    4, 50, 5, 17, 8, 10, 3, 68, 7, 57, 2, 73, 6, 71, 0, 53, 1, 64, 
    1, 17, 6, 25, 4, 81, 8, 99, 7, 79, 5, 55, 0, 18, 2, 57, 3, 32
  };
  const int q8376[] = {
    9, 9, // Number of jobs and machines
    2, 14, 1, 49, 6, 25, 5, 45, 8,  9, 3, 53, 7, 53, 0, 55, 4, 99, 
    7, 46, 3, 48, 1, 57, 5, 54, 0,  7, 4, 23, 8, 19, 2, 81, 6, 54, 
    4, 76, 0, 79, 7, 75, 6,  2, 5, 68, 1, 52, 2, 93, 3, 60, 8, 32, 
    2, 97, 7, 75, 6, 57, 3, 72, 8, 83, 1, 59, 0,  5, 4,  1, 5, 21, 
    0, 69, 4, 18, 5, 14, 2, 82, 3,  9, 7, 22, 6, 12, 1, 27, 8, 28, 
    8, 75, 0, 19, 2, 49, 3, 55, 1, 84, 4, 44, 6, 80, 5, 75, 7, 18, 
    4, 97, 8, 25, 0, 92, 3, 14, 6,  5, 5, 42, 1, 19, 2, 30, 7, 36, 
    1, 58, 2, 93, 7, 57, 6, 30, 0,  7, 4, 69, 5, 49, 3, 27, 8, 59, 
    3,  5, 7, 18, 4,  6, 0,  3, 6, 83, 1, 55, 8, 71, 2, 52, 5, 77
  };
  const int q8377[] = {
    9, 9, // Number of jobs and machines
    8,  6, 3, 81, 1, 89, 4, 80, 5,  7, 2, 57, 0, 53, 7,  8, 6, 42, 
    8, 98, 7, 21, 4, 69, 5, 45, 0, 71, 1, 48, 3, 36, 6, 49, 2, 44, 
    1, 93, 7, 16, 0, 37, 5, 58, 6, 50, 3, 95, 8, 70, 2, 62, 4, 11, 
    5, 10, 2,  7, 4, 11, 1, 62, 3,  7, 8, 45, 7, 13, 0, 34, 6, 76, 
    0, 82, 3, 66, 4, 55, 2, 36, 5, 62, 7, 14, 6, 67, 8, 57, 1, 43, 
    4, 59, 5, 96, 1, 51, 2, 68, 3, 33, 6, 17, 0, 99, 7, 15, 8, 21, 
    3, 86, 7, 48, 8, 71, 4, 26, 2, 67, 6, 94, 0, 58, 1, 67, 5, 38, 
    5, 38, 8, 13, 2, 70, 6, 50, 4, 56, 0,  7, 7, 56, 1, 76, 3, 77, 
    4, 45, 8, 89, 3, 39, 0, 40, 1, 10, 2, 67, 5, 29, 6,  5, 7, 72
  };
  const int q8378[] = {
    9, 9, // Number of jobs and machines
    1, 64, 0, 59, 7, 51, 2, 10, 3, 66, 8, 30, 6, 40, 4, 10, 5, 38, 
    2, 71, 3, 29, 0,  3, 8, 12, 1, 39, 7, 78, 5, 54, 6, 41, 4, 45, 
    2, 77, 5, 93, 1, 79, 3, 29, 6, 44, 4, 43, 8, 23, 7, 65, 0, 56, 
    5, 44, 8, 37, 3, 21, 4, 32, 0, 11, 6, 25, 1, 44, 2, 45, 7, 33, 
    0, 35, 7, 91, 6, 70, 4,  4, 2, 34, 1,  5, 8, 66, 5, 19, 3, 49, 
    3,  7, 4, 78, 8, 93, 5, 87, 6, 63, 0, 21, 2,  4, 1, 65, 7, 53, 
    8, 20, 2, 35, 6, 20, 7, 52, 1, 97, 0, 73, 3, 53, 4,  8, 5, 26, 
    8, 74, 0, 74, 7, 73, 6, 47, 5, 86, 1, 97, 3, 44, 4, 34, 2, 61, 
    0, 60, 2, 79, 6, 37, 3, 59, 7,  2, 1, 50, 8, 57, 4, 55, 5, 30
  };
  const int q8379[] = {
    9, 9, // Number of jobs and machines
    1, 53, 6, 63, 8,  1, 5, 97, 0, 71, 2, 20, 3,  7, 7, 48, 4, 78, 
    3, 14, 1, 45, 5, 59, 8, 91, 7, 32, 0, 72, 6, 37, 2, 74, 4, 39, 
    1, 68, 3, 28, 4,  5, 6, 82, 8, 89, 7, 97, 5, 46, 0,  9, 2, 82, 
    4, 87, 8,  6, 2, 65, 3, 41, 5, 23, 1,  8, 0, 47, 6, 69, 7, 57, 
    3,  7, 7, 15, 2, 81, 8, 77, 4, 65, 6, 41, 0, 70, 5, 43, 1, 61, 
    4, 54, 1,  1, 5, 99, 6, 28, 0, 84, 8, 91, 3, 66, 2, 46, 7, 75, 
    7, 56, 6, 81, 2, 56, 4, 78, 5, 42, 3, 67, 1, 93, 0, 83, 8,  5, 
    8,  3, 0, 23, 3, 91, 4, 77, 2, 52, 1, 37, 5, 81, 6, 19, 7, 60, 
    8,  7, 0, 63, 4,  9, 1, 32, 5, 17, 7, 52, 2, 27, 3, 33, 6, 62
  };
  const int q8380[] = {
    9, 9, // Number of jobs and machines
    3, 86, 7, 22, 2,  2, 0, 99, 5, 33, 4,  3, 8, 78, 6, 40, 1, 24, 
    8, 32, 2, 26, 0, 83, 1, 69, 6, 78, 7, 72, 4,  7, 3,  9, 5, 47, 
    6, 94, 4, 67, 1, 99, 8, 41, 5, 81, 3, 79, 7, 67, 2, 71, 0, 99, 
    6, 68, 1, 93, 4, 59, 0,  1, 7,  8, 2, 59, 3, 54, 8, 34, 5, 56, 
    8, 53, 0, 53, 3, 25, 6, 65, 7, 32, 1, 21, 5, 27, 2, 21, 4,  9, 
    4, 94, 1, 67, 0, 56, 7, 38, 3, 63, 8, 81, 2, 42, 5, 54, 6, 30, 
    0, 93, 2, 68, 6, 44, 1, 27, 5, 46, 3,  9, 8, 99, 7, 54, 4, 77, 
    5, 50, 7, 16, 3, 91, 8, 13, 6, 48, 4, 46, 0, 92, 2, 48, 1, 95, 
    4, 12, 3,  5, 2, 94, 0, 77, 1, 62, 5, 83, 8, 95, 7, 95, 6, 88
  };
  const int q8381[] = {
    9, 9, // Number of jobs and machines
    2, 78, 0, 69, 5,  9, 4, 11, 7, 20, 3, 54, 6, 11, 8, 64, 1, 50, 
    0, 33, 7, 89, 3, 51, 8, 54, 4, 78, 2, 96, 6, 83, 1, 80, 5, 49, 
    8, 45, 7, 63, 0, 24, 1, 40, 3, 75, 4, 90, 5, 82, 6, 79, 2, 85, 
    3, 20, 4, 36, 6, 76, 7, 37, 2, 54, 5, 87, 1, 61, 0, 48, 8, 91, 
    6, 53, 8, 76, 7, 16, 5, 12, 0, 97, 1, 11, 3, 28, 2, 14, 4,  1, 
    6, 68, 3,  1, 1, 74, 2, 31, 4, 68, 7,  4, 0, 15, 5,  9, 8, 27, 
    5, 72, 1, 58, 3, 12, 6, 11, 2, 31, 0, 74, 8, 94, 7, 50, 4, 24, 
    8, 43, 7, 33, 4, 81, 5, 23, 0, 81, 1, 33, 6, 61, 2, 15, 3, 40, 
    2, 73, 6, 38, 7, 76, 1, 15, 0, 98, 3,  2, 4, 98, 5, 45, 8, 26
  };
  const int q8382[] = {
    9, 9, // Number of jobs and machines
    7,  6, 1, 17, 2, 68, 4, 95, 0,  8, 5, 93, 6, 51, 8, 38, 3, 73, 
    7, 57, 6, 46, 2, 82, 1, 30, 3, 74, 8, 33, 4, 53, 5, 74, 0, 62, 
    3, 86, 2, 46, 7, 48, 6, 92, 4, 88, 5,  5, 1, 66, 0, 44, 8, 40, 
    0, 77, 4, 99, 5, 93, 7, 44, 3, 12, 6, 91, 8,  9, 1, 58, 2, 80, 
    2, 94, 7, 28, 1, 31, 8, 38, 0, 28, 3, 42, 6, 88, 4, 52, 5, 15, 
    2, 32, 4, 89, 7,  6, 1, 77, 6, 25, 5, 73, 0, 66, 8, 84, 3, 62, 
    8, 22, 4, 77, 3, 98, 2, 54, 0, 98, 1, 75, 5,  2, 6, 88, 7, 83, 
    0, 81, 6, 87, 1, 42, 8,  7, 7, 24, 3, 78, 5, 66, 2, 26, 4, 71, 
    6, 38, 1, 44, 8, 46, 5,  6, 4, 36, 0, 74, 3, 10, 2, 79, 7, 96
  };
  const int q8383[] = {
    9, 9, // Number of jobs and machines
    2, 18, 7, 65, 6, 92, 5, 83, 4, 87, 3, 10, 0, 61, 1, 41, 8, 89, 
    4, 82, 0, 50, 3, 68, 1, 88, 5, 17, 2, 14, 6, 19, 7,  1, 8, 83, 
    0, 56, 7, 18, 1, 50, 4, 48, 5, 30, 8, 76, 2,  2, 3, 71, 6, 97, 
    1, 18, 2, 33, 7, 74, 5, 17, 8, 11, 4, 23, 6, 63, 0, 86, 3, 73, 
    8, 62, 7, 75, 2, 41, 4, 32, 3, 91, 5,  1, 1, 64, 0, 50, 6, 43, 
    7, 13, 5, 32, 3, 33, 2, 41, 1, 29, 4, 41, 6, 22, 8, 97, 0,  8, 
    7, 49, 0, 33, 4, 22, 8, 84, 3, 88, 1, 85, 2, 84, 6, 94, 5, 90, 
    2, 73, 4, 65, 0,  8, 5, 34, 1, 90, 8, 32, 6,  2, 3, 27, 7, 99, 
    3, 85, 1, 74, 2, 42, 4, 15, 7, 91, 8, 28, 0, 52, 6, 78, 5, 41
  };
  const int q8384[] = {
    9, 9, // Number of jobs and machines
    5, 53, 8, 69, 7, 73, 4, 66, 1,  5, 2, 85, 6, 87, 3, 43, 0, 81, 
    4, 79, 1, 83, 8, 66, 5, 66, 3, 23, 7, 17, 2, 28, 6,  1, 0, 98, 
    1, 65, 0, 15, 8, 32, 7, 60, 5, 41, 2, 82, 6, 23, 4, 11, 3, 68, 
    5, 56, 4, 31, 8,  1, 3, 63, 0, 45, 7, 58, 6, 85, 2, 50, 1, 77, 
    5,  7, 7, 56, 8, 47, 0, 53, 1, 65, 4, 86, 6, 97, 3,  4, 2, 28, 
    8, 95, 3,  6, 7, 94, 5, 45, 4, 92, 1, 48, 6, 40, 0, 82, 2, 51, 
    4, 12, 0,  3, 2, 83, 8, 63, 5, 46, 6, 20, 3, 92, 1, 47, 7, 75, 
    2, 99, 6, 56, 3, 19, 4, 90, 8, 74, 5, 53, 7, 82, 1, 82, 0, 99, 
    8, 79, 1, 91, 5, 62, 7, 56, 4, 87, 0, 65, 2, 47, 3, 49, 6,  1
  };
  const int q8385[] = {
    9, 9, // Number of jobs and machines
    1, 58, 6, 55, 7, 23, 2, 98, 5,  4, 8, 29, 4, 21, 0, 77, 3,  4, 
    2, 51, 6, 58, 0, 85, 8,  6, 4, 88, 3, 93, 5, 57, 1, 20, 7, 72, 
    8, 14, 7, 84, 4, 99, 0, 99, 3, 34, 6, 81, 1, 16, 2, 26, 5, 20, 
    3, 31, 6, 86, 0, 71, 8, 41, 4, 26, 1, 92, 5, 56, 2, 59, 7, 92, 
    3,  3, 2, 40, 6, 34, 8, 53, 5, 11, 0, 29, 1, 22, 7, 79, 4, 34, 
    2, 62, 7, 69, 6, 19, 1,  6, 4, 79, 8, 78, 0, 26, 3, 14, 5, 86, 
    5, 82, 6, 72, 1, 47, 7,  6, 0, 45, 8, 73, 4, 42, 3, 87, 2, 84, 
    3, 69, 1, 39, 4, 71, 5, 86, 7, 52, 6, 63, 8, 43, 2, 81, 0, 48, 
    2,  1, 8, 96, 0, 41, 6, 15, 4, 36, 5, 30, 1, 74, 7, 61, 3,  9
  };
  const int q8386[] = {
    9, 9, // Number of jobs and machines
    8, 68, 0, 71, 5,  8, 4, 38, 7, 51, 1, 47, 2, 76, 6, 29, 3, 26, 
    8, 82, 1, 37, 4, 48, 7, 30, 6, 35, 3, 51, 2, 18, 5, 10, 0, 34, 
    2, 54, 6, 71, 7,  8, 8,  5, 5, 64, 3,  7, 0, 17, 1, 86, 4, 26, 
    8, 35, 5, 27, 4, 99, 3, 81, 2, 80, 1,  6, 7, 68, 0,  8, 6, 12, 
    3,  8, 6, 68, 8, 43, 4, 76, 0, 70, 1, 26, 2, 10, 5, 77, 7,  1, 
    3, 56, 0, 96, 2, 20, 5, 76, 4, 40, 1, 39, 7, 54, 6, 77, 8, 38, 
    7,  8, 6, 17, 3, 86, 2, 53, 8, 70, 5,  3, 4, 88, 0, 11, 1, 45, 
    1, 87, 5, 15, 6, 97, 3, 82, 0, 60, 2, 36, 4, 85, 8, 77, 7, 96, 
    7, 69, 0, 34, 1, 81, 2, 98, 3, 44, 4, 62, 6, 67, 8, 14, 5, 98
  };
  const int q8387[] = {
    9, 9, // Number of jobs and machines
    8, 48, 5, 88, 7, 15, 3, 66, 4, 57, 6, 31, 2, 44, 1, 77, 0, 27, 
    6, 55, 7,  4, 8,  8, 4, 41, 5, 15, 2, 18, 1, 48, 0, 53, 3, 98, 
    0, 21, 8, 28, 7, 98, 4, 90, 5, 83, 3, 35, 6, 19, 2, 90, 1,  9, 
    4, 43, 5, 24, 1, 36, 8, 41, 0, 33, 6, 69, 7, 16, 2, 63, 3, 37, 
    6, 24, 4, 46, 3, 39, 2, 49, 8, 85, 1,  2, 5, 91, 7, 23, 0, 92, 
    8, 43, 2, 38, 4, 67, 5, 98, 1, 15, 7, 58, 0, 29, 6, 97, 3, 99, 
    4, 67, 5, 85, 2, 18, 0, 18, 3, 16, 7, 87, 1, 50, 6, 55, 8, 83, 
    8, 94, 3, 82, 7, 75, 2, 73, 4, 20, 0, 65, 5, 70, 6, 45, 1, 77, 
    4, 32, 2, 28, 8,  1, 5, 44, 6, 45, 1, 70, 0, 75, 3, 74, 7, 89
  };
  const int q8388[] = {
    9, 9, // Number of jobs and machines
    4, 19, 8,  6, 5, 94, 1, 94, 0, 91, 6, 89, 2, 34, 7, 76, 3, 98, 
    7, 34, 8, 92, 5, 39, 6,  7, 2, 16, 4, 98, 0, 47, 3, 85, 1, 20, 
    2, 27, 0, 69, 7, 70, 1, 20, 8, 42, 6, 44, 4, 89, 3, 63, 5, 27, 
    3, 89, 6, 94, 8, 63, 2, 54, 0, 88, 5, 68, 4, 23, 1, 36, 7, 32, 
    0, 81, 2, 81, 1,  9, 4, 60, 3, 98, 5, 75, 7,  7, 8, 77, 6, 48, 
    0, 88, 5, 23, 7, 34, 1, 32, 6, 41, 4, 75, 2, 19, 8, 27, 3, 89, 
    6, 65, 2,  7, 7, 84, 0, 30, 1, 63, 4, 63, 8, 29, 3, 52, 5, 86, 
    5, 46, 1, 56, 3, 16, 0, 43, 7, 54, 4, 40, 2, 96, 8, 51, 6, 27, 
    7, 63, 5, 60, 2, 73, 1, 50, 0, 45, 4, 64, 3, 69, 8, 10, 6, 58
  };
  const int q8389[] = {
    9, 9, // Number of jobs and machines
    6, 67, 8, 79, 2, 87, 0, 59, 1,  5, 4, 67, 5, 65, 7, 26, 3, 27, 
    1, 25, 6, 11, 0, 27, 5, 23, 2,  7, 3, 34, 8,  3, 4, 32, 7,  4, 
    8,  2, 2, 51, 6, 12, 0, 30, 7, 64, 4, 41, 1, 65, 5, 77, 3, 23, 
    4, 39, 3, 58, 7, 11, 8, 77, 0, 28, 5, 27, 2, 32, 6, 75, 1, 15, 
    7, 68, 6, 50, 5, 44, 0, 21, 8, 28, 4, 88, 3, 41, 1, 65, 2, 40, 
    6,  8, 2, 75, 0, 41, 4, 51, 1, 92, 8, 55, 3, 77, 5, 58, 7, 73, 
    1, 41, 4, 31, 5, 87, 3,  4, 7, 14, 8, 25, 6, 47, 2, 33, 0, 67, 
    3, 97, 7, 19, 8, 15, 0,  9, 1, 19, 2, 66, 4, 46, 6, 59, 5, 14, 
    8, 86, 5, 90, 1, 30, 4, 90, 3, 51, 0, 48, 2, 52, 7, 21, 6, 62
  };
  const int q8390[] = {
    9, 9, // Number of jobs and machines
    3, 63, 2, 26, 0, 64, 8, 88, 6, 55, 5,  6, 4, 83, 1, 29, 7, 55, 
    8, 21, 7, 35, 0, 94, 5, 11, 3, 75, 1, 50, 2, 58, 4, 85, 6, 27, 
    7, 58, 2, 71, 6, 17, 3, 94, 4, 99, 0, 93, 1, 59, 8, 21, 5, 62, 
    4, 18, 1, 68, 6, 91, 7, 32, 5, 59, 0, 91, 8, 77, 2, 12, 3, 25, 
    0, 20, 6, 28, 2, 80, 7, 91, 5, 26, 1, 84, 8, 19, 4, 49, 3, 81, 
    8, 47, 5, 79, 6, 79, 3, 59, 2, 37, 4, 73, 0,  4, 7, 29, 1, 19, 
    7, 21, 4,  3, 2, 19, 8, 84, 1, 83, 6, 62, 5, 42, 0, 70, 3, 53, 
    8, 56, 3, 42, 5, 85, 0, 96, 1,  2, 4, 93, 7, 80, 2, 49, 6, 95, 
    2, 70, 0, 24, 3, 61, 7, 62, 8, 40, 6, 98, 4, 89, 1,  3, 5,  1
  };
  const int q8391[] = {
    9, 9, // Number of jobs and machines
    0, 64, 1, 89, 8, 88, 7, 87, 2, 50, 5, 50, 6, 25, 3, 29, 4, 53, 
    0,  2, 6, 85, 5, 89, 1, 88, 2, 10, 7, 47, 3, 46, 8, 12, 4, 94, 
    0, 31, 3, 47, 8, 12, 2, 40, 4, 82, 6, 20, 5, 56, 1, 77, 7, 22, 
    0, 13, 3, 33, 8, 13, 7, 12, 4, 86, 2,  8, 6, 82, 1, 29, 5,  4, 
    4, 20, 5,  6, 7, 89, 3, 74, 8, 34, 2,  9, 0, 24, 6, 89, 1, 74, 
    0, 71, 4, 14, 2, 83, 8, 64, 1, 10, 7, 51, 5, 22, 6, 70, 3, 46, 
    1,  9, 2, 60, 6, 71, 8, 50, 5, 42, 4, 62, 3, 11, 7, 52, 0, 90, 
    6, 65, 2, 42, 5, 45, 7, 34, 1, 90, 3,  6, 4, 37, 8, 75, 0, 87, 
    3, 12, 8, 70, 7, 57, 6, 61, 0, 62, 1, 85, 2, 37, 5, 31, 4, 59
  };
  const int q8392[] = {
    9, 9, // Number of jobs and machines
    7, 81, 2, 53, 8, 85, 1, 15, 0, 49, 5, 64, 6,  3, 4, 43, 3, 13, 
    7, 53, 5, 78, 0, 94, 6, 13, 2, 77, 8, 27, 3, 20, 1, 55, 4, 26, 
    8, 90, 3, 93, 6, 65, 0, 62, 2, 53, 7, 80, 5,  2, 4, 88, 1, 92, 
    3, 34, 6, 72, 1, 80, 4,  5, 5, 17, 0, 90, 2, 51, 7, 12, 8,  4, 
    6,  2, 4, 81, 1, 16, 8, 56, 0, 85, 3, 27, 2, 32, 5, 38, 7, 24, 
    2, 35, 6, 17, 4, 41, 3, 44, 0, 96, 1, 44, 7, 45, 5, 93, 8, 75, 
    7, 64, 4, 98, 2,  1, 6, 27, 8,  8, 3, 98, 0, 92, 1,  9, 5, 35, 
    0, 58, 6, 23, 1,  5, 5, 11, 4, 76, 3, 58, 8, 59, 2, 47, 7, 96, 
    8, 98, 6, 50, 3, 55, 2,  9, 4, 87, 5,  3, 7, 12, 0, 28, 1, 61
  };
  const int q8393[] = {
    9, 9, // Number of jobs and machines
    5, 31, 1,  7, 7, 37, 2, 55, 4, 47, 0, 73, 8, 66, 3, 33, 6, 77, 
    7, 64, 1, 28, 6, 45, 2, 88, 0, 30, 5, 32, 3, 45, 8, 91, 4, 70, 
    7, 77, 8, 69, 3, 84, 1,  6, 0, 52, 6, 41, 5, 97, 4, 11, 2, 54, 
    2, 85, 7, 22, 8, 21, 1, 22, 3, 25, 4, 69, 5, 78, 6, 22, 0, 66, 
    7, 35, 5, 30, 3, 70, 6,  9, 0, 71, 1, 24, 2,  4, 4, 10, 8, 62, 
    4, 26, 6, 13, 2, 11, 7, 50, 5, 93, 3, 95, 1, 81, 0, 21, 8, 19, 
    5,  6, 1, 96, 4, 93, 3, 12, 8, 58, 6, 56, 2, 64, 0, 30, 7, 20, 
    1, 82, 3, 26, 0, 15, 4, 54, 2,  6, 7, 20, 8, 62, 5, 48, 6, 81, 
    2, 13, 8, 47, 7, 27, 4, 72, 3, 64, 5, 13, 6, 99, 0, 70, 1, 58
  };
  const int q8394[] = {
    9, 9, // Number of jobs and machines
    6, 82, 2, 35, 7, 78, 1, 92, 0, 37, 4, 64, 8, 73, 5, 96, 3, 63, 
    1, 40, 3, 24, 5, 91, 2, 23, 6, 40, 4, 58, 7, 32, 8,  2, 0, 34, 
    1, 99, 2, 48, 0, 39, 7, 97, 4,  6, 8, 17, 3,  1, 5, 90, 6, 83, 
    6, 67, 0, 36, 4, 81, 1, 30, 2, 28, 3, 99, 7, 36, 5, 41, 8, 27, 
    6, 82, 0, 99, 7, 17, 8,  9, 2, 29, 3, 61, 4,  3, 5, 16, 1, 35, 
    7, 93, 2, 20, 4, 76, 6, 92, 5, 49, 1, 12, 0, 77, 8, 87, 3, 78, 
    0,  1, 6, 70, 8, 20, 2, 47, 1,  7, 4, 60, 7, 13, 3, 60, 5, 94, 
    6, 27, 4, 51, 0, 13, 3, 70, 8,  1, 7, 20, 1,  2, 2, 68, 5, 63, 
    0, 88, 7, 19, 6, 52, 8,  6, 3, 30, 4, 69, 2,  6, 1, 98, 5, 21
  };
  const int q8395[] = {
    9, 9, // Number of jobs and machines
    7, 50, 2, 54, 1, 50, 6, 51, 3, 33, 0, 90, 8, 44, 4, 95, 5, 16, 
    0, 24, 7, 95, 8, 11, 6, 43, 1, 94, 4, 58, 3, 51, 5, 89, 2, 39, 
    2,  2, 5, 75, 3, 32, 1, 52, 7, 81, 0, 73, 8, 26, 6, 55, 4, 79, 
    7, 21, 5, 95, 8, 96, 4, 63, 0, 14, 2, 28, 3, 67, 6, 34, 1, 69, 
    0, 89, 7, 96, 3, 87, 5, 68, 1, 29, 4, 14, 2, 51, 8, 43, 6, 38, 
    6,  5, 2, 61, 7, 41, 5, 24, 8, 52, 3, 89, 4, 65, 1, 87, 0, 81, 
    1, 62, 8, 75, 5, 82, 3, 66, 4, 56, 2, 12, 0, 34, 7, 85, 6, 89, 
    7, 64, 3, 57, 8, 48, 1, 37, 0, 19, 6, 45, 2, 90, 5, 65, 4,  8, 
    3, 52, 4, 22, 1, 57, 8, 75, 0,  6, 5,  8, 2, 69, 6, 24, 7, 15
  };
  const int q8396[] = {
    9, 9, // Number of jobs and machines
    3, 43, 6, 90, 4, 43, 5, 20, 0, 49, 8, 79, 2, 27, 1, 86, 7, 16, 
    8, 16, 6, 45, 5,  8, 7, 65, 2, 83, 1, 91, 3, 17, 0, 11, 4,  4, 
    5,  6, 8,  3, 4, 42, 7, 42, 3, 88, 1, 61, 0, 69, 2, 57, 6, 78, 
    8,  8, 6, 85, 0, 38, 4, 33, 3, 47, 1, 89, 5,  3, 7, 80, 2, 94, 
    0, 20, 6, 70, 1, 26, 5, 95, 8, 95, 2, 30, 7, 99, 3, 78, 4, 92, 
    8, 62, 3, 98, 0, 28, 4, 66, 2, 74, 5, 89, 1, 83, 6, 63, 7, 94, 
    5, 99, 6, 80, 4, 70, 8, 13, 0, 77, 2, 82, 7, 11, 1, 27, 3, 77, 
    7,  4, 8, 36, 0, 85, 4, 72, 6,  2, 5, 93, 3, 66, 2,  6, 1, 89, 
    7, 64, 0, 83, 2, 24, 8, 10, 5, 33, 3, 65, 1, 19, 6, 35, 4,  7
  };
  const int q8397[] = {
    9, 9, // Number of jobs and machines
    6,  9, 3, 19, 1, 58, 0, 36, 5, 64, 2, 17, 4, 45, 7, 36, 8, 43, 
    4,  6, 8, 25, 5, 51, 1, 73, 3,  7, 2, 96, 7, 39, 6, 86, 0, 95, 
    6, 25, 8, 92, 4, 55, 1, 50, 2, 47, 5, 26, 0, 61, 3, 94, 7, 82, 
    7,  1, 0,  8, 8, 90, 1, 49, 2, 51, 5,  9, 3, 86, 6, 79, 4, 71, 
    2, 27, 0, 66, 5,  5, 4,  1, 6, 45, 1, 94, 3, 48, 7, 92, 8, 89, 
    4, 96, 8, 30, 2,  8, 3, 83, 0, 31, 7,  7, 6, 90, 5, 35, 1, 15, 
    5, 65, 2, 83, 4, 53, 6, 70, 3, 74, 1, 39, 7, 48, 0, 62, 8, 50, 
    1, 21, 8, 83, 6, 25, 7,  1, 2, 35, 4, 86, 3, 90, 5, 60, 0,  8, 
    0, 19, 6, 51, 3, 76, 1, 35, 5, 42, 2, 26, 4, 68, 7, 94, 8, 13
  };
  const int q8398[] = {
    9, 9, // Number of jobs and machines
    5, 38, 1,  1, 2, 47, 0,  7, 8, 52, 4, 91, 6,  6, 7, 20, 3, 23, 
    6, 81, 4, 69, 3, 50, 5, 68, 2, 26, 8,  8, 0, 83, 7, 34, 1, 40, 
    0, 74, 1,  2, 6, 17, 7, 16, 4, 61, 3, 72, 5, 49, 2, 80, 8, 41, 
    3, 49, 6, 56, 2, 46, 8, 20, 1, 37, 0, 92, 7, 81, 5, 14, 4, 34, 
    7, 22, 2, 42, 6, 66, 8, 87, 4, 75, 1, 55, 5, 42, 3, 75, 0,  9, 
    8, 81, 5, 92, 6, 21, 1, 67, 0, 76, 4, 88, 3, 82, 7,  6, 2, 88, 
    4, 15, 6, 89, 5, 22, 3, 28, 0,  4, 1, 34, 8, 89, 7, 98, 2, 94, 
    6,  1, 0, 18, 8, 57, 7, 50, 2, 35, 4, 77, 5, 98, 1, 16, 3,  3, 
    7, 30, 2, 51, 1, 15, 6,  6, 5, 57, 0, 51, 4, 89, 3, 95, 8, 87
  };
  const int q8399[] = {
    9, 9, // Number of jobs and machines
    3, 72, 0, 71, 5, 65, 1, 80, 8, 14, 2, 66, 4, 10, 7,  7, 6, 54, 
    5, 86, 2, 83, 8, 61, 6, 41, 4, 34, 0, 91, 7, 71, 3, 19, 1, 32, 
    2, 36, 6, 89, 1, 88, 8,  8, 3, 50, 0, 28, 5, 15, 4, 89, 7, 65, 
    5, 49, 8, 91, 0, 11, 6,  9, 3, 87, 7, 50, 1, 23, 4,  4, 2,  5, 
    6, 60, 0, 43, 3, 82, 8, 26, 2, 16, 7,  8, 4, 99, 5, 15, 1, 97, 
    8, 51, 5, 28, 3, 62, 2, 90, 4, 84, 0, 54, 6, 87, 7, 28, 1, 86, 
    7, 86, 0, 21, 1, 67, 4, 24, 3, 14, 2, 42, 8,  2, 6, 23, 5, 87, 
    6, 66, 8, 68, 4, 86, 7, 20, 3, 63, 2, 28, 0, 36, 1, 17, 5,  5, 
    4, 38, 0, 58, 1, 75, 7, 70, 5, 92, 6, 44, 2, 99, 3, 83, 8, 33
  };
  const int q8400[] = {
    9, 9, // Number of jobs and machines
    1, 33, 3, 73, 7, 91, 5, 87, 8, 71, 4, 95, 6, 66, 2, 99, 0, 90, 
    4, 28, 1, 82, 7, 57, 8, 90, 2, 22, 6, 47, 5, 13, 0, 43, 3, 80, 
    4, 49, 7, 90, 5, 69, 8, 55, 1, 57, 6, 48, 3, 96, 2, 86, 0, 16, 
    3, 37, 1, 19, 8,  3, 0, 32, 2, 49, 6, 65, 5,  3, 4, 48, 7, 14, 
    6, 91, 0, 46, 4, 41, 5, 14, 7, 64, 2, 81, 1, 62, 3, 15, 8, 67, 
    7, 68, 8, 77, 2, 85, 1, 14, 6, 51, 0, 49, 5, 90, 4, 75, 3, 83, 
    1, 85, 0, 28, 4, 12, 3, 28, 8, 26, 5, 34, 7, 65, 2, 63, 6, 11, 
    4, 59, 2, 34, 3, 80, 1, 89, 8, 13, 7, 39, 6, 97, 0, 28, 5, 27, 
    4, 93, 6, 15, 3, 69, 7, 81, 0,  1, 1, 51, 5, 47, 2, 82, 8, 64
  };
  const int q8401[] = {
    9, 9, // Number of jobs and machines
    5, 79, 6, 78, 8, 99, 4,  6, 3, 15, 0, 38, 1, 24, 7, 37, 2,  8, 
    5, 58, 0, 84, 1, 64, 4, 42, 3, 71, 7, 35, 2, 15, 6, 69, 8, 24, 
    5, 66, 2, 47, 7, 86, 4, 89, 0, 37, 6, 97, 3, 83, 8, 77, 1, 71, 
    0, 93, 3, 32, 1, 98, 7, 88, 6, 26, 5, 61, 2, 54, 4, 50, 8, 38, 
    5, 36, 1, 77, 7, 43, 2,  1, 3, 49, 0, 80, 4, 27, 8, 85, 6, 17, 
    0, 54, 3, 83, 1, 84, 2, 31, 8, 85, 4, 77, 5, 12, 7, 53, 6,  6, 
    0, 85, 4, 16, 2, 19, 3, 69, 5, 25, 6, 29, 7, 44, 8, 68, 1,  4, 
    1, 69, 6, 76, 8, 92, 5, 61, 7, 23, 2, 88, 0, 33, 4, 29, 3, 15, 
    5, 88, 8, 97, 4, 52, 2, 54, 7, 98, 6, 40, 1, 95, 0, 30, 3,  2
  };
  const int q8402[] = {
    9, 9, // Number of jobs and machines
    7, 93, 0, 12, 8, 55, 1, 48, 5, 66, 4, 56, 2, 17, 3,  9, 6, 29, 
    4, 29, 0, 19, 7, 49, 2, 90, 5, 52, 8, 55, 1, 15, 3, 30, 6,  4, 
    4, 70, 1,  9, 2,  7, 3, 85, 6, 77, 0, 54, 8, 24, 7, 32, 5, 25, 
    3, 71, 8, 81, 7, 64, 4, 89, 6, 60, 0, 88, 1, 63, 5, 36, 2, 49, 
    3, 83, 6, 20, 7, 85, 2, 38, 8, 79, 5, 30, 4, 41, 0, 34, 1, 28, 
    4, 25, 6, 72, 1, 68, 7, 67, 0, 80, 8, 50, 3, 44, 5, 20, 2, 50, 
    0, 11, 4, 15, 5, 81, 3, 70, 2, 85, 7, 10, 8, 81, 6, 21, 1, 42, 
    6, 21, 8, 46, 4, 68, 7, 89, 3, 72, 1, 46, 5, 61, 0, 52, 2, 53, 
    0, 21, 5,  1, 2, 41, 3,  7, 4, 99, 7, 66, 6, 44, 8, 95, 1,  8
  };
  const int q8403[] = {
    9, 9, // Number of jobs and machines
    0, 74, 6, 15, 2, 50, 5,  8, 3, 20, 8, 26, 7,  2, 1, 82, 4, 77, 
    6, 33, 2, 71, 1,  2, 4, 31, 8, 81, 7, 65, 3, 67, 5, 47, 0,  1, 
    5, 15, 2, 97, 8, 52, 4, 43, 3, 13, 6,  1, 7, 17, 1,  4, 0,  5, 
    6, 65, 4, 86, 2, 26, 3, 64, 7,  5, 8, 55, 1,  8, 0, 54, 5,  1, 
    2, 40, 5, 10, 8, 60, 7, 27, 0, 61, 4, 42, 1, 23, 3, 50, 6,  9, 
    2, 87, 4, 76, 5, 57, 1, 34, 3, 72, 0, 86, 7, 82, 8, 69, 6,  8, 
    3, 77, 7,  6, 0, 64, 1, 87, 6, 79, 2, 43, 4, 46, 8, 35, 5, 89, 
    4, 97, 7,  9, 2, 72, 1,  5, 5, 12, 3, 88, 6, 51, 8, 76, 0, 20, 
    7, 21, 5, 95, 0, 60, 6,  1, 2, 54, 3,  3, 4, 94, 8, 29, 1, 20
  };
  const int q8404[] = {
    9, 9, // Number of jobs and machines
    2, 92, 7, 69, 1, 40, 0, 59, 6, 67, 8, 80, 4, 47, 5, 59, 3, 71, 
    7, 28, 3,  4, 5, 84, 4, 77, 0, 83, 1, 21, 2, 46, 8, 31, 6, 10, 
    7, 99, 4, 95, 8, 77, 5, 94, 1,  2, 6, 84, 2, 63, 3, 28, 0, 51, 
    8, 10, 6, 17, 2, 72, 7, 23, 3, 84, 4, 47, 1, 68, 5, 85, 0, 23, 
    5, 46, 8, 97, 1, 78, 3,  8, 4,  9, 2, 39, 6, 14, 0, 94, 7, 64, 
    8, 73, 5, 43, 2, 47, 1,  4, 3, 74, 6, 70, 0, 42, 4, 40, 7,  4, 
    6, 16, 7, 91, 1, 15, 5,  8, 2,  3, 3, 82, 4, 38, 0,  9, 8, 40, 
    1, 79, 0, 50, 6, 42, 4, 95, 8, 34, 5, 33, 7, 44, 2, 84, 3, 60, 
    5, 79, 2, 38, 7, 99, 1, 63, 0, 23, 4, 99, 8, 34, 6, 89, 3, 98
  };
  const int q8405[] = {
    9, 9, // Number of jobs and machines
    1, 80, 8, 65, 2, 67, 7, 81, 3,  7, 5, 86, 0, 85, 6, 69, 4, 27, 
    5,  3, 0, 87, 1, 85, 8, 99, 7, 87, 2, 21, 4, 94, 6, 15, 3, 16, 
    6,  9, 2, 12, 3, 11, 1, 91, 8, 25, 4, 59, 5, 92, 7,  3, 0,  1, 
    4, 59, 3, 87, 6, 53, 7, 82, 1, 59, 2, 29, 8, 39, 5, 52, 0, 51, 
    0, 73, 2, 61, 4, 79, 1, 79, 5, 86, 7, 75, 3,  2, 6, 19, 8, 14, 
    6, 32, 7, 35, 8, 39, 1, 97, 3, 61, 0, 55, 2, 28, 4, 33, 5, 51, 
    7, 21, 0, 37, 4, 64, 6, 71, 2, 21, 8, 19, 3, 74, 1, 98, 5, 23, 
    4, 27, 1, 26, 6, 47, 8, 97, 2, 61, 7, 56, 3, 56, 5, 97, 0, 52, 
    6, 36, 3, 41, 4, 89, 7, 32, 8, 45, 2,  8, 1, 61, 0, 42, 5, 69
  };
  const int q8406[] = {
    9, 9, // Number of jobs and machines
    4, 53, 8, 91, 2, 88, 7, 56, 5, 54, 0, 39, 6, 77, 1, 52, 3,  5, 
    3,  7, 2,  6, 0, 53, 1, 18, 8, 17, 6, 92, 4, 69, 5, 62, 7, 42, 
    8, 86, 3, 75, 2, 25, 0, 76, 1, 30, 4, 94, 6, 59, 7, 11, 5, 44, 
    0, 55, 5, 52, 7, 19, 8, 14, 6, 86, 3, 82, 2, 46, 1, 25, 4, 69, 
    8, 61, 4, 42, 7, 55, 5, 19, 0, 15, 2, 33, 1, 28, 3, 28, 6, 58, 
    0, 33, 7, 98, 2, 41, 5, 86, 4, 27, 3, 99, 8,  3, 6, 22, 1, 46, 
    1, 51, 7, 39, 5, 22, 6, 78, 8, 71, 4,  7, 2, 80, 3, 81, 0,  8, 
    5, 46, 1,  2, 3, 52, 8, 59, 6, 53, 4, 49, 2, 60, 7, 29, 0, 34, 
    1, 42, 2, 49, 6, 20, 0,  9, 7, 90, 8,  3, 3, 23, 5, 38, 4, 44
  };
  const int q8407[] = {
    9, 9, // Number of jobs and machines
    3, 88, 0, 70, 2, 91, 6, 96, 8, 25, 4, 38, 7, 64, 5, 82, 1, 18, 
    0, 10, 1,  8, 5, 64, 4, 58, 8, 25, 7, 16, 6, 98, 2, 92, 3, 61, 
    6, 73, 3, 33, 5, 75, 8, 28, 4, 72, 2, 98, 1, 47, 7, 20, 0, 28, 
    1,  2, 2, 96, 4, 66, 8, 58, 5, 37, 7, 72, 0, 59, 3, 76, 6, 10, 
    0, 25, 2, 19, 5, 37, 7, 49, 3, 68, 6, 25, 8, 51, 4, 92, 1, 31, 
    1, 63, 0,  6, 7,  9, 6, 93, 8, 82, 3, 73, 2, 76, 4, 55, 5, 48, 
    4, 65, 2, 63, 6, 61, 7, 61, 8, 47, 5, 56, 0, 98, 1, 13, 3, 65, 
    5, 74, 8, 50, 7, 65, 3, 43, 6, 70, 0, 44, 2, 62, 4, 46, 1,  9, 
    0, 71, 4, 26, 7, 59, 5, 87, 6, 87, 2,  6, 3, 27, 8, 59, 1, 39
  };
  const int q8408[] = {
    9, 9, // Number of jobs and machines
    4, 95, 2, 64, 1, 26, 3, 98, 8, 59, 5,  4, 0, 49, 6, 45, 7, 13, 
    2, 51, 3, 47, 1, 55, 7, 99, 5, 52, 6, 70, 8, 53, 4, 23, 0,  9, 
    1,  3, 2, 45, 0, 92, 5, 18, 7, 30, 3,  6, 6, 44, 8, 45, 4, 59, 
    5, 77, 3, 85, 8, 66, 1, 28, 6, 40, 0, 11, 2, 89, 7, 23, 4, 73, 
    2, 69, 4, 49, 3, 15, 5, 57, 7,  6, 0, 78, 6, 10, 8, 37, 1, 25, 
    4, 91, 8, 49, 3, 99, 7, 32, 1, 64, 6, 93, 2, 74, 0, 84, 5, 44, 
    8, 67, 0,  5, 4, 27, 1, 55, 5, 63, 3, 42, 2, 16, 6, 69, 7, 61, 
    1, 47, 5, 95, 8, 29, 3, 51, 0, 66, 6,  9, 7,  3, 2, 53, 4,  5, 
    7, 89, 3, 72, 0, 70, 1, 28, 6, 93, 4, 13, 5, 36, 2, 55, 8, 32
  };
  const int q8409[] = {
    9, 9, // Number of jobs and machines
    6, 84, 1, 58, 0, 15, 2, 20, 5, 84, 7, 87, 3, 79, 8, 63, 4, 56, 
    0, 23, 3, 52, 6, 47, 1, 20, 5, 32, 2, 20, 7, 46, 8, 75, 4, 87, 
    2, 78, 8, 39, 5, 25, 7, 16, 6, 36, 0, 90, 1, 14, 3, 25, 4, 53, 
    3, 82, 1, 72, 4, 36, 7, 76, 2, 10, 8, 97, 0, 73, 5, 58, 6, 93, 
    2, 80, 3, 10, 4,  5, 8, 61, 1, 21, 6,  1, 5, 79, 0, 87, 7, 50, 
    5, 20, 3, 72, 6, 50, 2, 34, 7, 11, 1, 81, 8, 28, 0, 59, 4, 74, 
    3, 57, 2,  2, 5, 70, 6, 44, 7, 15, 0, 38, 4,  3, 1, 93, 8, 77, 
    4, 53, 5, 83, 0, 17, 3, 89, 7, 59, 8,  9, 2, 31, 1, 23, 6, 91, 
    2, 41, 0, 56, 3, 90, 5, 52, 7, 50, 4, 81, 1, 93, 8, 22, 6, 67
  };
  const int q8410[] = {
    9, 9, // Number of jobs and machines
    7, 27, 8, 44, 1, 42, 4, 90, 2, 80, 0, 69, 3, 16, 5, 20, 6, 10, 
    4, 50, 5, 28, 8, 81, 1, 70, 3, 92, 2, 47, 6,  6, 0, 75, 7, 15, 
    0,  6, 3, 20, 2, 16, 6, 18, 1, 80, 8, 37, 4, 36, 5, 83, 7,  7, 
    0, 62, 1, 51, 3, 39, 7, 23, 2, 47, 6, 26, 8, 98, 5, 89, 4,  6, 
    1, 40, 5, 62, 4, 88, 3, 57, 8, 17, 2, 60, 0, 50, 7, 33, 6, 52, 
    2, 31, 5, 16, 8, 93, 6, 24, 4, 91, 7, 65, 3, 94, 1, 81, 0, 49, 
    3, 90, 0,  8, 1, 94, 7,  9, 2, 72, 8, 76, 6,  1, 4,  3, 5, 15, 
    5, 32, 1, 41, 0, 90, 6, 51, 2, 67, 7, 34, 4,  8, 8, 91, 3, 13, 
    1, 13, 3, 70, 6, 64, 0, 95, 8,  1, 2, 99, 5,  1, 7, 75, 4, 24
  };
  const int q8411[] = {
    9, 9, // Number of jobs and machines
    8, 49, 0, 94, 7, 98, 4, 98, 2,  2, 3, 28, 6, 85, 1, 91, 5, 33, 
    1, 12, 2, 86, 5, 81, 8, 45, 3, 63, 6, 96, 7, 43, 4, 70, 0,  9, 
    2, 92, 1, 27, 5, 40, 7, 57, 3, 14, 4, 89, 0, 80, 8, 74, 6, 74, 
    8, 52, 4, 59, 6, 10, 7, 26, 2, 22, 1, 16, 5, 65, 3, 68, 0, 92, 
    6, 94, 5, 95, 1, 65, 0, 88, 2, 44, 4, 43, 8, 76, 3,  9, 7, 71, 
    7, 57, 6, 95, 2, 82, 8, 57, 3, 26, 4, 29, 0, 43, 1, 78, 5, 32, 
    4, 83, 0, 26, 2,  9, 3, 36, 1, 97, 7, 67, 6, 10, 5, 70, 8, 38, 
    1, 75, 0, 64, 2,  6, 5, 56, 7, 25, 8, 71, 6, 11, 4, 57, 3,  1, 
    8, 82, 5, 20, 3, 32, 1, 29, 6, 97, 2, 32, 4, 65, 0, 18, 7, 97
  };
  const int q8412[] = {
    9, 9, // Number of jobs and machines
    6, 56, 3, 90, 8, 10, 1, 74, 2,  5, 7, 72, 5, 54, 0, 99, 4,  8, 
    3,  9, 1, 99, 2, 53, 7, 89, 6, 58, 4, 23, 5, 23, 0, 25, 8, 43, 
    1, 54, 8, 81, 0, 37, 5, 17, 3, 78, 7, 69, 6, 17, 4, 20, 2, 68, 
    7, 91, 1, 22, 5, 33, 2, 97, 3, 16, 4, 72, 0, 32, 8, 98, 6, 42, 
    8, 55, 4, 32, 6, 47, 1, 14, 2, 61, 0, 82, 7, 68, 3, 82, 5, 62, 
    4, 46, 3, 79, 8, 36, 7, 71, 6, 51, 0, 90, 1, 74, 5, 18, 2, 97, 
    0, 26, 5,  2, 6, 79, 2, 57, 4, 53, 8, 87, 7, 65, 1, 67, 3, 15, 
    0, 72, 8, 69, 4, 25, 2, 65, 3,  7, 7, 95, 1, 20, 6, 26, 5, 74, 
    5, 52, 6, 71, 1, 16, 7,  1, 2, 89, 0, 77, 4, 49, 8, 17, 3, 19
  };
  const int q8413[] = {
    9, 9, // Number of jobs and machines
    5, 76, 3, 14, 1, 26, 4, 96, 6, 56, 7, 49, 8,  6, 2, 96, 0, 10, 
    1, 84, 2, 63, 0, 69, 6, 88, 8, 45, 5, 62, 3, 41, 7, 44, 4, 97, 
    0, 94, 7, 55, 8, 19, 6, 20, 2, 75, 3, 53, 4, 48, 1, 88, 5, 14, 
    5, 78, 8, 88, 4, 56, 1, 98, 0, 91, 2, 99, 3, 30, 6, 76, 7, 71, 
    0, 10, 8, 22, 6, 33, 7, 15, 3,  5, 5, 13, 4, 30, 2, 75, 1, 82, 
    5, 70, 2, 75, 0, 34, 4, 97, 7, 20, 6, 26, 8, 26, 1, 46, 3, 30, 
    5, 66, 8, 78, 2, 53, 3, 60, 6, 92, 0, 88, 7, 51, 4,  5, 1, 56, 
    7, 56, 6, 54, 4, 60, 2,  8, 0, 51, 8, 34, 1, 80, 5, 70, 3, 52, 
    1, 30, 3, 76, 7, 50, 4, 36, 2, 65, 8, 13, 6, 84, 0, 45, 5, 36
  };
  const int q8414[] = {
    9, 9, // Number of jobs and machines
    0, 45, 7, 29, 5, 81, 8, 96, 1, 82, 6, 66, 3, 29, 2, 37, 4, 21, 
    2, 45, 8, 36, 0,  5, 6,  1, 4, 87, 5, 91, 3, 48, 7, 88, 1, 31, 
    8, 21, 0, 58, 6, 98, 4, 46, 5, 39, 3, 66, 1, 79, 7, 72, 2, 27, 
    5, 28, 2, 18, 1, 73, 3, 13, 7, 93, 4, 50, 0, 13, 8, 53, 6, 67, 
    3, 50, 7, 49, 0, 11, 8, 26, 4, 92, 6, 63, 1,  2, 2, 14, 5, 36, 
    7, 50, 8, 49, 5, 89, 3, 72, 2, 18, 4, 49, 6, 89, 1, 83, 0, 98, 
    4, 61, 5, 89, 8, 65, 0, 84, 2, 64, 3, 64, 7, 68, 1, 31, 6, 46, 
    2, 62, 8, 62, 4, 47, 7, 56, 3, 45, 5, 30, 1, 46, 0, 18, 6, 21, 
    7, 28, 1, 35, 4, 43, 0,  3, 8, 37, 6, 30, 2, 49, 5, 44, 3, 24
  };
  const int q8415[] = {
    9, 9, // Number of jobs and machines
    5, 10, 1, 99, 6,  1, 0, 41, 2, 94, 4, 93, 3, 97, 7, 88, 8, 32, 
    1, 67, 5, 90, 6, 37, 2, 79, 3, 74, 8, 17, 7, 78, 0, 90, 4, 43, 
    6, 87, 2,  4, 1, 10, 0, 61, 8, 46, 7, 18, 5, 99, 4, 39, 3, 97, 
    2, 53, 1, 12, 5, 59, 4,  5, 7, 53, 6, 61, 8,  9, 0, 26, 3, 26, 
    3, 87, 1, 81, 8, 96, 2,  5, 0, 74, 4, 91, 5, 49, 7, 77, 6, 55, 
    8, 77, 3, 32, 6, 54, 7, 76, 0,  3, 4, 18, 2, 99, 1,  6, 5,  4, 
    8, 20, 3, 59, 6, 51, 2,  8, 5, 92, 1, 53, 0, 54, 7, 49, 4, 32, 
    7,  1, 6, 10, 0,  6, 3, 55, 1, 44, 2, 34, 5, 57, 4, 27, 8, 23, 
    6, 81, 2, 67, 3, 82, 5, 76, 4, 20, 8, 73, 7, 97, 0, 77, 1, 59
  };
  const int q8416[] = {
    9, 9, // Number of jobs and machines
    5, 84, 8, 21, 0, 48, 1, 56, 2, 32, 4, 21, 6,  4, 7,  3, 3, 93, 
    7, 81, 3, 80, 6, 91, 4, 49, 1, 52, 2, 19, 0, 12, 8, 53, 5, 93, 
    3,  8, 2, 74, 7, 85, 5, 69, 6, 10, 8, 30, 4, 62, 1, 48, 0, 34, 
    1, 12, 5, 94, 7, 44, 6, 97, 3, 66, 0, 54, 2, 10, 4, 71, 8, 43, 
    5, 63, 1, 36, 6, 61, 0, 85, 4, 90, 8,  2, 3, 95, 2, 58, 7, 38, 
    4, 54, 8, 19, 2, 30, 0, 45, 5, 70, 7, 76, 6, 59, 3,  7, 1, 25, 
    6, 82, 4, 17, 1,  4, 3, 91, 7, 28, 2, 80, 8, 80, 0, 36, 5, 93, 
    8, 67, 1, 91, 2, 27, 7, 86, 5, 16, 6, 66, 4, 44, 3,  5, 0, 61, 
    3, 47, 0, 19, 2, 13, 6, 60, 7,  4, 4, 40, 8,  9, 1, 71, 5, 29
  };
  const int q8417[] = {
    9, 9, // Number of jobs and machines
    2, 71, 7, 94, 3,  9, 5, 43, 0,  3, 6, 49, 4, 16, 1, 84, 8, 28, 
    5, 26, 0, 19, 4, 51, 7, 87, 2, 97, 1, 24, 3,  4, 8, 56, 6, 66, 
    8, 97, 3, 88, 0, 31, 1, 78, 7, 98, 6, 27, 4, 60, 2, 59, 5, 29, 
    7, 41, 6, 63, 3, 90, 8, 30, 0, 59, 1, 60, 4, 62, 5, 55, 2, 93, 
    3, 99, 2, 38, 8, 51, 4, 29, 5, 46, 0, 64, 6,  6, 7, 24, 1, 10, 
    7, 19, 8,  1, 6, 15, 5, 40, 2, 64, 0, 58, 3, 38, 1, 16, 4, 14, 
    6,  2, 1, 36, 0, 81, 2, 12, 7, 92, 5, 82, 4, 66, 3, 88, 8, 72, 
    1, 94, 3, 35, 5, 75, 4, 33, 7, 34, 0, 88, 2, 39, 6, 46, 8, 99, 
    6, 37, 0, 76, 7,  4, 5, 88, 4, 94, 8, 73, 3, 66, 2, 56, 1, 38
  };
  const int q8418[] = {
    9, 9, // Number of jobs and machines
    4, 38, 3, 22, 6, 19, 0,  7, 5,  2, 1, 72, 8, 32, 2, 18, 7, 80, 
    1, 78, 2, 39, 4, 24, 7, 40, 8,  7, 3, 70, 0, 46, 6, 98, 5, 60, 
    2, 41, 5, 92, 7, 38, 6, 39, 8, 95, 4, 79, 1, 87, 0, 23, 3,  6, 
    6, 80, 4, 46, 0, 35, 7, 30, 2, 21, 3, 42, 8, 29, 5, 43, 1, 54, 
    4, 61, 5,  8, 1, 98, 3, 75, 0, 48, 8, 32, 7, 86, 2, 35, 6, 41, 
    1, 76, 6, 36, 5, 42, 2, 35, 7, 63, 0, 12, 4, 54, 3, 77, 8, 54, 
    5, 35, 4, 66, 0, 75, 1, 40, 3, 50, 7, 11, 8, 50, 6, 84, 2, 11, 
    4,  9, 6, 35, 1, 25, 8, 76, 7,  6, 0, 89, 3, 65, 5, 95, 2, 18, 
    6, 94, 4, 97, 0, 37, 2,  1, 1, 86, 7, 65, 8, 54, 5, 82, 3, 93
  };
  const int q8419[] = {
    9, 9, // Number of jobs and machines
    1, 65, 4, 54, 5, 20, 0, 34, 6, 33, 3, 90, 7, 46, 8, 82, 2, 79, 
    6,  1, 4, 59, 0, 16, 3, 64, 7, 45, 8, 97, 5, 70, 2, 34, 1, 71, 
    0, 73, 6,  1, 1, 77, 4, 87, 8, 96, 3, 64, 2, 67, 7, 54, 5, 40, 
    1, 71, 6, 36, 7, 69, 4, 19, 0,  1, 2,  9, 3, 85, 8, 75, 5, 53, 
    4, 10, 3, 41, 8, 57, 1, 53, 5, 36, 7, 79, 0,  8, 2, 99, 6, 64, 
    8, 71, 0, 18, 5, 77, 1, 60, 2, 33, 7, 83, 4, 32, 3, 93, 6, 63, 
    7,  7, 0, 91, 4, 81, 5, 64, 1, 30, 6,  1, 8, 78, 2, 66, 3, 99, 
    2, 13, 6, 81, 8, 12, 7, 64, 0, 42, 3, 50, 4,  9, 1,  9, 5, 64, 
    3,  2, 7, 64, 1, 95, 8, 31, 0, 98, 2, 19, 4, 95, 5, 79, 6,  9
  };
  const int q8420[] = {
    9, 9, // Number of jobs and machines
    5, 76, 3,  3, 4, 86, 8, 90, 6, 45, 2, 70, 7, 63, 1, 10, 0, 24, 
    3, 85, 1, 90, 4, 50, 0, 40, 2, 89, 6, 41, 8, 63, 5, 27, 7, 18, 
    8, 45, 3, 25, 7, 75, 2, 42, 5, 85, 0, 34, 1, 45, 6, 98, 4, 86, 
    3, 40, 0, 65, 7, 12, 1, 68, 4,  9, 8,  8, 5, 80, 6,  5, 2, 14, 
    0, 53, 4, 44, 1, 94, 6, 37, 3, 46, 8, 44, 5, 10, 2, 69, 7, 15, 
    7, 80, 1, 89, 8, 74, 0, 23, 5, 74, 6, 91, 3, 12, 4, 67, 2, 63, 
    1,  9, 4, 15, 8, 61, 5, 97, 6, 84, 2, 82, 7, 93, 0,  9, 3, 45, 
    7, 56, 8, 46, 3, 74, 1, 48, 6, 64, 0, 80, 2, 24, 5, 66, 4,  1, 
    8, 25, 7, 10, 3, 83, 5, 67, 0, 47, 6, 90, 2, 52, 1, 51, 4, 83
  };
  const int q8421[] = {
    9, 9, // Number of jobs and machines
    1, 47, 6, 18, 4, 32, 2, 71, 8, 59, 5, 40, 3, 44, 0, 47, 7, 74, 
    2,  2, 8, 59, 1, 15, 5,  5, 0, 32, 4, 64, 6, 42, 3, 20, 7, 56, 
    6, 17, 4, 23, 0, 57, 1, 19, 5,  5, 3, 40, 7, 65, 2, 15, 8, 46, 
    4, 46, 8, 86, 6, 15, 7, 97, 2, 93, 5, 26, 1, 98, 3, 54, 0, 85, 
    0, 89, 2, 73, 1, 88, 8, 66, 6, 38, 3, 23, 5, 66, 7, 11, 4, 54, 
    6, 23, 8, 71, 2, 41, 0, 58, 4, 81, 7, 90, 5, 41, 3, 72, 1, 25, 
    3, 49, 7, 90, 6, 75, 5, 70, 0, 17, 8, 96, 4, 17, 2, 79, 1, 29, 
    6, 75, 8, 42, 0, 28, 1,  7, 2, 69, 5,  6, 3, 40, 7,  8, 4, 90, 
    1, 53, 6, 10, 0,  6, 4,  1, 8, 63, 7, 84, 2,  3, 3, 79, 5, 87
  };
  const int q8422[] = {
    9, 9, // Number of jobs and machines
    4, 18, 0, 73, 2, 36, 7, 98, 1, 89, 8, 32, 3,  8, 6, 57, 5, 79, 
    8,  8, 5, 71, 4,  2, 0, 81, 6,  5, 7, 19, 2, 24, 1, 49, 3, 72, 
    5, 50, 1,  2, 4, 50, 2, 14, 7, 14, 6, 73, 8,  5, 3, 37, 0, 99, 
    6, 68, 3, 98, 0, 88, 2, 14, 1, 44, 4, 29, 7, 49, 8, 80, 5, 96, 
    8, 50, 1, 86, 6, 16, 4, 20, 3, 47, 2, 43, 7, 34, 5, 23, 0, 77, 
    7, 31, 4, 51, 5, 81, 0, 93, 3, 39, 8, 74, 6, 51, 1,  5, 2, 76, 
    3, 12, 8, 11, 7, 52, 0, 45, 6, 68, 2, 25, 5, 87, 4, 80, 1,  5, 
    2, 18, 5, 14, 1, 61, 0, 65, 8, 47, 3, 30, 7,  9, 4, 68, 6, 51, 
    8, 69, 2, 67, 0, 57, 1, 94, 4, 55, 6, 95, 7, 83, 3, 96, 5, 93
  };
  const int q8423[] = {
    9, 9, // Number of jobs and machines
    4, 68, 7, 59, 0, 12, 3, 80, 6, 54, 1, 52, 5, 32, 8,  4, 2, 84, 
    2, 46, 5, 19, 4, 83, 8, 60, 7,  5, 3, 37, 6,  9, 1, 48, 0, 59, 
    5, 90, 8, 38, 7,  6, 6, 37, 0, 44, 2, 56, 4, 48, 1, 86, 3, 36, 
    7, 30, 1, 38, 3,  9, 5, 77, 6, 29, 4,  1, 8, 92, 0, 34, 2, 29, 
    3, 78, 4, 92, 5, 76, 7, 36, 2, 15, 8, 59, 1, 29, 6, 78, 0,  5, 
    3, 50, 1, 25, 5, 38, 4, 29, 8, 34, 0, 81, 2, 97, 7, 65, 6, 89, 
    3, 68, 4, 64, 2, 99, 5, 69, 0,  7, 6,  1, 1, 28, 8,  2, 7, 97, 
    5, 87, 2,  8, 4,  3, 0, 38, 1, 21, 6,  5, 3, 87, 8, 82, 7,  1, 
    5, 18, 2, 40, 6, 80, 3, 83, 1, 51, 8, 47, 7, 21, 4, 56, 0, 24
  };
  const int q8424[] = {
    9, 9, // Number of jobs and machines
    1,  6, 0, 38, 4, 51, 5, 22, 8, 37, 2, 29, 3, 71, 7, 88, 6, 61, 
    5, 86, 8, 90, 6, 17, 7,  1, 2, 57, 3, 25, 0, 85, 1, 26, 4, 46, 
    3, 93, 4, 74, 5, 22, 7, 77, 8, 59, 0, 99, 1, 51, 2, 77, 6,  1, 
    1, 87, 2, 99, 3, 23, 8, 31, 4, 87, 6, 47, 7, 63, 0, 17, 5, 99, 
    4,  5, 5, 58, 1, 69, 2, 97, 3, 39, 0, 52, 7, 22, 8, 27, 6, 29, 
    5, 24, 1, 61, 8, 80, 7, 29, 2,  4, 4, 70, 6, 55, 3, 16, 0, 17, 
    1, 13, 7,  4, 6, 41, 5, 96, 2, 48, 8, 32, 3, 32, 4, 24, 0, 16, 
    4, 97, 6, 35, 7, 29, 3, 48, 1, 77, 5, 60, 2, 71, 8, 97, 0, 26, 
    4, 45, 6, 37, 8, 43, 0, 75, 1, 41, 2, 24, 3, 88, 7, 36, 5,  2
  };
  const int q8425[] = {
    9, 9, // Number of jobs and machines
    5, 97, 3, 99, 7, 56, 0, 65, 6, 33, 4, 64, 1, 51, 8, 58, 2, 48, 
    3,  4, 6, 12, 8, 98, 2, 97, 5, 37, 0,  2, 1, 25, 4, 25, 7, 71, 
    7, 47, 3, 50, 0, 52, 4, 30, 5, 93, 8,  3, 2, 15, 6, 65, 1, 83, 
    7, 17, 8, 63, 5, 23, 6, 94, 3, 98, 2, 94, 1, 28, 0, 99, 4, 60, 
    0, 47, 8, 87, 1, 70, 6,  3, 7, 12, 2, 31, 3, 50, 4, 73, 5, 67, 
    5, 89, 1, 27, 2, 78, 6, 56, 0, 83, 8, 24, 7, 65, 4, 47, 3, 62, 
    6, 68, 7, 17, 5, 96, 2, 45, 3, 63, 8, 72, 4, 14, 1, 53, 0, 61, 
    2, 88, 7, 80, 8, 28, 0, 82, 6, 46, 4, 93, 3, 51, 5, 82, 1, 35, 
    8, 81, 2, 16, 5, 96, 3, 29, 6, 50, 1, 30, 4,  5, 0, 19, 7, 64
  };
  const int q8426[] = {
    9, 9, // Number of jobs and machines
    4, 52, 5, 67, 0, 55, 7, 33, 2, 40, 6, 12, 8, 18, 3, 33, 1, 62, 
    8, 32, 7, 19, 6,  1, 0, 83, 1, 28, 2, 16, 4, 61, 5, 76, 3, 67, 
    5, 22, 3,  3, 4, 74, 8, 62, 6,  7, 0,  6, 7, 25, 2, 39, 1, 83, 
    1, 35, 0, 69, 2, 48, 7, 51, 8, 35, 3,  3, 6, 75, 4, 57, 5, 95, 
    5, 57, 3, 22, 7, 61, 2, 32, 8, 37, 6, 25, 0,  4, 1, 54, 4, 14, 
    0, 75, 7, 77, 8, 61, 3, 40, 5, 23, 2, 77, 4, 75, 6, 70, 1, 73, 
    0, 60, 5, 86, 2, 28, 8, 44, 6, 66, 3,  3, 7, 36, 1, 68, 4, 32, 
    7,  4, 5,  7, 8, 61, 3, 87, 6, 78, 2, 85, 4, 16, 0, 13, 1, 31, 
    2, 20, 4, 77, 5,  4, 7, 55, 0, 31, 1, 30, 3,  9, 8, 36, 6,  4
  };
  const int q8427[] = {
    9, 9, // Number of jobs and machines
    0, 85, 3, 26, 6, 82, 4, 37, 2, 92, 7, 26, 8,  8, 5, 27, 1, 57, 
    6, 79, 3, 38, 4, 25, 2,  6, 7, 51, 1, 63, 0, 97, 5, 89, 8, 19, 
    0, 54, 4, 87, 7, 67, 3, 39, 6, 21, 1,  3, 2, 47, 5, 34, 8, 15, 
    1, 31, 4, 17, 0, 60, 3, 98, 5, 80, 7, 73, 6, 40, 8, 20, 2, 92, 
    7, 59, 6, 93, 0, 40, 2, 98, 5, 82, 4, 21, 1, 20, 8, 52, 3, 81, 
    4, 10, 1, 71, 7, 46, 2, 45, 8, 89, 5, 16, 0, 26, 6, 30, 3, 86, 
    0, 15, 2, 64, 6, 95, 5, 59, 3, 62, 7, 53, 4, 59, 1, 47, 8, 45, 
    1, 50, 6, 12, 3, 42, 4, 40, 0, 14, 7,  6, 8,  5, 5, 29, 2, 62, 
    5, 56, 2, 42, 1, 22, 6, 63, 0, 25, 7, 18, 3,  4, 8, 91, 4, 78
  };
  const int q8428[] = {
    9, 9, // Number of jobs and machines
    4, 96, 5, 33, 3, 96, 6, 67, 1, 53, 7, 48, 2, 29, 0,  6, 8, 21, 
    6, 91, 1, 24, 7, 60, 3, 66, 8, 10, 2, 31, 0, 73, 5, 94, 4, 13, 
    8, 83, 3, 96, 2, 83, 4, 36, 6,  3, 0, 45, 1, 84, 5, 19, 7,  6, 
    5,  4, 7, 45, 4, 43, 8, 84, 0, 77, 1, 45, 2, 92, 6,  3, 3, 94, 
    2, 50, 5, 50, 7, 33, 1, 81, 4, 87, 6, 64, 3, 43, 0, 41, 8, 30, 
    3, 56, 2, 37, 8, 88, 4, 73, 1, 58, 0, 70, 7, 18, 5, 69, 6, 16, 
    5, 74, 8, 28, 7, 42, 3, 47, 0, 26, 2, 64, 6, 30, 1, 99, 4, 87, 
    1, 98, 5,  8, 7, 40, 3, 80, 0, 68, 6, 43, 2, 76, 8, 41, 4,  4, 
    7, 23, 2, 46, 1, 73, 5, 63, 8, 94, 0,  3, 6, 94, 4, 65, 3, 90
  };
  const int q8429[] = {
    9, 9, // Number of jobs and machines
    1, 67, 7, 63, 5, 19, 3,  2, 0, 26, 6, 48, 2, 40, 8, 17, 4, 66, 
    1, 86, 4, 90, 6, 29, 5, 35, 0, 15, 3, 44, 8, 59, 7, 38, 2, 31, 
    2, 57, 0, 44, 6, 37, 3, 55, 8, 42, 7, 76, 1, 38, 4, 62, 5, 63, 
    7, 71, 6, 28, 4, 46, 5, 80, 2, 24, 3, 75, 0, 52, 8, 41, 1, 56, 
    4, 76, 8, 56, 0, 30, 6, 48, 5, 10, 1, 77, 7, 23, 3, 28, 2, 47, 
    2, 14, 5, 34, 7, 38, 0, 42, 6, 62, 8, 28, 4, 72, 3, 71, 1, 32, 
    5, 37, 8,  5, 3, 31, 0, 46, 1, 18, 4, 50, 7, 33, 2, 99, 6, 89, 
    0, 16, 1, 37, 3, 39, 6, 90, 5, 25, 2, 78, 8, 28, 7, 62, 4, 29, 
    5, 91, 2, 50, 4, 65, 7, 90, 1, 42, 0,  7, 8, 29, 3, 77, 6, 75
  };
  const int q8430[] = {
    9, 9, // Number of jobs and machines
    6, 30, 0, 46, 7, 20, 2, 68, 8, 98, 1,  3, 4, 39, 5, 62, 3, 26, 
    5, 66, 8, 66, 7, 62, 3, 49, 2, 75, 4, 49, 0, 93, 1,  7, 6, 89, 
    0, 78, 6,  3, 5, 70, 7, 59, 8, 35, 4, 33, 3, 73, 1, 82, 2, 29, 
    5, 53, 6, 89, 1, 64, 4, 95, 7, 44, 2, 33, 3, 58, 8, 31, 0, 17, 
    4, 66, 6, 22, 1, 75, 2, 77, 3, 45, 0, 90, 7, 87, 8, 66, 5, 45, 
    5,  3, 7, 44, 3, 30, 2, 57, 4, 45, 1, 11, 8, 31, 6, 13, 0, 65, 
    5, 30, 4, 14, 8, 63, 7, 35, 6, 97, 3, 57, 0, 45, 1, 41, 2, 76, 
    2, 74, 3, 64, 1, 99, 4, 83, 0, 53, 8, 57, 5, 14, 7, 44, 6, 93, 
    5, 65, 7, 78, 2, 14, 8,  7, 4, 64, 0, 29, 1, 94, 3, 96, 6, 98
  };
  const int q8431[] = {
    9, 9, // Number of jobs and machines
    6, 46, 5, 24, 1,  8, 8, 88, 7, 87, 2, 56, 0,  1, 3, 74, 4, 99, 
    1,  8, 3, 77, 6, 63, 8, 66, 4, 89, 7, 41, 2, 45, 0, 49, 5, 58, 
    4, 82, 2, 91, 1,  5, 6, 59, 0,  1, 8, 29, 7, 38, 5, 42, 3, 79, 
    5, 12, 6, 79, 8, 11, 3,  3, 2, 26, 0, 65, 4, 31, 7, 91, 1, 58, 
    1, 44, 3, 55, 4, 69, 8,  2, 2, 28, 5,  2, 6, 37, 7, 21, 0, 17, 
    1, 54, 2, 58, 4, 54, 7, 51, 3,  1, 5, 19, 6, 79, 0, 63, 8, 51, 
    0, 29, 5, 40, 4, 26, 2,  6, 8, 11, 7,  5, 3, 62, 1, 10, 6, 80, 
    6, 34, 7, 15, 8,  2, 3, 29, 4, 75, 1, 75, 5, 52, 2, 86, 0, 56, 
    5, 13, 7, 53, 8, 62, 4, 79, 2, 37, 3, 27, 1, 26, 6, 23, 0, 50
  };
  const int q8432[] = {
    9, 9, // Number of jobs and machines
    7, 62, 2, 51, 6, 17, 0, 39, 4, 87, 3, 39, 8, 31, 1, 74, 5, 71, 
    1, 12, 8, 15, 3, 11, 0, 66, 7, 77, 5, 17, 2, 83, 4, 59, 6, 57, 
    4, 40, 5, 48, 8, 51, 7, 11, 3, 72, 1, 11, 2, 14, 6, 22, 0, 69, 
    0, 51, 1, 69, 6, 48, 4, 32, 8, 58, 5, 82, 7, 37, 3,  8, 2, 29, 
    7, 97, 1, 22, 3, 18, 6, 73, 4,  2, 8, 22, 2, 81, 5,  2, 0, 72, 
    2, 62, 8, 69, 4, 35, 5, 15, 7, 42, 3, 30, 1, 44, 6, 44, 0, 35, 
    3, 39, 0, 72, 7, 17, 2, 33, 4, 11, 6, 94, 1, 39, 8, 87, 5, 97, 
    5, 34, 7, 29, 4, 56, 2, 17, 6, 14, 8, 23, 3, 15, 1, 56, 0, 14, 
    1, 81, 5, 40, 4, 14, 7, 42, 2, 47, 8,  9, 3, 90, 6, 55, 0,  5
  };
  const int q8433[] = {
    9, 9, // Number of jobs and machines
    3, 54, 1, 84, 4, 68, 2, 83, 0, 60, 6, 84, 7, 76, 8, 79, 5, 47, 
    6, 85, 4, 72, 0, 50, 5, 47, 3, 75, 1, 76, 8, 32, 7, 45, 2, 61, 
    8,  3, 1, 84, 3, 59, 7, 36, 5, 65, 2, 55, 4, 78, 0, 96, 6, 21, 
    5, 91, 6, 26, 0, 57, 2, 45, 3, 25, 1, 47, 7, 77, 8,  3, 4, 18, 
    5, 39, 8,  9, 3, 84, 2, 73, 4, 99, 1, 67, 6, 12, 0, 30, 7, 89, 
    0, 21, 3, 77, 5, 68, 8, 74, 6, 26, 2, 41, 4, 78, 7, 48, 1, 47, 
    2, 84, 6, 52, 1, 54, 5,  9, 7, 24, 8, 66, 3, 48, 4, 75, 0, 48, 
    1, 64, 3, 69, 6, 56, 4,  4, 7,  8, 2, 90, 8, 10, 0, 93, 5, 51, 
    2, 54, 6, 31, 1, 14, 8, 41, 7, 98, 3, 82, 0,  6, 4, 26, 5, 52
  };
  const int q8434[] = {
    9, 9, // Number of jobs and machines
    5, 81, 1, 10, 6, 98, 7, 39, 8, 68, 2, 53, 3, 63, 0, 47, 4, 72, 
    1, 63, 0, 35, 4, 22, 2, 21, 5,  4, 6, 17, 3, 77, 7, 88, 8, 21, 
    6, 22, 4, 44, 3,  8, 0, 88, 5,  7, 8, 60, 2, 64, 7, 37, 1,  1, 
    7, 52, 3, 99, 5, 47, 0, 86, 6, 97, 8, 65, 2, 72, 1,  2, 4, 29, 
    4, 21, 8, 33, 6, 18, 0, 44, 2, 42, 3, 45, 1, 15, 7, 66, 5, 98, 
    4, 52, 0,  1, 2, 37, 6, 75, 7, 57, 5, 36, 8,  8, 3, 32, 1, 44, 
    2, 55, 4, 17, 0, 36, 1, 25, 6,  7, 5, 12, 3, 24, 8,  5, 7,  1, 
    8, 77, 2, 11, 5,  9, 4, 56, 1,  9, 6, 96, 0, 14, 3, 66, 7, 25, 
    0, 17, 7, 46, 4, 43, 1, 21, 5, 20, 2, 24, 6, 18, 8, 31, 3, 84
  };
  const int q8435[] = {
    9, 9, // Number of jobs and machines
    3, 26, 7, 32, 6, 47, 1, 91, 0,  3, 5, 15, 8, 11, 4, 99, 2, 78, 
    8, 91, 6,  9, 4, 82, 1,  9, 2, 65, 0, 38, 7, 74, 3, 51, 5, 89, 
    5, 75, 8, 18, 0,  2, 7, 11, 1, 87, 6, 17, 4, 67, 3, 21, 2, 20, 
    0, 46, 6, 79, 4, 73, 1, 82, 8, 45, 3, 67, 5, 10, 7, 47, 2, 19, 
    5,  2, 7, 26, 2, 90, 6,  8, 0, 95, 1, 44, 8, 99, 4, 84, 3, 34, 
    0,  5, 7, 69, 8, 59, 2, 76, 1, 27, 5, 34, 6, 77, 4, 61, 3, 81, 
    5,  3, 7,  6, 4, 94, 3, 23, 2, 73, 8, 24, 6, 50, 1, 56, 0, 89, 
    4, 27, 8, 67, 0, 65, 6, 85, 7, 37, 5,  1, 2, 79, 1, 68, 3, 42, 
    7, 55, 5, 93, 0, 56, 2, 12, 3, 64, 8, 47, 6,  6, 1, 35, 4, 56
  };
  const int q8436[] = {
    9, 9, // Number of jobs and machines
    6, 78, 7, 40, 4, 29, 8, 71, 1, 42, 0, 84, 3, 48, 2, 64, 5, 67, 
    7, 86, 0, 24, 8, 28, 1, 86, 6, 54, 2, 30, 3,  5, 5, 65, 4, 21, 
    3, 74, 4, 77, 8, 93, 1, 25, 5, 74, 2, 47, 7, 83, 0, 82, 6, 21, 
    4, 24, 5, 55, 3, 63, 6, 17, 8, 31, 7, 90, 1, 97, 2, 88, 0, 75, 
    6, 30, 0,  9, 8,  4, 4, 42, 1, 69, 7, 31, 2,  4, 3, 25, 5, 67, 
    1, 83, 3, 58, 7, 75, 6, 28, 8, 59, 4, 43, 2, 21, 5, 92, 0, 63, 
    6, 95, 4, 79, 8, 22, 0, 14, 2,  9, 1, 84, 3, 99, 7,  9, 5, 25, 
    0, 97, 2, 50, 1, 58, 8, 90, 5, 73, 6, 87, 4, 27, 7, 65, 3, 54, 
    4, 42, 8, 83, 2, 31, 1, 78, 6, 18, 3, 72, 0, 17, 5, 24, 7, 50
  };
  const int q8437[] = {
    9, 9, // Number of jobs and machines
    4, 80, 2, 89, 6, 45, 8, 18, 3, 56, 5, 21, 7, 83, 0, 32, 1, 37, 
    4, 93, 5, 54, 8, 64, 3, 41, 0, 28, 7, 38, 2, 30, 6, 85, 1,  7, 
    2, 45, 5, 76, 8, 41, 1, 78, 0,  9, 3, 81, 4,  2, 6, 31, 7, 16, 
    6, 35, 8, 54, 2, 39, 7, 24, 5, 48, 4, 99, 1, 75, 3, 75, 0,  5, 
    4, 18, 6, 35, 1, 75, 5, 72, 0, 91, 3, 17, 2, 23, 7, 36, 8,  7, 
    2, 99, 0, 58, 5, 22, 8, 11, 1, 76, 3, 92, 6, 12, 4, 87, 7, 70, 
    6, 77, 4, 60, 3, 31, 5, 68, 0, 25, 1, 45, 7, 15, 2,  2, 8, 17, 
    2,  4, 7, 61, 5, 82, 6,  2, 3, 30, 0,  3, 1, 74, 8, 39, 4,  6, 
    7, 44, 4, 37, 5, 98, 0, 37, 6,  1, 8, 64, 2, 56, 3, 33, 1, 23
  };
  const int q8438[] = {
    9, 9, // Number of jobs and machines
    4, 11, 1, 50, 2, 38, 8, 35, 5, 39, 7, 73, 6, 26, 3, 51, 0,  6, 
    6, 80, 0, 30, 4, 96, 5, 12, 7, 91, 1, 17, 3, 18, 2, 87, 8, 63, 
    6, 89, 8, 87, 1, 74, 4, 60, 5, 47, 3, 32, 7, 59, 2, 60, 0, 48, 
    3, 12, 5,  5, 6, 89, 2, 85, 4, 21, 8, 51, 1, 25, 0,  6, 7, 74, 
    5, 32, 8, 55, 3, 77, 2, 71, 0, 36, 6, 69, 1, 93, 4, 29, 7,  8, 
    6, 85, 4, 24, 3, 73, 8, 26, 5, 80, 7, 31, 0, 92, 2, 46, 1, 60, 
    8, 27, 5, 14, 0, 37, 7, 60, 4, 33, 6, 22, 2, 92, 3, 33, 1, 74, 
    8, 25, 2, 90, 1,  7, 5, 80, 4, 14, 7, 34, 6, 39, 0,  9, 3, 95, 
    6, 38, 2,  8, 5, 25, 7, 43, 0, 48, 3, 45, 4, 81, 1, 25, 8, 56
  };
  const int q8439[] = {
    9, 9, // Number of jobs and machines
    4, 49, 3, 76, 6, 18, 1, 51, 2, 90, 8, 92, 7, 20, 0, 35, 5, 55, 
    1, 68, 4, 46, 3,  7, 2, 66, 8, 53, 7, 91, 6, 24, 5, 13, 0, 99, 
    5, 98, 3, 97, 1, 67, 0, 31, 2, 29, 7,  5, 8, 47, 6, 62, 4, 25, 
    1, 72, 7, 96, 3, 14, 5, 81, 0, 76, 2, 24, 6, 56, 8, 12, 4, 91, 
    3, 48, 4, 37, 1, 45, 5,  3, 2, 93, 7, 14, 0, 68, 6, 17, 8, 39, 
    6, 81, 7, 62, 0, 59, 4, 59, 8, 66, 1, 30, 3,  9, 2, 10, 5, 42, 
    7, 53, 2, 87, 5,  7, 0, 91, 6, 21, 8, 27, 1, 65, 4, 48, 3, 71, 
    3, 52, 7, 89, 1, 94, 6, 64, 2, 15, 4, 67, 5, 67, 0,  6, 8, 52, 
    6, 25, 3, 98, 0, 26, 8, 79, 1, 52, 7, 78, 5, 17, 2, 48, 4,  2
  };
  const int q8440[] = {
    9, 9, // Number of jobs and machines
    4, 14, 2, 78, 0, 55, 3, 13, 7,  8, 5, 10, 1, 66, 8, 67, 6, 18, 
    3, 43, 7, 92, 1, 52, 5, 41, 2, 85, 8, 56, 4, 49, 0, 94, 6,  3, 
    5, 36, 6, 33, 3, 80, 0, 42, 4, 33, 2, 41, 8,  6, 7, 66, 1, 34, 
    7, 76, 5, 10, 6, 75, 8,  2, 2, 45, 3, 89, 0, 75, 1, 90, 4, 59, 
    6, 48, 5, 54, 8, 74, 2, 39, 3, 76, 4, 61, 1, 84, 7, 78, 0, 38, 
    7, 40, 5, 61, 8,  3, 2, 64, 6, 36, 1, 98, 0, 76, 3, 42, 4, 32, 
    7, 30, 1, 82, 2, 17, 4, 66, 8, 10, 0,  6, 5, 75, 6, 69, 3, 82, 
    7, 33, 2, 40, 3, 91, 0, 18, 4, 84, 5, 58, 6, 69, 1, 71, 8, 84, 
    3, 13, 0, 96, 6, 56, 5, 60, 1, 66, 8,  7, 7, 55, 2, 32, 4, 80
  };
  const int q8441[] = {
    9, 9, // Number of jobs and machines
    0,  6, 1, 16, 7, 85, 2, 54, 3,  7, 8, 99, 5, 21, 4, 18, 6, 52, 
    2, 48, 4, 38, 7, 84, 0, 44, 8, 39, 5, 82, 3, 19, 6, 34, 1, 49, 
    8, 47, 4, 79, 2, 73, 3,  5, 7, 91, 0,  9, 6, 42, 5, 16, 1, 73, 
    1, 54, 7, 76, 3, 30, 5, 74, 0,  4, 6, 98, 8, 87, 2, 73, 4, 89, 
    7, 36, 4, 41, 5, 69, 0, 87, 2, 12, 6, 23, 1, 60, 8, 29, 3, 23, 
    1, 78, 7, 94, 3, 76, 8,  4, 6, 48, 5, 67, 4, 63, 0, 75, 2, 52, 
    7, 14, 2, 65, 3, 43, 4, 85, 0, 56, 8, 16, 6, 63, 1, 32, 5, 16, 
    5,  2, 7, 88, 2, 68, 1, 63, 0, 64, 3, 44, 6, 33, 4, 82, 8, 13, 
    4, 89, 5, 19, 6, 85, 3, 54, 2, 18, 1, 47, 7, 86, 0, 58, 8, 50
  };
  const int q8442[] = {
    9, 9, // Number of jobs and machines
    8, 29, 4, 84, 0, 30, 7, 31, 5, 13, 2, 59, 1, 83, 3, 10, 6, 48, 
    1, 88, 3, 74, 5, 65, 6, 63, 4, 45, 7, 51, 2, 41, 0, 32, 8, 92, 
    6, 37, 2,  7, 5, 34, 4, 98, 7, 28, 1,  2, 8, 19, 0, 61, 3, 62, 
    0, 29, 5, 32, 7, 58, 1, 87, 4, 16, 6, 10, 8,  8, 2, 24, 3,  9, 
    4,  6, 2, 37, 3, 61, 7, 77, 8, 46, 0, 15, 1, 48, 5, 12, 6, 62, 
    2, 20, 4, 53, 1, 88, 8, 43, 5, 98, 0, 92, 3, 35, 6, 43, 7, 72, 
    8, 68, 4, 75, 5,  7, 1, 32, 7, 57, 0, 89, 2,  4, 6, 43, 3, 62, 
    2, 50, 5, 64, 3, 89, 1, 43, 7,  8, 8, 30, 6, 82, 0,  9, 4, 52, 
    1, 78, 2, 81, 5, 94, 8, 98, 4, 32, 0, 93, 3, 34, 6, 39, 7, 10
  };
  const int q8443[] = {
    9, 9, // Number of jobs and machines
    2, 58, 1, 61, 8,  2, 3, 93, 0, 20, 5, 57, 4, 17, 7, 24, 6, 45, 
    2, 52, 1, 64, 4, 53, 8, 69, 6, 29, 3, 11, 0, 76, 5, 28, 7, 82, 
    4, 33, 0, 79, 2, 13, 6, 59, 3, 54, 8, 24, 7, 59, 5, 94, 1, 26, 
    1, 47, 3, 53, 2, 54, 7, 47, 0, 23, 8, 16, 5, 76, 6, 25, 4,  3, 
    0, 41, 6, 57, 1, 59, 2, 19, 7, 58, 3, 33, 8, 35, 4, 34, 5, 78, 
    7, 72, 1, 86, 4, 52, 3, 13, 6, 32, 8, 51, 0, 40, 5, 17, 2, 58, 
    0, 23, 4, 33, 1, 25, 6, 42, 2, 21, 3,  8, 8, 63, 7, 30, 5,  5, 
    5, 12, 1, 32, 0, 27, 3, 27, 4, 52, 7, 75, 8, 82, 2, 88, 6, 51, 
    2,  6, 0,  5, 3, 43, 1, 96, 6, 68, 8, 94, 5, 46, 4, 23, 7, 38
  };
  const int q8444[] = {
    9, 9, // Number of jobs and machines
    4, 18, 2, 73, 6, 41, 3, 73, 0, 72, 8, 97, 7, 65, 1, 91, 5, 21, 
    6, 67, 0, 43, 2, 10, 8, 55, 7, 22, 3, 91, 5, 11, 4, 17, 1, 11, 
    4, 32, 7, 10, 2,  9, 8, 65, 6, 61, 3, 11, 5, 42, 0, 54, 1, 48, 
    2, 46, 7, 43, 8, 29, 0,  2, 3, 46, 5, 49, 1, 30, 4, 74, 6, 29, 
    5, 79, 6, 18, 3, 25, 1, 68, 8, 56, 4, 13, 7, 80, 2, 93, 0, 81, 
    8,  5, 0,  1, 2, 40, 3, 39, 4,  5, 5, 49, 7, 24, 1,  2, 6, 53, 
    2, 59, 8, 89, 6, 56, 3,  5, 7, 86, 5, 66, 0, 97, 4, 20, 1, 64, 
    5, 17, 2, 59, 4, 44, 0, 29, 7, 79, 6, 77, 3, 21, 1,  4, 8, 61, 
    2, 67, 1, 66, 5, 23, 3, 27, 4, 49, 8, 69, 6, 85, 0, 75, 7,  8
  };
  const int q8445[] = {
    9, 9, // Number of jobs and machines
    6, 50, 8, 58, 5,  5, 4, 71, 3,  8, 1, 56, 0, 59, 2, 69, 7, 98, 
    1, 18, 4,  8, 8, 71, 0,  4, 5, 88, 3, 79, 2, 61, 6, 85, 7, 95, 
    7, 17, 5, 76, 0,  5, 1, 76, 2, 79, 6, 17, 3, 56, 4,  3, 8, 39, 
    7, 43, 2,  8, 4,  2, 1, 42, 0, 64, 8, 87, 6, 69, 5, 86, 3,  4, 
    6, 78, 4, 59, 5, 87, 8,  3, 3, 39, 1, 99, 7, 42, 2, 29, 0, 17, 
    4, 89, 0, 91, 2,  5, 6, 14, 7, 20, 5, 35, 1, 86, 8, 17, 3, 66, 
    2, 36, 6, 36, 7, 31, 4, 85, 5, 11, 3, 53, 0, 54, 8, 33, 1, 12, 
    7, 32, 4, 48, 2, 81, 1, 31, 8, 48, 0,  2, 6, 60, 3, 12, 5, 54, 
    5, 21, 3, 56, 4, 81, 6, 43, 8, 79, 1, 57, 7, 98, 2, 71, 0, 93
  };
  const int q8446[] = {
    9, 9, // Number of jobs and machines
    6, 24, 8, 21, 4, 52, 7, 63, 0,  8, 1, 19, 3, 65, 5, 89, 2, 31, 
    4, 19, 1, 73, 7, 95, 6, 27, 3, 24, 2, 17, 8, 77, 5, 29, 0, 70, 
    2, 98, 7, 41, 6,  6, 5, 48, 1,  3, 8, 80, 4, 42, 0, 68, 3, 26, 
    3, 14, 1, 20, 6, 30, 8, 46, 2, 86, 5, 77, 0, 97, 7, 19, 4, 59, 
    3, 44, 8, 31, 4, 78, 0, 59, 2, 22, 7, 13, 5, 17, 1, 65, 6, 91, 
    4, 83, 2, 52, 5, 78, 7, 30, 6, 42, 1, 95, 3, 23, 0, 21, 8, 26, 
    5, 65, 2, 32, 3, 85, 8, 19, 4, 25, 7, 27, 1, 77, 0, 57, 6, 34, 
    0, 86, 3,  7, 2, 14, 4, 75, 8, 40, 5, 24, 6, 10, 7, 38, 1, 33, 
    6, 16, 3, 26, 7, 20, 4, 44, 1, 14, 5, 86, 2, 27, 0, 77, 8, 28
  };
  const int q8447[] = {
    9, 9, // Number of jobs and machines
    0, 88, 4, 58, 3, 79, 7, 86, 1, 85, 2, 72, 6, 59, 5, 99, 8, 46, 
    6, 17, 1, 68, 3, 24, 8, 21, 5, 43, 4, 91, 0, 49, 7, 52, 2,  2, 
    8, 25, 7, 96, 4, 84, 5, 77, 2, 29, 3, 37, 0,  5, 6, 28, 1, 25, 
    8, 26, 3,  5, 5, 49, 6, 72, 1, 24, 7,  5, 0, 31, 4, 56, 2, 58, 
    7, 79, 8, 94, 3, 30, 2, 70, 4, 84, 5,  5, 6, 42, 1, 19, 0, 81, 
    4,  8, 3, 35, 0, 16, 2, 30, 1, 95, 5, 92, 8, 92, 7, 54, 6, 67, 
    3, 93, 8, 82, 6, 54, 1, 28, 0, 25, 4, 57, 5, 55, 7, 47, 2,  5, 
    4, 19, 8, 52, 7,  6, 0, 99, 2, 77, 6, 45, 3, 43, 5, 48, 1, 38, 
    2, 91, 4, 78, 5, 49, 8, 37, 3, 98, 0, 53, 7, 98, 1, 68, 6, 47
  };
  const int q8448[] = {
    9, 9, // Number of jobs and machines
    1, 97, 7, 86, 0, 46, 8, 29, 6, 83, 4, 56, 5, 96, 2, 93, 3, 29, 
    3, 48, 7, 93, 1, 44, 2, 17, 5, 53, 6, 59, 8, 29, 4, 96, 0, 48, 
    5, 62, 8, 15, 1, 80, 7, 56, 4, 85, 2, 49, 6, 32, 3, 55, 0, 75, 
    0, 66, 6, 26, 3, 92, 1, 88, 7, 39, 5, 82, 8, 83, 2, 41, 4, 41, 
    0, 54, 4, 85, 3, 98, 6,  2, 1, 96, 7, 56, 2, 64, 8, 22, 5, 67, 
    0, 22, 7, 50, 2, 49, 3, 69, 1, 66, 8, 70, 4, 74, 5, 12, 6, 71, 
    0, 26, 1, 85, 3, 48, 5, 21, 8, 49, 6, 66, 4,  8, 2, 96, 7, 27, 
    3, 81, 2, 97, 7, 28, 1, 32, 0, 75, 5, 27, 4,  6, 8, 50, 6, 11, 
    7, 32, 5, 51, 2, 25, 8, 41, 3, 16, 1, 69, 4, 82, 6, 38, 0, 54
  };
  const int q8449[] = {
    9, 9, // Number of jobs and machines
    5, 89, 1, 68, 3, 33, 7, 30, 0, 39, 4, 12, 8, 52, 2, 44, 6, 53, 
    4, 59, 7, 77, 3, 30, 1, 18, 5, 12, 0, 94, 8, 58, 2, 57, 6, 98, 
    0, 17, 2, 31, 1, 56, 5, 59, 6, 57, 4, 93, 7, 10, 8, 24, 3, 71, 
    8, 71, 0,  5, 1, 84, 2, 80, 7, 33, 4, 79, 3, 51, 5, 29, 6, 99, 
    0, 94, 2, 73, 5, 26, 8, 83, 4, 98, 6, 96, 3, 86, 1, 40, 7, 79, 
    5, 98, 7, 74, 1, 75, 0,  2, 6, 71, 3,  2, 4, 77, 8, 88, 2, 10, 
    8, 19, 3, 68, 6, 25, 1, 12, 4, 38, 7, 69, 2, 47, 5, 97, 0, 31, 
    8, 10, 1, 79, 3, 62, 5, 62, 7, 89, 4, 88, 2, 48, 0, 62, 6, 23, 
    4, 58, 2, 45, 6, 37, 7,  1, 3, 65, 0, 64, 5,  1, 1,  1, 8, 88
  };
  const int q8450[] = {
    9, 9, // Number of jobs and machines
    2, 46, 1, 56, 4, 26, 6, 68, 0, 87, 3, 96, 5,  4, 8, 48, 7, 40, 
    1, 42, 7, 45, 0, 41, 4, 69, 5, 92, 3, 98, 6, 41, 2, 66, 8, 14, 
    3,  1, 0, 89, 7, 86, 8,  7, 5, 36, 1, 68, 4, 34, 6,  7, 2,  7, 
    5, 43, 2, 68, 1, 56, 0, 65, 8, 74, 7, 63, 3, 61, 6, 48, 4, 91, 
    5, 95, 4, 68, 8, 23, 2, 23, 0, 88, 3, 10, 7, 55, 1, 75, 6, 64, 
    0, 84, 5, 74, 7, 88, 4, 78, 2, 11, 3, 43, 1,  8, 6, 84, 8, 79, 
    0, 79, 3, 72, 6, 54, 1, 78, 4, 35, 2, 22, 8, 50, 5,  4, 7, 33, 
    3, 79, 1, 51, 5, 47, 6, 40, 0, 28, 4, 44, 7, 79, 8, 88, 2, 96, 
    1, 72, 0, 43, 2, 45, 7, 62, 5,  6, 8, 50, 4, 49, 3, 35, 6, 69
  };
  const int q8451[] = {
    9, 9, // Number of jobs and machines
    6,  6, 2,  4, 7, 70, 8, 61, 0, 31, 5, 79, 1, 28, 4, 11, 3, 20, 
    2, 93, 0, 14, 7, 72, 8, 50, 3, 69, 5, 20, 4, 17, 1, 60, 6, 82, 
    8, 75, 2, 41, 6, 97, 4,  5, 3,  5, 7, 76, 5, 37, 0, 79, 1, 84, 
    4, 88, 1,  9, 5, 91, 0, 60, 8, 93, 7, 85, 6, 27, 2,  1, 3, 25, 
    7,  7, 0, 43, 5, 63, 3, 48, 4, 89, 2,  6, 8, 22, 6, 98, 1, 10, 
    7, 38, 5, 58, 4, 68, 6, 64, 0, 56, 8, 31, 3, 78, 2, 66, 1, 97, 
    6, 79, 1,  5, 7, 99, 0, 12, 8, 74, 4, 24, 5, 92, 3, 28, 2, 28, 
    0, 38, 1, 64, 4, 54, 8, 35, 5, 56, 7, 45, 3, 52, 6, 99, 2,  6, 
    1, 71, 3, 89, 5, 31, 8, 51, 2, 18, 7,  7, 0, 74, 6, 20, 4, 86
  };
  const int q8452[] = {
    9, 9, // Number of jobs and machines
    0, 75, 5, 81, 6, 66, 3, 84, 7, 90, 4, 90, 1, 60, 2, 76, 8, 97, 
    5, 80, 1,  2, 8, 91, 6, 99, 3, 69, 4, 60, 7,  7, 0, 34, 2, 66, 
    8, 19, 3, 88, 2, 31, 4, 83, 6, 46, 1, 88, 0, 21, 7, 84, 5, 29, 
    0, 89, 1, 98, 6, 64, 5, 92, 7, 84, 2, 80, 8, 60, 4, 62, 3, 73, 
    4, 46, 0,  1, 8, 73, 2, 39, 5, 51, 3, 42, 6, 44, 7, 13, 1, 88, 
    7,  2, 5, 51, 8, 91, 3, 21, 1, 19, 0, 81, 4, 61, 2, 61, 6, 75, 
    1, 59, 6, 44, 8,  8, 5, 47, 2, 54, 7,  5, 3, 48, 0, 40, 4, 79, 
    7, 13, 3, 11, 4, 81, 8, 87, 2, 91, 6,  4, 0, 94, 1, 53, 5, 34, 
    5,  5, 3, 80, 8, 70, 2, 83, 1, 24, 4, 95, 0, 55, 7, 38, 6, 21
  };
  const int q8453[] = {
    9, 9, // Number of jobs and machines
    0, 54, 1, 68, 7, 68, 5, 36, 8,  3, 4, 12, 3, 61, 2, 95, 6, 55, 
    1, 48, 4, 72, 0, 22, 2, 92, 8, 99, 7, 17, 3, 32, 6, 16, 5, 86, 
    3, 70, 6, 83, 4, 18, 8,  6, 2, 34, 0,  4, 5, 60, 7, 75, 1, 84, 
    0,  5, 8, 95, 1, 24, 2, 77, 5, 87, 3, 15, 6, 77, 4, 64, 7, 63, 
    3, 13, 4, 56, 8, 59, 0, 82, 7, 45, 2, 72, 6, 92, 1, 40, 5, 59, 
    8, 15, 5, 38, 1, 17, 6, 10, 7, 41, 0, 46, 4, 97, 3, 29, 2, 87, 
    2, 51, 3, 37, 7, 93, 4, 15, 1, 99, 6, 29, 5, 70, 8, 76, 0, 43, 
    0, 93, 2, 55, 6, 64, 4, 85, 3, 54, 1, 30, 8, 47, 7, 19, 5, 44, 
    6, 10, 7, 13, 4, 53, 8,  8, 3, 67, 5, 20, 0, 91, 1, 13, 2, 38
  };
  const int q8454[] = {
    9, 9, // Number of jobs and machines
    3, 24, 1, 73, 4, 96, 7, 39, 0, 84, 6, 30, 8, 45, 2, 74, 5, 35, 
    6, 14, 2, 80, 3, 45, 0, 32, 1, 55, 8, 44, 7, 45, 4, 80, 5, 80, 
    6, 57, 2, 10, 7, 84, 5, 23, 3, 11, 1, 17, 8, 32, 4, 11, 0, 38, 
    5, 68, 3, 67, 4, 87, 8, 83, 6, 40, 7, 59, 2,  5, 1, 77, 0, 48, 
    5, 41, 0, 89, 7, 34, 6,  4, 1, 44, 8, 52, 4, 41, 2, 27, 3, 79, 
    8, 26, 3, 72, 5, 91, 4, 63, 0, 90, 1, 49, 2, 26, 6, 96, 7, 74, 
    2, 21, 5, 19, 4, 67, 7,  5, 0, 81, 8, 20, 3, 37, 6, 92, 1, 21, 
    7, 16, 6, 37, 2, 60, 3, 94, 0, 87, 4,  5, 1, 24, 8, 27, 5,  2, 
    1, 91, 4, 73, 7,  6, 2, 22, 0, 52, 8, 37, 6, 55, 5, 38, 3, 21
  };
  const int q8455[] = {
    9, 9, // Number of jobs and machines
    6, 76, 0, 48, 4, 71, 2, 32, 8, 28, 5, 30, 3, 24, 7, 35, 1, 59, 
    1, 22, 7, 94, 5, 87, 0, 58, 6, 96, 2,  3, 3, 19, 8, 87, 4, 14, 
    8, 59, 4, 24, 7,  2, 0, 20, 3, 57, 6, 19, 2, 10, 5, 55, 1, 11, 
    8, 90, 3, 34, 7, 81, 5, 51, 2, 94, 6, 69, 0, 23, 4, 34, 1, 27, 
    1, 93, 7, 82, 4, 63, 2, 96, 5, 71, 0, 84, 6, 64, 8, 17, 3, 66, 
    2, 42, 7, 29, 6, 10, 4,  1, 8,  3, 0, 26, 5, 18, 3, 24, 1, 42, 
    7, 17, 4, 51, 1, 95, 5, 66, 2, 50, 0, 45, 6, 92, 8, 44, 3, 57, 
    3, 58, 7,  6, 4, 43, 2, 59, 8, 80, 5, 11, 1,  7, 0, 10, 6, 23, 
    6, 57, 0, 44, 2, 17, 7, 70, 8, 26, 3,  3, 1, 17, 4, 41, 5, 48
  };
  const int q8456[] = {
    9, 9, // Number of jobs and machines
    0, 76, 8, 36, 5, 97, 6, 28, 4, 75, 2,  3, 1, 72, 3, 81, 7, 22, 
    2, 14, 8, 15, 7, 93, 0, 35, 4, 70, 6, 80, 5, 22, 3, 90, 1, 14, 
    3, 71, 1,  8, 4, 41, 8, 20, 7,  8, 6, 40, 2, 68, 0, 75, 5, 50, 
    2, 29, 0, 78, 4, 88, 3, 63, 8, 29, 6, 12, 5, 47, 7, 97, 1, 63, 
    1, 33, 5, 92, 2, 79, 3, 29, 0, 86, 7, 41, 8,  3, 4, 14, 6, 82, 
    4, 20, 7, 73, 8, 12, 3, 20, 5, 48, 1, 97, 6, 78, 0, 71, 2, 76, 
    6, 89, 4, 64, 7, 66, 0, 37, 3, 29, 2, 49, 1, 76, 8, 85, 5, 43, 
    3, 28, 7, 15, 1, 74, 6, 29, 0, 88, 8, 32, 2, 97, 5, 69, 4, 69, 
    8, 45, 2, 93, 6, 45, 0, 71, 7, 98, 1, 11, 4, 74, 5, 41, 3, 19
  };
  const int q8457[] = {
    9, 9, // Number of jobs and machines
    0, 12, 4, 16, 5, 89, 7,  2, 1, 32, 2, 14, 6, 87, 8, 46, 3, 85, 
    7, 24, 2, 63, 6, 50, 4, 41, 1, 31, 3, 68, 8, 23, 5, 96, 0, 80, 
    5, 84, 3, 25, 4, 33, 1, 61, 2, 40, 7, 93, 0, 27, 8, 37, 6, 38, 
    2, 10, 8,  1, 6, 46, 0, 32, 3, 84, 1, 11, 7, 48, 4, 46, 5, 35, 
    4, 23, 8,  6, 1, 54, 6, 78, 3, 78, 5, 20, 2, 19, 0, 96, 7, 75, 
    5, 70, 4, 62, 6, 30, 2, 49, 0,  3, 1,  7, 7, 23, 8, 69, 3, 94, 
    0, 80, 7, 32, 6, 32, 8, 70, 1, 36, 5, 19, 3, 25, 4,  4, 2, 50, 
    1, 24, 7, 10, 8, 88, 3, 26, 6, 35, 4, 22, 2,  4, 0, 30, 5, 75, 
    2, 74, 8, 18, 5, 86, 7, 74, 0, 71, 1, 94, 3, 63, 6, 76, 4, 12
  };
  const int q8458[] = {
    9, 9, // Number of jobs and machines
    3,  3, 1, 52, 5, 85, 4, 52, 2, 10, 6, 75, 0, 17, 8, 30, 7, 95, 
    6, 90, 8,  6, 0, 39, 7, 71, 1, 25, 3, 64, 2, 80, 5, 15, 4, 45, 
    8, 29, 6, 95, 7, 10, 5, 62, 4, 42, 1, 40, 0, 83, 3, 13, 2, 91, 
    6, 55, 4, 37, 8, 53, 5, 91, 2, 17, 7,  5, 0, 41, 1, 86, 3, 23, 
    4, 59, 1, 51, 3, 43, 8, 20, 7, 82, 2,  1, 6, 46, 5, 81, 0, 70, 
    5, 82, 4, 34, 2, 59, 8, 42, 7, 22, 0, 62, 6, 36, 3, 80, 1, 22, 
    5, 37, 3, 86, 2, 63, 7, 14, 8, 64, 1, 52, 4, 79, 0, 74, 6, 82, 
    7, 25, 3, 11, 8,  2, 6, 59, 1, 33, 4, 22, 0, 49, 2, 23, 5, 34, 
    6, 56, 8, 66, 1, 66, 7,  3, 5, 54, 3, 87, 2, 16, 4,  9, 0, 67
  };
  const int q8459[] = {
    9, 9, // Number of jobs and machines
    3, 40, 8, 97, 2, 92, 4,  7, 0, 47, 5,  8, 7, 48, 6, 93, 1, 44, 
    0, 17, 4, 36, 8, 37, 3, 95, 6, 24, 1, 44, 7, 96, 2, 40, 5, 82, 
    7, 64, 0, 15, 3, 65, 5,  1, 2, 90, 8, 61, 6, 56, 4, 34, 1, 70, 
    7, 15, 1, 90, 5, 82, 4, 73, 2, 60, 8, 24, 0, 11, 3,  9, 6, 37, 
    6, 59, 1, 47, 3, 63, 8, 40, 5, 51, 2, 65, 7, 88, 0, 34, 4,  3, 
    3, 95, 8, 74, 7, 57, 2, 86, 6, 84, 5, 69, 0, 37, 4, 18, 1, 70, 
    1, 62, 7, 90, 5, 46, 8,  1, 2, 36, 6, 69, 3, 46, 0, 17, 4, 59, 
    1, 20, 7, 39, 2, 82, 6, 30, 5, 14, 0, 79, 4, 31, 3, 71, 8, 68, 
    6, 53, 7, 86, 2, 76, 0, 80, 4, 14, 8, 63, 1, 36, 5, 67, 3, 42
  };
  const int q8460[] = {
    9, 9, // Number of jobs and machines
    6, 70, 8, 28, 4,  3, 7, 52, 1, 15, 2, 67, 5, 30, 0, 43, 3, 59, 
    7, 98, 0, 88, 2, 45, 8, 69, 4, 51, 1, 51, 3, 10, 5, 37, 6, 33, 
    3, 40, 6, 62, 4, 81, 1, 59, 5,  2, 7, 43, 0, 43, 8, 83, 2, 24, 
    1, 48, 4, 30, 7, 77, 6, 47, 8, 39, 3, 63, 2, 15, 0, 53, 5, 83, 
    4, 85, 5, 84, 6,  9, 3, 39, 1, 97, 0, 78, 7, 43, 8, 33, 2, 50, 
    4, 46, 3, 94, 1, 23, 7, 30, 2, 36, 0, 74, 6, 77, 8, 17, 5,  1, 
    7, 79, 4, 32, 3, 53, 5, 63, 0, 59, 6, 70, 8, 41, 2, 13, 1, 80, 
    8, 75, 3, 87, 1, 10, 4, 25, 5, 55, 6, 37, 7, 14, 0, 21, 2, 20, 
    2, 86, 6, 86, 7, 65, 0, 13, 4, 25, 5, 26, 1, 63, 3, 25, 8, 17
  };
  const int q8461[] = {
    9, 9, // Number of jobs and machines
    2, 97, 0, 52, 1, 75, 8, 25, 5, 59, 7, 30, 4, 63, 6, 96, 3, 66, 
    3, 22, 4, 34, 8, 10, 5, 10, 2, 72, 0, 10, 7, 33, 6, 48, 1, 87, 
    2,  5, 8, 10, 4, 41, 1, 18, 6, 92, 0, 80, 3, 75, 5, 35, 7, 93, 
    7, 60, 8, 32, 5, 94, 0, 52, 1, 93, 2,  6, 3, 87, 6, 79, 4, 25, 
    0, 37, 7, 36, 1, 56, 3, 99, 5, 64, 6, 56, 2, 89, 8, 78, 4, 17, 
    4, 99, 3, 42, 6, 91, 1, 36, 0, 28, 7, 46, 5, 75, 8, 37, 2, 73, 
    5, 68, 1, 90, 4,  5, 0, 49, 8,  3, 7, 22, 2, 47, 3, 55, 6, 70, 
    8, 84, 2, 42, 5, 52, 7, 93, 6, 75, 3, 50, 1, 69, 0, 87, 4, 97, 
    8, 93, 6, 14, 0, 32, 5,  8, 3, 84, 7, 82, 1, 72, 2, 97, 4, 64
  };
  const int q8462[] = {
    9, 9, // Number of jobs and machines
    5, 83, 7, 61, 6, 39, 4, 51, 2, 52, 8, 17, 3, 92, 1, 59, 0, 80, 
    5,  5, 8, 47, 3, 56, 7, 10, 1, 42, 2,  9, 4, 73, 6, 74, 0, 73, 
    4, 32, 7, 37, 8, 69, 3, 17, 1, 13, 0, 58, 6,  3, 5, 72, 2, 41, 
    3, 85, 7, 95, 5, 31, 1, 14, 4, 61, 2, 47, 8, 51, 6, 75, 0, 24, 
    0, 61, 5, 36, 8,  7, 7, 67, 2,  3, 3, 33, 6, 81, 1, 27, 4, 63, 
    4, 75, 6, 62, 1, 84, 2,  8, 3, 92, 7, 61, 5, 52, 8, 96, 0, 20, 
    2, 98, 0, 50, 5, 78, 3,  7, 4, 77, 8, 63, 1, 91, 7, 13, 6, 42, 
    3, 39, 7, 71, 1, 11, 2, 65, 5, 16, 0, 39, 8, 42, 6, 19, 4, 78, 
    1, 17, 6, 54, 2, 41, 7, 75, 8, 32, 3, 82, 0, 34, 5, 57, 4, 27
  };
  const int q8463[] = {
    9, 9, // Number of jobs and machines
    8, 78, 2, 37, 7, 66, 5,  9, 3, 55, 0, 40, 1, 99, 6,  1, 4, 15, 
    1, 50, 5, 41, 7, 54, 2, 42, 4, 33, 0, 76, 3,  6, 6, 15, 8, 13, 
    8, 45, 3, 99, 5, 54, 4, 39, 0, 87, 7, 87, 6, 55, 2, 60, 1, 13, 
    0, 19, 7, 99, 4, 78, 5,  8, 2,  3, 8, 58, 1, 57, 6, 65, 3, 52, 
    0, 50, 1, 41, 8, 33, 6, 65, 5, 99, 4,  9, 3, 31, 7, 31, 2, 28, 
    4, 10, 1, 64, 3, 99, 5, 56, 8, 63, 7, 87, 0, 46, 2, 44, 6, 88, 
    3, 66, 1, 77, 8, 38, 0,  4, 2, 85, 7,  3, 4, 46, 6,  9, 5, 50, 
    7, 88, 0, 99, 1,  2, 4, 84, 6, 19, 3, 58, 8, 81, 2, 48, 5, 91, 
    3, 74, 8, 11, 6, 44, 2, 95, 5, 26, 0, 11, 4, 94, 1, 73, 7, 37
  };
  const int q8464[] = {
    9, 9, // Number of jobs and machines
    6, 90, 0, 79, 5, 22, 2, 65, 8, 17, 3, 37, 1, 93, 4,  1, 7, 40, 
    8, 13, 6, 18, 3, 51, 5, 12, 2,  9, 0, 18, 4, 53, 7, 94, 1,  8, 
    2, 90, 7, 32, 6, 74, 0, 93, 5, 52, 4, 53, 1, 15, 3, 83, 8, 98, 
    2, 24, 7, 66, 1, 65, 3, 41, 5,  2, 0,  4, 4, 23, 8, 55, 6, 42, 
    4, 68, 2, 83, 7, 23, 0, 76, 8, 78, 3, 74, 1, 69, 5, 73, 6, 70, 
    3, 91, 6, 65, 0, 26, 2, 76, 4, 93, 5, 15, 7, 70, 1, 35, 8, 85, 
    8, 28, 2, 42, 7, 94, 5,  3, 1, 92, 4, 57, 0, 24, 3, 17, 6, 93, 
    3, 36, 8, 66, 0,  3, 6,  9, 4, 91, 5, 66, 2, 92, 1, 19, 7, 76, 
    8, 38, 4, 95, 0, 85, 3,  5, 2, 17, 5, 31, 1, 59, 7, 95, 6, 12
  };
  const int q8465[] = {
    9, 9, // Number of jobs and machines
    6, 53, 4, 56, 2, 94, 8, 75, 3, 87, 7, 97, 5, 94, 1, 60, 0, 42, 
    6, 47, 3, 22, 1, 36, 0, 21, 2, 35, 7,  6, 5, 59, 8, 56, 4, 13, 
    3, 48, 2, 26, 7, 33, 0, 83, 6, 44, 8, 80, 4, 55, 5, 65, 1, 46, 
    8, 86, 2, 93, 1, 96, 4, 40, 6,  1, 5, 27, 7, 57, 3, 77, 0, 43, 
    6,  1, 4, 21, 1, 73, 3, 42, 7, 62, 2, 29, 8,  6, 0, 56, 5, 80, 
    6, 56, 1, 50, 8, 53, 2, 78, 3, 61, 4, 68, 7, 56, 0, 51, 5, 20, 
    8, 93, 2, 93, 6, 36, 1, 83, 0,  4, 5, 16, 4, 78, 3, 87, 7, 26, 
    6, 73, 7, 85, 8, 39, 4, 88, 2, 13, 0, 66, 5, 99, 3, 65, 1, 28, 
    1, 73, 4, 44, 8, 13, 6, 38, 3, 61, 0,  7, 5, 36, 2, 41, 7, 76
  };
  const int q8466[] = {
    9, 9, // Number of jobs and machines
    7, 59, 3, 15, 5, 86, 0, 77, 8, 26, 1, 60, 2, 33, 6, 69, 4, 91, 
    0, 87, 6, 62, 2, 59, 7, 22, 8, 19, 4, 17, 1,  7, 3, 47, 5, 19, 
    5, 66, 6,  9, 0, 20, 4, 81, 8, 19, 3, 45, 1, 81, 7, 67, 2, 51, 
    4, 66, 2, 72, 1, 61, 6, 53, 3, 86, 8, 54, 5, 81, 0, 83, 7, 47, 
    8, 94, 1, 47, 3,  3, 2, 53, 4, 58, 6, 49, 7, 69, 5, 46, 0, 94, 
    4, 91, 3,  8, 8, 27, 6, 51, 2, 18, 5, 67, 0, 76, 1, 45, 7, 96, 
    7, 70, 6, 95, 0, 22, 5, 74, 2, 62, 8, 15, 1, 94, 4, 35, 3, 36, 
    0, 86, 4, 39, 5, 52, 3, 13, 7, 27, 8, 98, 1, 34, 6, 17, 2, 57, 
    6, 27, 3, 66, 7, 51, 8, 63, 2, 82, 4, 45, 1, 80, 5, 56, 0, 39
  };
  const int q8467[] = {
    9, 9, // Number of jobs and machines
    4, 93, 2, 57, 5, 68, 8, 39, 6, 92, 3,  8, 1, 88, 7, 69, 0, 49, 
    5, 32, 0,  6, 8, 87, 3, 63, 1, 54, 4, 28, 2, 58, 7, 73, 6, 52, 
    1,  8, 0, 31, 2, 43, 8, 15, 4, 95, 5, 48, 7, 37, 3, 37, 6, 32, 
    4, 71, 5, 59, 6, 57, 0, 46, 3, 63, 8, 47, 7, 30, 1, 85, 2, 39, 
    6, 31, 0, 68, 4, 14, 3,  8, 7, 76, 1,  1, 5,  5, 8, 97, 2, 60, 
    8, 71, 0, 19, 5, 41, 3, 37, 6, 43, 7, 42, 4, 25, 1, 82, 2,  8, 
    0, 98, 4, 96, 7, 16, 6, 27, 5,  7, 2,  7, 3, 40, 8, 75, 1, 74, 
    0, 43, 1, 39, 7, 60, 4, 52, 5, 74, 6, 60, 2,  8, 3, 66, 8,  2, 
    6, 25, 5, 64, 1, 85, 8, 43, 2, 68, 4, 14, 7, 55, 0, 30, 3, 41
  };
  const int q8468[] = {
    9, 9, // Number of jobs and machines
    1, 54, 4, 78, 0, 71, 3, 65, 5, 46, 8, 37, 7, 20, 6, 57, 2, 77, 
    2, 53, 7, 68, 8, 41, 3, 48, 5, 68, 0, 52, 6, 29, 1, 59, 4, 46, 
    8, 48, 3, 24, 0, 53, 1, 76, 4, 54, 7, 92, 5, 11, 2, 33, 6, 95, 
    0, 51, 7,  4, 5, 96, 8, 80, 2, 75, 3, 98, 1, 80, 6, 85, 4, 79, 
    5, 94, 2, 95, 7, 88, 8, 59, 1, 97, 0, 21, 4, 12, 6, 37, 3, 52, 
    7,  1, 6, 43, 0, 47, 1,  2, 3, 97, 5, 57, 8, 83, 4, 91, 2, 97, 
    1, 57, 8, 73, 7, 75, 4,  2, 3, 70, 5, 42, 6, 46, 0,  7, 2,  4, 
    4, 37, 5, 73, 8, 70, 3, 40, 7, 10, 0, 73, 6, 85, 2, 47, 1, 13, 
    1, 17, 7, 76, 5, 96, 2, 75, 8, 60, 6, 60, 4, 88, 0, 18, 3, 59
  };
  const int q8469[] = {
    9, 9, // Number of jobs and machines
    2, 55, 1, 25, 3,  5, 8, 76, 6, 27, 4,  9, 0, 69, 5, 21, 7, 96, 
    3, 63, 0, 80, 2, 71, 1, 84, 4, 73, 8, 69, 7, 86, 5, 21, 6, 86, 
    5, 89, 2, 91, 8, 64, 4, 18, 1, 82, 6, 24, 7, 17, 3, 71, 0, 63, 
    0, 79, 8, 81, 1, 35, 3, 61, 5, 94, 7, 74, 2, 57, 4, 56, 6,  2, 
    1, 48, 7, 33, 3, 72, 5, 10, 0, 74, 4, 63, 8,  9, 2, 56, 6, 18, 
    3, 15, 8, 17, 2,  3, 5, 26, 0, 99, 4, 55, 7, 42, 6, 97, 1, 86, 
    1, 68, 6, 32, 5, 56, 4, 55, 3, 94, 7, 23, 8, 41, 0, 79, 2,  2, 
    3, 41, 4, 29, 0, 98, 1, 99, 6, 74, 7, 65, 5, 48, 2, 79, 8, 91, 
    2, 73, 4, 79, 7, 90, 3,  9, 0, 92, 1, 48, 6, 31, 8, 80, 5, 52
  };
  const int q8470[] = {
    9, 9, // Number of jobs and machines
    7, 54, 8, 30, 3, 93, 4,  3, 2, 19, 5, 89, 0, 12, 6, 32, 1, 35, 
    3, 13, 5, 94, 7, 25, 6, 29, 8, 49, 2, 98, 4, 66, 1, 36, 0, 37, 
    4, 78, 2, 53, 1, 89, 6, 17, 3, 19, 8, 44, 7, 44, 0, 76, 5, 51, 
    3, 36, 4, 19, 7, 79, 1, 14, 0,  2, 2, 68, 6, 89, 8, 29, 5, 75, 
    7, 72, 8, 18, 6, 66, 5, 63, 3, 21, 2, 68, 0, 59, 4, 88, 1,  6, 
    8, 36, 2, 44, 4, 40, 0, 93, 5, 88, 3, 88, 7,  9, 1, 58, 6, 65, 
    0, 37, 5, 38, 6, 75, 4, 81, 1,  3, 7, 85, 8, 86, 2, 38, 3, 42, 
    2, 96, 6, 12, 5, 51, 3, 12, 4, 78, 0,  8, 8, 76, 7, 99, 1, 23, 
    2, 55, 3, 99, 0, 42, 1, 46, 8, 87, 7, 64, 6, 83, 5, 33, 4,  2
  };
  const int q8471[] = {
    9, 9, // Number of jobs and machines
    0, 26, 3, 46, 8,  6, 4, 41, 6, 12, 5, 31, 2, 11, 1, 94, 7, 79, 
    2, 20, 8,  4, 1, 51, 0,  1, 4, 51, 3, 31, 7, 56, 5, 90, 6, 64, 
    6, 39, 2, 43, 0, 14, 7, 18, 5, 63, 3, 18, 4, 29, 8,  5, 1, 55, 
    3, 68, 2, 95, 6, 34, 7, 37, 5,  8, 8, 28, 1, 82, 4, 70, 0, 53, 
    7, 14, 5, 62, 1, 41, 4, 73, 8, 38, 3, 59, 2,  2, 6, 25, 0, 72, 
    0, 98, 2, 92, 3, 50, 4, 61, 8, 23, 7, 56, 1, 39, 5, 85, 6, 19, 
    1, 86, 3, 15, 6,  3, 2, 98, 8, 67, 7, 26, 4, 48, 5, 63, 0, 84, 
    6, 86, 0, 47, 7, 80, 5, 81, 8, 75, 4, 10, 2, 56, 1, 78, 3, 23, 
    4, 46, 2, 38, 5, 24, 6, 67, 3, 93, 7, 43, 8, 89, 0, 95, 1, 55
  };
  const int q8472[] = {
    9, 9, // Number of jobs and machines
    8, 19, 6, 88, 3, 21, 5, 83, 7, 42, 2,  3, 1, 27, 0, 59, 4, 69, 
    2, 56, 5, 61, 7, 52, 3, 48, 6, 31, 4, 29, 8, 65, 0, 15, 1, 52, 
    2, 14, 3, 15, 4, 94, 0, 39, 7, 88, 1, 62, 5, 68, 8, 81, 6, 13, 
    4, 89, 5,  1, 2, 52, 7, 90, 8, 83, 0, 24, 3, 95, 1, 48, 6, 82, 
    5, 51, 7, 54, 6, 65, 0, 48, 4, 33, 8, 97, 2, 48, 3, 86, 1, 66, 
    1, 98, 8, 78, 4, 41, 0, 84, 5, 16, 2, 95, 7, 52, 3, 88, 6, 58, 
    3, 67, 8, 91, 4, 96, 1, 75, 5, 71, 7, 57, 0,  4, 2, 58, 6, 48, 
    6, 72, 3, 58, 1, 37, 7,  6, 5, 17, 0, 59, 8, 64, 2, 98, 4, 45, 
    7, 68, 6, 51, 3, 33, 2, 82, 4, 48, 5,  1, 8, 47, 1, 73, 0, 83
  };
  const int q8473[] = {
    9, 9, // Number of jobs and machines
    1, 62, 3, 96, 4, 30, 6, 78, 0,  9, 8, 34, 2, 20, 5, 12, 7, 34, 
    8, 52, 3, 81, 7,  7, 2,  3, 4, 67, 1, 10, 5, 77, 6, 41, 0, 64, 
    2, 31, 8, 98, 6, 18, 1, 83, 0, 27, 5, 12, 7, 56, 4, 17, 3, 70, 
    5, 67, 4, 77, 1, 79, 3, 52, 2, 51, 7, 96, 0, 71, 6, 82, 8, 60, 
    0, 31, 7, 59, 1, 85, 4, 31, 2, 51, 8, 67, 6, 89, 3, 71, 5, 10, 
    1, 10, 8, 26, 6, 71, 2, 36, 7,  3, 3, 36, 5, 76, 4, 30, 0,  2, 
    0, 76, 7,  6, 8, 56, 4, 72, 1, 63, 3, 61, 6, 66, 2, 62, 5,  1, 
    5,  6, 1, 92, 8, 37, 7, 97, 3,  7, 6, 19, 4, 19, 0,  9, 2, 59, 
    8,  1, 7, 64, 1,  3, 2, 95, 5, 28, 6, 68, 0, 28, 4, 15, 3, 21
  };
  const int q8474[] = {
    9, 9, // Number of jobs and machines
    6, 91, 0, 11, 8, 75, 1, 50, 4, 42, 3, 20, 5, 53, 2, 92, 7, 24, 
    8, 78, 4, 31, 3, 58, 5, 80, 7, 28, 2, 68, 6, 38, 0, 95, 1,  8, 
    6, 35, 5, 79, 8, 35, 0, 77, 4, 31, 1, 24, 3, 68, 7, 39, 2, 99, 
    1, 73, 6, 31, 5, 24, 2, 25, 8, 76, 7, 99, 3, 25, 0, 92, 4, 91, 
    6, 63, 2, 39, 0, 55, 5, 97, 8, 47, 4, 36, 1, 52, 3, 40, 7, 38, 
    0, 26, 4, 90, 2, 10, 5, 79, 8, 59, 6, 31, 7, 52, 1, 53, 3, 59, 
    3, 93, 4, 23, 7, 16, 1, 72, 2, 73, 6, 28, 8, 29, 0, 44, 5, 79, 
    1, 25, 4, 84, 6, 32, 7, 72, 3, 72, 2, 19, 0,  7, 8, 68, 5, 60, 
    3, 50, 7, 38, 4, 99, 1, 94, 2, 29, 8, 41, 5, 10, 0, 11, 6, 79
  };
  const int q8475[] = {
    9, 9, // Number of jobs and machines
    4, 90, 0, 71, 5, 81, 3, 52, 6,  9, 1, 85, 8, 59, 7, 87, 2, 17, 
    7, 34, 3, 71, 8, 71, 6, 18, 2, 34, 4,  5, 5, 48, 0, 34, 1, 15, 
    1, 66, 0, 58, 8, 59, 2, 86, 7,  6, 6,  3, 3, 81, 5, 14, 4, 90, 
    2, 87, 1, 19, 5, 47, 3,  2, 8, 63, 0,  7, 4, 88, 6,  6, 7, 27, 
    3, 95, 1, 89, 4, 12, 0, 76, 2, 27, 7, 20, 5, 63, 8, 73, 6, 12, 
    2, 34, 0,  4, 3, 39, 6, 49, 1, 56, 8, 70, 5, 21, 4,  3, 7, 37, 
    8, 13, 0, 80, 4, 50, 1, 36, 7, 64, 3, 82, 2, 22, 6, 48, 5, 80, 
    7, 76, 3, 34, 0, 52, 2, 10, 1,  2, 4, 21, 8, 62, 6, 57, 5,  2, 
    6, 73, 8, 38, 7, 81, 3, 98, 0, 88, 2, 14, 5, 93, 4, 78, 1, 50
  };
  const int q8476[] = {
    9, 9, // Number of jobs and machines
    6, 76, 3, 23, 2, 85, 7, 56, 8, 99, 4, 32, 0, 11, 5, 51, 1, 38, 
    8, 34, 1, 94, 4, 27, 0, 46, 2, 14, 6, 41, 7, 12, 3, 61, 5, 32, 
    3, 99, 5, 11, 6, 41, 8, 65, 4, 47, 1, 41, 2, 79, 7, 62, 0, 79, 
    4, 92, 8, 17, 5, 78, 6, 83, 0, 91, 7, 64, 2, 38, 1, 44, 3, 82, 
    4, 91, 0, 32, 3, 56, 1,  1, 2, 43, 7, 20, 5, 90, 8, 85, 6, 59, 
    0,  3, 4,  6, 8, 83, 3, 89, 1, 64, 6, 36, 2, 21, 7, 86, 5, 68, 
    8, 53, 4, 88, 0, 34, 3, 48, 1, 90, 2, 54, 6, 60, 5, 40, 7, 62, 
    4, 73, 5,  4, 8, 24, 2, 50, 0, 40, 3, 58, 6, 41, 7, 90, 1,  3, 
    6, 69, 5, 88, 3, 80, 7, 10, 0, 12, 4, 17, 8, 10, 2, 45, 1, 28
  };
  const int q8477[] = {
    9, 9, // Number of jobs and machines
    2, 42, 7, 77, 1, 22, 6, 57, 3, 31, 8, 12, 5, 44, 0, 15, 4, 98, 
    3, 55, 0, 19, 4, 15, 7, 62, 5, 65, 2, 21, 1, 25, 8, 56, 6,  4, 
    8,  8, 4, 70, 2, 75, 5,  3, 1, 95, 0, 73, 3, 28, 6, 23, 7, 76, 
    2, 19, 6, 44, 8, 58, 3, 15, 7, 54, 0, 30, 5, 80, 1, 46, 4,  4, 
    0, 36, 5, 13, 7, 69, 8, 33, 2, 30, 4, 75, 1, 12, 3, 61, 6,  1, 
    3, 52, 5, 34, 6, 97, 8, 93, 4, 61, 7, 14, 1, 63, 2, 48, 0, 19, 
    8, 44, 2, 57, 3, 94, 0, 95, 1, 50, 6, 62, 4, 75, 7,  6, 5, 27, 
    0, 55, 5, 95, 4, 23, 6, 30, 3, 60, 2, 91, 8, 29, 1, 31, 7, 33, 
    8, 58, 4, 56, 6, 16, 3, 33, 5, 79, 7, 67, 0, 83, 1, 66, 2, 10
  };
  const int q8478[] = {
    9, 9, // Number of jobs and machines
    8, 95, 0, 38, 6,  4, 5, 59, 1, 84, 7, 21, 4, 28, 3, 53, 2, 52, 
    7, 37, 0, 54, 8, 36, 3, 87, 2, 85, 1, 69, 5, 32, 6, 83, 4, 93, 
    4, 43, 8, 90, 6, 69, 2, 28, 0, 43, 3, 74, 1, 24, 5, 34, 7,  3, 
    8, 20, 5, 17, 0, 93, 3, 67, 2, 64, 1, 85, 7, 23, 4, 58, 6, 16, 
    0, 53, 7, 45, 1, 82, 3, 85, 5, 26, 8, 10, 4, 43, 6, 20, 2, 37, 
    4, 44, 1, 59, 5, 52, 0, 83, 8, 25, 2, 64, 7, 62, 6, 45, 3, 86, 
    8, 72, 7, 94, 1, 30, 5, 38, 2, 27, 0, 32, 6, 36, 3, 98, 4, 67, 
    3, 48, 8, 46, 2, 14, 1, 55, 4, 82, 0, 47, 5, 25, 7, 20, 6, 24, 
    1, 44, 0, 39, 6, 74, 8, 17, 5, 11, 7, 33, 2, 47, 4, 80, 3, 53
  };
  const int q8479[] = {
    9, 9, // Number of jobs and machines
    6, 35, 7, 30, 2, 61, 0, 39, 5, 65, 8, 71, 4, 35, 3, 61, 1, 86, 
    6, 11, 5, 91, 7, 90, 3, 92, 0, 62, 4, 81, 2, 52, 1, 72, 8, 16, 
    3, 12, 6, 42, 5, 12, 2, 36, 8, 65, 0, 94, 1, 86, 7, 54, 4, 93, 
    6,  1, 4, 17, 7,  2, 2, 23, 1, 17, 0, 78, 8, 72, 5, 95, 3, 10, 
    2, 14, 6, 19, 0, 89, 4, 63, 1, 13, 7, 69, 5,  4, 8, 39, 3, 54, 
    2, 89, 1, 63, 8, 39, 7, 10, 0, 59, 5, 70, 3, 26, 6, 31, 4, 26, 
    2,  4, 4,  4, 1, 82, 7, 34, 6, 36, 8, 21, 5, 87, 0, 27, 3, 45, 
    3,  5, 0, 89, 8, 82, 7, 55, 5, 72, 2, 61, 4, 28, 1, 69, 6, 42, 
    5, 20, 4, 20, 7, 38, 0, 68, 8, 96, 2, 60, 6, 91, 1, 10, 3,  5
  };
  const int q8480[] = {
    9, 9, // Number of jobs and machines
    3, 23, 5, 14, 1, 50, 4, 50, 8, 82, 0, 25, 6, 41, 2, 59, 7, 44, 
    8, 93, 0, 11, 1, 44, 3, 80, 4, 17, 2, 37, 7, 37, 5, 44, 6, 58, 
    1, 85, 4, 95, 0, 28, 8, 80, 7, 64, 6, 11, 2, 15, 5, 93, 3, 62, 
    5, 51, 3, 89, 2, 11, 1, 99, 0, 40, 8, 31, 7, 25, 6, 10, 4, 23, 
    0, 18, 7, 92, 6, 79, 5, 87, 3, 20, 2, 13, 1, 93, 4, 60, 8, 76, 
    0, 41, 7, 91, 6, 18, 3,  8, 5, 48, 2, 65, 8, 96, 4, 76, 1, 34, 
    2, 25, 3, 93, 4, 45, 1, 93, 8, 19, 7, 17, 6, 36, 0, 26, 5, 94, 
    7, 28, 2, 40, 0, 59, 4, 45, 8, 37, 5, 21, 6, 20, 1, 18, 3, 76, 
    5, 51, 8, 56, 3,  9, 0, 53, 4, 88, 7, 80, 1, 90, 2, 21, 6, 45
  };
  const int q8481[] = {
    9, 9, // Number of jobs and machines
    0, 89, 3, 46, 7,  4, 5, 95, 1, 56, 4, 54, 6, 90, 2, 60, 8, 78, 
    6, 96, 8, 19, 7, 21, 5, 52, 1, 60, 3, 58, 4, 75, 2, 89, 0, 99, 
    7,  5, 0, 16, 3, 41, 4, 51, 8, 78, 2, 98, 5, 15, 1, 22, 6, 83, 
    7, 12, 3, 42, 1, 15, 8, 29, 6,  9, 0,  7, 2, 36, 4, 56, 5,  9, 
    2, 61, 5, 52, 1, 27, 4, 24, 0, 96, 3, 54, 7, 33, 8, 45, 6, 72, 
    4, 16, 2, 72, 7, 57, 3, 55, 0, 95, 1, 28, 5, 73, 6, 53, 8, 64, 
    7, 10, 4, 81, 2, 19, 1, 81, 8, 83, 6, 31, 3, 46, 0, 54, 5, 39, 
    2, 45, 4,  2, 5, 28, 0, 89, 6, 12, 7, 41, 8, 73, 3,  8, 1, 37, 
    2, 35, 7, 68, 5, 18, 0,  6, 6, 94, 8, 23, 4,  5, 1, 16, 3, 89
  };
  const int q8482[] = {
    9, 9, // Number of jobs and machines
    1, 34, 2, 44, 3, 68, 8, 35, 5, 45, 4, 45, 6, 81, 0, 77, 7, 54, 
    6, 80, 2, 62, 1, 27, 8, 53, 5, 32, 3, 42, 4, 43, 0, 85, 7, 35, 
    5, 99, 8, 73, 1, 46, 7, 64, 4, 89, 2, 37, 6, 40, 0, 14, 3, 59, 
    5, 91, 4, 93, 6, 39, 3, 63, 0, 49, 2, 87, 7,  6, 8, 95, 1, 99, 
    2, 19, 6, 25, 5, 91, 3, 75, 8,  1, 7, 67, 4,  4, 0, 29, 1, 24, 
    6, 22, 2, 81, 0, 12, 8, 71, 3, 16, 7, 91, 4, 95, 1, 51, 5, 12, 
    3,  9, 7, 97, 6,  8, 1, 76, 5, 76, 4, 47, 8, 56, 2, 81, 0, 84, 
    1, 85, 0, 90, 7, 91, 6, 42, 5, 27, 8, 97, 3, 31, 4, 53, 2, 82, 
    0, 59, 3, 43, 5, 87, 8, 10, 6, 59, 7, 46, 1,  8, 2,  6, 4, 27
  };
  const int q8483[] = {
    9, 9, // Number of jobs and machines
    8, 60, 3, 58, 5, 61, 7, 35, 6, 77, 2, 10, 0, 34, 4, 27, 1, 60, 
    0, 30, 8, 12, 1, 31, 2, 58, 4, 61, 3,  1, 6, 16, 7, 17, 5, 33, 
    0, 93, 1, 66, 7, 89, 4,  3, 8, 49, 3, 45, 2,  2, 5,  8, 6,  7, 
    1, 78, 3, 37, 2, 56, 0, 74, 8, 36, 5, 72, 6, 33, 4,  7, 7, 81, 
    5, 77, 6, 43, 4, 25, 0, 70, 7,  1, 1, 96, 2, 21, 8, 30, 3, 15, 
    3, 95, 4, 97, 5, 69, 1, 55, 0, 88, 6, 60, 7, 56, 2, 72, 8, 21, 
    1, 86, 2, 61, 8,  1, 5, 94, 6, 60, 4, 84, 7,  8, 0, 49, 3, 63, 
    7, 29, 3, 20, 1, 90, 8, 12, 6, 29, 4, 35, 2, 62, 0, 64, 5, 88, 
    1, 14, 7, 21, 3, 88, 2, 24, 8, 62, 0,  3, 6, 17, 5, 55, 4, 46
  };
  const int q8484[] = {
    9, 9, // Number of jobs and machines
    2, 81, 8, 65, 5, 36, 0, 86, 4, 82, 1, 63, 7, 51, 3, 51, 6, 58, 
    2, 19, 6, 41, 3, 29, 1,  7, 4, 14, 7, 29, 8, 76, 5, 79, 0, 28, 
    8, 30, 2, 51, 6, 18, 1, 42, 5, 33, 4, 86, 7, 68, 3, 26, 0, 62, 
    8, 43, 2, 25, 7, 14, 5, 95, 1, 16, 4, 60, 6, 92, 3, 57, 0, 84, 
    0, 12, 5, 78, 2, 10, 6, 84, 4, 22, 3,  4, 8, 28, 7, 18, 1, 49, 
    8, 50, 6, 14, 7, 90, 1, 54, 3, 64, 5, 84, 2, 61, 4, 65, 0, 81, 
    5, 75, 4, 30, 2,  8, 0, 54, 8, 39, 6, 34, 3, 85, 1, 45, 7, 46, 
    5, 76, 2, 13, 8, 55, 1, 21, 4, 67, 6, 63, 7, 33, 3, 31, 0, 73, 
    0, 11, 1, 46, 3, 14, 8, 79, 7, 53, 5, 87, 6, 33, 2, 34, 4, 14
  };
  const int q8485[] = {
    9, 9, // Number of jobs and machines
    7, 88, 4, 79, 6, 11, 0,  5, 1, 94, 8, 48, 2, 50, 3, 66, 5,  6, 
    2, 94, 1, 28, 5, 62, 8, 38, 0, 67, 4, 42, 3, 12, 7, 72, 6, 35, 
    8,  6, 7, 25, 4,  4, 1, 35, 2, 87, 5, 23, 3, 67, 6, 51, 0, 93, 
    3, 30, 6, 18, 7, 70, 0, 84, 8,  9, 4, 14, 5, 73, 1, 54, 2, 35, 
    2, 50, 8, 74, 0, 46, 1, 69, 6, 39, 3,  7, 7, 77, 4, 57, 5, 77, 
    3, 99, 7, 33, 1, 63, 2, 53, 5, 85, 6, 94, 8, 84, 0, 63, 4,  8, 
    6,  1, 1, 64, 8, 95, 3, 69, 7, 26, 5, 51, 4, 47, 0, 73, 2, 96, 
    6, 27, 4, 31, 8,  8, 2, 15, 3, 11, 0, 46, 7, 11, 5, 38, 1, 53, 
    2, 13, 4, 59, 5, 61, 8, 47, 3, 37, 1, 12, 0, 15, 6, 11, 7, 78
  };
  const int q8486[] = {
    9, 9, // Number of jobs and machines
    4, 88, 7, 60, 0, 96, 1, 23, 5, 87, 2, 73, 3, 76, 6, 58, 8, 30, 
    1, 32, 0, 38, 3, 83, 2, 72, 8, 19, 4, 14, 5, 78, 6, 18, 7, 91, 
    2, 48, 0,  8, 7, 28, 5,  1, 6, 41, 1, 41, 3, 12, 4, 58, 8, 54, 
    7, 94, 4, 68, 8, 19, 0, 35, 6, 64, 3,  4, 1, 51, 2, 45, 5, 75, 
    0, 76, 1, 94, 4,  3, 6, 67, 2, 18, 8, 39, 7, 96, 3, 43, 5, 64, 
    4,  2, 8, 51, 1, 60, 2, 24, 5,  8, 0, 99, 7, 65, 6, 32, 3, 27, 
    8, 23, 7, 41, 2, 40, 5, 20, 1, 77, 6,  4, 3, 60, 4, 71, 0, 44, 
    8, 86, 2, 10, 4, 77, 5, 30, 7, 79, 6, 68, 1, 18, 0, 22, 3, 70, 
    6,  8, 7, 85, 1, 23, 0, 71, 2, 43, 4, 14, 3, 62, 5, 61, 8, 37
  };
  const int q8487[] = {
    9, 9, // Number of jobs and machines
    3, 94, 0,  5, 8, 47, 7,  6, 4, 69, 6, 30, 1, 44, 5, 60, 2, 79, 
    8,  3, 1, 72, 2, 50, 4, 52, 6, 90, 3, 60, 7, 23, 0, 82, 5, 98, 
    3, 84, 5,  3, 1, 64, 6, 52, 0, 44, 8, 60, 4,  5, 7, 68, 2, 34, 
    3, 57, 5, 48, 7, 98, 6, 69, 2, 65, 0, 95, 4, 36, 8, 51, 1, 79, 
    1, 69, 7, 44, 4, 38, 0, 48, 6, 34, 8, 62, 2, 87, 5, 60, 3, 42, 
    5,  4, 2, 68, 8, 55, 3, 42, 4, 87, 6, 74, 0, 16, 1, 40, 7, 83, 
    2, 47, 7, 54, 3, 10, 6, 80, 5, 41, 4, 42, 0, 84, 1, 90, 8, 29, 
    4, 72, 0, 77, 5, 94, 1, 34, 3, 82, 7, 18, 2,  6, 6, 11, 8, 42, 
    5, 59, 7,  3, 8,  7, 4, 92, 3,  4, 6, 19, 0, 65, 1, 44, 2, 84
  };
  const int q8488[] = {
    9, 9, // Number of jobs and machines
    0, 50, 7, 46, 1, 44, 2, 19, 3, 60, 4, 79, 5, 53, 6, 30, 8, 25, 
    0, 75, 1, 23, 6, 61, 2, 94, 8, 63, 5, 56, 3, 94, 4, 33, 7, 78, 
    4,  4, 6, 38, 3, 27, 1, 92, 2, 44, 7, 55, 8, 86, 0, 17, 5, 87, 
    3, 44, 1, 80, 0, 14, 4, 18, 8, 73, 2, 59, 5, 95, 7, 79, 6, 57, 
    5, 94, 6, 19, 8, 55, 3, 49, 4, 83, 7, 15, 0, 47, 1, 55, 2,  6, 
    8, 54, 5, 89, 1, 22, 6, 18, 2, 72, 3, 69, 4, 95, 7, 17, 0, 67, 
    3, 15, 2, 85, 7, 45, 1, 52, 5, 86, 6,  4, 0, 53, 8, 16, 4, 33, 
    8, 56, 3, 86, 6, 39, 4, 34, 5, 51, 7, 48, 1, 18, 0, 85, 2, 61, 
    8, 41, 1,  9, 7, 51, 3, 65, 2, 20, 4,  9, 5, 36, 6, 77, 0, 59
  };
  const int q8489[] = {
    9, 9, // Number of jobs and machines
    6, 38, 7, 56, 1, 50, 4, 15, 0, 81, 8, 46, 5, 80, 2, 98, 3, 80, 
    0, 83, 1, 23, 2, 79, 5, 69, 4, 29, 8, 17, 3,  5, 7, 58, 6, 99, 
    8, 22, 7, 96, 4, 77, 6, 55, 1, 26, 5, 71, 2,  7, 0, 16, 3, 33, 
    2, 27, 7, 88, 1, 40, 3, 11, 6, 15, 0, 43, 8, 13, 5, 16, 4, 46, 
    5, 23, 2, 16, 6, 50, 8, 98, 3, 19, 4, 96, 1, 15, 0, 88, 7, 47, 
    2,  3, 0, 29, 8, 42, 5, 12, 6,  6, 3, 12, 4, 28, 1, 55, 7, 21, 
    6, 65, 4,  9, 1, 27, 3, 36, 2, 64, 7, 96, 5, 43, 0, 15, 8, 58, 
    6, 19, 3, 99, 0, 27, 1, 24, 8, 81, 5, 12, 4,  6, 2, 36, 7, 59, 
    4, 11, 8, 18, 7, 91, 2, 10, 6, 97, 5, 42, 1, 88, 0, 48, 3, 85
  };
  const int q8490[] = {
    9, 9, // Number of jobs and machines
    2, 22, 4, 54, 1, 13, 6, 30, 8,  7, 5, 46, 7,  1, 3, 18, 0, 26, 
    5, 47, 1,  6, 6, 54, 8, 92, 4, 93, 3,  7, 2, 32, 7, 40, 0,  6, 
    3,  7, 2, 38, 0, 99, 1, 41, 5, 11, 6, 79, 4, 63, 8, 50, 7, 64, 
    2, 68, 1, 30, 7, 72, 8, 41, 5, 85, 4, 27, 3, 23, 0, 22, 6, 20, 
    6, 22, 3, 44, 8, 15, 1, 52, 7, 42, 0, 38, 5, 59, 2, 15, 4, 74, 
    0, 79, 5, 69, 8, 43, 1, 89, 7, 82, 6, 10, 2, 28, 4, 25, 3, 15, 
    3,  6, 4, 23, 8, 15, 1, 14, 0,  4, 7, 27, 6,  5, 2, 44, 5, 19, 
    0, 54, 8, 82, 5, 86, 6, 13, 4, 81, 3, 91, 2, 42, 7, 37, 1, 57, 
    5, 84, 0, 95, 7, 94, 2, 82, 3, 73, 1, 19, 4, 90, 8, 14, 6, 25
  };
  const int q8491[] = {
    9, 9, // Number of jobs and machines
    5, 63, 8, 73, 7, 99, 1, 22, 0,  3, 2, 40, 6, 87, 4,  3, 3, 16, 
    5, 55, 8, 77, 7, 38, 1, 82, 4, 69, 3, 56, 2, 28, 6, 46, 0, 97, 
    6, 40, 1,  1, 2, 36, 5, 62, 4, 41, 8, 24, 0, 34, 7, 71, 3,  9, 
    2, 58, 7,  5, 1,  6, 0, 22, 4, 86, 8, 76, 6, 93, 3, 44, 5,  1, 
    4, 13, 8, 81, 6, 60, 0, 71, 1, 82, 3, 37, 5, 19, 7, 77, 2,  5, 
    7, 56, 5, 30, 8, 82, 2, 20, 0, 23, 3, 40, 1, 93, 4, 48, 6,  6, 
    4, 98, 1,  1, 2, 55, 0,  7, 7, 89, 8, 90, 3, 42, 5, 59, 6,  8, 
    8, 24, 5, 86, 4, 72, 7, 36, 2, 68, 1, 95, 6, 56, 3, 34, 0, 75, 
    1, 11, 3, 17, 7,  5, 8, 76, 2, 13, 4, 66, 6, 85, 0, 92, 5, 12
  };
  const int q8492[] = {
    9, 9, // Number of jobs and machines
    8, 44, 4, 51, 7, 26, 5, 76, 2, 13, 3, 36, 0, 13, 6,  2, 1,  5, 
    1,  2, 6, 11, 3, 91, 7, 40, 4, 76, 0, 73, 8, 48, 5, 66, 2, 96, 
    0, 45, 5, 53, 7, 26, 4, 20, 2, 62, 6, 33, 1, 76, 3, 99, 8, 75, 
    5,  6, 2, 31, 1, 71, 0, 44, 7, 35, 4,  3, 3, 36, 6, 82, 8, 54, 
    4,  8, 7, 87, 3,  8, 8, 84, 6, 98, 1,  7, 5, 42, 0, 43, 2, 47, 
    8, 77, 0, 72, 1, 11, 6, 36, 2, 34, 3, 42, 5, 92, 4, 60, 7, 32, 
    2, 75, 5, 84, 4, 21, 6, 13, 1,  5, 0, 16, 7,  2, 3, 35, 8, 85, 
    6, 68, 5, 33, 1, 43, 8, 90, 7, 36, 4, 28, 3, 75, 0, 53, 2, 87, 
    8, 25, 5, 30, 0, 92, 7, 90, 6,  9, 2, 68, 4, 97, 1, 41, 3,  2
  };
  const int q8493[] = {
    9, 9, // Number of jobs and machines
    0, 17, 5, 31, 7, 39, 3, 63, 8, 70, 1,  4, 2, 54, 4, 83, 6, 41, 
    6, 89, 1, 15, 7, 38, 2, 66, 5, 81, 8, 94, 4, 88, 3, 36, 0, 88, 
    7, 35, 0, 86, 4, 84, 1, 79, 3, 26, 6, 52, 5, 68, 2, 46, 8, 58, 
    2, 95, 7, 75, 3, 63, 8, 60, 4, 20, 5, 42, 1, 90, 6, 11, 0, 90, 
    2, 23, 7, 27, 0, 32, 5,  3, 1, 51, 6, 24, 8, 16, 4, 99, 3, 24, 
    1, 45, 5,  5, 4, 87, 8, 77, 7,  9, 6,  6, 0, 34, 2, 37, 3, 89, 
    4, 97, 6, 57, 5, 87, 1, 60, 0, 72, 2, 46, 8, 34, 7, 13, 3, 52, 
    3, 66, 0, 60, 7, 11, 6, 84, 4, 40, 1, 96, 5, 59, 8, 44, 2, 74, 
    6, 26, 3, 76, 4, 78, 1, 49, 8, 98, 2, 53, 0, 82, 5, 83, 7, 92
  };
  const int q8494[] = {
    9, 9, // Number of jobs and machines
    3, 86, 2, 20, 1, 23, 8, 90, 7, 26, 0, 62, 5, 30, 6, 31, 4, 45, 
    6, 33, 1, 34, 7, 84, 8, 15, 0, 52, 5, 83, 4, 33, 2, 28, 3, 30, 
    2, 72, 5, 36, 7, 55, 1, 59, 6, 28, 0, 15, 4, 43, 3, 17, 8, 76, 
    4, 76, 0, 53, 8,  4, 6, 13, 1, 56, 5, 88, 7, 66, 2, 40, 3, 71, 
    1, 91, 5, 61, 7,  7, 6,  2, 3, 50, 4, 68, 2, 49, 0, 92, 8, 87, 
    6, 51, 2, 95, 1, 10, 0, 20, 7, 39, 4, 28, 8, 15, 5, 94, 3, 89, 
    6, 61, 5, 29, 7, 50, 3, 18, 0, 28, 1, 30, 8, 18, 4, 20, 2, 13, 
    3, 62, 5, 42, 1, 24, 4, 49, 2, 39, 7, 92, 6, 67, 8, 45, 0, 12, 
    0, 19, 2, 98, 5,  9, 8, 91, 1, 31, 4, 23, 6, 56, 3, 68, 7, 39
  };
  const int q8495[] = {
    9, 9, // Number of jobs and machines
    1, 93, 6, 71, 0, 67, 2, 55, 8, 48, 4, 82, 7, 46, 3, 28, 5, 66, 
    4, 80, 2, 53, 8, 55, 7, 82, 6, 23, 0, 11, 3, 40, 1, 68, 5, 40, 
    8, 34, 2, 25, 4, 76, 5, 51, 3, 73, 1, 42, 6,  2, 7,  2, 0, 95, 
    1, 35, 6,  3, 0, 72, 8, 31, 7, 33, 2, 93, 3, 64, 4, 32, 5, 21, 
    3, 12, 0, 81, 4, 16, 8, 74, 2, 58, 7, 38, 5, 98, 1, 70, 6, 90, 
    7, 43, 0,  6, 2, 69, 3, 25, 8, 15, 5, 18, 6, 95, 1, 73, 4, 76, 
    3, 55, 1, 28, 4, 19, 0, 30, 6, 80, 5, 62, 2, 83, 8,  6, 7, 77, 
    3, 68, 2,  6, 1, 50, 5, 13, 6, 74, 8, 15, 0, 83, 7, 91, 4, 97, 
    8, 43, 0, 66, 4, 24, 1, 42, 2, 40, 6, 31, 3, 75, 7, 61, 5,  4
  };
  const int q8496[] = {
    9, 9, // Number of jobs and machines
    0, 87, 1, 16, 8, 13, 2,  5, 3, 98, 4, 38, 7, 35, 5, 12, 6,  1, 
    6, 53, 8, 35, 4, 91, 7, 11, 1, 64, 3, 62, 5, 67, 0, 27, 2, 66, 
    6, 71, 8, 10, 0, 93, 5, 71, 1, 72, 4, 99, 3, 32, 2,  2, 7, 14, 
    4, 70, 7, 42, 6, 67, 1, 82, 8, 78, 3, 74, 0, 56, 2, 73, 5, 11, 
    3, 65, 5, 82, 7,  8, 2, 99, 6, 38, 1, 83, 4, 10, 8, 71, 0, 98, 
    5, 20, 8,  3, 0, 89, 2, 12, 3,  7, 1,  7, 4, 20, 6, 28, 7, 40, 
    7, 84, 3, 65, 8, 15, 6,  3, 5, 38, 2, 81, 0, 67, 4, 57, 1, 62, 
    0, 84, 1, 60, 4, 35, 2, 66, 3, 37, 8, 17, 5, 83, 7, 92, 6, 45, 
    5,  5, 7, 83, 4, 80, 0, 63, 6, 77, 1, 75, 8, 21, 2, 50, 3, 40
  };
  const int q8497[] = {
    9, 9, // Number of jobs and machines
    8, 10, 4, 83, 2, 79, 3, 12, 6, 98, 5,  6, 7, 42, 1, 40, 0, 64, 
    1, 83, 3,  2, 0, 14, 6, 59, 7, 39, 8, 84, 4, 75, 2, 81, 5, 51, 
    4, 97, 5,  7, 7, 38, 6,  5, 0, 19, 8, 86, 3, 18, 2, 52, 1, 91, 
    3, 69, 0, 78, 1, 96, 4,  2, 7, 76, 6, 94, 2, 12, 8, 77, 5, 53, 
    8, 45, 7, 32, 5, 10, 4, 44, 0, 94, 3, 11, 6, 12, 2, 96, 1, 28, 
    8, 18, 6, 86, 5, 85, 7, 80, 4, 63, 1, 39, 3, 69, 2, 44, 0, 35, 
    3, 59, 8, 69, 4, 86, 7, 12, 6, 29, 2, 47, 5, 61, 1, 66, 0,  5, 
    4,  9, 5, 83, 1, 55, 0, 34, 2, 90, 3, 85, 7, 99, 6, 51, 8, 34, 
    4, 59, 2,  1, 6, 97, 7, 14, 0, 61, 8, 67, 1, 68, 5, 27, 3, 36
  };
  const int q8498[] = {
    9, 9, // Number of jobs and machines
    4, 90, 0, 34, 5, 83, 7,  1, 3, 89, 6, 22, 2, 46, 8, 76, 1, 63, 
    7, 39, 5, 41, 3, 55, 2, 83, 8, 52, 4, 77, 0, 29, 6,  7, 1, 71, 
    3, 31, 8, 97, 7, 24, 2,  9, 4, 29, 0, 17, 5, 55, 1,  2, 6, 64, 
    3, 84, 1, 96, 2, 76, 7, 67, 0, 53, 5, 62, 4, 86, 6, 76, 8, 22, 
    0, 97, 8, 59, 6, 13, 3, 74, 1, 93, 5, 16, 4, 10, 2, 10, 7, 76, 
    1, 86, 2, 43, 6, 60, 0, 29, 8, 43, 3, 78, 4,  3, 7, 86, 5, 27, 
    3, 32, 1, 44, 5, 90, 0, 96, 6, 29, 8, 34, 7, 88, 2, 12, 4, 99, 
    8, 54, 3, 78, 2, 37, 7, 27, 4, 81, 1, 75, 6, 20, 0, 41, 5, 99, 
    6, 68, 8, 17, 1, 36, 5, 75, 3, 70, 2, 72, 0, 12, 7, 21, 4, 22
  };
  const int q8499[] = {
    9, 9, // Number of jobs and machines
    3, 54, 7, 60, 1, 23, 5, 27, 0, 91, 4, 86, 6, 12, 2,  2, 8, 61, 
    8, 89, 0, 64, 6, 84, 2, 78, 5, 57, 7, 12, 1, 85, 4, 24, 3, 51, 
    0, 89, 8, 57, 1,  3, 5, 63, 2, 80, 7, 86, 4, 47, 3, 74, 6,  3, 
    5, 82, 3, 48, 4, 92, 2, 42, 7, 88, 1, 42, 0, 89, 6,  5, 8, 33, 
    1, 55, 7, 90, 5, 33, 8, 14, 3, 32, 0, 45, 2, 85, 4, 69, 6, 48, 
    8, 96, 3, 38, 5,  2, 7, 59, 4, 58, 2, 79, 6, 55, 0, 32, 1, 11, 
    7, 54, 5, 95, 0, 25, 2, 81, 6, 62, 1, 36, 4, 56, 8, 92, 3, 41, 
    4, 94, 2, 31, 0, 13, 8, 43, 7, 20, 3, 43, 5, 42, 6, 94, 1,  3, 
    1, 38, 7, 20, 5, 83, 2, 47, 4,  3, 8, 27, 3, 62, 6, 99, 0, 75
  };
  const int q8500[] = {
    9, 9, // Number of jobs and machines
    7, 40, 1, 77, 8, 73, 2, 52, 5, 32, 0, 99, 6, 13, 3, 78, 4, 34, 
    4, 68, 5, 93, 6, 63, 2,  7, 0, 82, 8,  6, 1, 77, 3, 94, 7, 37, 
    7, 38, 2, 26, 6, 41, 1, 37, 3,  3, 0, 88, 4, 66, 8, 31, 5, 78, 
    7, 86, 1, 84, 6, 23, 8, 77, 2, 31, 3, 50, 4, 56, 0, 51, 5,  3, 
    8, 79, 7, 13, 6, 42, 1, 33, 0, 83, 2, 78, 3, 30, 5, 98, 4, 92, 
    1, 91, 2, 12, 0,  3, 3, 14, 6, 62, 7, 90, 5, 83, 4, 91, 8, 77, 
    6, 69, 2,  9, 7, 25, 4, 47, 5, 22, 0, 38, 1, 72, 8, 93, 3, 39, 
    3, 36, 1, 25, 6, 42, 5, 39, 7, 41, 0, 99, 2,  4, 8, 67, 4, 89, 
    5, 12, 2, 98, 4, 60, 1, 28, 8, 42, 6, 52, 7, 21, 3, 81, 0, 17
  };
  const int q8501[] = {
    9, 9, // Number of jobs and machines
    1, 12, 0, 51, 3, 92, 4, 89, 2, 12, 6, 88, 7, 39, 8, 45, 5, 18, 
    6, 59, 7, 38, 1,  5, 2, 76, 3, 43, 0, 48, 5, 52, 8, 95, 4, 66, 
    7, 39, 0, 77, 2, 53, 4, 53, 3, 81, 5, 84, 6, 72, 1, 46, 8, 15, 
    8, 34, 6, 33, 2, 98, 1, 92, 3, 10, 7, 71, 0, 17, 4, 99, 5, 42, 
    0, 65, 2, 57, 7, 61, 3, 76, 5, 40, 1,  6, 4, 52, 6, 55, 8, 80, 
    3, 62, 7, 17, 2,  9, 1, 34, 4, 11, 8, 73, 0, 93, 6, 62, 5, 79, 
    5, 99, 1, 66, 2, 24, 3, 94, 8, 65, 0, 11, 7, 54, 6, 89, 4, 90, 
    2, 17, 5, 52, 1, 79, 6, 95, 3, 55, 4, 38, 8, 75, 7, 62, 0, 33, 
    8, 18, 4, 99, 7, 98, 5, 27, 6, 16, 1, 67, 3, 42, 0, 71, 2, 48
  };
  const int q8502[] = {
    9, 9, // Number of jobs and machines
    7, 88, 4, 91, 2,  1, 5, 93, 1, 74, 3, 70, 8, 76, 6, 21, 0, 11, 
    4, 42, 8, 21, 2, 75, 3, 22, 5, 71, 6, 13, 1, 66, 0, 35, 7, 79, 
    5, 99, 7, 17, 3, 27, 6, 64, 8, 27, 1, 74, 0, 43, 2, 98, 4, 83, 
    4, 66, 1, 42, 7, 47, 0, 43, 2, 44, 6, 24, 5, 55, 8, 96, 3, 47, 
    4, 56, 3, 28, 5, 91, 7, 25, 2, 46, 0, 45, 8, 38, 1, 62, 6, 28, 
    3, 60, 0, 84, 1, 46, 2, 86, 5, 35, 6, 49, 8, 54, 4, 41, 7, 14, 
    2, 34, 4, 33, 7, 38, 5, 99, 0, 13, 3, 20, 1, 24, 6, 73, 8, 15, 
    4, 30, 8, 52, 2, 36, 3, 44, 1, 94, 0, 73, 7, 29, 6, 40, 5, 35, 
    5, 24, 0, 17, 3, 81, 1, 53, 6, 59, 8, 41, 2, 21, 4, 87, 7, 63
  };
  const int q8503[] = {
    9, 9, // Number of jobs and machines
    5, 54, 8, 57, 3, 74, 0, 94, 4,  9, 7, 64, 6, 35, 1, 86, 2, 39, 
    4, 63, 3, 24, 5, 62, 7, 13, 6,  9, 2, 50, 8, 42, 0, 33, 1, 20, 
    2, 81, 3, 74, 7, 41, 6,  1, 0, 97, 8, 16, 4, 84, 1, 22, 5, 92, 
    8, 60, 7,  2, 2, 60, 4, 53, 0, 71, 6, 73, 3, 66, 5,  2, 1,  2, 
    3,  1, 0, 92, 7, 19, 4, 93, 1, 13, 5,  1, 6, 48, 8, 42, 2, 19, 
    5, 28, 3, 60, 1,  4, 0, 55, 7,  8, 4,  8, 8, 50, 2, 61, 6, 20, 
    8, 58, 1, 53, 5, 80, 7, 66, 3,  1, 0, 13, 6, 82, 2, 38, 4, 10, 
    0, 21, 6, 84, 4, 48, 7, 67, 2, 97, 5, 96, 3, 47, 1, 57, 8, 44, 
    4,  4, 3, 72, 7, 63, 1, 20, 0, 55, 2, 48, 5, 49, 6, 39, 8, 86
  };
  const int q8504[] = {
    9, 9, // Number of jobs and machines
    3, 87, 7, 46, 2, 32, 0, 68, 6, 52, 5, 43, 8, 39, 1, 70, 4, 43, 
    2, 86, 7, 61, 4, 45, 5,  9, 1, 66, 6,  5, 8, 65, 3, 66, 0, 57, 
    1, 82, 8, 81, 0, 76, 5, 82, 7, 13, 3,  5, 6, 62, 4, 53, 2, 67, 
    7, 93, 0, 44, 1, 80, 8, 15, 5, 69, 3, 64, 4, 46, 6, 36, 2, 81, 
    7, 64, 3, 13, 0,  7, 4, 72, 6, 79, 8, 23, 2, 19, 1, 79, 5, 81, 
    5, 39, 8, 78, 1, 22, 2, 29, 4, 80, 3, 88, 7, 60, 6, 56, 0, 13, 
    3, 66, 4, 60, 5, 29, 2, 65, 8, 10, 1, 92, 7, 76, 0, 78, 6, 25, 
    3, 14, 1, 76, 5, 73, 2, 65, 4, 88, 7, 73, 8, 78, 0, 21, 6, 86, 
    0, 36, 6, 21, 3, 49, 7, 96, 2, 70, 8, 60, 5, 14, 1, 49, 4, 11
  };
  const int q8505[] = {
    9, 9, // Number of jobs and machines
    8,  3, 1, 93, 7, 92, 2, 77, 4, 40, 0, 52, 6, 48, 3, 29, 5, 97, 
    4, 56, 7, 48, 0, 46, 3, 60, 2, 17, 5, 41, 8,  5, 1, 38, 6, 44, 
    8, 51, 1, 26, 3, 28, 6, 23, 7, 98, 4, 69, 5,  1, 2, 60, 0, 49, 
    7,  9, 3, 48, 5, 23, 1, 75, 4, 24, 2,  3, 8, 42, 6, 72, 0,  1, 
    0, 44, 6, 30, 8, 83, 4, 93, 1, 14, 7, 84, 2, 67, 3, 22, 5, 45, 
    3, 92, 4, 95, 8, 57, 2,  5, 5, 70, 0, 86, 7, 56, 1,  3, 6, 76, 
    6, 13, 4, 89, 7, 81, 5, 32, 0, 83, 2, 99, 8, 60, 3,  4, 1, 65, 
    8, 73, 4, 96, 0, 51, 3, 54, 5, 61, 2, 23, 7, 51, 6, 32, 1, 22, 
    2, 26, 1, 32, 5, 25, 3, 70, 8, 41, 4, 11, 7, 23, 0, 52, 6,  4
  };
  const int q8506[] = {
    9, 9, // Number of jobs and machines
    3, 21, 8, 25, 5,  8, 0, 35, 2,  3, 6, 25, 7, 94, 1, 98, 4, 23, 
    8, 11, 3, 21, 1, 80, 0, 97, 2, 59, 5, 89, 6, 60, 7, 46, 4, 65, 
    4,  9, 6, 19, 1, 40, 8, 87, 2, 29, 3, 77, 0, 92, 5,  8, 7, 33, 
    4,  4, 2, 39, 8, 55, 3, 77, 1, 35, 5, 73, 6, 30, 0, 87, 7, 64, 
    8, 98, 7, 13, 1, 38, 3, 17, 2, 66, 5, 19, 6, 31, 0,  4, 4, 91, 
    2, 98, 4, 25, 0, 44, 8, 23, 5, 77, 3, 48, 7, 76, 1, 93, 6,  4, 
    5, 66, 4, 29, 6, 16, 0, 63, 2, 23, 1, 59, 3, 20, 8, 21, 7,  9, 
    7, 24, 3, 62, 5, 56, 4, 20, 8, 99, 1, 46, 6, 72, 2, 27, 0, 14, 
    8, 75, 5, 25, 3, 55, 6,  7, 0, 95, 1, 56, 2, 10, 4, 59, 7, 34
  };
  const int q8507[] = {
    9, 9, // Number of jobs and machines
    2, 19, 3, 31, 1, 55, 7, 10, 4, 30, 6, 85, 8, 19, 5, 87, 0, 95, 
    4, 23, 2, 26, 5, 97, 3, 10, 7,  2, 0, 38, 8, 89, 6, 18, 1, 30, 
    3, 48, 5, 54, 8, 32, 0, 49, 6, 83, 7, 35, 2, 18, 4, 55, 1,  2, 
    1, 80, 2, 22, 0, 29, 3, 97, 7, 22, 4, 98, 5, 93, 8, 36, 6, 55, 
    7, 61, 6, 50, 1, 32, 8, 75, 3, 92, 2, 45, 4, 40, 5, 62, 0, 29, 
    2, 44, 3, 11, 0, 34, 5,  8, 7, 97, 1, 82, 8, 51, 4, 58, 6, 55, 
    6, 51, 2, 90, 1, 94, 0, 92, 3, 92, 4, 48, 8, 71, 7, 82, 5, 53, 
    2, 96, 8, 32, 6, 82, 1, 92, 5, 86, 3, 68, 7, 76, 4, 25, 0,  9, 
    5, 11, 0, 97, 1,  1, 8, 14, 3, 18, 7, 66, 4, 51, 2, 22, 6,  1
  };
  const int q8508[] = {
    9, 9, // Number of jobs and machines
    5, 27, 1, 75, 8, 60, 4,  1, 7, 17, 3, 10, 2, 26, 0, 87, 6,  6, 
    3, 63, 1, 93, 5, 84, 7, 66, 0, 26, 8, 33, 2, 94, 4, 93, 6, 21, 
    8, 25, 3, 63, 5, 10, 6,  3, 4, 80, 2, 94, 7, 10, 1, 38, 0, 58, 
    4, 84, 2, 82, 8, 78, 6, 72, 0, 42, 3, 10, 1, 92, 7, 55, 5, 67, 
    4,  2, 1, 45, 7, 93, 3, 36, 6, 14, 8, 33, 0, 93, 5, 58, 2, 85, 
    1,  1, 5, 41, 2, 10, 0,  3, 4, 90, 8, 56, 7, 30, 6, 69, 3, 32, 
    6, 81, 1, 42, 0,  1, 5, 48, 2, 14, 3, 29, 8, 27, 7, 13, 4, 24, 
    6, 32, 5, 37, 8, 81, 3, 41, 1, 19, 4, 27, 0, 59, 7, 35, 2, 31, 
    4, 18, 7, 96, 2, 66, 5, 82, 0, 88, 1, 45, 8, 87, 3, 12, 6, 15
  };
  const int q8509[] = {
    9, 9, // Number of jobs and machines
    8, 53, 7, 49, 2, 44, 3, 89, 6, 34, 0, 62, 1, 88, 4, 59, 5, 54, 
    5, 18, 0, 46, 7, 79, 4, 66, 6,  8, 3, 80, 1, 93, 8,  8, 2,  2, 
    1, 71, 7, 91, 8, 51, 0, 78, 4, 77, 2, 59, 5, 18, 3, 89, 6, 42, 
    3, 40, 7, 63, 8, 86, 5, 36, 4, 49, 2, 97, 0, 72, 6,  8, 1, 70, 
    2, 63, 1, 56, 3,  7, 8, 76, 6, 59, 0, 54, 4, 61, 5, 48, 7, 66, 
    0, 69, 4, 79, 6, 34, 8, 30, 1, 90, 7, 91, 5, 28, 2, 23, 3, 12, 
    8,  4, 1, 91, 7, 60, 0, 68, 3, 49, 6, 46, 5, 40, 4, 74, 2, 57, 
    7, 31, 2, 39, 4, 96, 1, 91, 8, 61, 5, 67, 0, 37, 3, 39, 6, 45, 
    3, 33, 1, 63, 6,  1, 2, 96, 4,  7, 7, 18, 0, 20, 8, 87, 5,  2
  };
  const int q8510[] = {
    9, 9, // Number of jobs and machines
    7, 42, 2, 40, 5, 56, 4,  9, 1, 10, 6, 24, 0, 29, 3, 95, 8,  6, 
    2, 32, 4, 14, 3, 69, 7, 44, 1, 28, 8, 34, 6, 99, 5, 88, 0, 41, 
    2, 23, 0, 11, 7, 16, 6, 85, 5,  7, 8, 77, 4, 89, 1, 56, 3, 67, 
    4, 91, 8, 87, 1, 98, 5, 66, 3, 82, 0, 51, 6, 23, 2, 54, 7, 33, 
    7, 50, 1, 51, 3, 18, 5,  5, 2, 75, 8,  6, 4, 74, 6, 87, 0, 72, 
    3, 12, 6, 15, 7, 19, 4, 91, 2, 53, 1, 40, 8, 73, 0, 80, 5, 19, 
    0, 19, 8, 88, 2, 95, 6, 38, 3, 59, 4, 81, 5, 51, 1, 72, 7, 90, 
    0, 48, 5, 56, 3, 53, 4,  6, 2, 14, 7, 49, 8, 87, 1, 44, 6, 20, 
    6, 78, 7,  5, 5, 96, 1, 49, 8, 75, 4, 74, 3, 35, 0, 50, 2, 73
  };
  const int q8511[] = {
    9, 9, // Number of jobs and machines
    2, 37, 6, 15, 8,  7, 1, 35, 4, 51, 3, 12, 5, 21, 0, 98, 7, 77, 
    4, 88, 5, 71, 6,  7, 7, 42, 3, 66, 8, 25, 2, 42, 0, 62, 1, 22, 
    7, 17, 0,  1, 6, 39, 4, 35, 2, 54, 8, 88, 5, 72, 3, 54, 1, 75, 
    6, 59, 4, 72, 8, 42, 3, 74, 5, 62, 1, 35, 7, 85, 2, 34, 0, 60, 
    2, 10, 4, 28, 6,  2, 5, 55, 3, 18, 0, 74, 8, 67, 1, 22, 7, 68, 
    7, 43, 0, 48, 2, 62, 1, 43, 5, 87, 4, 19, 8, 21, 3,  5, 6, 29, 
    7, 24, 4, 43, 6, 58, 0, 27, 2, 73, 3, 27, 5, 27, 8, 37, 1, 79, 
    6, 44, 4, 34, 2,  9, 8, 26, 7, 78, 1,  9, 0, 98, 5, 26, 3,  4, 
    1, 51, 5, 93, 3, 62, 6, 28, 4, 75, 8,  5, 0, 94, 2, 93, 7,  7
  };
  const int q8512[] = {
    9, 9, // Number of jobs and machines
    8, 79, 1, 91, 5,  2, 0, 73, 3, 49, 6, 97, 2, 35, 4, 11, 7,  2, 
    4,  9, 5, 60, 6, 96, 0, 33, 7,  6, 2, 19, 1, 12, 3, 73, 8, 69, 
    2, 28, 8, 22, 0, 38, 3, 90, 7, 68, 4, 50, 1, 13, 5, 48, 6, 41, 
    2,  2, 7, 84, 3, 14, 6, 76, 8, 79, 5,  1, 1, 75, 4, 97, 0,  5, 
    8, 11, 0,  6, 5, 66, 4, 81, 1, 36, 7, 24, 2, 14, 3, 71, 6, 16, 
    6, 80, 3, 31, 7, 28, 4, 18, 0, 72, 8,  2, 2, 37, 5, 20, 1, 97, 
    0, 10, 1, 50, 3, 12, 4, 56, 5, 38, 8, 98, 7, 81, 6, 18, 2, 22, 
    5,  6, 8, 14, 0, 78, 3, 83, 2, 45, 7, 56, 1, 98, 4,  1, 6, 47, 
    5, 34, 7, 66, 3, 58, 1, 71, 6, 89, 2, 76, 0, 62, 8, 14, 4,  5
  };
  const int q8513[] = {
    9, 9, // Number of jobs and machines
    3,  6, 4, 52, 1, 61, 8, 32, 7, 53, 0, 87, 2,  7, 6, 87, 5, 54, 
    5, 47, 0, 65, 2, 23, 7, 38, 4, 43, 6, 23, 1,  5, 3, 34, 8, 30, 
    3, 79, 1, 93, 8, 73, 5, 28, 6, 22, 4,  4, 7, 57, 2, 53, 0, 12, 
    0, 50, 7, 97, 6, 77, 3, 42, 1, 67, 4, 16, 5, 68, 2,  3, 8, 55, 
    2,  3, 8, 29, 1, 77, 4, 45, 3, 44, 6, 89, 0, 27, 7, 97, 5, 87, 
    8, 38, 2, 85, 4,  6, 0, 28, 3, 28, 6, 16, 5, 32, 1, 34, 7,  8, 
    7, 45, 4, 94, 3, 85, 5, 19, 0, 10, 2, 63, 1, 15, 6, 99, 8, 69, 
    2, 80, 8, 46, 6, 15, 5, 65, 1, 70, 7, 80, 3, 24, 4, 29, 0, 61, 
    7, 41, 6, 59, 0, 58, 8,  2, 2, 87, 5, 71, 3, 84, 1, 46, 4, 71
  };
  const int q8514[] = {
    9, 9, // Number of jobs and machines
    2, 19, 6, 85, 4, 11, 5, 87, 7, 99, 8, 52, 3, 85, 0, 26, 1, 94, 
    4, 30, 7, 98, 5, 14, 0, 58, 2, 92, 6, 89, 3, 20, 1, 41, 8, 87, 
    3, 94, 2, 90, 8, 47, 6, 51, 5, 98, 0, 66, 7, 43, 4, 35, 1, 64, 
    1, 55, 5, 62, 4, 19, 7, 35, 8, 60, 3, 70, 2, 37, 0, 13, 6, 52, 
    8, 99, 1, 86, 4, 24, 7,  7, 0, 65, 5, 65, 3, 15, 2, 26, 6, 43, 
    6, 52, 1, 65, 2, 75, 7, 42, 8, 59, 4,  6, 5, 91, 3, 87, 0, 81, 
    6, 23, 8, 84, 3, 74, 5, 14, 7, 28, 1, 95, 2, 94, 0, 26, 4, 90, 
    6,  9, 5,  3, 4,  2, 7, 45, 0, 18, 2, 71, 8, 81, 3, 28, 1, 23, 
    3, 79, 2, 53, 5, 87, 1, 11, 4, 39, 7, 66, 8, 85, 0, 16, 6, 46
  };
  const int q8515[] = {
    9, 9, // Number of jobs and machines
    2, 34, 7, 72, 3,  5, 5, 34, 8, 76, 1, 66, 0, 38, 4, 32, 6, 95, 
    8,  9, 1, 81, 6, 28, 7,  8, 5, 85, 3, 15, 2, 43, 4,  5, 0, 50, 
    0,  7, 6, 10, 3,  2, 1, 40, 4, 81, 8, 65, 2, 28, 5,  5, 7, 20, 
    8, 95, 1, 87, 2, 73, 4, 34, 6, 58, 7, 10, 5, 66, 0, 79, 3, 64, 
    3, 30, 1,  1, 6, 97, 4, 84, 2, 32, 0, 97, 7, 15, 5, 12, 8,  6, 
    6, 67, 1, 32, 2, 81, 3, 32, 5, 98, 4,  2, 0,  4, 7, 10, 8, 49, 
    3, 98, 6, 55, 0, 53, 4, 11, 7, 80, 1, 98, 2, 31, 8, 20, 5, 74, 
    5, 32, 2, 76, 1, 41, 4, 22, 3, 84, 0, 44, 7, 17, 8,  2, 6, 62, 
    8, 11, 4, 78, 2, 67, 5,  6, 0, 82, 7, 77, 3, 36, 6, 18, 1, 71
  };
  const int q8516[] = {
    9, 9, // Number of jobs and machines
    8, 61, 0, 97, 6, 82, 5, 27, 1, 78, 7, 59, 4, 23, 3, 16, 2, 57, 
    5, 47, 3, 99, 6, 26, 0, 19, 1, 95, 2, 12, 7, 37, 4, 84, 8, 95, 
    0, 89, 5, 96, 4, 15, 8, 50, 1, 50, 7, 79, 2, 77, 6, 91, 3, 29, 
    3, 10, 0, 20, 6, 26, 5, 15, 1, 50, 8, 12, 2,  1, 7, 23, 4,  8, 
    3, 10, 0, 73, 6, 20, 4, 84, 2, 47, 8, 76, 7, 99, 5, 23, 1, 47, 
    7, 84, 5, 98, 2, 58, 0, 67, 6,  7, 8, 89, 3, 81, 4, 24, 1, 63, 
    5, 83, 3, 63, 6, 85, 8, 86, 7, 63, 2, 52, 0, 70, 4, 80, 1, 90, 
    8, 87, 6, 34, 5, 49, 0, 55, 1,  2, 2, 85, 4,  1, 7, 13, 3, 27, 
    2, 33, 6, 16, 0, 25, 4, 43, 3, 92, 5, 63, 7, 52, 1,  5, 8, 48
  };
  const int q8517[] = {
    9, 9, // Number of jobs and machines
    8,  1, 0, 26, 6, 85, 4, 10, 1, 89, 7, 77, 5, 95, 2, 72, 3, 52, 
    0, 17, 3, 54, 1, 87, 6, 72, 8, 52, 7, 73, 5, 12, 4, 16, 2, 11, 
    7, 53, 0, 43, 5, 95, 6, 90, 2, 75, 4, 14, 8, 63, 1, 70, 3, 42, 
    2, 21, 3, 29, 6, 15, 7, 45, 5, 95, 0, 80, 1, 93, 4, 57, 8, 90, 
    1,  6, 6, 23, 0, 89, 7, 21, 5, 53, 8, 44, 4, 89, 3,  4, 2, 54, 
    2, 84, 5, 97, 4, 59, 1, 25, 3, 37, 8, 73, 6, 92, 7, 45, 0, 59, 
    4, 91, 0,  9, 5, 47, 7, 80, 3,  3, 1, 88, 8, 58, 6,  7, 2, 12, 
    5, 59, 7, 97, 1, 47, 3, 84, 0, 63, 2,  5, 8, 54, 4, 51, 6, 72, 
    6, 51, 5, 19, 3, 82, 4, 20, 1, 21, 2, 55, 8, 75, 7, 56, 0, 56
  };
  const int q8518[] = {
    9, 9, // Number of jobs and machines
    4,  3, 0, 26, 8, 49, 3, 29, 1, 73, 5,  6, 6, 76, 7, 22, 2, 91, 
    2, 32, 5, 70, 0, 43, 4, 64, 6, 41, 8, 40, 3, 64, 7,  7, 1, 66, 
    7, 23, 8, 44, 5, 44, 6, 15, 4, 26, 2, 77, 3, 98, 0, 18, 1, 72, 
    6, 94, 2, 47, 3, 72, 8, 31, 1, 78, 0, 11, 7, 28, 4, 20, 5, 71, 
    6, 22, 5, 58, 0, 12, 8,  5, 1, 52, 3, 34, 7, 30, 2, 73, 4, 24, 
    8, 55, 5, 59, 3, 42, 1, 46, 4, 81, 7, 74, 2, 93, 0, 76, 6,  8, 
    4, 85, 6, 28, 3, 97, 0, 86, 1, 49, 2, 16, 7, 29, 8, 24, 5,  2, 
    0,  3, 1,  5, 7, 61, 3, 10, 6, 74, 8,  1, 5, 63, 4, 60, 2, 65, 
    6, 32, 8, 26, 3, 27, 5, 49, 0,  2, 7, 87, 2, 30, 4, 74, 1, 58
  };
  const int q8519[] = {
    9, 9, // Number of jobs and machines
    3, 72, 0, 65, 4, 32, 2, 15, 6, 41, 1, 23, 5, 17, 8, 35, 7, 10, 
    3, 11, 8, 29, 6, 62, 4, 75, 2, 91, 5, 58, 1, 73, 7, 11, 0, 68, 
    3,  7, 0, 28, 4, 12, 1, 74, 8, 12, 6, 11, 2, 88, 5, 90, 7, 31, 
    4, 49, 7, 31, 3, 94, 0, 88, 6, 31, 1, 21, 8,  4, 5, 75, 2,  8, 
    1, 50, 4, 63, 7, 40, 5, 13, 0,  6, 2, 62, 8, 24, 6, 37, 3, 57, 
    6, 47, 7, 32, 1, 96, 0, 75, 2, 44, 4, 27, 8, 15, 5, 61, 3, 60, 
    3, 37, 4, 70, 7, 33, 0, 39, 2, 84, 8, 85, 5, 53, 6, 41, 1, 16, 
    8, 48, 7, 15, 5, 45, 0, 36, 1, 22, 4, 52, 3, 99, 6, 43, 2, 12, 
    0,  8, 2, 74, 6, 83, 7, 26, 8, 59, 1, 75, 5, 79, 3, 43, 4, 92
  };
  const int q8520[] = {
    9, 9, // Number of jobs and machines
    0, 61, 5, 68, 8, 66, 1, 25, 2, 33, 6, 62, 7, 19, 3, 14, 4,  2, 
    8, 20, 4,  5, 3,  7, 1, 28, 2, 43, 7, 51, 0,  2, 5,  8, 6, 62, 
    7, 66, 2, 77, 0, 78, 1, 27, 8, 29, 3, 32, 6, 37, 5, 20, 4, 10, 
    7,  2, 3, 28, 2, 82, 5, 38, 4, 78, 1, 57, 6,  3, 0,  4, 8, 39, 
    5, 30, 2, 50, 3, 18, 0, 46, 8, 11, 1, 56, 7, 41, 4, 96, 6,  3, 
    1, 38, 8, 60, 3, 84, 0, 28, 6,  6, 5, 42, 4, 85, 7, 67, 2, 21, 
    2, 85, 4, 72, 7, 75, 5, 11, 1,  4, 8, 13, 6, 73, 0, 57, 3, 50, 
    0, 43, 1, 81, 7, 75, 6, 26, 3, 47, 8, 12, 4, 34, 2, 35, 5, 28, 
    8, 31, 4, 23, 7, 93, 1, 35, 2, 14, 5, 87, 0, 25, 6, 31, 3, 23
  };
  const int q8521[] = {
    9, 9, // Number of jobs and machines
    0, 53, 4, 20, 1, 11, 3, 47, 7, 30, 5, 80, 6, 32, 8, 52, 2, 54, 
    1, 53, 4, 88, 2, 98, 8, 36, 5, 58, 7, 11, 3, 99, 0, 11, 6,  4, 
    2, 47, 0, 58, 3, 19, 6,  5, 1, 76, 5, 20, 7, 28, 4, 75, 8, 77, 
    7, 87, 3, 34, 6, 63, 2, 96, 0, 95, 4, 25, 1, 53, 5, 39, 8, 91, 
    6, 54, 2, 63, 5, 99, 1, 22, 0, 81, 8, 90, 7, 53, 3, 40, 4, 57, 
    3, 49, 7, 60, 2, 20, 8, 27, 6, 72, 1, 22, 4, 55, 5, 89, 0, 10, 
    0, 43, 7, 60, 5, 23, 1, 34, 8, 94, 3, 57, 4, 22, 2, 49, 6, 56, 
    4, 78, 7, 93, 8, 59, 3, 40, 2,  3, 5, 99, 6, 66, 0, 53, 1, 59, 
    7, 35, 5, 84, 6, 53, 0, 38, 4, 55, 8, 88, 1,  4, 2, 47, 3, 20
  };
  const int q8522[] = {
    9, 9, // Number of jobs and machines
    3, 74, 8, 16, 2, 76, 1, 64, 6, 83, 7, 24, 0, 89, 4, 59, 5, 96, 
    3, 65, 4, 53, 8, 20, 0, 71, 7, 72, 5, 79, 1, 82, 6, 13, 2, 57, 
    3, 13, 5, 26, 7, 89, 1, 91, 0, 43, 8, 33, 6, 12, 4, 13, 2, 99, 
    3, 75, 1, 83, 7, 82, 2, 42, 6, 54, 0, 86, 5, 81, 8, 59, 4, 81, 
    0, 48, 3, 97, 6, 13, 1, 48, 4, 75, 5, 30, 2,  6, 8, 97, 7, 56, 
    3, 21, 7, 29, 8, 74, 4,  4, 5, 99, 2, 55, 0, 92, 1,  1, 6, 62, 
    3,  7, 1, 32, 0, 51, 6, 70, 8, 87, 4, 15, 5, 57, 2, 91, 7, 67, 
    2,  7, 5, 26, 6, 71, 8, 62, 4,  9, 7, 88, 1, 71, 0, 64, 3, 31, 
    6, 87, 3, 64, 5, 90, 4, 94, 8, 19, 7, 89, 1, 53, 2, 46, 0, 61
  };
  const int q8523[] = {
    9, 9, // Number of jobs and machines
    8, 85, 5, 27, 2, 49, 7, 52, 3, 60, 0, 57, 4, 31, 1, 73, 6, 54, 
    4, 71, 1, 61, 8, 81, 7, 40, 6, 43, 0, 73, 3,  6, 2, 67, 5, 99, 
    6, 20, 4, 27, 8, 22, 0,  6, 5, 76, 7, 58, 1,  1, 2,  7, 3, 54, 
    6, 59, 2, 77, 3, 42, 1, 63, 7, 92, 4, 86, 8, 80, 5, 80, 0, 37, 
    0, 31, 3, 33, 4, 35, 1, 18, 5,  6, 7, 41, 2, 92, 8, 42, 6,  7, 
    7, 39, 1, 66, 5, 71, 3, 69, 8, 67, 0, 35, 2, 42, 4, 87, 6, 45, 
    0, 50, 7,  2, 1,  5, 2, 98, 3, 20, 4, 66, 8, 40, 6, 93, 5, 17, 
    8, 36, 4, 86, 7, 96, 0, 73, 5, 77, 3,  9, 2, 22, 6, 87, 1, 51, 
    8, 19, 5, 91, 2, 37, 0, 56, 6, 25, 3, 21, 7, 31, 1, 25, 4, 57
  };
  const int q8524[] = {
    9, 9, // Number of jobs and machines
    3, 92, 6, 70, 4, 36, 5,  4, 7, 72, 1, 96, 8, 95, 2,  5, 0, 13, 
    3, 61, 2, 38, 7, 38, 8, 48, 6, 27, 0, 25, 1, 47, 4, 78, 5, 80, 
    1, 39, 5, 15, 4,  4, 8, 77, 7, 94, 6, 75, 2, 41, 3, 36, 0, 49, 
    7, 60, 4, 87, 8, 24, 3, 34, 0, 13, 2, 88, 5, 22, 6, 95, 1, 84, 
    3,  1, 5, 67, 2, 69, 1, 85, 8, 23, 4, 27, 6, 78, 0, 34, 7, 83, 
    0,  6, 3, 40, 4,  6, 8, 90, 1, 47, 5, 97, 2,  2, 6, 34, 7, 59, 
    3,  7, 6, 14, 5,  2, 1, 69, 0, 12, 8, 67, 7, 69, 2, 38, 4, 79, 
    1, 89, 7, 11, 6, 10, 3, 49, 5, 61, 4, 68, 8, 79, 2, 84, 0, 12, 
    2, 73, 5, 65, 8,  2, 0, 83, 1, 40, 4, 91, 7, 70, 6, 83, 3, 16
  };
  const int q8525[] = {
    9, 9, // Number of jobs and machines
    1, 97, 8, 72, 3, 86, 7, 26, 0, 37, 5, 57, 4, 63, 6, 14, 2, 73, 
    7, 85, 6, 72, 1, 68, 8, 99, 2, 42, 5,  7, 0, 81, 3, 96, 4, 48, 
    0, 26, 6, 49, 1, 64, 7, 82, 4, 37, 8, 67, 2, 10, 3, 92, 5,  7, 
    4, 62, 0, 11, 5, 14, 8, 16, 6, 35, 2, 65, 7, 34, 3, 58, 1, 26, 
    4, 27, 3, 43, 7, 24, 5, 25, 0, 75, 6, 98, 2, 57, 1, 63, 8, 49, 
    4,  8, 6, 61, 7, 81, 0, 94, 2, 25, 3, 23, 1, 10, 8, 85, 5, 51, 
    0, 65, 8, 76, 6, 41, 7,  4, 3, 74, 2, 87, 4, 54, 1, 23, 5, 86, 
    3, 68, 4, 13, 6,  6, 7, 18, 2, 41, 8, 94, 5, 21, 0, 66, 1, 71, 
    8, 69, 7, 98, 5, 19, 3, 69, 6, 33, 1, 62, 4, 39, 2, 35, 0, 53
  };
  const int q8526[] = {
    9, 9, // Number of jobs and machines
    0, 92, 3, 92, 2, 21, 4, 39, 8, 26, 6, 18, 5,  3, 7, 66, 1, 16, 
    3, 11, 6, 88, 4, 27, 0, 46, 1, 94, 8, 73, 2, 39, 5, 91, 7,  8, 
    4, 91, 8, 68, 0, 74, 3, 23, 2,  1, 7, 20, 5, 46, 6, 67, 1, 76, 
    0, 67, 6, 77, 7, 59, 8, 18, 2,  9, 3, 63, 1, 34, 5,  8, 4, 29, 
    4, 72, 2, 61, 8, 84, 1, 89, 7,  2, 0, 78, 3,  5, 5, 57, 6, 17, 
    6, 97, 1, 38, 0, 83, 5,  1, 2, 75, 4, 26, 8, 96, 3,  9, 7, 11, 
    0, 44, 8, 31, 6, 55, 1, 29, 5,  6, 3, 87, 4,  2, 7, 45, 2, 93, 
    7, 99, 2, 87, 4, 53, 1, 98, 8, 38, 6, 44, 5, 96, 0, 21, 3, 42, 
    3, 70, 1, 64, 2,  8, 5, 61, 4, 62, 7,  7, 8, 32, 0, 10, 6, 56
  };
  const int q8527[] = {
    9, 9, // Number of jobs and machines
    6, 29, 2, 91, 1,  3, 3, 47, 8, 31, 5, 39, 4, 89, 7, 70, 0, 55, 
    2, 66, 6, 19, 8, 57, 0, 87, 1, 89, 3, 72, 5, 46, 7,  2, 4,  2, 
    5, 58, 1, 31, 0, 94, 8, 20, 3, 99, 7, 37, 2, 39, 6, 48, 4, 21, 
    6, 44, 5, 50, 4, 39, 8, 77, 3, 86, 7, 16, 2, 38, 0, 18, 1, 21, 
    4, 44, 3, 81, 1, 94, 2, 43, 7, 10, 8, 84, 5, 29, 0, 67, 6, 38, 
    5, 97, 0, 87, 4, 64, 6, 47, 2, 35, 3, 38, 1, 60, 7, 95, 8, 50, 
    2,  8, 0, 24, 7, 55, 8, 43, 3, 55, 5, 39, 1, 70, 4, 78, 6, 93, 
    2, 32, 4, 58, 5, 57, 7, 19, 3, 88, 0, 19, 6, 47, 1,  8, 8, 23, 
    3, 50, 4, 36, 6, 32, 1, 10, 2, 72, 5, 83, 8, 25, 7, 43, 0, 86
  };
  const int q8528[] = {
    9, 9, // Number of jobs and machines
    6, 64, 4, 33, 0, 94, 1, 66, 2, 91, 3, 11, 5, 81, 8, 47, 7, 98, 
    2, 48, 3, 33, 7, 52, 4,  6, 0, 27, 8, 93, 6, 99, 5, 94, 1, 55, 
    4, 40, 3, 21, 0, 89, 1, 26, 5, 32, 8, 40, 2, 42, 6, 79, 7, 52, 
    5, 80, 1, 19, 7, 40, 0, 40, 6, 68, 3, 12, 8, 21, 2, 82, 4, 13, 
    7, 10, 1, 10, 8, 16, 5, 60, 3, 26, 0, 71, 4, 65, 2, 62, 6, 87, 
    0, 85, 3, 11, 2, 32, 4, 69, 6, 71, 8, 54, 7, 80, 1, 59, 5, 98, 
    3, 25, 7, 14, 0, 27, 5,  6, 4, 60, 6, 82, 2, 83, 8, 29, 1, 99, 
    2, 33, 8, 80, 0,  8, 5, 39, 3, 39, 4, 23, 6, 84, 7, 32, 1,  8, 
    4, 97, 2, 17, 7, 66, 3, 15, 1, 27, 8,  3, 0, 45, 5, 47, 6, 48
  };
  const int q8529[] = {
    9, 9, // Number of jobs and machines
    5, 50, 3, 23, 0, 25, 6, 41, 1, 28, 7,  6, 8, 45, 4, 63, 2, 27, 
    2,  9, 1, 12, 0,  6, 8, 27, 4, 29, 6, 95, 3, 53, 5, 98, 7, 46, 
    0, 26, 2, 45, 7, 52, 6, 62, 4, 40, 8, 50, 1, 21, 5, 64, 3,  4, 
    4, 55, 1,  5, 3, 64, 8, 79, 7, 10, 5, 48, 0, 55, 2,  4, 6, 20, 
    1, 27, 3, 74, 2, 35, 8, 85, 5, 98, 4,  1, 6, 11, 7, 74, 0, 23, 
    7, 41, 6, 15, 1, 36, 2, 94, 8, 70, 3, 66, 4, 34, 0, 51, 5, 82, 
    1, 36, 0, 63, 8, 74, 2,  8, 7, 95, 5, 10, 6, 31, 3,  6, 4, 69, 
    8, 83, 1, 80, 4, 54, 0,  4, 3, 69, 7, 90, 6, 94, 2, 18, 5, 41, 
    7, 48, 4, 18, 5,  5, 8, 23, 0, 23, 1, 81, 3, 80, 2, 91, 6, 55
  };
  const int q8530[] = {
    9, 9, // Number of jobs and machines
    7, 94, 8, 47, 4, 36, 2, 38, 6, 53, 5, 48, 0, 17, 3, 52, 1, 64, 
    6, 83, 0,  4, 7, 79, 1, 50, 5,  3, 2, 18, 8, 45, 3, 80, 4, 50, 
    4, 99, 3, 23, 2, 92, 0, 67, 5,  9, 7, 91, 1,  8, 8,  7, 6,  7, 
    5, 85, 6, 69, 2, 97, 1, 12, 4, 72, 7, 85, 8, 43, 3, 83, 0,  2, 
    4, 79, 7, 42, 2, 52, 5, 39, 8, 51, 3, 35, 6, 84, 1, 66, 0, 53, 
    2, 51, 4,  8, 8, 60, 1, 37, 7, 86, 0, 70, 3, 52, 6,  3, 5, 15, 
    7,  6, 8, 43, 3, 45, 5, 79, 6, 29, 0, 59, 4, 34, 2, 87, 1, 79, 
    2, 20, 5, 34, 1, 28, 3, 24, 4,  1, 0, 86, 6, 32, 7, 24, 8, 89, 
    2, 56, 1, 82, 8, 91, 4, 80, 7, 35, 6, 88, 3, 72, 0, 68, 5, 44
  };
  const int q8531[] = {
    9, 9, // Number of jobs and machines
    1, 72, 4, 91, 5,  6, 0, 41, 6, 10, 2, 42, 3, 83, 7, 44, 8,  2, 
    6, 87, 4,  3, 8, 14, 1, 85, 2, 80, 5, 73, 7, 73, 3, 13, 0, 36, 
    4, 80, 1, 34, 2, 98, 3, 11, 6, 54, 7, 60, 5, 24, 0, 62, 8, 25, 
    4,  8, 2, 98, 1, 83, 6, 93, 0, 13, 7, 39, 5, 98, 8, 36, 3, 52, 
    8, 91, 3, 45, 4, 40, 0, 42, 5, 50, 6,  1, 7, 98, 2, 50, 1, 31, 
    1, 45, 3, 51, 2, 61, 5,  4, 0, 89, 6, 17, 8, 20, 7, 39, 4, 78, 
    6, 26, 5, 42, 2, 36, 3, 71, 7, 67, 4,  4, 8, 28, 0, 53, 1, 61, 
    3, 45, 8,  2, 1, 71, 5, 19, 7, 81, 0, 19, 6, 47, 2, 36, 4, 37, 
    1, 38, 0, 66, 5, 68, 2, 38, 3, 39, 8, 90, 7, 22, 4, 25, 6,  8
  };
  const int q8532[] = {
    9, 9, // Number of jobs and machines
    1, 81, 3, 26, 4,  2, 0, 74, 6, 26, 5, 14, 2, 98, 7, 69, 8, 11, 
    1, 50, 6, 94, 0, 71, 4, 39, 8, 18, 3, 40, 2, 75, 5, 76, 7, 85, 
    2, 36, 7, 78, 0, 58, 8, 14, 4, 43, 1, 84, 6, 62, 3, 29, 5, 76, 
    4, 89, 3, 48, 2, 61, 5, 64, 7, 54, 0, 41, 1, 84, 8,  3, 6, 92, 
    4, 13, 8, 57, 0, 30, 5, 72, 3, 93, 6, 86, 7, 10, 1, 39, 2, 19, 
    3, 76, 6, 13, 2, 11, 5, 62, 8, 49, 0, 20, 7, 55, 1, 37, 4, 99, 
    2, 36, 0, 52, 5, 98, 7, 89, 8, 39, 1, 56, 4, 31, 6, 39, 3, 50, 
    1, 93, 3,  9, 5, 21, 6, 23, 4, 29, 8, 39, 2, 73, 0, 11, 7, 65, 
    7, 94, 5, 17, 0, 19, 6, 31, 3, 51, 1,  3, 2, 32, 8, 66, 4, 50
  };
  const int q8533[] = {
    9, 9, // Number of jobs and machines
    3, 97, 4, 66, 2, 19, 5,  7, 6, 38, 0, 38, 7, 65, 8,  9, 1, 10, 
    5, 44, 6, 31, 7, 87, 3, 98, 2, 88, 4, 53, 8, 67, 0, 70, 1, 12, 
    3, 13, 7, 78, 6, 41, 1, 72, 4, 37, 5, 69, 0, 39, 8, 88, 2, 55, 
    7, 25, 2, 35, 8, 57, 6, 44, 1, 52, 4, 69, 5, 89, 3,  7, 0, 91, 
    8, 12, 3, 15, 1, 37, 6, 29, 0, 45, 7,  7, 4, 94, 5, 41, 2, 59, 
    3, 14, 1, 39, 4, 81, 8, 39, 0, 20, 7, 16, 5, 84, 2, 62, 6, 69, 
    3, 64, 5, 78, 6, 45, 7, 56, 1, 98, 4,  4, 2, 88, 0, 23, 8,  2, 
    2, 23, 6, 35, 3, 64, 7, 60, 4, 42, 1, 90, 5, 77, 0, 55, 8, 64, 
    4, 55, 2, 13, 0,  5, 8, 18, 6, 48, 5, 31, 7, 70, 1, 24, 3, 93
  };
  const int q8534[] = {
    9, 9, // Number of jobs and machines
    5,  8, 7, 39, 1, 20, 8, 52, 0, 27, 6, 33, 4, 50, 3, 65, 2, 58, 
    1, 77, 6, 36, 8, 92, 5, 75, 4, 67, 0, 42, 7, 78, 3,  3, 2, 78, 
    4, 36, 8, 79, 5, 28, 7, 84, 2, 38, 1, 90, 0, 36, 6, 39, 3, 17, 
    2, 29, 4,  8, 0, 18, 8, 16, 5, 48, 1, 69, 6, 88, 3, 48, 7, 76, 
    5, 65, 1, 14, 4, 91, 8, 74, 0, 93, 3, 47, 2, 28, 6, 35, 7, 99, 
    2, 42, 7, 19, 8, 83, 0, 49, 1, 64, 5, 61, 3, 83, 4, 88, 6, 72, 
    4, 44, 5,  8, 1, 22, 6, 51, 2, 33, 7, 61, 3, 69, 0, 70, 8, 48, 
    2, 28, 3,  3, 0,  4, 8, 65, 1, 63, 7, 54, 6, 19, 5, 60, 4, 39, 
    3, 72, 1, 90, 6, 81, 7, 59, 5, 19, 0, 59, 8, 91, 2, 28, 4, 87
  };
  const int q8535[] = {
    9, 9, // Number of jobs and machines
    4, 37, 5, 76, 6,  9, 3, 59, 7, 35, 0, 20, 1,  7, 2, 57, 8, 47, 
    4, 23, 3, 26, 1, 45, 5, 55, 8, 62, 0, 84, 6, 43, 7, 63, 2, 31, 
    0, 49, 5, 53, 3, 66, 2, 55, 8, 21, 7, 93, 6, 61, 1, 48, 4, 85, 
    0, 41, 4, 92, 1, 17, 8, 35, 7, 67, 5, 94, 2, 97, 3,  9, 6, 72, 
    6,  8, 3, 25, 5, 24, 1, 44, 0, 26, 7, 51, 2, 56, 8,  1, 4, 23, 
    2, 38, 0, 70, 5, 66, 6,  6, 7, 21, 8, 64, 1, 38, 3, 28, 4, 28, 
    1, 57, 3, 44, 6, 35, 5, 30, 8, 65, 2, 11, 0, 95, 7, 40, 4, 56, 
    5, 90, 1, 58, 6, 71, 0, 58, 7, 86, 2, 55, 3, 85, 4, 27, 8, 64, 
    3, 25, 5, 23, 4, 64, 2, 49, 0, 91, 6, 22, 7, 55, 1, 86, 8,  5
  };
  const int q8536[] = {
    9, 9, // Number of jobs and machines
    4, 87, 6,  9, 1, 24, 8,  8, 3, 81, 7, 51, 0, 95, 2, 48, 5, 99, 
    2, 35, 1, 96, 6, 11, 3, 76, 8,  4, 4, 21, 7, 64, 5, 11, 0, 56, 
    4, 93, 1, 14, 8, 52, 6, 21, 7,  4, 3, 94, 5, 43, 2, 38, 0, 46, 
    7, 84, 2, 72, 5,  6, 0, 43, 1, 78, 6, 43, 3, 80, 4, 58, 8,  2, 
    4, 95, 8, 18, 2, 29, 6,  2, 5, 31, 0, 38, 1, 52, 3, 96, 7, 32, 
    0, 65, 3, 69, 8, 87, 5, 32, 4, 78, 2, 24, 6, 11, 1, 52, 7, 47, 
    6, 94, 2, 38, 0, 19, 7, 44, 5, 58, 4, 62, 8, 98, 3, 54, 1, 11, 
    5, 39, 7, 66, 6, 66, 0, 71, 3, 89, 4,  5, 2, 76, 8, 51, 1, 87, 
    8, 33, 1, 47, 3,  4, 5, 72, 6, 97, 0, 10, 4, 10, 2, 81, 7, 82
  };
  const int q8537[] = {
    9, 9, // Number of jobs and machines
    6, 82, 1, 54, 7, 59, 4, 74, 8, 17, 3, 71, 5,  4, 2, 95, 0, 79, 
    7, 64, 4, 34, 1, 35, 5, 26, 2, 77, 6,  8, 0, 13, 8, 82, 3, 15, 
    1, 13, 4, 66, 3, 43, 7, 45, 8, 87, 6, 23, 5, 22, 2, 96, 0, 48, 
    7,  1, 1, 16, 3,  7, 8, 95, 6, 83, 2, 31, 0, 53, 4, 45, 5, 85, 
    7, 49, 5, 70, 0, 38, 8, 28, 4, 77, 2, 38, 3, 61, 6, 84, 1, 59, 
    8, 78, 1, 22, 6, 14, 0, 73, 2, 22, 5, 19, 7, 85, 4, 25, 3, 43, 
    6, 14, 0, 97, 2, 85, 3, 17, 5, 76, 7,  6, 1,  8, 4, 92, 8, 50, 
    4, 40, 8, 44, 7, 86, 5, 68, 0, 81, 2, 83, 3, 53, 6, 51, 1, 18, 
    0, 33, 3, 27, 1, 92, 8, 82, 4, 61, 2, 11, 5, 32, 6, 66, 7, 32
  };
  const int q8538[] = {
    9, 9, // Number of jobs and machines
    2, 16, 7, 76, 0, 58, 3, 30, 1, 62, 8, 18, 5, 13, 4,  6, 6, 64, 
    3, 24, 1, 44, 8, 72, 4, 19, 0, 79, 7, 34, 6, 50, 5, 18, 2, 16, 
    5, 82, 7, 66, 4, 66, 2, 74, 8, 50, 6, 32, 1, 55, 3,  2, 0, 71, 
    4,  8, 6, 18, 1, 27, 3, 46, 2, 72, 5, 76, 0, 29, 8, 13, 7,  2, 
    7, 78, 8,  4, 1, 27, 0, 12, 6, 85, 3, 78, 5, 65, 4, 16, 2, 29, 
    5, 71, 7, 64, 2, 33, 0, 60, 3, 86, 8, 51, 4, 45, 1, 49, 6, 53, 
    3, 10, 6, 77, 2, 40, 7, 62, 0, 11, 1, 58, 4, 52, 8, 30, 5, 66, 
    0, 60, 1, 57, 2, 50, 7, 67, 6, 15, 5, 97, 8, 53, 4, 60, 3, 10, 
    3, 29, 5,  6, 2, 62, 7, 64, 0, 29, 1, 35, 4,  4, 6, 28, 8, 53
  };
  const int q8539[] = {
    9, 9, // Number of jobs and machines
    3, 95, 0,  9, 7, 49, 4,  3, 5, 46, 1, 80, 6, 35, 8,  1, 2, 43, 
    6, 82, 7, 19, 1, 43, 8, 23, 2, 13, 3, 64, 5, 96, 4, 59, 0, 94, 
    0, 61, 1,  7, 3, 61, 8, 20, 5,  3, 2,  2, 6, 58, 4, 71, 7, 40, 
    0, 70, 7, 82, 2, 11, 5, 87, 1, 67, 3, 49, 4, 67, 6, 91, 8, 90, 
    8, 91, 5, 60, 7, 56, 3, 17, 1, 47, 6, 99, 4, 86, 2, 36, 0, 41, 
    7, 78, 2, 48, 6, 38, 3, 98, 8, 93, 5, 51, 4, 56, 0, 52, 1, 47, 
    6, 13, 7, 98, 5, 98, 0,  7, 3, 74, 2, 11, 8, 14, 1, 52, 4, 66, 
    5, 52, 2, 68, 0, 41, 1, 17, 4, 80, 3, 78, 6, 29, 7, 61, 8,  4, 
    8, 61, 1, 19, 5, 98, 3, 28, 7, 62, 6, 33, 0, 58, 2, 58, 4, 48
  };
  const int q8540[] = {
    9, 9, // Number of jobs and machines
    8, 89, 2, 41, 5, 28, 3, 48, 6, 83, 4, 70, 1,  9, 0, 53, 7, 71, 
    8, 88, 1, 91, 5, 88, 6,  1, 4, 92, 7, 65, 0, 94, 3, 25, 2, 56, 
    3, 91, 4, 74, 7, 60, 5, 51, 6, 77, 2, 78, 8, 17, 1, 30, 0, 79, 
    7,  8, 2, 67, 0, 62, 1, 92, 6,  9, 5, 63, 3, 52, 8, 43, 4,  1, 
    1, 40, 4, 31, 0, 86, 7, 33, 5, 98, 6, 66, 3, 60, 8, 56, 2, 79, 
    7, 94, 5, 21, 3, 80, 6,  1, 1, 37, 0, 42, 2, 56, 4, 35, 8, 22, 
    6, 57, 4,  6, 2, 33, 3,  4, 5, 15, 7, 70, 1, 30, 8, 12, 0,  1, 
    8, 16, 2, 40, 3, 29, 6, 72, 1,  4, 4, 14, 5, 15, 0,  5, 7, 95, 
    3, 69, 2, 98, 5, 85, 0, 39, 7, 65, 8,  1, 6, 25, 4, 84, 1, 80
  };
  const int q8541[] = {
    9, 9, // Number of jobs and machines
    3, 28, 7, 81, 8, 59, 2, 46, 0, 63, 6,  7, 4, 34, 1, 67, 5, 86, 
    3, 71, 0,  1, 2, 92, 6, 76, 4, 72, 1, 56, 5, 91, 8, 96, 7,  4, 
    6, 21, 8,  8, 2,  4, 3, 94, 0,  5, 1,  2, 5, 16, 7, 35, 4, 49, 
    0, 72, 8, 70, 2, 68, 6, 25, 5, 75, 4, 61, 3, 41, 7, 97, 1, 60, 
    7, 41, 8, 78, 1, 97, 4,  3, 2, 12, 5, 27, 0, 80, 3, 70, 6, 58, 
    1, 29, 8, 12, 2, 19, 5, 50, 0, 46, 4, 69, 6, 53, 3, 83, 7, 57, 
    5, 17, 3, 45, 1, 92, 7, 16, 8, 28, 0, 19, 6, 45, 4, 28, 2, 10, 
    8, 34, 1, 92, 7, 75, 2, 34, 6, 43, 4,  7, 3, 96, 0,  4, 5, 71, 
    7, 16, 1, 87, 5, 45, 8, 67, 0, 23, 3,  6, 6, 39, 2, 45, 4, 43
  };
  const int q8542[] = {
    9, 9, // Number of jobs and machines
    6, 39, 2, 19, 8, 88, 4, 85, 7, 92, 3, 99, 5, 39, 1,  9, 0, 88, 
    4, 40, 7, 45, 8, 14, 1, 13, 6, 52, 0, 40, 5, 48, 2, 38, 3, 19, 
    0, 20, 6, 20, 8, 50, 4, 27, 2, 49, 5, 26, 1, 25, 3, 49, 7, 45, 
    5, 87, 7, 47, 8, 47, 3, 62, 2, 10, 0, 31, 6, 28, 1, 63, 4, 23, 
    4, 63, 2, 94, 5, 22, 6, 32, 3, 23, 0, 81, 1, 53, 8, 74, 7, 89, 
    5, 86, 3, 89, 1, 95, 8, 53, 4, 44, 6,  1, 2, 22, 0, 29, 7, 18, 
    8, 84, 4, 70, 0, 92, 3, 35, 1, 53, 6, 96, 2, 91, 5, 31, 7, 12, 
    8, 48, 1, 79, 4, 51, 3,  5, 7, 16, 2, 61, 6, 59, 5, 78, 0,  3, 
    0, 70, 4, 28, 8,  8, 2, 34, 3,  7, 1, 66, 6, 70, 7, 83, 5, 65
  };
  const int q8543[] = {
    9, 9, // Number of jobs and machines
    8, 85, 1, 62, 2, 36, 5, 39, 6, 62, 3, 70, 0, 41, 7, 46, 4, 79, 
    7, 52, 5, 50, 6, 85, 1, 48, 3, 77, 2, 69, 4, 13, 0, 10, 8, 59, 
    5, 52, 3, 91, 6, 72, 7, 90, 2, 87, 8, 43, 0, 45, 1, 79, 4, 20, 
    4, 85, 1, 12, 5, 56, 7, 63, 8, 57, 6, 71, 2, 94, 3, 87, 0, 67, 
    3, 86, 8, 36, 2, 18, 6, 11, 0, 81, 5, 35, 1, 57, 7, 91, 4, 39, 
    0, 80, 4, 66, 1, 87, 5, 66, 7, 64, 6, 55, 3,  2, 2, 51, 8, 59, 
    2, 95, 7, 70, 5, 32, 0, 84, 6, 32, 4, 42, 3, 96, 1, 57, 8, 53, 
    5, 13, 4, 74, 6,  2, 8, 53, 2, 12, 7, 11, 0, 24, 3, 36, 1, 71, 
    5, 11, 6, 23, 3, 72, 2,  4, 8, 28, 0, 34, 4, 76, 7, 91, 1, 44
  };
  const int q8544[] = {
    9, 9, // Number of jobs and machines
    4, 10, 3, 60, 6, 27, 7, 22, 1, 68, 8, 98, 2, 20, 5, 99, 0, 65, 
    7, 58, 5, 49, 8, 56, 3, 18, 1, 11, 4, 86, 0, 48, 2, 11, 6,  4, 
    4, 98, 2, 13, 3, 24, 0, 37, 1, 69, 6, 50, 5, 61, 8, 56, 7, 89, 
    6, 57, 7, 46, 0, 13, 1, 45, 5, 58, 2, 52, 3, 66, 8, 85, 4, 13, 
    2, 97, 8, 41, 0, 93, 7,  6, 4, 13, 5, 10, 6, 29, 1, 38, 3, 86, 
    7, 85, 8, 16, 3, 65, 5, 88, 0, 46, 1, 28, 2, 55, 6, 48, 4, 33, 
    6, 75, 8, 79, 1, 53, 7, 46, 4, 87, 3, 39, 5, 39, 0, 14, 2, 69, 
    0, 90, 1, 13, 3,  5, 5,  1, 8, 41, 6, 88, 2, 49, 4, 26, 7, 89, 
    8, 50, 4, 15, 1,  2, 2, 53, 6, 92, 3, 55, 0,  3, 5, 50, 7, 39
  };
  const int q8545[] = {
    9, 9, // Number of jobs and machines
    8, 35, 3, 46, 1,  9, 4, 91, 0, 57, 5, 87, 7, 62, 2, 22, 6, 51, 
    6, 97, 8, 46, 1, 90, 5, 42, 3, 94, 4, 31, 2, 52, 0, 48, 7, 93, 
    4, 95, 7, 69, 2, 57, 5,  8, 6, 61, 1, 12, 0, 13, 8, 79, 3, 12, 
    7, 83, 3, 39, 2, 88, 6, 28, 8, 27, 0, 86, 5, 97, 4, 25, 1, 35, 
    2, 94, 7, 82, 5, 31, 6, 30, 3, 10, 1, 14, 0, 10, 8, 85, 4, 54, 
    4, 94, 8, 96, 0, 19, 5, 49, 7, 27, 2, 36, 1, 44, 6, 13, 3, 36, 
    6, 21, 0, 31, 4, 75, 8, 72, 2, 79, 5, 76, 1, 48, 3, 12, 7, 47, 
    3, 88, 1, 57, 7, 77, 0, 49, 6, 97, 4, 81, 5, 30, 8, 95, 2, 89, 
    1, 49, 2, 16, 4, 94, 5,  5, 7, 32, 0,  4, 8,  4, 6, 21, 3, 17
  };
  const int q8546[] = {
    9, 9, // Number of jobs and machines
    8, 20, 5, 65, 1, 77, 0,  9, 6, 46, 2, 46, 3, 18, 7, 33, 4, 47, 
    8, 57, 3,  3, 7, 28, 4, 98, 2, 68, 6, 51, 0, 35, 5, 95, 1, 39, 
    8, 94, 6, 61, 4, 50, 0, 42, 3, 42, 5, 10, 2, 80, 1, 51, 7, 49, 
    1, 96, 0, 56, 4, 53, 2, 19, 3, 79, 6, 25, 7, 55, 5, 64, 8, 31, 
    0, 83, 7, 57, 8, 64, 3, 56, 6, 41, 1, 16, 4, 78, 5, 99, 2,  1, 
    4, 36, 1,  6, 2, 30, 6, 92, 7, 25, 0, 32, 8, 10, 3, 82, 5, 91, 
    5, 32, 0,  7, 7, 81, 8, 82, 3, 81, 1, 15, 2, 72, 6, 58, 4, 73, 
    4, 13, 6, 12, 1,  7, 2, 43, 7, 42, 3, 96, 5, 28, 0, 16, 8, 80, 
    5, 77, 0, 40, 2, 40, 6, 63, 4, 12, 1, 64, 7, 78, 3, 18, 8, 94
  };
  const int q8547[] = {
    9, 9, // Number of jobs and machines
    3, 81, 6, 56, 2, 53, 4, 43, 1, 67, 8, 24, 0, 17, 5, 41, 7, 10, 
    2, 70, 3, 78, 5, 53, 4, 19, 1, 11, 7, 45, 8, 58, 6, 91, 0, 25, 
    0, 54, 4, 79, 2, 82, 3, 19, 7, 88, 8, 78, 6, 99, 5, 10, 1, 29, 
    7, 63, 1, 16, 6, 71, 4, 24, 2, 89, 3, 63, 8, 85, 0, 43, 5, 14, 
    4, 55, 0,  4, 1, 40, 8, 59, 5, 99, 6, 46, 2, 49, 7, 94, 3, 83, 
    0, 17, 3, 88, 5, 25, 7, 71, 4, 46, 1, 62, 6,  8, 8, 16, 2, 85, 
    4, 46, 0, 26, 8, 88, 2, 25, 6, 67, 5, 42, 3, 49, 7,  4, 1, 58, 
    0, 61, 2, 34, 3, 43, 4, 61, 7, 62, 1, 57, 6, 85, 8, 42, 5, 80, 
    4, 93, 5, 31, 6, 53, 3, 13, 0, 70, 7, 85, 2, 35, 1, 46, 8, 41
  };
  const int q8548[] = {
    9, 9, // Number of jobs and machines
    1, 99, 4, 68, 6, 66, 0, 21, 2, 54, 7, 91, 5, 78, 3, 13, 8, 21, 
    6, 25, 4, 91, 7, 65, 3, 21, 0, 66, 5, 70, 2, 35, 1, 83, 8, 45, 
    6,  5, 1, 89, 8, 25, 5, 30, 0, 94, 7, 86, 2,  2, 4, 94, 3, 15, 
    5, 94, 0, 10, 6, 75, 4, 26, 1, 28, 2, 17, 3, 82, 7, 76, 8, 25, 
    8, 48, 1, 55, 0, 57, 6, 31, 3, 96, 2, 56, 5, 26, 4, 97, 7, 15, 
    3, 82, 4, 57, 1,  1, 6, 86, 8, 86, 5,  8, 7, 48, 0, 21, 2, 36, 
    0, 84, 5, 78, 4, 79, 8, 22, 7,  9, 3, 60, 6, 14, 2, 56, 1, 78, 
    5, 33, 0, 84, 6, 31, 7,  6, 2, 62, 3, 32, 1, 69, 8, 50, 4, 23, 
    4, 51, 6, 27, 8, 67, 7, 92, 3, 84, 5, 98, 2, 37, 0, 55, 1, 32
  };
  const int q8549[] = {
    9, 9, // Number of jobs and machines
    8, 17, 3, 59, 5, 83, 4, 64, 6, 11, 0, 82, 1, 98, 2, 15, 7, 13, 
    3, 45, 8, 53, 4,  7, 1, 91, 2, 85, 6, 57, 7, 68, 0, 70, 5, 86, 
    1, 93, 3, 73, 0, 38, 8, 70, 6, 48, 4, 29, 7,  9, 2,  5, 5, 68, 
    0, 94, 3, 58, 1, 65, 8, 84, 7, 70, 2, 48, 5, 51, 6, 53, 4, 46, 
    8, 78, 7,  6, 3, 94, 5, 38, 1, 21, 2, 98, 0, 59, 4, 32, 6,  5, 
    8, 43, 2, 22, 4, 27, 5, 20, 7, 43, 6, 45, 1, 80, 0, 69, 3, 40, 
    5, 45, 3, 43, 7, 75, 0, 70, 2, 63, 1, 70, 8, 74, 4, 80, 6,  2, 
    6, 81, 0, 36, 7, 71, 2,  6, 4, 29, 1, 29, 8, 41, 5, 40, 3, 82, 
    4, 36, 3, 46, 0, 12, 8,  4, 6,  1, 1, 11, 7, 59, 2, 60, 5, 82
  };
  const int q8550[] = {
    9, 9, // Number of jobs and machines
    0, 85, 3, 78, 5, 84, 2,  1, 1, 27, 7,  5, 6, 29, 4, 52, 8, 25, 
    0, 43, 6, 99, 4, 34, 5, 53, 1, 15, 8, 96, 2, 56, 7,  5, 3, 10, 
    4, 83, 1, 18, 2, 23, 7, 48, 5, 27, 8, 28, 0, 37, 3, 30, 6, 81, 
    1,  2, 2, 61, 8, 81, 4, 37, 3, 32, 5, 96, 7, 30, 0, 82, 6, 50, 
    6, 21, 7, 98, 0, 63, 5, 79, 8, 25, 1, 28, 3, 35, 4, 42, 2, 11, 
    3, 11, 0,  3, 4, 84, 5, 40, 6, 30, 2, 84, 7, 59, 1, 93, 8, 19, 
    3, 49, 4, 95, 2, 81, 1, 51, 6, 40, 7, 50, 5,  3, 8, 13, 0, 28, 
    7, 17, 5, 83, 2, 69, 0,  1, 6,  5, 4, 79, 3, 32, 8, 64, 1, 18, 
    6, 50, 2, 64, 3, 63, 1, 13, 4, 58, 7, 36, 5, 65, 8, 74, 0, 91
  };
  const int q8551[] = {
    9, 9, // Number of jobs and machines
    5, 31, 2,  3, 0, 84, 3, 96, 6, 46, 1, 15, 7, 37, 8, 15, 4,  8, 
    4, 40, 8, 19, 2, 67, 5, 85, 7, 37, 0, 14, 6, 60, 1, 32, 3, 13, 
    3, 67, 4, 70, 8, 48, 2, 22, 5, 73, 7, 72, 0, 70, 6, 38, 1, 58, 
    5, 18, 0,  5, 1, 97, 3, 11, 6, 54, 7, 44, 8, 74, 4,  2, 2, 54, 
    4,  1, 2, 55, 3, 70, 5, 20, 6, 83, 0, 31, 1, 31, 7, 18, 8,  2, 
    3, 95, 1, 35, 2, 98, 8, 70, 0, 74, 4, 95, 7, 34, 6, 80, 5, 58, 
    0,  6, 5, 61, 2, 67, 3, 68, 4, 20, 7, 66, 6, 66, 8, 72, 1, 84, 
    7, 15, 5,  4, 4, 67, 1, 85, 0, 99, 6, 38, 3, 56, 2, 83, 8, 85, 
    5,  4, 8, 89, 7, 52, 1, 78, 6, 72, 3, 16, 4, 90, 2, 41, 0, 93
  };
  const int q8552[] = {
    9, 9, // Number of jobs and machines
    3, 45, 0, 59, 7, 28, 4, 53, 6, 38, 2,  2, 1, 64, 5, 15, 8,  4, 
    6, 57, 1, 95, 8, 46, 0, 95, 5, 42, 3, 63, 4, 94, 2, 46, 7, 62, 
    5, 65, 6, 98, 4, 49, 1, 33, 0, 83, 3, 84, 2, 87, 7, 95, 8, 92, 
    3, 10, 4, 96, 5, 62, 1, 82, 6,  5, 7, 92, 2,  2, 0, 23, 8, 95, 
    7, 40, 4, 14, 0, 38, 8, 54, 2, 98, 1, 47, 3, 86, 5, 76, 6,  4, 
    5,  9, 0, 72, 4, 73, 1, 59, 6, 34, 2, 26, 7, 20, 3, 31, 8, 92, 
    1, 47, 6,  4, 7, 53, 2, 80, 3, 22, 8, 67, 4, 32, 5, 85, 0, 38, 
    1, 61, 0, 60, 3, 84, 2, 24, 7, 96, 5, 15, 4, 54, 6, 47, 8, 91, 
    0, 59, 4, 11, 8, 72, 3, 70, 2, 25, 1, 28, 7, 79, 5, 67, 6,  5
  };
  const int q8553[] = {
    9, 9, // Number of jobs and machines
    8, 93, 6, 28, 1, 73, 2, 94, 3, 73, 5, 67, 7, 82, 0, 72, 4, 95, 
    7, 80, 0, 19, 8, 94, 4, 13, 2, 49, 6, 14, 5, 61, 3,  4, 1, 16, 
    1, 20, 4, 10, 7, 15, 3, 76, 5, 18, 2, 61, 6, 78, 0, 61, 8, 86, 
    8, 80, 3, 77, 5, 38, 1, 23, 7, 92, 2, 42, 0, 13, 6, 90, 4, 12, 
    0, 94, 2, 95, 3, 85, 8, 75, 1, 19, 5, 52, 4, 81, 7, 65, 6, 65, 
    4,  4, 7, 45, 8, 73, 6, 15, 3, 30, 0, 49, 2, 99, 5, 45, 1, 30, 
    6, 24, 2, 92, 0, 89, 3, 51, 5, 22, 7, 71, 1, 19, 4, 15, 8, 54, 
    4, 99, 3, 28, 6, 25, 8, 94, 5, 32, 0, 37, 1,  2, 2, 37, 7, 42, 
    1,  4, 7, 81, 8, 11, 3, 27, 6, 91, 0,  2, 5, 22, 2, 80, 4, 19
  };
  const int q8554[] = {
    9, 9, // Number of jobs and machines
    5, 76, 2, 79, 3, 52, 0, 56, 6, 39, 8, 54, 1, 30, 7, 35, 4, 49, 
    1, 82, 8, 21, 5, 45, 2, 61, 6, 17, 7, 19, 3, 76, 0, 74, 4, 87, 
    2, 42, 8, 34, 5, 55, 1, 59, 0, 78, 7, 62, 6, 44, 3, 51, 4, 33, 
    8, 63, 3, 95, 0, 47, 6, 90, 1,  4, 2, 70, 4, 91, 5, 52, 7, 81, 
    6, 32, 5,  6, 0, 64, 3, 15, 8, 74, 7, 35, 1, 97, 2, 26, 4, 11, 
    2, 59, 3, 42, 1,  3, 7, 72, 8, 76, 0, 68, 6, 74, 5, 74, 4, 47, 
    4, 98, 1,  4, 0, 88, 8, 72, 7, 43, 5, 46, 6, 26, 2, 92, 3, 91, 
    3, 39, 4, 33, 0, 86, 5, 81, 7, 66, 6, 84, 1, 66, 2, 64, 8,  9, 
    0,  9, 3, 53, 1, 52, 2, 22, 6, 48, 4, 60, 7, 25, 5, 96, 8, 59
  };
  const int q8555[] = {
    9, 9, // Number of jobs and machines
    0,  1, 6, 16, 4, 50, 1,  2, 8, 88, 7, 33, 2,  2, 5, 70, 3,  1, 
    5,  9, 1, 88, 7, 66, 0, 71, 4, 79, 2, 13, 3, 39, 6, 96, 8, 66, 
    0, 27, 7,  4, 6,  8, 1,  8, 8, 81, 5, 13, 3, 96, 2, 17, 4, 84, 
    2, 78, 0, 24, 4, 47, 1, 68, 7, 32, 3, 66, 8, 56, 5, 31, 6, 30, 
    0, 75, 5, 21, 6, 43, 3, 44, 2, 32, 4, 28, 1, 40, 7, 71, 8, 87, 
    0, 40, 8, 42, 3, 49, 5, 61, 4, 93, 6, 51, 1, 62, 7, 23, 2, 85, 
    6, 42, 4,  6, 3, 92, 5, 88, 1, 39, 8, 93, 0, 96, 7, 62, 2, 49, 
    5, 49, 1, 74, 0, 69, 4, 22, 3, 76, 7, 21, 2, 99, 6, 98, 8,  8, 
    7, 45, 5, 11, 6, 49, 1, 50, 0, 30, 2, 28, 4, 90, 3, 16, 8, 26
  };
  const int q8556[] = {
    9, 9, // Number of jobs and machines
    0, 53, 6, 88, 3, 39, 2, 51, 7, 85, 4,  2, 5, 20, 1, 46, 8, 78, 
    0, 70, 8, 60, 1, 13, 5, 79, 2, 29, 4, 48, 6, 46, 7, 25, 3, 49, 
    5, 47, 6, 18, 8, 31, 2, 57, 4, 70, 1, 23, 3, 99, 0, 22, 7, 21, 
    6,  2, 8, 41, 1, 58, 7, 14, 3, 74, 5, 83, 2, 51, 0, 85, 4, 80, 
    0, 50, 6, 48, 2,  9, 4, 36, 8, 81, 1, 29, 7, 99, 5, 91, 3, 99, 
    3, 44, 1,  1, 4, 41, 7,  3, 8, 80, 2, 42, 6, 98, 0, 15, 5, 44, 
    7,  9, 8, 20, 6, 51, 3, 67, 0, 30, 5, 14, 1, 63, 2, 49, 4, 79, 
    4,  6, 3, 23, 1, 23, 6, 68, 7, 61, 5, 37, 2, 37, 0, 54, 8,  3, 
    1, 76, 0, 38, 4, 15, 6,  5, 7, 35, 3, 92, 2, 82, 8, 83, 5, 96
  };
  const int q8557[] = {
    9, 9, // Number of jobs and machines
    2, 52, 3, 29, 5, 97, 4, 18, 1, 91, 8, 31, 0, 63, 6, 61, 7, 55, 
    4, 83, 0, 86, 3,  8, 2, 69, 1, 76, 7, 35, 5, 40, 6, 90, 8, 42, 
    5, 91, 3, 92, 0, 93, 1, 31, 6, 13, 2, 14, 8, 33, 4, 54, 7, 68, 
    1, 92, 7, 92, 4, 40, 6, 81, 5, 54, 0, 99, 3,  1, 2, 95, 8, 90, 
    6, 26, 8, 27, 4, 94, 0, 90, 5, 10, 1,  3, 2, 41, 7, 62, 3, 23, 
    5, 49, 4, 60, 1, 95, 0,  5, 8, 26, 2, 27, 6, 79, 7, 19, 3, 71, 
    7, 36, 3, 71, 5, 72, 2, 75, 1, 23, 8, 40, 6,  3, 0, 42, 4, 78, 
    3, 88, 6, 52, 8, 14, 4, 10, 0, 50, 7, 80, 5, 26, 1, 29, 2, 48, 
    3, 97, 7,  6, 0, 93, 1, 23, 6, 18, 2,  1, 5, 55, 4,  8, 8,  6
  };
  const int q8558[] = {
    9, 9, // Number of jobs and machines
    7, 18, 1, 89, 6, 16, 2,  6, 4, 90, 3, 30, 0, 10, 8,  8, 5,  6, 
    0, 98, 3, 40, 5, 85, 6, 25, 8, 92, 4,  5, 1, 79, 2, 53, 7, 50, 
    6, 33, 1, 20, 3, 14, 7, 82, 8, 86, 2, 26, 5,  2, 0, 46, 4, 40, 
    5, 88, 6, 80, 0, 30, 8, 57, 1, 98, 2, 28, 4, 37, 3, 46, 7,  6, 
    3, 49, 4, 44, 1, 67, 0, 10, 6,  1, 8,  8, 7, 87, 2, 19, 5, 15, 
    5, 73, 1, 56, 3, 17, 2, 45, 0, 21, 6, 96, 8, 91, 4, 24, 7, 26, 
    2, 85, 7, 45, 5, 76, 8, 50, 6, 79, 3,  5, 1, 55, 4,  2, 0, 36, 
    4,  8, 1, 62, 7, 60, 2, 97, 3, 54, 6, 57, 0, 12, 8, 49, 5, 72, 
    8, 21, 3, 40, 1, 80, 5, 67, 6, 68, 2, 53, 4, 42, 7, 83, 0, 32
  };
  const int q8559[] = {
    9, 9, // Number of jobs and machines
    0, 29, 2, 24, 8, 28, 3, 34, 5, 19, 6, 16, 4, 19, 1, 98, 7, 47, 
    2, 13, 1, 41, 0, 85, 4, 59, 8, 53, 5, 79, 6, 41, 7, 75, 3, 32, 
    2, 80, 6, 12, 8,  8, 7, 99, 3, 50, 5, 62, 4, 14, 0, 34, 1, 88, 
    8, 90, 5, 50, 3, 74, 4, 98, 1, 67, 7, 91, 6, 32, 0, 54, 2, 87, 
    4, 76, 3, 96, 0, 28, 5, 93, 8, 31, 1, 92, 2, 61, 6, 62, 7, 14, 
    5, 74, 0,  9, 3, 53, 2, 88, 4, 48, 7,  3, 6, 86, 1, 54, 8, 17, 
    5, 16, 1, 53, 0, 18, 8, 41, 6, 54, 2, 76, 4,  1, 7, 47, 3, 60, 
    7, 86, 8, 84, 6,  7, 4, 15, 1, 20, 3, 92, 5, 72, 2, 62, 0, 67, 
    5, 67, 7, 69, 1, 89, 8, 49, 3, 58, 0, 41, 2, 39, 6, 28, 4, 76
  };
  const int q8560[] = {
    9, 9, // Number of jobs and machines
    4, 56, 0, 60, 1, 34, 3, 80, 2, 84, 5, 90, 6, 35, 7, 90, 8, 32, 
    1, 19, 5, 33, 3, 62, 6, 86, 2, 83, 4, 20, 7, 44, 8, 80, 0, 94, 
    8, 51, 3, 57, 2, 58, 0,  4, 4, 13, 5, 27, 7, 76, 1, 19, 6, 22, 
    0, 64, 6, 87, 4, 62, 7, 15, 8, 60, 3, 31, 5, 25, 2, 99, 1, 67, 
    3, 16, 8,  7, 2, 58, 4, 88, 5, 86, 0, 48, 6, 55, 7, 45, 1, 75, 
    7, 15, 6, 88, 3, 87, 1, 78, 2, 19, 5, 98, 4, 79, 8, 49, 0, 50, 
    6, 85, 4, 86, 7, 13, 8, 17, 1, 36, 2, 99, 0,  1, 5, 79, 3, 87, 
    7, 14, 3, 63, 2, 66, 6, 70, 1, 44, 8, 66, 4,  3, 0, 50, 5, 44, 
    8, 23, 7, 81, 5, 73, 2, 72, 1, 67, 6, 22, 0, 41, 4, 79, 3, 91
  };
  const int q8561[] = {
    9, 9, // Number of jobs and machines
    4, 96, 3, 22, 7, 31, 1, 69, 2, 13, 0,  5, 8, 16, 6, 99, 5, 26, 
    2, 67, 0, 65, 4, 26, 8, 78, 5, 36, 6, 38, 7, 46, 3, 91, 1, 22, 
    2,  5, 7, 82, 4, 66, 0, 66, 6, 48, 8, 62, 3, 27, 1, 96, 5, 77, 
    5, 21, 8, 91, 2, 18, 1,  7, 3, 23, 7, 50, 4, 47, 0, 71, 6,  8, 
    3, 71, 1, 75, 6, 49, 2, 59, 8, 33, 0, 47, 5, 44, 7, 32, 4, 98, 
    4,  2, 8, 50, 7, 55, 1, 33, 3, 84, 2, 96, 5, 97, 0, 41, 6, 27, 
    3, 96, 0, 35, 5, 84, 8, 86, 1, 95, 2, 74, 7, 93, 4, 13, 6, 47, 
    0, 22, 4, 27, 3, 77, 2, 64, 1, 88, 8, 16, 5, 85, 6, 95, 7, 40, 
    5, 81, 6,  9, 3, 62, 1, 74, 0, 70, 8, 37, 7, 47, 2, 72, 4, 52
  };
  const int q8562[] = {
    9, 9, // Number of jobs and machines
    0, 12, 7, 63, 2, 28, 4, 88, 5, 31, 1, 89, 8, 30, 3, 20, 6, 85, 
    6, 73, 0, 71, 5, 94, 1, 14, 7, 97, 2, 48, 8, 45, 3,  9, 4, 56, 
    8, 53, 4, 98, 2, 38, 3, 97, 5, 21, 7, 13, 6, 30, 0, 50, 1, 83, 
    0, 98, 2,  6, 6, 39, 3, 57, 1, 85, 5, 89, 4, 53, 8, 46, 7,  4, 
    8, 40, 1, 12, 5, 25, 6, 42, 7, 65, 4, 41, 3, 48, 2, 10, 0,  7, 
    7, 76, 0, 41, 1, 14, 5, 67, 3, 10, 4, 52, 6, 59, 8, 52, 2, 13, 
    7, 40, 8, 16, 4, 14, 6,  2, 0, 64, 1, 41, 3, 42, 5, 78, 2, 79, 
    2, 98, 3, 92, 1, 16, 7, 59, 0, 91, 6, 67, 4, 24, 8, 72, 5, 73, 
    6, 15, 3, 30, 2, 92, 5,  9, 0, 90, 1, 73, 8, 48, 7, 67, 4, 82
  };
  const int q8563[] = {
    9, 9, // Number of jobs and machines
    1, 90, 8, 53, 3, 79, 0, 40, 5, 53, 2, 47, 6, 76, 4, 33, 7,  8, 
    7, 23, 2, 54, 6, 63, 1, 86, 3, 16, 5, 94, 8, 52, 4, 23, 0, 17, 
    3, 69, 5, 35, 8, 58, 2, 90, 4, 54, 1, 86, 7, 33, 0, 89, 6, 96, 
    8, 71, 3, 68, 0, 40, 5, 82, 2, 22, 6, 86, 1, 72, 7, 35, 4, 17, 
    8, 44, 7,  4, 2, 40, 6, 47, 4, 86, 5, 99, 3, 33, 0, 54, 1, 84, 
    8, 85, 3, 12, 4, 85, 7, 25, 2, 13, 1, 34, 0, 79, 5, 65, 6, 48, 
    8, 32, 1, 19, 6, 12, 3, 34, 7, 22, 2, 50, 4, 48, 5, 58, 0, 32, 
    2, 65, 5, 74, 4, 59, 1, 85, 6, 17, 0, 27, 3, 27, 8, 14, 7, 63, 
    1, 40, 7, 75, 0, 74, 8, 90, 3, 13, 4, 50, 6, 71, 2, 43, 5, 70
  };
  const int q8564[] = {
    9, 9, // Number of jobs and machines
    1, 29, 6, 46, 8, 42, 4, 73, 5, 77, 3, 16, 0,  3, 7, 75, 2, 29, 
    7, 76, 5, 42, 8, 94, 6, 50, 1, 25, 4, 41, 0, 24, 2, 34, 3, 89, 
    4, 67, 2, 66, 1, 15, 0, 66, 7, 46, 3, 74, 8, 75, 6, 37, 5, 35, 
    3, 84, 7, 12, 6, 76, 8, 64, 2, 36, 4, 15, 5, 33, 1, 81, 0, 11, 
    5, 24, 1, 45, 6, 82, 3, 77, 8, 81, 7, 50, 4, 38, 0, 91, 2, 31, 
    6,  3, 1, 23, 5,  2, 2, 42, 4, 66, 0, 15, 3, 72, 8,  3, 7, 99, 
    3, 88, 5, 98, 8,  8, 2, 77, 1,  2, 0, 79, 7, 49, 4, 65, 6,  2, 
    7, 23, 8, 38, 2, 73, 3, 13, 6, 37, 4,  9, 1, 45, 0, 98, 5, 88, 
    8, 37, 2, 44, 6, 67, 7, 82, 3,  1, 0, 97, 5, 39, 4,  9, 1, 52
  };
  const int q8565[] = {
    9, 9, // Number of jobs and machines
    2, 30, 1, 80, 6,  2, 7, 50, 3, 54, 4, 95, 5, 41, 0, 71, 8, 13, 
    3, 97, 8, 90, 1, 66, 6, 59, 4, 27, 7, 88, 5, 38, 0, 68, 2,  3, 
    4, 41, 7,  4, 1, 89, 8, 88, 0, 89, 5, 33, 2, 88, 6, 99, 3,  9, 
    7,  3, 6, 21, 8, 59, 0, 45, 2, 67, 4, 78, 3, 37, 1, 97, 5, 29, 
    2, 79, 0, 52, 1, 95, 7, 90, 3, 38, 6, 77, 5, 19, 8, 87, 4, 28, 
    2, 25, 4, 24, 5, 67, 3, 13, 8, 84, 7, 79, 6, 45, 0, 87, 1, 30, 
    4, 68, 7, 58, 6, 97, 1, 88, 8, 84, 0, 78, 5, 16, 2, 13, 3, 75, 
    0, 90, 1,  5, 7, 29, 4, 64, 3, 45, 6, 46, 2, 23, 8, 49, 5, 66, 
    5, 82, 1, 29, 6, 90, 4, 44, 8, 15, 7, 19, 2, 14, 0,  4, 3, 54
  };
  const int q8566[] = {
    9, 9, // Number of jobs and machines
    2, 48, 3, 20, 8,  4, 7, 15, 5, 43, 1,  9, 0, 40, 4, 89, 6, 17, 
    0, 89, 2,  2, 8, 45, 3, 33, 4, 98, 7, 76, 6, 62, 1, 26, 5, 74, 
    2, 14, 3, 61, 0, 33, 6, 31, 7, 98, 5, 94, 1, 52, 8, 98, 4, 63, 
    0, 25, 3, 29, 1, 44, 8, 34, 4, 49, 2, 56, 6, 76, 7, 78, 5, 27, 
    6, 86, 2, 64, 5, 50, 7, 43, 4, 83, 1, 76, 8, 87, 3, 85, 0, 60, 
    0, 37, 6, 13, 5, 66, 4,  2, 3, 84, 2, 29, 7, 11, 1, 53, 8, 62, 
    6, 90, 4, 12, 2, 44, 0, 18, 7, 99, 5, 81, 8, 98, 3,  7, 1, 44, 
    1, 98, 5, 30, 0, 50, 8, 92, 7, 60, 4, 16, 6, 43, 3, 88, 2, 20, 
    1, 24, 7, 26, 6, 37, 5, 36, 4, 69, 0, 75, 8,  9, 2,  2, 3, 42
  };
  const int q8567[] = {
    9, 9, // Number of jobs and machines
    2, 47, 5, 81, 3, 64, 1, 47, 7, 74, 4, 89, 0, 10, 6, 78, 8, 92, 
    0, 11, 3, 33, 5, 99, 2, 82, 4, 99, 1, 79, 7, 86, 6, 99, 8, 49, 
    1, 63, 2, 35, 3, 31, 0, 40, 4, 51, 6, 74, 5, 67, 8, 26, 7, 27, 
    6, 74, 3, 57, 1, 78, 5,  6, 8, 60, 4, 37, 0, 34, 7, 65, 2, 58, 
    7, 25, 8, 64, 0, 55, 5, 12, 2, 83, 6, 30, 3,  1, 1, 51, 4, 79, 
    3, 82, 0, 82, 1, 97, 4,  4, 2, 90, 5,  1, 8, 21, 6, 21, 7, 65, 
    1, 76, 5, 70, 0, 18, 6, 11, 4, 47, 8, 80, 3, 44, 2,  5, 7, 42, 
    7, 62, 5, 41, 2, 59, 3, 41, 4, 39, 8, 96, 0, 94, 1, 47, 6, 79, 
    3, 88, 2, 87, 8, 96, 4, 56, 6, 15, 7, 66, 0, 52, 5, 61, 1, 91
  };
  const int q8568[] = {
    9, 9, // Number of jobs and machines
    3, 44, 7, 51, 2, 76, 6, 12, 0, 62, 1, 25, 5, 84, 8, 43, 4, 44, 
    0, 30, 8, 54, 4, 51, 1, 72, 3, 38, 6, 27, 7, 86, 2, 47, 5, 61, 
    7, 54, 3, 63, 0, 89, 5, 54, 4, 85, 1, 75, 6, 14, 8, 35, 2, 35, 
    6, 69, 2, 24, 8, 94, 5, 59, 4, 13, 1, 83, 7, 28, 3,  9, 0,  1, 
    5, 97, 1, 47, 6, 18, 8, 90, 3, 50, 7, 48, 2, 95, 4, 42, 0, 54, 
    2, 12, 6, 49, 4, 88, 7, 33, 8, 73, 0, 68, 3, 46, 5, 52, 1,  1, 
    4, 89, 0, 45, 7, 35, 8, 71, 1, 29, 6, 14, 3, 18, 5, 23, 2, 42, 
    5, 54, 8, 92, 6, 38, 3, 48, 7, 21, 4, 59, 1, 37, 2, 15, 0,  2, 
    0, 49, 6, 31, 2, 77, 5, 62, 8, 54, 1, 78, 3, 10, 7, 35, 4, 10
  };
  const int q8569[] = {
    9, 9, // Number of jobs and machines
    3, 56, 6, 87, 8, 59, 5, 97, 7, 11, 2, 65, 0, 61, 1, 12, 4,  8, 
    0, 58, 3, 59, 6, 32, 5,  4, 1, 75, 7, 21, 2, 73, 8, 29, 4, 54, 
    7, 45, 6, 67, 5, 75, 8, 64, 3, 85, 4, 13, 0, 79, 2, 62, 1, 63, 
    5, 88, 2, 78, 6, 22, 0, 98, 7, 78, 3, 91, 8, 17, 4, 21, 1, 32, 
    1, 20, 4, 13, 0, 57, 3, 28, 5, 57, 2, 62, 8, 99, 6, 68, 7, 95, 
    7, 52, 2, 49, 4, 95, 3, 95, 8, 61, 0, 23, 5, 98, 6,  2, 1, 51, 
    6, 23, 3, 80, 7, 24, 2, 19, 5, 95, 8, 21, 4, 42, 0, 93, 1, 72, 
    8, 87, 5, 55, 0, 72, 1, 32, 4, 65, 6, 48, 3, 94, 2, 44, 7, 29, 
    8, 99, 1, 14, 2, 47, 5, 11, 6, 77, 7, 64, 4, 93, 3,  4, 0, 81
  };
  const int q8570[] = {
    9, 9, // Number of jobs and machines
    7,  1, 3, 36, 6, 34, 1, 60, 0, 32, 2, 89, 5, 29, 4, 32, 8, 60, 
    6, 79, 5, 72, 7, 84, 1, 87, 0, 14, 3, 69, 2, 62, 4, 28, 8, 91, 
    2, 15, 7, 73, 0, 19, 6, 39, 8, 91, 3, 59, 1, 56, 5, 48, 4, 39, 
    1, 66, 5, 93, 2, 81, 4,  8, 3, 31, 8, 50, 7, 19, 6, 50, 0, 27, 
    8, 75, 5, 91, 7, 34, 3, 80, 2, 20, 1, 47, 0, 78, 4, 74, 6, 24, 
    2, 11, 8, 49, 1, 30, 4, 40, 3, 88, 7, 35, 0, 73, 5, 75, 6, 69, 
    1, 70, 5, 11, 2, 98, 3, 14, 0, 63, 7, 18, 6, 59, 4, 35, 8, 17, 
    0, 61, 2, 97, 8, 14, 5, 75, 3, 56, 7,  8, 6, 48, 1, 92, 4, 21, 
    5, 16, 8, 99, 6, 36, 0, 49, 1,  7, 3, 98, 4, 18, 7, 20, 2, 92
  };
  const int q8571[] = {
    9, 9, // Number of jobs and machines
    1, 74, 0,  3, 6, 87, 4, 70, 3, 11, 2, 97, 5, 26, 8, 61, 7, 45, 
    8, 12, 0, 60, 2, 38, 6, 76, 7,  1, 5, 52, 4, 28, 1, 26, 3, 77, 
    5, 87, 7, 87, 8,  4, 4, 97, 1, 48, 0, 59, 3, 63, 6, 29, 2, 47, 
    4, 76, 1, 34, 6,  9, 7, 32, 2, 61, 3, 27, 5, 97, 0, 46, 8, 11, 
    3, 30, 2, 79, 6, 52, 4, 18, 0, 81, 7,  1, 8, 98, 5, 98, 1, 18, 
    0, 73, 7, 41, 6, 84, 8, 16, 5, 64, 1, 20, 2, 95, 3, 14, 4, 88, 
    8, 91, 7, 69, 3, 98, 2, 25, 1, 70, 0, 59, 6, 30, 4, 10, 5, 97, 
    3, 45, 4, 65, 8,  7, 7, 39, 6, 88, 0, 58, 1,  6, 5, 95, 2, 15, 
    8, 81, 6, 74, 5, 26, 1, 18, 7, 27, 3, 72, 0,  5, 2, 95, 4, 87
  };
  const int q8572[] = {
    9, 9, // Number of jobs and machines
    2, 95, 3, 77, 5, 92, 1, 86, 4, 54, 8, 52, 7, 66, 6, 35, 0, 11, 
    6, 81, 5,  3, 8, 98, 1, 55, 0, 81, 3, 56, 2, 93, 7, 87, 4, 13, 
    0, 23, 6, 60, 5, 59, 7, 68, 2, 95, 8, 67, 4, 95, 1, 87, 3, 78, 
    2, 95, 0, 72, 1, 17, 5, 52, 8, 82, 6,  3, 7, 55, 4, 22, 3, 10, 
    2, 87, 6, 44, 4, 76, 7, 49, 3, 64, 0, 90, 8,  1, 1, 86, 5, 83, 
    8, 78, 7, 59, 4, 99, 5, 82, 0, 74, 2, 61, 1, 17, 6, 42, 3, 93, 
    0, 96, 6, 32, 1, 74, 5, 25, 7, 88, 8, 33, 2, 77, 4, 87, 3, 44, 
    5, 26, 8,  6, 7, 56, 0, 61, 3, 61, 6, 79, 4,  2, 2, 63, 1, 14, 
    7, 72, 1, 95, 3, 10, 0, 55, 5,  9, 2, 95, 8, 46, 6, 75, 4, 58
  };
  const int q8573[] = {
    9, 9, // Number of jobs and machines
    8, 73, 0, 83, 6, 14, 4, 66, 1, 67, 5, 96, 3, 24, 2, 30, 7,  3, 
    7,  4, 3, 69, 5, 80, 1, 34, 0, 50, 4, 69, 6, 48, 2, 85, 8, 33, 
    2, 42, 1, 61, 3, 24, 0, 78, 4, 94, 8, 54, 5, 66, 7,  3, 6, 95, 
    1, 87, 6, 80, 5, 44, 7, 30, 4,  7, 0, 80, 8, 10, 3, 94, 2, 12, 
    0, 71, 6, 33, 3,  4, 4, 78, 5, 87, 8, 94, 1, 46, 7, 73, 2, 20, 
    6, 51, 2, 64, 4, 25, 1, 39, 8, 30, 0, 22, 5, 23, 3,  4, 7,  4, 
    6, 16, 8, 80, 7, 97, 3, 34, 4, 36, 0, 29, 2, 83, 5, 90, 1, 46, 
    6, 63, 3, 47, 4, 10, 2, 51, 8, 82, 1, 25, 5,  1, 7, 78, 0, 92, 
    3, 30, 0, 50, 8, 76, 6, 44, 5, 62, 7, 86, 1, 78, 4, 61, 2,  6
  };
  const int q8574[] = {
    9, 9, // Number of jobs and machines
    1, 14, 8, 55, 2, 86, 6, 89, 3, 87, 4, 28, 5, 52, 0, 90, 7, 80, 
    8, 26, 7, 71, 4, 92, 0, 11, 3, 32, 1, 27, 2, 21, 5, 27, 6, 31, 
    2, 57, 4, 54, 1, 11, 8, 74, 6, 55, 7, 47, 3, 75, 5,  5, 0, 95, 
    5, 43, 0, 59, 4, 81, 2,  9, 3, 91, 8, 65, 7, 83, 6, 99, 1, 63, 
    0, 90, 5, 46, 3, 77, 2, 58, 8, 85, 6, 22, 4, 54, 7, 69, 1, 44, 
    5, 34, 2, 78, 1, 16, 4, 65, 0, 62, 7, 75, 3, 51, 8, 17, 6, 17, 
    3, 82, 0, 86, 1, 94, 5, 46, 8, 90, 2, 41, 7, 36, 6,  9, 4, 35, 
    5, 62, 6, 94, 8, 22, 1, 23, 0, 39, 3, 57, 4, 13, 2, 97, 7, 24, 
    5,  3, 6, 19, 2, 28, 0, 19, 8, 15, 3, 30, 7, 85, 4, 21, 1, 73
  };
  const int q8575[] = {
    9, 9, // Number of jobs and machines
    2, 31, 6, 42, 8, 10, 5, 89, 7, 67, 1, 45, 3, 30, 0, 53, 4, 74, 
    8, 15, 2,  1, 3, 95, 6,  5, 1, 88, 5,  9, 0, 28, 7, 15, 4, 42, 
    7, 41, 0, 29, 3, 38, 8, 31, 1, 56, 6, 22, 4, 87, 5, 31, 2, 54, 
    2, 36, 5, 17, 4, 31, 6, 47, 8, 48, 7, 33, 0, 80, 3, 24, 1, 86, 
    0, 83, 2,  4, 7, 49, 8, 18, 5, 69, 1, 65, 4, 15, 6, 56, 3, 43, 
    6,  8, 0, 60, 1, 96, 7, 91, 2, 56, 5, 56, 4, 70, 3, 98, 8, 59, 
    6, 14, 1, 80, 4, 79, 5, 26, 0, 30, 2, 45, 7, 87, 8, 43, 3, 72, 
    5, 89, 4, 97, 0, 30, 1, 62, 7, 71, 3, 15, 8, 95, 6, 44, 2, 77, 
    6, 47, 8, 10, 5, 65, 0, 16, 7, 59, 4,  7, 1, 81, 3, 54, 2, 79
  };
  const int q8576[] = {
    9, 9, // Number of jobs and machines
    3, 78, 7, 63, 8,  7, 2,  8, 6, 83, 1, 74, 5, 11, 0, 22, 4, 89, 
    3,  5, 8, 92, 5, 30, 6, 40, 2, 28, 7, 32, 4, 81, 0, 16, 1, 49, 
    1, 81, 3, 51, 0, 26, 7, 84, 4, 83, 5, 71, 8, 72, 2, 50, 6, 94, 
    4, 14, 5,  9, 7, 64, 8, 83, 2, 68, 0, 78, 3, 95, 6, 60, 1, 33, 
    2, 31, 4, 62, 3, 86, 5,  5, 0,  6, 6,  1, 7, 14, 8, 26, 1,  6, 
    2, 34, 8, 52, 1, 56, 0, 14, 6, 57, 7, 72, 5, 95, 4, 87, 3, 16, 
    3, 48, 6, 78, 5, 23, 4, 34, 0, 95, 1, 68, 8,  8, 2, 53, 7, 95, 
    0, 63, 3,  7, 6, 72, 4, 47, 8, 93, 2, 44, 5, 12, 7, 20, 1,  4, 
    0, 77, 5,  5, 3, 42, 1, 56, 2, 25, 7, 70, 6, 27, 4, 33, 8, 44
  };
  const int q8577[] = {
    9, 9, // Number of jobs and machines
    2, 24, 7, 14, 3,  2, 6, 14, 4, 29, 8, 76, 1, 45, 5, 91, 0, 39, 
    3, 37, 4,  4, 5, 76, 0, 52, 6, 37, 7, 62, 2, 11, 1, 56, 8, 19, 
    3, 85, 0, 10, 1, 45, 6, 47, 7, 42, 2, 72, 8, 60, 5, 41, 4, 48, 
    2, 88, 4, 31, 7, 43, 3, 63, 8, 88, 0, 24, 1, 82, 5, 87, 6, 66, 
    4, 47, 6, 49, 7,  3, 5, 91, 2, 77, 3, 98, 8, 46, 0, 99, 1, 80, 
    0,  8, 2, 14, 8, 12, 1, 44, 4, 91, 6, 91, 3, 86, 7, 15, 5, 57, 
    6, 50, 7, 37, 5, 22, 1, 46, 4, 83, 3, 94, 2, 12, 8, 45, 0, 66, 
    3, 26, 4, 13, 1, 35, 0, 84, 6, 55, 8, 66, 2, 88, 7, 80, 5, 18, 
    4, 51, 5, 65, 0,  6, 2, 78, 8, 34, 3, 85, 1, 86, 6, 54, 7, 74
  };
  const int q8578[] = {
    9, 9, // Number of jobs and machines
    8, 98, 0, 51, 3, 14, 7, 34, 1,  6, 4, 90, 2, 10, 5, 22, 6, 85, 
    6, 26, 4, 81, 1, 29, 8, 71, 7, 55, 0, 41, 3, 30, 2, 79, 5, 68, 
    8, 17, 6,  2, 1, 69, 4, 61, 5, 48, 3, 11, 2,  5, 7,  9, 0, 80, 
    2, 75, 7, 81, 4, 28, 1, 43, 0,  6, 5, 98, 6, 50, 3, 14, 8, 44, 
    7, 82, 1, 32, 2, 65, 3, 91, 8, 64, 6, 58, 0, 29, 4, 50, 5, 43, 
    3, 29, 1, 75, 4,  1, 5, 70, 7, 76, 2, 36, 6, 63, 0, 56, 8, 59, 
    3, 98, 6, 61, 4, 88, 2, 43, 1, 62, 5, 21, 0, 29, 7, 82, 8, 61, 
    4, 55, 0,  5, 2, 93, 6, 72, 5, 42, 3, 45, 7, 89, 8, 94, 1, 79, 
    8, 41, 2, 97, 0,  6, 5, 74, 1, 73, 6, 89, 7, 63, 4, 47, 3, 69
  };
  const int q8579[] = {
    9, 9, // Number of jobs and machines
    7, 29, 3, 18, 0, 20, 5, 28, 4, 92, 8, 49, 6, 87, 2, 61, 1, 20, 
    0, 23, 1, 41, 6, 49, 5, 42, 7, 50, 3, 28, 8, 78, 4, 29, 2, 67, 
    5,  8, 6, 11, 1, 20, 4, 77, 3, 65, 7, 96, 0, 87, 2, 82, 8,  3, 
    4, 66, 8, 48, 2, 93, 1, 52, 0, 48, 6, 42, 3, 75, 7, 87, 5, 19, 
    0, 15, 4, 21, 8, 14, 1,  9, 2, 82, 7, 42, 6,  9, 5, 43, 3, 23, 
    2, 73, 3, 95, 1, 58, 5, 92, 4, 86, 7, 14, 8, 20, 0,  5, 6, 41, 
    8, 71, 1, 67, 6, 95, 5, 42, 7, 19, 0, 36, 3, 78, 4, 82, 2, 93, 
    4, 33, 8, 39, 1, 35, 5, 61, 7,  7, 3, 93, 6,  5, 2, 74, 0, 41, 
    1,  6, 2,  1, 4, 55, 5, 47, 6, 85, 7, 35, 8, 16, 3, 23, 0, 67
  };
  const int q8580[] = {
    9, 9, // Number of jobs and machines
    4, 50, 8, 94, 7, 36, 0, 91, 5, 63, 2, 61, 1, 71, 6, 91, 3, 31, 
    4, 36, 7, 22, 0, 19, 6, 84, 8, 53, 2, 91, 5, 37, 1, 81, 3, 91, 
    1, 15, 5, 43, 7, 94, 6, 54, 2, 61, 0, 95, 8, 29, 3, 93, 4, 17, 
    1, 78, 4, 25, 3, 59, 2, 46, 0, 60, 6, 47, 7, 38, 5, 94, 8,  7, 
    2,  9, 6,  6, 7, 30, 8, 34, 3, 60, 1, 20, 0, 62, 4, 82, 5, 92, 
    3, 73, 2, 73, 4, 98, 5, 99, 8,  7, 7, 13, 0, 72, 6, 71, 1, 96, 
    5, 51, 3,  2, 8, 48, 6, 28, 0, 73, 7, 45, 4, 35, 2, 36, 1, 97, 
    1, 26, 8, 56, 3, 85, 5, 30, 6, 74, 2, 36, 0, 50, 7, 70, 4, 64, 
    0, 94, 3, 62, 4, 17, 1, 66, 8, 93, 6, 65, 5, 44, 2, 62, 7, 23
  };
  const int q8581[] = {
    9, 9, // Number of jobs and machines
    2, 33, 7, 34, 3, 24, 8, 33, 5, 47, 0, 11, 1, 18, 4, 25, 6, 83, 
    5, 31, 3, 27, 6, 65, 1, 42, 8, 47, 0, 14, 7, 20, 2, 34, 4, 63, 
    7, 92, 3, 15, 4, 22, 8, 39, 2, 31, 0, 90, 1, 58, 5, 95, 6, 86, 
    8, 56, 2,  8, 3, 84, 6, 58, 5, 27, 1, 74, 4, 63, 0, 82, 7, 14, 
    3, 99, 0, 91, 2, 50, 1, 49, 7, 59, 5,  3, 4, 26, 6, 95, 8, 37, 
    3, 49, 5, 63, 2, 10, 1, 88, 4, 11, 8, 10, 7, 90, 6, 57, 0, 11, 
    5, 96, 0, 93, 1, 29, 8, 35, 4, 71, 2, 96, 6, 43, 3, 35, 7, 52, 
    4, 58, 1, 93, 0, 90, 7, 61, 8, 18, 5, 50, 2, 74, 3, 16, 6, 92, 
    2, 46, 7, 77, 1, 14, 6, 68, 5,  4, 0, 74, 8, 12, 3, 82, 4, 87
  };
  const int q8582[] = {
    9, 9, // Number of jobs and machines
    6, 57, 8, 34, 0, 88, 4, 79, 7, 73, 5, 34, 1, 75, 3, 13, 2, 32, 
    0,  9, 7,  5, 1, 34, 2, 77, 3, 54, 8, 89, 4, 22, 5,  5, 6, 81, 
    7, 82, 4, 39, 2, 37, 1, 53, 5, 77, 0,  7, 8, 48, 6,  1, 3, 42, 
    8, 62, 7, 94, 4, 93, 0, 28, 3, 33, 1, 14, 5, 42, 2, 51, 6, 33, 
    3, 59, 0, 56, 5,  8, 6, 29, 4, 59, 2, 11, 1, 59, 8, 52, 7, 29, 
    7,  5, 8, 57, 2, 39, 5, 47, 1, 89, 3,  6, 0, 35, 4, 55, 6,  1, 
    8, 64, 1, 14, 0,  3, 6, 43, 7, 86, 2, 21, 3, 91, 4, 68, 5, 68, 
    5, 27, 7, 79, 4, 46, 6, 59, 0, 43, 3, 38, 2, 99, 1, 48, 8, 67, 
    4, 84, 3, 61, 5, 30, 8, 27, 7, 75, 0, 10, 2, 94, 1, 10, 6,  8
  };
  const int q8583[] = {
    9, 9, // Number of jobs and machines
    5, 49, 7, 68, 6, 98, 8, 47, 0, 89, 2, 92, 4, 18, 1, 29, 3, 42, 
    0, 24, 3, 35, 5, 99, 4, 12, 6, 59, 1, 28, 7, 86, 8, 30, 2, 27, 
    1, 34, 0, 10, 5, 56, 8, 45, 6, 58, 4, 27, 3, 58, 2, 45, 7, 53, 
    6, 70, 2, 83, 8, 38, 4, 93, 3, 69, 5, 44, 0, 89, 7, 29, 1, 94, 
    5, 60, 7, 10, 2,  7, 8, 63, 0,  7, 1, 94, 6, 40, 4, 67, 3, 64, 
    3, 70, 5, 26, 4, 10, 7, 27, 8, 80, 6, 39, 0, 58, 2, 80, 1, 71, 
    3, 26, 8, 57, 7, 21, 6, 62, 0, 44, 4, 63, 5, 17, 2, 59, 1, 76, 
    0, 51, 1,  8, 6, 66, 3, 16, 7, 96, 4, 29, 5, 18, 2, 97, 8,  3, 
    8, 85, 4, 21, 2, 98, 1, 54, 3, 85, 0, 54, 5, 22, 6, 93, 7, 57
  };
  const int q8584[] = {
    9, 9, // Number of jobs and machines
    5, 35, 6, 83, 7, 58, 1, 99, 3, 77, 0, 50, 4, 31, 2, 33, 8, 56, 
    5,  9, 3,  4, 6, 50, 7, 42, 8, 31, 2,  1, 1, 67, 0, 19, 4, 60, 
    4, 59, 5, 93, 0, 15, 8, 87, 6, 93, 1, 30, 3, 50, 2, 79, 7, 62, 
    4, 61, 7, 18, 0, 19, 8, 32, 6, 41, 2, 27, 1, 94, 5, 96, 3, 56, 
    4, 83, 8, 37, 0, 94, 5, 87, 2, 12, 1, 19, 3, 37, 6, 64, 7, 28, 
    8, 64, 3, 27, 2, 58, 5, 66, 0, 71, 1, 59, 6, 21, 7, 60, 4,  9, 
    5, 16, 6,  4, 2, 68, 3, 83, 1, 61, 0, 73, 7, 22, 8, 62, 4, 83, 
    1, 29, 3, 92, 2, 89, 7, 90, 0, 80, 5, 71, 6, 27, 8, 98, 4,  5, 
    0, 66, 3, 63, 6, 43, 2, 89, 8, 93, 4, 58, 1, 72, 7, 72, 5, 50
  };
  const int q8585[] = {
    9, 9, // Number of jobs and machines
    0,  9, 1, 20, 4, 55, 2, 52, 3,  3, 7, 33, 8, 75, 6, 23, 5, 13, 
    7, 96, 5, 67, 8, 54, 4, 66, 3, 51, 6, 72, 0, 67, 2, 32, 1, 55, 
    6, 57, 7, 47, 2, 11, 0, 96, 3, 45, 4, 37, 8, 70, 1,  6, 5, 43, 
    4, 52, 5, 63, 0, 94, 1, 78, 3, 63, 2, 81, 6, 41, 8, 15, 7, 41, 
    1, 10, 6, 17, 4, 12, 7, 63, 8, 14, 5, 59, 3, 93, 2, 78, 0,  7, 
    2, 22, 8, 24, 6, 66, 3, 83, 1, 35, 5, 75, 4, 81, 0,  6, 7, 63, 
    0, 86, 6, 72, 3, 36, 8, 21, 4, 73, 2, 32, 1, 97, 5,  2, 7, 56, 
    4, 54, 8, 40, 2, 29, 7, 41, 3, 16, 0, 70, 5, 33, 6, 86, 1, 15, 
    7, 51, 2, 60, 4, 71, 8, 68, 5, 57, 0, 77, 1, 27, 6, 66, 3, 79
  };
  const int q8586[] = {
    9, 9, // Number of jobs and machines
    4, 27, 7, 20, 2, 63, 5, 59, 6, 16, 1, 46, 3, 64, 8, 18, 0, 96, 
    0, 74, 7, 57, 3, 26, 4, 95, 8, 75, 6, 22, 5, 21, 1, 56, 2, 81, 
    6, 91, 5, 15, 3, 99, 1, 73, 7,  9, 2, 66, 8, 16, 4, 23, 0, 82, 
    6, 80, 8,  9, 1, 19, 7,  1, 5, 84, 0,  4, 3, 63, 4, 99, 2, 88, 
    7, 22, 3, 18, 5, 85, 2, 95, 8, 19, 0, 94, 4, 93, 1, 78, 6,  9, 
    8, 70, 0, 86, 6, 75, 4, 83, 7, 82, 1, 30, 5,  2, 2, 81, 3, 24, 
    7, 58, 0, 39, 1, 77, 8, 81, 5, 27, 6, 79, 3, 63, 4, 34, 2, 23, 
    6, 27, 0, 27, 2, 58, 8, 91, 5, 41, 7, 36, 1, 61, 3, 15, 4, 99, 
    0,  8, 7, 87, 4, 79, 5, 68, 2, 11, 6, 67, 1, 66, 3, 60, 8, 24
  };
  const int q8587[] = {
    9, 9, // Number of jobs and machines
    2, 27, 4, 28, 3, 99, 0, 77, 8, 41, 5,  1, 1, 36, 7, 29, 6, 35, 
    8,  1, 5, 89, 7,  9, 6, 91, 4, 96, 2, 22, 1, 48, 0, 68, 3, 19, 
    1, 70, 4, 77, 8, 68, 5, 43, 2, 54, 7, 51, 0, 53, 6, 33, 3, 59, 
    1, 80, 5, 91, 4, 90, 3, 72, 0, 18, 2, 31, 6, 84, 7,  5, 8, 23, 
    8, 34, 4, 20, 7, 32, 5, 50, 0, 77, 2, 97, 1, 98, 3, 90, 6, 38, 
    7, 96, 2, 20, 6, 10, 5, 74, 8, 96, 4, 93, 1, 86, 0, 71, 3, 81, 
    2, 22, 7, 34, 4, 81, 8, 86, 6, 39, 0, 13, 1, 38, 3, 33, 5, 75, 
    1, 20, 6, 43, 3,  9, 8, 85, 7, 98, 2, 64, 5, 48, 0, 48, 4,  7, 
    7, 35, 1, 28, 8, 76, 5, 84, 2, 14, 6, 81, 0, 78, 3, 83, 4, 66
  };
  const int q8588[] = {
    9, 9, // Number of jobs and machines
    1, 67, 4, 56, 3,  3, 7, 17, 0,  4, 8, 23, 5, 75, 2, 19, 6, 28, 
    1, 46, 2, 50, 0, 85, 6, 11, 7,  2, 5, 71, 4, 67, 3, 49, 8, 30, 
    0, 42, 1, 88, 7, 58, 4, 58, 6, 54, 8, 88, 2, 29, 5, 65, 3, 56, 
    0, 62, 3, 26, 4, 33, 8, 47, 6,  6, 1, 79, 2, 32, 7, 70, 5, 52, 
    8,  5, 7, 52, 6, 88, 0, 90, 2, 37, 1, 22, 3, 39, 5, 79, 4, 80, 
    5, 53, 8, 92, 0,  1, 1, 90, 7, 51, 3, 17, 2, 45, 4, 56, 6,  1, 
    5, 18, 4, 52, 7, 50, 6, 31, 0, 80, 2, 83, 3,  7, 8, 47, 1, 68, 
    2, 71, 3, 51, 8, 83, 6, 53, 0, 65, 7, 96, 4, 21, 5, 33, 1,  8, 
    3, 60, 4, 64, 6, 33, 0, 94, 2, 77, 7, 47, 1, 67, 5, 16, 8, 35
  };
  const int q8589[] = {
    9, 9, // Number of jobs and machines
    2, 56, 0, 67, 6, 32, 1, 48, 4, 31, 5, 94, 3, 81, 8, 53, 7, 19, 
    5, 41, 6, 45, 7, 56, 0, 21, 3, 81, 1, 90, 4, 10, 8, 48, 2, 26, 
    8, 76, 6,  9, 3, 10, 1, 81, 7, 81, 4, 14, 5,  6, 2, 44, 0, 44, 
    2, 83, 6, 24, 7, 60, 4, 86, 8, 40, 1, 71, 5, 86, 3, 68, 0, 36, 
    5, 61, 2, 86, 4,  6, 6, 41, 1, 20, 0, 87, 3,  8, 7, 16, 8,  7, 
    8, 36, 2, 52, 0, 89, 6, 30, 5, 60, 3, 98, 7, 15, 1, 28, 4, 72, 
    1, 46, 6, 18, 0, 27, 2, 50, 7, 95, 8, 62, 3, 23, 4, 49, 5, 83, 
    7, 22, 0, 51, 2, 63, 8, 35, 4, 56, 6, 85, 1, 42, 5, 54, 3, 48, 
    6, 98, 5,  3, 7, 74, 1, 90, 8, 27, 0, 83, 4,  7, 3, 37, 2, 43
  };
  const int q8590[] = {
    9, 9, // Number of jobs and machines
    4, 68, 2, 57, 7, 62, 3, 69, 1, 73, 0, 84, 6, 94, 8, 73, 5, 66, 
    8, 60, 4, 53, 7, 35, 2, 18, 0, 95, 6, 30, 5, 81, 1, 58, 3, 72, 
    7, 74, 1, 93, 2, 91, 4, 79, 6, 77, 0, 38, 3,  5, 8, 23, 5,  9, 
    7, 48, 2,  1, 6, 44, 0,  4, 3, 36, 4, 85, 8, 15, 1, 22, 5, 56, 
    1, 14, 5, 34, 8, 37, 7, 48, 0, 74, 6, 62, 2, 89, 4, 54, 3, 46, 
    4, 73, 8, 63, 3, 39, 7, 48, 2, 98, 1, 82, 5, 64, 0, 75, 6,  8, 
    3,  5, 5, 39, 6, 10, 4, 27, 2,  4, 0, 56, 7, 43, 1, 15, 8, 93, 
    4, 21, 6, 14, 7, 32, 0, 75, 5, 76, 2, 97, 3, 79, 1, 86, 8, 39, 
    0,  5, 2, 74, 4, 62, 8,  3, 3, 45, 1, 42, 5, 58, 6, 41, 7, 11
  };
  const int q8591[] = {
    9, 9, // Number of jobs and machines
    1, 91, 2, 24, 8,  4, 0, 35, 4, 32, 5, 83, 7, 30, 3, 24, 6,  6, 
    7, 12, 3, 16, 1, 74, 5, 13, 6, 47, 8, 36, 2, 35, 0, 42, 4, 65, 
    5, 42, 2, 57, 7, 24, 0, 17, 4, 67, 3, 94, 6, 80, 8, 98, 1, 29, 
    2, 82, 5, 83, 8, 73, 3, 48, 7, 13, 0, 89, 1, 95, 4,  1, 6, 40, 
    2, 46, 5, 66, 7, 76, 8, 74, 6, 46, 1,  1, 4, 97, 3, 20, 0, 89, 
    1, 57, 5, 29, 7, 94, 2,  3, 4, 52, 8, 82, 0, 11, 6, 39, 3, 20, 
    7, 24, 8, 14, 5, 31, 3, 17, 4, 73, 0, 57, 1, 87, 6, 70, 2, 42, 
    2, 76, 6, 90, 1, 51, 3,  2, 4, 45, 5, 82, 0, 79, 7, 85, 8,  5, 
    6, 39, 5, 60, 8, 28, 7, 85, 2, 55, 0, 70, 1, 44, 4, 39, 3, 38
  };
  const int q8592[] = {
    9, 9, // Number of jobs and machines
    6, 32, 2, 76, 0, 59, 4, 52, 8, 60, 5, 97, 7, 47, 1, 49, 3,  4, 
    8, 45, 7, 11, 6, 18, 4, 70, 3, 49, 5, 48, 1, 73, 2, 98, 0, 56, 
    4, 70, 7, 18, 1, 85, 2, 21, 5, 23, 8, 70, 0, 31, 3, 18, 6, 35, 
    7, 32, 6, 16, 8, 18, 3, 30, 0, 31, 4,  5, 1, 43, 2, 46, 5, 43, 
    2, 21, 6, 47, 3, 45, 0,  4, 5, 37, 1, 38, 4, 51, 7, 45, 8, 56, 
    1, 63, 0, 94, 3, 75, 8, 96, 7, 65, 4, 85, 5, 58, 6, 90, 2, 23, 
    5, 55, 4, 61, 8, 58, 1, 76, 6, 23, 2, 60, 7, 24, 3, 45, 0, 32, 
    5, 81, 7, 40, 0, 69, 8, 64, 2, 71, 1, 44, 4, 92, 3, 88, 6, 41, 
    1, 65, 3, 68, 4, 55, 2, 20, 8, 45, 5, 38, 7, 81, 6, 28, 0,  6
  };
  const int q8593[] = {
    9, 9, // Number of jobs and machines
    3, 20, 5, 95, 7, 64, 6, 42, 0, 93, 8, 39, 1, 22, 4, 91, 2, 43, 
    6, 91, 5, 43, 3, 62, 7, 80, 2, 69, 8,  6, 1, 36, 0, 29, 4, 85, 
    8, 53, 7, 96, 5,  8, 1, 38, 6, 74, 2, 11, 4, 74, 3, 73, 0, 28, 
    5, 14, 2, 40, 6, 63, 4, 88, 1, 52, 7, 99, 0, 61, 8, 67, 3, 35, 
    7, 50, 2, 77, 8, 11, 1, 93, 5, 27, 6, 80, 0, 55, 4, 60, 3, 74, 
    5, 10, 4, 57, 7, 68, 8, 11, 6, 92, 3,  8, 1, 44, 0, 59, 2,  9, 
    3, 80, 6, 23, 0, 74, 2, 12, 8, 22, 7, 95, 5, 27, 4, 66, 1, 46, 
    4, 72, 1,  8, 6, 72, 5, 89, 7, 23, 8, 50, 0, 13, 3, 24, 2, 90, 
    7, 83, 6, 37, 2, 44, 8, 28, 3, 52, 4, 27, 5, 52, 0, 45, 1, 18
  };
  const int q8594[] = {
    9, 9, // Number of jobs and machines
    6, 31, 5, 28, 3, 27, 8, 71, 4, 31, 7, 26, 0, 32, 2, 55, 1, 73, 
    1, 89, 5, 59, 7, 43, 3, 70, 0, 33, 8, 61, 6, 45, 2, 65, 4, 82, 
    3, 47, 4, 43, 2, 42, 1, 86, 6, 10, 0, 96, 7, 41, 5, 95, 8, 58, 
    8, 86, 6, 34, 0, 59, 3, 54, 4, 18, 2, 87, 5, 16, 7, 23, 1, 80, 
    1, 55, 6, 49, 2, 56, 5, 85, 7, 70, 3, 40, 8, 80, 4, 21, 0, 70, 
    3, 12, 1,  6, 8, 42, 7, 51, 6, 36, 0, 95, 2, 59, 5, 33, 4, 34, 
    8, 32, 1, 21, 2, 25, 7, 32, 5, 47, 3,  2, 0, 79, 4, 71, 6, 74, 
    3,  1, 8,  3, 1, 63, 0, 52, 2, 16, 4,  3, 6,  6, 7,  4, 5, 74, 
    1, 30, 5, 86, 2, 99, 7, 17, 4, 50, 0, 37, 3, 62, 8, 71, 6, 37
  };
  const int q8595[] = {
    9, 9, // Number of jobs and machines
    0,  3, 4, 46, 6, 98, 8, 93, 2, 61, 5, 13, 3, 40, 7, 91, 1, 86, 
    8, 71, 6, 99, 7, 31, 2, 88, 5, 79, 4, 73, 1, 41, 3, 70, 0, 14, 
    0, 52, 2, 27, 8, 49, 5, 13, 3,  1, 4, 32, 6, 26, 1, 90, 7, 90, 
    3, 70, 4, 75, 1, 30, 7, 22, 6,  4, 8, 51, 0,  7, 5, 25, 2,  9, 
    7, 86, 4, 64, 3, 17, 1, 34, 0, 89, 5, 95, 8, 94, 2, 82, 6, 71, 
    1, 41, 3, 63, 4, 17, 0, 27, 7, 98, 6, 75, 8, 18, 5, 62, 2, 43, 
    0, 47, 2, 36, 6, 26, 7, 62, 8, 33, 5, 74, 1,  5, 3, 51, 4, 47, 
    8, 68, 2,  5, 7, 80, 5, 53, 1, 89, 3, 36, 4, 12, 0, 29, 6, 49, 
    5, 19, 0, 70, 4, 58, 3, 80, 1, 77, 8, 24, 6, 25, 7, 86, 2, 50
  };
  const int q8596[] = {
    9, 9, // Number of jobs and machines
    6, 95, 8, 89, 5, 69, 1,  3, 3, 97, 0, 63, 7, 24, 4, 38, 2, 97, 
    8, 58, 2, 16, 7, 46, 6, 47, 4, 76, 0, 28, 1, 88, 5, 95, 3, 16, 
    7, 96, 8,  9, 2, 63, 0, 80, 4, 76, 1, 58, 3, 96, 6, 87, 5, 93, 
    3, 12, 6, 83, 2, 27, 8,  8, 1,  3, 7, 44, 5, 60, 4, 93, 0, 27, 
    3, 99, 2, 76, 7, 58, 5, 69, 4, 88, 6, 69, 0, 18, 1, 40, 8, 65, 
    0, 62, 2, 26, 6, 24, 4, 68, 5, 52, 3, 37, 1, 31, 8, 33, 7, 10, 
    6, 52, 5, 36, 7, 57, 3, 20, 2, 45, 1,  8, 4, 33, 8, 96, 0, 70, 
    3,  9, 6, 85, 7, 68, 5, 88, 2, 62, 4, 95, 8, 99, 0, 77, 1,  3, 
    1, 69, 2, 17, 7, 82, 3, 90, 4, 84, 6, 70, 0, 85, 5, 75, 8, 90
  };
  const int q8597[] = {
    9, 9, // Number of jobs and machines
    0, 14, 5, 37, 2, 61, 3, 51, 4, 27, 8, 45, 7, 74, 6, 45, 1, 66, 
    8, 95, 4, 74, 1, 66, 3, 98, 2,  2, 6,  1, 5, 78, 0,  4, 7, 43, 
    8,  8, 6, 53, 1,  9, 3, 82, 2, 89, 4, 85, 5, 43, 0, 87, 7, 32, 
    4, 84, 3, 67, 5, 21, 0, 74, 7, 90, 2,  9, 1, 32, 8, 37, 6, 21, 
    2, 37, 3, 87, 0, 50, 4,  2, 1, 67, 8, 26, 6,  6, 5, 89, 7, 19, 
    0, 32, 2, 11, 1, 28, 8, 77, 7, 52, 4, 64, 6, 12, 5, 57, 3, 44, 
    2, 57, 0, 17, 6, 41, 4, 93, 1, 37, 3, 48, 5, 80, 8,  1, 7, 55, 
    8, 75, 4,  6, 5, 88, 3, 85, 1, 39, 2, 64, 6, 30, 7, 27, 0, 41, 
    4, 61, 2, 89, 0, 65, 3, 38, 5, 20, 7, 92, 1, 74, 8, 21, 6, 55
  };
  const int q8598[] = {
    9, 9, // Number of jobs and machines
    4, 68, 0, 16, 8, 40, 3, 22, 5, 47, 1, 42, 2, 38, 6, 39, 7, 57, 
    0, 89, 5, 32, 4, 35, 1, 92, 3, 29, 7, 32, 2, 86, 6, 33, 8, 56, 
    8, 45, 6, 20, 4, 24, 7, 93, 1, 41, 2, 52, 3,  1, 5, 62, 0, 39, 
    3, 74, 2, 70, 8, 17, 7, 38, 6, 11, 1, 61, 0, 18, 4, 38, 5, 49, 
    7, 62, 3, 70, 0, 97, 4, 93, 1, 49, 2, 21, 8, 42, 6, 11, 5, 65, 
    8, 19, 1, 60, 5,  9, 7, 33, 4, 59, 2, 20, 3, 20, 0, 99, 6, 94, 
    8, 64, 4, 31, 0, 23, 6, 60, 7, 10, 3, 46, 2, 24, 5, 32, 1, 79, 
    2,  2, 3, 78, 4, 81, 1, 11, 6, 73, 8, 80, 5, 16, 0, 69, 7, 57, 
    8, 77, 5, 49, 4, 87, 7, 38, 1, 70, 2, 51, 6, 77, 3, 67, 0, 20
  };
  const int q8599[] = {
    9, 9, // Number of jobs and machines
    1, 42, 5, 47, 3, 56, 4, 98, 6, 66, 2, 52, 0, 26, 8, 44, 7, 46, 
    8, 90, 2, 54, 6, 23, 7, 97, 1, 59, 5, 64, 4, 57, 3, 50, 0, 10, 
    0, 86, 4, 45, 5, 72, 3, 11, 6, 56, 1, 59, 7, 42, 2, 94, 8, 12, 
    5, 17, 2, 76, 1, 38, 6, 15, 0, 28, 4,  9, 8, 99, 3, 60, 7, 52, 
    7, 37, 5, 28, 3,  2, 4, 10, 1,  6, 2, 74, 6, 50, 8, 90, 0, 72, 
    4, 79, 3, 78, 5, 31, 7, 31, 6, 88, 0, 75, 1, 55, 2, 88, 8, 14, 
    2, 17, 1, 74, 6, 11, 7,  5, 4, 20, 0, 78, 5, 26, 3, 79, 8, 51, 
    4, 88, 0, 73, 1, 95, 8, 74, 6, 88, 3, 63, 7, 68, 2, 39, 5, 83, 
    4, 29, 1,  1, 8, 12, 3, 93, 2, 29, 7,  7, 6, 98, 0, 56, 5, 93
  };
  const int q8600[] = {
    9, 9, // Number of jobs and machines
    3, 78, 4, 78, 2, 72, 6,  7, 8, 97, 1, 38, 0, 92, 7, 51, 5, 28, 
    6, 86, 2, 63, 5, 79, 7, 91, 1, 84, 3, 89, 4, 37, 8, 22, 0, 83, 
    0, 55, 1, 85, 2, 28, 3, 86, 4, 45, 5, 95, 7, 91, 8, 76, 6, 45, 
    5, 61, 7, 52, 8, 54, 4, 91, 3,  3, 6, 41, 2, 76, 0, 70, 1, 21, 
    1, 11, 4, 12, 3, 76, 2, 50, 6, 97, 5, 43, 8, 38, 0, 98, 7, 82, 
    6, 32, 5, 98, 3, 19, 8, 91, 1, 44, 0,  6, 7, 63, 4, 74, 2,  1, 
    0,  1, 4, 20, 5, 47, 1,  9, 3,  5, 6, 34, 7, 91, 8, 98, 2, 74, 
    4, 57, 5, 96, 3,  3, 2, 99, 0, 30, 6, 37, 8, 48, 1, 29, 7, 34, 
    2, 41, 3,  8, 4, 50, 6,  3, 5, 55, 7, 57, 0,  8, 1, 94, 8, 70
  };
  const int q8601[] = {
    9, 9, // Number of jobs and machines
    6, 16, 8, 60, 1, 42, 7, 31, 3,  6, 2, 77, 0, 93, 4, 55, 5, 56, 
    6, 36, 3, 10, 4, 41, 1, 39, 2,  2, 5, 87, 7, 42, 0,  2, 8, 73, 
    7, 71, 4, 79, 6, 53, 0, 47, 2, 46, 3, 87, 1, 72, 8, 73, 5, 12, 
    4, 64, 6, 36, 8, 58, 0, 12, 5, 18, 3, 81, 1, 16, 7, 83, 2, 33, 
    0,  1, 4, 20, 8, 72, 5, 44, 3, 16, 1, 23, 6, 52, 7, 84, 2, 10, 
    4, 45, 3, 67, 1,  1, 7, 28, 6, 60, 2,  2, 0, 56, 5, 22, 8, 12, 
    5, 46, 8, 64, 2, 40, 6, 22, 0, 44, 1, 87, 3, 56, 7,  4, 4, 90, 
    3, 34, 8, 81, 1, 95, 5, 59, 2, 21, 7, 18, 6, 50, 0, 44, 4, 55, 
    3, 52, 7, 95, 2, 87, 6, 78, 0, 79, 5,  3, 1, 54, 4, 34, 8, 81
  };
  const int q8602[] = {
    9, 9, // Number of jobs and machines
    0, 54, 2, 35, 7, 41, 3, 24, 8, 87, 5, 65, 4, 77, 1, 42, 6, 73, 
    7, 84, 1, 12, 0, 19, 3, 36, 2, 34, 8, 53, 6, 64, 4, 93, 5, 34, 
    3, 14, 8, 64, 4, 62, 6, 17, 1, 37, 5, 48, 2, 68, 7, 10, 0, 41, 
    0, 60, 1, 18, 4, 77, 5, 83, 7, 55, 2, 67, 6, 12, 8, 26, 3, 38, 
    1, 79, 8, 44, 6, 18, 2, 87, 4, 64, 3,  4, 7, 89, 0, 44, 5, 64, 
    7, 64, 6, 71, 3, 81, 2, 70, 4, 22, 1, 30, 5, 68, 8, 52, 0, 36, 
    0, 42, 5, 96, 4, 75, 3, 98, 8, 72, 6, 40, 1, 77, 2, 91, 7, 47, 
    5, 58, 4, 10, 1, 75, 7, 79, 0, 60, 8, 56, 2,  7, 6, 31, 3, 94, 
    8,  9, 0, 53, 1, 47, 6, 90, 2, 63, 3, 69, 4, 22, 7,  8, 5, 66
  };
  const int q8603[] = {
    9, 9, // Number of jobs and machines
    3, 12, 8, 20, 1, 55, 7, 78, 0, 70, 2, 57, 4, 91, 5, 61, 6,  4, 
    1, 44, 6, 44, 3, 62, 7, 29, 0, 74, 2, 98, 5, 66, 4, 29, 8, 89, 
    4, 95, 6, 57, 7, 51, 8, 70, 3, 25, 1,  1, 0, 89, 5, 87, 2, 53, 
    8, 93, 4, 47, 0, 57, 5, 99, 6, 89, 1, 63, 2, 14, 7, 11, 3, 17, 
    6, 93, 1, 56, 5, 90, 4, 82, 7, 20, 3, 17, 0, 10, 2, 89, 8, 95, 
    7,  8, 1,  2, 0, 56, 8,  6, 5, 39, 4, 23, 2, 31, 3, 53, 6, 87, 
    1, 17, 0, 79, 2, 73, 5, 13, 4,  7, 6, 67, 8, 94, 7, 11, 3, 36, 
    7, 53, 8, 84, 1, 38, 6, 65, 3, 48, 5, 16, 4, 69, 2, 81, 0, 16, 
    7, 81, 2, 70, 6, 96, 4,  9, 8, 68, 0, 96, 5, 37, 1, 89, 3,  6
  };
  const int q8604[] = {
    9, 9, // Number of jobs and machines
    0, 78, 2, 59, 7, 64, 5, 52, 4, 27, 6, 10, 3, 79, 8, 68, 1, 45, 
    3, 70, 4, 19, 8, 74, 6,  7, 1,  4, 7,  9, 2,  9, 5, 32, 0, 96, 
    4, 62, 0, 41, 2, 37, 7, 84, 6,  5, 3, 80, 1,  3, 5, 53, 8, 88, 
    7, 47, 8, 34, 0, 23, 2, 57, 4, 61, 6, 74, 3, 38, 5,  3, 1, 14, 
    4, 68, 2,  3, 5, 79, 8, 40, 7, 32, 0, 12, 6, 29, 3, 72, 1, 42, 
    0, 50, 8, 68, 1, 88, 3, 16, 2, 53, 7, 35, 5, 73, 4, 25, 6, 57, 
    0, 24, 2, 33, 7, 84, 5, 30, 6, 91, 4, 66, 3, 27, 8, 14, 1, 43, 
    7, 76, 5, 42, 1, 30, 6,  8, 8,  7, 4, 36, 3, 38, 2, 69, 0, 83, 
    8, 96, 4, 86, 2,  3, 3, 84, 0, 26, 5, 89, 6, 40, 1, 78, 7, 11
  };
  const int q8605[] = {
    9, 9, // Number of jobs and machines
    5, 87, 1, 61, 6, 49, 8, 56, 4, 76, 7, 16, 3, 65, 0, 29, 2, 37, 
    2,  1, 3, 77, 1, 28, 6, 85, 0, 22, 4, 30, 7, 52, 5, 94, 8, 36, 
    3,  2, 5, 93, 2, 72, 0,  3, 1,  3, 4, 39, 8, 46, 6, 48, 7, 53, 
    1, 26, 6, 82, 3, 28, 8, 49, 4, 91, 2, 40, 5, 15, 7, 71, 0, 51, 
    0, 40, 1, 16, 4, 80, 8, 43, 5, 92, 3, 37, 6, 97, 7,  5, 2, 33, 
    8, 93, 4, 85, 1, 12, 0, 64, 7, 84, 3, 89, 2, 66, 5, 96, 6,  9, 
    4, 18, 5, 57, 2, 89, 8, 18, 1, 57, 7, 64, 3, 35, 6, 89, 0, 51, 
    7,  3, 4, 61, 3, 65, 2, 52, 0, 17, 6, 88, 1, 64, 5, 42, 8, 81, 
    2, 37, 4, 89, 6, 34, 0, 93, 5, 16, 7, 82, 1, 70, 8, 80, 3, 65
  };
  const int q8606[] = {
    9, 9, // Number of jobs and machines
    5, 89, 1, 69, 0,  8, 7, 75, 6, 76, 2, 25, 8, 49, 3, 29, 4, 56, 
    2, 16, 4, 45, 7, 67, 3, 37, 0, 57, 1,  9, 5, 98, 8, 65, 6, 86, 
    8, 41, 5, 43, 1, 93, 3, 86, 6, 92, 7, 46, 0,  9, 2, 36, 4, 57, 
    1, 90, 2, 31, 0, 55, 6, 53, 7, 35, 4, 92, 8, 97, 3,  6, 5, 94, 
    1, 59, 4, 22, 2, 40, 0, 42, 8, 80, 7, 44, 3, 50, 5, 23, 6, 84, 
    8, 65, 6, 31, 7, 98, 1, 11, 2, 74, 0, 22, 3, 86, 5, 86, 4, 13, 
    3, 36, 6,  5, 8, 63, 2, 96, 5, 62, 4, 58, 1, 37, 7, 99, 0,  6, 
    4, 60, 1, 75, 8, 14, 5, 47, 6,  8, 7, 73, 3, 37, 0, 54, 2, 11, 
    3, 18, 1, 26, 8, 29, 6, 49, 5, 66, 7,  2, 0, 44, 2, 80, 4, 11
  };
  const int q8607[] = {
    9, 9, // Number of jobs and machines
    7, 21, 1, 17, 2, 67, 8, 71, 5, 29, 6, 80, 3, 54, 0, 13, 4, 36, 
    0, 87, 2, 87, 8, 37, 5, 82, 6, 94, 4, 98, 1, 41, 3, 74, 7, 54, 
    2, 96, 0, 93, 4, 30, 8, 68, 3, 45, 7, 57, 6, 71, 1, 19, 5, 79, 
    7, 99, 2, 65, 5, 84, 6, 33, 4, 57, 0, 25, 8, 26, 3,  7, 1, 85, 
    3, 26, 6, 32, 1, 79, 2, 72, 0, 37, 5, 33, 4, 76, 7, 64, 8, 58, 
    4, 10, 0, 40, 5, 65, 7, 85, 1, 91, 6,  8, 2, 16, 8, 90, 3, 39, 
    2, 68, 3, 53, 7, 73, 8, 31, 4, 43, 1, 30, 0, 37, 6,  4, 5, 43, 
    6, 55, 5, 15, 0, 88, 7,  8, 2, 34, 8, 40, 1, 24, 3,  7, 4, 79, 
    4,  6, 0, 84, 6, 92, 1,  5, 5, 85, 7, 85, 3, 29, 8, 96, 2, 97
  };
  const int q8608[] = {
    9, 9, // Number of jobs and machines
    2, 34, 4, 54, 1, 13, 8, 44, 0, 97, 6, 65, 5, 64, 3, 58, 7, 67, 
    6, 40, 2, 68, 3, 43, 7, 97, 1, 42, 8, 62, 0, 50, 5, 41, 4,  2, 
    3, 55, 1, 77, 7, 68, 5, 41, 2, 71, 8, 24, 0, 49, 6, 34, 4, 11, 
    0, 35, 7, 23, 1, 94, 3, 90, 5, 47, 2, 68, 8, 22, 6, 26, 4, 20, 
    5, 80, 1, 93, 0, 40, 6, 48, 8, 53, 4, 29, 7, 68, 2, 45, 3, 36, 
    1, 89, 2, 74, 0, 10, 6, 84, 7, 38, 5, 41, 8, 88, 3, 77, 4, 17, 
    2, 82, 4, 74, 8, 76, 5, 95, 7, 27, 1, 75, 0, 22, 6, 31, 3, 11, 
    7,  8, 8, 32, 4, 16, 1, 47, 3, 72, 0, 89, 2, 39, 6, 91, 5,  2, 
    5, 12, 1, 75, 6, 45, 3, 63, 4, 64, 2, 15, 7, 19, 0, 10, 8, 63
  };
  const int q8609[] = {
    9, 9, // Number of jobs and machines
    0,  8, 7,  7, 5, 65, 8, 90, 1, 26, 6, 29, 2, 43, 4, 94, 3,  8, 
    3, 93, 4, 21, 2, 11, 5,  1, 8, 86, 7, 10, 0,  9, 1, 56, 6, 50, 
    0, 66, 6, 92, 7, 92, 8, 45, 4, 15, 1, 47, 2, 58, 5, 49, 3, 68, 
    6, 90, 2, 48, 8, 29, 7, 22, 5, 50, 3, 12, 4,  4, 1, 68, 0,  1, 
    5, 81, 4, 90, 6, 42, 0, 46, 1, 55, 3, 53, 8, 69, 7, 43, 2, 24, 
    8, 12, 1, 34, 5, 13, 3, 28, 4, 72, 0, 30, 6, 57, 7, 74, 2, 88, 
    1, 35, 4, 30, 3, 66, 0, 54, 7, 97, 8, 78, 2, 95, 6, 86, 5, 13, 
    7, 94, 2, 78, 1, 16, 4, 34, 0, 99, 3, 28, 6, 37, 5, 87, 8, 73, 
    6, 81, 2, 54, 5, 39, 0, 40, 1, 93, 8, 33, 3, 36, 7, 73, 4,  2
  };
  const int q8610[] = {
    9, 9, // Number of jobs and machines
    6, 16, 0, 79, 4, 41, 8, 83, 2, 74, 5, 67, 7, 87, 3, 13, 1, 79, 
    4,  7, 2,  5, 0, 99, 5, 67, 8, 98, 1, 10, 7, 13, 6, 49, 3, 59, 
    4, 98, 2,  8, 1, 22, 0, 85, 5, 92, 3, 64, 8, 33, 7, 64, 6, 18, 
    2, 74, 8, 89, 3,  1, 5, 20, 0, 11, 1, 25, 6, 81, 7, 31, 4, 24, 
    7, 43, 6,  9, 3, 42, 4, 73, 8,  1, 1, 49, 5, 99, 0, 17, 2, 13, 
    7, 23, 0, 87, 3, 86, 2, 10, 6, 52, 1, 72, 4,  8, 8,  4, 5,  3, 
    4, 23, 1, 95, 5,  6, 8, 91, 6, 45, 0,  2, 7,  8, 2, 51, 3, 17, 
    3, 64, 0, 96, 8, 75, 4, 83, 5, 55, 2, 26, 7, 38, 6,  7, 1, 18, 
    8, 27, 4, 39, 5, 54, 2, 91, 6, 94, 7, 94, 1, 87, 3, 72, 0, 40
  };
  const int q8611[] = {
    9, 9, // Number of jobs and machines
    0, 56, 2, 82, 6, 62, 3, 37, 8, 99, 5, 21, 1, 77, 4, 98, 7, 96, 
    0, 16, 2, 16, 4, 35, 7,  4, 8, 96, 3,  2, 1, 20, 5, 39, 6, 53, 
    5, 32, 7, 65, 2, 28, 8, 53, 6, 45, 3,  4, 0, 96, 4, 40, 1, 15, 
    3, 65, 0, 67, 7, 94, 5, 56, 6, 94, 8, 75, 2, 31, 4, 42, 1, 43, 
    3, 12, 7, 58, 5,  6, 2, 85, 4, 67, 0, 34, 1, 63, 8, 66, 6, 36, 
    4, 48, 6,  5, 1, 14, 2, 10, 5, 53, 0, 98, 3, 20, 8, 26, 7, 88, 
    6, 45, 1, 39, 7, 95, 5, 78, 0, 63, 8, 29, 4, 58, 2, 33, 3, 35, 
    8, 46, 6, 58, 3, 83, 0, 46, 5,  1, 1, 35, 2, 28, 7, 10, 4, 67, 
    8, 13, 5, 63, 2, 58, 4, 42, 7, 68, 1, 80, 0, 66, 3, 18, 6, 58
  };
  const int q8612[] = {
    9, 9, // Number of jobs and machines
    4, 27, 6, 46, 1, 68, 3, 17, 2, 94, 8, 85, 0, 45, 7, 61, 5, 55, 
    7, 70, 1, 89, 6, 90, 5, 26, 4, 70, 0, 83, 3, 96, 8, 83, 2, 36, 
    6, 31, 4, 58, 0, 28, 1, 36, 2, 53, 5, 83, 8, 91, 7,  7, 3, 46, 
    7, 19, 3, 64, 0, 57, 5,  1, 6, 90, 4, 15, 2, 71, 8, 88, 1, 88, 
    6, 17, 4, 85, 1, 94, 2, 46, 3, 28, 7, 36, 5, 57, 0, 89, 8, 50, 
    2, 83, 4, 71, 8, 65, 6,  2, 0, 98, 1,  7, 3, 42, 5, 11, 7,  1, 
    2, 28, 1, 85, 4,  3, 6, 31, 3, 12, 8, 48, 7, 50, 5, 58, 0, 41, 
    8, 26, 6, 73, 0, 40, 1, 27, 3, 58, 5, 42, 4, 26, 2, 77, 7, 38, 
    7, 88, 8, 59, 1, 68, 2, 13, 5, 91, 0, 35, 4,  1, 3,  2, 6, 49
  };
  const int q8613[] = {
    9, 9, // Number of jobs and machines
    1, 99, 3, 94, 6, 35, 2, 71, 5, 59, 8, 39, 4, 18, 0, 19, 7, 32, 
    1, 24, 0, 19, 8, 19, 2, 98, 5, 19, 4, 12, 3,  7, 6, 37, 7,  1, 
    7, 40, 8, 68, 3, 18, 5, 24, 4, 64, 2, 73, 1, 79, 6, 51, 0, 90, 
    8, 40, 1, 79, 3, 22, 7, 25, 6, 50, 2, 53, 4, 59, 0, 50, 5, 74, 
    7, 68, 3, 32, 0, 50, 2, 52, 4,  9, 1, 22, 6, 77, 8, 24, 5, 54, 
    2,  4, 5,  4, 4, 28, 0,  2, 3, 51, 1, 56, 8, 37, 6, 40, 7, 33, 
    1,  1, 0, 64, 7,  7, 8, 53, 6, 93, 2, 46, 4, 49, 5, 78, 3, 89, 
    7, 26, 3, 85, 6, 38, 0, 34, 1, 60, 4, 21, 5, 37, 8, 86, 2, 64, 
    7, 87, 3, 86, 8, 43, 4, 44, 1, 91, 2, 68, 6, 47, 5, 71, 0, 91
  };
  const int q8614[] = {
    9, 9, // Number of jobs and machines
    8, 36, 2, 28, 5,  7, 1, 56, 4, 34, 0, 29, 6, 78, 3, 53, 7, 55, 
    6, 55, 2, 69, 5, 46, 3, 86, 7,  5, 1, 21, 0, 60, 4, 40, 8, 45, 
    0, 53, 7, 47, 2, 98, 4,  3, 8, 74, 5, 49, 6, 76, 1, 25, 3, 51, 
    1, 96, 3, 54, 5,  3, 7, 17, 8, 61, 0,  4, 4, 22, 6, 55, 2, 11, 
    6, 20, 3, 26, 0, 98, 1, 44, 5, 31, 7, 86, 8, 26, 4, 93, 2, 53, 
    8, 51, 6, 12, 5,  5, 1, 28, 3, 99, 0, 76, 4, 87, 7, 51, 2, 99, 
    1, 61, 7, 69, 2, 81, 5, 74, 4, 47, 3,  5, 8, 50, 6, 89, 0, 65, 
    0, 59, 7, 56, 4, 85, 3, 69, 6, 43, 8, 17, 1, 12, 2, 84, 5, 19, 
    8, 60, 2, 25, 4, 30, 3, 46, 6, 60, 1, 80, 0, 30, 5, 73, 7, 52
  };
  const int q8615[] = {
    9, 9, // Number of jobs and machines
    1, 69, 2, 48, 8, 14, 3, 10, 6, 48, 7, 75, 0, 37, 4,  1, 5, 44, 
    2, 74, 3, 46, 5, 32, 8,  4, 1, 56, 7, 86, 4, 34, 6, 63, 0, 26, 
    5, 65, 0, 82, 7, 13, 1, 75, 4, 80, 3, 61, 2, 25, 8, 31, 6,  8, 
    6, 71, 2, 87, 0, 31, 4, 45, 8, 25, 1, 27, 5, 13, 7, 79, 3, 29, 
    2, 11, 7, 87, 0, 90, 3, 99, 5,  5, 1, 84, 6, 33, 4, 62, 8, 32, 
    2, 80, 1, 94, 4, 91, 3, 21, 8, 39, 7, 19, 0, 67, 6, 38, 5, 51, 
    6, 34, 2, 45, 5,  9, 1, 96, 8, 91, 3, 25, 0, 89, 4, 25, 7, 66, 
    6, 46, 2, 49, 4, 44, 8, 81, 5, 63, 3, 57, 1, 51, 7, 58, 0, 93, 
    3, 72, 0, 70, 2, 51, 6, 72, 7, 93, 1, 57, 5, 62, 4, 27, 8, 95
  };
  const int q8616[] = {
    9, 9, // Number of jobs and machines
    0, 72, 6, 72, 5, 63, 1, 51, 7, 33, 8, 65, 4, 22, 3, 68, 2, 83, 
    4, 99, 8, 19, 3, 56, 2,  3, 5, 70, 7, 44, 6, 91, 0, 42, 1,  1, 
    6, 81, 8, 66, 1, 79, 2,  2, 7, 65, 4, 25, 5, 94, 3, 15, 0,  6, 
    3, 36, 2, 72, 1, 14, 6, 36, 5, 34, 4, 52, 0, 64, 7, 66, 8, 52, 
    0, 73, 3, 77, 8, 62, 5, 65, 6, 67, 1, 34, 2, 43, 7, 49, 4, 19, 
    3, 53, 4, 98, 5, 34, 7, 25, 2, 17, 6, 24, 1, 66, 8, 15, 0, 83, 
    1, 82, 3, 21, 4,  8, 2,  8, 8, 20, 5, 81, 7, 24, 0, 20, 6, 82, 
    8, 14, 5,  7, 6,  7, 1,  8, 4, 95, 7, 37, 2, 94, 3, 21, 0, 36, 
    1, 58, 0, 18, 5, 68, 4, 56, 6, 66, 7, 87, 8, 84, 2, 28, 3, 74
  };
  const int q8617[] = {
    9, 9, // Number of jobs and machines
    4, 94, 2, 41, 8,  4, 7, 58, 3, 26, 6, 96, 0, 18, 5, 65, 1, 75, 
    2, 20, 1, 53, 6, 84, 7, 49, 8, 37, 0, 67, 5, 21, 3, 34, 4, 88, 
    8, 65, 2, 25, 1, 92, 3, 38, 7, 38, 5, 95, 6, 82, 4, 27, 0, 27, 
    2, 48, 0, 80, 6,  7, 5, 71, 8, 64, 1, 13, 3, 82, 7, 60, 4, 93, 
    5,  8, 4,  3, 2, 70, 3, 76, 8, 85, 1, 66, 7, 83, 6, 62, 0, 77, 
    3, 54, 6, 13, 4,  6, 0, 83, 8, 11, 7, 47, 2, 48, 5, 35, 1, 53, 
    3, 45, 6, 86, 2, 55, 7, 18, 1, 43, 5, 48, 4, 74, 0, 73, 8, 82, 
    2, 82, 4, 63, 1, 36, 6, 64, 3, 38, 5, 59, 8, 13, 7, 93, 0, 62, 
    8, 30, 4, 72, 5, 14, 3, 22, 1, 45, 2, 28, 0, 36, 7,  6, 6, 92
  };
  const int q8618[] = {
    9, 9, // Number of jobs and machines
    0, 20, 1, 42, 6, 63, 5, 91, 8, 72, 7, 56, 3, 75, 2, 31, 4,  2, 
    0, 19, 8, 84, 2, 57, 6, 77, 4, 63, 1, 55, 5, 70, 7, 46, 3, 44, 
    7, 17, 5, 69, 8, 19, 4, 10, 0, 18, 1, 99, 6, 67, 3, 29, 2, 40, 
    2, 47, 8, 28, 4, 78, 0, 97, 6,  1, 3, 72, 7,  9, 5, 97, 1, 18, 
    7, 39, 8, 41, 1, 79, 5, 92, 6,  2, 3, 59, 4, 87, 0, 26, 2,  3, 
    4, 70, 0, 63, 2, 68, 3, 60, 7, 11, 1, 52, 6, 52, 8, 82, 5, 91, 
    0, 70, 5, 40, 2, 66, 1, 35, 7, 67, 6, 57, 4, 43, 8, 28, 3, 94, 
    8, 58, 5,  3, 4, 69, 2, 17, 7, 77, 6, 13, 1, 65, 3, 85, 0, 51, 
    1, 36, 3, 24, 2, 50, 8, 53, 6, 21, 5,  8, 7, 29, 0, 15, 4, 25
  };
  const int q8619[] = {
    9, 9, // Number of jobs and machines
    2, 13, 0, 53, 7, 34, 1, 95, 4, 11, 8, 61, 3, 28, 6, 17, 5, 62, 
    7, 81, 8, 26, 1,  4, 6, 64, 3, 93, 5, 33, 0,  3, 4, 92, 2, 63, 
    2, 17, 0, 35, 7, 65, 3, 60, 4, 87, 1, 65, 6, 56, 8, 34, 5, 99, 
    1, 63, 4, 72, 0, 69, 5, 67, 6, 60, 7,  7, 2, 80, 8, 88, 3, 44, 
    3, 22, 0, 75, 1, 73, 5, 66, 2, 63, 8, 85, 6, 64, 7, 14, 4, 62, 
    4, 46, 8, 73, 0, 65, 2, 34, 5,  2, 7, 75, 6, 15, 3,  6, 1, 91, 
    1, 63, 0, 36, 3, 58, 4, 65, 8, 64, 2, 26, 6, 27, 5, 61, 7, 24, 
    7,  1, 6, 51, 3, 71, 1, 45, 8, 25, 2, 86, 4, 92, 0, 68, 5, 40, 
    7, 62, 0, 87, 2, 95, 5, 27, 8, 51, 4, 45, 3, 42, 6, 96, 1, 48
  };
  const int q8620[] = {
    9, 9, // Number of jobs and machines
    3, 85, 4, 49, 6, 29, 1, 64, 8,  9, 0, 12, 2, 68, 5, 82, 7, 56, 
    3, 47, 0, 77, 2, 62, 5, 91, 1, 60, 7, 73, 4, 56, 6,  9, 8, 33, 
    2, 11, 4, 97, 7, 78, 8, 52, 5, 60, 3, 43, 0, 94, 1, 58, 6, 12, 
    2, 62, 3, 51, 8, 44, 0, 71, 4, 77, 6, 84, 5, 77, 1, 42, 7, 23, 
    3, 76, 2, 27, 5, 44, 6, 85, 8, 51, 1, 94, 7, 76, 4, 69, 0, 41, 
    1, 23, 2, 29, 7, 67, 0, 75, 4, 82, 5, 82, 8, 61, 3, 49, 6, 42, 
    0,  7, 6, 60, 2, 75, 8, 74, 3, 23, 1, 71, 4, 56, 5,  1, 7, 43, 
    7, 31, 1, 39, 5, 81, 6,  1, 4, 53, 0, 55, 8, 29, 3, 24, 2, 63, 
    6, 62, 0,  6, 4, 71, 1, 59, 2, 85, 8, 30, 7, 24, 3, 60, 5,  7
  };
  const int q8621[] = {
    9, 9, // Number of jobs and machines
    6,  8, 3, 85, 8, 21, 0, 46, 1, 93, 2, 35, 4, 11, 7, 90, 5, 26, 
    3, 46, 7, 47, 1, 67, 2,  6, 4, 74, 5, 55, 0, 65, 8, 14, 6,  2, 
    7, 39, 3, 39, 4,  2, 8, 52, 1, 30, 6, 42, 5, 30, 2, 68, 0, 34, 
    4, 80, 7, 18, 8, 23, 6, 63, 0, 37, 1, 66, 2, 83, 3, 58, 5, 94, 
    4, 15, 0, 89, 1, 11, 3, 82, 2, 38, 8, 69, 6, 37, 5, 27, 7, 89, 
    8, 39, 4, 30, 7, 99, 5, 93, 0, 98, 6, 64, 1, 48, 2, 19, 3, 64, 
    3, 57, 2,  4, 5, 46, 6, 93, 7, 64, 8, 15, 4,  6, 1, 51, 0,  2, 
    5, 86, 2, 75, 0, 29, 3, 73, 4, 42, 1, 95, 8, 80, 6, 87, 7, 64, 
    0, 31, 3, 18, 1, 87, 2, 34, 7, 13, 8, 59, 4, 10, 6, 17, 5, 43
  };
  const int q8622[] = {
    9, 9, // Number of jobs and machines
    0, 21, 1, 64, 2, 77, 3, 96, 8, 48, 6, 75, 5, 10, 4, 95, 7, 31, 
    3, 84, 6, 29, 5, 76, 0, 90, 2,  7, 8, 12, 1, 60, 4, 40, 7, 36, 
    1, 13, 3, 18, 5, 81, 4,  5, 8, 96, 6, 74, 0, 85, 7, 50, 2, 97, 
    0, 75, 1, 10, 8, 54, 5, 62, 2, 49, 7, 46, 4, 56, 3, 39, 6, 87, 
    8, 40, 5, 22, 3, 62, 1,  9, 4, 58, 2, 56, 7, 53, 6, 32, 0, 17, 
    6, 79, 7, 24, 1, 90, 8, 14, 3, 40, 5, 50, 2, 44, 0, 79, 4, 45, 
    7, 20, 8, 53, 0, 52, 3,  4, 6, 59, 2, 29, 1, 47, 4, 10, 5,  3, 
    1, 20, 0, 95, 6, 32, 4, 11, 3,  9, 8, 57, 2, 76, 5, 69, 7, 29, 
    0, 54, 3, 56, 1, 79, 6, 22, 2, 97, 4, 31, 5, 45, 7, 71, 8, 94
  };
  const int q8623[] = {
    9, 9, // Number of jobs and machines
    8,  6, 0, 95, 3, 77, 2, 55, 1, 87, 5, 56, 4, 88, 6, 49, 7,  4, 
    8, 22, 5, 49, 7,  3, 6, 13, 3, 60, 2, 84, 0, 21, 4, 96, 1,  9, 
    7, 87, 8, 12, 2, 94, 6, 51, 4, 28, 3,  1, 1, 91, 0, 32, 5, 47, 
    7, 28, 1, 37, 2, 46, 5, 66, 4, 88, 6, 45, 0, 91, 3, 21, 8, 87, 
    1, 40, 7, 27, 0, 50, 8, 95, 4,  7, 3, 70, 6, 80, 2, 23, 5, 48, 
    1, 39, 0, 38, 8, 79, 3, 12, 7,  6, 6, 93, 2, 96, 5, 94, 4,  5, 
    3, 67, 2, 89, 0, 15, 6, 84, 5, 70, 8, 37, 4, 38, 7, 64, 1, 48, 
    1, 97, 7, 51, 5, 41, 6, 16, 4, 59, 0, 55, 3,  2, 8, 71, 2, 80, 
    4, 42, 2, 36, 6, 18, 7, 38, 5, 99, 8, 97, 3, 61, 1, 60, 0, 94
  };
  const int q8624[] = {
    9, 9, // Number of jobs and machines
    7, 30, 2, 66, 3, 97, 4, 16, 5, 30, 6, 98, 1, 43, 8, 10, 0, 85, 
    2, 73, 4, 68, 6, 45, 5, 73, 0, 32, 3, 78, 1,  8, 8, 52, 7, 94, 
    3, 95, 0, 55, 1, 79, 6, 22, 5,  1, 4, 18, 7, 33, 2, 56, 8, 61, 
    2, 61, 0, 43, 4, 22, 3, 20, 1, 15, 6, 26, 5, 22, 7, 13, 8, 59, 
    3, 80, 5, 70, 1, 75, 8,  5, 4, 46, 7, 49, 2,  7, 6, 95, 0, 95, 
    2, 91, 4, 27, 3, 72, 6, 14, 5, 92, 0,  5, 1, 10, 8, 20, 7, 29, 
    5, 82, 2, 15, 1, 36, 6, 37, 3, 56, 7, 40, 8, 33, 0, 45, 4,  1, 
    6, 81, 7,  5, 3,  6, 5, 99, 8, 58, 0, 97, 1, 13, 4, 76, 2, 61, 
    6,  7, 8, 28, 4, 25, 5, 90, 3, 58, 1, 71, 0, 74, 7, 39, 2, 67
  };
  const int q8625[] = {
    9, 9, // Number of jobs and machines
    0,  9, 8, 57, 6, 43, 5, 43, 2, 29, 4, 39, 1, 56, 3, 14, 7, 64, 
    1, 23, 2, 93, 0, 69, 4, 71, 7, 50, 6, 65, 5, 85, 3, 96, 8, 49, 
    8, 96, 4, 49, 0, 53, 2, 91, 5, 43, 1, 51, 7, 74, 6, 38, 3, 92, 
    0, 46, 4, 86, 6, 68, 2, 79, 7, 60, 5, 74, 3, 24, 8, 35, 1, 81, 
    3, 95, 0, 62, 1, 89, 2, 83, 5, 26, 8,  3, 7,  8, 4, 89, 6,  2, 
    6, 96, 4, 74, 3, 26, 7, 27, 2, 32, 1, 21, 8, 34, 0, 61, 5, 89, 
    0, 98, 5, 39, 8, 68, 4, 73, 6, 85, 7, 96, 3, 84, 2, 45, 1, 85, 
    3, 54, 5,  7, 7, 46, 2, 93, 0, 84, 6, 79, 1,  1, 4, 40, 8, 81, 
    7, 42, 0, 88, 5, 35, 3, 60, 2, 21, 4, 91, 1, 22, 6, 41, 8, 30
  };
  const int q8626[] = {
    9, 9, // Number of jobs and machines
    8, 98, 3, 21, 1, 64, 4,  9, 0, 89, 7, 71, 5, 36, 2,  5, 6, 19, 
    7, 85, 1, 29, 0, 85, 6, 30, 4, 34, 2, 57, 5, 31, 8, 42, 3, 84, 
    6, 90, 0, 30, 4, 67, 5, 36, 3, 93, 8, 59, 7, 25, 1, 48, 2, 63, 
    8, 24, 3, 89, 7, 83, 1, 50, 4, 99, 2, 91, 6, 28, 0, 39, 5, 32, 
    0, 31, 8, 13, 1, 11, 3,  6, 2, 18, 7, 30, 6, 86, 4, 24, 5, 27, 
    7, 59, 0, 24, 3, 32, 4, 54, 8, 72, 1, 70, 5, 40, 2, 11, 6,  6, 
    6, 32, 7, 89, 1, 55, 0, 95, 4, 15, 2, 92, 8,  8, 3,  2, 5, 10, 
    7, 68, 4, 58, 1, 17, 2, 79, 5, 32, 0, 40, 3, 24, 8,  8, 6, 62, 
    8, 10, 4, 68, 3, 51, 0, 95, 2, 49, 1, 63, 7, 62, 6, 49, 5, 92
  };
  const int q8627[] = {
    9, 9, // Number of jobs and machines
    6, 85, 8, 62, 7, 65, 0, 65, 4, 93, 2, 37, 3, 18, 1, 22, 5, 92, 
    5, 33, 6, 21, 7, 73, 0, 82, 3, 46, 8, 80, 1, 80, 4, 52, 2, 60, 
    6, 86, 4, 91, 7, 37, 3,  3, 5, 90, 8, 83, 0, 86, 2,  9, 1, 99, 
    1, 25, 0, 49, 5, 42, 8, 37, 2, 21, 6, 43, 4, 73, 7, 92, 3, 11, 
    4, 85, 1,  7, 7, 99, 8, 55, 3, 26, 0,  2, 6,  7, 2, 68, 5, 57, 
    1, 38, 8, 38, 3, 42, 6, 70, 0, 61, 4, 51, 5, 35, 2, 30, 7, 49, 
    1, 94, 8, 13, 5, 81, 6, 71, 0, 71, 4, 50, 3, 32, 2, 87, 7, 34, 
    0, 51, 4, 30, 7, 51, 2, 32, 5, 98, 1, 95, 8, 38, 3, 32, 6, 87, 
    3, 60, 1, 48, 8, 70, 7, 41, 6, 84, 4, 69, 0,  2, 2,  6, 5, 26
  };
  const int q8628[] = {
    9, 9, // Number of jobs and machines
    2, 70, 3, 64, 4, 27, 5, 37, 0, 85, 8, 49, 6, 92, 1, 38, 7, 21, 
    8, 95, 4, 55, 2, 75, 1, 15, 0, 69, 5, 12, 6, 94, 3, 34, 7, 54, 
    0, 66, 3, 50, 1, 52, 6, 78, 8,  3, 4, 98, 2, 80, 5, 10, 7, 85, 
    1, 10, 2, 46, 8, 13, 5,  5, 0, 39, 7, 74, 3, 20, 6, 70, 4, 15, 
    2,  3, 6, 34, 7, 11, 0, 90, 1, 90, 8, 13, 4, 88, 5,  5, 3, 62, 
    4, 93, 7, 28, 6, 34, 0, 86, 5, 88, 1, 77, 3, 85, 2, 71, 8, 64, 
    6, 51, 7, 28, 2, 27, 5, 66, 8, 50, 4, 48, 3, 42, 0, 71, 1, 21, 
    1, 27, 7, 90, 6, 60, 3, 76, 8, 42, 2, 32, 5, 72, 4, 30, 0, 19, 
    0, 80, 3, 76, 4, 46, 7, 13, 2, 45, 8, 49, 1, 22, 6,  3, 5, 45
  };
  const int q8629[] = {
    9, 9, // Number of jobs and machines
    5, 93, 0,  5, 2, 20, 6, 50, 8, 44, 4, 58, 3, 63, 7, 38, 1, 53, 
    8, 65, 5, 97, 4, 22, 6, 37, 3, 17, 0, 36, 1, 27, 2, 53, 7, 86, 
    2, 44, 8, 18, 7, 62, 5,  6, 6, 59, 3, 52, 4, 34, 1, 59, 0, 10, 
    3, 46, 5, 79, 8, 62, 4, 35, 2, 41, 1, 95, 7, 25, 6, 43, 0, 45, 
    0, 61, 2, 69, 7, 68, 5,  5, 1,  3, 6, 73, 3, 44, 8, 95, 4, 80, 
    6, 71, 0, 12, 1, 38, 4, 60, 5, 79, 7, 43, 3, 54, 2, 87, 8, 50, 
    8,  8, 6, 26, 1, 71, 7, 63, 2, 38, 4, 89, 5, 80, 3, 95, 0,  4, 
    2,  8, 4, 59, 0, 90, 8, 13, 3, 93, 6, 86, 1, 74, 7, 84, 5, 81, 
    2,  3, 4, 11, 7, 61, 0, 39, 1, 70, 3, 82, 8, 37, 5, 79, 6, 10
  };
  const int q8630[] = {
    9, 9, // Number of jobs and machines
    4, 56, 5, 18, 8, 68, 2, 44, 7, 29, 1, 31, 0, 81, 6, 14, 3, 17, 
    6, 64, 2, 17, 1, 82, 3, 43, 4, 43, 5, 29, 0, 10, 8, 95, 7, 18, 
    0, 48, 5, 62, 3, 65, 2, 81, 7, 26, 6, 66, 1, 89, 4, 52, 8, 32, 
    0, 57, 1, 77, 2, 86, 4, 85, 5, 85, 7,  7, 3, 70, 6, 29, 8, 12, 
    4, 11, 7, 63, 1,  7, 3, 34, 0, 39, 5, 26, 2, 41, 8, 65, 6, 32, 
    7, 94, 2, 56, 3, 48, 8, 12, 1, 60, 5, 28, 4, 97, 6, 30, 0,  3, 
    4, 76, 6, 98, 3, 84, 7, 80, 0, 37, 1, 93, 5, 80, 2, 77, 8, 51, 
    3, 49, 1, 79, 7,  4, 5, 92, 2, 59, 8,  4, 4, 42, 0,  2, 6, 29, 
    2, 74, 0, 39, 3, 70, 5, 61, 7,  7, 1, 37, 4, 24, 8, 70, 6, 99
  };
  const int q8631[] = {
    9, 9, // Number of jobs and machines
    5, 14, 8,  5, 4, 50, 1, 72, 7, 70, 6, 68, 0, 70, 3, 24, 2, 10, 
    7, 74, 6, 29, 2, 87, 1, 26, 8, 46, 4, 45, 0, 73, 3, 39, 5, 64, 
    3, 96, 8, 30, 1, 61, 5, 60, 4, 47, 2, 30, 6, 49, 7, 94, 0, 47, 
    6, 18, 5, 69, 2, 59, 4, 10, 8, 77, 1, 17, 3, 88, 0, 47, 7,  1, 
    1, 11, 4, 13, 0, 44, 5, 44, 6, 31, 2, 40, 7, 70, 8,  3, 3, 82, 
    1, 11, 3, 20, 0, 86, 2, 20, 7, 96, 8,  7, 5, 38, 6, 28, 4, 45, 
    2,  2, 5,  6, 6,  8, 7, 62, 8, 92, 1, 70, 0, 23, 3, 87, 4, 97, 
    7, 83, 8, 28, 1,  6, 5, 65, 3, 51, 4, 14, 2, 29, 0, 46, 6, 87, 
    4, 45, 5, 23, 3, 65, 2, 10, 8, 72, 7, 93, 6, 50, 0, 72, 1, 92
  };
  const int q8632[] = {
    9, 9, // Number of jobs and machines
    4, 96, 6,  7, 1, 86, 7, 63, 5, 87, 3, 52, 2, 31, 0,  6, 8, 61, 
    0, 58, 4, 24, 2, 63, 7, 75, 1, 72, 6, 12, 5, 34, 3, 24, 8, 22, 
    1, 46, 8, 42, 7, 60, 6, 77, 3, 33, 4, 62, 5, 46, 2, 95, 0, 68, 
    3, 63, 1, 33, 5, 12, 7, 16, 2, 10, 8, 90, 4, 16, 0, 30, 6,  1, 
    5, 47, 2, 69, 8,  5, 6, 77, 1,  9, 7, 79, 3,  2, 4, 27, 0, 36, 
    1, 44, 7,  2, 8, 22, 5, 66, 3, 76, 2, 45, 6, 28, 0,  3, 4, 50, 
    4, 64, 0, 87, 1, 19, 3, 48, 7,  7, 8, 16, 6, 98, 2, 96, 5,  8, 
    3, 69, 4, 16, 8,  9, 7, 11, 6, 90, 1, 34, 5,  9, 0, 97, 2,  8, 
    3,  7, 2, 94, 8, 22, 6, 42, 4, 25, 5, 20, 0,  2, 1, 91, 7, 42
  };
  const int q8633[] = {
    9, 9, // Number of jobs and machines
    7, 25, 4, 91, 3, 41, 0, 85, 5, 94, 6, 14, 8, 48, 2, 77, 1, 16, 
    1, 74, 7, 59, 4, 79, 3, 89, 2, 97, 0, 66, 8, 83, 6, 60, 5,  1, 
    7, 69, 0, 34, 5, 84, 8, 93, 6, 69, 4, 75, 1, 59, 2, 26, 3, 71, 
    4, 74, 0, 28, 2, 42, 6, 79, 8, 58, 3, 55, 1, 91, 5, 94, 7, 82, 
    6, 30, 7, 90, 5, 46, 8, 96, 1, 14, 0, 70, 4,  1, 2, 49, 3, 75, 
    1, 29, 5, 53, 7, 78, 2, 16, 3, 28, 0, 77, 8, 96, 6, 47, 4,  7, 
    8, 56, 2,  8, 7, 15, 6, 97, 0, 61, 4, 77, 5, 72, 1, 60, 3, 81, 
    3,  2, 0, 30, 1, 72, 6, 88, 2, 29, 7, 96, 4, 17, 8, 65, 5, 52, 
    3,  9, 6, 99, 7, 27, 4, 99, 8, 94, 0, 64, 2, 17, 1, 40, 5, 41
  };
  const int q8634[] = {
    9, 9, // Number of jobs and machines
    2, 91, 5, 65, 4, 60, 1, 88, 7, 61, 0, 22, 6, 90, 8, 43, 3, 57, 
    2, 79, 7, 13, 4, 62, 3, 47, 5, 38, 6, 71, 8, 22, 0, 36, 1, 51, 
    0, 96, 2, 96, 5, 88, 3, 87, 1, 50, 4, 30, 6, 15, 8, 82, 7, 34, 
    6, 46, 0,  7, 7, 82, 2, 46, 5,  7, 1, 18, 8, 69, 3, 85, 4, 83, 
    1, 66, 2, 61, 7, 42, 0, 51, 6, 62, 8, 26, 5, 16, 3, 32, 4, 38, 
    6, 53, 1, 50, 5, 22, 0, 27, 4, 33, 7, 66, 8, 13, 3, 54, 2, 37, 
    5, 98, 7, 42, 8, 35, 2, 45, 6, 76, 0, 35, 3,  3, 1, 32, 4, 40, 
    4, 38, 3, 46, 8, 46, 7, 84, 2, 99, 6, 39, 1,  4, 0, 88, 5, 85, 
    7, 19, 3, 32, 8, 83, 4, 88, 0, 56, 1, 66, 2,  6, 5, 80, 6, 97
  };
  const int q8635[] = {
    9, 9, // Number of jobs and machines
    0, 46, 1, 96, 7,  9, 8, 71, 3, 69, 2, 22, 6, 82, 4, 48, 5, 39, 
    6, 98, 1,  3, 8, 38, 7, 40, 0, 27, 3, 41, 5, 18, 2, 64, 4, 76, 
    2,  2, 8, 63, 5, 57, 1, 26, 3, 27, 0, 44, 4, 65, 7, 57, 6, 35, 
    8, 66, 6, 91, 3, 50, 1, 34, 4, 30, 7, 97, 2, 70, 0, 74, 5, 86, 
    2, 43, 8, 29, 3, 67, 7, 63, 0, 54, 1, 45, 6, 76, 5, 91, 4, 45, 
    7, 50, 5, 66, 6, 43, 2, 29, 1,  5, 4, 11, 3, 26, 8, 45, 0, 53, 
    7, 15, 2, 83, 6, 53, 8, 87, 3, 75, 5, 91, 1, 68, 0, 58, 4, 60, 
    0, 93, 3, 18, 6, 50, 1, 28, 2, 59, 4, 74, 5, 64, 7, 56, 8, 47, 
    6, 11, 8, 41, 0, 16, 7, 44, 5, 83, 3, 21, 1, 20, 2, 14, 4, 92
  };
  const int q8636[] = {
    9, 9, // Number of jobs and machines
    6, 92, 0, 64, 4, 24, 1, 60, 2, 47, 7, 50, 3, 47, 8,  4, 5, 40, 
    7,  8, 1, 43, 3, 52, 6, 49, 2, 57, 4, 93, 5, 17, 8, 24, 0, 40, 
    2, 81, 3, 24, 6, 84, 4, 49, 5,  2, 1, 91, 0, 27, 8, 53, 7, 88, 
    3, 10, 8, 35, 5, 90, 2, 20, 6, 54, 0, 10, 7, 12, 4, 92, 1, 44, 
    2, 24, 4, 10, 0, 46, 6, 12, 8, 91, 1, 53, 7, 18, 5, 19, 3,  7, 
    0, 56, 5, 94, 7, 29, 2, 21, 6, 39, 3, 36, 8, 86, 1, 92, 4, 73, 
    1, 77, 2, 46, 0, 19, 3, 93, 5, 25, 6, 24, 8, 59, 7, 66, 4, 20, 
    0, 27, 2, 31, 3, 97, 1, 28, 5, 63, 7, 21, 4, 40, 6, 94, 8, 98, 
    7, 73, 5, 40, 3, 21, 6, 20, 4, 38, 0, 20, 1, 25, 2, 75, 8, 10
  };
  const int q8637[] = {
    9, 9, // Number of jobs and machines
    8, 13, 3, 65, 0, 86, 7, 27, 4, 97, 2,  2, 1, 72, 6, 56, 5, 70, 
    0, 29, 2, 59, 6, 99, 7, 71, 8, 60, 5, 25, 1, 18, 3, 73, 4, 37, 
    3, 99, 1, 52, 0, 34, 5, 41, 4, 65, 8,  4, 6, 81, 7, 24, 2, 91, 
    8, 69, 4, 96, 0, 67, 7, 47, 2, 31, 1, 48, 3,  2, 6, 81, 5, 24, 
    6, 33, 4, 47, 5, 13, 3, 52, 8, 80, 0, 66, 1, 62, 2, 95, 7, 53, 
    2, 34, 7, 72, 4,  7, 6, 40, 1, 22, 8, 53, 0, 88, 3, 19, 5, 53, 
    0, 53, 8, 59, 1, 63, 3, 76, 2,  3, 5, 87, 6, 44, 7, 17, 4, 19, 
    2, 78, 7, 15, 1, 76, 5, 18, 0, 40, 8, 90, 4, 58, 6, 64, 3, 10, 
    8, 45, 0, 52, 6, 22, 4, 10, 7,  1, 1, 67, 5, 26, 3,  3, 2, 95
  };
  const int q8638[] = {
    9, 9, // Number of jobs and machines
    8, 70, 3, 19, 0, 14, 6, 83, 7,  9, 1, 10, 2,  5, 4, 83, 5, 87, 
    0, 93, 2, 96, 7, 15, 4, 89, 5, 43, 8, 73, 6, 19, 3, 62, 1, 55, 
    2, 66, 7, 22, 8, 93, 3, 91, 5, 23, 1, 57, 4, 34, 6, 18, 0, 91, 
    8, 95, 4, 55, 1, 44, 7, 16, 3, 84, 6, 29, 2, 88, 5, 13, 0, 80, 
    3, 81, 4, 69, 7, 57, 8, 85, 2, 95, 5,  9, 1, 31, 0, 99, 6, 89, 
    8, 74, 2,  4, 3, 10, 4, 79, 6, 19, 0, 67, 7, 10, 5, 23, 1, 32, 
    7, 96, 4, 86, 5, 82, 3, 30, 2, 14, 0, 47, 6, 21, 1, 99, 8, 31, 
    5, 13, 0, 94, 6, 93, 1, 90, 2, 38, 8, 18, 3,  5, 7, 10, 4, 59, 
    5, 68, 7, 92, 1, 34, 6, 45, 2, 75, 0, 99, 4, 84, 8,  6, 3, 33
  };
  const int q8639[] = {
    9, 9, // Number of jobs and machines
    2, 23, 0, 51, 7, 35, 6, 63, 3, 42, 1, 53, 5,  3, 8,  4, 4, 19, 
    1, 38, 5, 88, 8, 59, 3, 63, 7, 11, 6, 71, 4, 80, 0, 20, 2, 90, 
    7, 13, 3, 55, 5, 16, 6, 43, 2, 60, 8, 47, 0, 98, 1, 76, 4, 32, 
    7, 41, 5, 65, 6, 52, 1, 19, 4, 62, 8, 45, 2, 89, 3, 43, 0,  4, 
    3, 76, 0, 74, 7, 72, 6, 48, 4, 77, 5, 21, 8, 62, 2, 36, 1, 30, 
    0, 87, 4, 12, 2, 17, 6,  3, 8, 98, 7, 96, 3, 16, 1, 21, 5, 63, 
    0, 19, 1, 77, 2,  6, 6,  3, 3, 76, 5, 60, 7, 42, 8, 57, 4,  2, 
    5, 91, 1, 32, 2, 15, 6, 59, 4, 41, 8, 12, 7, 72, 3, 95, 0, 65, 
    7, 88, 3, 43, 0, 87, 6, 59, 8, 91, 1, 87, 4, 90, 2, 21, 5, 18
  };
  const int q8640[] = {
    9, 9, // Number of jobs and machines
    7, 62, 4, 25, 2, 73, 8, 29, 1, 80, 0, 84, 5, 54, 3, 50, 6, 99, 
    1, 61, 4, 89, 2, 68, 0, 85, 8, 81, 5, 48, 6,  7, 3, 57, 7, 31, 
    4, 36, 2, 33, 3, 38, 7, 57, 8, 88, 6, 80, 0, 66, 5, 94, 1, 35, 
    1, 31, 4,  4, 0, 86, 5, 49, 7, 56, 6, 61, 2, 80, 8, 79, 3, 62, 
    7, 19, 5, 15, 3, 98, 8, 51, 6, 61, 2, 23, 4,  9, 0, 50, 1, 44, 
    6, 82, 3,  5, 0, 44, 1, 68, 4, 94, 7, 64, 5,  1, 8, 51, 2, 36, 
    6, 63, 8, 35, 0, 62, 4, 71, 3, 63, 7, 75, 5, 41, 1, 34, 2, 44, 
    8, 41, 3, 88, 2, 29, 7, 96, 6, 29, 1, 14, 5, 43, 0, 78, 4,  7, 
    7, 25, 0, 53, 5, 89, 4,  9, 2,  9, 6, 25, 8, 53, 1, 39, 3, 59
  };
  const int q8641[] = {
    9, 9, // Number of jobs and machines
    5, 15, 0, 12, 6, 28, 4, 54, 1, 28, 3, 11, 2, 75, 7, 12, 8,  1, 
    6, 70, 8, 57, 7, 24, 0, 77, 1,  3, 5, 95, 2,  7, 3, 19, 4, 32, 
    6, 82, 1, 14, 5, 45, 8, 13, 0, 90, 3, 69, 7, 25, 2, 87, 4, 46, 
    8, 81, 5, 16, 0, 78, 3, 95, 4, 59, 1, 71, 7, 54, 2, 47, 6, 22, 
    8, 38, 1, 51, 7, 47, 6, 15, 2,  8, 5,  8, 3,  9, 4, 45, 0, 35, 
    4, 63, 8, 41, 5, 35, 6,  4, 2, 64, 7, 38, 1, 85, 0, 67, 3, 44, 
    5, 13, 8, 33, 2, 17, 4, 58, 7, 64, 0, 68, 3, 39, 6, 74, 1, 29, 
    4, 66, 7, 52, 8, 25, 5, 91, 1,  6, 3, 27, 2, 23, 0, 91, 6,  5, 
    3, 42, 5, 46, 7, 44, 2, 50, 8, 85, 6, 17, 0, 83, 1, 24, 4, 51
  };
  const int q8642[] = {
    9, 9, // Number of jobs and machines
    2, 40, 8, 20, 3, 94, 0, 52, 1, 67, 7, 41, 4, 50, 6, 58, 5, 74, 
    4, 71, 0, 22, 2, 56, 7, 17, 8, 90, 6, 14, 1, 94, 3, 79, 5, 70, 
    5, 38, 6, 58, 0,  8, 4, 88, 1, 51, 2, 96, 7, 15, 3, 78, 8, 35, 
    5, 68, 8, 21, 7,  6, 3, 84, 1, 73, 0, 52, 6, 24, 4, 77, 2, 98, 
    1, 67, 6, 72, 0, 66, 3, 97, 5, 71, 4, 45, 8, 18, 7, 71, 2, 94, 
    0, 61, 1, 45, 7,  7, 3, 63, 4, 75, 8, 30, 2,  6, 6, 10, 5, 51, 
    2, 65, 7, 47, 1, 47, 6, 63, 5, 38, 0, 20, 8, 50, 4, 34, 3, 37, 
    1, 11, 6, 81, 4, 54, 2, 53, 8, 99, 5, 78, 0, 22, 3, 11, 7, 93, 
    8, 78, 6,  6, 0, 48, 5, 59, 1, 51, 3, 44, 7, 50, 2, 30, 4, 22
  };
  const int q8643[] = {
    9, 9, // Number of jobs and machines
    8, 74, 6, 13, 5, 53, 1, 55, 2, 71, 0, 67, 7, 88, 4, 92, 3, 99, 
    8, 56, 7, 65, 0, 53, 1, 37, 5, 86, 6, 25, 4, 99, 2, 26, 3, 50, 
    5, 75, 0,  9, 2, 59, 3, 39, 6, 56, 8, 25, 1, 34, 4, 28, 7,  7, 
    8, 89, 1, 71, 7,  7, 6, 48, 5, 97, 3, 85, 2, 32, 0, 80, 4, 39, 
    4, 15, 6, 43, 0, 79, 1, 80, 5, 65, 3, 93, 7, 25, 8, 45, 2, 36, 
    8, 65, 5, 64, 1, 97, 4, 82, 7,  5, 2, 99, 3, 56, 6, 65, 0, 78, 
    7, 24, 6, 81, 2, 37, 3, 50, 5, 86, 0,  3, 1, 30, 4, 15, 8, 15, 
    5, 24, 0, 98, 4, 60, 1, 70, 8, 32, 7,  9, 3, 75, 6, 39, 2, 15, 
    1, 16, 2, 43, 8, 32, 4, 50, 6, 20, 0, 79, 5, 31, 7, 67, 3, 69
  };
  const int q8644[] = {
    9, 9, // Number of jobs and machines
    1, 96, 0, 53, 4, 78, 6, 28, 8, 14, 7, 14, 5, 59, 3, 58, 2, 83, 
    5, 24, 7,  2, 1, 50, 2, 35, 4, 54, 0, 61, 6, 43, 3, 70, 8, 95, 
    2, 47, 6, 15, 4, 86, 3,  9, 7, 32, 5, 39, 8, 66, 1, 27, 0, 89, 
    5, 90, 1, 39, 2, 36, 4, 25, 3, 24, 8, 16, 7, 98, 0, 18, 6, 54, 
    0, 45, 6, 33, 3, 27, 4, 61, 1, 10, 2, 27, 5, 10, 8,  3, 7, 99, 
    4, 72, 1, 86, 6, 81, 7, 88, 0, 77, 8, 32, 3, 66, 5, 91, 2, 51, 
    2, 20, 5, 23, 8, 56, 6, 58, 3, 57, 0, 21, 7, 50, 4, 87, 1, 94, 
    5, 69, 0, 15, 2, 77, 8, 78, 1, 81, 6, 97, 3, 57, 7, 14, 4, 97, 
    4, 48, 7, 97, 8, 55, 2, 63, 5, 93, 3, 85, 0, 48, 6, 47, 1, 93
  };
  const int q8645[] = {
    9, 9, // Number of jobs and machines
    4, 73, 2, 74, 5, 60, 1, 38, 7, 63, 0, 98, 6, 85, 8, 18, 3, 17, 
    1,  5, 8, 47, 2, 15, 6,  9, 5, 19, 4, 85, 7, 19, 0, 91, 3, 48, 
    5, 64, 4, 51, 1,  9, 7, 64, 6, 62, 0, 58, 2, 47, 3, 83, 8, 12, 
    4, 73, 2, 83, 6, 65, 0, 69, 5, 13, 8, 83, 3, 97, 1,  1, 7,  7, 
    8, 49, 1, 18, 6, 13, 0, 14, 3,  3, 5, 65, 4, 45, 2, 10, 7, 66, 
    2, 38, 7, 22, 3, 91, 4, 39, 5, 33, 8, 14, 1, 22, 0, 16, 6, 36, 
    1,  8, 7, 17, 3, 87, 4, 36, 0, 68, 5, 47, 8, 51, 6, 12, 2, 38, 
    7, 71, 0, 17, 8, 18, 5, 39, 4, 24, 6, 92, 2, 88, 1, 42, 3, 24, 
    8, 50, 3, 35, 5,  4, 6, 10, 4, 58, 2, 17, 7, 62, 0, 64, 1, 93
  };
  const int q8646[] = {
    9, 9, // Number of jobs and machines
    7, 54, 4, 20, 3, 28, 6, 34, 1, 81, 5, 73, 2,  1, 8, 21, 0, 14, 
    0, 78, 7, 42, 8, 70, 1, 10, 3, 98, 4, 68, 2, 29, 6, 51, 5, 70, 
    0, 62, 3, 53, 7, 66, 1, 67, 2, 72, 8, 58, 4, 81, 6, 88, 5, 83, 
    5, 74, 2, 22, 3, 76, 0, 89, 6, 92, 7, 58, 8,  6, 1, 35, 4,  8, 
    4, 13, 8, 80, 6, 19, 0, 14, 3, 17, 1, 52, 7, 10, 5,  2, 2, 38, 
    6,  6, 4, 96, 8, 58, 3, 62, 5, 15, 2, 37, 0, 65, 7, 12, 1, 23, 
    6, 44, 5, 92, 8, 40, 1, 97, 0, 18, 4, 54, 3,  6, 2, 47, 7, 83, 
    5, 45, 2, 96, 6, 36, 8, 75, 4, 38, 3, 53, 0, 37, 1, 82, 7,  9, 
    3, 72, 1, 32, 7, 49, 4, 61, 6, 66, 0, 74, 8, 63, 5, 51, 2,  8
  };
  const int q8647[] = {
    9, 9, // Number of jobs and machines
    7, 28, 2, 92, 0, 39, 6, 94, 4, 37, 1, 19, 8, 10, 5, 98, 3, 15, 
    7, 80, 1, 91, 4, 98, 2, 59, 3, 11, 6, 81, 8, 87, 0, 52, 5, 92, 
    1, 91, 8, 12, 3, 70, 7, 50, 0, 18, 4, 20, 2, 23, 6, 34, 5, 14, 
    7, 32, 5,  5, 8, 85, 2, 79, 4, 88, 1, 53, 0, 80, 3, 61, 6, 15, 
    7, 56, 1, 60, 6, 86, 2, 20, 4, 12, 3, 30, 5, 11, 0, 31, 8, 45, 
    8, 20, 4, 42, 0, 71, 5, 74, 6, 91, 7, 36, 3, 76, 2, 61, 1, 12, 
    5, 76, 0, 26, 7, 47, 2, 91, 8, 72, 6, 92, 3, 19, 1, 52, 4, 62, 
    0,  2, 1, 14, 4,  8, 6, 38, 2, 56, 8, 29, 3, 75, 5, 72, 7, 86, 
    3, 61, 6, 43, 7, 76, 5, 88, 0, 21, 8, 75, 4, 47, 1, 19, 2, 28
  };
  const int q8648[] = {
    9, 9, // Number of jobs and machines
    1, 98, 0, 13, 8,  9, 5, 90, 3,  4, 4, 88, 6, 61, 2, 47, 7, 15, 
    2, 16, 6, 46, 3, 60, 0, 23, 4, 76, 5, 99, 8, 91, 1, 64, 7, 14, 
    4, 70, 1, 61, 6, 27, 8, 55, 7, 53, 0, 18, 5, 33, 3, 43, 2, 44, 
    3, 98, 6, 87, 7, 40, 4, 75, 1, 49, 5, 55, 8, 77, 2, 41, 0, 30, 
    7, 92, 2, 62, 6, 52, 1, 23, 3, 97, 4,  6, 8, 61, 0, 28, 5,  6, 
    1, 30, 7, 96, 6, 92, 0, 42, 4, 82, 2, 12, 3, 99, 5, 75, 8, 68, 
    6, 60, 1,  8, 2, 72, 0, 83, 8, 58, 3, 77, 5,  9, 4, 75, 7, 81, 
    2, 46, 7, 44, 5, 94, 1, 53, 4, 79, 6, 40, 3, 30, 0, 81, 8, 60, 
    3, 66, 0, 31, 2, 61, 6, 12, 7, 32, 4, 44, 5, 25, 1, 40, 8, 56
  };
  const int q8649[] = {
    9, 9, // Number of jobs and machines
    5, 91, 0, 44, 2, 87, 1, 26, 4,  7, 8, 73, 3, 76, 7,  6, 6, 27, 
    5, 15, 0, 79, 8, 20, 1, 78, 7, 84, 3, 87, 2, 13, 6, 28, 4, 78, 
    1, 76, 5, 98, 8, 71, 4, 65, 3, 92, 2, 42, 0, 13, 6, 49, 7, 85, 
    5, 15, 2, 40, 1, 63, 0, 80, 6, 48, 7, 95, 4, 59, 8, 77, 3, 97, 
    4, 65, 6, 88, 3, 71, 8, 48, 7,  9, 0, 29, 5,  3, 2, 56, 1, 29, 
    2, 41, 1, 23, 0, 16, 6, 50, 7, 44, 3, 94, 8, 27, 5, 86, 4, 76, 
    0, 85, 7, 48, 3, 36, 2, 56, 6, 11, 8, 31, 1, 70, 5, 71, 4, 65, 
    6, 48, 1, 20, 3, 15, 7, 13, 0, 46, 5, 27, 4, 29, 8, 89, 2, 57, 
    2, 38, 4, 61, 7, 94, 3,  5, 1, 94, 6, 33, 0,  1, 8, 78, 5, 91
  };
  const int q8650[] = {
    9, 9, // Number of jobs and machines
    6, 25, 7, 89, 8, 44, 1, 95, 3, 69, 0, 68, 4, 83, 5, 53, 2, 70, 
    1, 22, 2, 21, 7, 73, 0, 16, 8, 58, 4, 40, 5, 79, 3, 76, 6, 35, 
    3, 52, 7, 85, 1, 47, 2, 57, 8,  1, 6, 60, 5,  9, 4, 68, 0, 99, 
    8, 83, 0, 14, 6, 98, 4, 70, 2, 84, 3, 90, 7, 32, 1, 72, 5, 26, 
    5, 97, 1, 23, 0, 28, 4, 21, 3, 66, 7, 41, 2, 83, 6, 46, 8, 78, 
    1,  4, 2, 18, 7,  2, 3, 77, 5, 58, 0, 32, 4, 23, 8, 35, 6, 94, 
    1, 92, 7, 54, 3, 63, 5, 36, 8, 74, 2, 29, 6, 48, 0,  9, 4, 29, 
    7, 93, 3, 66, 8, 63, 1, 47, 6, 88, 0, 40, 5, 33, 4, 82, 2, 17, 
    8, 24, 5, 96, 7, 39, 2,  4, 0,  4, 3, 46, 4,  5, 1, 52, 6, 11
  };
  const int q8651[] = {
    9, 9, // Number of jobs and machines
    3, 19, 8, 51, 6, 16, 2, 98, 7, 89, 0, 54, 5, 34, 4,  1, 1, 99, 
    8, 39, 2, 55, 5, 26, 0, 69, 7, 68, 6, 52, 3, 22, 4, 92, 1, 41, 
    6, 45, 0, 45, 8, 27, 2, 74, 7, 70, 4, 36, 3, 69, 1, 74, 5, 75, 
    8, 48, 4, 10, 6, 71, 5, 93, 0, 54, 7, 73, 2, 64, 3, 40, 1, 90, 
    5, 74, 2, 63, 1, 83, 4, 23, 3, 90, 8, 47, 0, 85, 6, 18, 7, 58, 
    8, 23, 6, 68, 0, 31, 7, 55, 4, 16, 5,  1, 2, 80, 1, 63, 3, 36, 
    3, 53, 5, 35, 0, 53, 4, 73, 8, 53, 1, 72, 2,  5, 6, 93, 7, 20, 
    5, 29, 6, 77, 3, 65, 1, 25, 7, 94, 4, 77, 0, 27, 2, 90, 8, 95, 
    4, 91, 5, 79, 7, 71, 8, 16, 6, 73, 2, 89, 1, 71, 3, 57, 0, 27
  };
  const int q8652[] = {
    9, 9, // Number of jobs and machines
    7, 42, 5, 28, 1, 25, 3, 24, 6, 28, 4, 32, 0, 13, 8, 32, 2,  4, 
    7, 39, 1, 48, 8, 92, 3, 95, 0, 34, 6, 46, 2, 23, 5, 44, 4, 20, 
    1, 59, 5, 54, 2, 32, 8, 44, 7, 44, 3, 51, 6,  3, 0, 52, 4, 23, 
    1, 42, 6, 89, 5,  7, 3, 53, 4, 87, 7, 72, 0, 48, 2, 29, 8, 92, 
    2,  6, 6,  1, 4, 61, 7, 99, 5, 34, 1, 88, 3,  2, 0, 61, 8, 63, 
    8,  7, 6, 73, 0, 84, 4, 71, 5, 22, 1, 37, 2, 71, 7, 91, 3, 59, 
    3, 50, 4, 35, 0, 85, 2, 89, 7, 30, 6, 39, 1, 85, 8, 59, 5, 49, 
    5, 56, 1, 13, 8,  9, 2, 23, 6, 28, 7, 35, 4, 87, 3,  1, 0, 60, 
    4, 41, 1, 22, 0, 80, 6,  3, 2,  3, 5, 87, 7, 33, 3, 45, 8,  6
  };
  const int q8653[] = {
    9, 9, // Number of jobs and machines
    5, 64, 0, 56, 8, 72, 1,  6, 3, 27, 7, 26, 4, 18, 6, 46, 2, 39, 
    4, 84, 8, 18, 7,  8, 2,  1, 0,  6, 1, 60, 6, 81, 5,  5, 3, 94, 
    7, 23, 6, 71, 8, 81, 1, 76, 3, 75, 5,  9, 2, 22, 0, 65, 4, 45, 
    0, 78, 6, 84, 3,  9, 8, 27, 5, 46, 2, 14, 1, 10, 4, 78, 7, 17, 
    0, 99, 3, 64, 8, 42, 7,  7, 5, 68, 6, 25, 4, 86, 1, 78, 2, 48, 
    7, 19, 6, 21, 4, 15, 3, 44, 5, 56, 0, 65, 1, 79, 8, 40, 2, 24, 
    1, 34, 3, 70, 5,  1, 6, 62, 2, 52, 8, 43, 7, 48, 0, 20, 4, 74, 
    5, 56, 3, 14, 1, 94, 8,  4, 2, 73, 0,  2, 6, 92, 7, 40, 4, 91, 
    1, 69, 4, 35, 7, 60, 8, 74, 3, 48, 2, 24, 0, 73, 6, 50, 5, 43
  };
  const int q8654[] = {
    9, 9, // Number of jobs and machines
    0, 32, 8, 27, 6, 29, 1, 42, 2, 23, 4, 66, 5, 21, 3, 88, 7, 88, 
    1, 54, 0, 28, 2, 40, 8, 91, 6, 77, 4, 58, 3, 24, 7, 36, 5, 16, 
    8, 84, 1, 23, 6, 74, 2, 78, 5, 50, 4, 30, 3, 39, 0, 62, 7, 50, 
    0, 15, 4, 15, 3, 88, 7, 95, 2, 46, 6, 70, 5, 39, 8, 46, 1, 76, 
    5, 63, 1, 39, 3, 62, 2, 31, 8, 54, 7, 88, 6, 97, 0, 98, 4, 18, 
    0, 65, 5, 64, 4, 40, 2, 22, 1, 40, 8,  1, 7, 16, 3, 77, 6, 27, 
    8, 18, 1, 58, 3, 14, 6, 76, 5,  2, 2, 51, 4, 81, 0,  3, 7, 67, 
    8, 48, 1, 14, 6, 59, 7, 57, 5, 63, 3, 17, 0, 34, 2, 99, 4, 50, 
    2, 87, 6, 25, 8, 64, 7, 98, 0, 98, 5, 68, 4, 53, 3, 50, 1, 29
  };
  const int q8655[] = {
    9, 9, // Number of jobs and machines
    7, 17, 0, 75, 5, 78, 2, 18, 8, 83, 1, 44, 6,  7, 3, 82, 4, 41, 
    3, 15, 6, 45, 2, 95, 0, 72, 4, 66, 1, 60, 8, 21, 5, 42, 7, 36, 
    7, 99, 1, 40, 0, 40, 6, 93, 2, 71, 8, 12, 5, 57, 4, 34, 3, 50, 
    6, 85, 8, 68, 1, 51, 3, 36, 4, 14, 7, 11, 5, 33, 2, 30, 0, 58, 
    1, 38, 7, 18, 0, 47, 6, 49, 5, 83, 4, 16, 3, 80, 2, 39, 8, 14, 
    7, 87, 8, 32, 2, 83, 4, 23, 1, 56, 5, 52, 0, 40, 6, 64, 3,  2, 
    4, 47, 8, 56, 0,  4, 2, 60, 6, 88, 1, 30, 5,  6, 7, 15, 3, 57, 
    8, 22, 2, 51, 6, 43, 7, 82, 0, 95, 1,  1, 5, 68, 3, 56, 4, 51, 
    0, 66, 8, 27, 3, 63, 4, 78, 7, 74, 6, 71, 2, 49, 1, 97, 5, 73
  };
  const int q8656[] = {
    9, 9, // Number of jobs and machines
    8, 61, 4, 40, 2, 51, 6, 66, 5, 42, 7, 59, 1, 33, 0, 41, 3, 91, 
    7, 22, 0, 44, 6, 77, 3, 15, 5,  8, 4, 33, 2, 21, 1, 80, 8, 56, 
    5, 59, 1,  8, 7, 91, 0, 78, 2, 44, 3, 24, 4, 84, 8, 31, 6, 88, 
    0, 88, 5, 64, 8, 39, 1, 49, 2, 32, 4, 36, 6, 48, 3, 93, 7, 16, 
    4, 61, 6, 94, 0, 73, 1, 31, 3,  7, 2,  7, 7, 55, 8, 83, 5, 78, 
    7, 28, 5, 32, 8, 85, 2, 88, 0, 37, 6, 91, 1, 14, 4, 18, 3, 11, 
    1,  8, 4, 35, 7, 98, 6, 52, 2, 83, 5, 87, 0, 44, 3, 46, 8, 16, 
    6, 51, 4, 47, 8, 47, 2, 70, 0, 32, 3, 69, 7,  8, 1,  7, 5, 63, 
    8, 18, 0, 63, 3, 64, 7, 89, 4, 25, 5, 28, 2, 78, 1, 88, 6, 42
  };
  const int q8657[] = {
    9, 9, // Number of jobs and machines
    3, 40, 1, 67, 8, 81, 4,  3, 7, 49, 5,  2, 0, 73, 2, 49, 6, 32, 
    6, 31, 1, 81, 7, 16, 8, 78, 5, 27, 3, 25, 0, 52, 2, 67, 4, 74, 
    8, 62, 7, 32, 5, 98, 4, 90, 0, 98, 3, 82, 6, 54, 1, 99, 2, 24, 
    3, 13, 0, 54, 2, 10, 4, 88, 6, 19, 8, 62, 1, 16, 7, 10, 5, 13, 
    3, 27, 8, 75, 7, 99, 6, 49, 5, 30, 0, 37, 1, 61, 2, 27, 4,  4, 
    0, 67, 2, 86, 4, 48, 6, 72, 7, 34, 1, 16, 5, 15, 8, 82, 3, 35, 
    8, 54, 6, 21, 3, 87, 5, 71, 4, 40, 7, 25, 1, 57, 2, 67, 0, 93, 
    2,  6, 1, 78, 8, 38, 6,  3, 3, 88, 4,  9, 0, 37, 7, 79, 5, 77, 
    6, 76, 5, 34, 1, 37, 4, 83, 3, 92, 8, 96, 7, 43, 2, 59, 0, 72
  };
  const int q8658[] = {
    9, 9, // Number of jobs and machines
    8, 96, 5, 17, 4, 96, 6, 13, 3, 76, 7, 59, 2, 58, 1, 79, 0, 21, 
    7, 26, 4, 65, 0, 17, 1, 34, 3,  9, 8, 51, 5, 84, 6, 52, 2, 98, 
    2, 98, 3, 23, 1, 44, 0, 75, 5, 43, 6, 72, 7, 34, 4, 15, 8, 32, 
    6, 37, 0, 49, 2, 41, 7, 53, 8, 70, 5, 35, 3, 33, 1, 89, 4, 27, 
    5, 86, 4, 41, 1, 74, 8, 13, 7,  7, 2, 31, 0,  5, 3, 54, 6, 97, 
    6, 65, 2, 51, 5, 73, 8, 78, 3, 41, 4, 96, 1, 32, 7, 33, 0, 26, 
    6, 49, 7, 53, 3, 58, 1,  4, 5, 86, 4, 47, 2,  6, 0, 65, 8, 85, 
    3, 62, 4, 82, 5, 22, 8, 30, 1, 99, 2, 13, 0, 42, 7, 32, 6, 20, 
    4, 76, 0, 83, 3,  7, 1, 50, 6, 74, 7, 13, 5, 78, 2,  4, 8, 23
  };
  const int q8659[] = {
    9, 9, // Number of jobs and machines
    7,  4, 8, 29, 1, 52, 5, 48, 2, 32, 3,  6, 4, 58, 6, 43, 0,  8, 
    6, 64, 4, 63, 2, 46, 0, 29, 7, 78, 8, 47, 3, 28, 1, 27, 5, 67, 
    3,  6, 6, 91, 2, 70, 5, 98, 8, 47, 1, 51, 7, 51, 0, 14, 4, 77, 
    4, 13, 8, 96, 7, 99, 3, 28, 5, 53, 2, 60, 6, 44, 1, 87, 0, 78, 
    6, 79, 4, 49, 7,  5, 0, 77, 3, 76, 2, 40, 5, 42, 8, 78, 1, 31, 
    2, 66, 3, 20, 5,  6, 0, 75, 8, 54, 4, 59, 1, 77, 6, 68, 7, 39, 
    1, 74, 4, 20, 6, 59, 0,  8, 8, 62, 5, 25, 2, 95, 7, 46, 3, 20, 
    4,  1, 5, 67, 3, 65, 6, 87, 7, 17, 2, 15, 1, 79, 0, 94, 8, 36, 
    8, 10, 6,  8, 7, 14, 3,  1, 0, 38, 1,  1, 2, 47, 5, 56, 4, 36
  };
  const int q8660[] = {
    9, 9, // Number of jobs and machines
    7, 66, 1, 72, 3, 74, 0, 18, 8, 93, 5, 10, 4, 98, 6, 71, 2, 75, 
    4, 15, 8, 23, 5, 68, 2, 39, 1, 65, 0, 57, 6, 82, 7, 77, 3, 87, 
    7,  9, 6, 46, 8,  9, 1, 45, 4, 71, 2, 17, 3, 95, 0, 25, 5, 60, 
    1, 29, 2, 22, 4, 10, 8, 25, 6, 66, 7, 38, 0, 81, 3, 76, 5, 37, 
    5, 53, 6, 89, 7, 53, 3, 55, 4, 18, 1, 82, 0, 83, 8, 82, 2, 22, 
    3, 14, 2, 23, 4, 78, 0, 26, 8, 13, 7, 81, 5, 24, 1, 64, 6, 89, 
    8, 22, 1, 22, 6,  9, 2, 93, 5,  4, 4, 59, 7, 40, 0,  5, 3, 79, 
    5, 20, 4, 58, 6, 73, 0, 32, 2, 42, 3, 57, 7, 51, 8, 10, 1, 56, 
    0, 90, 8, 39, 1, 43, 2, 68, 4, 65, 7, 46, 6, 20, 5, 25, 3, 32
  };
  const int q8661[] = {
    9, 9, // Number of jobs and machines
    5,  1, 3, 69, 2, 89, 1, 29, 7, 90, 8, 24, 6, 62, 4, 88, 0, 73, 
    2, 85, 5, 37, 4, 15, 1, 99, 8,  2, 0,  3, 3, 15, 6, 33, 7, 94, 
    5, 58, 1, 55, 4, 36, 7, 10, 3, 35, 0, 29, 6, 25, 2, 89, 8, 57, 
    3, 36, 0, 30, 6, 36, 1,  1, 5, 47, 2, 42, 7, 17, 8, 82, 4, 10, 
    1, 76, 7, 94, 8, 47, 0, 49, 3, 73, 6, 56, 4, 27, 2, 59, 5, 93, 
    7, 86, 5, 72, 8, 12, 2, 11, 1, 10, 4,  2, 0, 17, 6, 19, 3, 63, 
    6, 44, 2, 47, 3, 99, 7, 98, 8, 46, 4, 30, 0, 80, 1,  3, 5, 74, 
    8, 98, 5, 33, 7, 38, 6, 56, 3, 46, 1, 93, 0, 67, 4, 24, 2, 28, 
    7, 15, 3, 36, 5, 69, 1, 33, 2, 43, 6, 81, 8, 32, 0,  8, 4, 65
  };
  const int q8662[] = {
    9, 9, // Number of jobs and machines
    7, 90, 2, 85, 8, 87, 4, 67, 1,  2, 3, 42, 6,  1, 0,  9, 5, 68, 
    1, 63, 7,  5, 4, 99, 5, 75, 2, 74, 8, 27, 0, 45, 3, 16, 6, 64, 
    5, 72, 7, 53, 6, 15, 1, 49, 8, 57, 2, 77, 0, 36, 4, 81, 3, 76, 
    1, 41, 6, 98, 4,  6, 3, 43, 7, 10, 8, 73, 5, 92, 0, 20, 2,  7, 
    5,  8, 4, 19, 7, 74, 3, 36, 2,  7, 8, 99, 6, 60, 1, 70, 0, 80, 
    1, 66, 3, 66, 5,  1, 8, 17, 0, 53, 7, 36, 2, 20, 4, 16, 6, 32, 
    3, 18, 1, 13, 4, 98, 2, 84, 8, 98, 7, 91, 0, 43, 5, 41, 6, 41, 
    6,  3, 7, 83, 1, 95, 0, 58, 4, 70, 2, 91, 5, 88, 3, 83, 8, 29, 
    1, 45, 4, 49, 5, 25, 3, 46, 0,  8, 8, 99, 7, 52, 6, 45, 2, 79
  };
  const int q8663[] = {
    9, 9, // Number of jobs and machines
    4, 80, 2,  5, 7, 55, 1, 53, 8, 62, 0, 60, 6, 47, 5, 28, 3, 76, 
    3, 46, 2, 86, 6, 69, 0, 66, 1, 91, 7, 18, 8, 94, 5, 56, 4, 62, 
    3, 81, 8, 68, 5, 30, 2,  6, 7, 66, 0, 10, 4, 57, 1, 75, 6, 73, 
    8, 82, 4, 57, 5, 70, 1, 28, 3, 94, 2, 50, 7, 77, 6, 60, 0, 66, 
    1, 48, 3, 59, 6, 21, 8, 77, 2, 88, 5, 15, 0, 29, 4, 30, 7, 68, 
    3, 38, 5, 74, 1, 33, 2, 74, 4, 93, 8, 10, 0, 95, 6, 41, 7, 64, 
    7, 67, 5, 37, 4, 13, 1, 81, 8, 45, 3, 51, 0, 94, 6,  9, 2, 57, 
    2, 61, 3,  1, 0, 98, 8, 26, 5, 24, 7, 42, 6, 18, 1, 35, 4, 25, 
    3, 87, 2, 48, 7, 88, 0, 43, 8, 55, 1, 60, 5, 63, 6,  3, 4, 67
  };
  const int q8664[] = {
    9, 9, // Number of jobs and machines
    2,  6, 7, 64, 6, 89, 0,  2, 4, 58, 5, 64, 3, 79, 1,  7, 8, 13, 
    7, 89, 1, 34, 8, 30, 5, 50, 2, 45, 3,  7, 6, 89, 0, 78, 4, 15, 
    7, 73, 5, 66, 3, 63, 6, 65, 8, 57, 0, 13, 4, 18, 2, 92, 1, 57, 
    6, 84, 5,  3, 8, 61, 4, 84, 3, 97, 2, 67, 1, 84, 0, 52, 7,  6, 
    0, 51, 3, 72, 2, 68, 4,  2, 1, 66, 6, 38, 7, 34, 8, 80, 5, 28, 
    6, 87, 7, 17, 1, 56, 3, 12, 4, 97, 2, 11, 8, 67, 5, 18, 0, 29, 
    1, 81, 0, 76, 5, 63, 7, 94, 4, 12, 6, 87, 3, 29, 2, 91, 8, 27, 
    7, 27, 8, 81, 4, 30, 0, 81, 6, 46, 3, 28, 2, 84, 5, 58, 1, 66, 
    6, 81, 2, 57, 0, 15, 1, 68, 4, 97, 5,  6, 7, 76, 8, 58, 3, 90
  };
  const int q8665[] = {
    9, 9, // Number of jobs and machines
    8, 65, 5, 50, 6, 16, 7, 21, 4, 73, 1, 49, 0, 94, 3,  4, 2, 28, 
    8, 50, 0, 25, 3, 40, 5, 77, 2, 80, 7, 80, 1, 16, 4, 58, 6, 72, 
    3, 53, 7, 50, 1, 75, 6, 75, 0, 78, 4, 18, 2, 82, 5,  5, 8, 37, 
    7, 60, 3, 79, 8, 50, 2, 21, 0, 20, 4, 41, 1, 94, 6, 56, 5,  5, 
    1, 35, 2, 17, 3, 93, 8, 27, 7, 53, 5, 21, 4, 88, 0, 78, 6, 74, 
    8, 84, 0, 82, 5, 69, 1, 71, 3, 71, 6, 33, 7, 93, 2, 63, 4, 22, 
    0, 67, 7,  7, 4, 33, 8, 47, 2,  1, 3, 55, 5, 76, 1, 14, 6, 17, 
    3, 68, 6, 27, 5, 96, 0, 94, 4, 11, 2, 58, 7, 25, 1, 16, 8, 89, 
    4, 86, 0, 43, 6, 87, 5, 79, 2, 84, 8, 83, 7, 82, 3, 85, 1, 14
  };
  const int q8666[] = {
    9, 9, // Number of jobs and machines
    6, 60, 7, 11, 3, 67, 2, 62, 8, 15, 0, 72, 5, 26, 4, 33, 1, 35, 
    0, 89, 1, 89, 2, 41, 6,  2, 5, 22, 7, 47, 3, 57, 4,  7, 8, 43, 
    5, 50, 1, 28, 7, 23, 0, 54, 3, 84, 2, 47, 6, 13, 4, 29, 8, 66, 
    4,  5, 8, 13, 6,  5, 1, 71, 2, 65, 3, 84, 7, 61, 5, 56, 0, 57, 
    7, 67, 0, 68, 8, 53, 5, 43, 3, 47, 1, 21, 2, 85, 4, 83, 6, 29, 
    0, 27, 1, 98, 2, 46, 8, 20, 4, 70, 3, 99, 6, 44, 5, 31, 7, 41, 
    1, 90, 2, 31, 4, 12, 3, 96, 6, 57, 8, 91, 5, 58, 7, 80, 0, 69, 
    8, 39, 7, 94, 3, 68, 0, 82, 2, 90, 6, 16, 4, 27, 1, 91, 5, 60, 
    3, 80, 1,  4, 2, 50, 5, 38, 6, 71, 0, 44, 8,  5, 4, 86, 7, 45
  };
  const int q8667[] = {
    9, 9, // Number of jobs and machines
    3, 80, 2, 36, 8, 29, 0, 59, 4, 39, 6, 43, 7, 87, 5, 63, 1, 66, 
    5, 96, 7, 39, 1, 34, 2, 83, 4, 28, 0, 65, 3, 76, 6, 56, 8, 86, 
    7, 81, 5, 97, 4, 37, 8,  3, 2, 72, 3, 30, 6,  1, 0, 46, 1, 63, 
    6, 55, 8, 44, 7, 73, 0, 78, 5, 90, 2, 51, 3, 71, 4,  5, 1, 80, 
    4,  2, 5, 65, 3,  5, 2, 27, 0, 87, 8, 97, 7, 16, 1, 53, 6, 36, 
    8, 92, 6, 86, 5, 95, 2, 44, 4, 56, 1, 68, 7,  5, 3, 15, 0, 25, 
    4, 34, 8, 34, 3,  5, 6, 21, 1, 13, 7, 67, 5, 18, 0, 52, 2, 40, 
    3,  1, 7, 85, 8, 79, 2, 33, 1, 58, 4, 46, 6, 70, 5, 61, 0, 48, 
    2,  5, 7, 37, 8, 86, 3, 34, 0, 83, 4, 35, 6, 98, 5, 22, 1, 32
  };
  const int q8668[] = {
    9, 9, // Number of jobs and machines
    3, 37, 0, 83, 2, 76, 1, 57, 4, 67, 6, 42, 7, 85, 5, 98, 8, 56, 
    7, 30, 0, 39, 3, 46, 1,  1, 5, 95, 2, 20, 4, 94, 6, 65, 8, 65, 
    5, 57, 7, 63, 4, 55, 6, 52, 2, 36, 8, 58, 3, 31, 1, 54, 0, 91, 
    7, 44, 1, 13, 8,  6, 2, 15, 0, 95, 6, 80, 5, 77, 4, 74, 3, 52, 
    5, 98, 7, 13, 4, 86, 6, 23, 2, 88, 8, 12, 0, 97, 3, 84, 1, 52, 
    3, 71, 2, 65, 7, 26, 6, 87, 5, 64, 8,  9, 1, 98, 4, 97, 0,  9, 
    3, 12, 7, 71, 0, 52, 2,  5, 8, 14, 1, 31, 6, 97, 5, 37, 4, 29, 
    5, 76, 2, 88, 6, 66, 4, 41, 3, 51, 1, 96, 0, 86, 7, 91, 8, 56, 
    5, 68, 8, 45, 6, 12, 7, 90, 1,  9, 3, 36, 2, 60, 0,  8, 4, 19
  };
  const int q8669[] = {
    9, 9, // Number of jobs and machines
    6, 69, 4, 41, 3, 46, 0, 20, 1, 18, 5, 90, 8, 79, 2, 34, 7, 72, 
    5, 39, 4, 65, 0,  4, 7, 69, 3, 72, 1, 85, 6, 89, 8, 58, 2, 63, 
    4, 43, 6, 14, 7, 46, 8, 78, 2, 70, 3, 98, 1, 52, 5, 92, 0, 81, 
    6, 31, 8, 12, 5, 66, 1, 64, 2, 62, 3, 35, 7, 85, 0, 29, 4, 77, 
    4, 11, 8, 98, 6, 74, 0,  2, 7, 74, 2, 46, 1, 71, 3, 80, 5, 69, 
    7, 44, 8, 56, 6,  5, 1, 12, 5, 61, 3, 66, 2, 69, 0, 71, 4, 13, 
    8, 81, 7,  3, 2,  7, 5, 26, 3, 64, 1, 75, 0, 93, 4,  3, 6, 69, 
    6, 70, 5, 80, 4, 49, 0, 56, 1, 45, 2, 73, 7, 44, 8, 50, 3, 79, 
    5, 79, 4, 52, 2, 99, 1,  2, 0, 93, 8, 20, 6, 96, 3, 53, 7, 82
  };
  const int q8670[] = {
    9, 9, // Number of jobs and machines
    5, 31, 1, 56, 0,  5, 7, 62, 3, 42, 4, 43, 8,  9, 6, 37, 2, 30, 
    5, 18, 0, 48, 8,  2, 3, 53, 6, 46, 4, 67, 7, 26, 1,  3, 2,  9, 
    7, 11, 4, 55, 5,  2, 8, 92, 3, 29, 6, 24, 0, 66, 1, 87, 2, 16, 
    1, 50, 0,  7, 8, 84, 3, 73, 7, 47, 6, 56, 5, 26, 4, 88, 2, 83, 
    8, 21, 3, 58, 5, 79, 1, 55, 7, 71, 2, 18, 0,  2, 4,  4, 6, 82, 
    4, 46, 8, 42, 1, 85, 6, 81, 0, 84, 5, 58, 3, 11, 7, 95, 2, 46, 
    8,  9, 3,  3, 4, 84, 7, 35, 0, 10, 5, 64, 2, 72, 1, 22, 6, 71, 
    4, 44, 8, 45, 5, 18, 6, 65, 2, 30, 1,  7, 7, 30, 0, 92, 3, 54, 
    8,  3, 1, 38, 6, 45, 0, 17, 7, 55, 3, 53, 5, 64, 2, 95, 4,  4
  };
  const int q8671[] = {
    9, 9, // Number of jobs and machines
    4, 49, 2, 60, 1, 13, 3, 46, 0, 67, 5,  4, 8, 11, 7, 97, 6, 15, 
    1, 61, 3, 69, 8, 73, 5, 71, 4, 95, 7, 29, 0, 43, 2, 69, 6, 77, 
    2, 78, 4,  2, 7, 99, 6, 34, 0, 83, 3, 94, 5, 78, 8, 35, 1, 45, 
    1, 60, 5, 24, 7, 76, 4, 58, 0,  2, 6, 35, 8, 35, 2, 47, 3, 55, 
    5, 48, 1, 50, 8,  1, 6, 98, 4, 38, 0, 27, 7, 62, 2, 11, 3, 33, 
    7,  4, 3, 49, 0,  2, 4, 30, 6, 73, 5, 78, 2, 46, 8, 36, 1, 56, 
    0, 17, 1, 65, 3, 21, 8, 80, 4, 27, 6, 15, 5, 85, 7, 50, 2, 13, 
    0, 37, 5, 87, 8, 67, 3, 92, 2, 61, 4, 42, 6, 13, 7,  7, 1, 70, 
    8, 82, 4, 62, 7, 62, 2, 18, 5, 86, 3, 73, 1, 91, 0, 61, 6, 49
  };
  const int q8672[] = {
    9, 9, // Number of jobs and machines
    0, 70, 7, 97, 1, 17, 5, 35, 2, 94, 3, 78, 8,  9, 4, 63, 6, 63, 
    2, 21, 5, 78, 6, 95, 4,  9, 8, 36, 3, 31, 0, 61, 7, 32, 1, 80, 
    7, 22, 0, 68, 4, 25, 8, 58, 6, 93, 3, 55, 2, 48, 1, 98, 5, 48, 
    7, 29, 5, 80, 2, 93, 1, 44, 8, 94, 3, 52, 4, 91, 0, 79, 6, 61, 
    4, 21, 6, 49, 1, 31, 8, 98, 2, 66, 5, 75, 7, 89, 3, 74, 0, 83, 
    0, 44, 8, 59, 5, 21, 2, 73, 7, 89, 4, 75, 1, 74, 3, 19, 6, 20, 
    1, 16, 5, 53, 7, 31, 2, 20, 3, 93, 4, 62, 6, 12, 0, 95, 8, 30, 
    7, 94, 8, 94, 2, 85, 6, 78, 5, 36, 1,  5, 0,  8, 4, 50, 3, 93, 
    5,  1, 0, 55, 1,  7, 6, 75, 3, 15, 7, 37, 4, 94, 8, 23, 2,  4
  };
  const int q8673[] = {
    9, 9, // Number of jobs and machines
    3, 55, 1, 40, 4, 82, 7, 34, 0, 46, 5, 21, 6, 81, 2, 46, 8, 46, 
    7, 21, 5, 15, 8, 74, 6, 31, 1, 26, 2, 74, 4, 60, 0, 11, 3, 62, 
    2, 86, 5, 34, 0, 17, 6, 86, 1, 17, 3, 23, 4, 60, 7, 24, 8, 30, 
    6, 12, 1, 65, 8, 42, 3, 18, 7, 88, 5, 69, 0, 34, 4, 49, 2, 19, 
    4, 96, 6, 59, 3, 22, 5, 35, 8, 28, 0, 23, 1, 92, 7, 40, 2, 90, 
    0, 12, 1, 52, 2, 52, 4, 57, 7, 54, 5, 25, 6, 51, 8, 45, 3, 56, 
    8, 59, 6, 24, 7, 25, 4, 10, 2,  7, 3, 84, 5, 13, 0,  5, 1, 16, 
    0,  2, 8, 94, 7, 44, 4, 66, 1, 64, 2, 13, 5, 93, 6,  1, 3, 11, 
    1, 15, 8, 78, 2, 84, 7, 44, 3, 35, 6, 73, 4, 68, 0, 32, 5, 61
  };
  const int q8674[] = {
    9, 9, // Number of jobs and machines
    3, 89, 4, 78, 7, 59, 0, 29, 6, 19, 5, 16, 8, 51, 1, 12, 2, 90, 
    4, 55, 6, 79, 0, 84, 7, 12, 8, 46, 2, 71, 5, 41, 3, 89, 1, 59, 
    7, 50, 1, 67, 6, 56, 4, 79, 3,  7, 0, 36, 2, 69, 5, 59, 8, 99, 
    0, 97, 7, 15, 5, 48, 8, 71, 1, 65, 3, 61, 4, 99, 6, 95, 2, 13, 
    8, 27, 1, 94, 3, 25, 6,  8, 4, 87, 7, 13, 5, 85, 2, 70, 0, 82, 
    3, 21, 4, 19, 5, 37, 0, 72, 1, 34, 7, 14, 8,  5, 2, 72, 6, 42, 
    3, 25, 8, 19, 5, 32, 1, 40, 2, 64, 0, 82, 4, 95, 6, 88, 7, 28, 
    4, 63, 2, 16, 6, 87, 3, 78, 7, 56, 5, 85, 1, 99, 0, 68, 8, 46, 
    6, 13, 3, 25, 4, 62, 7, 55, 2, 15, 1, 57, 0, 61, 8, 82, 5, 25
  };
  const int q8675[] = {
    9, 9, // Number of jobs and machines
    7, 23, 1, 36, 0, 99, 6, 59, 5, 48, 8, 51, 3, 19, 2, 94, 4, 28, 
    6, 44, 8,  8, 2, 24, 7, 21, 3,  4, 1, 91, 4,  2, 5, 93, 0, 50, 
    1, 61, 2, 95, 3, 84, 0, 97, 6, 60, 5, 51, 4, 88, 8, 71, 7, 13, 
    0, 62, 5, 69, 3, 65, 7, 97, 4, 96, 2, 82, 6, 98, 8, 35, 1, 29, 
    3, 30, 8, 69, 6, 30, 5, 34, 2, 87, 0, 12, 7, 90, 4, 56, 1, 41, 
    8, 75, 7, 38, 0, 96, 6, 50, 1,  9, 2, 48, 3, 20, 5, 69, 4, 59, 
    5,  2, 6, 94, 2, 31, 4, 30, 3, 60, 7, 22, 8, 61, 1, 58, 0, 50, 
    4, 16, 1, 46, 3, 80, 8,  4, 6, 16, 0, 80, 7, 57, 2, 76, 5, 28, 
    6, 19, 2, 19, 1, 49, 0, 61, 8, 25, 3, 24, 4, 90, 5, 85, 7, 87
  };
  const int q8676[] = {
    9, 9, // Number of jobs and machines
    4, 95, 2, 23, 3, 34, 6, 36, 8, 10, 7, 98, 1, 35, 0, 62, 5, 57, 
    7, 87, 3, 41, 0, 70, 1,  7, 8, 98, 4,  8, 6, 85, 5, 63, 2, 91, 
    8, 52, 2, 47, 1, 61, 5, 93, 7, 47, 4, 60, 6, 65, 0, 37, 3, 74, 
    3, 44, 0, 69, 2, 25, 4, 60, 8, 41, 7, 39, 5, 23, 1, 90, 6, 42, 
    6,  2, 8,  1, 3,  2, 1, 90, 4, 73, 2, 78, 0,  7, 5, 17, 7,  2, 
    1,  8, 4, 52, 0, 89, 7, 73, 2, 82, 6, 93, 8, 85, 3, 53, 5, 32, 
    6, 46, 0, 74, 8, 64, 7, 53, 2, 69, 4, 48, 1, 35, 3, 30, 5, 94, 
    1, 29, 5, 59, 3, 11, 0,  6, 6, 86, 8,  7, 4, 43, 2, 59, 7, 36, 
    6, 63, 5, 14, 7, 47, 8, 26, 3, 52, 4, 59, 1, 95, 2, 54, 0, 71
  };
  const int q8677[] = {
    9, 9, // Number of jobs and machines
    2, 25, 1, 70, 5, 49, 7, 29, 8, 91, 0, 96, 3, 45, 4, 10, 6, 25, 
    1, 80, 7, 52, 2, 57, 8, 16, 0, 31, 3, 41, 6, 13, 5, 60, 4, 61, 
    7, 10, 3,  4, 0, 74, 8, 39, 2, 66, 4, 77, 5, 33, 6, 39, 1, 23, 
    6, 93, 5, 51, 2, 22, 3,  7, 8, 92, 4, 38, 0, 25, 7, 47, 1,  2, 
    1, 85, 5, 69, 2, 74, 6,  8, 4,  5, 8, 88, 3, 21, 0,  1, 7, 94, 
    5, 67, 0, 91, 6, 55, 3, 96, 7, 38, 8, 29, 2,  6, 1, 29, 4, 10, 
    1, 53, 0, 54, 5, 40, 3, 22, 6, 68, 4, 19, 2, 25, 7, 24, 8, 74, 
    8, 59, 0, 79, 7, 17, 4, 81, 3, 52, 1, 36, 5, 85, 2, 92, 6, 22, 
    5, 98, 3, 82, 1,  4, 6, 71, 8, 30, 2, 76, 0, 68, 4, 53, 7, 54
  };
  const int q8678[] = {
    9, 9, // Number of jobs and machines
    5, 59, 1, 32, 0,  3, 6, 76, 2, 16, 4, 77, 3, 22, 8, 52, 7, 98, 
    3, 78, 1, 13, 6, 33, 2, 39, 4, 49, 0, 57, 5, 68, 8, 61, 7, 70, 
    2, 21, 1, 55, 4, 50, 0, 46, 7, 60, 8, 83, 3, 63, 5,  5, 6, 58, 
    8, 12, 6, 52, 3, 54, 7, 51, 0, 19, 2, 81, 4, 41, 1, 22, 5, 66, 
    7,  5, 5, 47, 3, 94, 1, 41, 2, 33, 4, 92, 6, 74, 0, 25, 8, 67, 
    2, 53, 5, 72, 6, 23, 1, 22, 4, 76, 8, 66, 3, 61, 0, 81, 7, 75, 
    6, 38, 0, 46, 7, 90, 3, 65, 8,  2, 5, 74, 2, 17, 4, 75, 1, 73, 
    0, 62, 6, 79, 3, 79, 2, 72, 8,  2, 5, 63, 4, 82, 1, 26, 7, 59, 
    6, 23, 7, 92, 4,  3, 2, 42, 1,  6, 3, 85, 0, 43, 5, 70, 8, 97
  };
  const int q8679[] = {
    9, 9, // Number of jobs and machines
    2,  3, 3, 90, 7, 13, 4, 32, 0, 60, 6, 74, 1, 40, 5, 95, 8, 56, 
    8, 58, 6, 48, 0, 14, 1, 81, 3, 57, 7, 20, 4,  4, 2, 43, 5, 32, 
    3, 23, 5, 24, 0, 49, 2, 85, 1, 36, 8, 73, 4, 76, 7, 27, 6, 30, 
    0, 65, 2, 20, 4, 89, 6, 48, 7, 78, 5,  3, 1, 10, 3, 38, 8, 75, 
    1, 50, 8, 47, 6, 69, 3, 73, 0, 89, 4, 29, 5, 74, 2, 54, 7, 73, 
    2, 98, 5, 85, 7, 47, 8,  7, 3, 64, 6, 90, 1, 28, 4, 84, 0, 39, 
    1, 95, 8, 13, 3,  6, 0, 73, 5, 94, 7, 86, 4, 37, 6, 35, 2, 87, 
    0, 85, 6, 82, 2, 51, 5, 56, 8, 27, 1, 47, 3, 84, 4, 77, 7, 91, 
    4, 54, 8, 57, 0, 28, 6, 98, 2, 49, 1, 52, 3, 65, 5, 51, 7, 93
  };
  const int q8680[] = {
    9, 9, // Number of jobs and machines
    5, 66, 0, 89, 1, 12, 4,  3, 7, 29, 2,  3, 8, 49, 3, 18, 6, 86, 
    8, 27, 4, 63, 5, 64, 0, 43, 3, 74, 1, 43, 7, 44, 6, 98, 2, 35, 
    8, 40, 1, 33, 2, 49, 0,  7, 6, 17, 5, 20, 4, 61, 3, 66, 7, 17, 
    2, 23, 7, 40, 8,  5, 6, 85, 5, 43, 0, 89, 1,  3, 4, 89, 3, 28, 
    0, 40, 1, 56, 7,  7, 6, 35, 2, 80, 8, 98, 4, 76, 5, 69, 3, 71, 
    4, 71, 0, 87, 6, 95, 2, 59, 3, 41, 8, 54, 7, 73, 5, 91, 1,  5, 
    5, 20, 6, 33, 7, 96, 1, 87, 0, 49, 8, 45, 2, 99, 3, 55, 4,  1, 
    3, 74, 1, 95, 4, 43, 2, 61, 6, 57, 0, 60, 7,  6, 8, 70, 5, 49, 
    1, 47, 6, 34, 5, 22, 0, 22, 2, 66, 3, 81, 4, 43, 7, 11, 8, 14
  };
  const int q8681[] = {
    9, 9, // Number of jobs and machines
    5, 35, 8, 51, 2, 83, 4, 40, 7, 61, 3, 72, 6, 47, 1, 42, 0, 79, 
    4, 73, 1, 30, 2, 22, 6, 23, 3, 98, 8,  5, 0, 13, 5, 15, 7, 83, 
    7, 91, 2, 66, 1, 39, 6, 44, 4, 28, 3, 62, 8, 74, 5, 64, 0, 62, 
    8, 29, 6, 72, 3, 40, 4, 27, 1, 59, 7, 76, 2, 13, 5, 64, 0, 50, 
    2,  4, 6, 90, 7,  7, 1, 93, 8, 24, 3, 29, 5, 74, 0, 73, 4, 50, 
    5, 63, 3, 73, 7, 37, 0, 27, 6, 30, 4, 77, 2, 33, 1, 50, 8, 47, 
    3, 72, 5, 20, 2, 17, 4, 65, 7, 75, 0, 92, 1, 43, 8, 89, 6, 14, 
    2, 60, 6, 88, 8, 73, 7,  5, 0, 71, 4, 52, 5, 80, 3,  9, 1, 31, 
    0, 74, 6,  2, 1, 44, 3, 28, 7, 88, 2, 33, 4, 69, 5, 49, 8,  6
  };
  const int q8682[] = {
    9, 9, // Number of jobs and machines
    2, 26, 1, 31, 4, 25, 6, 48, 5, 83, 7, 95, 8, 69, 0,  6, 3, 72, 
    0, 29, 7, 52, 2, 67, 1, 47, 4, 22, 6, 55, 3, 81, 5, 49, 8, 66, 
    1, 73, 0, 61, 6, 88, 4, 67, 7, 75, 2, 50, 8,  4, 3, 84, 5, 73, 
    4, 76, 5, 28, 6, 13, 2, 58, 3, 22, 8,  6, 1, 37, 7, 63, 0,  2, 
    5, 26, 0, 81, 2, 37, 1, 25, 4, 35, 7, 17, 6, 21, 8, 66, 3, 66, 
    0,  1, 1, 87, 2, 44, 8, 52, 6, 45, 3, 29, 7, 14, 5, 95, 4, 19, 
    4, 12, 8, 82, 5, 99, 6, 78, 3, 26, 0, 27, 7, 52, 2, 58, 1, 65, 
    5,  7, 2, 69, 7, 83, 4,  7, 8, 92, 1, 94, 3, 34, 0, 24, 6, 74, 
    8, 58, 5, 45, 3, 71, 6, 34, 1,  4, 7, 41, 0, 91, 4, 51, 2, 95
  };
  const int q8683[] = {
    9, 9, // Number of jobs and machines
    0, 94, 1, 74, 5, 35, 2, 60, 7, 52, 3, 64, 6, 96, 4, 10, 8, 59, 
    5,  6, 7,  1, 6, 90, 0, 79, 2, 45, 8,  7, 4, 57, 3, 34, 1, 71, 
    8, 27, 6, 76, 0, 87, 7, 71, 2, 61, 1, 47, 5, 21, 3, 90, 4, 68, 
    3, 26, 6, 30, 0, 64, 5,  5, 8, 57, 4, 22, 1, 32, 2, 97, 7, 95, 
    2, 19, 6, 22, 4, 35, 8,  4, 1, 21, 7, 39, 0, 57, 5, 82, 3, 94, 
    4, 73, 5, 49, 7, 46, 1,  9, 6,  2, 3, 87, 0, 37, 8, 44, 2, 58, 
    2, 69, 1, 33, 8, 57, 5,  4, 0,  1, 4, 49, 3, 55, 6, 45, 7,  6, 
    5, 47, 7, 17, 2,  1, 4, 95, 0, 15, 6, 58, 1, 14, 3, 90, 8, 17, 
    1,  1, 5, 80, 0, 49, 7, 88, 8, 52, 4, 50, 3, 47, 2, 62, 6, 54
  };
  const int q8684[] = {
    9, 9, // Number of jobs and machines
    8, 19, 0, 65, 1, 52, 2, 17, 7, 69, 4,  1, 3, 78, 5, 21, 6, 33, 
    0, 20, 2, 67, 8, 43, 3, 47, 4, 26, 1, 15, 7,  2, 5, 11, 6, 89, 
    1, 29, 3, 21, 7,  9, 0, 99, 8, 25, 5, 24, 6, 65, 2,  2, 4, 60, 
    1, 32, 2, 85, 4, 85, 6, 34, 7, 48, 0, 88, 3, 17, 5, 43, 8, 17, 
    1, 26, 2, 85, 8, 55, 0,  6, 6, 90, 5, 17, 4, 75, 3, 64, 7, 11, 
    2, 41, 6, 47, 5, 13, 4, 38, 7, 94, 1, 52, 3, 34, 8, 21, 0, 70, 
    0, 40, 1, 91, 7, 59, 8, 63, 2, 11, 6, 12, 3,  7, 5, 83, 4, 68, 
    5, 87, 8, 31, 4, 87, 1, 43, 7, 26, 2, 93, 0, 95, 3, 56, 6, 91, 
    8, 77, 3, 31, 5, 26, 0, 93, 1, 26, 7, 63, 4, 44, 6,  2, 2, 91
  };
  const int q8685[] = {
    9, 9, // Number of jobs and machines
    1, 98, 2, 48, 5, 89, 3, 72, 4, 23, 8, 24, 6, 61, 7, 87, 0, 56, 
    7, 72, 6, 13, 1, 44, 3, 92, 5,  4, 2, 81, 4, 96, 8, 24, 0,  7, 
    6, 22, 0, 33, 8, 61, 1, 83, 4,  3, 5,  5, 3, 37, 7,  4, 2, 94, 
    3, 36, 0, 89, 4, 96, 7, 21, 8, 28, 2, 50, 1, 83, 5, 58, 6, 41, 
    7, 35, 6, 13, 5, 26, 1, 31, 2, 77, 3, 31, 8, 28, 0, 65, 4, 76, 
    1, 30, 4, 18, 6, 92, 5,  5, 8, 59, 7,  8, 3, 95, 0, 94, 2, 87, 
    7, 74, 3, 80, 4, 81, 1, 93, 6, 81, 0, 71, 8,  1, 5, 38, 2, 15, 
    4, 54, 1, 17, 7, 48, 8, 73, 2, 49, 5, 95, 3, 34, 6, 51, 0, 18, 
    0, 42, 4, 73, 3,  5, 7, 40, 6, 85, 5, 41, 1, 61, 2, 64, 8, 28
  };
  const int q8686[] = {
    9, 9, // Number of jobs and machines
    5, 79, 6, 40, 3,  7, 0, 19, 1, 25, 8, 49, 2, 23, 7, 95, 4, 78, 
    5, 63, 6, 58, 2, 72, 8, 55, 0, 78, 4, 76, 1, 64, 3, 29, 7, 14, 
    3, 11, 8, 39, 5, 46, 4,  6, 0, 27, 2, 46, 7, 53, 1, 10, 6, 60, 
    8, 54, 2, 59, 7, 38, 1, 63, 4, 58, 3, 85, 6, 30, 5, 81, 0,  3, 
    6, 31, 1, 34, 0, 12, 4, 50, 7,  1, 3, 48, 5, 63, 2, 68, 8,  5, 
    7, 42, 8, 28, 0, 94, 6, 51, 5, 57, 1,  4, 3, 47, 2, 74, 4, 64, 
    3, 23, 5, 60, 8, 56, 1, 33, 4, 79, 7, 97, 6, 58, 2, 76, 0,  5, 
    6, 98, 5, 27, 0, 96, 7, 52, 8, 71, 4, 87, 1, 86, 3, 64, 2, 29, 
    6, 47, 0, 19, 5, 80, 2, 35, 7, 17, 3, 26, 1, 84, 8, 53, 4, 89
  };
  const int q8687[] = {
    9, 9, // Number of jobs and machines
    4, 83, 8, 33, 2, 48, 3, 83, 0, 19, 7, 60, 5, 25, 1, 14, 6,  3, 
    4, 89, 1, 23, 3, 68, 6, 67, 8, 41, 7, 56, 5, 53, 0, 67, 2, 99, 
    6, 29, 0, 85, 5, 26, 2, 64, 8, 13, 1, 41, 3, 74, 4, 18, 7, 55, 
    8, 69, 5, 13, 4, 51, 1, 72, 2, 59, 0, 35, 6,  5, 7,  9, 3, 72, 
    6, 22, 1, 60, 2, 39, 0, 94, 5, 30, 3,  9, 4, 10, 8, 60, 7, 54, 
    7, 23, 5, 35, 4, 42, 1, 79, 8, 24, 0, 58, 3, 34, 6, 23, 2, 57, 
    3, 66, 1, 28, 5, 82, 6, 65, 7, 80, 2, 32, 0, 43, 8, 52, 4, 58, 
    1, 63, 0, 41, 5, 80, 6, 25, 8, 85, 7, 35, 4, 94, 3, 42, 2,  1, 
    8, 39, 3, 90, 0, 25, 1, 22, 6, 99, 4, 54, 5, 59, 7, 91, 2, 73
  };
  const int q8688[] = {
    9, 9, // Number of jobs and machines
    6, 76, 7, 34, 3,  6, 8, 29, 5, 81, 0, 11, 2, 72, 4, 10, 1, 52, 
    6, 33, 0, 26, 4, 74, 1, 98, 2, 68, 8, 33, 3, 35, 7, 17, 5, 81, 
    7, 23, 3, 39, 6, 16, 0,  4, 8, 78, 4, 93, 1, 81, 2, 86, 5, 39, 
    1, 72, 6,  6, 7,  9, 0, 28, 2, 28, 4, 83, 5, 85, 8,  8, 3, 10, 
    4, 74, 1, 30, 7, 70, 0, 35, 6, 31, 5, 48, 8, 11, 2, 47, 3, 62, 
    0, 95, 7, 38, 8, 76, 6,  1, 5, 29, 4, 56, 3, 73, 1, 20, 2, 66, 
    8,  1, 7, 37, 1, 83, 3, 52, 2, 32, 0, 17, 4, 85, 5,  3, 6, 76, 
    7, 28, 2, 38, 5, 85, 1, 52, 8, 39, 0, 10, 4,  2, 3, 81, 6, 12, 
    1, 37, 2, 93, 3, 46, 7, 10, 8, 91, 4, 31, 0, 98, 6, 54, 5, 61
  };
  const int q8689[] = {
    9, 9, // Number of jobs and machines
    0, 57, 8, 78, 3, 81, 5, 67, 1, 34, 7,  5, 2, 59, 4, 22, 6, 71, 
    4, 53, 2, 59, 1, 47, 8, 25, 7, 74, 5, 54, 0, 69, 6, 27, 3, 22, 
    7,  9, 8,  2, 0, 25, 4, 47, 3, 87, 6, 32, 2, 40, 1, 96, 5, 50, 
    2, 11, 8, 92, 5, 78, 3, 97, 4,  7, 0, 33, 1, 78, 6, 10, 7, 10, 
    6, 23, 7, 19, 1, 45, 8, 85, 4, 44, 5, 53, 3, 46, 0, 38, 2, 94, 
    6, 47, 2, 12, 7, 62, 4, 27, 1, 94, 5, 71, 8, 15, 0, 87, 3, 24, 
    0, 69, 8, 87, 7, 41, 5, 98, 6, 57, 2, 88, 4, 51, 1, 26, 3, 24, 
    8,  6, 7, 89, 2, 51, 4, 14, 1, 15, 0, 44, 3, 67, 5, 55, 6, 38, 
    6, 42, 4, 82, 7, 44, 5, 71, 3, 97, 1,  3, 0, 35, 2, 90, 8, 11
  };
  const int q8690[] = {
    9, 9, // Number of jobs and machines
    2, 91, 4, 43, 6, 14, 0, 17, 5, 56, 1, 15, 3, 93, 8, 13, 7, 40, 
    3, 15, 1, 65, 2, 26, 4, 80, 0, 96, 8, 95, 5, 10, 7, 38, 6,  5, 
    8, 37, 7, 17, 3,  9, 5, 84, 2, 35, 4, 27, 6, 45, 1, 50, 0, 67, 
    3, 23, 7, 47, 6, 20, 0, 52, 5, 57, 2, 11, 8, 61, 4, 90, 1, 52, 
    3, 91, 1, 68, 7, 97, 2, 58, 0, 76, 5, 42, 8, 89, 4, 62, 6, 87, 
    1, 74, 8, 83, 3, 62, 6, 96, 4, 66, 2, 91, 0, 25, 5, 53, 7, 69, 
    6, 33, 8, 43, 2,  6, 1, 80, 3, 50, 5, 66, 0, 42, 4, 29, 7, 77, 
    8, 58, 2,  3, 3, 90, 6, 78, 7, 92, 5, 60, 0, 44, 1, 24, 4,  5, 
    7, 97, 4, 22, 3, 50, 2, 58, 0, 83, 6, 89, 5, 94, 1, 39, 8, 71
  };
  const int q8691[] = {
    9, 9, // Number of jobs and machines
    2, 23, 0,  8, 5, 36, 7, 66, 3, 40, 1, 71, 8, 58, 4,  3, 6,  1, 
    3, 45, 7, 70, 6, 71, 5, 67, 2, 57, 4, 82, 8, 35, 1,  5, 0, 58, 
    3, 70, 1, 74, 0, 36, 4, 58, 5,  4, 7, 84, 6, 89, 2, 81, 8, 43, 
    2, 40, 7, 66, 3, 17, 5,  5, 0, 76, 1, 25, 4, 71, 6, 21, 8, 13, 
    3, 63, 1, 88, 4, 22, 6, 21, 0, 22, 2, 59, 8, 69, 7, 15, 5, 39, 
    6, 79, 4,  3, 2,  2, 8, 92, 0, 65, 1, 79, 7, 82, 3, 76, 5, 53, 
    4, 91, 1, 61, 7, 34, 0, 98, 8, 56, 6,  8, 2, 97, 3, 73, 5, 17, 
    5, 84, 6, 73, 2, 67, 3, 54, 7, 78, 8,  9, 0, 31, 1, 17, 4, 56, 
    0, 15, 8, 91, 2, 72, 6, 11, 4, 27, 3, 89, 7, 55, 1, 88, 5, 85
  };
  const int q8692[] = {
    9, 9, // Number of jobs and machines
    3, 11, 0, 89, 4, 40, 1, 53, 2,  3, 8, 28, 6, 58, 7, 36, 5,  2, 
    3,  2, 1, 31, 4, 32, 0, 50, 7, 14, 8, 51, 2,  8, 6, 95, 5, 35, 
    2, 56, 8, 33, 1, 25, 3, 47, 7, 38, 6, 56, 4, 82, 0, 41, 5, 89, 
    6, 87, 3, 85, 5,  8, 8, 89, 2, 77, 0, 78, 4, 17, 7, 49, 1, 10, 
    4, 84, 1,  2, 2, 32, 7, 93, 6, 59, 8, 43, 0, 83, 5, 27, 3, 24, 
    1, 80, 7, 87, 0, 29, 3, 44, 2, 76, 8, 70, 4,  7, 6, 99, 5, 74, 
    3, 65, 4, 99, 8, 79, 2, 57, 0, 38, 6, 93, 7, 64, 5, 86, 1, 73, 
    7, 97, 6, 23, 8, 97, 3, 48, 4, 53, 0, 21, 5, 46, 2, 19, 1, 88, 
    0, 24, 3, 91, 2, 21, 1, 89, 8, 79, 4, 98, 5, 44, 7, 36, 6, 80
  };
  const int q8693[] = {
    9, 9, // Number of jobs and machines
    6, 28, 4, 50, 0, 47, 8, 52, 3, 94, 1, 98, 7, 29, 2,  5, 5, 14, 
    6, 27, 8, 23, 2, 35, 5, 42, 3, 97, 7, 72, 1, 84, 4, 22, 0,  8, 
    8, 86, 7, 35, 3,  1, 0, 97, 5, 48, 4, 35, 2, 77, 1,  3, 6,  6, 
    2, 66, 6, 35, 4, 36, 5,  1, 1, 17, 8, 15, 7, 97, 0, 69, 3, 42, 
    6, 15, 1, 22, 5, 35, 8, 90, 3, 97, 0, 44, 4, 67, 7, 25, 2, 33, 
    2, 20, 0, 70, 4, 98, 1, 47, 5, 29, 7, 71, 8, 59, 6,  2, 3,  6, 
    6, 20, 4, 14, 3, 81, 8, 11, 0, 60, 7, 12, 2, 54, 5, 22, 1, 98, 
    5, 35, 2, 95, 0, 33, 3, 20, 4, 90, 6, 49, 7, 76, 8, 13, 1, 83, 
    4, 48, 5, 20, 7, 23, 6, 20, 3, 30, 0, 39, 2, 89, 1, 38, 8, 95
  };
  const int q8694[] = {
    9, 9, // Number of jobs and machines
    5, 73, 7, 72, 2, 45, 6,  7, 8, 76, 1, 21, 4, 25, 3, 44, 0, 52, 
    2, 81, 3, 51, 8, 76, 5, 73, 7, 44, 6, 37, 4, 59, 0, 85, 1, 87, 
    0, 95, 1, 53, 7, 84, 4, 28, 2, 23, 5, 64, 6, 66, 3, 11, 8, 71, 
    4, 90, 6, 91, 0, 29, 5, 88, 2, 94, 3, 60, 7, 14, 1, 28, 8, 40, 
    8, 87, 3, 37, 1, 45, 5, 69, 4, 16, 7, 67, 0, 43, 2, 81, 6, 62, 
    8, 83, 0, 49, 1, 52, 3, 51, 6, 90, 4, 55, 7, 92, 2,  8, 5, 11, 
    5, 69, 1, 97, 0,  4, 3, 76, 2, 68, 7, 79, 6, 43, 4, 62, 8, 17, 
    3, 21, 2, 32, 4, 46, 0, 13, 6, 11, 7, 41, 8, 34, 1, 85, 5, 61, 
    3, 88, 1, 48, 0, 18, 7, 83, 4, 85, 2, 14, 6, 39, 8, 98, 5, 27
  };
  const int q8695[] = {
    9, 9, // Number of jobs and machines
    1, 67, 8, 16, 5, 17, 0, 79, 6, 91, 3, 37, 4, 53, 7,  4, 2, 73, 
    3, 13, 6,  5, 8, 57, 4, 93, 0, 75, 1,  6, 5, 40, 7, 20, 2,  6, 
    0, 11, 5, 88, 8, 11, 2, 34, 3, 58, 6, 30, 1, 90, 7, 11, 4, 93, 
    5, 66, 0, 92, 3, 74, 1, 73, 4, 77, 2, 98, 8,  5, 7, 23, 6,  6, 
    2, 86, 8, 30, 3, 78, 6, 17, 1, 85, 0, 87, 4, 19, 5, 31, 7, 62, 
    8, 26, 7, 91, 1, 18, 4, 82, 5, 96, 6, 14, 2, 17, 0, 79, 3, 80, 
    0, 45, 2, 97, 4, 54, 3, 22, 5, 68, 6,  7, 7, 95, 1,  4, 8, 88, 
    6, 91, 8, 99, 5, 73, 1, 37, 3, 33, 7, 91, 4, 90, 2, 83, 0, 21, 
    5, 25, 7, 46, 8, 13, 6, 19, 3, 39, 2, 10, 4, 47, 1, 10, 0, 19
  };
  const int q8696[] = {
    9, 9, // Number of jobs and machines
    2, 93, 1,  5, 8, 42, 0, 80, 7, 75, 3, 94, 5, 92, 6, 47, 4, 87, 
    5, 53, 7, 97, 3, 85, 4, 88, 1,  7, 0, 50, 6, 30, 8, 22, 2, 90, 
    0, 61, 8, 62, 7, 66, 4, 50, 2, 63, 6,  4, 5, 85, 1,  6, 3, 22, 
    3, 52, 5, 30, 4, 20, 1, 57, 8, 19, 7,  4, 0, 50, 6, 59, 2, 85, 
    7, 83, 1, 53, 6, 30, 2, 82, 5, 67, 3, 15, 0, 35, 8, 81, 4, 55, 
    3, 80, 6, 53, 7,  4, 4, 61, 5, 16, 2, 74, 0, 81, 1, 54, 8,  8, 
    5, 41, 8,  1, 7, 63, 4, 59, 0, 68, 2, 29, 1, 86, 6,  6, 3, 36, 
    3, 84, 4, 41, 2, 30, 5, 70, 6, 67, 8, 73, 1, 68, 0, 43, 7, 91, 
    0, 54, 4, 11, 5, 76, 7, 90, 6, 66, 2, 46, 1, 83, 3, 32, 8, 94
  };
  const int q8697[] = {
    9, 9, // Number of jobs and machines
    2, 79, 1, 57, 8, 25, 5, 99, 7, 73, 6, 78, 0, 43, 4, 19, 3, 42, 
    7,  9, 1, 31, 8, 47, 3, 32, 4, 12, 5, 79, 2, 92, 6, 19, 0, 74, 
    0, 20, 2, 24, 4,  9, 5, 24, 8, 43, 3, 65, 1, 30, 7,  7, 6, 87, 
    3, 18, 7, 14, 1,  9, 8, 34, 4, 19, 2, 93, 5, 32, 0, 81, 6, 12, 
    8, 36, 1, 99, 5,  2, 6, 39, 2, 18, 4,  6, 0,  5, 3, 52, 7, 21, 
    8, 29, 6, 85, 5, 70, 7, 69, 1,  3, 2,  9, 3, 12, 0, 18, 4, 58, 
    4, 41, 6, 52, 8, 27, 5, 94, 7,  6, 3, 12, 0, 59, 1, 30, 2,  3, 
    3, 41, 7, 75, 8, 47, 5, 28, 2, 57, 1, 17, 0, 45, 6, 91, 4,  8, 
    4, 33, 1, 66, 8, 12, 3, 37, 6, 10, 7, 29, 5, 58, 0, 57, 2, 82
  };
  const int q8698[] = {
    9, 9, // Number of jobs and machines
    6, 21, 7, 94, 0, 11, 1, 94, 2, 18, 8, 50, 4, 21, 3, 12, 5,  3, 
    5, 78, 2, 68, 6, 57, 8, 61, 1, 70, 4, 70, 7, 16, 0, 68, 3, 40, 
    3, 90, 6, 96, 4, 68, 7, 30, 2, 24, 8, 49, 5, 40, 1,  5, 0,  3, 
    5, 28, 8, 62, 4, 89, 0, 42, 3, 59, 6, 38, 2,  8, 1, 79, 7, 11, 
    8, 69, 5, 62, 2, 71, 6, 46, 4, 10, 7, 45, 0, 82, 3, 65, 1, 59, 
    4, 91, 8, 68, 6, 36, 2, 60, 3, 24, 1, 22, 7, 28, 5, 29, 0, 17, 
    5, 62, 6, 57, 3, 64, 0, 27, 2, 16, 4, 12, 1, 48, 7,  7, 8, 72, 
    2,  6, 6, 49, 5, 63, 7, 13, 8, 11, 0, 75, 1,  7, 3,  5, 4, 47, 
    8, 67, 4, 47, 1, 55, 6, 29, 5, 29, 3, 12, 7, 70, 0, 27, 2, 27
  };
  const int q8699[] = {
    9, 9, // Number of jobs and machines
    2, 97, 0, 66, 4, 18, 6,  3, 7, 80, 8, 87, 5, 51, 1, 52, 3, 68, 
    4, 88, 1, 95, 6, 77, 7, 95, 8, 34, 2, 72, 0, 80, 5, 41, 3, 25, 
    8, 76, 0, 64, 6, 45, 3, 90, 2, 11, 1, 29, 4, 10, 7, 50, 5, 56, 
    8,  3, 6, 95, 7, 28, 0,  8, 2, 84, 5, 63, 4, 93, 3, 87, 1,  1, 
    5, 54, 3, 95, 4, 13, 1, 93, 6,  5, 7, 49, 2, 32, 0, 74, 8, 13, 
    7,  1, 5, 68, 8, 59, 4, 40, 0, 95, 1, 33, 6,  8, 3,  3, 2, 18, 
    1, 50, 7, 23, 2, 18, 3, 36, 6, 66, 0, 48, 5, 59, 8,  8, 4, 35, 
    8, 51, 3, 56, 0, 64, 7, 39, 4, 64, 5,  8, 1, 53, 2,  2, 6, 48, 
    8, 47, 2, 70, 6, 75, 0, 68, 3, 80, 4, 97, 7, 34, 1, 85, 5, 34
  };
  const int q8700[] = {
    9, 9, // Number of jobs and machines
    2, 85, 4, 96, 8, 69, 5, 55, 3, 68, 1, 59, 6, 10, 0, 84, 7, 85, 
    3, 46, 5, 78, 4, 37, 1, 50, 0, 54, 7, 24, 8, 32, 2, 57, 6, 10, 
    6,  8, 0, 86, 1, 11, 3, 61, 7, 43, 2, 96, 8, 48, 5, 44, 4, 32, 
    1,  3, 5, 44, 0, 66, 4, 38, 6, 27, 8, 11, 2, 94, 3, 17, 7, 36, 
    1, 45, 8, 84, 2, 10, 5, 22, 7, 77, 4, 94, 6,  2, 0, 53, 3, 45, 
    8, 29, 1, 57, 2, 90, 5, 13, 7, 79, 3, 97, 0, 13, 4, 49, 6, 18, 
    1, 85, 7, 94, 4, 68, 6, 51, 2, 94, 0, 73, 8, 17, 3,  9, 5, 23, 
    7, 72, 3, 59, 0, 19, 8, 57, 6, 38, 4, 69, 2, 87, 5, 19, 1, 39, 
    3, 36, 6, 87, 8, 16, 0, 35, 1, 78, 4, 29, 5, 68, 7, 29, 2, 82
  };
  const int q8701[] = {
    9, 9, // Number of jobs and machines
    4, 49, 6, 93, 7, 24, 1, 26, 0,  5, 2, 71, 8, 35, 3, 34, 5,  9, 
    7, 80, 8, 80, 0, 45, 6,  5, 1, 96, 2, 15, 3, 38, 5,  2, 4, 38, 
    5, 52, 3, 22, 6, 67, 1, 83, 4, 72, 7, 18, 2, 67, 0, 16, 8, 99, 
    1, 79, 5, 33, 3, 24, 6, 95, 7, 79, 8, 74, 4, 37, 2, 49, 0, 72, 
    7, 43, 1, 14, 8, 82, 2, 98, 6, 99, 5, 62, 3, 51, 0, 64, 4, 81, 
    3, 72, 0, 58, 2, 55, 5, 82, 8, 38, 4, 73, 6,  4, 7, 71, 1, 29, 
    1,  3, 6, 42, 0, 30, 4, 63, 7, 49, 8, 39, 5, 10, 2, 14, 3, 49, 
    5, 97, 4, 13, 0, 78, 8, 18, 1, 91, 6, 87, 2, 40, 3, 87, 7,  5, 
    2, 60, 3, 64, 4, 42, 6, 82, 5,  6, 7, 60, 8,  2, 1,  3, 0, 17
  };
  const int q8702[] = {
    9, 9, // Number of jobs and machines
    2, 31, 5, 21, 0,  3, 6, 15, 1, 27, 3, 44, 8, 11, 7, 40, 4, 95, 
    5, 59, 0, 16, 4,  5, 8, 13, 1, 79, 2, 55, 6, 62, 3, 28, 7, 26, 
    2, 71, 3, 75, 8,  4, 0, 11, 5, 43, 1, 43, 4, 48, 7, 82, 6, 24, 
    4,  2, 2, 25, 3, 54, 7,  8, 5, 78, 1, 61, 8, 33, 0, 65, 6, 43, 
    4, 31, 0, 34, 1, 89, 5, 96, 3, 29, 2, 62, 7, 14, 8, 44, 6, 95, 
    1,  3, 3,  9, 6,  2, 7, 89, 4, 19, 8, 86, 5,  6, 2, 43, 0,  5, 
    7, 38, 3, 42, 1,  3, 5, 78, 4, 70, 8, 17, 0, 30, 2, 68, 6, 19, 
    1, 47, 8,  5, 6, 28, 5, 47, 3, 98, 2, 53, 0, 40, 4, 19, 7, 63, 
    5, 72, 3, 59, 2,  2, 7, 86, 6, 66, 1, 72, 0, 24, 4, 58, 8, 54
  };
  const int q8703[] = {
    9, 9, // Number of jobs and machines
    7, 62, 8, 45, 6, 61, 2, 40, 1, 94, 4, 69, 3, 51, 0, 66, 5, 90, 
    7, 29, 1, 55, 8, 14, 6,  4, 2, 78, 3, 99, 5,  9, 4, 77, 0, 25, 
    0, 59, 1, 76, 4, 19, 3, 70, 6, 76, 5, 59, 2, 71, 7, 94, 8, 28, 
    7, 54, 5, 59, 1, 80, 0, 54, 4, 22, 8, 95, 2,  1, 3, 24, 6, 44, 
    2, 91, 3, 85, 6, 36, 1, 16, 8, 76, 4, 72, 5, 92, 7, 56, 0, 28, 
    5, 39, 2, 96, 7, 27, 3,  7, 1, 56, 4, 44, 8, 61, 6, 43, 0, 90, 
    6,  4, 2, 32, 0, 26, 7, 69, 1, 31, 3, 36, 8, 28, 5, 51, 4,  6, 
    3,  8, 7, 44, 5, 80, 1, 60, 4, 20, 2, 23, 0, 38, 6, 68, 8, 73, 
    1, 20, 8, 31, 3, 58, 7, 41, 2, 15, 6, 39, 4, 66, 0, 82, 5, 82
  };
  const int q8704[] = {
    9, 9, // Number of jobs and machines
    6, 74, 8, 18, 3,  4, 2, 84, 5,  2, 4, 38, 7, 10, 0, 52, 1, 63, 
    0, 95, 7, 29, 6, 56, 2, 69, 4, 41, 5, 82, 3, 86, 8, 53, 1, 24, 
    3, 62, 0, 27, 8, 31, 1, 82, 4, 76, 6, 26, 5, 11, 2, 13, 7, 42, 
    2, 67, 0, 78, 3, 80, 1, 17, 6, 41, 5, 23, 4, 22, 8, 33, 7, 11, 
    4, 78, 6, 32, 1,  8, 7, 64, 8, 80, 3, 16, 5, 73, 2, 97, 0, 38, 
    5, 26, 0, 29, 1, 85, 8, 87, 7, 79, 4, 70, 6, 17, 2, 91, 3, 29, 
    4, 58, 8, 95, 1, 61, 7, 44, 2, 28, 6,  3, 5, 50, 3, 27, 0, 42, 
    1, 90, 8, 50, 5, 21, 3, 67, 7, 35, 4, 14, 0, 95, 2,  5, 6, 92, 
    2, 22, 0, 36, 5, 62, 4, 72, 8, 51, 3, 56, 1, 51, 7,  6, 6, 76
  };
  const int q8705[] = {
    9, 9, // Number of jobs and machines
    8, 48, 2, 66, 6, 75, 7, 52, 0, 26, 1, 53, 4, 70, 5, 70, 3, 75, 
    4, 62, 7, 66, 8, 70, 0, 67, 2, 36, 5, 42, 1, 58, 3, 76, 6, 74, 
    4, 32, 6, 18, 5, 38, 0,  6, 8, 40, 3, 78, 2, 13, 7, 51, 1, 52, 
    7, 93, 2,  4, 5, 45, 1, 10, 3, 34, 0, 71, 8, 85, 4, 35, 6, 97, 
    8, 10, 7, 19, 6, 12, 2, 13, 1, 76, 0, 75, 4, 92, 3, 14, 5, 86, 
    6, 26, 0, 88, 5, 98, 8, 62, 7, 53, 2, 23, 3, 86, 1, 79, 4, 22, 
    6, 92, 2, 58, 3,  9, 5, 84, 0, 75, 1, 85, 4, 29, 7, 54, 8, 38, 
    5, 17, 6, 73, 0, 76, 3, 80, 1, 93, 2, 61, 4, 28, 7, 61, 8, 52, 
    2, 69, 5,  9, 1, 43, 4, 48, 8, 57, 0, 27, 6, 29, 3, 13, 7,  8
  };
  const int q8706[] = {
    9, 9, // Number of jobs and machines
    6, 95, 1, 45, 2, 22, 5, 34, 0,  8, 4, 53, 7, 60, 8, 74, 3, 40, 
    1, 21, 3, 99, 6, 93, 0, 50, 5, 68, 7, 66, 2, 73, 8, 46, 4, 27, 
    4, 88, 8, 41, 1, 81, 5, 11, 2, 68, 7, 19, 6,  1, 3, 74, 0, 11, 
    2, 81, 5, 19, 7, 25, 1, 49, 8, 29, 0, 34, 6, 38, 4, 39, 3, 73, 
    6, 14, 3, 50, 0, 77, 2, 76, 5, 81, 8,  5, 7, 28, 1, 69, 4, 39, 
    1, 97, 5, 67, 3, 38, 0, 38, 2, 46, 7, 76, 8, 93, 4, 64, 6, 35, 
    8, 29, 6, 55, 7, 46, 5, 91, 4, 12, 3, 62, 0, 72, 2, 60, 1, 20, 
    6, 14, 5, 51, 1, 33, 8, 13, 7, 35, 0, 93, 4, 23, 2, 43, 3, 12, 
    7, 52, 6, 10, 8, 72, 1, 38, 4, 77, 3, 56, 5, 52, 0, 89, 2,  6
  };
  const int q8707[] = {
    9, 9, // Number of jobs and machines
    1, 37, 5,  1, 6,  5, 8, 55, 2, 96, 7, 95, 3, 92, 4, 41, 0, 45, 
    8, 21, 7, 93, 3, 30, 0, 82, 2, 22, 5, 11, 6,  4, 1, 36, 4, 26, 
    3, 98, 7, 39, 0, 56, 2,  3, 1, 83, 4, 81, 6,  7, 8, 67, 5,  8, 
    1, 81, 8, 59, 6, 58, 4, 89, 0, 94, 3, 84, 5, 18, 7, 32, 2, 94, 
    6, 95, 8, 25, 5, 98, 0, 12, 2, 31, 7, 70, 1, 27, 3, 17, 4, 54, 
    3, 63, 7, 51, 0, 77, 8, 84, 1, 56, 4, 21, 5, 39, 6,  5, 2, 96, 
    6, 71, 7, 74, 3, 49, 5, 94, 1, 12, 4, 25, 8, 65, 0, 22, 2, 72, 
    3, 30, 6, 42, 4, 30, 7, 21, 8, 78, 1, 26, 2, 80, 0, 18, 5, 37, 
    1, 72, 8, 38, 4,  7, 7,  8, 2, 50, 0, 26, 6,  5, 5, 47, 3, 94
  };
  const int q8708[] = {
    9, 9, // Number of jobs and machines
    3, 46, 8, 96, 6, 47, 4, 79, 5, 68, 0, 29, 1, 40, 2,  9, 7, 62, 
    3, 51, 8, 29, 5, 46, 2, 72, 6, 18, 1, 92, 4, 78, 0, 89, 7, 25, 
    3, 36, 0, 86, 7, 44, 6, 41, 4, 13, 5, 84, 8, 28, 2, 56, 1, 99, 
    0,  3, 4, 98, 2, 51, 1, 50, 7, 32, 5, 27, 6, 20, 3, 27, 8, 87, 
    4, 21, 6, 97, 7, 46, 0, 56, 5, 85, 3, 93, 1, 41, 2, 94, 8, 54, 
    4, 33, 3, 21, 7, 46, 6, 54, 2, 46, 5, 69, 8, 85, 0, 94, 1, 40, 
    7, 22, 4,  9, 3, 71, 2, 55, 0, 35, 6, 92, 1, 29, 8, 57, 5, 76, 
    0, 62, 3,  1, 8, 80, 1, 90, 2, 65, 5, 16, 7, 88, 4, 58, 6, 56, 
    7, 10, 0, 87, 3, 41, 8, 36, 2, 22, 1, 35, 4, 38, 5, 83, 6, 70
  };
  const int q8709[] = {
    9, 9, // Number of jobs and machines
    8, 36, 6,  5, 2, 20, 4, 54, 7, 84, 3, 69, 5, 32, 0, 52, 1, 79, 
    1, 64, 7, 52, 5, 29, 3, 20, 0, 40, 4, 61, 8, 99, 2, 41, 6, 10, 
    3, 39, 2, 55, 4, 20, 8, 14, 1, 75, 6,  2, 0, 20, 7,  9, 5, 92, 
    3, 48, 0, 41, 6, 17, 7, 24, 5, 48, 1, 30, 2, 23, 4, 88, 8, 28, 
    7, 17, 5, 24, 0, 12, 1, 75, 2, 71, 4, 91, 8, 58, 6, 65, 3, 13, 
    8, 90, 5, 32, 7, 20, 3,  8, 6, 98, 4, 21, 0, 10, 1, 99, 2, 62, 
    2, 95, 0, 52, 6, 68, 3, 73, 4, 66, 7, 42, 5, 78, 8, 34, 1, 22, 
    1, 18, 2,  6, 8, 75, 7, 38, 5, 82, 6, 16, 0, 41, 4, 31, 3, 43, 
    7, 66, 6, 80, 2, 45, 8, 86, 5, 26, 1, 53, 0, 35, 4, 27, 3, 68
  };
  const int q8710[] = {
    9, 9, // Number of jobs and machines
    3, 66, 0, 80, 4, 55, 6, 16, 7,  1, 1, 44, 2, 48, 8, 88, 5, 91, 
    1, 56, 8, 72, 7, 22, 0,  2, 2, 79, 4, 85, 3, 94, 5, 12, 6, 53, 
    3, 47, 6, 31, 1, 55, 5, 70, 2, 18, 7,  8, 0, 93, 8, 94, 4, 11, 
    0, 39, 8, 16, 2, 28, 4,  1, 6, 41, 5, 12, 1, 69, 7, 15, 3, 75, 
    2, 37, 0, 75, 4, 93, 6,  3, 7, 48, 1, 19, 5, 67, 8, 16, 3, 26, 
    4,  4, 8, 63, 5, 87, 1, 76, 3, 40, 6, 73, 2, 43, 7, 86, 0, 99, 
    0, 31, 1, 30, 8, 40, 7, 51, 3, 84, 4, 80, 6, 94, 5, 29, 2, 90, 
    7, 11, 6, 43, 2, 42, 8,  4, 5, 66, 0, 58, 1, 81, 3, 13, 4, 78, 
    0, 33, 8, 33, 7, 74, 5, 10, 1, 70, 3, 55, 2, 72, 4,  5, 6, 95
  };
  const int q8711[] = {
    9, 9, // Number of jobs and machines
    3, 72, 8, 40, 1, 11, 0, 90, 5, 87, 6,  3, 7, 37, 2, 67, 4, 71, 
    8, 97, 4, 65, 1, 16, 2, 33, 3, 90, 7, 13, 0, 86, 5,  9, 6, 69, 
    6, 68, 2, 79, 5, 59, 3, 23, 8, 80, 7,  7, 4, 32, 0, 39, 1, 55, 
    2, 17, 1, 45, 0, 98, 3, 32, 5,  7, 6, 73, 4, 36, 8, 70, 7, 62, 
    7, 92, 3, 35, 2,  3, 1, 98, 5, 91, 0, 68, 4, 55, 8, 10, 6, 98, 
    0, 50, 7, 47, 4, 56, 8, 56, 2, 39, 6, 74, 1, 22, 5, 48, 3, 61, 
    6, 55, 3, 56, 0, 34, 7, 35, 8, 27, 5, 91, 4, 74, 1, 71, 2, 34, 
    5, 10, 6, 85, 4, 42, 7, 69, 1, 22, 0, 10, 2, 25, 3, 53, 8, 58, 
    8, 33, 0, 13, 1, 84, 3, 63, 4, 94, 2, 45, 6, 75, 7,  2, 5, 24
  };
  const int q8712[] = {
    9, 9, // Number of jobs and machines
    1,  9, 5, 64, 7,  1, 3, 37, 8, 12, 4, 79, 2, 23, 6, 72, 0, 51, 
    5, 75, 4, 56, 8, 97, 7, 42, 6, 83, 0, 46, 3, 58, 1,  9, 2,  5, 
    5, 52, 7, 45, 4, 43, 2, 83, 0, 89, 8, 61, 6, 80, 1, 53, 3, 43, 
    8, 29, 7, 99, 5, 27, 2, 13, 1, 60, 4, 34, 3, 32, 6, 48, 0, 11, 
    4, 26, 3, 51, 6, 95, 2, 54, 1, 27, 7, 36, 0, 55, 8, 98, 5, 82, 
    1, 40, 4, 26, 3, 70, 2, 95, 8, 79, 6,  9, 5, 22, 7, 94, 0, 10, 
    7, 48, 3, 67, 2, 80, 5,  9, 8, 45, 0, 46, 4, 78, 1, 56, 6,  2, 
    8, 19, 6, 96, 2, 29, 5, 69, 4, 73, 3, 32, 1, 66, 0, 89, 7, 74, 
    1,  1, 4, 58, 6, 22, 7, 74, 8, 43, 5, 70, 0,  7, 2, 67, 3, 40
  };
  const int q8713[] = {
    9, 9, // Number of jobs and machines
    3, 86, 5, 46, 8, 57, 6, 52, 2, 26, 1, 43, 4, 83, 7, 65, 0, 17, 
    7,  4, 8, 22, 4, 40, 6, 27, 5,  3, 2, 82, 1, 26, 3, 29, 0, 81, 
    8, 15, 3, 21, 7, 53, 6, 10, 0, 54, 5, 43, 1,  5, 4, 86, 2, 32, 
    8, 85, 1, 91, 3, 14, 5, 68, 2, 25, 4, 19, 7, 85, 0, 80, 6, 63, 
    0, 49, 3, 72, 5, 80, 8, 66, 1, 67, 7,  9, 2, 57, 6, 22, 4, 76, 
    2, 48, 1, 78, 0, 75, 8, 77, 5, 75, 4, 74, 7, 92, 6, 99, 3, 12, 
    2, 66, 8, 12, 7, 13, 1, 88, 5, 69, 0, 55, 6, 44, 4, 75, 3, 54, 
    4, 34, 0,  4, 1, 30, 7, 57, 3, 18, 8, 34, 6,  5, 2, 49, 5, 89, 
    5, 93, 2, 77, 7, 11, 3, 96, 1, 87, 4, 48, 6, 52, 0, 35, 8, 46
  };
  const int q8714[] = {
    9, 9, // Number of jobs and machines
    4, 13, 3, 67, 7, 93, 8, 55, 6, 97, 5, 39, 2, 67, 1, 32, 0,  6, 
    4, 90, 6, 37, 8,  2, 0, 81, 1, 81, 3, 77, 5, 23, 7, 82, 2,  2, 
    1, 58, 2,  2, 8, 61, 7, 89, 3, 95, 0, 39, 4, 90, 5, 12, 6, 77, 
    6, 35, 2, 30, 1, 22, 7, 65, 8, 93, 4, 62, 5, 58, 0,  7, 3, 85, 
    4, 92, 6, 44, 8, 72, 3, 46, 0, 47, 1, 72, 7,  5, 5, 17, 2, 13, 
    8, 94, 4, 42, 0, 65, 5, 15, 7, 30, 1, 44, 2, 72, 6, 94, 3, 34, 
    0, 50, 2, 74, 8, 36, 4, 87, 7, 14, 6, 69, 5, 79, 1, 28, 3, 70, 
    8, 39, 7, 28, 0, 93, 4, 19, 1, 66, 5, 35, 3, 64, 6, 18, 2, 25, 
    7, 35, 8, 81, 1, 10, 4, 51, 3, 64, 6, 31, 5, 14, 2, 90, 0, 70
  };
  const int q8715[] = {
    9, 9, // Number of jobs and machines
    7, 81, 0, 89, 4, 77, 1, 59, 5, 98, 8, 57, 3, 57, 2, 31, 6, 65, 
    3, 87, 8, 68, 2, 45, 7, 58, 6, 21, 4, 16, 1, 58, 0, 64, 5, 31, 
    1, 26, 3, 79, 8,  1, 4, 84, 0, 20, 6, 52, 7, 33, 5, 77, 2, 68, 
    1, 88, 4, 67, 0, 37, 7, 53, 8, 99, 3, 45, 6, 44, 2,  9, 5, 32, 
    7, 60, 3, 25, 8, 10, 2, 33, 0, 57, 5,  7, 4, 34, 6, 60, 1,  4, 
    2, 91, 5, 24, 3, 36, 8, 36, 4, 56, 0, 91, 6, 56, 7, 22, 1,  9, 
    1, 40, 0, 82, 5, 48, 3, 22, 4, 60, 7, 97, 2, 15, 8, 71, 6,  6, 
    3, 57, 6, 61, 5, 29, 0, 84, 8, 23, 2,  2, 1, 60, 4, 20, 7, 66, 
    6, 85, 0, 11, 7, 75, 2, 66, 5, 48, 3, 39, 1, 37, 8, 17, 4, 80
  };
  const int q8716[] = {
    9, 9, // Number of jobs and machines
    7, 68, 4, 86, 5, 22, 3,  9, 6, 29, 0,  1, 2, 29, 8, 51, 1, 84, 
    5, 24, 8, 28, 2,  7, 0, 16, 6, 86, 3, 13, 1, 85, 7, 89, 4, 84, 
    5, 65, 8, 29, 7, 84, 0, 86, 2,  6, 1, 85, 6,  9, 4, 64, 3, 23, 
    8, 78, 5, 52, 4, 15, 0, 99, 6, 35, 3, 40, 7, 70, 2, 17, 1, 36, 
    1, 24, 2,  3, 0, 54, 5, 37, 4,  3, 6, 73, 8, 39, 7, 62, 3, 13, 
    8, 21, 2, 98, 1, 78, 6, 99, 7, 25, 4, 52, 5, 59, 0, 55, 3, 83, 
    1, 39, 3, 90, 2, 60, 8, 73, 5, 47, 7, 52, 6, 72, 4, 34, 0, 19, 
    2, 66, 0, 79, 7, 56, 6, 94, 8,  4, 4, 77, 5,  5, 1, 28, 3,  4, 
    7, 38, 3, 57, 2, 54, 0,  6, 1, 32, 6, 67, 4, 76, 5, 75, 8, 77
  };
  const int q8717[] = {
    9, 9, // Number of jobs and machines
    5, 27, 7, 63, 6, 65, 3, 54, 8,  8, 2, 46, 4, 68, 0, 46, 1, 32, 
    7, 62, 8, 48, 5, 84, 4, 20, 3, 23, 0, 87, 1, 95, 2, 88, 6, 83, 
    7, 12, 8, 11, 4, 21, 0, 35, 5, 30, 2, 65, 1, 88, 3, 37, 6, 11, 
    6, 99, 1, 66, 7, 40, 0, 50, 3, 85, 2, 14, 8, 94, 5, 42, 4, 93, 
    7, 51, 3, 25, 1, 93, 4, 58, 0,  7, 8, 22, 6, 31, 5, 16, 2, 64, 
    4, 36, 6, 26, 2, 36, 1, 28, 3, 45, 0, 41, 8, 12, 7, 89, 5, 54, 
    6, 12, 4,  5, 8, 72, 2, 91, 7, 30, 3, 78, 1, 45, 5, 85, 0, 71, 
    0, 36, 6, 46, 8, 88, 4, 36, 2, 45, 7, 20, 3, 19, 5, 87, 1, 83, 
    1, 85, 8, 13, 0, 46, 4, 59, 6, 57, 5, 80, 3, 87, 7, 80, 2,  9
  };
  const int q8718[] = {
    9, 9, // Number of jobs and machines
    7, 52, 3, 28, 8, 67, 4, 80, 5,  7, 1, 24, 6, 40, 0,  4, 2,  4, 
    5, 92, 0, 96, 4, 23, 7, 26, 2, 33, 1, 15, 8, 81, 6, 25, 3, 83, 
    3, 72, 2, 56, 8, 24, 7, 20, 4, 72, 0, 21, 5, 41, 1, 22, 6, 46, 
    8, 37, 6, 39, 4, 11, 5, 78, 7, 14, 2, 91, 3, 62, 0, 84, 1, 21, 
    0,  5, 5, 19, 1, 64, 7, 68, 3, 58, 4,  8, 2, 56, 6, 61, 8, 54, 
    8,  8, 0, 12, 2, 99, 7, 63, 1,  7, 4, 90, 6,  4, 3, 86, 5, 85, 
    1, 71, 4, 84, 8,  6, 3,  6, 5, 15, 2,  4, 7, 71, 6, 24, 0, 34, 
    3, 88, 2,  3, 0,  6, 6, 83, 5, 41, 8,  3, 4, 21, 1,  7, 7, 22, 
    3, 59, 4,  1, 7, 59, 8, 95, 5, 19, 6, 71, 2, 99, 1, 95, 0,  7
  };
  const int q8719[] = {
    9, 9, // Number of jobs and machines
    7, 69, 1, 82, 2, 14, 6, 89, 5, 63, 3, 26, 8, 64, 4, 59, 0, 18, 
    8, 48, 7, 14, 2, 24, 1, 67, 5, 17, 4, 28, 0, 73, 6, 65, 3, 16, 
    0, 48, 5,  4, 7, 64, 2,  7, 1, 54, 4, 96, 6, 56, 3,  1, 8, 85, 
    4, 23, 6, 21, 1, 74, 7, 29, 3, 81, 0, 27, 5, 75, 2, 24, 8, 59, 
    5, 40, 0, 48, 4, 45, 2, 24, 3, 43, 6, 58, 7, 77, 1, 21, 8, 22, 
    7, 60, 1, 94, 5, 49, 8, 71, 4, 95, 3, 94, 2, 52, 6, 12, 0, 41, 
    1, 13, 7, 30, 4, 24, 5, 43, 2, 94, 6, 47, 8,  2, 3, 27, 0, 87, 
    4, 96, 8, 73, 2, 65, 1,  9, 0, 41, 5, 41, 6, 11, 3, 83, 7, 49, 
    6, 79, 4, 49, 3, 74, 1, 13, 0, 95, 8, 47, 7, 32, 2,  4, 5, 17
  };
  const int q8720[] = {
    9, 9, // Number of jobs and machines
    6, 68, 3, 77, 8, 46, 0, 73, 4, 87, 5, 45, 2,  7, 7, 61, 1, 25, 
    1, 15, 5, 14, 4, 35, 3, 23, 0, 37, 7, 85, 8, 15, 2, 25, 6, 75, 
    7,  3, 4, 53, 2, 69, 1, 25, 5, 44, 6, 87, 0, 97, 3, 34, 8, 89, 
    5, 22, 1,  3, 8, 55, 2, 34, 4, 13, 0, 18, 7, 49, 3, 98, 6, 47, 
    0, 90, 3, 43, 7, 57, 1, 43, 2,  7, 8,  6, 4, 66, 5, 41, 6, 63, 
    8, 49, 2, 46, 5, 83, 3, 18, 1, 58, 4, 68, 7, 93, 6, 32, 0,  3, 
    1, 57, 6, 75, 0,  1, 7, 84, 5, 27, 3, 53, 2, 81, 8, 23, 4, 39, 
    6, 52, 8, 34, 0, 73, 4, 53, 2, 47, 3, 12, 7, 79, 1, 48, 5, 71, 
    7, 19, 5, 87, 4, 21, 1, 18, 0, 15, 3, 19, 6, 15, 2, 45, 8, 83
  };
  const int q8721[] = {
    9, 9, // Number of jobs and machines
    1, 74, 0, 49, 5, 65, 7, 80, 3, 16, 6, 21, 4,  5, 2, 49, 8, 56, 
    5, 24, 3, 36, 1, 24, 0, 45, 2, 40, 7, 29, 8, 59, 6, 88, 4, 44, 
    0, 61, 2, 49, 6, 92, 8, 16, 1, 89, 5, 37, 3, 82, 4, 71, 7, 59, 
    0, 13, 2, 79, 6, 28, 7, 48, 3, 71, 5,  8, 8, 80, 4, 15, 1, 60, 
    5, 27, 4, 26, 2, 29, 8, 28, 6, 55, 1, 35, 7, 40, 0, 49, 3, 76, 
    8, 11, 2, 35, 1, 85, 6, 68, 3,  7, 5, 18, 7, 19, 4, 26, 0, 77, 
    8, 34, 1, 94, 4, 28, 6, 20, 0, 50, 5, 57, 3, 93, 7, 11, 2, 72, 
    0, 51, 3, 90, 7, 11, 4, 49, 5,  5, 6,  3, 2, 17, 8, 82, 1, 63, 
    0, 88, 8, 78, 6,  8, 1, 84, 4, 21, 7, 72, 2, 20, 3, 51, 5,  9
  };
  const int q8722[] = {
    9, 9, // Number of jobs and machines
    6, 10, 1, 81, 8, 94, 2,  7, 5, 33, 3,  8, 4,  2, 0, 11, 7, 71, 
    7, 48, 8, 89, 4, 97, 2, 82, 0, 72, 6, 96, 1, 73, 5,  4, 3, 29, 
    0, 99, 2, 78, 1, 11, 6, 59, 5, 94, 8, 68, 7, 78, 4, 54, 3, 84, 
    2, 33, 5, 49, 1, 87, 3, 46, 8, 75, 6, 54, 0,  9, 7, 36, 4,  9, 
    5, 29, 4, 42, 1, 88, 3, 52, 6, 37, 2, 30, 8, 79, 0,  9, 7, 71, 
    7, 70, 6, 78, 1, 97, 4, 72, 3, 14, 2, 36, 8, 76, 5, 88, 0, 92, 
    2, 31, 7,  8, 3, 74, 0, 60, 6, 22, 4, 67, 1, 66, 5, 46, 8, 43, 
    1, 27, 0, 66, 2, 75, 7,  4, 8, 79, 3, 92, 5,  8, 4, 75, 6, 38, 
    8, 69, 7, 78, 4, 96, 3, 19, 2, 83, 6, 82, 5, 67, 0, 58, 1, 74
  };
  const int q8723[] = {
    9, 9, // Number of jobs and machines
    0, 48, 3, 78, 5, 29, 8, 26, 1, 76, 7, 14, 6, 35, 4, 17, 2, 28, 
    3, 97, 4, 97, 0, 87, 6, 60, 8, 12, 1, 25, 7, 75, 2,  2, 5, 29, 
    3, 34, 1, 72, 7, 28, 6, 36, 8, 58, 0, 19, 5, 18, 4, 63, 2, 63, 
    3, 52, 4, 99, 2,  1, 8, 19, 1, 90, 6, 35, 5, 32, 7, 78, 0, 71, 
    4, 26, 3, 62, 0, 30, 6, 21, 5, 23, 8, 11, 7, 96, 2, 96, 1,  9, 
    5, 16, 0, 23, 7, 49, 2, 73, 1, 57, 4, 82, 3, 24, 6, 52, 8, 69, 
    2, 93, 4, 13, 8, 21, 1, 45, 3, 40, 5, 97, 7, 84, 6, 22, 0, 81, 
    5, 22, 0, 99, 8, 44, 2, 48, 1, 65, 6,  9, 3, 94, 7, 89, 4, 20, 
    2, 28, 5, 78, 3, 68, 1, 24, 0, 40, 7, 79, 4, 71, 8, 66, 6, 67
  };
  const int q8724[] = {
    9, 9, // Number of jobs and machines
    6, 36, 2, 95, 0, 99, 8, 32, 1, 16, 4, 31, 7, 23, 5, 46, 3, 36, 
    7, 91, 5, 61, 1, 64, 3, 25, 8,  4, 0, 94, 6, 52, 4,  1, 2, 85, 
    0, 52, 3, 56, 4,  1, 7, 72, 5, 83, 1, 26, 2, 13, 8, 90, 6, 49, 
    4,  2, 6, 69, 0, 40, 7,  2, 1, 48, 3, 42, 2, 54, 5, 66, 8, 86, 
    5, 52, 8, 19, 7, 82, 0, 61, 3, 31, 4, 44, 1, 50, 6, 68, 2, 40, 
    1, 16, 7, 25, 5,  5, 3, 63, 6, 73, 4, 94, 8, 56, 0, 67, 2, 41, 
    6, 84, 4, 99, 0,  1, 1, 23, 8, 33, 7, 26, 2, 88, 5, 22, 3, 61, 
    2, 33, 8, 14, 1, 24, 3, 36, 6, 83, 7, 11, 0, 92, 4, 76, 5, 64, 
    1, 40, 3, 41, 2,  9, 4, 52, 8, 67, 6, 70, 0, 27, 7, 10, 5, 83
  };
  const int q8725[] = {
    9, 9, // Number of jobs and machines
    5, 40, 3, 74, 2, 33, 8, 27, 1, 13, 4, 94, 0, 65, 6, 86, 7, 97, 
    3, 68, 7, 34, 0, 59, 5, 15, 1, 87, 8, 97, 6, 67, 2,  5, 4,  9, 
    0, 64, 7, 80, 4, 91, 5, 63, 3, 86, 1, 10, 6, 67, 8, 23, 2, 43, 
    6, 20, 7, 81, 5, 75, 8, 65, 2, 55, 3, 87, 0, 10, 4, 51, 1, 60, 
    2, 45, 7, 46, 8, 92, 0, 14, 4, 55, 5, 24, 6, 41, 1, 19, 3, 59, 
    3, 10, 5, 15, 6, 24, 2, 53, 0, 82, 1, 37, 4, 27, 8, 33, 7, 12, 
    3, 20, 4, 68, 0, 35, 6, 48, 5, 88, 7, 41, 8, 62, 1, 30, 2, 24, 
    1,  5, 3, 92, 7, 69, 5,  1, 6, 86, 0, 41, 8, 47, 2, 46, 4, 74, 
    1, 52, 6, 62, 8, 98, 3, 79, 0, 93, 4, 18, 2, 84, 5,  2, 7, 80
  };
  const int q8726[] = {
    9, 9, // Number of jobs and machines
    2, 98, 8, 32, 5, 89, 1, 79, 6,  2, 3, 12, 4, 79, 7, 16, 0, 33, 
    6, 89, 7, 93, 5, 57, 2, 18, 0, 95, 4, 41, 3, 70, 1, 71, 8, 92, 
    6, 76, 3, 56, 1, 90, 0, 95, 7, 46, 4,  7, 2, 20, 5, 64, 8, 32, 
    3, 80, 8, 60, 1, 81, 6, 40, 7, 50, 5, 16, 4,  6, 2, 26, 0, 58, 
    2, 16, 5, 13, 6, 54, 7, 42, 3,  4, 1, 53, 0, 21, 4,  1, 8, 54, 
    2, 35, 0, 80, 4, 48, 5, 99, 6, 30, 1, 71, 7, 16, 3, 55, 8, 15, 
    2, 78, 0, 60, 8, 62, 1, 38, 4, 76, 5, 83, 6, 94, 7, 41, 3, 12, 
    7, 96, 3, 24, 2, 89, 4, 67, 6, 97, 5, 92, 0, 28, 8,  6, 1, 45, 
    0, 47, 4, 80, 3, 75, 5,  4, 2, 83, 1, 27, 6, 16, 8,  2, 7, 81
  };
  const int q8727[] = {
    9, 9, // Number of jobs and machines
    2, 11, 8, 53, 5, 97, 4, 54, 6, 41, 1, 63, 7, 24, 0,  8, 3, 32, 
    6, 98, 8, 37, 2,  9, 7, 42, 4, 88, 5, 19, 1, 41, 0, 76, 3,  1, 
    4,  6, 7, 95, 8, 88, 2, 86, 6, 63, 1, 64, 3, 13, 0, 38, 5, 20, 
    0, 58, 3, 40, 7, 13, 8,  9, 1, 46, 4, 95, 2, 70, 5, 66, 6, 80, 
    2, 35, 3, 44, 5, 25, 0, 64, 6, 59, 4, 94, 8, 98, 1,  5, 7, 94, 
    6, 97, 7, 86, 1, 53, 4, 58, 0, 27, 5, 62, 2, 92, 8,  3, 3, 76, 
    4, 11, 3, 25, 6, 11, 2, 62, 5, 50, 7, 37, 8, 51, 1,  7, 0, 53, 
    8, 87, 2, 16, 1, 72, 5, 30, 4, 16, 0, 43, 7, 73, 3, 96, 6, 24, 
    1, 91, 6, 87, 4, 50, 3, 21, 0, 41, 5, 58, 2, 20, 8, 19, 7,  4
  };
  const int q8728[] = {
    9, 9, // Number of jobs and machines
    7, 16, 1, 20, 8, 37, 3, 74, 5, 52, 0, 32, 4, 93, 6, 55, 2, 28, 
    8, 60, 2, 93, 3, 61, 1, 62, 5, 83, 6, 86, 4, 49, 0, 49, 7, 61, 
    5, 41, 4, 87, 3, 50, 2, 76, 0, 53, 8,  4, 7, 97, 6, 81, 1, 48, 
    8,  2, 0, 40, 4, 64, 2, 39, 1, 89, 7, 95, 6, 81, 5, 97, 3, 22, 
    3, 32, 2, 33, 5, 10, 7, 13, 6, 84, 1, 22, 4, 36, 8, 84, 0, 21, 
    0,  5, 3, 83, 1, 36, 5, 29, 2, 53, 7, 11, 6, 88, 4, 51, 8, 32, 
    7, 79, 0,  9, 3, 18, 8, 54, 2, 66, 4,  1, 5, 17, 1, 31, 6, 84, 
    4, 25, 8,  7, 1, 52, 6, 51, 7,  7, 0,  7, 2,  4, 3, 87, 5, 52, 
    3, 67, 7, 50, 6, 36, 5, 60, 0, 78, 2, 17, 8, 70, 1, 84, 4, 64
  };
  const int q8729[] = {
    9, 9, // Number of jobs and machines
    0, 77, 7, 59, 8, 70, 1, 72, 4, 70, 2, 37, 3, 30, 5,  3, 6, 84, 
    5, 79, 0, 62, 7, 44, 1,  4, 8, 48, 2, 91, 3, 16, 4, 69, 6, 67, 
    6, 89, 5, 55, 7, 90, 3, 98, 8, 65, 2, 35, 0, 59, 4, 95, 1, 22, 
    0, 20, 1, 24, 2, 67, 5, 53, 8, 49, 4, 70, 7, 77, 6, 79, 3, 10, 
    3, 42, 7, 37, 5, 56, 1, 11, 4, 57, 2, 32, 8,  7, 0, 27, 6, 85, 
    4,  8, 6, 88, 5, 26, 0, 25, 3, 70, 2, 50, 1, 53, 7, 90, 8, 45, 
    8,  1, 4, 92, 3, 47, 0, 90, 6, 10, 1, 10, 2, 14, 5, 35, 7,  9, 
    1, 93, 5, 86, 2, 83, 4, 97, 0, 11, 7, 11, 6, 70, 3, 28, 8, 94, 
    0, 51, 8, 32, 6, 18, 7, 94, 1, 97, 2, 22, 4, 34, 3, 70, 5, 28
  };
  const int q8730[] = {
    9, 9, // Number of jobs and machines
    4, 44, 7, 20, 6, 21, 5,  3, 3,  9, 0, 14, 1, 92, 8, 39, 2, 98, 
    5, 95, 1, 53, 2, 88, 0, 55, 3, 30, 4, 44, 8,  4, 7, 74, 6, 95, 
    5, 46, 7, 62, 3, 21, 1,  3, 0, 47, 6, 22, 4, 69, 2, 20, 8, 78, 
    5, 14, 3, 70, 8, 87, 7, 45, 0, 62, 1, 15, 4,  3, 2, 61, 6, 82, 
    0,  7, 1, 10, 3, 77, 5, 99, 7, 24, 4, 90, 8, 24, 2, 28, 6, 85, 
    1, 87, 8, 38, 3, 61, 7, 64, 6, 84, 5, 66, 2, 86, 0, 50, 4, 26, 
    0, 55, 8, 15, 2,  1, 4, 32, 6, 71, 3, 37, 1, 50, 5, 39, 7, 45, 
    8, 51, 2,  8, 0, 30, 6, 48, 5, 68, 7,  2, 3, 62, 1, 45, 4, 22, 
    2, 75, 8, 45, 3, 89, 0, 12, 5, 61, 7, 29, 1,  7, 6, 27, 4, 19
  };
  const int q8731[] = {
    9, 9, // Number of jobs and machines
    1, 37, 0, 41, 4, 71, 6, 59, 7, 83, 3,  8, 8, 14, 5, 64, 2, 49, 
    1, 86, 2, 33, 8, 19, 4, 21, 0, 33, 5, 29, 6, 97, 3, 60, 7, 53, 
    0, 59, 1, 92, 7, 64, 8, 47, 6, 91, 4, 72, 5, 43, 3, 54, 2, 61, 
    4, 60, 7, 81, 6,  6, 5, 13, 2, 82, 0, 15, 3, 27, 1, 35, 8, 96, 
    8, 31, 3, 22, 6, 62, 5, 83, 4, 52, 2, 93, 7, 72, 0, 28, 1, 26, 
    7, 14, 6, 40, 8, 48, 5, 93, 4, 72, 0, 80, 3, 20, 1, 64, 2, 22, 
    0, 50, 4, 27, 5, 68, 8, 98, 2, 69, 3, 55, 6, 21, 7, 85, 1, 38, 
    0, 11, 2, 86, 5, 59, 8, 91, 1, 29, 3, 95, 6, 28, 4, 78, 7,  9, 
    1, 59, 0, 71, 5, 94, 8, 13, 6, 44, 2, 57, 3, 79, 7,  5, 4,  9
  };
  const int q8732[] = {
    9, 9, // Number of jobs and machines
    2,  9, 1, 41, 4, 79, 8, 56, 7, 58, 3, 19, 5, 32, 0, 64, 6, 46, 
    3, 34, 7, 81, 8, 65, 2, 76, 6, 87, 4, 43, 0, 60, 1, 90, 5, 13, 
    3,  9, 7, 57, 1, 90, 8, 79, 4, 75, 6, 59, 0, 45, 5, 66, 2, 91, 
    0,  7, 7, 60, 5, 59, 6, 53, 4,  1, 2, 35, 3, 46, 8, 33, 1, 57, 
    1, 62, 6, 16, 0,  2, 4, 69, 3, 78, 8, 72, 5, 11, 7, 50, 2, 32, 
    0, 29, 2, 81, 6, 63, 3, 73, 7, 67, 8, 30, 4, 51, 5, 76, 1, 81, 
    5, 43, 1, 11, 6, 47, 3, 70, 2, 51, 4, 79, 0, 27, 7, 23, 8, 37, 
    7, 59, 4, 63, 1, 20, 8, 56, 6, 57, 2, 80, 0, 42, 3, 34, 5, 56, 
    8, 64, 5, 79, 2,  2, 0, 18, 3, 12, 4,  2, 7,  6, 6, 61, 1, 12
  };
  const int q8733[] = {
    9, 9, // Number of jobs and machines
    7, 12, 1,  2, 3, 68, 8,  3, 5, 57, 6, 30, 0,  5, 4, 35, 2, 47, 
    7, 59, 4,  7, 6, 79, 2, 16, 0, 88, 1, 28, 5, 32, 8, 21, 3, 18, 
    6, 55, 0, 59, 5, 84, 8, 98, 3, 65, 1, 43, 2, 29, 4,  7, 7, 45, 
    1, 45, 3, 73, 0, 30, 8, 84, 6, 47, 7, 30, 5, 23, 2, 52, 4,  4, 
    3, 91, 1, 62, 4, 67, 7, 77, 6, 64, 8, 32, 0, 72, 2, 19, 5, 35, 
    6, 17, 5, 65, 4, 28, 0, 23, 1, 59, 8, 81, 7, 17, 2, 56, 3, 82, 
    1, 91, 7, 73, 2, 97, 3, 23, 6, 66, 4, 84, 5, 70, 8, 20, 0, 94, 
    7, 40, 1, 29, 3, 74, 2,  6, 8, 46, 5, 64, 6, 48, 0, 97, 4, 58, 
    5, 61, 1, 69, 8,  7, 6, 45, 2, 60, 7, 12, 3, 10, 0, 71, 4, 71
  };
  const int q8734[] = {
    9, 9, // Number of jobs and machines
    0, 91, 7, 59, 6, 86, 1, 96, 8, 72, 2, 89, 5,  9, 4, 64, 3, 72, 
    4, 84, 5, 52, 1, 53, 3, 77, 0, 94, 2, 77, 8, 60, 6, 17, 7, 29, 
    1, 53, 7, 48, 3, 51, 2, 95, 5, 72, 6, 54, 4, 83, 0, 15, 8, 40, 
    1, 24, 6, 35, 8, 72, 0, 54, 3, 82, 2, 21, 5, 78, 7, 92, 4, 98, 
    6, 45, 1, 29, 7, 82, 0, 72, 5, 85, 2, 84, 8, 22, 3, 31, 4, 52, 
    0, 47, 4,  4, 7, 85, 5, 60, 6, 70, 2, 26, 8, 17, 3, 81, 1, 33, 
    2, 22, 8, 16, 0, 98, 5, 27, 1, 23, 6,  6, 7, 98, 3, 26, 4, 14, 
    5, 89, 7, 53, 6, 21, 3, 55, 1, 69, 2, 14, 4, 25, 8, 81, 0, 51, 
    1, 38, 0,  5, 2, 78, 6, 26, 5, 60, 7, 62, 8,  4, 3, 83, 4, 27
  };
  const int q8735[] = {
    9, 9, // Number of jobs and machines
    0, 64, 4, 56, 6, 98, 8, 81, 1, 36, 7, 92, 5, 78, 3, 90, 2, 66, 
    0, 54, 4,  3, 1, 55, 2, 28, 6, 26, 5, 61, 8, 65, 7,  9, 3, 23, 
    6, 45, 1, 62, 7, 84, 8, 60, 0, 20, 5, 43, 2, 24, 3,  2, 4, 38, 
    1, 35, 3, 11, 7, 64, 4, 82, 6, 78, 8, 54, 5, 46, 0, 35, 2, 15, 
    4, 25, 1, 30, 8, 37, 2, 66, 7, 95, 3, 87, 6, 32, 5, 92, 0, 43, 
    6,  1, 5, 31, 2, 67, 7, 54, 1, 66, 0, 93, 8, 99, 4,  1, 3, 54, 
    7, 91, 5, 36, 3,  4, 4, 35, 8, 66, 2, 54, 6, 55, 0, 82, 1, 47, 
    8, 83, 1, 95, 2, 70, 3, 63, 5, 36, 0, 19, 6, 54, 7, 27, 4,  1, 
    0, 16, 8, 41, 5, 78, 6, 20, 7, 11, 2, 70, 3, 79, 1, 87, 4, 22
  };
  const int q8736[] = {
    9, 9, // Number of jobs and machines
    5, 38, 7, 87, 8,  3, 3, 63, 6, 61, 1, 77, 0, 96, 4,  5, 2, 36, 
    5, 27, 0, 87, 2, 31, 8, 70, 7, 67, 3, 39, 4, 28, 6, 19, 1, 22, 
    8, 96, 5, 91, 0, 47, 6,  4, 3, 54, 4, 23, 7, 83, 1, 86, 2, 50, 
    5, 16, 1,  3, 6,  3, 8, 17, 3, 28, 4, 45, 7, 29, 0, 15, 2, 30, 
    2, 70, 4, 52, 3, 62, 1, 87, 5, 96, 0, 67, 7, 75, 8, 79, 6, 58, 
    1, 73, 4, 62, 6, 91, 8, 12, 0, 95, 3,  1, 2,  7, 7, 96, 5, 11, 
    0, 29, 8, 61, 4, 61, 1, 79, 7, 40, 3, 23, 6, 59, 5, 98, 2, 96, 
    1, 57, 0, 66, 5, 17, 6,  9, 4,  2, 3, 97, 8, 52, 2, 60, 7, 46, 
    1,  1, 4, 89, 6, 95, 7, 79, 8, 71, 0, 46, 5, 76, 3, 47, 2, 77
  };
  const int q8737[] = {
    9, 9, // Number of jobs and machines
    5, 83, 4, 23, 3, 80, 2,  9, 8, 42, 7, 74, 1,  6, 0,  3, 6,  8, 
    6, 43, 5, 51, 0, 94, 8, 34, 7, 80, 2, 27, 1, 19, 4, 59, 3,  9, 
    7, 44, 5, 79, 8, 36, 4, 72, 0, 10, 6, 80, 1, 25, 3, 35, 2, 58, 
    5, 11, 6, 17, 2, 54, 1, 73, 8, 27, 4, 33, 0, 25, 3, 90, 7, 80, 
    7, 80, 6, 94, 8, 15, 4, 78, 5, 82, 2, 17, 1, 42, 0, 45, 3, 98, 
    6, 46, 7, 71, 5, 95, 1, 67, 8, 85, 3, 13, 4, 12, 0, 80, 2, 31, 
    1, 26, 8, 46, 4, 61, 5, 82, 3, 91, 2, 67, 7, 64, 6, 71, 0, 86, 
    8, 68, 0, 21, 6, 56, 1, 27, 4, 49, 3, 15, 5, 37, 2, 72, 7, 92, 
    3, 96, 4, 70, 0, 24, 2, 33, 7, 76, 1, 91, 5, 18, 6, 22, 8, 54
  };
  const int q8738[] = {
    9, 9, // Number of jobs and machines
    4, 33, 2, 30, 6, 32, 7, 19, 8, 97, 1, 43, 0, 94, 3,  3, 5,  7, 
    7,  2, 5, 64, 0, 46, 3, 74, 1, 83, 6, 28, 2, 29, 4,  4, 8, 54, 
    2, 10, 7, 82, 6, 27, 0, 20, 3, 83, 1, 78, 8, 36, 4,  3, 5, 48, 
    0, 44, 7, 26, 6,  8, 2, 40, 1, 30, 8, 25, 5, 10, 3, 63, 4, 81, 
    1, 70, 8, 37, 0, 84, 5, 79, 7,  2, 3, 32, 4, 73, 6, 88, 2, 69, 
    7, 47, 2, 63, 0, 63, 6, 14, 1, 89, 8, 65, 5, 18, 3, 51, 4, 90, 
    4, 13, 7, 82, 6, 61, 5, 79, 0, 90, 8, 45, 1,  7, 3, 95, 2, 64, 
    1, 24, 5, 95, 2, 73, 6, 49, 0, 20, 3, 70, 7, 76, 4, 15, 8, 98, 
    5, 13, 3, 54, 1, 33, 6, 34, 0, 62, 7, 12, 8, 29, 4, 76, 2, 34
  };
  const int q8739[] = {
    9, 9, // Number of jobs and machines
    2,  4, 4, 55, 1, 34, 5, 29, 6, 37, 0, 95, 8, 43, 7, 55, 3, 41, 
    1, 22, 4, 93, 8, 72, 7, 89, 5, 26, 2, 85, 0, 66, 6, 34, 3, 94, 
    2, 43, 1, 88, 6, 23, 7, 13, 5, 25, 4, 81, 0, 14, 8, 98, 3, 24, 
    0,  9, 7, 17, 8, 87, 4, 51, 3, 45, 2, 71, 5, 68, 6,  3, 1, 92, 
    6, 58, 2, 70, 1, 36, 0, 11, 3, 34, 4,  5, 5, 14, 8, 40, 7, 38, 
    4,  2, 5, 47, 0, 63, 1, 93, 8, 83, 7, 44, 6, 58, 2, 68, 3, 37, 
    7, 88, 5, 46, 4, 76, 6, 29, 8, 28, 1, 10, 2, 76, 3, 91, 0, 20, 
    0, 24, 3, 74, 7, 19, 6, 92, 2, 90, 4, 62, 1, 70, 5, 91, 8, 22, 
    5, 89, 0, 16, 8, 54, 1, 83, 3, 22, 6, 71, 2, 30, 7, 54, 4, 22
  };
  const int q8740[] = {
    9, 9, // Number of jobs and machines
    2, 75, 1, 34, 7, 91, 8, 70, 0, 40, 3, 77, 5, 95, 6, 62, 4, 12, 
    2, 86, 0, 94, 6, 40, 3, 51, 4,  9, 5, 76, 1, 51, 7, 72, 8, 83, 
    2, 28, 6, 98, 7, 20, 5, 97, 4, 37, 8, 17, 0, 50, 1, 21, 3, 89, 
    6, 89, 3, 52, 1, 44, 8, 17, 7, 29, 4, 39, 0, 42, 2, 49, 5,  5, 
    3, 73, 2, 97, 4,  8, 5, 40, 8,  2, 0,  4, 1, 62, 6, 53, 7, 89, 
    5, 49, 1, 48, 0, 23, 3, 84, 2, 15, 7, 45, 6, 39, 8, 18, 4, 42, 
    3, 44, 5, 63, 6, 24, 8, 49, 2, 97, 4, 13, 1,  9, 0, 41, 7, 43, 
    8, 27, 7, 42, 3, 70, 0, 85, 6, 42, 4, 15, 5, 60, 1, 50, 2, 80, 
    6, 73, 7, 56, 5, 49, 4, 17, 0,  6, 3, 62, 8, 56, 2, 68, 1, 83
  };
  const int q8741[] = {
    9, 9, // Number of jobs and machines
    5, 69, 1, 92, 3, 71, 7, 73, 8, 22, 2, 15, 0, 16, 4, 88, 6, 93, 
    8, 72, 2, 88, 1, 14, 0, 97, 7, 63, 4, 59, 3, 54, 6, 40, 5, 76, 
    6, 13, 1, 27, 4, 39, 7, 95, 3, 68, 5, 88, 0, 28, 8, 91, 2, 16, 
    8, 54, 5, 40, 1, 50, 6, 47, 2, 98, 7, 45, 0, 21, 3, 15, 4,  4, 
    0, 88, 8, 37, 4, 33, 5, 39, 6, 64, 2, 93, 3, 28, 1, 21, 7, 70, 
    7, 55, 0,  6, 8, 28, 6, 79, 1, 67, 2, 24, 5, 49, 3, 89, 4, 44, 
    2, 46, 8, 65, 6, 65, 3, 69, 4, 88, 1, 28, 0, 56, 7, 53, 5, 49, 
    0, 79, 2, 90, 1,  5, 8, 77, 6, 99, 5, 70, 7, 59, 4, 61, 3, 52, 
    8, 36, 2, 63, 0, 51, 3, 52, 4, 52, 1, 65, 6, 79, 5, 68, 7,  6
  };
  const int q8742[] = {
    9, 9, // Number of jobs and machines
    0, 13, 1, 57, 4, 12, 3, 63, 7,  8, 8, 57, 2, 29, 6, 14, 5, 61, 
    3, 67, 6, 51, 0, 78, 7, 35, 5, 33, 2, 28, 8, 90, 1,  3, 4, 14, 
    7, 23, 4,  4, 1, 75, 2, 46, 0, 77, 5, 59, 8, 21, 6, 13, 3, 44, 
    0, 40, 6, 11, 7, 78, 3, 19, 1, 20, 4, 91, 8, 80, 2, 80, 5, 72, 
    4, 18, 2, 54, 1,  1, 8, 73, 0, 64, 7, 61, 5, 72, 3, 51, 6, 14, 
    6, 72, 7, 99, 4, 86, 1, 27, 8, 70, 3, 68, 2, 67, 5, 98, 0, 17, 
    5, 58, 2,  1, 0, 35, 7, 14, 1, 28, 3, 88, 6,  8, 8, 78, 4, 86, 
    0,  8, 5, 47, 2, 72, 4, 83, 7, 19, 8, 70, 3, 13, 1,  7, 6,  9, 
    8, 80, 6, 32, 3, 67, 7, 94, 4, 40, 2, 99, 1, 15, 0, 44, 5, 82
  };
  const int q8743[] = {
    9, 9, // Number of jobs and machines
    1, 80, 2, 89, 7, 19, 3, 24, 4, 57, 0,  2, 6, 75, 8, 77, 5, 38, 
    3, 42, 2, 41, 1, 95, 6,  7, 8, 95, 5, 37, 7,  5, 4, 13, 0, 67, 
    7, 68, 0, 85, 4, 14, 1, 87, 2, 82, 8, 92, 5, 24, 3, 68, 6, 44, 
    0, 73, 3, 38, 8, 89, 4,  5, 5, 55, 1, 34, 6, 40, 7, 71, 2, 82, 
    0, 92, 2, 43, 4, 15, 6, 29, 7, 64, 3, 13, 1, 64, 5, 17, 8, 95, 
    2, 61, 1, 68, 4, 51, 3, 28, 7, 53, 0, 34, 5, 96, 6, 86, 8, 28, 
    8,  5, 5,  2, 7, 88, 0, 23, 3, 39, 4, 66, 6, 48, 2, 19, 1, 70, 
    6, 47, 8, 44, 2, 83, 1,  8, 4, 23, 5, 86, 7, 58, 0, 31, 3, 13, 
    1, 73, 7, 41, 4,  9, 6, 41, 8, 44, 5,  7, 2, 30, 3, 84, 0, 76
  };
  const int q8744[] = {
    9, 9, // Number of jobs and machines
    7, 17, 6, 75, 3, 24, 2, 98, 8, 47, 4, 99, 0, 90, 1,  9, 5, 11, 
    5, 74, 6, 82, 3, 74, 2, 68, 7, 23, 1, 65, 0, 20, 4,  2, 8, 65, 
    1, 80, 7, 47, 6, 80, 4,  6, 5,  2, 3, 76, 0, 51, 2, 67, 8, 57, 
    5, 99, 6, 67, 7, 30, 4, 33, 8, 47, 0, 86, 3, 72, 2, 73, 1, 85, 
    8, 97, 0, 69, 2,  1, 3, 53, 6, 17, 5, 15, 4, 30, 7, 36, 1, 63, 
    6, 33, 3, 76, 5, 90, 4, 62, 2, 10, 8, 16, 7, 43, 1, 13, 0, 46, 
    6, 47, 4, 14, 2, 79, 5, 48, 3,  9, 8, 21, 0, 71, 1, 93, 7, 93, 
    4, 36, 6, 40, 0, 43, 2, 43, 7, 89, 1, 46, 8, 36, 5, 13, 3, 28, 
    5, 24, 0, 86, 6,  9, 7, 72, 1, 59, 3, 28, 8, 36, 2, 22, 4, 89
  };
  const int q8745[] = {
    9, 9, // Number of jobs and machines
    0, 39, 8, 10, 7, 38, 4, 10, 6, 19, 5, 43, 3, 46, 2, 77, 1, 21, 
    8, 39, 2,  5, 6, 44, 3, 57, 0, 84, 4, 38, 5, 43, 7, 91, 1, 92, 
    7, 52, 5, 90, 2, 32, 8, 96, 0, 24, 6, 20, 4, 96, 3, 82, 1, 55, 
    3,  6, 1, 18, 5, 14, 8,  9, 0, 59, 7, 22, 6,  5, 4, 63, 2, 19, 
    3, 38, 5, 86, 2, 10, 0, 14, 4, 83, 8, 76, 1, 84, 6, 56, 7, 68, 
    3, 76, 8, 53, 0, 47, 7, 28, 4, 37, 2, 29, 6, 59, 5, 76, 1,  9, 
    7, 84, 8, 29, 6, 28, 0, 47, 2,  6, 1, 65, 5, 78, 4, 84, 3, 74, 
    7, 33, 2, 16, 1, 35, 4, 30, 3, 85, 0, 70, 5, 85, 6, 56, 8, 30, 
    5, 98, 6, 43, 7, 13, 4, 63, 1, 97, 2, 44, 0, 35, 8, 30, 3,  6
  };
  const int q8746[] = {
    9, 9, // Number of jobs and machines
    7, 82, 0, 38, 2, 49, 8, 42, 1,  2, 4,  9, 6, 37, 3, 25, 5, 63, 
    6, 72, 0, 33, 3, 40, 4, 67, 5, 42, 7, 42, 8,  3, 1,  1, 2, 67, 
    1, 98, 0, 42, 2, 56, 3, 72, 8, 84, 4, 19, 5, 83, 6, 80, 7, 11, 
    0, 97, 7, 52, 2, 64, 6, 74, 5, 14, 1, 74, 4, 76, 8, 84, 3, 59, 
    6, 80, 2, 40, 7, 20, 0, 10, 4, 69, 8, 29, 1, 34, 5, 20, 3, 24, 
    3, 17, 5, 68, 4, 39, 2, 40, 6, 92, 7, 22, 0, 56, 8, 54, 1, 97, 
    2, 95, 0, 63, 1, 24, 4, 19, 6, 76, 3,  8, 8, 29, 5,  4, 7,  3, 
    3, 44, 4, 24, 5, 17, 6, 84, 0, 60, 7, 62, 8, 50, 2, 86, 1, 28, 
    2, 37, 5, 99, 4, 58, 7, 46, 0, 29, 6, 56, 1, 16, 3, 32, 8, 34
  };
  const int q8747[] = {
    9, 9, // Number of jobs and machines
    8, 98, 6, 96, 0, 51, 5, 71, 3, 97, 4, 77, 1, 31, 7, 12, 2, 51, 
    1,  2, 4, 17, 8,  9, 6, 35, 5, 95, 3, 70, 2, 63, 7, 73, 0, 33, 
    1, 10, 3,  7, 8,  4, 6, 14, 2, 43, 5, 30, 7, 72, 0,  5, 4, 38, 
    4, 44, 3, 27, 8, 21, 6, 38, 7, 68, 0, 83, 1, 18, 2,  8, 5, 39, 
    2, 47, 3, 74, 6, 56, 5, 15, 0, 42, 8, 80, 1, 78, 7, 75, 4, 80, 
    5, 68, 6, 58, 3,  7, 8, 57, 7, 45, 2, 40, 0, 94, 4, 63, 1, 80, 
    3, 15, 5, 59, 1,  5, 6,  8, 2, 92, 0, 29, 7, 34, 4, 15, 8, 30, 
    5, 51, 6,  9, 7, 23, 8, 59, 0, 35, 1, 91, 2, 10, 4, 96, 3, 25, 
    0, 93, 4, 44, 2, 70, 8, 40, 1, 36, 5, 73, 7, 48, 6, 64, 3, 66
  };
  const int q8748[] = {
    9, 9, // Number of jobs and machines
    8, 69, 6,  6, 1, 15, 3, 24, 4, 94, 0, 74, 5, 83, 7, 84, 2, 42, 
    0, 37, 8, 45, 2,  5, 5, 57, 4, 63, 6, 66, 7, 60, 1,  2, 3, 80, 
    2, 23, 8, 43, 6, 81, 3, 90, 5, 40, 7, 74, 4, 85, 1, 27, 0, 18, 
    0, 21, 2, 38, 4, 26, 8, 57, 1, 91, 7, 23, 3, 56, 5, 61, 6, 83, 
    5, 55, 1, 34, 0, 93, 3, 49, 7, 21, 2, 98, 8, 17, 6, 74, 4, 53, 
    7,  3, 0, 29, 4, 48, 8, 41, 5, 70, 3, 16, 2, 65, 1, 89, 6, 44, 
    8, 28, 0, 41, 5, 79, 7, 82, 2, 32, 1, 61, 3, 99, 6, 90, 4, 76, 
    1, 77, 8, 95, 4, 46, 5, 21, 3, 11, 7, 91, 2, 96, 0, 83, 6, 21, 
    1, 19, 7, 98, 6, 77, 5, 10, 2, 20, 0, 45, 3, 66, 4, 30, 8, 79
  };
  const int q8749[] = {
    9, 9, // Number of jobs and machines
    6, 95, 5, 46, 3, 10, 1, 93, 7, 72, 8, 60, 4, 45, 0, 96, 2, 44, 
    3, 36, 4, 91, 0,  6, 8, 22, 5, 42, 7, 72, 6, 48, 1, 67, 2, 94, 
    8, 45, 6, 34, 4, 63, 7, 89, 2, 84, 0, 47, 1, 34, 5, 58, 3,  1, 
    5, 34, 1, 23, 8, 81, 2, 47, 7, 58, 6, 44, 3, 72, 0, 40, 4, 95, 
    7, 12, 1, 28, 0, 96, 6, 98, 2, 85, 8, 48, 4, 34, 5,  6, 3, 55, 
    3, 32, 5, 33, 4, 91, 0,  8, 7, 44, 2, 38, 8, 58, 1, 48, 6, 21, 
    0, 67, 2, 64, 4, 68, 7, 51, 5, 45, 6, 36, 1, 71, 3, 70, 8, 93, 
    3, 46, 6, 35, 0, 96, 4, 63, 5, 93, 1,  3, 8, 10, 2, 84, 7, 75, 
    5, 68, 3, 84, 4, 41, 2, 90, 0, 60, 7,  9, 8, 65, 1, 99, 6, 15
  };
  const int q8750[] = {
    9, 9, // Number of jobs and machines
    6,  5, 0, 17, 7, 53, 1, 53, 4, 16, 2, 87, 8, 67, 5, 96, 3, 55, 
    6, 37, 7, 65, 4, 34, 5, 86, 2, 35, 0, 73, 3, 84, 1, 57, 8, 22, 
    4, 59, 3, 97, 0, 86, 2, 76, 6, 18, 5, 55, 7, 84, 8, 81, 1, 27, 
    8,  5, 0, 87, 2,  9, 4, 28, 6, 29, 1, 71, 3, 33, 5, 56, 7, 91, 
    6, 48, 0, 28, 3, 63, 7,  2, 8, 39, 5, 86, 1, 31, 4, 29, 2, 29, 
    3, 76, 5, 96, 6, 75, 4, 88, 0, 54, 1, 16, 2, 19, 8, 10, 7, 96, 
    1, 13, 5, 98, 7,  6, 0, 99, 6, 83, 3, 38, 4, 21, 8, 51, 2, 18, 
    1, 78, 5, 54, 3, 43, 8, 61, 6, 55, 7, 97, 4, 86, 0, 79, 2, 63, 
    6, 72, 3, 63, 5, 14, 4, 20, 0, 25, 7, 32, 2,  7, 8, 88, 1, 81
  };
  const int q8751[] = {
    9, 9, // Number of jobs and machines
    8, 50, 0, 51, 3, 41, 4, 10, 5, 82, 7, 80, 6, 44, 2, 28, 1,  5, 
    3, 63, 7, 67, 4, 70, 2, 41, 1, 97, 5, 34, 8, 98, 0, 13, 6, 66, 
    0, 35, 6, 20, 8,  6, 3, 48, 1, 93, 7, 48, 4, 66, 2, 43, 5, 13, 
    0,  1, 8,  4, 7, 24, 2, 56, 4, 65, 5, 86, 3, 85, 1, 10, 6, 17, 
    5, 46, 8, 14, 2,  3, 0, 91, 1, 33, 7, 22, 4, 89, 6, 91, 3, 21, 
    4, 86, 2, 13, 0, 77, 8, 59, 3, 63, 7, 30, 5, 88, 6, 73, 1, 39, 
    8, 73, 0, 65, 3, 57, 6, 43, 7, 11, 4, 65, 5, 79, 1, 74, 2, 39, 
    2, 32, 0, 71, 5, 69, 7, 86, 8, 77, 6,  3, 3, 78, 4, 39, 1, 57, 
    5, 12, 0, 75, 1,  7, 7,  9, 6, 77, 8, 48, 3, 17, 2, 30, 4, 28
  };
  const int q8752[] = {
    9, 9, // Number of jobs and machines
    3, 26, 5, 49, 8, 48, 7,  5, 2, 59, 4,  7, 0, 15, 1, 30, 6, 90, 
    0, 92, 2,  9, 4, 96, 8, 52, 1, 20, 3, 36, 6, 70, 7, 25, 5,  9, 
    1, 48, 8,  4, 5, 27, 6, 70, 7, 62, 4,  5, 2, 53, 3, 87, 0, 82, 
    8, 97, 1,  2, 3, 89, 7, 35, 5, 32, 4, 61, 2, 94, 6, 39, 0, 96, 
    7, 26, 5, 14, 2, 36, 4, 93, 0, 34, 6, 90, 8, 83, 3,  9, 1, 81, 
    1, 78, 3, 51, 5, 36, 4, 99, 7,  6, 6,  4, 0, 39, 8, 85, 2, 23, 
    6, 21, 3, 25, 7, 24, 2, 80, 4, 19, 1, 71, 5, 44, 8, 92, 0, 68, 
    6, 65, 0, 19, 3, 51, 1, 39, 7, 44, 5, 71, 2, 97, 4, 11, 8, 11, 
    0, 51, 3, 63, 8, 36, 4,  8, 5,  6, 1, 57, 2, 19, 6, 48, 7, 35
  };
  const int q8753[] = {
    9, 9, // Number of jobs and machines
    8, 97, 3, 16, 2, 53, 5, 20, 6, 43, 7, 63, 0, 90, 1, 87, 4, 80, 
    0, 18, 3, 88, 4, 52, 2, 79, 5, 10, 6, 35, 8, 21, 7, 45, 1, 16, 
    0, 21, 2, 83, 1, 78, 5, 13, 3,  1, 6, 20, 4, 88, 7,  6, 8, 69, 
    3, 30, 7, 90, 2, 80, 1, 11, 5, 37, 6, 43, 4,  6, 8, 84, 0, 45, 
    7, 48, 4, 93, 2,  3, 5, 59, 3, 45, 1, 83, 6, 47, 0, 53, 8, 31, 
    7, 94, 8,  3, 4, 11, 1, 96, 6, 13, 2, 75, 0, 74, 5, 75, 3, 19, 
    0, 84, 8, 90, 7, 49, 2, 32, 5, 62, 3, 86, 1, 87, 4,  5, 6, 76, 
    6, 92, 4, 27, 8, 75, 0, 34, 1, 62, 3, 32, 7, 94, 2, 27, 5, 20, 
    2,  7, 8, 35, 6, 22, 3, 33, 7, 75, 4, 33, 0, 23, 1,  5, 5, 56
  };
  const int q8754[] = {
    9, 9, // Number of jobs and machines
    4, 22, 5, 98, 2,  8, 8,  8, 6, 60, 0, 63, 7, 21, 1, 50, 3, 58, 
    4,  1, 7, 38, 5, 40, 2, 57, 6,  2, 3, 36, 1, 60, 0, 45, 8, 92, 
    7, 83, 1, 74, 3,  9, 0, 95, 6, 17, 8, 31, 4, 50, 5, 67, 2,  9, 
    3, 34, 2, 92, 1, 23, 5, 67, 6, 99, 0, 79, 8,  2, 7, 23, 4, 62, 
    0, 93, 8,  5, 7, 45, 1, 80, 5, 84, 4, 44, 6, 72, 2, 67, 3, 92, 
    4, 66, 8, 81, 2, 41, 1, 92, 7, 72, 6, 35, 0,  3, 3, 35, 5, 91, 
    2, 91, 5, 27, 7, 21, 0, 97, 8,  1, 1, 81, 3, 89, 6,  9, 4, 35, 
    7, 33, 3, 68, 0, 76, 8, 84, 5, 78, 4, 25, 2, 10, 1, 39, 6,  2, 
    5, 90, 7, 93, 4, 19, 3, 24, 8, 59, 6, 85, 2, 29, 1, 77, 0,  7
  };
  const int q8755[] = {
    9, 9, // Number of jobs and machines
    5, 14, 3, 96, 1, 16, 0, 81, 2, 90, 8, 46, 7, 23, 4, 90, 6, 74, 
    7, 33, 4, 39, 0, 59, 6, 18, 2, 56, 1, 48, 5, 74, 8, 66, 3, 13, 
    5, 37, 3, 43, 1, 67, 4, 43, 6, 72, 8, 81, 7, 45, 0, 79, 2, 85, 
    7, 14, 5, 61, 1, 23, 4, 49, 2, 26, 6, 72, 0, 40, 3, 73, 8, 21, 
    3, 47, 4, 88, 8, 65, 5, 89, 7, 14, 0, 99, 1, 21, 2, 82, 6, 34, 
    8, 73, 7, 58, 1, 28, 3,  3, 6, 17, 4, 20, 2,  3, 5, 79, 0, 35, 
    0, 76, 3, 68, 5, 78, 8, 22, 7, 27, 6, 79, 4, 66, 1, 22, 2, 39, 
    7, 40, 8, 64, 0, 10, 1, 19, 4, 61, 2, 15, 6, 19, 3, 35, 5, 17, 
    1, 12, 4, 73, 7, 37, 2,  1, 3, 46, 6, 44, 5, 49, 8, 64, 0, 96
  };
  const int q8756[] = {
    9, 9, // Number of jobs and machines
    5, 56, 7, 98, 3, 92, 8, 69, 6, 52, 1, 66, 4, 55, 0, 96, 2, 29, 
    0, 37, 7, 89, 1, 86, 6, 28, 8, 39, 5, 86, 3, 49, 2, 63, 4, 35, 
    4, 73, 0, 66, 3, 10, 8, 80, 1,  3, 5, 85, 7, 57, 6, 13, 2, 35, 
    7, 10, 8, 72, 1,  7, 5, 82, 4, 42, 6,  4, 0, 49, 2, 81, 3, 98, 
    7, 35, 6,  3, 4, 73, 1, 66, 8, 69, 0, 72, 5, 80, 2, 81, 3, 62, 
    4, 82, 0, 12, 2, 56, 1, 24, 7, 77, 3, 76, 8, 34, 6, 85, 5, 24, 
    0, 74, 2, 89, 1, 94, 5,  4, 4, 21, 7, 71, 6, 83, 3, 57, 8, 96, 
    7, 65, 0, 69, 1, 85, 2, 56, 8, 38, 6,  9, 4, 88, 5,  8, 3, 37, 
    3, 69, 2, 11, 0, 37, 5,  1, 1, 76, 6, 88, 7, 28, 8, 85, 4, 24
  };
  const int q8757[] = {
    9, 9, // Number of jobs and machines
    3, 75, 7, 80, 8, 43, 2, 54, 1, 93, 4, 45, 6, 38, 0, 52, 5, 53, 
    4, 93, 8, 75, 0, 15, 7, 80, 3, 56, 2, 19, 5, 69, 1, 25, 6,  8, 
    7, 52, 1,  8, 6, 51, 2, 73, 0, 21, 8, 41, 3, 13, 5, 63, 4, 32, 
    5, 30, 2, 55, 7, 24, 4, 94, 8, 35, 1, 26, 6, 63, 0, 57, 3, 93, 
    5, 37, 7,  3, 8, 33, 6, 41, 4, 77, 0,  9, 1, 25, 3, 67, 2, 84, 
    2, 17, 0, 97, 8, 97, 1, 31, 5, 18, 6, 22, 7,  3, 4, 37, 3,  1, 
    6, 62, 8, 89, 3, 66, 7, 14, 5,  7, 2, 36, 4, 99, 1, 26, 0,  8, 
    6, 27, 3, 24, 4, 99, 1, 96, 5, 35, 8, 55, 2, 61, 0, 58, 7, 21, 
    1, 89, 7, 24, 0, 26, 6, 19, 4, 40, 5, 82, 2, 60, 3, 38, 8, 50
  };
  const int q8758[] = {
    9, 9, // Number of jobs and machines
    2, 97, 7, 20, 5, 42, 8, 13, 4, 83, 3, 53, 0, 34, 1, 33, 6, 43, 
    4, 42, 8, 35, 2, 95, 6, 14, 5, 31, 1, 31, 0, 96, 3, 47, 7, 99, 
    3, 27, 0, 22, 8, 95, 2, 54, 6, 34, 7,  4, 4,  2, 1, 12, 5, 29, 
    5, 99, 8, 59, 1,  9, 0, 80, 3, 30, 4, 21, 7, 90, 6, 79, 2, 69, 
    3,  8, 7, 33, 6, 26, 0, 42, 2, 50, 1, 46, 8, 12, 5, 75, 4, 68, 
    2,  2, 0, 25, 1, 97, 5, 35, 8, 72, 3, 60, 7, 45, 4, 53, 6, 18, 
    0, 57, 7, 33, 5, 55, 8, 69, 6, 14, 4, 29, 1, 87, 3, 12, 2, 84, 
    8, 99, 6, 85, 1, 45, 7, 64, 4,  5, 3, 24, 0, 46, 5, 80, 2, 43, 
    5, 22, 6,  5, 4, 38, 3, 47, 1, 55, 0, 57, 8, 18, 7, 23, 2, 50
  };
  const int q8759[] = {
    9, 9, // Number of jobs and machines
    8, 38, 4, 79, 6, 42, 2, 75, 3, 50, 1, 21, 7, 87, 5,  9, 0, 75, 
    1, 70, 2, 78, 3, 85, 7, 96, 0, 22, 4, 41, 8, 11, 6,  6, 5, 59, 
    7,  6, 0, 91, 1, 14, 4, 76, 3, 43, 8, 50, 5, 88, 6, 61, 2, 69, 
    8, 58, 3, 33, 6, 35, 0, 43, 4, 92, 1, 40, 7, 35, 5, 17, 2, 54, 
    3, 36, 1, 95, 7, 46, 5, 98, 0, 71, 2,  6, 6, 39, 4, 28, 8, 38, 
    5, 34, 4, 45, 7, 89, 6, 37, 1, 85, 0, 48, 3,  2, 8, 70, 2, 23, 
    1, 12, 7, 65, 5, 42, 2, 13, 3, 50, 8, 53, 6, 31, 0, 48, 4, 67, 
    1, 10, 3, 68, 6, 28, 7,  6, 5, 64, 0,  1, 8, 64, 2, 63, 4, 58, 
    7, 40, 5, 15, 1, 42, 8,  3, 4, 64, 2, 62, 6, 76, 3, 15, 0, 13
  };
  const int q8760[] = {
    9, 9, // Number of jobs and machines
    7, 15, 4, 81, 8, 10, 5, 11, 6, 14, 0, 92, 2, 30, 1,  7, 3, 42, 
    8, 19, 1, 48, 5, 86, 3, 36, 4, 74, 2,  7, 6, 53, 7, 36, 0, 33, 
    5, 43, 0, 33, 3, 10, 4,  6, 7, 15, 2, 38, 8, 10, 6, 43, 1, 37, 
    3, 75, 2, 48, 1, 72, 6, 18, 8, 91, 0, 29, 5, 47, 7, 88, 4, 51, 
    3, 15, 6, 66, 1, 34, 8, 47, 4, 37, 7, 31, 5, 80, 0, 19, 2, 10, 
    6, 86, 5, 40, 3, 11, 7, 18, 0, 18, 8, 31, 2, 91, 4, 41, 1, 22, 
    8, 75, 5, 39, 6, 28, 2, 92, 1, 32, 7, 72, 0, 26, 3, 84, 4, 94, 
    6, 62, 7, 51, 2, 35, 3, 80, 8, 41, 1, 11, 4, 93, 5, 16, 0, 33, 
    2, 66, 0, 91, 5,  2, 1, 28, 3, 48, 7, 55, 6, 15, 4, 37, 8, 20
  };
  const int q8761[] = {
    9, 9, // Number of jobs and machines
    5, 50, 3, 27, 0, 92, 1, 27, 7, 14, 4, 47, 2, 44, 6, 12, 8, 89, 
    6, 86, 7, 55, 8, 33, 1, 86, 5, 97, 3, 13, 2, 32, 0, 47, 4,  9, 
    1, 85, 4, 54, 6, 46, 7, 66, 5,  1, 2, 22, 3, 99, 8, 63, 0, 69, 
    6, 94, 2, 37, 7, 22, 1, 41, 8, 84, 5, 51, 3, 32, 4, 21, 0, 62, 
    2, 78, 0, 36, 1, 56, 8, 84, 7, 25, 3, 20, 6, 42, 4, 48, 5, 48, 
    0,  2, 1, 94, 6, 64, 3,  1, 4, 85, 2, 11, 7, 93, 5, 99, 8, 92, 
    6,  7, 8, 72, 7, 10, 5, 66, 4, 77, 1, 89, 0, 89, 3,  9, 2, 98, 
    3, 24, 1,  8, 0, 76, 4, 52, 8, 71, 7, 65, 6, 64, 2, 60, 5, 48, 
    3, 82, 6, 69, 5, 71, 0, 12, 8,  1, 4, 29, 7, 96, 1,  6, 2, 54
  };
  const int q8762[] = {
    9, 9, // Number of jobs and machines
    8, 15, 5, 43, 0,  9, 4,  5, 6, 59, 3, 96, 7, 72, 1,  6, 2, 52, 
    2, 72, 4, 53, 3,  3, 7, 67, 1,  7, 0, 87, 6, 35, 8, 94, 5, 49, 
    4, 31, 3, 92, 7, 60, 0,  4, 6, 66, 5, 78, 1, 14, 2, 49, 8, 72, 
    1, 32, 0, 58, 8, 12, 7, 54, 3, 57, 2, 38, 6, 72, 5, 37, 4, 12, 
    1, 95, 4,  5, 6, 71, 3, 18, 7, 43, 5, 82, 8, 35, 2, 16, 0, 92, 
    6, 15, 5, 89, 3, 80, 0, 95, 1, 14, 4, 34, 7, 74, 2, 98, 8, 54, 
    6, 44, 4, 62, 0, 59, 8, 11, 3, 88, 7,  4, 5, 99, 1, 91, 2, 56, 
    1,  7, 3, 11, 6, 81, 7, 54, 4, 85, 0, 52, 5,  3, 8,  1, 2, 26, 
    8, 45, 5, 63, 4, 28, 0, 53, 2,  7, 3, 37, 6, 18, 7, 33, 1, 48
  };
  const int q8763[] = {
    9, 9, // Number of jobs and machines
    8, 16, 1, 79, 0, 67, 5, 26, 7, 76, 6, 33, 2, 75, 3, 59, 4, 28, 
    4, 59, 1, 88, 6, 59, 2, 63, 0, 34, 8,  4, 7, 91, 3, 57, 5, 10, 
    7, 94, 1, 54, 0, 41, 3, 16, 2, 64, 6, 81, 5,  4, 4, 90, 8, 84, 
    0,  8, 6, 46, 3, 58, 5, 54, 4, 82, 7, 25, 2, 22, 8, 92, 1, 67, 
    4, 25, 0, 50, 1, 27, 6, 93, 7, 73, 3, 24, 8, 84, 2, 19, 5, 21, 
    6, 63, 7, 10, 5, 54, 4, 60, 8, 49, 0, 18, 2, 72, 1, 19, 3, 92, 
    1, 43, 3, 60, 8, 57, 4, 84, 5, 99, 6, 87, 7,  4, 0, 68, 2, 58, 
    7, 57, 8, 22, 0, 97, 5, 35, 3, 53, 2, 40, 1, 42, 6, 34, 4,  3, 
    5, 52, 3,  6, 6, 59, 7, 14, 0, 16, 1, 21, 8, 51, 2, 12, 4, 40
  };
  const int q8764[] = {
    9, 9, // Number of jobs and machines
    7,  9, 4, 95, 2, 16, 1, 37, 6, 36, 8, 42, 3, 81, 5,  3, 0, 37, 
    0, 86, 8, 56, 1, 59, 6,  1, 3, 71, 4,  6, 2, 43, 7, 25, 5,  4, 
    3, 49, 7, 54, 6, 23, 8,  4, 4, 44, 0, 47, 5, 22, 1, 67, 2, 96, 
    5, 53, 3, 10, 1, 94, 6, 11, 2,  7, 0, 67, 4, 51, 8, 47, 7, 71, 
    7, 75, 3,  1, 1, 79, 4, 77, 6,  3, 0, 68, 8, 37, 5, 26, 2, 21, 
    4, 46, 6, 82, 7, 72, 8, 48, 1, 61, 3, 26, 5, 28, 0, 87, 2, 49, 
    7, 84, 6, 88, 4, 65, 2, 10, 0, 17, 8,  6, 3, 24, 5, 67, 1, 11, 
    0, 25, 8, 85, 3, 56, 1, 93, 4, 64, 2, 27, 5, 46, 7, 74, 6,  6, 
    7, 67, 6, 16, 0, 92, 3, 40, 2,  5, 8, 94, 1, 46, 4, 45, 5, 93
  };
  const int q8765[] = {
    9, 9, // Number of jobs and machines
    8, 90, 7,  6, 2, 61, 5, 26, 4,  6, 0,  4, 3, 15, 6, 22, 1, 93, 
    1, 62, 4, 81, 7, 57, 0, 82, 2,  6, 6, 90, 3, 44, 8, 34, 5, 24, 
    3, 19, 7, 22, 2, 75, 4, 90, 5, 26, 8, 64, 1, 12, 6, 41, 0, 12, 
    3, 39, 1, 55, 0, 41, 4, 64, 2, 35, 7, 81, 5, 23, 8, 76, 6, 24, 
    0, 47, 2, 60, 4, 95, 5, 33, 7, 60, 1, 35, 3, 70, 8, 82, 6, 97, 
    5,  3, 7, 51, 1, 24, 8,  2, 2, 10, 0, 37, 3, 22, 6, 57, 4, 68, 
    0, 16, 5, 13, 1, 89, 7, 20, 4, 91, 8, 65, 3, 36, 2, 58, 6, 21, 
    7, 81, 2, 79, 4, 79, 3, 59, 8, 13, 0, 41, 1, 75, 5, 61, 6, 23, 
    4, 36, 2, 68, 0, 26, 6, 25, 7, 28, 8, 29, 1, 23, 3, 61, 5, 69
  };
  const int q8766[] = {
    9, 9, // Number of jobs and machines
    4, 44, 7,  6, 0, 79, 8, 52, 5, 87, 2, 13, 6, 94, 3, 11, 1, 15, 
    7, 45, 8, 50, 4, 83, 6, 50, 5, 89, 3, 49, 1,  5, 0,  1, 2, 57, 
    2,  4, 4, 21, 3,  2, 0, 59, 6, 13, 1, 42, 7, 25, 8, 26, 5, 15, 
    4, 40, 6, 75, 8, 17, 1, 62, 3, 55, 2, 23, 7, 32, 0, 81, 5, 24, 
    6,  9, 7, 57, 4, 70, 8, 99, 0, 87, 1, 34, 5, 36, 2, 71, 3, 23, 
    7, 35, 3,  2, 1,  5, 8, 74, 2, 49, 0, 42, 5, 64, 6, 38, 4, 57, 
    6, 53, 2, 28, 7, 95, 4,  1, 3, 26, 0, 17, 1, 60, 5, 19, 8, 82, 
    6, 44, 7,  1, 1, 89, 8, 68, 0, 65, 5, 53, 2, 45, 3,  7, 4, 12, 
    5, 33, 0, 23, 2, 30, 1, 19, 8, 25, 3, 54, 6, 56, 7, 96, 4, 42
  };
  const int q8767[] = {
    9, 9, // Number of jobs and machines
    5, 40, 7, 77, 6, 37, 2, 40, 1, 64, 0, 67, 3, 41, 4, 48, 8, 72, 
    5,  8, 6, 77, 1, 76, 2, 92, 4, 99, 8, 48, 7, 59, 3, 35, 0, 13, 
    1, 84, 0, 70, 2, 69, 7, 81, 6, 96, 3, 88, 5, 79, 4, 37, 8, 93, 
    3, 33, 1, 28, 6,  4, 4, 19, 5, 91, 2, 88, 0, 67, 7, 67, 8, 98, 
    1, 96, 5, 86, 6, 34, 0, 22, 2, 90, 8, 38, 3, 64, 4, 59, 7, 94, 
    8, 93, 2, 80, 6, 62, 5, 20, 7, 52, 0, 76, 4, 59, 1, 22, 3, 68, 
    0, 28, 7, 97, 8, 59, 5, 19, 6,  6, 4,  6, 1, 32, 2, 26, 3, 49, 
    7, 97, 1, 75, 6, 26, 2, 88, 5,  3, 3, 14, 8, 86, 0, 86, 4, 34, 
    0, 17, 6, 32, 4, 76, 3, 92, 1, 13, 8, 26, 5, 10, 2, 12, 7, 64
  };
  const int q8768[] = {
    9, 9, // Number of jobs and machines
    2, 65, 5, 29, 6,  6, 3, 80, 4, 90, 1, 52, 8, 83, 0, 83, 7, 48, 
    8, 26, 6, 33, 0, 77, 4, 20, 1, 35, 5, 57, 3, 86, 2, 30, 7, 44, 
    3, 11, 1, 36, 7, 54, 6, 67, 5, 46, 8,  3, 2,  9, 0, 82, 4,  7, 
    8, 59, 0, 95, 1, 19, 5, 52, 4, 71, 2,  2, 3, 12, 6, 58, 7, 21, 
    8, 90, 5, 68, 7, 73, 3,  6, 0, 18, 6, 38, 4, 87, 2, 88, 1, 78, 
    6, 11, 4,  3, 7, 90, 5, 45, 2, 30, 3, 73, 8, 81, 1,  9, 0, 24, 
    4, 42, 7, 71, 5, 88, 1,  1, 3, 36, 2, 40, 6, 35, 8, 86, 0, 96, 
    5, 72, 8, 67, 2, 78, 7, 42, 6, 43, 0, 29, 4, 15, 1, 91, 3, 61, 
    4, 49, 7, 81, 1, 71, 3, 14, 8, 47, 2, 18, 0, 81, 5, 72, 6, 89
  };
  const int q8769[] = {
    9, 9, // Number of jobs and machines
    2, 35, 0, 96, 7, 29, 6, 68, 4, 36, 1, 11, 5, 15, 3, 51, 8, 10, 
    3, 89, 0,  1, 6, 52, 5, 39, 4, 39, 8, 51, 7, 76, 2, 60, 1, 51, 
    7, 65, 0,  7, 5, 69, 6, 24, 8, 13, 4, 52, 3,  6, 1, 97, 2, 77, 
    2, 20, 1, 49, 7, 92, 5, 17, 6, 72, 8, 12, 0, 81, 3, 45, 4, 44, 
    1, 28, 4, 28, 5, 53, 3, 41, 8, 28, 2, 75, 7, 96, 0, 16, 6, 79, 
    1, 14, 2, 44, 3, 23, 7, 58, 4,  9, 5, 73, 0, 61, 8, 94, 6, 99, 
    4, 62, 1, 49, 2, 68, 6, 84, 8, 68, 3, 86, 7, 17, 5, 31, 0, 38, 
    2, 31, 8, 35, 4, 76, 0,  1, 3, 90, 6, 60, 7,  2, 5, 81, 1, 58, 
    0, 87, 1, 23, 6, 12, 5, 47, 7, 96, 2,  3, 8, 65, 3, 16, 4, 50
  };
  const int q8770[] = {
    9, 9, // Number of jobs and machines
    5, 49, 8, 67, 4, 15, 0, 87, 3, 99, 1, 74, 2, 41, 6, 88, 7, 74, 
    4, 43, 0, 38, 1, 11, 8, 76, 7, 37, 5,  1, 2, 15, 6,  7, 3, 86, 
    5, 54, 0, 82, 2, 96, 4, 67, 8, 22, 1, 54, 7, 80, 3, 68, 6, 29, 
    6, 61, 5, 60, 4, 61, 8, 83, 1,  2, 2, 30, 0, 21, 3, 50, 7, 94, 
    8, 36, 4, 95, 1, 14, 5, 93, 0, 96, 2, 31, 7, 37, 3, 78, 6, 52, 
    0, 90, 3, 90, 1, 19, 8, 40, 5, 23, 6, 34, 2,  6, 4, 73, 7, 92, 
    7, 17, 8, 94, 5, 23, 2, 57, 3, 56, 0, 69, 1, 30, 6, 67, 4, 40, 
    4,  5, 8, 97, 0, 37, 3, 54, 2, 98, 1, 45, 7, 59, 5, 80, 6, 33, 
    7, 15, 2, 50, 4,  4, 6, 13, 0, 11, 5,  8, 1, 89, 8, 15, 3, 12
  };
  const int q8771[] = {
    9, 9, // Number of jobs and machines
    6, 21, 0, 61, 1, 92, 7, 27, 4, 31, 3,  6, 8, 13, 2, 92, 5, 83, 
    4, 97, 1, 47, 5, 89, 6, 70, 3, 26, 0, 32, 7,  2, 2, 17, 8, 14, 
    6, 98, 4, 65, 2, 89, 0, 91, 8, 31, 1, 84, 7, 76, 5, 98, 3, 25, 
    4, 77, 5, 25, 8, 39, 3, 73, 6, 31, 2, 77, 1, 74, 7, 62, 0,  5, 
    8, 56, 3, 10, 5, 19, 0, 35, 6, 58, 2, 76, 7, 88, 4, 61, 1, 65, 
    0,  2, 6, 94, 2, 58, 3,  7, 7, 49, 5, 27, 1, 47, 8,  4, 4, 59, 
    8, 72, 2, 86, 7, 16, 5, 20, 0,  8, 4, 20, 3, 11, 6, 53, 1,  8, 
    7, 91, 8, 46, 0, 86, 2, 65, 6, 71, 5, 12, 4, 74, 3, 14, 1, 19, 
    1, 54, 3, 25, 6,  2, 8, 44, 0, 46, 5, 41, 4, 40, 2, 72, 7,  8
  };
  const int q8772[] = {
    9, 9, // Number of jobs and machines
    4, 52, 3, 83, 5,  2, 2, 93, 1, 23, 7, 59, 6, 50, 0, 91, 8, 47, 
    2, 93, 4, 28, 6, 29, 7, 61, 1, 47, 3, 16, 5, 43, 8, 93, 0,  6, 
    1, 95, 5, 72, 6, 15, 3, 45, 8, 90, 4, 84, 2, 38, 0, 86, 7, 45, 
    1, 84, 6, 51, 7, 67, 2, 72, 3, 61, 4, 18, 8,  7, 0, 14, 5, 74, 
    8, 47, 2, 53, 7, 86, 5, 79, 6, 59, 0, 53, 1, 83, 3, 17, 4, 80, 
    3,  3, 0, 31, 7, 46, 1, 88, 4, 33, 6, 56, 8, 70, 5, 69, 2, 21, 
    6, 33, 2, 71, 0, 45, 1, 69, 3, 44, 8,  2, 4, 21, 5, 15, 7, 15, 
    0, 93, 4, 57, 7,  7, 8,  1, 1, 75, 6, 83, 2, 68, 5, 74, 3, 62, 
    1, 38, 7, 34, 5, 71, 3, 91, 8, 10, 6, 98, 0,  7, 4,  4, 2, 18
  };
  const int q8773[] = {
    9, 9, // Number of jobs and machines
    7, 38, 4, 41, 6, 32, 8, 19, 3, 66, 1, 20, 2,  9, 0, 66, 5, 54, 
    5, 75, 6, 88, 8, 29, 2, 56, 3, 82, 7, 59, 1,  1, 4, 79, 0, 29, 
    0, 40, 2, 83, 8, 54, 7, 89, 1,  1, 4, 50, 3, 76, 6, 70, 5, 68, 
    8, 51, 6, 56, 5, 23, 2, 14, 0,  8, 3, 61, 7, 71, 1, 39, 4, 31, 
    3, 48, 2, 84, 1,  9, 5, 31, 4, 20, 7, 18, 6, 79, 8, 43, 0, 24, 
    4,  8, 6, 84, 0, 35, 1, 90, 2, 15, 8, 64, 3, 69, 7, 76, 5, 24, 
    1, 21, 2, 59, 8,  1, 6, 87, 3, 54, 4, 58, 7, 84, 5, 62, 0, 28, 
    7, 72, 0, 35, 4, 47, 2, 41, 1, 82, 3, 39, 8, 61, 6, 18, 5, 77, 
    6, 20, 3, 46, 0, 17, 5, 43, 8, 27, 2, 64, 1, 33, 7,  9, 4, 76
  };
  const int q8774[] = {
    9, 9, // Number of jobs and machines
    3, 36, 2, 36, 0,  4, 5, 39, 6, 70, 4, 85, 1, 62, 7,  9, 8, 35, 
    4, 83, 2, 72, 3, 11, 1, 93, 6, 58, 7, 30, 8, 16, 0, 61, 5, 24, 
    1,  7, 8, 19, 3, 57, 2, 76, 4,  9, 5,  3, 6,  6, 0, 47, 7, 45, 
    0, 51, 8, 50, 1,  9, 5, 32, 6, 94, 4, 46, 7, 40, 2, 19, 3, 51, 
    8, 82, 3, 85, 4, 52, 0, 52, 5, 87, 1, 57, 6, 80, 7, 94, 2, 63, 
    1, 93, 5, 82, 3, 33, 0, 91, 8, 64, 2, 32, 6, 50, 4, 93, 7, 56, 
    2, 18, 4, 82, 5, 69, 0, 31, 6, 97, 3, 96, 7, 12, 8, 23, 1, 58, 
    8,  4, 4, 66, 7, 44, 1, 63, 0, 86, 2, 31, 3, 74, 6, 99, 5, 54, 
    4, 28, 0, 42, 5, 80, 3, 84, 1, 19, 7, 57, 6, 61, 2, 40, 8, 35
  };
  const int q8775[] = {
    9, 9, // Number of jobs and machines
    2, 56, 7, 32, 3, 49, 8, 35, 4, 15, 6, 72, 5, 77, 1, 25, 0, 89, 
    0, 65, 1, 86, 7,  6, 4, 74, 8, 38, 3, 15, 5, 52, 6, 30, 2, 85, 
    3, 25, 7, 77, 2, 49, 5, 82, 4, 59, 1, 18, 8, 98, 0, 57, 6, 43, 
    0, 72, 6, 79, 7, 19, 3, 33, 1, 27, 2, 43, 4, 44, 5, 36, 8, 91, 
    2, 68, 5,  6, 4, 30, 3, 94, 6, 43, 7, 90, 1, 72, 0, 96, 8, 45, 
    3,  7, 0, 29, 2, 35, 7,  2, 1, 17, 6, 17, 5, 71, 8, 85, 4, 97, 
    4, 14, 5, 94, 2,  3, 6, 45, 8, 73, 7, 55, 1, 87, 3, 34, 0, 75, 
    1, 47, 7, 35, 2, 54, 0,  9, 8, 37, 5, 73, 3, 40, 6, 24, 4, 53, 
    7, 89, 3, 64, 2, 86, 0, 35, 8, 58, 6, 42, 1, 24, 5, 99, 4, 42
  };
  const int q8776[] = {
    9, 9, // Number of jobs and machines
    1, 77, 0, 89, 3, 22, 8, 38, 7, 83, 6, 37, 4, 67, 2, 58, 5, 49, 
    4, 47, 8, 30, 3, 80, 6, 90, 2, 63, 0, 22, 1, 76, 5, 34, 7,  6, 
    7, 66, 5, 82, 4, 15, 2, 39, 3, 24, 6, 21, 1, 24, 0, 68, 8,  5, 
    7, 87, 0, 71, 4, 41, 1, 42, 5, 43, 6, 68, 2, 60, 3, 78, 8, 92, 
    5, 44, 1, 37, 8, 94, 0,  4, 2, 68, 6, 34, 3, 96, 4, 65, 7, 23, 
    4, 79, 6, 11, 1, 52, 2, 63, 8, 50, 5, 18, 0,  6, 7, 74, 3, 11, 
    7, 26, 4, 97, 2, 83, 3, 56, 8, 50, 5, 43, 1, 85, 0, 72, 6, 95, 
    8, 94, 7, 93, 5,  5, 6,  9, 0, 42, 3, 13, 1, 67, 2, 29, 4, 58, 
    4, 39, 6, 26, 3, 62, 7, 70, 0, 65, 8, 60, 2,  5, 1,  2, 5,  5
  };
  const int q8777[] = {
    9, 9, // Number of jobs and machines
    8, 55, 1, 58, 4, 15, 6, 42, 5, 16, 7, 24, 2, 19, 0, 20, 3, 24, 
    7, 88, 8, 86, 4, 60, 2, 91, 0, 39, 6, 53, 3, 68, 1, 73, 5, 72, 
    2, 91, 8, 48, 6, 11, 0, 32, 5, 66, 7, 34, 4, 82, 3, 32, 1, 19, 
    3, 16, 7, 69, 6,  1, 5, 46, 1, 16, 2, 48, 4, 95, 0, 49, 8, 29, 
    0, 78, 7, 54, 4,  6, 8, 98, 6, 70, 2, 94, 1, 35, 3, 81, 5, 86, 
    0, 24, 2, 90, 6, 41, 5, 53, 8,  7, 4, 82, 1, 31, 3, 62, 7, 83, 
    6, 84, 2, 43, 0, 69, 5, 29, 3, 16, 1, 22, 7, 92, 4, 29, 8, 80, 
    2, 55, 0, 55, 8, 87, 6, 80, 5, 39, 4, 81, 3, 70, 7, 13, 1, 89, 
    7, 21, 5, 86, 6, 25, 3, 95, 0, 50, 1, 15, 4, 50, 8, 75, 2, 14
  };
  const int q8778[] = {
    9, 9, // Number of jobs and machines
    7,  3, 8, 73, 3, 62, 4, 71, 5, 92, 6, 17, 0, 58, 2, 12, 1, 16, 
    2, 78, 4, 26, 7, 72, 6, 50, 0, 46, 8, 50, 5,  9, 1, 78, 3, 37, 
    0, 90, 2, 68, 5, 90, 7, 88, 1, 31, 8, 15, 4, 94, 3, 52, 6, 81, 
    8, 67, 0, 69, 7, 56, 1, 61, 3, 91, 5, 72, 2, 85, 6, 85, 4, 34, 
    0, 17, 3,  3, 2, 11, 5, 94, 7, 45, 6, 75, 8, 59, 4, 46, 1, 54, 
    8,  3, 5, 40, 1, 24, 6, 95, 0, 77, 7,  2, 4, 53, 3, 77, 2, 57, 
    7, 44, 1, 10, 8, 54, 4, 81, 3, 53, 0, 32, 5, 19, 2, 48, 6, 63, 
    1, 67, 8, 89, 5, 66, 6, 77, 0, 73, 3, 66, 7, 56, 2,  7, 4,  2, 
    1, 51, 5, 85, 2, 37, 6, 51, 8, 94, 4, 89, 0, 50, 7,  7, 3, 43
  };
  const int q8779[] = {
    9, 9, // Number of jobs and machines
    4, 41, 2, 24, 1, 67, 5, 27, 3, 46, 0, 17, 7, 53, 6, 54, 8, 76, 
    7, 38, 2, 79, 3,  2, 8, 46, 6, 76, 0, 42, 1, 87, 5, 75, 4, 48, 
    7, 74, 0, 19, 5, 24, 2, 98, 3, 41, 6, 59, 1, 38, 8, 61, 4, 63, 
    2, 17, 6, 92, 8, 12, 5, 65, 0, 85, 4,  1, 7, 58, 3, 56, 1, 83, 
    8, 78, 6, 25, 0, 88, 3, 81, 2, 78, 5,  2, 7, 42, 4, 49, 1, 54, 
    2,  6, 1, 64, 4, 61, 3, 85, 7, 68, 6, 26, 0, 22, 5,  8, 8, 47, 
    7, 64, 3,  6, 2, 85, 0, 23, 8, 52, 6,  8, 1, 57, 4, 38, 5,  8, 
    0, 77, 1, 72, 7, 46, 4, 66, 2, 57, 5, 12, 6, 63, 8, 88, 3, 82, 
    5, 55, 6, 54, 7, 68, 0, 31, 4, 39, 1, 70, 2, 44, 8, 39, 3, 97
  };
  const int q8780[] = {
    9, 9, // Number of jobs and machines
    3, 20, 0, 59, 6, 97, 8, 16, 7, 89, 1, 79, 5, 28, 4, 48, 2, 40, 
    0, 75, 1, 22, 8, 39, 2, 29, 3, 62, 4, 88, 6, 87, 7, 58, 5, 26, 
    0, 86, 7, 50, 4, 17, 8,  6, 3, 92, 2, 28, 6, 48, 1, 98, 5, 89, 
    6, 23, 4, 51, 8, 12, 5, 23, 0, 85, 7,  6, 2, 23, 3,  7, 1, 51, 
    5, 43, 8, 48, 0, 54, 1, 24, 2, 66, 3, 28, 6,  7, 7, 87, 4, 18, 
    2, 34, 0, 45, 8,  9, 6, 75, 5, 97, 3, 78, 7, 15, 4, 17, 1, 43, 
    8,  5, 5,  6, 7, 30, 6, 14, 2, 92, 4,  5, 1, 68, 0, 72, 3, 73, 
    8, 56, 0, 61, 5, 40, 1,  5, 4, 90, 6, 79, 7,  1, 2, 66, 3,  8, 
    5, 72, 6, 67, 1, 36, 4, 82, 3,  1, 0, 13, 7, 42, 8, 63, 2, 72
  };
  const int q8781[] = {
    9, 9, // Number of jobs and machines
    0, 18, 3, 21, 7, 60, 8, 49, 2, 12, 4, 27, 6, 71, 5, 21, 1, 36, 
    3, 36, 6, 66, 1, 33, 7, 64, 4, 80, 5, 37, 2, 84, 0, 59, 8, 28, 
    5, 76, 8, 35, 2,  3, 0, 50, 4, 28, 1, 38, 7, 60, 3, 77, 6,  8, 
    3, 36, 4, 40, 0, 52, 7, 61, 2, 13, 5,  4, 1, 20, 8, 68, 6, 50, 
    1, 25, 4,  9, 7, 61, 2, 82, 6, 75, 8, 91, 0, 63, 5, 72, 3, 92, 
    7, 50, 0, 97, 5, 47, 4, 84, 3, 81, 2, 40, 1, 95, 8, 74, 6, 51, 
    4, 81, 5, 52, 3, 15, 2, 33, 1, 68, 0, 43, 6, 41, 7, 52, 8, 61, 
    1, 52, 2, 52, 8, 59, 4, 55, 7, 45, 3, 23, 0, 34, 6, 87, 5, 19, 
    3, 15, 5, 31, 6, 87, 1, 85, 0, 53, 8, 42, 7, 40, 4, 52, 2, 32
  };
  const int q8782[] = {
    9, 9, // Number of jobs and machines
    7, 94, 2, 82, 5, 39, 3, 20, 0, 74, 4, 49, 1, 51, 6, 97, 8, 11, 
    8, 67, 7,  5, 1, 78, 4, 41, 5, 29, 3, 37, 2, 12, 0, 25, 6,  4, 
    7, 79, 5, 23, 2, 95, 3, 71, 0, 40, 4, 73, 6, 41, 8, 61, 1, 95, 
    1,  7, 6, 24, 0, 27, 3, 97, 4, 66, 2, 98, 8, 59, 5, 43, 7, 36, 
    4, 38, 3, 80, 6, 10, 7, 65, 2,  2, 0, 39, 8, 57, 1, 89, 5, 42, 
    1, 51, 2, 79, 6, 58, 4, 29, 3, 52, 8,  9, 7, 41, 0, 30, 5, 28, 
    3, 16, 0, 82, 5,  4, 8, 46, 1,  8, 7, 41, 4,  6, 2, 15, 6, 74, 
    5, 86, 0, 55, 2,  6, 6, 12, 7, 48, 1, 68, 4, 67, 8, 22, 3, 20, 
    8, 44, 4, 28, 3, 91, 5, 86, 7, 78, 1, 29, 0,  3, 2, 10, 6, 50
  };
  const int q8783[] = {
    9, 9, // Number of jobs and machines
    1, 78, 8, 28, 2, 37, 0, 95, 6, 20, 7, 75, 3, 96, 4,  8, 5, 37, 
    8, 56, 4, 21, 6, 89, 7, 45, 0, 62, 1, 61, 5, 70, 3, 98, 2, 72, 
    2, 54, 1, 41, 5, 17, 6, 56, 4, 64, 8, 10, 0, 74, 7, 79, 3, 19, 
    4, 98, 5, 45, 8, 31, 3, 53, 7, 21, 2, 33, 0, 85, 6,  8, 1, 17, 
    2, 70, 3, 20, 5, 15, 8, 91, 7, 11, 6, 99, 4, 87, 0, 51, 1,  3, 
    4, 72, 7, 82, 0, 33, 1, 22, 8,  7, 5, 19, 2, 59, 3, 35, 6, 39, 
    3, 34, 5, 51, 6, 97, 0, 98, 4, 62, 8, 77, 1, 54, 7, 96, 2,  3, 
    6, 10, 7,  4, 4, 86, 8, 89, 0, 49, 5, 46, 3, 54, 2, 79, 1, 27, 
    2, 87, 1, 31, 4, 36, 7,  4, 5, 48, 3, 17, 6, 51, 8, 33, 0, 19
  };
  const int q8784[] = {
    9, 9, // Number of jobs and machines
    7, 71, 1, 95, 5, 31, 8, 45, 3, 28, 4, 76, 6, 99, 0,  1, 2, 31, 
    4,  1, 7, 80, 2, 70, 0, 90, 8, 34, 3,  9, 1, 99, 5, 62, 6, 76, 
    2, 32, 3, 74, 6, 98, 4, 83, 0,  4, 5, 56, 8, 62, 1, 31, 7, 59, 
    2, 13, 0, 47, 8, 74, 6, 87, 7, 40, 1, 35, 3, 30, 4, 58, 5, 89, 
    8,  5, 2, 97, 1, 62, 0, 68, 5, 89, 4, 88, 6, 69, 7,  6, 3, 35, 
    7,  7, 0, 51, 4, 80, 5, 28, 8, 25, 6, 17, 1, 45, 3, 35, 2, 54, 
    3,  1, 0, 73, 4, 53, 8, 67, 5, 86, 1,  7, 6, 93, 2, 98, 7, 34, 
    4, 70, 1, 43, 5, 28, 0,  8, 8, 50, 2, 84, 7, 67, 6, 31, 3, 63, 
    7, 76, 2, 28, 3, 41, 1, 19, 0, 45, 5, 96, 8,  2, 6, 11, 4, 18
  };
  const int q8785[] = {
    9, 9, // Number of jobs and machines
    4,  5, 1, 84, 7, 86, 2, 83, 0, 98, 3, 87, 5, 49, 6, 40, 8, 66, 
    6, 56, 7, 57, 4, 78, 1, 82, 5, 51, 2, 83, 8, 89, 3, 70, 0, 98, 
    6, 82, 8, 89, 2, 53, 3, 60, 7, 88, 1, 43, 4,  2, 5, 71, 0, 16, 
    3, 17, 5, 60, 6, 56, 0, 67, 4, 96, 2,  3, 8, 98, 1, 12, 7,  1, 
    3, 30, 8, 96, 0, 30, 4, 69, 5, 43, 1, 46, 7, 10, 2, 43, 6, 21, 
    6,  5, 3, 17, 4, 98, 0, 20, 5, 90, 1, 93, 8, 65, 2, 52, 7,  8, 
    0, 51, 6, 22, 8, 32, 4, 37, 3, 61, 7, 61, 1,  1, 5, 81, 2, 87, 
    1,  3, 3, 38, 2, 24, 8, 84, 4, 89, 5, 74, 7, 67, 0, 61, 6, 43, 
    3, 34, 1, 56, 4, 68, 6, 35, 5, 38, 2, 93, 0, 30, 8, 99, 7, 15
  };
  const int q8786[] = {
    9, 9, // Number of jobs and machines
    0, 83, 6,  3, 7, 83, 8, 36, 5, 69, 4, 23, 3, 46, 1, 13, 2, 68, 
    7, 16, 6, 71, 4, 50, 2, 86, 3, 70, 8, 70, 0, 68, 5, 52, 1,  5, 
    5, 64, 2, 17, 3, 61, 4, 25, 8, 82, 6, 78, 7, 26, 0, 60, 1, 17, 
    7, 53, 0, 52, 8, 77, 5, 65, 2,  8, 4, 29, 3, 18, 1, 94, 6, 44, 
    1, 60, 0,  5, 3, 66, 2, 91, 4, 84, 7, 93, 5, 40, 8, 31, 6, 48, 
    3, 65, 5, 97, 1, 79, 2,  4, 7, 26, 6,  2, 0, 40, 8, 25, 4, 86, 
    3, 39, 8, 43, 5, 40, 6, 34, 0, 22, 4, 29, 7, 89, 2, 40, 1, 76, 
    4, 24, 1, 66, 2, 79, 7, 58, 0, 58, 6, 28, 5, 84, 8, 70, 3, 34, 
    3, 77, 0,  5, 4, 91, 7, 24, 8, 60, 1,  3, 5, 64, 2,  6, 6, 11
  };
  const int q8787[] = {
    9, 9, // Number of jobs and machines
    3, 59, 4, 24, 6, 65, 2, 51, 8, 35, 1, 98, 7, 70, 0, 82, 5, 65, 
    1, 75, 5, 96, 2, 57, 8, 27, 4, 17, 3, 52, 6, 22, 0, 83, 7, 66, 
    3, 83, 8,  8, 1, 31, 6, 70, 5, 27, 7, 62, 0, 88, 4, 18, 2, 33, 
    3, 99, 1, 20, 8, 42, 4, 96, 5, 62, 6, 11, 0, 67, 7, 24, 2, 82, 
    3, 15, 4, 57, 6, 65, 7, 63, 8, 19, 2, 74, 0, 40, 1, 11, 5, 66, 
    8,  4, 6, 25, 2, 48, 5, 14, 4, 29, 0, 62, 1, 49, 3, 45, 7, 17, 
    7, 81, 8, 64, 1, 74, 4, 32, 0, 24, 3, 35, 6, 21, 5, 25, 2, 72, 
    6, 76, 2, 93, 0, 57, 4, 22, 3, 38, 7, 74, 1, 36, 8, 98, 5, 80, 
    4, 48, 8, 41, 0, 30, 6, 85, 3,  3, 2, 48, 7, 96, 1, 80, 5, 57
  };
  const int q8788[] = {
    9, 9, // Number of jobs and machines
    5, 42, 7, 33, 8, 30, 2, 81, 3, 80, 6, 58, 4, 12, 1, 38, 0, 51, 
    4, 86, 0, 10, 6, 68, 2, 70, 5, 95, 8, 81, 1, 61, 7, 79, 3, 33, 
    5, 58, 1, 76, 0, 99, 4, 45, 6, 96, 2, 94, 7, 83, 8, 76, 3, 76, 
    3, 33, 1, 78, 5, 48, 6, 87, 8, 10, 7, 90, 2, 51, 0,  4, 4, 98, 
    2, 86, 4, 13, 1, 31, 3, 43, 7,  8, 5, 16, 6, 31, 0, 54, 8, 27, 
    7, 14, 0, 24, 5, 15, 8, 52, 2, 56, 6,  1, 3, 41, 4, 94, 1, 89, 
    1, 42, 0,  8, 2, 47, 6, 26, 7, 36, 5, 52, 8, 40, 4, 44, 3, 37, 
    1, 66, 3, 51, 5, 91, 8, 43, 6, 12, 7, 20, 4, 36, 2, 13, 0,  9, 
    2, 20, 0, 39, 5, 12, 1, 29, 6, 76, 8, 18, 4, 86, 7, 90, 3, 16
  };
  const int q8789[] = {
    9, 9, // Number of jobs and machines
    6, 39, 0, 46, 2, 51, 5, 99, 7, 84, 3, 30, 1, 41, 8, 26, 4, 70, 
    8, 33, 2, 61, 4, 55, 0,  1, 7, 78, 6, 32, 3, 51, 1, 59, 5, 24, 
    4, 85, 7, 60, 6,  1, 8, 97, 2, 93, 5,  5, 0, 48, 3, 83, 1, 70, 
    0, 23, 5, 90, 7, 80, 3, 85, 8, 66, 6, 62, 1,  3, 2,  8, 4, 73, 
    5, 60, 4, 18, 6, 93, 3, 76, 8, 36, 7, 53, 1, 45, 2, 78, 0, 78, 
    3, 86, 5, 27, 0, 85, 4, 95, 7, 14, 8, 62, 2, 99, 6, 16, 1, 70, 
    8, 59, 2, 57, 4, 81, 3, 48, 1, 23, 7, 58, 0, 71, 6, 19, 5,  4, 
    3, 91, 7, 43, 4, 62, 5,  8, 8,  3, 0, 86, 2,  7, 1, 50, 6,  9, 
    2, 49, 3, 65, 6, 99, 8, 86, 5, 44, 1, 39, 0, 90, 7, 43, 4, 34
  };
  const int q8790[] = {
    9, 9, // Number of jobs and machines
    1, 43, 8, 53, 7, 28, 0, 32, 3, 74, 6, 77, 5,  6, 4, 12, 2, 29, 
    7, 78, 6, 99, 8, 19, 1, 93, 4, 31, 3, 72, 2, 45, 0, 20, 5, 55, 
    0, 90, 2, 23, 5, 19, 8, 73, 1, 18, 6, 10, 7, 93, 4, 81, 3, 62, 
    0, 22, 4, 10, 7, 91, 2, 83, 6, 64, 1, 33, 5, 97, 8, 31, 3, 12, 
    6, 40, 5, 40, 2, 97, 3, 33, 4, 82, 1, 43, 7,  3, 8, 68, 0, 81, 
    0, 98, 2, 47, 5, 49, 7, 88, 6, 97, 3, 34, 4, 21, 1, 27, 8, 98, 
    5, 90, 4, 89, 8,  6, 2,  6, 0, 41, 6, 28, 7, 36, 1, 84, 3, 23, 
    4, 42, 1, 30, 2, 94, 3, 57, 7, 94, 5,  3, 6, 14, 8, 61, 0, 19, 
    2, 96, 0, 69, 8, 37, 3, 90, 6, 81, 1, 66, 4, 67, 5, 78, 7, 13
  };
  const int q8791[] = {
    9, 9, // Number of jobs and machines
    1, 92, 4, 44, 3, 60, 7, 70, 5, 77, 0, 15, 6, 35, 8, 41, 2, 69, 
    2, 18, 7, 67, 0, 30, 3, 71, 6, 54, 8, 19, 5, 88, 1, 97, 4, 77, 
    8,  9, 0, 72, 2, 52, 6, 47, 5, 42, 1, 36, 7, 83, 4, 10, 3, 80, 
    6, 25, 1, 38, 8, 20, 4, 57, 3,  3, 2, 81, 5, 91, 0, 83, 7, 61, 
    5, 29, 2, 54, 0, 91, 3, 23, 7, 27, 6, 57, 1, 98, 4, 88, 8, 98, 
    8, 71, 1, 75, 3, 93, 2, 31, 0, 99, 5, 79, 4, 99, 6, 78, 7, 92, 
    0, 98, 3, 86, 2, 90, 6,  5, 5, 75, 8, 73, 1, 53, 4, 81, 7, 87, 
    7,  1, 8,  6, 3, 68, 5, 35, 2, 91, 0, 30, 6, 22, 1, 36, 4, 37, 
    7, 44, 2, 44, 5, 11, 0,  7, 3,  4, 4, 44, 6, 16, 1, 83, 8, 94
  };
  const int q8792[] = {
    9, 9, // Number of jobs and machines
    4, 95, 8, 71, 2, 48, 0, 65, 5,  7, 3, 53, 6, 61, 7, 16, 1, 61, 
    6, 90, 3, 37, 8,  5, 0, 82, 2, 30, 4,  1, 7,  3, 5, 15, 1, 22, 
    6, 14, 8, 25, 0, 16, 4,  1, 2, 16, 3, 15, 5, 78, 1, 18, 7, 65, 
    6, 84, 1, 23, 7, 49, 3, 41, 8, 50, 0, 51, 4, 15, 5, 91, 2, 52, 
    3, 68, 2, 75, 1, 46, 8, 98, 4, 66, 7, 45, 6,  6, 5, 49, 0, 36, 
    0, 73, 1,  1, 8, 13, 3, 53, 4, 68, 6, 30, 5, 66, 7, 31, 2, 38, 
    3, 58, 2, 78, 1, 10, 8, 53, 0,  5, 4, 25, 6, 98, 7,  5, 5, 40, 
    7, 13, 1, 16, 2, 56, 8, 56, 6, 14, 3, 11, 0, 31, 5, 92, 4, 65, 
    5, 85, 2, 81, 8,  6, 6, 75, 7, 95, 4,  6, 1, 58, 0, 88, 3, 39
  };
  const int q8793[] = {
    9, 9, // Number of jobs and machines
    1, 67, 4, 60, 8,  3, 5,  5, 6, 75, 7, 73, 3, 70, 0, 96, 2,  3, 
    2, 78, 5, 28, 7,  3, 6, 67, 3, 74, 1, 61, 0, 67, 8, 56, 4, 58, 
    3,  6, 1, 31, 5, 85, 0, 29, 7, 92, 4, 47, 6, 16, 2, 44, 8, 35, 
    3, 90, 4, 47, 1, 14, 7, 46, 2, 57, 6, 18, 5, 40, 0, 85, 8,  5, 
    5, 46, 4,  3, 8,  3, 0, 11, 6, 22, 2, 95, 3, 44, 1, 58, 7,  4, 
    8, 65, 7, 27, 5, 60, 4, 29, 3,  3, 6, 32, 0, 59, 1, 33, 2, 70, 
    7, 64, 3, 16, 5, 10, 2, 86, 4, 83, 1, 99, 0, 54, 6, 42, 8, 94, 
    5, 36, 4,  7, 1, 23, 7, 29, 8, 46, 2, 91, 3, 17, 6, 77, 0, 64, 
    8, 78, 4, 22, 7, 15, 5, 26, 0, 46, 2, 49, 1, 83, 3, 38, 6, 92
  };
  const int q8794[] = {
    9, 9, // Number of jobs and machines
    8, 27, 1, 83, 0, 42, 7, 94, 6, 59, 3, 17, 4, 91, 5,  5, 2, 90, 
    4, 77, 5, 23, 1, 62, 3, 91, 2, 51, 7, 91, 0, 51, 6, 83, 8, 71, 
    8, 25, 6,  7, 3,  8, 0, 56, 1, 43, 2, 90, 5,  9, 4, 66, 7, 78, 
    1, 54, 7, 70, 8, 19, 5, 49, 2, 28, 3, 33, 0, 37, 4, 53, 6, 84, 
    7,  8, 5, 37, 4, 89, 6, 89, 3, 59, 1, 37, 2, 31, 8, 60, 0, 95, 
    2, 97, 7, 71, 3, 91, 0, 10, 6, 83, 5, 53, 8, 36, 1, 88, 4, 16, 
    4, 84, 1, 26, 6, 51, 7, 97, 2, 39, 0, 13, 8, 20, 3, 38, 5, 98, 
    1, 23, 8, 71, 0, 36, 3,  4, 4, 49, 5, 50, 6, 52, 7, 55, 2, 99, 
    6, 71, 2, 32, 3, 46, 8, 83, 4, 12, 7, 37, 1, 78, 5,  8, 0, 52
  };
  const int q8795[] = {
    9, 9, // Number of jobs and machines
    1, 43, 4,  2, 5, 68, 7, 43, 3, 28, 8,  1, 2, 79, 0, 11, 6, 77, 
    8, 84, 0, 45, 7, 39, 5, 99, 3, 18, 6, 90, 2, 98, 1, 77, 4, 86, 
    6, 65, 4, 52, 1, 71, 5,  3, 3, 79, 8, 30, 7, 64, 2,  2, 0,  2, 
    4, 48, 5, 96, 7, 87, 1,  3, 0, 66, 3, 28, 8, 75, 2, 18, 6, 33, 
    2, 51, 0, 36, 7, 84, 5, 67, 4, 68, 6, 78, 3, 48, 8, 21, 1, 94, 
    0, 66, 8, 60, 7, 45, 6, 94, 3, 91, 1,  1, 4, 36, 2, 35, 5, 60, 
    1, 54, 7, 94, 6, 96, 5, 16, 4, 58, 2, 24, 3, 71, 8, 97, 0, 87, 
    8, 17, 1, 34, 2, 76, 6, 60, 3, 14, 4, 45, 7, 93, 5, 75, 0, 29, 
    2, 39, 1,  3, 8,  4, 6, 11, 0, 72, 4, 12, 7, 16, 3, 84, 5, 55
  };
  const int q8796[] = {
    9, 9, // Number of jobs and machines
    1, 54, 7, 31, 5, 41, 6, 72, 3, 46, 4, 50, 0, 45, 2, 82, 8, 25, 
    8, 12, 0, 21, 4, 54, 2, 30, 3, 55, 7, 82, 6, 21, 1, 27, 5, 90, 
    2, 57, 5,  2, 8, 20, 0, 20, 3, 73, 7, 33, 4, 70, 1, 51, 6, 93, 
    3, 48, 2, 76, 0, 54, 1, 67, 4, 57, 8, 22, 7, 31, 5, 25, 6, 70, 
    3, 60, 8, 18, 6, 49, 7, 27, 4,  3, 0, 97, 2, 95, 5, 69, 1, 70, 
    5, 54, 3, 85, 2, 83, 6, 30, 1, 14, 8, 39, 0, 17, 4, 96, 7, 34, 
    1, 86, 4, 74, 8, 45, 7, 80, 6, 97, 0, 73, 2, 70, 5, 18, 3, 99, 
    5,  7, 1, 51, 2, 15, 7, 40, 4, 10, 8, 81, 6, 15, 3, 32, 0, 87, 
    7, 15, 3, 56, 2, 81, 8, 18, 6, 84, 1,  8, 4, 32, 0, 68, 5, 62
  };
  const int q8797[] = {
    9, 9, // Number of jobs and machines
    6,  7, 8, 45, 2,  1, 4, 69, 3, 22, 1, 91, 5, 75, 0, 68, 7,  8, 
    7, 49, 0, 85, 4, 63, 3, 23, 5, 96, 8, 83, 6,  5, 2,  8, 1, 76, 
    0, 75, 2, 91, 1,  9, 3, 19, 7, 38, 6, 93, 8, 97, 4, 65, 5, 22, 
    2, 76, 6, 18, 1, 60, 7, 87, 0, 17, 3, 89, 5, 80, 8, 27, 4, 75, 
    2, 23, 0, 75, 1, 81, 4, 50, 3, 79, 5, 20, 6, 86, 8, 80, 7, 25, 
    4, 21, 7, 19, 3, 69, 0, 83, 1, 33, 6, 57, 2, 45, 5, 73, 8, 59, 
    7, 24, 0, 12, 3, 39, 5, 14, 1, 55, 8, 42, 4, 66, 2, 52, 6, 10, 
    5, 81, 4, 26, 3,  7, 1, 33, 6, 19, 8, 89, 7,  5, 2, 79, 0, 20, 
    8, 92, 3, 57, 6, 91, 7,  6, 4, 79, 0, 53, 5, 58, 1, 59, 2,  2
  };
  const int q8798[] = {
    9, 9, // Number of jobs and machines
    7,  6, 1, 14, 8, 66, 3, 73, 4, 73, 6, 40, 2, 40, 5, 55, 0, 80, 
    7, 69, 8, 16, 6, 60, 2, 93, 4, 82, 3, 21, 1, 94, 5, 23, 0, 29, 
    8, 97, 1, 44, 3, 25, 6, 59, 7, 14, 4, 35, 0, 58, 2, 43, 5, 68, 
    8, 53, 3, 74, 4, 78, 6, 95, 2, 22, 7, 56, 0,  1, 5, 53, 1, 88, 
    3, 63, 8, 40, 0, 95, 4, 87, 7, 90, 6, 30, 1, 32, 5, 46, 2, 75, 
    7, 29, 8, 28, 5,  3, 4, 82, 2,  5, 6, 97, 0, 85, 3, 88, 1, 30, 
    8, 30, 4, 99, 3, 30, 0, 74, 5, 13, 1, 61, 2, 96, 7, 11, 6, 36, 
    4, 36, 2, 79, 7, 68, 6, 50, 1, 48, 8, 69, 5, 17, 3, 27, 0, 44, 
    8, 41, 0, 41, 7, 27, 3, 24, 4, 14, 2, 97, 6, 48, 5, 30, 1, 88
  };
  const int q8799[] = {
    9, 9, // Number of jobs and machines
    4, 42, 8, 11, 1, 19, 3, 90, 5, 40, 7, 33, 6, 62, 0, 22, 2, 37, 
    8, 10, 4, 55, 3, 96, 1, 58, 0, 70, 2, 60, 5, 45, 7,  4, 6, 24, 
    8, 42, 5, 34, 3,  5, 0, 75, 6, 55, 4, 13, 2, 43, 7, 77, 1,  3, 
    1, 69, 6, 68, 5,  6, 3, 53, 0, 43, 2, 78, 8, 48, 7, 89, 4, 48, 
    6, 83, 4, 61, 2, 75, 3, 62, 8, 41, 0, 69, 7,  5, 5, 74, 1, 95, 
    8, 72, 1, 36, 5, 61, 0, 88, 2, 29, 6,  5, 4, 25, 3, 94, 7, 10, 
    6, 50, 0, 97, 7, 16, 8, 10, 3, 41, 2, 78, 5, 33, 4,  4, 1,  7, 
    8, 42, 0, 53, 2, 22, 7, 51, 6, 34, 3, 80, 1, 23, 5, 68, 4, 44, 
    7,  2, 0, 55, 1, 58, 4, 52, 2, 58, 3, 69, 8, 53, 6, 79, 5,  7
  };
  const int q8800[] = {
    9, 9, // Number of jobs and machines
    5, 79, 4, 57, 0, 20, 7, 73, 1, 23, 6,  1, 2, 38, 3, 18, 8,  9, 
    7, 59, 0, 53, 2, 67, 1, 72, 5, 27, 8, 74, 4, 94, 6, 21, 3, 77, 
    1, 26, 8, 62, 3, 99, 0, 31, 6, 94, 2, 31, 7, 33, 4, 61, 5, 44, 
    7, 26, 4, 51, 0, 34, 2, 13, 6, 87, 5, 11, 8, 67, 3,  8, 1, 75, 
    2, 65, 3, 36, 6, 13, 8, 82, 5, 23, 4, 64, 0, 49, 7, 39, 1, 35, 
    1, 31, 0,  4, 2, 68, 8, 70, 4, 85, 6, 31, 5, 47, 7, 55, 3, 66, 
    8, 19, 6, 76, 3, 73, 7, 71, 4, 24, 2, 13, 5,  8, 0, 65, 1, 68, 
    1, 69, 8, 20, 3, 10, 5, 72, 2, 55, 4, 24, 0, 11, 7, 48, 6, 25, 
    6, 32, 4, 28, 8,  3, 7, 38, 5, 25, 2, 72, 1, 49, 0, 69, 3, 18
  };
  const int q8801[] = {
    9, 9, // Number of jobs and machines
    8, 24, 1, 57, 7, 77, 2, 41, 6, 26, 5, 35, 0, 21, 4, 19, 3, 53, 
    0, 66, 2, 25, 5, 14, 8, 73, 7, 25, 1, 30, 4, 43, 3,  4, 6, 74, 
    7, 93, 2, 45, 0, 69, 8, 80, 4, 60, 6, 60, 1,  3, 5, 34, 3, 89, 
    8, 55, 0, 82, 2, 63, 7, 15, 1, 46, 5, 91, 3, 61, 4, 76, 6, 55, 
    7,  1, 3, 30, 6, 57, 1, 13, 5, 38, 4, 24, 2, 54, 0, 84, 8, 58, 
    3, 22, 5, 75, 7,  1, 0,  4, 4, 11, 8, 52, 1,  8, 6, 74, 2, 10, 
    4, 87, 3, 45, 8, 43, 0, 84, 7, 87, 1, 95, 6, 94, 5, 19, 2, 99, 
    5, 13, 0, 50, 3, 98, 2, 49, 7, 46, 6, 90, 4, 19, 8, 89, 1, 31, 
    3,  2, 7,  9, 6, 74, 8, 22, 1, 48, 0, 70, 4, 36, 2, 73, 5, 76
  };
  const int q8802[] = {
    9, 9, // Number of jobs and machines
    1, 50, 2, 74, 3, 92, 0, 33, 6, 92, 4, 71, 8, 11, 7, 12, 5, 56, 
    5, 93, 7, 42, 1, 47, 0,  8, 4, 64, 2,  1, 8, 56, 6,  9, 3, 47, 
    7, 22, 4, 50, 8, 44, 1, 96, 0, 80, 3, 75, 6, 88, 5, 84, 2, 15, 
    6, 95, 5, 65, 2, 87, 1, 70, 7, 32, 4, 82, 0, 43, 8, 36, 3, 46, 
    5, 21, 8, 96, 3, 14, 0, 58, 4,  6, 6, 53, 2, 45, 1, 26, 7,  1, 
    2, 35, 5, 31, 8, 72, 3, 83, 7, 18, 4, 44, 6, 39, 1, 45, 0, 56, 
    1, 55, 0, 14, 7, 29, 5, 33, 8, 20, 2, 33, 3,  1, 4, 57, 6, 30, 
    8, 85, 5, 30, 4, 24, 0, 66, 2, 69, 3,  8, 1, 95, 7, 41, 6, 81, 
    0, 14, 2, 80, 5, 61, 4, 81, 3, 86, 6, 14, 1, 36, 7, 93, 8, 73
  };
  const int q8803[] = {
    9, 9, // Number of jobs and machines
    4, 16, 3, 22, 0, 44, 7, 54, 2, 73, 5, 89, 8, 91, 6,  4, 1, 50, 
    3, 24, 1, 29, 0, 62, 7, 56, 8, 42, 6, 26, 4, 63, 5, 48, 2, 59, 
    6, 19, 8, 50, 4, 77, 2, 18, 0, 30, 3, 76, 1, 95, 5, 90, 7, 16, 
    7, 11, 1, 58, 8, 37, 0, 55, 6, 57, 3, 20, 4,  3, 5, 18, 2,  1, 
    3, 60, 1, 39, 8, 96, 7, 55, 2, 70, 5, 27, 0, 27, 6, 66, 4, 18, 
    1, 99, 6, 60, 2, 49, 0, 39, 4,  4, 7, 52, 5, 28, 3, 16, 8, 10, 
    7,  3, 3, 21, 6,  5, 4, 74, 2, 72, 8, 79, 1, 45, 0, 92, 5, 99, 
    8, 75, 6, 38, 7, 85, 4, 72, 5, 15, 3, 75, 0, 58, 1, 29, 2, 57, 
    2, 34, 1, 85, 8, 55, 5, 72, 6,  9, 4, 32, 0, 20, 7, 26, 3, 12
  };
  const int q8804[] = {
    9, 9, // Number of jobs and machines
    8,  4, 1, 37, 2, 15, 0,  8, 4, 25, 5, 78, 3, 62, 7, 24, 6, 18, 
    0, 72, 7, 91, 2, 89, 8, 58, 4, 77, 5, 12, 3, 21, 1, 38, 6, 47, 
    8, 69, 4, 13, 0, 29, 7, 33, 5, 53, 2, 13, 3, 57, 1, 61, 6,  6, 
    6, 35, 1, 11, 7, 90, 5, 46, 8, 13, 0, 73, 2, 44, 3, 40, 4, 35, 
    2, 94, 0, 40, 1,  5, 6, 76, 7, 23, 5, 17, 3, 30, 8, 11, 4, 21, 
    6, 24, 0, 89, 3, 31, 5, 10, 8, 12, 2, 48, 4, 14, 7, 60, 1, 94, 
    1, 31, 6, 86, 4,  9, 8, 33, 0, 78, 3, 41, 5, 72, 7, 15, 2, 88, 
    2, 38, 3, 36, 7, 99, 6, 59, 5, 68, 0, 16, 1, 49, 8, 24, 4, 65, 
    5, 46, 8, 15, 0, 74, 3, 82, 2, 73, 6, 25, 4, 36, 7, 18, 1,  1
  };
  const int q8805[] = {
    9, 9, // Number of jobs and machines
    3, 58, 0, 67, 7, 42, 1, 25, 2,  7, 5, 47, 4, 69, 6, 22, 8, 35, 
    4, 80, 3,  7, 6, 55, 5, 46, 1, 54, 0, 55, 7, 73, 8, 51, 2, 60, 
    7, 24, 8, 39, 1, 33, 4, 52, 0, 46, 5, 94, 2, 70, 6, 69, 3, 26, 
    7, 34, 4, 60, 0, 63, 3, 56, 5, 22, 6, 53, 2, 45, 1, 40, 8, 60, 
    1, 53, 4, 68, 0, 92, 2, 48, 6, 21, 5, 83, 8, 88, 3, 49, 7, 82, 
    1, 92, 8,  3, 6, 94, 3, 16, 0, 88, 7, 28, 5, 80, 4, 93, 2, 13, 
    1, 40, 7,  2, 6, 38, 2, 51, 0, 90, 3, 81, 4, 94, 8, 17, 5, 39, 
    4, 64, 3, 92, 5,  2, 7,  5, 2, 60, 1, 63, 6,  2, 0,  2, 8, 15, 
    0, 70, 8, 67, 3, 58, 7, 96, 6, 95, 4, 39, 2, 21, 1, 21, 5,  9
  };
  const int q8806[] = {
    9, 9, // Number of jobs and machines
    3, 73, 2, 11, 8,  3, 1, 19, 4, 53, 6, 66, 0, 79, 7, 64, 5, 76, 
    5, 13, 7, 51, 6, 73, 4, 69, 0, 81, 8, 22, 3, 24, 1, 23, 2,  9, 
    3, 42, 8, 24, 6, 66, 7,  1, 4, 54, 2, 45, 5, 50, 0, 56, 1, 20, 
    5, 13, 4, 13, 3,  3, 8, 46, 2, 12, 6, 66, 0, 68, 7, 63, 1, 64, 
    3, 46, 5, 41, 6, 87, 0, 87, 2, 37, 1, 65, 8, 35, 7, 71, 4, 60, 
    5, 77, 3, 38, 6, 52, 4,  8, 2,  8, 1, 34, 8, 70, 0, 51, 7, 52, 
    8, 53, 6, 65, 2, 96, 5, 34, 7, 16, 4, 14, 1, 50, 0, 95, 3, 93, 
    4, 83, 3, 89, 6, 61, 2, 73, 8, 54, 7, 42, 5, 75, 0, 44, 1, 62, 
    8, 57, 0, 24, 1, 17, 4, 33, 5, 74, 7, 80, 2, 49, 6, 97, 3, 14
  };
  const int q8807[] = {
    9, 9, // Number of jobs and machines
    1, 46, 7, 79, 6, 20, 3, 51, 0, 77, 2, 39, 4, 65, 5, 70, 8, 30, 
    3, 30, 8, 65, 6, 63, 4, 97, 5,  6, 2, 45, 7, 76, 1, 14, 0, 86, 
    1, 41, 4, 40, 0, 71, 6, 77, 3, 35, 8, 54, 5, 12, 7,  3, 2, 94, 
    6, 58, 7, 54, 5, 62, 2, 33, 8, 80, 3,  5, 4, 56, 1, 12, 0, 40, 
    7, 12, 4, 46, 6, 68, 2, 40, 0,  5, 3, 71, 8, 35, 5, 35, 1, 15, 
    2,  1, 8, 85, 1,  9, 7, 65, 5, 37, 4, 96, 3, 45, 6, 71, 0, 69, 
    0, 37, 6, 11, 7, 66, 8, 14, 3, 60, 1, 40, 2, 47, 5, 83, 4, 25, 
    2, 85, 3, 50, 1,  7, 0, 59, 5, 89, 8, 82, 7, 63, 6,  7, 4, 23, 
    4, 56, 6, 70, 1, 16, 3, 58, 8, 18, 7, 97, 2, 91, 0, 58, 5, 39
  };
  const int q8808[] = {
    9, 9, // Number of jobs and machines
    0, 21, 7, 32, 2, 97, 8, 71, 4, 35, 5, 71, 3, 54, 1, 46, 6, 42, 
    1, 91, 6, 16, 2, 46, 7, 69, 5, 57, 3, 48, 8, 35, 4, 27, 0,  5, 
    2, 70, 7, 29, 3, 19, 8, 85, 1, 42, 4, 74, 0, 15, 5,  2, 6, 83, 
    0, 57, 2,  6, 5, 44, 6, 33, 8,  5, 7, 55, 4, 21, 3, 86, 1,  3, 
    3, 43, 1, 66, 8, 89, 5, 99, 4, 90, 6, 96, 2, 21, 7, 67, 0, 92, 
    2, 92, 8, 28, 5, 69, 0, 24, 3, 38, 7, 36, 1, 26, 4, 98, 6, 36, 
    3, 77, 5, 35, 2, 39, 8, 71, 4, 76, 0, 90, 1, 54, 7, 21, 6, 40, 
    3, 42, 1,  4, 2, 52, 0, 14, 4, 39, 8, 69, 6, 91, 7, 97, 5, 68, 
    3, 41, 1, 57, 5, 81, 7, 48, 8,  6, 0, 65, 6, 19, 4, 60, 2, 18
  };
  const int q8809[] = {
    9, 9, // Number of jobs and machines
    7, 32, 1, 69, 2,  6, 6,  1, 3, 25, 0, 93, 5,  9, 4, 76, 8, 49, 
    8, 59, 5, 58, 0, 97, 6, 76, 3, 79, 2, 20, 4, 49, 1, 85, 7,  1, 
    1, 81, 3, 64, 7, 71, 5, 75, 2, 67, 6,  6, 8, 81, 4, 19, 0, 78, 
    6, 20, 3, 62, 8, 50, 0, 90, 5,  4, 2, 21, 7,  8, 1, 54, 4, 14, 
    5, 11, 3, 33, 7, 51, 1,  7, 2, 29, 4, 14, 0, 53, 6, 72, 8, 53, 
    6, 60, 4, 93, 7, 49, 8, 20, 3, 88, 0, 91, 2, 99, 5, 93, 1, 74, 
    4, 47, 2, 82, 6, 47, 8, 45, 0, 49, 5, 97, 7, 64, 3, 98, 1, 45, 
    5, 44, 3, 35, 7, 52, 1, 61, 6, 32, 2, 14, 4, 53, 8, 56, 0, 24, 
    0, 69, 3, 24, 4, 39, 6, 21, 7, 78, 1, 69, 5, 66, 8, 18, 2, 40
  };
  const int q8810[] = {
    9, 9, // Number of jobs and machines
    4, 76, 7, 96, 8, 93, 0, 34, 1, 76, 6, 26, 3, 64, 5, 60, 2, 95, 
    2,  6, 5, 85, 7, 22, 6, 19, 3, 23, 8,  8, 0, 35, 4, 87, 1, 55, 
    5, 59, 3, 43, 2, 17, 6, 15, 0, 19, 8,  5, 7, 87, 1, 44, 4, 17, 
    0, 33, 8, 84, 4, 15, 5, 13, 6, 88, 2, 72, 1, 79, 3, 91, 7, 95, 
    0, 88, 4, 93, 5, 77, 3, 51, 6, 68, 7,  6, 1, 98, 8, 11, 2, 24, 
    0, 59, 7, 86, 5, 35, 8, 52, 1, 25, 2, 36, 3, 13, 4, 67, 6, 18, 
    3, 45, 5, 69, 1,  8, 0, 20, 4,  5, 2, 59, 8, 36, 6, 15, 7, 98, 
    4, 79, 6, 57, 7, 28, 1,  5, 8, 18, 0, 51, 2,  5, 5, 98, 3, 59, 
    2, 63, 6, 71, 8, 84, 0, 75, 7, 81, 4, 47, 1, 83, 3, 75, 5, 42
  };
  const int q8811[] = {
    9, 9, // Number of jobs and machines
    0, 33, 5, 78, 8,  8, 4, 19, 2, 78, 6,  3, 7, 93, 1, 67, 3, 81, 
    0, 18, 3, 77, 7, 90, 1, 95, 6, 29, 2, 44, 5, 44, 4, 52, 8, 10, 
    1, 40, 8, 29, 2, 69, 7, 79, 6, 63, 3, 82, 5, 10, 4, 41, 0,  1, 
    3, 70, 6, 66, 4, 24, 2, 43, 5, 24, 1, 65, 0, 48, 7, 65, 8, 24, 
    8, 49, 6,  1, 5, 47, 7, 72, 0, 88, 3, 39, 1, 69, 2, 43, 4, 43, 
    5, 30, 1, 14, 4, 28, 7, 71, 3, 42, 6, 78, 0, 22, 8, 82, 2,  3, 
    2, 70, 6, 15, 8, 31, 0, 75, 5, 86, 3, 76, 4, 31, 1, 11, 7, 81, 
    0, 43, 6, 96, 5, 71, 7, 65, 8, 54, 4, 82, 1,  3, 3, 57, 2, 96, 
    3, 73, 5, 27, 1,  3, 2,  6, 8, 85, 7, 46, 6, 16, 4, 40, 0, 14
  };
  const int q8812[] = {
    9, 9, // Number of jobs and machines
    2, 51, 1, 97, 8, 49, 6, 14, 7, 36, 0,  8, 5, 17, 4, 22, 3, 92, 
    6, 65, 7, 99, 2, 42, 1, 74, 0, 90, 3, 32, 5, 22, 8, 21, 4, 95, 
    0, 95, 3, 64, 2, 72, 6, 17, 4, 60, 7, 49, 8, 65, 1, 26, 5, 29, 
    5, 34, 3, 54, 8, 46, 4, 16, 7, 35, 0,  9, 6, 43, 1, 76, 2, 68, 
    6, 99, 4, 93, 2, 14, 8, 37, 3, 95, 7, 25, 1, 88, 5, 66, 0, 73, 
    4, 28, 5, 76, 8, 87, 2, 93, 1, 20, 0, 40, 6, 79, 7, 10, 3, 24, 
    8, 48, 4, 10, 7, 59, 2, 30, 1,  2, 0, 81, 3,  5, 6, 48, 5, 78, 
    3, 82, 8, 22, 7, 20, 5, 40, 0, 71, 6, 30, 2, 57, 4, 15, 1, 98, 
    8,  5, 3, 91, 4,  6, 7, 43, 5, 38, 1, 27, 0, 83, 6, 87, 2, 74
  };
  const int q8813[] = {
    9, 9, // Number of jobs and machines
    0, 69, 6, 14, 1, 63, 7, 78, 3, 40, 4,  2, 2, 25, 5, 56, 8, 11, 
    5, 38, 8,  1, 2, 69, 3, 14, 1,  8, 6,  4, 7, 48, 4, 57, 0, 69, 
    1, 45, 0, 14, 4, 75, 2, 19, 5, 45, 3, 45, 7, 51, 8, 56, 6, 82, 
    2, 67, 1, 44, 8, 91, 3, 40, 7, 78, 0, 50, 4, 74, 5, 41, 6, 10, 
    2, 49, 7, 90, 8,  2, 4, 90, 5, 77, 6, 44, 0, 71, 1, 74, 3, 50, 
    5, 90, 2, 48, 8, 21, 1, 33, 6, 38, 0, 85, 7, 38, 3, 14, 4,  4, 
    8, 23, 5, 54, 4, 38, 7,  7, 6, 94, 3, 98, 1, 58, 0, 54, 2, 44, 
    7, 82, 5, 97, 1, 44, 0, 42, 8, 78, 2, 48, 4, 56, 3, 59, 6, 64, 
    0, 91, 1,  7, 4, 40, 3, 87, 8, 64, 6, 54, 7,  2, 5, 40, 2, 82
  };
  const int q8814[] = {
    9, 9, // Number of jobs and machines
    6, 33, 7, 63, 1, 37, 0, 81, 8, 36, 5, 65, 2,  7, 3, 15, 4, 32, 
    2, 18, 7,  7, 6, 17, 5, 48, 0, 52, 1, 39, 8, 79, 4, 64, 3, 26, 
    6, 41, 5,  3, 2, 11, 4,  3, 8, 63, 7, 79, 0, 40, 1, 93, 3, 65, 
    6, 46, 3, 74, 2, 91, 7, 72, 0, 85, 5, 82, 4,  1, 8, 27, 1,  2, 
    0, 26, 5, 99, 2, 80, 8, 11, 7, 70, 3, 95, 6, 48, 4, 14, 1, 36, 
    0, 46, 4, 62, 3, 81, 1, 65, 7, 34, 6, 80, 2, 98, 5, 29, 8, 57, 
    6, 32, 1, 83, 3,  7, 2, 85, 5, 97, 8,  5, 7, 50, 0, 97, 4, 88, 
    8, 75, 5, 91, 7,  5, 3, 80, 4, 48, 6, 31, 0, 69, 2, 97, 1, 98, 
    2, 42, 7,  5, 0, 94, 1, 91, 8, 31, 4, 37, 6, 97, 3, 58, 5, 75
  };
  const int q8815[] = {
    9, 9, // Number of jobs and machines
    8, 83, 5, 65, 6, 95, 7, 67, 2, 44, 3, 30, 1, 24, 0,  8, 4, 80, 
    6, 50, 2, 77, 8, 86, 1, 96, 5, 78, 7,  4, 0, 41, 4, 61, 3, 88, 
    0,  5, 2, 19, 5, 97, 4, 22, 1, 28, 6, 43, 8, 49, 7, 92, 3, 51, 
    8, 60, 7, 42, 6, 26, 1, 20, 3, 69, 0, 44, 5, 69, 4,  9, 2, 49, 
    8, 22, 2, 13, 4, 69, 0, 53, 7, 23, 1, 52, 6, 52, 5, 34, 3, 83, 
    0,  2, 6, 45, 3, 20, 7, 72, 4, 46, 5, 18, 2, 80, 1, 95, 8, 63, 
    5, 90, 1, 26, 0, 40, 4, 98, 8, 92, 6, 56, 2, 94, 3, 10, 7, 66, 
    2, 20, 8, 73, 7, 55, 1, 28, 5, 76, 3, 28, 6, 91, 0, 51, 4, 11, 
    8, 72, 5, 59, 7, 74, 0, 64, 1, 58, 6, 60, 2,  2, 4, 81, 3, 23
  };
  const int q8816[] = {
    9, 9, // Number of jobs and machines
    6, 61, 1, 62, 4, 73, 0, 86, 7, 87, 5, 95, 2, 30, 8, 87, 3,  8, 
    2, 44, 0, 80, 4, 42, 3, 59, 5, 85, 7, 96, 6, 37, 8, 15, 1, 17, 
    1, 66, 0, 86, 3, 99, 2,  4, 8, 96, 7, 66, 5, 32, 4, 68, 6, 31, 
    6, 48, 4, 41, 0, 37, 7, 68, 8,  6, 1, 50, 3, 16, 5, 93, 2, 84, 
    6, 83, 5, 66, 0, 42, 4, 75, 8, 12, 3, 92, 7, 85, 1, 69, 2, 56, 
    1, 76, 8, 88, 6, 60, 0, 31, 3, 99, 2, 77, 7, 23, 5, 95, 4, 59, 
    7, 87, 8, 34, 2, 77, 5, 15, 1, 83, 6, 97, 0, 98, 4, 68, 3, 27, 
    6, 89, 2, 33, 7, 48, 0, 82, 4, 49, 5, 93, 3, 99, 1, 18, 8, 31, 
    7, 92, 8, 12, 1, 44, 4, 82, 0, 22, 2, 19, 6, 65, 5, 75, 3, 92
  };
  const int q8817[] = {
    9, 9, // Number of jobs and machines
    5, 38, 3, 90, 7, 59, 4, 27, 1, 80, 0, 47, 2, 88, 8, 45, 6, 72, 
    2, 14, 0, 59, 7, 59, 5, 78, 6, 78, 1, 68, 4, 44, 8, 52, 3, 12, 
    3, 21, 8, 60, 2, 45, 1, 24, 5, 13, 6, 26, 0, 99, 4, 29, 7, 52, 
    3, 52, 2, 99, 7, 42, 1, 95, 6, 18, 8, 38, 0, 39, 4, 87, 5, 35, 
    1, 28, 0, 61, 4, 12, 8, 86, 3, 61, 5, 94, 2, 46, 7, 60, 6, 40, 
    4, 87, 8, 11, 7, 19, 5, 82, 0, 65, 6, 79, 1, 82, 3, 67, 2, 10, 
    8, 11, 3, 84, 5, 65, 7, 63, 6, 35, 0, 30, 2, 64, 4, 19, 1, 31, 
    0,  9, 8, 31, 4, 81, 2, 37, 5, 89, 1, 95, 7, 60, 6, 82, 3, 27, 
    8, 88, 4, 74, 5, 97, 3, 52, 7, 98, 0, 67, 6, 19, 1, 39, 2, 52
  };
  const int q8818[] = {
    9, 9, // Number of jobs and machines
    6, 32, 0, 59, 5, 61, 8, 54, 4, 12, 2, 69, 3, 80, 1, 12, 7, 64, 
    1, 16, 3, 65, 0, 48, 7, 42, 8, 60, 2, 18, 4, 90, 6, 17, 5,  4, 
    5, 96, 2, 17, 4, 74, 3, 63, 7, 23, 8, 68, 1, 40, 6, 17, 0, 94, 
    3,  2, 7, 92, 1, 74, 5,  1, 2, 71, 4, 77, 8, 57, 0, 32, 6, 27, 
    8, 75, 4, 49, 3, 41, 0, 85, 7, 21, 6, 93, 1,  4, 5, 94, 2, 63, 
    2, 71, 6, 82, 5,  9, 3, 80, 4, 59, 7, 20, 8, 37, 0, 72, 1, 67, 
    8, 73, 7, 78, 5, 67, 1, 71, 6, 96, 3, 11, 2, 48, 4, 61, 0, 35, 
    4, 83, 6, 75, 7, 39, 1, 53, 0, 30, 2, 50, 5, 21, 8, 42, 3, 91, 
    8, 39, 2, 52, 0, 84, 6, 99, 7, 13, 3, 45, 4, 33, 1, 52, 5, 85
  };
  const int q8819[] = {
    9, 9, // Number of jobs and machines
    7, 49, 6, 35, 4, 34, 0, 40, 8, 39, 3, 75, 2, 79, 5, 86, 1, 32, 
    1, 86, 7, 18, 2, 39, 0, 19, 6, 87, 8, 82, 3, 47, 5, 54, 4, 46, 
    6, 82, 2, 77, 4, 66, 5, 27, 3, 82, 1, 65, 7, 90, 8, 59, 0,  2, 
    4, 58, 7, 29, 8, 44, 3,  1, 6, 90, 0,  7, 2, 56, 1, 46, 5, 57, 
    7, 86, 3, 71, 1, 33, 0, 36, 8, 19, 4, 72, 2, 42, 5, 12, 6, 44, 
    4,  1, 5, 28, 6, 79, 8, 21, 0, 41, 3, 91, 2, 34, 1,  7, 7,  5, 
    6, 51, 8, 10, 0, 28, 4, 21, 3, 58, 2, 12, 1, 99, 7, 27, 5,  9, 
    8, 11, 0,  7, 7, 90, 4, 48, 5, 16, 6, 80, 2, 12, 3, 96, 1, 39, 
    4, 18, 0, 25, 1, 80, 8, 75, 3, 96, 5, 43, 2, 20, 7, 26, 6, 72
  };
  const int q8820[] = {
    9, 9, // Number of jobs and machines
    5, 28, 2, 24, 3, 15, 7, 50, 0, 35, 4, 19, 6, 26, 1, 32, 8, 39, 
    0, 78, 1,  5, 3, 68, 8, 65, 2, 34, 6, 18, 5, 38, 4, 23, 7, 29, 
    3, 76, 7, 90, 2,  3, 4,  9, 1, 58, 5, 28, 6, 68, 0, 24, 8, 33, 
    4,  6, 3, 70, 5,  1, 8, 40, 7,  4, 2, 79, 6, 48, 0, 56, 1, 37, 
    4, 39, 0,  9, 7, 25, 5, 20, 1, 25, 2, 42, 8,  9, 6, 21, 3, 69, 
    0, 61, 4, 76, 2, 50, 7, 40, 3,  1, 5, 18, 6,  6, 1, 56, 8, 66, 
    3, 33, 6, 37, 0, 75, 2, 21, 8, 75, 5, 19, 7, 84, 1, 56, 4, 61, 
    0, 85, 1, 43, 3, 58, 5, 28, 2, 93, 8, 43, 6, 32, 7, 26, 4,  4, 
    1, 52, 3, 86, 7, 95, 6, 30, 0, 82, 8, 42, 2, 46, 4, 40, 5, 62
  };
  const int q8821[] = {
    9, 9, // Number of jobs and machines
    4, 25, 6, 33, 3, 25, 0, 32, 8,  8, 2, 41, 5, 59, 7, 13, 1, 17, 
    0, 85, 5, 92, 1, 95, 2, 61, 8, 29, 4, 99, 3, 32, 6, 56, 7,  9, 
    8,  5, 4, 94, 2, 85, 7, 71, 1,  4, 0, 71, 5, 77, 3, 28, 6, 55, 
    3, 93, 5, 53, 4, 51, 1, 52, 8,  8, 7, 46, 0, 52, 6, 83, 2, 46, 
    5, 21, 7, 16, 8, 25, 2, 42, 4, 10, 1, 36, 3, 50, 0, 33, 6, 32, 
    5, 38, 1, 21, 8, 37, 6, 84, 7, 97, 4,  8, 2, 27, 3, 63, 0, 40, 
    1, 69, 7, 33, 0, 72, 2, 88, 5,  6, 3, 93, 8, 93, 6, 78, 4, 69, 
    0, 61, 6, 27, 5, 60, 4, 50, 2, 76, 3, 12, 8, 29, 7, 77, 1, 59, 
    4, 25, 7, 74, 1, 11, 8, 30, 6,  8, 3, 51, 5, 18, 2, 27, 0, 87
  };
  const int q8822[] = {
    9, 9, // Number of jobs and machines
    4, 35, 2, 56, 0, 16, 8,  8, 5, 98, 6, 93, 7, 76, 3, 31, 1, 81, 
    1, 74, 8, 52, 6, 58, 4, 63, 5, 61, 7, 69, 0, 35, 3, 83, 2, 90, 
    0, 96, 5,  3, 6, 16, 1, 15, 8, 38, 2, 87, 3, 73, 4, 57, 7, 89, 
    4, 87, 0, 48, 2, 20, 8, 16, 5, 57, 7, 55, 6, 77, 3, 47, 1, 94, 
    6,  4, 7, 98, 1, 36, 5, 15, 2, 63, 0, 74, 4, 16, 8, 85, 3, 50, 
    4, 69, 1, 83, 3, 80, 8,  5, 0, 23, 7,  3, 2, 20, 6,  1, 5, 30, 
    1, 22, 7, 50, 8, 27, 3,  5, 4, 10, 5, 54, 0, 83, 2, 84, 6, 96, 
    3, 62, 0, 57, 4, 54, 1, 27, 8, 44, 5, 92, 6, 55, 2, 63, 7, 31, 
    5, 88, 3, 48, 0, 96, 7, 83, 8, 96, 2, 38, 6, 93, 1, 63, 4, 87
  };
  const int q8823[] = {
    9, 9, // Number of jobs and machines
    2, 95, 7, 90, 1, 96, 3, 65, 4, 85, 8, 50, 5, 87, 0, 32, 6, 26, 
    8, 14, 3, 37, 7, 96, 5, 28, 0, 40, 4, 93, 2, 76, 1,  4, 6, 68, 
    2, 82, 1, 60, 3,  9, 4, 78, 0, 60, 5, 68, 6, 78, 7, 43, 8, 19, 
    5, 75, 2, 16, 7,  5, 0, 69, 8, 85, 1, 97, 4, 18, 3, 70, 6, 25, 
    5, 91, 6, 12, 4, 99, 1, 90, 0, 20, 7, 47, 8, 99, 2, 18, 3, 91, 
    4, 94, 0, 67, 7, 68, 3, 83, 6, 91, 8, 58, 2, 77, 5, 72, 1, 10, 
    3,  8, 4, 12, 7, 93, 6, 72, 8, 40, 1, 96, 5, 62, 2, 47, 0, 77, 
    8, 98, 1, 37, 2, 81, 3, 55, 5, 74, 4, 86, 6, 91, 7, 26, 0, 45, 
    1, 89, 2, 20, 0, 62, 4, 77, 8, 16, 6, 68, 5, 62, 3,  6, 7, 98
  };
  const int q8824[] = {
    9, 9, // Number of jobs and machines
    2, 89, 1, 81, 8, 40, 6, 90, 0, 45, 3, 87, 4, 30, 5, 44, 7, 95, 
    3, 98, 7, 21, 8,  7, 5, 56, 2, 37, 4, 83, 0, 51, 1, 21, 6, 92, 
    2, 66, 7, 28, 8, 55, 5,  6, 3, 67, 0, 20, 4, 19, 1,  8, 6, 13, 
    1, 21, 0, 78, 3, 15, 6, 72, 7, 13, 2, 54, 5, 17, 8, 13, 4, 16, 
    3, 76, 6, 53, 5, 11, 4, 71, 2, 64, 1, 18, 8, 51, 7, 15, 0, 53, 
    8, 57, 7, 26, 0, 95, 1, 85, 3, 53, 2, 90, 5, 92, 4, 41, 6, 23, 
    6, 81, 2, 46, 5, 33, 0, 85, 1, 42, 8, 31, 3, 40, 7, 95, 4, 48, 
    3, 97, 8, 68, 7, 76, 0, 25, 1, 27, 5, 20, 6, 29, 4, 14, 2, 44, 
    2, 91, 7, 21, 6,  5, 1, 13, 8, 83, 4, 21, 5, 20, 3, 28, 0, 11
  };
  const int q8825[] = {
    9, 9, // Number of jobs and machines
    0, 86, 6, 43, 3, 60, 5, 30, 4, 14, 8, 15, 1,  3, 2, 72, 7, 67, 
    2, 66, 3, 64, 8, 98, 6, 41, 5, 72, 0, 30, 1, 54, 7,  1, 4, 91, 
    1, 77, 6, 54, 8, 31, 2, 92, 7, 81, 4, 26, 0, 60, 5,  6, 3,  1, 
    2, 80, 7, 43, 4, 77, 8, 12, 5, 21, 3, 18, 0, 26, 1, 27, 6, 42, 
    1, 65, 0, 48, 3, 97, 5, 96, 8, 46, 4, 39, 6, 71, 7, 33, 2, 87, 
    8, 67, 0, 38, 4, 70, 6, 57, 5, 18, 3, 27, 7, 72, 2, 70, 1, 44, 
    4, 59, 8, 31, 1, 11, 7, 56, 0, 77, 2, 55, 5, 96, 6, 65, 3, 81, 
    2, 54, 1, 41, 7, 16, 6, 15, 0, 67, 3, 71, 4, 17, 5, 43, 8, 24, 
    6, 23, 5, 58, 8, 41, 2, 56, 0, 40, 1, 18, 7,  1, 3, 49, 4, 17
  };
  const int q8826[] = {
    9, 9, // Number of jobs and machines
    2, 95, 6, 25, 4, 30, 1, 42, 8, 74, 5, 66, 7, 80, 3, 82, 0, 53, 
    6, 75, 0, 11, 5, 44, 4, 87, 7,  5, 1,  1, 2, 28, 8, 30, 3, 50, 
    7, 45, 4, 58, 3, 90, 6, 92, 5, 57, 8, 53, 2, 25, 1, 17, 0, 29, 
    4, 25, 0, 63, 2, 77, 1,  6, 5, 61, 3, 94, 6, 82, 8, 28, 7,  5, 
    4, 67, 6, 60, 8, 23, 0, 80, 1, 88, 3, 41, 2, 46, 5, 40, 7, 18, 
    2,  9, 0, 61, 8, 66, 5, 50, 6, 64, 3, 76, 1, 99, 4, 84, 7, 31, 
    6, 13, 3, 87, 2, 25, 7, 91, 5,  5, 8, 77, 1, 41, 0, 71, 4, 14, 
    2, 64, 7, 56, 3, 17, 5, 59, 8,  8, 6, 73, 0, 10, 4, 68, 1, 85, 
    6, 80, 8, 97, 4, 92, 5, 99, 0, 45, 7, 75, 2,  8, 3, 71, 1, 10
  };
  const int q8827[] = {
    9, 9, // Number of jobs and machines
    6, 11, 1, 93, 7, 96, 4, 78, 5, 89, 3, 13, 2, 80, 8, 13, 0, 96, 
    7, 44, 2, 98, 3, 95, 8, 72, 6, 51, 0, 20, 1, 42, 4, 66, 5, 14, 
    7, 71, 6, 35, 1, 63, 4, 36, 0, 59, 2, 33, 3, 82, 5, 20, 8, 94, 
    8,  1, 3, 74, 6, 47, 7, 65, 0, 47, 2, 98, 1, 52, 4, 30, 5, 69, 
    4, 45, 3, 91, 7, 33, 5, 63, 8, 56, 1, 89, 0, 29, 6, 25, 2, 76, 
    4, 61, 6, 85, 3, 90, 8, 54, 2, 81, 1, 22, 5, 93, 0, 65, 7, 51, 
    7, 28, 8, 52, 4, 70, 3, 70, 0, 96, 2, 64, 6,  3, 1, 32, 5,  6, 
    2, 27, 3, 51, 4, 97, 8, 75, 0, 24, 1, 15, 5, 22, 7, 16, 6, 26, 
    6, 52, 4, 62, 7, 74, 1, 92, 3, 69, 8,  7, 5, 12, 2, 15, 0, 41
  };
  const int q8828[] = {
    9, 9, // Number of jobs and machines
    1,  5, 2, 85, 0, 55, 8, 85, 4, 51, 6, 19, 7, 67, 3, 80, 5, 40, 
    0,  2, 1, 35, 8, 55, 7, 15, 2, 27, 6, 33, 4, 32, 3, 15, 5, 46, 
    5, 31, 8, 62, 7, 12, 3, 46, 1, 93, 6, 32, 0, 88, 2, 44, 4,  1, 
    0, 68, 5, 77, 6, 44, 3, 49, 4, 56, 2, 98, 1, 36, 7, 65, 8, 64, 
    1, 60, 5, 78, 2, 56, 4, 28, 0, 19, 8, 80, 6, 97, 7, 56, 3, 78, 
    3, 12, 1, 13, 6, 61, 5, 52, 7, 73, 2, 34, 8, 25, 0, 70, 4, 50, 
    6, 68, 7, 34, 4, 24, 0, 10, 3, 30, 1, 85, 8, 26, 2,  2, 5, 31, 
    5,  2, 4, 62, 8, 72, 3, 57, 2, 70, 1, 82, 6, 76, 7, 76, 0, 45, 
    6, 25, 0,  7, 5, 25, 2, 31, 8, 68, 1, 99, 7, 16, 4, 92, 3, 29
  };
  const int q8829[] = {
    9, 9, // Number of jobs and machines
    6,  9, 4, 35, 1, 52, 2, 24, 8, 32, 3,  2, 7, 35, 0,  6, 5, 47, 
    7, 33, 2, 32, 3, 66, 6, 18, 1, 24, 8, 35, 0, 64, 4, 49, 5, 22, 
    5, 29, 4, 77, 1, 23, 3, 65, 7, 67, 8, 24, 2, 65, 6, 16, 0, 37, 
    7, 88, 5, 29, 1, 37, 8, 58, 0, 82, 3, 94, 6, 51, 2, 78, 4, 30, 
    7, 41, 0, 13, 2, 70, 8, 42, 1, 45, 3, 75, 6, 17, 4, 97, 5, 95, 
    8, 96, 6, 55, 3, 10, 5, 40, 7, 63, 0, 69, 2, 63, 4, 43, 1, 46, 
    0, 30, 8, 80, 6, 56, 3, 88, 4, 65, 7, 62, 5, 41, 2, 41, 1, 10, 
    4, 37, 5, 10, 2, 86, 1, 65, 7, 58, 6, 95, 8, 33, 3, 98, 0, 66, 
    0, 78, 8, 98, 1, 37, 2, 34, 5, 71, 7, 30, 6,  8, 4,  9, 3,  6
  };
  const int q8830[] = {
    9, 9, // Number of jobs and machines
    5, 63, 8, 87, 4, 79, 0, 47, 6,  8, 2, 72, 7, 45, 3, 38, 1, 61, 
    4, 60, 8, 95, 6, 52, 3, 97, 1, 23, 0, 16, 7, 92, 5, 42, 2, 48, 
    2, 70, 3, 13, 0, 51, 7, 89, 5, 20, 6, 73, 1, 81, 4, 88, 8, 17, 
    2, 32, 0, 22, 1, 91, 4, 57, 3, 99, 5, 75, 6, 71, 7, 73, 8, 11, 
    6, 11, 7,  1, 5, 94, 2, 18, 1, 90, 0, 63, 4, 32, 8,  6, 3, 50, 
    2, 46, 7, 49, 3, 84, 0, 66, 6, 26, 4, 78, 1, 80, 8, 48, 5,  4, 
    1, 62, 6, 44, 7, 69, 8, 54, 4, 70, 0, 15, 3, 39, 2, 40, 5, 66, 
    8, 33, 5, 50, 6, 32, 0, 83, 1, 26, 2, 74, 7, 44, 3, 91, 4, 29, 
    2, 17, 1, 90, 5, 20, 7, 40, 3, 88, 6, 11, 4, 50, 0, 16, 8, 51
  };
  const int q8831[] = {
    9, 9, // Number of jobs and machines
    6, 34, 4, 70, 5, 76, 2, 73, 7, 30, 0, 93, 1, 14, 8, 72, 3, 80, 
    1,  9, 6, 16, 3, 32, 8, 18, 5, 30, 2, 48, 0, 16, 4, 33, 7, 15, 
    6, 19, 1, 97, 4, 71, 7, 77, 8, 81, 3, 89, 0,  5, 5,  2, 2, 17, 
    8, 29, 7, 22, 1,  4, 3, 98, 0, 32, 5, 33, 4, 84, 6, 85, 2, 15, 
    8, 26, 2, 57, 7, 71, 0, 85, 5, 94, 4, 17, 3, 63, 1, 36, 6, 26, 
    8, 64, 7, 23, 2, 38, 3, 71, 1, 48, 4, 83, 0, 21, 6, 68, 5, 83, 
    7, 61, 2, 27, 3, 62, 0, 92, 8, 46, 1,  7, 4, 69, 6, 84, 5, 56, 
    2, 30, 0, 30, 4, 80, 3,  2, 6,  1, 5, 65, 1,  1, 7, 70, 8, 27, 
    6, 44, 1, 37, 8, 76, 3, 45, 5, 41, 2, 68, 7, 51, 0, 50, 4, 11
  };
  const int q8832[] = {
    9, 9, // Number of jobs and machines
    3, 86, 6, 59, 2, 75, 5, 32, 0, 20, 7, 87, 8, 25, 4, 79, 1, 87, 
    1, 56, 4, 83, 7,  5, 5, 84, 8, 65, 6, 67, 2, 56, 0, 49, 3, 92, 
    7, 82, 0, 11, 1, 28, 6, 83, 5, 48, 8, 37, 3, 41, 2, 50, 4, 26, 
    2, 57, 5, 74, 0, 50, 8, 30, 7, 46, 1, 79, 3, 17, 4, 98, 6, 84, 
    2, 86, 6, 18, 1, 37, 0, 94, 7, 89, 5, 43, 4, 44, 3, 21, 8, 21, 
    4, 11, 3, 39, 2, 86, 7,  8, 5, 91, 0, 74, 6, 39, 8, 72, 1, 71, 
    1, 44, 7,  1, 4, 87, 5, 25, 8, 97, 6,  2, 2, 75, 3, 73, 0, 60, 
    3, 25, 0, 91, 7, 32, 2, 19, 4, 71, 8, 54, 1, 34, 6, 84, 5, 62, 
    0, 52, 2, 37, 5, 33, 8, 75, 4, 86, 1, 25, 6, 27, 7, 89, 3, 41
  };
  const int q8833[] = {
    9, 9, // Number of jobs and machines
    0, 17, 7, 68, 6, 68, 3, 75, 8, 30, 5, 62, 1, 45, 4, 53, 2, 76, 
    4, 27, 6, 38, 0, 45, 3, 97, 7, 93, 5, 54, 8, 89, 2, 20, 1, 89, 
    7,  3, 1, 76, 2, 55, 3, 21, 0,  7, 5, 35, 8, 12, 4, 67, 6, 25, 
    5, 40, 2,  9, 8, 84, 1, 72, 3, 93, 0, 80, 6, 92, 7, 15, 4, 35, 
    0, 96, 1, 96, 3, 12, 7, 39, 5, 26, 4,  6, 2, 31, 6, 97, 8, 89, 
    1, 55, 3, 66, 2, 53, 5, 16, 8, 40, 4, 81, 7, 68, 0, 12, 6, 15, 
    2, 34, 4, 27, 8, 96, 3,  2, 1, 15, 6, 85, 0, 10, 7, 74, 5, 88, 
    2, 46, 1, 84, 4, 24, 8, 21, 7, 40, 6,  4, 3, 32, 0, 67, 5, 13, 
    6, 91, 4, 49, 8, 23, 5, 19, 0, 13, 2, 80, 3, 15, 7, 33, 1, 62
  };
  const int q8834[] = {
    9, 9, // Number of jobs and machines
    0,  2, 2, 75, 6, 60, 8, 14, 4, 58, 1, 14, 3, 40, 5, 75, 7, 27, 
    6, 89, 7, 58, 5, 14, 0, 42, 2, 52, 1, 58, 3, 19, 4, 47, 8, 56, 
    6,  5, 2, 63, 4, 97, 3, 87, 0,  1, 1, 37, 5, 43, 7, 97, 8, 71, 
    3,  9, 0, 62, 4, 86, 6, 47, 1, 39, 2, 51, 7, 24, 5, 12, 8, 46, 
    4,  8, 3, 76, 8, 65, 5, 48, 2, 96, 6, 32, 1, 13, 7,  7, 0, 53, 
    6, 77, 7, 52, 2,  1, 5, 64, 3,  7, 4,  5, 8, 65, 1, 19, 0, 86, 
    4, 43, 1, 59, 3, 36, 5, 21, 7, 32, 2, 60, 6, 87, 8, 79, 0, 77, 
    1, 52, 0, 72, 2, 15, 4, 32, 8,  4, 5, 81, 7, 62, 3,  4, 6, 82, 
    3, 52, 6, 87, 2, 65, 0, 21, 8, 30, 1, 19, 5, 72, 4, 98, 7, 57
  };
  const int q8835[] = {
    9, 9, // Number of jobs and machines
    2, 24, 4, 63, 8, 47, 7, 56, 1, 82, 0, 53, 3, 90, 5, 77, 6, 62, 
    2, 78, 3, 29, 0, 64, 5, 72, 7, 48, 1, 59, 4, 41, 6,  7, 8, 17, 
    1, 69, 0, 29, 4, 25, 3, 22, 5,  1, 7, 75, 2, 10, 6, 58, 8, 52, 
    1, 44, 0, 21, 8, 47, 7, 86, 4, 39, 2, 42, 6, 29, 3, 32, 5, 61, 
    1, 76, 7, 70, 4, 71, 3, 53, 0, 93, 5, 96, 8, 15, 2, 25, 6, 34, 
    4, 87, 7,  5, 5, 23, 6, 85, 8, 67, 2, 14, 1, 39, 3, 27, 0, 91, 
    0, 87, 3, 46, 7, 79, 2, 94, 1, 71, 8, 49, 5, 22, 6, 73, 4, 74, 
    4, 75, 5, 13, 6, 88, 1, 73, 2,  9, 7, 18, 8, 85, 0, 23, 3, 84, 
    6, 84, 4,  6, 8, 50, 2, 45, 1, 18, 0, 19, 7, 29, 3, 86, 5, 27
  };
  const int q8836[] = {
    9, 9, // Number of jobs and machines
    2, 66, 3, 58, 0, 13, 6, 32, 5, 60, 1, 30, 8, 14, 4, 94, 7, 85, 
    1, 18, 8, 75, 3, 88, 4, 53, 6, 76, 2, 41, 0, 11, 7, 86, 5,  7, 
    3, 76, 6, 45, 1, 79, 8, 84, 7, 82, 2, 19, 4,  8, 5, 40, 0, 68, 
    8, 78, 2, 60, 1, 46, 4,  5, 0, 57, 5, 83, 3, 91, 7, 28, 6, 73, 
    3, 16, 1, 34, 4,  5, 5, 78, 2, 30, 0, 88, 7, 17, 8, 72, 6, 37, 
    3, 63, 6, 29, 4, 26, 1, 32, 2, 75, 8, 64, 5, 25, 7, 38, 0, 38, 
    6, 22, 3, 86, 2, 13, 0, 69, 4, 46, 1, 62, 5, 96, 8, 69, 7, 21, 
    0, 65, 3, 98, 8, 35, 7,  5, 5, 49, 4, 70, 1,  5, 6, 15, 2,  4, 
    4, 22, 0, 37, 5, 78, 6, 44, 2, 41, 3, 80, 1, 86, 7,  5, 8, 65
  };
  const int q8837[] = {
    9, 9, // Number of jobs and machines
    3, 48, 8, 82, 0, 66, 7, 93, 4, 55, 6, 46, 1, 62, 2, 76, 5, 21, 
    5, 68, 4, 44, 3, 63, 6, 85, 2, 72, 8, 88, 0, 33, 7, 92, 1, 72, 
    8, 33, 0, 37, 3, 57, 4, 83, 5, 22, 7, 41, 2, 25, 1,  1, 6, 93, 
    0, 16, 1, 16, 6, 24, 2, 97, 4, 69, 3, 84, 7, 93, 5, 70, 8, 19, 
    8, 51, 2, 19, 5, 55, 6, 31, 7, 66, 1, 99, 0, 72, 3, 68, 4, 93, 
    7, 60, 1, 58, 3, 76, 8, 95, 0, 40, 5, 93, 4, 81, 2, 57, 6, 46, 
    3, 86, 5, 88, 7, 19, 1, 57, 6, 85, 8, 12, 2, 99, 0, 87, 4, 87, 
    1, 13, 8, 82, 7, 81, 6, 82, 0, 16, 5, 42, 3, 87, 4, 14, 2, 88, 
    8, 76, 1, 86, 3, 99, 0,  4, 2, 74, 4, 25, 5,  9, 7,  6, 6, 98
  };
  const int q8838[] = {
    9, 9, // Number of jobs and machines
    2, 60, 3, 71, 8, 66, 4, 47, 1, 48, 6, 28, 5, 92, 7, 46, 0, 13, 
    7, 39, 8, 34, 4, 25, 3, 65, 6, 91, 5, 56, 2, 95, 0, 61, 1, 18, 
    3, 27, 0, 88, 1, 40, 7, 27, 6,  1, 4, 32, 2, 64, 8, 79, 5, 12, 
    5, 82, 4, 31, 7, 80, 3, 76, 1, 18, 8, 23, 6, 80, 0, 88, 2, 36, 
    5, 48, 6, 41, 0, 76, 8, 58, 4, 83, 2, 27, 1, 55, 3, 96, 7, 25, 
    6,  2, 0, 19, 8, 22, 2, 79, 3, 88, 7, 44, 5,  4, 4, 63, 1, 23, 
    7, 93, 5, 84, 3, 87, 2, 34, 4, 72, 1, 26, 6, 91, 0, 95, 8, 76, 
    3, 82, 6, 76, 5, 14, 7, 87, 0, 40, 4, 17, 8,  5, 2, 46, 1, 25, 
    7,  1, 2, 86, 0, 65, 4, 87, 3, 54, 8, 64, 1, 41, 5, 49, 6,  5
  };
  const int q8839[] = {
    9, 9, // Number of jobs and machines
    8, 42, 3, 76, 7, 97, 4, 26, 6,  5, 5,  1, 0, 45, 1, 70, 2, 56, 
    8, 17, 3, 57, 6, 77, 4, 38, 5, 11, 7,  5, 1, 93, 2, 61, 0, 95, 
    4,  5, 6, 66, 5, 52, 1, 16, 0, 52, 7, 63, 8,  6, 2, 48, 3, 85, 
    8, 10, 4, 24, 0, 11, 3, 40, 1, 16, 6, 25, 7, 13, 2, 20, 5, 60, 
    5,  3, 0, 65, 4, 98, 6, 15, 7, 42, 8, 18, 3, 52, 2, 62, 1, 65, 
    1, 33, 6, 43, 5, 14, 2, 34, 3, 99, 0, 41, 4, 24, 7, 89, 8, 48, 
    8, 21, 7, 58, 6, 36, 4, 77, 2, 44, 5, 41, 0, 97, 3, 83, 1,  4, 
    4, 52, 7, 52, 8, 26, 1, 60, 3, 62, 2, 58, 0, 60, 6, 50, 5, 25, 
    0, 39, 4, 72, 3, 45, 5, 42, 2, 18, 8,  4, 6, 65, 7, 19, 1, 11
  };
  const int q8840[] = {
    9, 9, // Number of jobs and machines
    3, 38, 4, 31, 5, 24, 6, 56, 7, 15, 1, 74, 2, 38, 8, 26, 0, 53, 
    2, 46, 7, 12, 8, 12, 6, 13, 3, 68, 5, 59, 4, 16, 1, 92, 0, 82, 
    2, 32, 6, 68, 0, 80, 5, 82, 4, 19, 1, 66, 3, 71, 7,  2, 8, 86, 
    1, 46, 4, 20, 8, 88, 5, 64, 2, 80, 7, 32, 0, 88, 3, 53, 6, 72, 
    8, 26, 0, 87, 6, 78, 2, 87, 5, 92, 7, 10, 1,  6, 4, 69, 3, 79, 
    2, 18, 8, 55, 5, 90, 6, 47, 7, 13, 1, 44, 4, 92, 3,  7, 0, 43, 
    0, 35, 3, 85, 6, 76, 8, 41, 1, 29, 7, 34, 4, 20, 2, 43, 5, 79, 
    5, 57, 3, 85, 6, 23, 1,  5, 8, 60, 2, 98, 4, 35, 7, 19, 0, 15, 
    6, 97, 8, 41, 7, 10, 5, 91, 0, 83, 2, 23, 1, 79, 4, 53, 3, 95
  };
  const int q8841[] = {
    9, 9, // Number of jobs and machines
    4, 86, 2,  2, 8, 61, 1, 13, 7, 80, 6, 95, 3, 95, 0, 93, 5, 84, 
    3, 72, 6, 41, 0, 61, 4, 28, 2, 42, 7, 87, 8, 19, 1, 34, 5, 47, 
    0,  4, 6, 90, 2, 27, 5, 69, 4, 99, 3, 59, 1, 15, 8, 17, 7, 15, 
    2, 79, 4, 68, 5, 12, 0,  2, 6, 82, 3, 92, 7, 41, 1, 23, 8, 35, 
    4, 26, 6,  3, 0,  3, 5, 86, 2, 62, 1, 69, 8, 41, 3, 38, 7, 70, 
    7, 79, 1, 96, 0, 58, 8, 46, 5, 96, 4, 75, 2, 28, 6, 26, 3, 56, 
    3,  7, 5, 30, 7, 27, 4, 56, 1, 46, 6, 68, 2, 83, 8, 80, 0, 88, 
    6, 12, 5, 50, 3, 89, 4, 50, 7,  7, 1, 96, 8, 50, 0, 14, 2,  6, 
    4, 13, 1, 85, 0, 66, 3, 32, 8, 77, 2, 95, 7,  7, 6, 84, 5, 54
  };
  const int q8842[] = {
    9, 9, // Number of jobs and machines
    4, 64, 1, 14, 8, 47, 0, 55, 5, 86, 2,  3, 7, 90, 6, 85, 3, 75, 
    0, 83, 3, 16, 8, 34, 5, 45, 6, 70, 7, 89, 4, 96, 1, 58, 2, 33, 
    3, 70, 1, 85, 8, 78, 6, 21, 2, 92, 0, 27, 5, 64, 4, 73, 7, 12, 
    6, 42, 5, 21, 7, 15, 4,  5, 3, 98, 0, 43, 2, 31, 8, 35, 1, 69, 
    4, 26, 7, 42, 0,  9, 3,  3, 2,  5, 6, 73, 8, 28, 1, 71, 5, 66, 
    0, 53, 4, 69, 5,  9, 7, 70, 3, 13, 8, 63, 6, 13, 1, 27, 2, 63, 
    1, 31, 3, 99, 6, 65, 2, 78, 8, 70, 7, 52, 5, 49, 0, 38, 4, 55, 
    1,  8, 0, 46, 7, 63, 8, 56, 4,  5, 3, 38, 5, 86, 2, 27, 6, 23, 
    4, 49, 1, 27, 7, 74, 6, 68, 5, 16, 3, 88, 2, 96, 8, 28, 0, 76
  };
  const int q8843[] = {
    9, 9, // Number of jobs and machines
    4,  1, 0,  6, 3, 62, 6, 30, 5, 11, 7, 36, 8, 69, 1, 73, 2, 86, 
    4, 89, 1, 13, 6, 87, 5, 24, 2, 97, 0, 55, 3, 31, 8, 50, 7, 61, 
    2,  1, 3, 62, 6, 98, 0, 86, 4, 68, 5, 43, 8, 26, 1, 36, 7, 96, 
    4, 52, 5, 85, 1, 11, 6, 41, 7, 55, 0, 96, 8, 18, 3, 18, 2, 87, 
    0, 27, 5, 27, 3, 64, 4, 68, 7, 64, 6, 73, 8, 18, 1, 50, 2, 79, 
    1, 69, 3, 99, 0, 21, 2, 14, 8, 13, 4, 29, 7, 42, 5, 18, 6, 44, 
    6, 80, 0, 41, 2, 47, 3, 79, 5, 68, 8, 47, 7, 56, 1, 96, 4, 41, 
    7, 28, 0, 16, 3, 76, 6, 10, 1, 61, 2, 95, 5, 49, 4, 25, 8, 94, 
    7, 37, 6, 41, 5,  1, 3,  8, 1, 42, 8, 41, 0, 54, 4, 13, 2, 43
  };
  const int q8844[] = {
    9, 9, // Number of jobs and machines
    4, 75, 5, 25, 1, 12, 2, 11, 0, 26, 8, 21, 7, 35, 3, 12, 6, 56, 
    4,  7, 6, 67, 7, 90, 0, 73, 2, 29, 3, 51, 5, 68, 8, 28, 1, 57, 
    0, 53, 1,  6, 3, 96, 7, 89, 2, 43, 6, 88, 8, 50, 5, 11, 4, 42, 
    0, 35, 7, 37, 6, 95, 1, 54, 2, 64, 3, 69, 5, 45, 8, 79, 4, 27, 
    0, 77, 2, 76, 8, 74, 1, 97, 7, 41, 6, 56, 4, 49, 3,  5, 5, 93, 
    8, 64, 0, 92, 7, 99, 2, 54, 4, 23, 6, 58, 3, 20, 1, 86, 5, 62, 
    6, 38, 0, 62, 1, 95, 5, 19, 3, 57, 4, 11, 7, 73, 2, 18, 8, 86, 
    2, 24, 5, 10, 1,  1, 3, 26, 8, 68, 0, 91, 4, 16, 6, 56, 7, 30, 
    8, 26, 1, 31, 3, 46, 6, 69, 2, 24, 5, 61, 0, 12, 4, 90, 7, 92
  };
  const int q8845[] = {
    9, 9, // Number of jobs and machines
    8, 16, 7, 75, 3, 15, 5, 86, 6, 68, 1, 75, 0, 77, 4, 67, 2, 54, 
    3, 75, 4, 43, 6, 55, 0, 81, 5, 27, 1, 84, 8, 31, 7, 24, 2, 17, 
    0, 59, 3,  5, 4, 47, 6, 24, 8, 80, 2, 24, 5, 98, 7, 63, 1, 24, 
    3, 33, 2,  2, 8, 78, 7, 39, 5, 21, 0, 28, 1, 90, 4, 25, 6, 67, 
    1, 55, 2, 13, 7, 42, 0, 20, 8, 65, 3, 58, 4, 56, 6, 51, 5, 51, 
    1, 81, 5, 69, 7, 74, 3, 92, 4, 40, 6, 84, 8, 93, 0, 22, 2, 15, 
    0, 22, 7, 49, 2, 31, 6, 90, 3, 55, 1, 44, 8, 31, 5, 91, 4, 95, 
    6, 88, 4, 37, 5, 84, 7, 94, 8,  5, 3,  5, 2, 70, 1, 73, 0, 81, 
    0, 47, 6, 56, 7, 65, 1, 25, 4, 94, 8, 45, 2, 49, 5, 18, 3, 24
  };
  const int q8846[] = {
    9, 9, // Number of jobs and machines
    4, 89, 6, 25, 2, 26, 5, 10, 8, 24, 7, 55, 0, 25, 1, 27, 3, 80, 
    5, 68, 3, 64, 0, 97, 7, 73, 2,  7, 4, 35, 6,  5, 1, 54, 8, 83, 
    5, 80, 4, 39, 6, 52, 2, 16, 7, 14, 0, 75, 1, 66, 8, 13, 3, 59, 
    3, 77, 8, 63, 4, 46, 7, 28, 1, 28, 5, 81, 0, 32, 2, 87, 6, 22, 
    8, 96, 1, 18, 3, 16, 2, 69, 7, 56, 4, 13, 6, 88, 5, 80, 0, 89, 
    6, 15, 1, 85, 5, 79, 0, 99, 2, 47, 3, 81, 8, 77, 7, 44, 4, 41, 
    5, 71, 1, 49, 4, 33, 8, 62, 6, 39, 0, 11, 3, 21, 2, 41, 7, 75, 
    4, 13, 8, 57, 3, 46, 5, 83, 2, 43, 0, 82, 1, 90, 6, 23, 7, 44, 
    7, 34, 5, 99, 1, 40, 6, 44, 0, 13, 4, 78, 8, 89, 3, 72, 2, 57
  };
  const int q8847[] = {
    9, 9, // Number of jobs and machines
    8, 31, 4, 37, 5, 24, 3, 86, 6,  7, 1, 20, 2, 85, 7, 54, 0,  1, 
    5, 15, 1, 49, 8, 19, 7, 65, 3, 45, 6, 19, 2, 27, 4,  3, 0, 32, 
    2, 19, 6, 52, 5, 57, 8, 10, 3, 37, 1, 79, 7, 70, 4, 40, 0, 41, 
    5, 73, 7, 83, 6, 25, 3,  4, 8, 63, 0,  4, 1, 49, 4, 25, 2, 13, 
    7, 35, 6,  7, 0, 59, 1, 34, 8, 79, 3, 22, 2,  8, 4, 30, 5, 82, 
    4, 26, 1, 85, 5, 49, 7, 53, 0, 11, 8, 76, 2, 19, 3, 44, 6, 75, 
    2,  1, 1, 50, 5, 96, 8, 81, 0, 90, 6, 36, 7, 74, 3, 95, 4, 56, 
    4, 18, 8, 27, 2, 46, 0, 18, 6, 90, 7, 53, 5, 85, 1, 39, 3,  7, 
    6, 77, 5, 42, 8, 86, 7, 38, 2, 35, 1, 84, 3, 37, 0, 96, 4, 33
  };
  const int q8848[] = {
    9, 9, // Number of jobs and machines
    3,  1, 1, 75, 8, 53, 0, 52, 5, 50, 4, 95, 2,  5, 7, 50, 6,  9, 
    7, 69, 4, 23, 6, 32, 5,  6, 3, 30, 2, 93, 1, 33, 0, 84, 8, 32, 
    3, 64, 4, 76, 0, 27, 7, 24, 5,  2, 8,  9, 2, 25, 1, 68, 6,  6, 
    8, 26, 4,  2, 0, 75, 5, 63, 3, 13, 6, 99, 7, 69, 1, 89, 2,  2, 
    6, 98, 4, 78, 5, 65, 0, 10, 7, 85, 3, 14, 1, 94, 8, 47, 2, 75, 
    1, 83, 3, 37, 2, 76, 8, 63, 4,  3, 0, 26, 6, 39, 7, 36, 5, 66, 
    7, 78, 1, 81, 0, 42, 5, 95, 6, 52, 8, 65, 3, 58, 2,  2, 4,  7, 
    6, 32, 8, 16, 5, 95, 0, 64, 2, 34, 7, 60, 1, 55, 3,  7, 4, 82, 
    5,  5, 0, 32, 3, 70, 8, 67, 6, 73, 7, 60, 2, 79, 4, 20, 1, 97
  };
  const int q8849[] = {
    9, 9, // Number of jobs and machines
    8, 10, 5, 65, 3, 82, 4, 53, 7, 12, 6, 11, 2,  4, 0, 22, 1, 10, 
    5, 54, 6, 71, 3,  5, 1, 77, 8, 12, 0, 91, 4, 10, 7, 33, 2, 45, 
    3, 63, 8, 32, 6, 44, 1, 85, 2, 86, 4, 54, 0, 55, 7, 96, 5, 93, 
    6, 17, 1, 43, 2, 49, 3, 35, 7, 48, 8,  1, 4, 77, 0,  4, 5, 18, 
    6, 51, 8, 53, 4, 69, 7, 12, 5, 44, 1, 72, 2,  3, 0, 78, 3, 58, 
    6, 36, 2, 57, 0, 43, 4, 98, 3, 15, 5, 15, 8, 83, 7, 76, 1, 45, 
    0, 97, 8, 67, 2, 85, 4, 82, 7,  9, 6, 33, 3, 78, 5, 74, 1, 49, 
    8, 76, 6, 13, 4, 63, 5, 45, 7, 43, 0,  7, 1, 39, 2, 20, 3, 16, 
    5, 13, 8, 93, 1, 93, 3, 57, 2, 91, 4, 21, 7, 35, 6, 41, 0, 56
  };
  const int q8850[] = {
    9, 9, // Number of jobs and machines
    1, 84, 6,  5, 7, 63, 2, 14, 0, 80, 4, 23, 8, 13, 5, 10, 3, 67, 
    6, 60, 8, 96, 5, 26, 1, 25, 7, 21, 0, 65, 3,  4, 4, 26, 2, 49, 
    1, 45, 8, 93, 6, 30, 5, 39, 0, 22, 3,  3, 4, 49, 2, 19, 7, 39, 
    8, 77, 2,  3, 5, 22, 7, 13, 3, 87, 0, 77, 4, 55, 6, 82, 1, 68, 
    7, 38, 6, 73, 5,  3, 4, 46, 1, 69, 3, 82, 0, 70, 8, 62, 2, 96, 
    7, 62, 6, 73, 2, 66, 5, 56, 8, 94, 3, 79, 0, 35, 4, 52, 1, 44, 
    5, 83, 6, 46, 2, 98, 3, 42, 7,  4, 1, 90, 0, 79, 8, 12, 4, 28, 
    6, 28, 3, 95, 2, 33, 8, 47, 1, 74, 4,  8, 0, 28, 7, 82, 5, 67, 
    2, 94, 4, 80, 7, 43, 1,  5, 8, 89, 3, 38, 6, 71, 5, 35, 0, 41
  };
  const int q8851[] = {
    9, 9, // Number of jobs and machines
    3, 36, 0, 42, 1, 47, 6, 93, 4, 60, 5, 24, 2, 38, 8, 14, 7, 91, 
    1, 45, 6,  1, 3, 34, 2, 58, 4, 59, 8, 37, 5, 20, 7, 75, 0, 24, 
    5, 66, 1, 86, 3, 27, 8, 23, 4, 43, 0, 65, 7, 76, 6, 40, 2, 44, 
    3,  2, 6, 92, 1, 84, 4, 56, 2, 74, 8,  9, 7, 76, 5, 38, 0, 35, 
    0, 55, 7, 94, 4, 93, 6, 15, 5, 53, 2, 98, 1, 98, 8, 24, 3, 96, 
    7, 19, 1, 15, 5, 46, 0,  9, 3, 27, 8,  8, 4, 62, 6, 45, 2, 12, 
    3,  7, 2, 19, 0,  2, 7, 34, 5, 76, 8, 47, 1,  3, 6, 22, 4, 72, 
    0, 34, 6, 24, 4, 18, 1, 35, 8, 75, 3, 32, 7, 21, 2, 75, 5, 20, 
    7, 25, 5, 97, 3, 69, 2, 64, 4, 68, 0, 35, 1, 47, 6, 13, 8, 84
  };
  const int q8852[] = {
    9, 9, // Number of jobs and machines
    5, 28, 2,  8, 8, 47, 4, 70, 1,  8, 3, 96, 7, 12, 0, 60, 6, 76, 
    3, 81, 4, 32, 6, 75, 8, 68, 0, 37, 7, 64, 2, 54, 1, 90, 5, 80, 
    6, 90, 8, 93, 1, 12, 5, 18, 4, 78, 0, 69, 7, 75, 3, 25, 2, 69, 
    8, 87, 4, 37, 3, 85, 2, 81, 7, 44, 1,  9, 5, 78, 0, 61, 6, 34, 
    7, 45, 6, 48, 1, 72, 3, 61, 5, 69, 8, 42, 2, 41, 4, 61, 0, 27, 
    5, 36, 6, 46, 0, 24, 7, 12, 2, 67, 8, 48, 3, 68, 4, 34, 1, 10, 
    6, 16, 2, 19, 4, 87, 0, 72, 5, 77, 7, 13, 8,  5, 3,  5, 1, 87, 
    4, 66, 1, 72, 7,  6, 5, 64, 0,  6, 3, 83, 2, 79, 8, 34, 6, 66, 
    3, 82, 6, 49, 0, 15, 4, 93, 2, 79, 5, 60, 7, 46, 1, 86, 8, 43
  };
  const int q8853[] = {
    9, 9, // Number of jobs and machines
    8, 89, 2, 96, 5, 94, 3, 35, 7, 83, 4,  2, 1, 49, 6, 67, 0, 19, 
    7, 50, 3, 78, 2, 35, 0,  6, 1, 76, 6, 98, 5, 82, 4, 73, 8,  7, 
    4, 26, 1, 69, 6, 90, 3, 91, 7, 39, 5, 73, 8, 95, 2, 67, 0, 95, 
    4, 28, 0,  2, 8, 31, 7, 73, 3, 56, 2, 56, 5, 19, 6, 70, 1,  9, 
    5, 85, 8, 53, 6, 68, 0, 25, 1, 44, 4,  7, 3, 49, 7, 14, 2, 92, 
    5, 57, 4, 65, 0, 68, 3,  2, 7, 41, 2, 94, 1, 85, 6, 74, 8, 99, 
    3, 26, 7, 78, 4,  7, 2, 15, 6, 89, 5, 37, 0, 12, 1, 57, 8, 94, 
    2, 36, 3, 71, 1, 63, 8, 90, 5, 44, 7, 16, 6, 78, 0, 94, 4, 12, 
    7, 14, 6, 63, 4, 81, 0, 15, 2, 74, 1, 87, 8, 12, 3, 74, 5, 46
  };
  const int q8854[] = {
    9, 9, // Number of jobs and machines
    3, 19, 6, 89, 7, 43, 2, 10, 8, 63, 4, 92, 1, 80, 0, 12, 5, 49, 
    5, 84, 2, 54, 3, 65, 6, 63, 7, 13, 1, 49, 0, 85, 8, 69, 4, 12, 
    4, 49, 1, 55, 7, 78, 5, 31, 0, 22, 3, 39, 6, 57, 2, 41, 8, 41, 
    5, 45, 7, 68, 6, 56, 8, 48, 3, 60, 1, 85, 2, 13, 0, 71, 4, 48, 
    7, 47, 2, 39, 4, 49, 8, 56, 6, 65, 0, 91, 5, 21, 1, 68, 3, 40, 
    8, 79, 6, 32, 7, 53, 1, 51, 3, 98, 5, 70, 4, 64, 0, 67, 2, 19, 
    3, 99, 0, 38, 7, 29, 1, 43, 5,  7, 4, 52, 8, 36, 6, 65, 2, 91, 
    2, 87, 7, 14, 4, 94, 1, 36, 6, 22, 0, 30, 5, 56, 3, 31, 8, 62, 
    3, 28, 2, 62, 1, 95, 7,  1, 0, 57, 5, 75, 6, 43, 4, 15, 8, 88
  };
  const int q8855[] = {
    9, 9, // Number of jobs and machines
    0, 71, 6, 53, 3, 48, 4, 80, 8, 68, 2, 51, 7, 83, 5, 12, 1, 85, 
    3, 38, 7, 17, 4, 29, 2, 34, 8, 53, 6, 84, 1,  6, 0, 29, 5, 37, 
    0, 81, 5, 23, 1,  5, 3, 51, 4, 61, 8, 35, 7, 88, 6, 30, 2, 18, 
    7, 89, 5, 24, 4, 57, 6, 89, 1, 19, 0, 44, 3,  4, 2, 82, 8, 71, 
    6, 10, 4, 19, 1, 31, 3, 92, 5, 90, 7, 71, 0, 91, 8,  2, 2,  4, 
    0, 87, 3,  3, 6, 34, 8, 16, 4, 69, 2, 55, 7, 36, 1, 56, 5, 97, 
    5, 51, 7, 14, 3, 74, 8, 21, 1, 41, 2, 41, 0, 18, 4, 48, 6, 67, 
    1, 77, 8, 42, 3, 49, 5, 70, 4, 14, 6, 32, 0, 33, 7, 10, 2, 18, 
    7, 97, 5, 78, 0, 25, 8, 96, 2, 82, 1, 79, 3, 25, 4, 45, 6,  1
  };
  const int q8856[] = {
    9, 9, // Number of jobs and machines
    1, 52, 0, 55, 3, 41, 4, 25, 7, 11, 5,  8, 8, 93, 2, 59, 6, 42, 
    3, 16, 2, 38, 4, 98, 6, 59, 5, 87, 7, 10, 0, 65, 1, 42, 8, 12, 
    0, 20, 2, 58, 7, 82, 5, 28, 4, 53, 1, 39, 8, 82, 3, 93, 6, 68, 
    1, 23, 6, 73, 3, 58, 4, 66, 8, 52, 0, 94, 2, 73, 5, 33, 7,  7, 
    0, 30, 1, 83, 3, 50, 5, 92, 6, 45, 7, 78, 2, 92, 8, 71, 4, 99, 
    6,  4, 3, 92, 7, 63, 2, 75, 0, 73, 8, 95, 5,  8, 4, 84, 1, 10, 
    7, 79, 2, 95, 3,  7, 0, 70, 1, 36, 5, 80, 6, 91, 8, 76, 4, 26, 
    8, 78, 4, 68, 0, 98, 2, 99, 1, 63, 5, 62, 3,  5, 7, 11, 6, 89, 
    7, 62, 2, 76, 3, 31, 4, 75, 8, 77, 1, 83, 6, 44, 5, 52, 0, 23
  };
  const int q8857[] = {
    9, 9, // Number of jobs and machines
    8, 57, 1, 80, 2, 19, 3, 92, 6, 35, 7, 60, 0, 90, 4,  5, 5, 17, 
    6, 17, 8, 41, 0, 18, 2, 74, 4, 57, 7, 63, 1, 99, 3, 24, 5, 52, 
    8, 31, 1, 29, 2, 16, 4, 22, 6, 42, 7, 99, 5, 70, 3, 39, 0, 84, 
    6, 30, 7, 32, 3,  5, 2, 39, 1, 14, 0, 48, 8, 19, 4, 51, 5, 57, 
    1, 20, 2, 56, 6, 55, 7,  4, 0, 77, 3, 62, 5,  1, 8,  7, 4, 80, 
    6, 51, 5,  7, 0, 40, 2, 77, 8, 66, 7, 52, 1, 70, 3, 89, 4, 82, 
    3, 22, 6, 88, 4,  8, 2,  6, 7, 99, 8, 86, 1, 65, 0, 75, 5, 87, 
    4, 91, 0, 28, 7, 12, 8,  4, 1, 31, 6, 11, 2, 50, 5, 79, 3, 95, 
    0, 46, 3, 34, 1, 78, 7, 45, 5, 83, 4, 14, 6, 39, 2, 38, 8, 80
  };
  const int q8858[] = {
    9, 9, // Number of jobs and machines
    8, 27, 2, 34, 7, 34, 5,  7, 6, 77, 3, 34, 4, 84, 0, 84, 1, 44, 
    1, 69, 3, 93, 7, 10, 5, 79, 2, 88, 0, 81, 8, 35, 6, 24, 4, 22, 
    7, 57, 5, 32, 4, 78, 6, 53, 2, 62, 8, 30, 0, 24, 1, 85, 3, 12, 
    2, 35, 4, 77, 0, 89, 5, 20, 7,  2, 8, 67, 6, 91, 1, 42, 3, 46, 
    1, 89, 0, 82, 6, 17, 8, 87, 2, 49, 5, 13, 3, 49, 4, 69, 7, 85, 
    8, 21, 7, 10, 3, 29, 2, 16, 6, 13, 4, 26, 5, 66, 0, 70, 1, 25, 
    2, 60, 3, 50, 7, 35, 4, 38, 6, 32, 0,  4, 1, 19, 8, 39, 5, 80, 
    6,  7, 1, 99, 8,  9, 7, 77, 4, 16, 2, 14, 3, 81, 0, 10, 5, 24, 
    8, 48, 2, 14, 7, 99, 1, 96, 4, 15, 6, 90, 0, 65, 3, 94, 5, 44
  };
  const int q8859[] = {
    9, 9, // Number of jobs and machines
    1, 65, 6, 87, 2, 24, 0, 85, 3, 48, 5, 60, 8, 25, 4, 57, 7, 65, 
    7, 30, 3, 83, 6, 26, 8,  2, 0, 10, 5, 65, 2, 96, 4, 28, 1, 33, 
    6, 60, 8, 90, 5, 24, 1, 55, 7, 67, 3, 43, 2, 94, 0, 60, 4, 69, 
    3, 11, 0, 26, 5, 32, 2, 34, 8, 15, 6, 43, 7, 28, 4, 91, 1, 37, 
    2, 52, 3, 26, 6, 61, 5, 90, 0, 55, 4, 36, 7, 93, 1, 33, 8, 36, 
    6, 51, 2, 15, 1, 12, 4,  6, 7, 60, 5, 20, 0, 34, 3, 53, 8, 85, 
    8, 43, 7, 63, 2, 28, 5, 64, 3,  9, 4, 78, 1, 51, 6, 92, 0, 76, 
    5, 77, 7,  1, 3, 94, 8, 97, 0, 31, 1, 53, 6,  2, 2, 68, 4, 44, 
    6, 29, 0, 28, 7, 29, 1, 88, 4, 34, 5, 90, 3, 84, 2, 79, 8,  7
  };
  const int q8860[] = {
    9, 9, // Number of jobs and machines
    4, 20, 1, 32, 8, 98, 2, 59, 0,  9, 6, 80, 3, 24, 5, 61, 7, 88, 
    7, 21, 5, 69, 4, 94, 0, 61, 6, 33, 2, 58, 1, 19, 3, 69, 8, 67, 
    2, 72, 6,  2, 0, 78, 3, 14, 4, 63, 7, 75, 5,  3, 1, 79, 8, 78, 
    3, 60, 7, 49, 6, 40, 8, 15, 1, 57, 0, 84, 2, 35, 5, 66, 4, 23, 
    5,  5, 4, 62, 8, 13, 3,  8, 2, 76, 7, 30, 6, 41, 1, 77, 0, 46, 
    4, 44, 1, 57, 3, 75, 2, 65, 0, 53, 6, 54, 5, 33, 7, 79, 8, 76, 
    3, 98, 5, 79, 2, 50, 4, 51, 1,  7, 8, 13, 0, 70, 7, 18, 6, 25, 
    0, 70, 8, 62, 6, 74, 5, 83, 7, 40, 3,  7, 2, 79, 4, 51, 1, 37, 
    5, 32, 4, 14, 1, 12, 0, 70, 7, 33, 3, 83, 6, 68, 8, 42, 2, 31
  };
  const int q8861[] = {
    9, 9, // Number of jobs and machines
    5, 67, 8, 63, 1, 45, 7, 91, 2, 53, 6, 98, 4, 26, 3, 83, 0,  8, 
    1, 42, 0, 69, 6,  4, 2, 62, 8, 39, 3, 29, 5, 67, 4, 56, 7, 56, 
    1, 65, 3, 88, 4, 79, 0, 79, 2, 57, 8, 92, 7, 74, 6, 69, 5,  9, 
    7, 64, 3, 34, 1, 89, 6,  3, 0, 69, 5, 47, 4, 47, 8,  4, 2, 97, 
    4, 55, 0, 17, 5, 99, 3, 90, 2, 83, 1, 28, 7, 40, 8, 30, 6, 23, 
    5, 25, 1, 35, 0, 22, 6, 98, 4, 17, 7, 10, 3, 97, 2, 29, 8, 76, 
    5,  5, 8, 72, 1, 75, 7, 89, 0,  7, 2, 43, 3, 47, 6, 39, 4, 56, 
    3, 66, 4, 93, 7, 85, 8, 59, 0, 55, 6, 45, 2, 92, 1, 39, 5, 54, 
    1, 24, 8, 59, 5, 84, 3, 30, 2, 54, 4, 68, 7, 61, 6, 28, 0, 30
  };
  const int q8862[] = {
    9, 9, // Number of jobs and machines
    8, 70, 1,  5, 2,  8, 6, 33, 7, 54, 4, 56, 3, 41, 5, 12, 0, 56, 
    4, 75, 6, 11, 5, 95, 3, 64, 2,  9, 0, 12, 7, 72, 1, 18, 8, 33, 
    8, 17, 0, 96, 3, 28, 2, 69, 4, 32, 1,  5, 7, 60, 6, 83, 5, 98, 
    5,  5, 1, 46, 6, 29, 4, 83, 8, 42, 3, 75, 0, 83, 7, 69, 2, 19, 
    5, 94, 6, 43, 8, 29, 3, 63, 4, 16, 7, 70, 2, 88, 0, 55, 1, 93, 
    2, 96, 1, 10, 3, 71, 4, 17, 0, 28, 5, 54, 6, 26, 7, 19, 8, 20, 
    4,  6, 8, 99, 2, 19, 6, 60, 0, 49, 5,  4, 1, 38, 7, 72, 3, 47, 
    2,  2, 5, 82, 6, 25, 1, 42, 3,  2, 8,  1, 7, 54, 0, 77, 4, 20, 
    5, 74, 0, 25, 6, 11, 3, 25, 7,  2, 2, 32, 8, 63, 1, 61, 4, 90
  };
  const int q8863[] = {
    9, 9, // Number of jobs and machines
    1, 51, 2, 22, 4, 72, 3, 72, 5,  1, 7, 96, 0, 30, 8, 59, 6, 58, 
    5,  8, 7, 11, 0, 61, 2, 14, 3, 16, 4, 47, 8, 33, 6, 39, 1, 89, 
    4, 66, 2, 72, 0, 65, 3,  6, 1, 94, 7, 55, 6, 79, 5, 73, 8,  1, 
    8,  7, 6, 64, 1, 14, 5, 54, 4, 57, 3, 61, 7, 37, 2, 91, 0,  5, 
    3, 10, 5, 99, 8, 67, 1, 31, 0, 76, 4, 10, 6, 13, 2, 90, 7, 86, 
    1, 59, 6, 20, 4, 24, 3, 94, 5, 33, 8, 79, 0,  9, 7, 65, 2, 98, 
    6, 23, 1, 25, 4, 51, 2, 10, 8, 48, 3, 58, 0, 50, 5, 64, 7, 45, 
    2, 81, 7, 65, 3, 95, 1, 74, 0, 53, 6, 21, 5, 16, 4, 71, 8, 24, 
    8, 85, 5, 81, 4, 23, 7,  5, 0, 54, 3, 47, 6, 76, 2, 14, 1, 93
  };
  const int q8864[] = {
    9, 9, // Number of jobs and machines
    2, 12, 8, 39, 7, 31, 1, 48, 3, 33, 5, 76, 4, 46, 0, 30, 6, 38, 
    7, 40, 6, 39, 2, 53, 0, 37, 3, 49, 4, 40, 5,  1, 1, 58, 8,  5, 
    2, 90, 0, 88, 4, 77, 3, 44, 5,  7, 7, 63, 6, 80, 8, 38, 1, 80, 
    8, 25, 0,  9, 5, 38, 4, 84, 7, 12, 6, 10, 3, 43, 1, 71, 2,  5, 
    6, 87, 0, 60, 5, 20, 4, 61, 8, 70, 7, 67, 3,  4, 2, 16, 1, 80, 
    4, 26, 6, 46, 1, 47, 3, 98, 0, 53, 8, 15, 2, 59, 5, 38, 7, 59, 
    2, 67, 5, 35, 0, 77, 8, 57, 1, 85, 6,  1, 4, 84, 7, 81, 3, 61, 
    7, 37, 3, 17, 2, 94, 6, 89, 5, 50, 8,  4, 0, 77, 4, 23, 1, 37, 
    5, 33, 6, 59, 2, 35, 8, 47, 0, 67, 4, 47, 7, 58, 1, 66, 3, 42
  };
  const int q8865[] = {
    9, 9, // Number of jobs and machines
    5, 63, 0, 97, 2, 22, 3, 12, 4, 30, 8, 18, 6, 58, 7, 95, 1, 71, 
    1, 86, 4,  6, 5, 44, 8, 91, 3, 65, 2, 88, 0, 53, 7, 76, 6, 50, 
    2, 29, 6, 10, 5, 71, 7, 99, 1, 16, 8, 66, 0, 72, 3,  6, 4, 24, 
    7, 34, 6, 72, 2, 31, 0, 10, 8, 78, 3, 99, 4, 50, 5, 81, 1, 59, 
    0,  5, 7, 61, 3, 53, 2, 75, 8, 49, 1, 62, 6, 30, 4, 58, 5,  1, 
    4, 53, 8, 95, 2, 92, 6, 79, 3, 45, 0,  1, 5, 69, 1, 75, 7, 91, 
    0, 64, 6, 28, 8, 92, 3,  9, 7, 70, 4,  3, 1, 82, 2, 91, 5, 94, 
    0, 65, 1, 61, 2, 83, 4, 46, 7, 48, 5, 53, 3, 82, 6, 81, 8, 53, 
    3, 84, 6, 77, 1, 33, 8, 30, 7, 12, 4, 13, 5, 38, 2,  6, 0, 23
  };
  const int q8866[] = {
    9, 9, // Number of jobs and machines
    8, 68, 7, 29, 4, 90, 0, 65, 6, 84, 5, 73, 3, 73, 2, 99, 1, 50, 
    2, 56, 1, 30, 7, 14, 3, 91, 6, 19, 8, 30, 0, 30, 4, 55, 5, 40, 
    5, 93, 3, 38, 7, 46, 2, 29, 1, 20, 8, 16, 6, 42, 4, 74, 0, 62, 
    6, 21, 5, 46, 8, 15, 1, 17, 4, 48, 3, 13, 2, 14, 0, 20, 7, 46, 
    2, 81, 0, 12, 6, 72, 5, 92, 8, 10, 1, 16, 3,  9, 4, 95, 7, 98, 
    4, 91, 7,  2, 8, 79, 2, 66, 5, 35, 6, 78, 1, 38, 0, 52, 3, 79, 
    4, 90, 0, 37, 6,  4, 3, 32, 1, 13, 2, 19, 8, 11, 5, 44, 7, 87, 
    0, 92, 8, 75, 3, 44, 5, 66, 1, 24, 2, 93, 4, 48, 7, 92, 6, 61, 
    3, 73, 2, 28, 0, 44, 8, 92, 6, 61, 4, 69, 1, 39, 7, 50, 5, 49
  };
  const int q8867[] = {
    9, 9, // Number of jobs and machines
    1,  7, 3, 88, 0, 48, 8, 57, 2, 24, 5, 65, 4, 47, 6, 47, 7, 30, 
    3, 62, 5, 34, 1, 98, 7, 90, 2, 70, 6, 43, 4, 67, 8, 55, 0, 98, 
    6, 62, 8, 64, 1, 15, 3, 46, 0, 61, 5, 96, 2, 22, 4, 28, 7, 47, 
    6, 81, 1, 71, 2, 84, 3,  8, 5,  4, 8, 48, 7, 33, 0, 80, 4, 28, 
    7, 29, 4, 92, 0, 59, 6, 69, 3, 43, 1, 28, 2, 95, 8, 25, 5, 33, 
    2, 80, 1, 53, 3, 21, 6,  2, 4, 47, 5, 66, 7, 28, 8, 10, 0, 69, 
    8, 59, 3,  9, 1, 25, 4, 72, 0, 45, 2, 48, 5, 56, 7, 10, 6, 19, 
    1, 75, 8, 61, 4, 73, 3, 72, 2, 57, 7, 73, 6, 90, 0, 34, 5, 72, 
    5, 67, 1, 30, 7, 47, 8, 88, 6, 50, 0, 27, 2, 20, 4, 43, 3, 58
  };
  const int q8868[] = {
    9, 9, // Number of jobs and machines
    2, 14, 6, 16, 7, 50, 0, 65, 4, 25, 5, 43, 3, 13, 1,  1, 8, 86, 
    2, 36, 3, 17, 7, 14, 0, 99, 4, 98, 1, 81, 5, 69, 8, 70, 6, 65, 
    8, 20, 6, 47, 4, 53, 5, 28, 3, 53, 7, 59, 2, 25, 1, 28, 0, 16, 
    8, 17, 5,  9, 3, 70, 0, 92, 7, 12, 4, 54, 6, 99, 1, 49, 2, 22, 
    8, 77, 6, 90, 5,  4, 7, 32, 2, 90, 0, 95, 4, 90, 3, 70, 1, 59, 
    8, 84, 2, 62, 1, 60, 4,  7, 3,  5, 0, 28, 7, 88, 5, 21, 6,  1, 
    1, 57, 0, 42, 5,  9, 7, 68, 8, 42, 6, 39, 2,  2, 4, 78, 3, 27, 
    6, 41, 0, 65, 7,  8, 3, 78, 2, 77, 5, 59, 8, 94, 1, 18, 4, 71, 
    4, 96, 5, 22, 8, 76, 2,  7, 3, 86, 0, 38, 1, 86, 6, 19, 7, 27
  };
  const int q8869[] = {
    9, 9, // Number of jobs and machines
    4, 22, 0, 78, 7, 32, 6, 96, 8, 61, 1, 31, 3,  4, 2,  4, 5, 63, 
    2, 44, 3, 45, 0,  4, 6, 94, 7, 72, 8, 50, 4, 71, 5, 56, 1, 80, 
    1, 61, 8, 55, 7, 73, 2, 64, 6, 25, 4, 69, 3, 53, 0, 18, 5, 49, 
    1, 17, 2, 10, 0, 12, 8, 56, 4, 91, 5, 77, 7,  5, 3, 58, 6, 58, 
    8, 84, 6, 80, 5, 91, 3, 41, 0, 34, 4, 18, 7, 35, 1, 61, 2, 78, 
    0, 95, 8, 24, 4, 32, 2, 68, 6, 94, 5, 17, 1,  7, 7, 30, 3, 48, 
    3, 12, 4, 86, 8, 42, 7, 50, 0, 85, 1, 73, 2, 20, 6, 55, 5, 58, 
    5, 59, 0,  9, 4,  3, 1,  9, 7, 97, 3, 47, 2, 85, 6, 99, 8,  3, 
    5, 44, 4, 37, 7, 41, 6, 22, 8, 44, 3, 57, 0, 33, 1, 74, 2, 36
  };
  const int q8870[] = {
    9, 9, // Number of jobs and machines
    8, 73, 0, 89, 1, 93, 3, 42, 2, 40, 5, 74, 7, 45, 4, 20, 6, 69, 
    1,  4, 7, 92, 3, 70, 6, 66, 0, 82, 8, 26, 4, 76, 2, 61, 5, 64, 
    2, 56, 4, 77, 8, 73, 5, 37, 7, 37, 6, 43, 3, 51, 1, 69, 0, 24, 
    6, 22, 5, 55, 2, 43, 3,  1, 0, 11, 8, 22, 7, 36, 4, 26, 1, 10, 
    5, 63, 1, 26, 6, 95, 2, 96, 7, 83, 8, 84, 3, 66, 4, 33, 0, 51, 
    8, 61, 0, 94, 3, 55, 7, 44, 6, 19, 4,  1, 5, 42, 1, 67, 2, 79, 
    8, 24, 0, 49, 4, 86, 6, 50, 1, 73, 7, 42, 5, 46, 3, 79, 2, 54, 
    0, 70, 4, 46, 8, 80, 3, 35, 2, 38, 1, 83, 6, 17, 7, 28, 5, 87, 
    0, 36, 3, 75, 2, 99, 8, 12, 1, 75, 7, 20, 6, 90, 4, 17, 5,  4
  };
  const int q8871[] = {
    9, 9, // Number of jobs and machines
    7, 64, 1, 76, 3,  3, 2, 97, 8, 27, 4, 40, 0, 62, 6, 10, 5, 25, 
    7, 51, 0, 11, 8, 51, 6,  5, 5, 92, 4, 32, 1,  3, 2, 79, 3,  3, 
    4, 41, 1, 28, 6, 20, 2, 95, 3, 74, 0, 58, 7, 69, 5, 22, 8, 23, 
    7, 50, 6, 29, 2, 69, 5, 42, 8, 81, 0, 99, 4, 62, 3, 58, 1, 42, 
    0, 92, 6, 95, 7, 79, 5, 49, 4, 41, 8, 62, 2, 65, 1, 17, 3, 51, 
    6, 25, 8,  4, 0, 62, 4, 26, 3, 15, 2, 70, 1, 14, 7, 59, 5, 29, 
    3, 13, 2, 69, 5, 76, 4, 58, 6, 91, 1, 83, 8, 20, 7, 76, 0, 32, 
    0, 84, 5, 89, 1, 99, 4, 59, 3, 56, 6, 82, 7, 46, 8,  3, 2, 64, 
    8, 72, 1, 93, 4, 93, 3, 72, 0, 39, 5, 66, 2, 53, 6, 31, 7, 31
  };
  const int q8872[] = {
    9, 9, // Number of jobs and machines
    4,  8, 3, 31, 8, 86, 1, 10, 2, 85, 0, 97, 5, 95, 6,  9, 7, 44, 
    4, 40, 7, 14, 0, 40, 2, 13, 1, 29, 6, 31, 8, 74, 5, 79, 3, 58, 
    2, 98, 1,  3, 7,  7, 0, 19, 8, 21, 6, 89, 5, 61, 4, 26, 3, 35, 
    5, 53, 0,  5, 3, 32, 8, 76, 7,  7, 2, 58, 6, 33, 1, 89, 4, 45, 
    5, 12, 4,  4, 8,  4, 7, 14, 1, 39, 0, 97, 3, 43, 6, 94, 2, 98, 
    0, 44, 3, 26, 6, 26, 8, 34, 1, 32, 5, 72, 2, 35, 4, 65, 7,  6, 
    8, 57, 2, 45, 4, 62, 1, 71, 5, 82, 7, 75, 6, 13, 3, 74, 0, 65, 
    4, 85, 2,  9, 0, 85, 5, 59, 1, 22, 3, 55, 8, 27, 7, 55, 6, 68, 
    4, 11, 0, 54, 3, 11, 2, 13, 1, 67, 6, 70, 5, 70, 7, 93, 8, 33
  };
  const int q8873[] = {
    9, 9, // Number of jobs and machines
    8, 44, 2, 17, 6, 81, 7, 53, 3, 40, 1, 84, 5,  5, 0, 94, 4, 93, 
    3, 88, 7, 12, 5, 71, 0, 52, 4, 46, 2,  7, 6,  6, 8, 25, 1, 87, 
    5, 50, 1, 86, 0,  5, 7, 22, 4, 38, 6, 74, 3, 28, 8, 29, 2, 88, 
    8, 59, 3, 13, 4, 90, 2, 31, 5, 75, 0, 69, 7, 40, 1, 16, 6, 71, 
    6, 37, 4, 20, 5, 32, 3, 50, 8, 62, 1, 52, 2, 64, 0, 43, 7, 36, 
    3, 20, 8, 48, 7, 70, 0, 79, 1, 91, 5, 71, 6, 32, 4, 35, 2, 81, 
    8,  7, 1, 95, 3, 60, 2, 69, 4, 38, 7, 96, 6,  3, 0,  7, 5, 47, 
    5, 83, 8,  1, 1, 95, 6, 27, 0, 48, 4, 70, 7, 20, 2, 79, 3, 88, 
    5, 92, 1, 44, 0, 73, 6, 28, 2, 42, 3, 89, 7, 10, 4, 34, 8, 71
  };
  const int q8874[] = {
    9, 9, // Number of jobs and machines
    8, 66, 3, 81, 6, 15, 2,  9, 4, 60, 1, 81, 5, 23, 7, 31, 0, 81, 
    7, 23, 1, 70, 6,  7, 0, 40, 5, 21, 2, 96, 3, 89, 8, 57, 4, 25, 
    2, 80, 5, 64, 4, 68, 1, 55, 6, 81, 0, 14, 3, 69, 7, 67, 8, 87, 
    5, 62, 2, 56, 3, 44, 0, 71, 4, 68, 1, 63, 6, 91, 8, 64, 7, 89, 
    1, 87, 8, 71, 5, 36, 6, 57, 7, 22, 4, 85, 0, 26, 3, 11, 2, 63, 
    2, 55, 1, 74, 5,  4, 3, 66, 4, 71, 8, 67, 7, 91, 0, 70, 6, 48, 
    8, 12, 0, 10, 2, 79, 3, 23, 4, 87, 6, 17, 5, 81, 1, 54, 7, 67, 
    2, 70, 4, 51, 8, 39, 1, 48, 6, 20, 3, 15, 7, 28, 5, 45, 0, 45, 
    1, 17, 7,  5, 4, 63, 5, 48, 6,  6, 2, 89, 0, 73, 3, 25, 8, 42
  };
  const int q8875[] = {
    9, 9, // Number of jobs and machines
    3, 51, 8, 32, 6,  8, 2,  1, 1, 33, 4, 52, 7, 42, 0, 41, 5, 79, 
    5, 85, 7, 86, 0, 62, 4, 21, 3, 86, 6, 67, 1, 14, 8, 37, 2, 86, 
    3, 17, 0,  2, 6, 31, 8, 74, 1,  6, 2, 86, 7, 77, 5, 26, 4, 24, 
    7, 46, 3, 54, 4, 44, 8, 57, 1, 82, 5, 72, 6, 56, 0,  1, 2, 33, 
    0, 85, 3, 37, 2, 22, 4, 14, 8, 44, 1, 64, 5, 73, 6, 63, 7, 71, 
    3, 58, 4, 53, 6, 89, 2, 26, 0, 23, 1, 89, 8, 14, 5, 54, 7, 39, 
    0, 79, 2, 60, 6, 25, 7, 89, 1, 14, 8, 19, 5, 58, 4, 56, 3, 88, 
    5, 17, 3,  4, 8, 59, 0,  1, 6, 99, 2, 89, 7, 89, 4, 74, 1, 16, 
    1, 40, 6,  1, 5, 71, 8,  7, 3,  1, 4, 71, 7, 44, 2, 31, 0, 51
  };
  const int q8876[] = {
    9, 9, // Number of jobs and machines
    2, 94, 7, 88, 6, 50, 8, 30, 5, 13, 0, 67, 4, 48, 3, 66, 1, 79, 
    7, 64, 6, 72, 2, 10, 1, 57, 4, 24, 8, 31, 5, 91, 3, 31, 0, 16, 
    3,  5, 6, 44, 5, 82, 2, 76, 7, 88, 0,  7, 8, 89, 1, 64, 4, 75, 
    7, 47, 1, 82, 0, 97, 2, 40, 6, 36, 4, 87, 3,  9, 5, 37, 8, 81, 
    0, 28, 4, 84, 7, 75, 8, 83, 1, 79, 6, 14, 5, 81, 3, 44, 2, 33, 
    8, 77, 7, 63, 3, 22, 2, 21, 4, 10, 6, 27, 5, 10, 0, 64, 1, 78, 
    2, 76, 0, 57, 4, 99, 7, 73, 5, 92, 6, 18, 8,  3, 3, 47, 1, 64, 
    5, 42, 1, 71, 6, 39, 0, 55, 7, 30, 2, 72, 3, 85, 8, 76, 4, 97, 
    6, 97, 1, 17, 4, 23, 8, 85, 5,  2, 2, 67, 7, 97, 0, 70, 3, 44
  };
  const int q8877[] = {
    9, 9, // Number of jobs and machines
    1, 87, 3, 71, 6, 49, 0, 26, 5,  9, 2, 29, 8, 69, 4, 10, 7, 22, 
    0, 31, 2, 63, 8, 22, 4, 47, 1, 10, 7, 46, 6, 13, 3, 69, 5, 82, 
    3, 98, 2, 23, 6, 16, 7, 80, 1, 28, 5, 44, 4, 50, 0, 99, 8, 36, 
    3,  6, 7, 13, 8,  6, 0,  7, 4, 87, 2, 57, 5, 97, 6, 13, 1, 98, 
    0, 40, 4, 81, 6,  1, 3, 43, 1, 27, 5, 26, 8, 49, 2, 52, 7, 27, 
    8, 75, 3, 34, 2, 21, 0,  6, 4,  6, 7, 91, 6, 51, 1, 42, 5, 83, 
    6, 33, 2,  5, 7, 68, 4, 10, 0, 70, 1, 40, 3, 18, 5, 15, 8, 99, 
    7, 62, 2, 53, 8, 37, 3, 71, 0, 12, 6, 43, 4, 41, 5, 18, 1,  2, 
    8, 30, 3, 32, 0, 74, 5, 19, 2, 65, 4, 40, 1, 19, 6, 17, 7, 54
  };
  const int q8878[] = {
    9, 9, // Number of jobs and machines
    4,  9, 6, 32, 5,  3, 3,  4, 1, 29, 7,  2, 8, 55, 2, 27, 0, 17, 
    5, 15, 0, 30, 7, 21, 2, 39, 4, 60, 1, 61, 3, 93, 6, 60, 8, 82, 
    7, 76, 3, 47, 2, 58, 0,  1, 5, 74, 8, 96, 6, 24, 1, 51, 4, 85, 
    3, 12, 6, 40, 1, 62, 8, 77, 2, 24, 5, 44, 0, 93, 7, 66, 4, 92, 
    8, 50, 2, 23, 5, 23, 1, 21, 7, 83, 0, 19, 4, 17, 6, 99, 3, 98, 
    7, 29, 3, 65, 8, 20, 4, 68, 0, 71, 1, 73, 6, 60, 5, 45, 2, 22, 
    6, 84, 4, 75, 2, 69, 8, 45, 7, 25, 5, 31, 3, 54, 0, 35, 1, 15, 
    5, 39, 6, 44, 7, 57, 8, 51, 2, 40, 4, 47, 3, 44, 0, 66, 1, 52, 
    0, 98, 1, 50, 5, 20, 4, 77, 3, 51, 7, 17, 2,  8, 6, 39, 8, 67
  };
  const int q8879[] = {
    9, 9, // Number of jobs and machines
    6, 94, 0, 17, 8, 34, 1, 40, 3, 98, 2, 81, 5,  2, 4, 60, 7, 10, 
    5, 84, 8, 21, 0, 47, 7, 41, 3, 41, 6,  4, 2, 38, 4,  6, 1, 89, 
    6, 71, 0, 58, 3, 83, 7, 27, 5, 31, 1, 10, 2, 52, 8, 34, 4, 61, 
    2, 39, 0, 94, 5,  7, 3, 98, 8, 19, 4, 86, 7, 25, 6, 40, 1, 36, 
    1, 18, 7, 27, 4, 37, 2, 74, 6, 14, 5, 12, 8, 18, 0, 76, 3, 72, 
    3, 54, 8,  3, 7, 22, 6, 98, 4, 94, 0, 49, 5, 48, 1, 59, 2,  9, 
    8, 59, 7,  7, 1, 96, 0, 55, 3,  7, 5, 32, 4, 64, 6, 89, 2, 32, 
    4, 28, 3, 38, 0, 35, 7, 51, 6, 51, 2, 89, 5, 96, 8, 78, 1, 17, 
    1, 70, 6, 55, 5, 87, 0, 17, 8, 37, 4, 20, 2, 94, 7, 83, 3, 71
  };
  const int q8880[] = {
    9, 9, // Number of jobs and machines
    5, 64, 1, 98, 6, 14, 8, 11, 2, 40, 0, 12, 3, 65, 4, 86, 7, 32, 
    5, 15, 0, 44, 1, 49, 3, 65, 6, 34, 8, 72, 2, 45, 4, 69, 7, 13, 
    0, 64, 4, 85, 3, 38, 6, 36, 1, 43, 8, 76, 5, 41, 2, 41, 7, 21, 
    5, 91, 7, 42, 0, 24, 1, 44, 4, 92, 6, 32, 3, 62, 2, 91, 8, 24, 
    2,  8, 5, 37, 0, 25, 8, 53, 3, 79, 1,  3, 6, 77, 7, 33, 4, 12, 
    8,  9, 0, 55, 7, 43, 4,  8, 5, 46, 6, 74, 3, 63, 2, 15, 1, 14, 
    8, 79, 6, 50, 3, 13, 5, 93, 0, 16, 7, 55, 4, 71, 1, 33, 2, 39, 
    1, 73, 7, 99, 5,  4, 4, 17, 6, 88, 2, 10, 0, 18, 3, 35, 8, 34, 
    1, 84, 8, 25, 6, 25, 2, 69, 4, 16, 3, 12, 0, 79, 7, 57, 5, 17
  };
  const int q8881[] = {
    9, 9, // Number of jobs and machines
    7, 39, 5,  5, 4, 46, 6, 97, 8, 46, 0, 73, 2, 52, 1, 52, 3, 32, 
    7, 98, 0, 24, 5,  3, 6, 30, 4, 27, 2, 42, 3, 27, 8, 97, 1,  7, 
    7, 25, 3, 95, 6,  7, 8, 48, 1, 47, 2, 25, 4, 31, 0, 50, 5, 99, 
    0, 42, 8, 81, 5, 35, 2, 15, 6, 71, 3, 54, 4, 19, 1, 40, 7, 31, 
    7, 44, 2, 13, 4, 31, 6, 34, 1, 89, 0, 17, 5, 93, 8, 47, 3, 70, 
    2, 77, 1, 49, 0, 99, 6, 64, 5, 68, 7, 87, 8, 56, 3, 55, 4, 42, 
    7, 37, 8,  8, 5,  6, 6, 29, 0, 22, 3, 96, 1, 82, 2, 24, 4, 40, 
    6, 69, 8, 16, 7, 39, 5, 33, 1, 47, 4, 54, 0, 89, 3,  4, 2, 43, 
    4, 43, 0, 56, 7, 67, 5, 66, 2, 73, 3, 26, 1, 16, 6, 75, 8, 67
  };
  const int q8882[] = {
    9, 9, // Number of jobs and machines
    1, 41, 3, 65, 8, 52, 0,  4, 5, 47, 6,  9, 2, 52, 4, 61, 7, 53, 
    2,  3, 6, 32, 4, 54, 8, 67, 7, 47, 5, 60, 3, 62, 1, 55, 0, 16, 
    3, 48, 6, 11, 8, 40, 0, 51, 5, 54, 1, 97, 7, 63, 2, 22, 4, 79, 
    1, 34, 8, 58, 6, 17, 5, 73, 2, 83, 4, 70, 0,  3, 3, 82, 7, 73, 
    3, 84, 7, 52, 8, 36, 1, 51, 6, 73, 0, 79, 2,  7, 5, 74, 4, 93, 
    2, 70, 7, 53, 5, 49, 8, 97, 3, 47, 4, 24, 6, 86, 1, 88, 0, 68, 
    3, 85, 0, 95, 7,  5, 4, 64, 8, 26, 5, 93, 2,  4, 6, 68, 1, 75, 
    4, 93, 6, 98, 8, 43, 5, 36, 3, 80, 0, 98, 1, 88, 2, 39, 7, 36, 
    6, 89, 5, 54, 0, 81, 3, 41, 2, 34, 7, 72, 8, 23, 1, 61, 4, 98
  };
  const int q8883[] = {
    9, 9, // Number of jobs and machines
    7, 55, 8, 35, 3, 16, 2, 29, 6, 45, 1, 50, 4, 34, 5, 89, 0, 87, 
    3, 93, 5, 48, 8, 30, 6,  4, 7, 24, 4, 31, 2, 36, 0, 59, 1, 68, 
    3, 78, 7, 66, 4, 24, 8, 76, 2, 59, 6, 30, 0, 25, 1, 69, 5,  9, 
    8, 71, 6, 47, 7, 44, 3, 97, 5, 49, 2, 55, 0, 75, 4, 95, 1, 93, 
    1, 76, 6, 66, 0, 56, 3, 76, 8, 30, 2, 84, 7, 33, 4, 38, 5, 97, 
    0, 15, 6, 46, 8, 95, 1, 65, 4, 33, 3, 69, 2, 25, 7, 87, 5, 59, 
    8, 27, 3, 39, 6,  5, 1, 78, 4, 84, 5, 28, 0, 75, 2, 94, 7, 29, 
    8, 33, 7, 74, 2, 84, 3, 51, 6,  9, 4, 13, 1, 35, 5, 52, 0, 60, 
    0,  4, 5,  8, 1, 75, 3, 96, 8, 90, 2, 97, 4, 14, 6, 65, 7, 36
  };
  const int q8884[] = {
    9, 9, // Number of jobs and machines
    6, 49, 4, 35, 7, 83, 8, 71, 2, 73, 5, 78, 0, 44, 1,  5, 3, 83, 
    1, 76, 5, 82, 7, 57, 6, 61, 2, 22, 3, 33, 8, 74, 0, 53, 4, 82, 
    2, 70, 3, 71, 7, 16, 0, 66, 1, 96, 5, 44, 6, 90, 8, 57, 4, 96, 
    3, 64, 6, 99, 8, 26, 1, 32, 4, 89, 7, 59, 2, 51, 0, 40, 5, 19, 
    2, 15, 1, 73, 3, 82, 0,  2, 7,  4, 4, 32, 8, 15, 5, 16, 6, 46, 
    2,  7, 7, 84, 8, 39, 6, 66, 0, 72, 3, 31, 1, 53, 4,  5, 5, 56, 
    5, 67, 2, 86, 1, 47, 0, 78, 7, 11, 3, 67, 8, 11, 4,  2, 6, 70, 
    0,  8, 8, 12, 7, 92, 6, 27, 4, 87, 2, 97, 5, 96, 3, 20, 1,  1, 
    1, 79, 6, 10, 2, 60, 8, 22, 4,  9, 5, 26, 7, 75, 3, 54, 0, 30
  };
  const int q8885[] = {
    9, 9, // Number of jobs and machines
    3, 86, 6, 96, 2, 35, 0, 17, 4, 83, 8, 21, 5, 88, 1, 22, 7, 34, 
    8, 80, 4, 94, 0, 70, 5, 18, 7, 87, 6, 74, 1, 19, 2, 34, 3, 43, 
    4,  6, 6, 67, 7, 46, 1, 47, 5, 52, 2, 46, 3, 29, 0, 97, 8, 20, 
    0, 11, 6, 10, 3, 72, 7, 64, 1, 96, 8, 26, 2, 89, 4, 47, 5, 83, 
    2,  2, 7, 41, 5, 41, 1, 22, 0, 61, 3, 90, 4, 90, 8, 83, 6, 55, 
    6, 75, 7, 32, 4,  1, 1, 70, 2, 86, 5, 91, 3, 72, 8, 79, 0, 18, 
    3, 11, 5, 14, 2, 61, 6,  7, 0, 46, 4,  9, 1, 40, 8, 90, 7, 96, 
    4, 25, 1,  7, 6, 14, 8, 22, 0, 34, 2, 31, 7, 89, 3, 55, 5, 41, 
    3, 79, 4, 90, 6, 94, 2, 66, 8, 85, 5, 73, 1, 23, 7, 65, 0, 42
  };
  const int q8886[] = {
    9, 9, // Number of jobs and machines
    6, 69, 7, 10, 0, 61, 5, 15, 8, 14, 3, 81, 1,  6, 2, 76, 4, 28, 
    7, 47, 6, 74, 3, 49, 2, 15, 1, 73, 0, 39, 5, 74, 4, 10, 8, 33, 
    0, 29, 2, 71, 8, 67, 7, 80, 1, 85, 3, 67, 5, 43, 6, 76, 4, 56, 
    3, 20, 8, 41, 0, 72, 5, 11, 2, 14, 6, 64, 4, 56, 1, 29, 7, 53, 
    2, 11, 7, 34, 5, 69, 4, 77, 8, 60, 0, 48, 1, 56, 6, 21, 3, 74, 
    6, 62, 1, 23, 0, 86, 3,  7, 2, 66, 7,  5, 8, 81, 4, 44, 5, 27, 
    2, 95, 7, 60, 3, 77, 5, 83, 0, 91, 4, 90, 1, 49, 8, 86, 6, 68, 
    3,  5, 5, 77, 8, 52, 4, 93, 6, 83, 0, 72, 1, 66, 2, 84, 7, 69, 
    4, 10, 3, 79, 6, 87, 5, 68, 7, 63, 8, 58, 0, 58, 2, 50, 1, 18
  };
  const int q8887[] = {
    9, 9, // Number of jobs and machines
    8, 28, 4,  7, 7, 50, 6, 45, 1, 60, 0, 18, 2, 82, 5, 40, 3, 32, 
    1, 60, 2, 83, 7, 62, 8, 89, 3, 54, 5, 68, 4, 34, 0, 45, 6, 15, 
    5, 29, 0, 31, 1, 25, 4, 27, 3,  2, 2, 73, 6, 97, 8, 54, 7, 81, 
    5, 99, 2, 83, 4, 21, 7, 47, 1, 15, 0, 25, 8, 35, 6, 84, 3, 19, 
    3, 37, 0, 27, 8, 58, 1, 70, 4, 50, 7, 35, 5, 73, 2, 81, 6, 21, 
    2, 21, 6, 84, 3, 52, 7, 33, 0, 75, 1, 84, 5, 22, 8, 67, 4, 75, 
    0,  7, 1, 85, 5, 72, 3, 47, 8, 50, 7, 88, 6, 60, 2, 84, 4, 17, 
    3, 61, 6, 54, 2, 16, 4, 29, 8, 86, 5, 70, 7, 92, 1, 45, 0, 49, 
    5, 97, 4, 50, 7, 98, 6, 84, 0, 61, 3, 32, 8, 23, 2, 99, 1, 99
  };
  const int q8888[] = {
    9, 9, // Number of jobs and machines
    0, 44, 7, 84, 3, 84, 6,  6, 2, 13, 4, 77, 8, 23, 1, 51, 5, 61, 
    3, 71, 0, 36, 8, 28, 4, 18, 1, 24, 2, 70, 6, 96, 5, 74, 7, 91, 
    2, 38, 4, 40, 5, 54, 8,  6, 3, 68, 1, 50, 0, 29, 6,  1, 7, 47, 
    3, 58, 0, 49, 8, 83, 7, 37, 6, 14, 4, 49, 1, 65, 2, 33, 5, 67, 
    6, 31, 4,  1, 5, 49, 0, 61, 1, 85, 3, 94, 2, 93, 8, 71, 7, 79, 
    3, 99, 4, 64, 0, 38, 5, 28, 8, 60, 6, 67, 7,  1, 1, 39, 2, 55, 
    3, 21, 5, 38, 6, 68, 0, 36, 2, 90, 1, 80, 8, 94, 7, 34, 4, 27, 
    6,  1, 8, 15, 2, 45, 7, 33, 4, 13, 1, 77, 5, 59, 3, 19, 0, 57, 
    2,  7, 0,  7, 1, 83, 8, 92, 5, 33, 3, 55, 7, 50, 6, 61, 4, 94
  };
  const int q8889[] = {
    9, 9, // Number of jobs and machines
    6, 43, 5, 58, 4, 56, 0, 96, 2, 22, 8, 50, 7, 47, 1, 53, 3, 53, 
    1,  2, 4, 54, 5, 68, 2, 49, 6, 72, 7, 55, 0, 64, 8, 62, 3,  5, 
    4, 31, 7, 34, 1, 42, 2, 11, 0, 15, 3, 47, 8, 61, 6, 18, 5, 72, 
    6, 57, 3, 36, 2, 34, 5, 21, 1, 73, 4, 73, 0, 91, 8, 41, 7, 71, 
    4, 22, 0, 90, 8,  6, 5, 31, 3, 93, 2, 23, 6, 88, 7, 20, 1, 92, 
    4, 16, 0, 12, 5, 89, 6, 97, 7, 46, 8,  1, 2, 32, 1, 54, 3, 28, 
    1, 55, 6, 82, 0, 70, 7, 12, 2, 82, 5, 30, 8, 74, 4, 62, 3, 12, 
    2, 53, 6, 82, 8,  2, 7, 25, 5, 88, 3, 14, 4, 83, 0, 59, 1, 40, 
    6, 82, 1, 75, 4, 16, 5, 82, 0, 70, 8, 91, 7, 53, 2, 81, 3, 98
  };
  const int q8890[] = {
    9, 9, // Number of jobs and machines
    0, 90, 7,  9, 8, 47, 2, 23, 5, 11, 4, 46, 6, 22, 1, 58, 3, 26, 
    6,  7, 0, 41, 3, 66, 4, 60, 8, 57, 5, 30, 1, 62, 7, 49, 2, 10, 
    4, 37, 5, 11, 6, 34, 1, 68, 0, 28, 7, 77, 3, 85, 8, 56, 2, 57, 
    3, 20, 6, 87, 4, 18, 0, 51, 8, 50, 5, 82, 1, 64, 2, 29, 7, 91, 
    7, 13, 5, 55, 4, 38, 0,  4, 3, 10, 2, 86, 1, 31, 6, 21, 8,  5, 
    3, 96, 7, 71, 6, 55, 5, 75, 1, 23, 4, 83, 0, 18, 2, 26, 8, 34, 
    3, 39, 2, 74, 6, 95, 5, 17, 7, 63, 4, 72, 1,  2, 0, 49, 8, 29, 
    1, 74, 3, 64, 6, 25, 5, 16, 4, 21, 8, 58, 2, 11, 0, 16, 7, 70, 
    1,  8, 6, 30, 2, 17, 7, 53, 4, 97, 5, 14, 0, 22, 3, 91, 8, 41
  };
  const int q8891[] = {
    9, 9, // Number of jobs and machines
    4, 54, 5, 31, 3, 73, 8, 47, 6, 40, 1, 53, 0, 36, 2, 83, 7, 76, 
    7, 86, 4, 44, 2, 74, 1, 60, 5, 15, 6, 16, 3, 34, 0, 20, 8, 83, 
    4, 33, 6, 47, 2, 45, 3,  5, 1, 42, 0, 94, 7, 44, 5, 84, 8,  1, 
    4, 39, 2, 41, 1, 65, 5, 37, 6, 83, 7, 16, 8, 47, 0, 39, 3, 78, 
    6, 29, 3, 77, 2, 49, 8, 70, 1,  6, 7, 10, 0, 14, 4, 45, 5, 19, 
    6, 56, 1, 85, 8, 71, 3, 65, 7, 92, 0, 26, 5, 24, 4, 14, 2,  5, 
    5, 16, 8, 60, 2, 20, 4,  3, 7,  3, 1, 37, 0, 35, 3, 21, 6, 78, 
    8, 16, 7, 80, 0, 34, 1, 63, 6, 27, 3, 97, 4, 49, 5, 92, 2, 28, 
    0, 24, 6, 69, 2, 50, 5, 28, 7, 25, 4, 13, 3, 95, 8, 27, 1,  4
  };
  const int q8892[] = {
    9, 9, // Number of jobs and machines
    8, 33, 3, 80, 6, 63, 5,  5, 4, 17, 2, 73, 0, 73, 1, 89, 7, 59, 
    0,  4, 1, 21, 2, 94, 3, 68, 5, 63, 6, 93, 4,  6, 7, 86, 8, 21, 
    3, 23, 8, 10, 1, 76, 6, 69, 5, 27, 4, 12, 0, 29, 7, 37, 2, 24, 
    2, 20, 6, 69, 3, 49, 5, 13, 4, 98, 8, 90, 0, 42, 7, 42, 1, 43, 
    2,  3, 8, 10, 7, 48, 4, 40, 6, 70, 3, 36, 1,  5, 0, 53, 5, 76, 
    5, 35, 2, 13, 1, 69, 7, 53, 4, 62, 0, 86, 6, 66, 3, 70, 8, 33, 
    1, 59, 6, 29, 3, 69, 0,  9, 8, 96, 5, 95, 2, 25, 4, 67, 7, 52, 
    0, 12, 5, 13, 3, 77, 6, 65, 8, 86, 2,  9, 1, 94, 4, 19, 7, 91, 
    2, 39, 4, 59, 7,  8, 8,  4, 1, 63, 5,  9, 0, 54, 3, 64, 6, 12
  };
  const int q8893[] = {
    9, 9, // Number of jobs and machines
    5, 37, 1, 52, 3, 58, 0, 52, 7, 91, 6, 41, 2, 19, 4, 69, 8, 35, 
    6,  1, 5, 11, 4, 92, 1, 80, 8, 61, 0, 67, 2, 49, 3,  4, 7, 95, 
    7, 10, 3, 64, 5, 31, 8, 43, 1, 61, 2, 68, 6, 52, 4, 53, 0, 48, 
    5, 31, 8, 16, 6, 94, 1, 38, 2, 19, 7, 53, 3, 64, 0, 65, 4, 48, 
    1, 50, 5, 48, 0, 16, 2,  3, 3, 17, 7, 39, 8, 66, 4, 31, 6, 64, 
    2, 34, 3, 94, 7, 21, 5, 68, 0, 83, 6, 23, 1, 79, 8, 13, 4, 15, 
    5, 20, 3, 15, 6,  5, 2, 33, 1, 88, 0, 26, 7, 69, 8, 19, 4, 48, 
    7, 61, 4, 27, 8, 48, 0, 43, 6, 92, 2, 19, 3, 80, 5, 65, 1, 19, 
    1, 16, 3, 22, 4, 83, 5, 33, 8, 18, 7,  6, 2, 73, 0, 19, 6, 87
  };
  const int q8894[] = {
    9, 9, // Number of jobs and machines
    5, 81, 7, 90, 1, 11, 2, 49, 3, 59, 6, 93, 0, 37, 4, 32, 8, 40, 
    7, 77, 5, 44, 0, 64, 2, 75, 8, 22, 1, 53, 3,  5, 4, 51, 6, 61, 
    0, 94, 2, 35, 4, 81, 3, 88, 6, 73, 8, 76, 1,  5, 5, 22, 7, 36, 
    5, 54, 3, 29, 4, 11, 2, 45, 0, 48, 8, 87, 7, 75, 1, 69, 6, 91, 
    0, 53, 1, 31, 8, 86, 2, 23, 5, 16, 7, 76, 4, 43, 3, 72, 6, 36, 
    3, 73, 4, 19, 5, 11, 6, 46, 7, 21, 2,  8, 0, 77, 1, 62, 8, 47, 
    6, 12, 1, 37, 4, 17, 5, 66, 8, 44, 2, 78, 3, 50, 0, 43, 7, 19, 
    3, 23, 5, 28, 7, 64, 6, 36, 2, 40, 4, 42, 1, 41, 8,  3, 0,  1, 
    2, 16, 3, 66, 1, 54, 5, 38, 6, 97, 4, 81, 7, 21, 8,  6, 0, 46
  };
  const int q8895[] = {
    9, 9, // Number of jobs and machines
    8, 50, 2, 51, 0, 61, 1, 86, 4, 12, 3, 24, 7, 71, 5, 26, 6, 51, 
    3,  1, 0, 27, 1, 31, 7, 89, 6, 90, 8, 34, 2,  9, 4, 22, 5, 76, 
    8, 90, 2, 32, 5,  4, 0, 56, 3, 47, 6, 12, 4, 72, 1, 90, 7, 54, 
    2, 34, 7, 13, 4,  2, 1, 36, 5,  1, 3, 55, 6, 45, 0, 25, 8, 85, 
    5, 44, 6, 72, 3, 32, 0, 30, 8, 35, 1, 33, 7, 87, 2, 23, 4, 13, 
    4, 12, 8, 75, 5, 88, 0, 12, 2,  5, 7, 38, 6, 62, 1, 54, 3, 15, 
    0, 10, 4, 69, 5, 11, 3, 39, 7, 60, 6, 38, 2, 55, 8, 29, 1, 59, 
    8, 21, 4, 33, 1,  4, 3, 33, 2, 82, 7, 99, 5, 82, 0, 36, 6, 56, 
    1, 44, 2, 35, 8, 13, 6, 65, 0, 10, 7, 47, 3, 59, 5, 86, 4, 45
  };
  const int q8896[] = {
    9, 9, // Number of jobs and machines
    3, 65, 1, 50, 7, 75, 2, 32, 0, 87, 5, 83, 8, 62, 6, 40, 4, 54, 
    0, 75, 7, 81, 1, 24, 5, 89, 4, 42, 3, 37, 8, 57, 2, 79, 6, 67, 
    0, 48, 6,  4, 3, 95, 4, 59, 8, 19, 2, 51, 7, 76, 1, 61, 5,  9, 
    6, 91, 7, 20, 0, 66, 3, 10, 8, 50, 4, 30, 2, 20, 1, 16, 5, 23, 
    0, 90, 5, 79, 4, 79, 2,  4, 7, 94, 1, 92, 3, 36, 6, 30, 8, 75, 
    6, 78, 3, 82, 0, 97, 4, 15, 7, 12, 5,  2, 2, 13, 8, 12, 1,  2, 
    4, 14, 7, 88, 5, 45, 8, 48, 2, 47, 0,  6, 3, 42, 6, 68, 1, 84, 
    8, 48, 5, 90, 6, 88, 4, 32, 3, 13, 2, 85, 0, 43, 7, 15, 1, 51, 
    2, 28, 7, 56, 0, 27, 3, 74, 6, 31, 4, 30, 5, 99, 1, 65, 8, 58
  };
  const int q8897[] = {
    9, 9, // Number of jobs and machines
    6, 91, 8, 56, 7, 88, 4, 78, 1, 99, 0, 56, 2,  5, 3,  9, 5, 73, 
    2, 11, 5, 35, 4, 18, 8, 26, 1, 36, 6, 88, 0, 93, 3, 62, 7, 10, 
    0, 90, 3, 54, 6, 20, 8, 29, 2,  7, 1, 65, 4,  8, 5,  2, 7, 21, 
    3, 67, 5, 87, 4, 41, 8, 38, 7, 62, 6, 26, 0, 75, 2,  7, 1, 41, 
    6, 89, 0, 80, 3, 71, 4, 82, 8, 77, 1, 68, 7, 75, 2, 10, 5,  4, 
    7, 79, 5, 26, 1, 72, 4, 84, 2, 87, 0, 59, 8, 83, 3, 85, 6,  1, 
    2, 50, 5, 12, 6, 47, 0, 33, 3, 14, 8, 45, 1, 21, 7, 89, 4, 53, 
    6, 20, 8, 42, 3, 11, 1,  3, 4, 10, 7, 87, 5, 75, 0,  7, 2, 49, 
    0, 26, 2, 86, 6, 13, 7, 24, 8, 72, 4, 91, 5, 29, 1, 59, 3, 71
  };
  const int q8898[] = {
    9, 9, // Number of jobs and machines
    2, 40, 7, 52, 8, 60, 0, 48, 6, 98, 3, 61, 1, 53, 5, 21, 4, 74, 
    5, 78, 0,  8, 7, 80, 4, 79, 2, 75, 1, 76, 6, 92, 3, 62, 8, 80, 
    1, 78, 5,  8, 7, 99, 2,  3, 8, 60, 3, 58, 4, 85, 6, 46, 0, 90, 
    6,  8, 7, 89, 5, 17, 8, 93, 0, 73, 3, 48, 4,  7, 1, 39, 2, 27, 
    2, 45, 4, 51, 0, 44, 6, 74, 1, 61, 8, 79, 3, 14, 7, 85, 5, 61, 
    4,  9, 2, 58, 5, 40, 8, 97, 1, 20, 0, 18, 6, 88, 3, 81, 7, 64, 
    2, 96, 8, 32, 7, 79, 5, 65, 6, 91, 3, 79, 1, 62, 0, 78, 4, 15, 
    5,  1, 3, 15, 8, 68, 7, 80, 4, 89, 6, 68, 1, 46, 2, 98, 0, 11, 
    2,  4, 4, 56, 1, 34, 6, 35, 0, 41, 7, 56, 3, 90, 5, 74, 8, 27
  };
  const int q8899[] = {
    9, 9, // Number of jobs and machines
    5,  2, 1, 58, 7,  3, 4, 72, 0, 18, 8,  8, 3, 34, 2, 93, 6, 98, 
    4,  8, 5, 63, 6, 53, 1, 18, 8, 18, 0, 79, 3, 45, 7, 68, 2, 79, 
    0, 87, 4, 75, 8, 77, 1, 11, 7, 51, 5, 88, 3, 98, 6, 19, 2, 69, 
    3, 28, 4, 89, 2, 36, 5, 48, 1, 34, 8, 63, 0,  4, 7, 76, 6, 99, 
    2, 76, 4, 20, 7, 11, 6, 70, 1, 43, 0, 21, 5,  7, 3, 58, 8, 90, 
    2, 17, 1, 89, 3, 55, 7, 39, 5, 58, 6, 46, 0,  7, 8, 11, 4, 66, 
    1, 43, 4, 10, 3, 60, 7, 65, 6, 76, 2, 85, 0, 70, 5, 33, 8, 83, 
    1, 36, 4, 34, 0, 30, 6, 64, 5, 76, 7, 93, 8,  7, 2, 47, 3, 70, 
    0, 36, 3, 91, 7, 75, 5, 71, 1, 10, 8,  1, 4, 23, 2, 98, 6, 38
  };
  const int q8900[] = {
    9, 9, // Number of jobs and machines
    7, 91, 0, 13, 8, 72, 4, 55, 6, 10, 2, 83, 3, 95, 5, 44, 1, 93, 
    7, 45, 8, 68, 0, 99, 1,  4, 3, 59, 6, 63, 2, 58, 4, 12, 5,  7, 
    4,  1, 8, 57, 3, 58, 1, 41, 0, 25, 5, 81, 2, 57, 7, 96, 6, 77, 
    5, 95, 7, 65, 6, 17, 8, 85, 0, 73, 2, 65, 3, 67, 1, 36, 4, 51, 
    0, 44, 8, 94, 3, 12, 4, 53, 6, 84, 2, 97, 7, 93, 1, 37, 5, 27, 
    3, 96, 8, 73, 7, 48, 4, 16, 2, 31, 0, 33, 1, 46, 5, 32, 6, 80, 
    7, 70, 8, 57, 1, 96, 4, 18, 3, 61, 6, 78, 5, 91, 2,  6, 0, 16, 
    6, 62, 8, 15, 2,  3, 0, 39, 4, 93, 1, 62, 5, 26, 3, 90, 7, 50, 
    6, 14, 8, 49, 2, 24, 1, 65, 5, 51, 0, 80, 4, 95, 3, 19, 7, 62
  };
  const int q8901[] = {
    9, 9, // Number of jobs and machines
    7, 82, 6, 45, 1, 28, 3, 39, 2,  3, 8, 68, 0, 49, 4, 23, 5, 73, 
    2,  2, 5, 86, 4, 48, 8, 64, 1, 93, 6, 89, 3, 67, 7, 69, 0, 95, 
    1, 61, 7, 13, 2, 71, 8, 32, 6, 46, 5, 73, 4, 10, 3, 10, 0, 54, 
    8, 14, 7, 35, 1, 40, 4, 71, 0, 46, 2,  7, 3,  2, 5, 30, 6, 82, 
    0, 56, 1, 52, 7, 37, 6, 55, 8, 99, 4, 86, 5, 86, 2, 97, 3,  6, 
    6, 35, 2, 31, 0,  6, 8, 30, 5,  6, 7, 74, 1, 49, 4,  5, 3, 27, 
    7, 76, 3, 24, 6, 56, 2, 25, 1, 99, 8, 50, 4, 63, 5, 37, 0, 70, 
    3, 78, 7, 78, 6,  8, 4, 49, 1, 37, 5, 95, 0, 14, 2, 91, 8, 17, 
    6, 56, 1, 53, 2, 54, 4, 13, 0, 68, 3, 57, 5, 11, 8, 82, 7, 46
  };
  const int q8902[] = {
    9, 9, // Number of jobs and machines
    7, 96, 1, 45, 2, 47, 3, 19, 5, 11, 4, 55, 6, 55, 0, 97, 8, 55, 
    4, 83, 5, 72, 6,  2, 0,  4, 7, 21, 3, 53, 8, 37, 1,  7, 2,  6, 
    6, 35, 5, 57, 7, 11, 2, 56, 0, 28, 4, 82, 1, 79, 8, 54, 3, 80, 
    2, 54, 6, 99, 1, 34, 7, 96, 0, 76, 8, 95, 3, 55, 4, 70, 5, 81, 
    1, 45, 3,  1, 7, 77, 4, 29, 8,  1, 5, 67, 0, 71, 2,  1, 6, 76, 
    2, 68, 1, 65, 4, 75, 7, 40, 6, 94, 5, 99, 8, 85, 3,  2, 0, 94, 
    7,  2, 0,  5, 8, 65, 4,  8, 6, 99, 5, 37, 1, 98, 3, 56, 2, 59, 
    3, 96, 2, 50, 6,  4, 4, 36, 5, 22, 7, 97, 0, 17, 1, 51, 8,  6, 
    8, 99, 5, 32, 3, 42, 2, 40, 4, 84, 0, 77, 7, 85, 1, 44, 6, 70
  };
  const int q8903[] = {
    9, 9, // Number of jobs and machines
    8, 30, 6,  9, 0, 60, 1, 14, 7,  1, 5, 95, 2, 51, 4, 17, 3, 40, 
    6, 80, 7, 97, 2, 51, 3, 66, 8, 99, 5, 13, 0,  7, 4,  1, 1, 90, 
    3, 55, 6, 51, 0, 25, 4, 75, 2, 10, 5, 11, 8, 76, 7, 14, 1, 16, 
    7, 61, 6, 52, 0, 77, 3,  9, 4, 47, 1, 40, 8, 19, 2, 90, 5, 91, 
    0, 97, 4, 27, 1, 54, 2, 58, 6, 49, 7, 69, 5, 54, 8, 79, 3, 38, 
    2, 19, 3, 58, 0, 56, 5, 96, 8, 22, 1, 65, 6, 39, 4, 52, 7, 73, 
    6, 96, 4, 34, 1,  5, 2, 66, 3, 26, 0, 91, 8, 75, 7, 76, 5, 59, 
    6, 71, 8, 94, 4, 96, 1, 24, 5, 59, 2, 17, 3, 77, 7, 88, 0, 84, 
    5, 47, 3, 38, 4, 58, 1, 50, 2, 51, 0, 16, 6, 65, 8, 36, 7, 67
  };
  const int q8904[] = {
    9, 9, // Number of jobs and machines
    7,  6, 2, 55, 8, 36, 3, 42, 4, 65, 1, 11, 0, 24, 6, 77, 5, 11, 
    5,  2, 2, 77, 1, 27, 6, 80, 0, 47, 8, 21, 7, 61, 4, 28, 3, 60, 
    8,  5, 3, 12, 0, 87, 1, 23, 6, 88, 4, 14, 2, 94, 5, 86, 7, 80, 
    8, 82, 7, 71, 5,  4, 4, 90, 1, 95, 2,  3, 3, 86, 6, 96, 0, 46, 
    6, 88, 4, 88, 7, 17, 5, 46, 2, 59, 8, 73, 1, 50, 3, 74, 0,  5, 
    6, 20, 4,  1, 5, 89, 0, 11, 7, 52, 3, 76, 1, 52, 2, 50, 8, 22, 
    0, 38, 4,  8, 8, 90, 7, 41, 5, 50, 1, 25, 2, 20, 6, 16, 3, 41, 
    3, 44, 4, 69, 1, 12, 8, 48, 2, 52, 5, 96, 6, 44, 7, 45, 0, 88, 
    6, 15, 4, 12, 5, 56, 3, 52, 8,  7, 1, 92, 0, 50, 2, 18, 7, 46
  };
  const int q8905[] = {
    9, 9, // Number of jobs and machines
    5, 40, 4,  2, 8, 95, 3, 35, 7, 10, 0, 97, 1, 87, 6, 23, 2, 55, 
    1, 26, 2, 68, 4,  8, 5, 21, 3, 17, 7, 49, 6, 76, 0, 10, 8, 46, 
    2, 78, 5,  5, 7, 72, 3, 85, 6, 38, 4, 92, 8, 34, 0,  9, 1,  4, 
    2, 69, 3, 72, 1, 81, 4, 68, 5, 81, 6, 90, 8, 31, 0, 47, 7, 28, 
    4, 18, 0, 59, 6, 25, 3, 86, 2, 71, 8, 12, 1, 95, 5, 65, 7, 22, 
    6, 51, 8, 68, 5, 10, 3, 99, 7, 42, 1, 66, 2, 34, 4, 89, 0, 10, 
    7, 75, 4, 56, 1, 94, 2, 95, 5, 47, 8, 29, 0, 14, 3, 87, 6, 64, 
    7, 97, 4,  5, 0, 91, 3, 62, 2, 63, 1, 13, 8, 90, 5, 27, 6, 48, 
    6, 26, 1, 59, 2, 19, 8, 15, 7,  1, 5, 43, 4, 28, 3, 78, 0, 91
  };
  const int q8906[] = {
    9, 9, // Number of jobs and machines
    5, 64, 4, 54, 6, 20, 3, 12, 2, 74, 1, 97, 8, 87, 0, 62, 7, 23, 
    7, 51, 1, 77, 3, 46, 6, 67, 0, 44, 4, 64, 8, 45, 5, 49, 2, 31, 
    3, 38, 2, 29, 4, 49, 8, 75, 7, 14, 0, 90, 1, 50, 6, 29, 5, 73, 
    3, 79, 1, 18, 7, 15, 5,  7, 2, 69, 4, 90, 6, 47, 8, 88, 0, 66, 
    4, 34, 1, 12, 6, 24, 8, 48, 5, 23, 3, 67, 7, 33, 0, 77, 2, 38, 
    2, 75, 0, 55, 3, 23, 8, 86, 4, 26, 6, 19, 5, 78, 1, 96, 7, 34, 
    8, 49, 6, 15, 4,  3, 7, 40, 0, 32, 1, 40, 5, 95, 2, 70, 3, 43, 
    3, 99, 6, 31, 8, 25, 0, 90, 7, 77, 5, 29, 1, 23, 2, 95, 4, 99, 
    1, 95, 8, 42, 5, 93, 0, 99, 7, 53, 3, 41, 2, 27, 6, 27, 4, 70
  };
  const int q8907[] = {
    9, 9, // Number of jobs and machines
    6, 94, 2, 94, 7, 68, 0, 18, 5, 48, 3, 16, 8, 96, 4, 61, 1, 79, 
    2, 68, 6,  1, 1, 24, 5, 91, 0, 74, 8, 15, 7, 99, 4, 97, 3, 30, 
    4, 71, 0, 15, 1, 91, 6, 38, 2, 20, 3, 33, 8, 77, 5, 72, 7, 78, 
    5, 37, 4, 35, 1, 46, 2, 63, 0, 37, 8, 48, 3, 21, 6, 24, 7, 65, 
    1, 99, 4, 16, 8, 85, 7, 66, 2, 15, 3, 11, 0, 34, 5, 38, 6, 23, 
    6, 11, 4, 48, 5, 91, 7, 18, 2, 36, 8, 79, 3, 26, 1, 37, 0, 27, 
    3, 68, 1, 80, 7, 60, 8, 72, 2, 73, 6, 24, 5, 52, 0, 35, 4, 37, 
    5, 20, 4, 62, 6, 42, 7,  1, 0, 17, 8, 41, 3, 21, 1, 49, 2, 53, 
    7, 69, 1, 81, 0, 89, 5,  8, 4, 97, 3,  3, 8, 17, 2, 59, 6, 10
  };
  const int q8908[] = {
    9, 9, // Number of jobs and machines
    8, 59, 5, 12, 7,  9, 3, 85, 0, 68, 4, 16, 1, 29, 2, 64, 6, 39, 
    6, 37, 3, 78, 4, 56, 2, 58, 5, 48, 7, 80, 8, 34, 0, 71, 1, 82, 
    6, 17, 3, 89, 5, 67, 4, 24, 7, 16, 1,  9, 2, 68, 0, 97, 8, 22, 
    4, 31, 6, 70, 5, 25, 2, 52, 1, 39, 0, 48, 3, 51, 8, 21, 7, 97, 
    0, 33, 8, 36, 1, 62, 2, 28, 5, 39, 6, 48, 4,  7, 7, 88, 3, 84, 
    7, 32, 2, 78, 3, 87, 5, 18, 1, 39, 8, 99, 0, 15, 6, 70, 4, 11, 
    1, 22, 4, 52, 8, 72, 3, 94, 7, 22, 5,  3, 6, 96, 0, 88, 2, 67, 
    7, 92, 5,  4, 6, 17, 8, 97, 3, 78, 0, 30, 4, 37, 2, 87, 1, 46, 
    7, 89, 0, 36, 4, 72, 3,  4, 2, 31, 8, 51, 5, 47, 6, 79, 1, 77
  };
  const int q8909[] = {
    9, 9, // Number of jobs and machines
    4, 13, 2, 82, 3, 24, 1, 10, 7, 58, 5, 19, 6, 84, 0, 71, 8, 83, 
    1, 78, 4, 80, 7, 43, 8, 70, 5, 19, 3,  2, 6, 36, 0, 16, 2, 76, 
    6, 36, 3, 12, 7, 76, 2, 17, 4, 76, 5, 33, 0, 90, 1, 22, 8, 81, 
    0, 49, 2, 17, 4, 27, 7, 36, 8, 81, 6, 58, 5, 13, 1, 52, 3, 81, 
    6, 57, 1, 60, 7, 59, 0, 40, 2, 18, 8, 76, 3, 66, 4, 11, 5, 58, 
    4, 68, 1, 41, 0, 68, 7, 83, 8,  8, 3, 57, 6, 37, 2, 45, 5, 64, 
    3, 29, 6, 48, 8, 57, 2,  5, 0, 40, 7, 66, 4,  1, 1, 69, 5, 85, 
    2, 68, 8, 95, 7, 10, 3,  4, 0, 68, 6, 12, 5, 28, 1, 13, 4, 99, 
    3, 63, 4, 86, 7, 30, 1, 35, 2,  4, 6, 71, 8, 95, 5, 15, 0, 61
  };
  const int q8910[] = {
    9, 9, // Number of jobs and machines
    5, 96, 7, 15, 4, 73, 6,  7, 0, 45, 3, 79, 8, 55, 1, 48, 2, 81, 
    7, 68, 1, 57, 3, 30, 4, 38, 0, 78, 2, 54, 5, 73, 6, 45, 8, 82, 
    5, 70, 7, 92, 2, 57, 3, 34, 8, 70, 0, 63, 6, 33, 1, 63, 4, 94, 
    4,  9, 6, 84, 0, 92, 2, 47, 8, 29, 1, 51, 7,  7, 3, 21, 5,  1, 
    8, 30, 0, 57, 7,  9, 4, 61, 5, 37, 6, 65, 2, 79, 3, 58, 1, 12, 
    7, 43, 4, 31, 3,  4, 6, 34, 8, 31, 2, 65, 1,  3, 0,  3, 5, 12, 
    1,  3, 2, 89, 8, 30, 5, 14, 6, 47, 4, 31, 0, 93, 3, 82, 7, 74, 
    6, 22, 4, 31, 5, 35, 2, 63, 1, 39, 0, 34, 8, 21, 7, 82, 3, 89, 
    6, 50, 5, 53, 2, 24, 1, 74, 8,  9, 0,  7, 3, 71, 4, 60, 7, 25
  };
  const int q8911[] = {
    9, 9, // Number of jobs and machines
    4, 66, 7, 14, 3, 33, 1, 75, 0, 67, 2, 51, 6,  4, 5, 34, 8,  4, 
    5, 36, 0, 47, 6, 73, 8, 87, 7, 17, 3, 33, 4, 85, 2, 79, 1, 14, 
    3, 26, 5, 18, 0, 20, 2, 87, 4, 54, 7, 13, 8, 60, 6, 31, 1, 76, 
    4, 71, 8,  6, 2, 27, 7, 41, 3, 94, 0, 73, 5, 60, 1,  2, 6, 36, 
    5, 32, 0, 41, 8, 20, 4, 91, 6, 27, 2, 25, 7,  8, 1, 78, 3, 60, 
    4, 89, 6, 73, 8, 34, 7, 82, 5, 69, 0, 76, 1, 51, 3, 96, 2, 12, 
    4, 76, 0, 51, 6,  6, 7, 82, 5, 37, 8, 86, 1, 90, 3, 60, 2, 70, 
    2,  8, 8, 76, 0, 61, 7, 90, 4, 20, 5, 86, 3, 83, 1, 73, 6, 31, 
    5, 17, 2, 23, 3, 81, 7, 29, 1,  1, 6, 38, 0, 23, 4, 24, 8, 51
  };
  const int q8912[] = {
    9, 9, // Number of jobs and machines
    1, 76, 0, 63, 3, 38, 8, 95, 4, 45, 6, 62, 2, 27, 7, 14, 5, 63, 
    7, 69, 1, 55, 2,  1, 8, 16, 0, 27, 5, 87, 4, 20, 3, 48, 6,  7, 
    8, 38, 7, 78, 2, 68, 4,  5, 0, 77, 1, 74, 6, 63, 5, 63, 3, 56, 
    0, 34, 4, 43, 5, 23, 6, 24, 7, 22, 2, 43, 8, 99, 3, 78, 1, 26, 
    5, 44, 0, 19, 8, 20, 4, 32, 1, 49, 6, 91, 2, 47, 7, 41, 3, 67, 
    7, 50, 8, 49, 2, 28, 5, 91, 0,  3, 6, 76, 1,  1, 4, 25, 3, 11, 
    4, 48, 2, 86, 8, 54, 3, 58, 5, 82, 6, 17, 1, 56, 7, 65, 0, 50, 
    6, 21, 2, 13, 7, 53, 5, 29, 4, 26, 8, 70, 0, 78, 1, 60, 3, 17, 
    3, 17, 5, 61, 2, 44, 7, 82, 1, 99, 0, 22, 6, 29, 4, 90, 8, 78
  };
  const int q8913[] = {
    9, 9, // Number of jobs and machines
    7, 74, 8, 77, 6, 58, 0, 70, 4, 45, 2, 90, 5, 18, 1, 82, 3, 61, 
    4,  8, 0, 50, 2, 65, 3, 72, 7, 42, 5, 58, 6, 48, 8, 30, 1, 14, 
    2, 22, 3, 31, 1,  7, 0, 95, 8, 57, 6, 86, 7, 70, 4, 61, 5, 16, 
    3, 80, 4, 94, 2, 15, 6, 71, 0, 31, 8, 23, 1, 80, 5, 70, 7, 28, 
    2, 38, 5, 73, 7, 34, 4, 32, 3, 61, 6,  6, 8, 82, 0, 49, 1,  8, 
    8, 15, 5, 59, 6, 33, 7, 25, 2, 54, 4, 38, 0, 48, 3, 36, 1, 51, 
    2,  4, 7, 16, 3, 34, 1, 14, 4, 48, 0, 83, 6, 40, 8,  3, 5, 51, 
    3, 51, 1, 41, 7, 14, 2, 53, 8, 41, 6, 26, 0, 39, 5, 91, 4, 38, 
    8, 97, 7, 32, 2, 56, 3, 78, 1, 67, 4, 99, 6,  9, 5, 54, 0, 31
  };
  const int q8914[] = {
    9, 9, // Number of jobs and machines
    0, 75, 7, 30, 4, 84, 3, 92, 5, 68, 1, 40, 6, 23, 8, 80, 2, 36, 
    1, 83, 7, 93, 2, 46, 4, 14, 6, 96, 5, 63, 0, 91, 3, 37, 8, 89, 
    0, 48, 5,  6, 1, 97, 8, 44, 2, 88, 7, 65, 3, 92, 4, 55, 6, 25, 
    2, 64, 6, 48, 0, 60, 4, 86, 1, 28, 8, 64, 7, 49, 5, 81, 3, 64, 
    3, 72, 7, 80, 4, 76, 1, 92, 8, 80, 5, 94, 6, 96, 0, 29, 2, 64, 
    8, 78, 6, 99, 4, 82, 2,  9, 0, 21, 7, 39, 1,  2, 3, 23, 5,  4, 
    3, 94, 4, 76, 1, 18, 2, 20, 5, 58, 8,  8, 6,  3, 7, 60, 0, 70, 
    6,  8, 4, 13, 0, 56, 2, 58, 8, 28, 3, 62, 7, 51, 1, 66, 5,  9, 
    6, 36, 2, 88, 7, 24, 3, 97, 0, 45, 1, 41, 5, 48, 4, 81, 8, 82
  };
  const int q8915[] = {
    9, 9, // Number of jobs and machines
    4, 38, 7, 26, 6, 99, 0, 39, 5, 17, 8, 29, 3, 74, 2,  2, 1,  5, 
    5, 82, 8, 64, 4,  7, 6, 97, 2, 29, 3, 26, 0, 33, 1, 79, 7, 57, 
    4, 77, 8, 86, 2, 10, 3, 75, 7, 26, 5, 97, 6, 92, 1, 94, 0, 20, 
    0, 95, 6, 52, 5, 85, 3, 79, 8, 62, 2, 55, 7, 53, 4, 31, 1,  7, 
    4, 36, 6, 59, 3, 25, 7, 92, 1, 52, 8, 99, 2, 13, 5, 19, 0, 44, 
    6, 56, 7, 65, 8,  5, 5, 14, 1, 90, 3, 16, 2, 61, 0, 35, 4,  3, 
    4, 79, 3, 52, 7, 48, 5, 64, 6, 31, 2, 89, 8, 93, 0, 76, 1, 91, 
    6, 24, 0,  2, 7, 93, 1,  7, 5, 37, 4, 28, 2, 58, 3, 31, 8, 60, 
    5, 18, 2, 92, 6, 69, 7, 55, 0, 63, 4, 39, 1,  6, 3, 97, 8, 67
  };
  const int q8916[] = {
    9, 9, // Number of jobs and machines
    0, 47, 7, 15, 2, 47, 6, 34, 4, 95, 5, 77, 3, 25, 1, 90, 8, 30, 
    6, 45, 4, 42, 5, 95, 3, 68, 0, 66, 8, 40, 1, 89, 7, 99, 2, 23, 
    8, 63, 7, 22, 0, 72, 6, 87, 2, 98, 1, 89, 5, 52, 3, 73, 4, 16, 
    6, 85, 8, 98, 3, 48, 4, 95, 1, 34, 5, 78, 2, 22, 0, 64, 7,  6, 
    3, 60, 1, 53, 8, 52, 2, 38, 5, 45, 0, 85, 7, 85, 4, 35, 6, 71, 
    8, 87, 3, 12, 7, 28, 6, 10, 4, 99, 5, 24, 1, 51, 0, 73, 2, 78, 
    6, 30, 0, 32, 7, 20, 3, 16, 8, 79, 2, 82, 1, 72, 5, 33, 4, 30, 
    7, 68, 5, 95, 3, 15, 0, 71, 2, 35, 8,  4, 6, 80, 4, 95, 1, 48, 
    4, 34, 6, 29, 5, 61, 2, 82, 7, 51, 1, 17, 8, 17, 3, 10, 0, 11
  };
  const int q8917[] = {
    9, 9, // Number of jobs and machines
    6, 50, 3, 62, 4, 94, 1, 98, 8, 29, 2, 68, 5, 80, 7, 18, 0, 11, 
    6, 56, 7, 87, 2, 42, 1, 43, 0, 14, 8, 36, 4, 43, 5, 52, 3, 42, 
    5, 70, 7, 18, 0, 15, 1, 49, 2, 70, 3,  9, 4,  7, 6,  5, 8, 66, 
    3, 98, 1, 45, 8,  9, 4, 56, 7, 31, 2, 29, 6, 32, 0, 89, 5, 94, 
    1, 74, 2, 46, 4, 96, 3,  9, 7,  6, 5, 54, 8, 86, 6, 99, 0, 31, 
    1,  5, 4, 17, 2, 75, 0, 90, 5, 45, 7, 81, 8, 67, 6, 19, 3, 57, 
    6, 46, 4, 27, 8, 14, 1, 77, 0, 88, 5, 18, 7, 16, 2, 30, 3, 45, 
    3, 84, 0, 17, 5, 44, 2, 94, 8, 40, 7, 68, 1, 33, 6,  7, 4, 97, 
    1, 21, 7, 37, 0,  6, 5, 45, 4, 69, 6, 76, 3,  1, 8, 93, 2, 73
  };
  const int q8918[] = {
    9, 9, // Number of jobs and machines
    6, 73, 4, 32, 0, 85, 3, 93, 7, 64, 2, 41, 1, 72, 8, 75, 5, 67, 
    1, 64, 4, 38, 5, 33, 7, 21, 6, 27, 3, 22, 8, 14, 0, 37, 2, 47, 
    3, 34, 4, 61, 0, 30, 8, 85, 7, 47, 1, 57, 5, 52, 2, 52, 6, 96, 
    7, 43, 4, 69, 5, 62, 6, 43, 3,  1, 0, 92, 2, 21, 1, 69, 8, 71, 
    2, 45, 1, 49, 5, 48, 8, 43, 3, 49, 7, 66, 4, 33, 0,  4, 6, 22, 
    4, 80, 1, 66, 8, 29, 7,  8, 2, 82, 3, 56, 5, 17, 6, 62, 0, 82, 
    4, 10, 1, 51, 0, 51, 3, 34, 8, 45, 2,  8, 7, 53, 6,  2, 5, 56, 
    2, 11, 0, 11, 4, 32, 1,  7, 8, 73, 7, 20, 5, 77, 3, 47, 6, 51, 
    4, 74, 1,  6, 5, 92, 6, 41, 3, 19, 0, 18, 7, 36, 8, 16, 2, 23
  };
  const int q8919[] = {
    9, 9, // Number of jobs and machines
    2, 16, 3, 15, 5, 71, 7, 87, 1,  4, 0, 50, 6, 24, 4,  8, 8, 31, 
    7, 50, 4, 19, 5, 41, 8, 64, 1, 71, 2, 43, 3, 64, 0, 69, 6, 15, 
    6, 74, 2, 84, 7,  2, 5,  5, 1, 31, 0, 71, 3, 99, 4, 76, 8, 63, 
    4,  2, 0, 20, 1, 28, 2, 69, 7, 56, 8, 65, 6, 59, 5, 45, 3,  2, 
    3, 45, 4, 41, 8, 68, 2, 66, 7, 43, 0,  2, 1,  4, 5, 16, 6, 51, 
    8, 74, 2, 41, 0, 19, 3, 67, 6, 82, 1, 81, 4, 28, 7, 83, 5,  6, 
    7, 28, 6, 92, 8,  9, 4, 23, 2, 97, 3, 74, 5, 58, 1, 17, 0, 68, 
    1,  3, 0, 91, 3, 36, 5, 93, 6, 41, 4, 39, 7, 22, 2, 37, 8, 89, 
    2, 72, 0, 30, 8, 76, 5, 51, 1, 38, 6, 62, 7, 93, 3,  4, 4, 97
  };
  const int q8920[] = {
    9, 9, // Number of jobs and machines
    5, 26, 0, 47, 1, 55, 8, 90, 2, 97, 6, 31, 7, 74, 4, 70, 3, 15, 
    6, 44, 4, 69, 5, 58, 8, 98, 7, 29, 2, 47, 3, 98, 1, 80, 0, 16, 
    6, 85, 3, 32, 5, 54, 7, 35, 8, 48, 1, 96, 4, 64, 0, 13, 2, 96, 
    2, 20, 5, 81, 3, 31, 0, 55, 4,  4, 8,  4, 7, 99, 6,  9, 1, 92, 
    3, 53, 6, 29, 7, 66, 0, 22, 2, 47, 4, 98, 1,  8, 8, 78, 5, 15, 
    1, 44, 7, 79, 6, 24, 5, 88, 4, 76, 3, 70, 2, 33, 8, 59, 0, 82, 
    5, 52, 7,  3, 4, 94, 8, 14, 0, 76, 6, 46, 3,  4, 2, 97, 1, 98, 
    6, 25, 4, 53, 5,  1, 7, 49, 0, 39, 2,  2, 1, 21, 3, 38, 8, 55, 
    0, 91, 3, 14, 7, 55, 4, 91, 5, 65, 6, 39, 2, 29, 8, 32, 1, 61
  };
  const int q8921[] = {
    9, 9, // Number of jobs and machines
    0, 90, 2, 34, 7, 75, 6,  6, 4, 92, 8, 95, 3, 69, 5, 36, 1, 52, 
    5,  4, 2, 80, 8, 71, 7, 41, 4, 31, 0, 70, 1, 20, 6, 45, 3, 51, 
    1, 87, 2, 40, 4, 87, 6, 74, 3, 54, 0, 78, 8, 83, 5, 27, 7, 38, 
    8, 37, 5, 51, 3,  5, 6, 70, 4, 96, 7, 23, 0, 53, 1, 61, 2, 48, 
    5, 96, 0, 68, 4, 38, 8, 67, 3, 48, 1, 50, 2, 26, 6, 26, 7, 95, 
    6, 14, 4, 96, 8, 51, 1, 31, 0, 96, 7, 79, 5, 89, 3, 44, 2, 85, 
    5, 47, 8, 73, 3, 66, 6, 77, 4, 49, 7, 51, 0, 96, 1, 69, 2,  1, 
    2, 64, 6, 87, 8, 26, 0, 57, 4, 22, 3,  1, 5, 39, 1,  3, 7,  2, 
    8, 57, 2,  2, 6, 59, 1, 84, 5, 71, 7, 22, 3, 72, 4, 92, 0, 21
  };
  const int q8922[] = {
    9, 9, // Number of jobs and machines
    5, 84, 1, 97, 3, 68, 6, 82, 2, 37, 4, 73, 8, 49, 7, 48, 0, 20, 
    6, 97, 2,  4, 0, 42, 7, 25, 8, 64, 3, 89, 4,  5, 1, 80, 5, 71, 
    4, 55, 6, 79, 2, 71, 0, 22, 7, 54, 8, 59, 3, 52, 1,  1, 5, 24, 
    1, 90, 7, 76, 2, 75, 8, 64, 5, 49, 3, 21, 4, 67, 0, 45, 6, 37, 
    8, 68, 1, 11, 4, 67, 5, 11, 7, 32, 2, 95, 0, 59, 6, 32, 3, 57, 
    4, 87, 0, 41, 6, 11, 1, 96, 3, 66, 2,  1, 8,  2, 5,  8, 7, 10, 
    7, 62, 1, 75, 4, 13, 6, 38, 2, 35, 5, 92, 8, 29, 3, 65, 0, 80, 
    7, 42, 8, 72, 3, 22, 6, 91, 2,  7, 4, 13, 5, 33, 0, 39, 1, 82, 
    1, 18, 7, 57, 5, 81, 3, 95, 2, 88, 4,  9, 6, 66, 0, 67, 8, 91
  };
  const int q8923[] = {
    9, 9, // Number of jobs and machines
    5, 22, 2, 57, 3, 81, 7, 42, 4, 67, 1, 50, 0, 19, 8, 61, 6,  3, 
    4, 20, 5, 66, 7, 65, 2, 93, 3, 23, 0, 44, 1, 31, 8, 34, 6,  5, 
    8, 29, 0, 80, 7, 65, 5, 23, 2, 34, 4, 59, 6, 91, 1, 23, 3, 61, 
    4, 37, 3, 88, 7, 17, 2, 73, 1, 31, 5, 97, 0, 45, 8, 98, 6, 66, 
    4, 85, 8, 28, 7, 71, 0,  9, 2, 23, 6, 17, 5, 24, 3, 58, 1, 41, 
    2, 66, 4, 74, 3, 47, 6, 15, 7, 74, 0, 37, 5, 67, 8, 93, 1, 19, 
    7, 81, 5, 88, 2, 50, 4, 66, 8, 98, 3, 36, 6, 60, 1, 83, 0, 43, 
    8, 20, 2, 89, 6, 71, 5, 61, 3, 55, 4, 55, 1, 52, 7, 36, 0, 47, 
    5,  8, 8, 48, 0, 49, 3, 61, 2, 46, 7, 61, 4, 23, 6, 67, 1, 72
  };
  const int q8924[] = {
    9, 9, // Number of jobs and machines
    2, 28, 3, 41, 8, 48, 5, 78, 0, 52, 7, 31, 6, 57, 1, 83, 4, 62, 
    7, 56, 4, 70, 0, 29, 3, 50, 8, 48, 1, 85, 6,  4, 5, 62, 2, 28, 
    8, 94, 1, 11, 2, 96, 6, 18, 5, 78, 4,  5, 7, 31, 3, 98, 0, 41, 
    6, 30, 7, 61, 2, 85, 4, 30, 5, 39, 8, 66, 3, 93, 1, 71, 0, 27, 
    3, 51, 8, 22, 1, 98, 2, 71, 6, 69, 4, 78, 5,  2, 7, 74, 0, 79, 
    4, 71, 0, 69, 8, 25, 1, 49, 2, 59, 6, 62, 5, 94, 7, 43, 3, 66, 
    8, 40, 1, 12, 5, 55, 3, 67, 2, 14, 6, 65, 0, 92, 4, 62, 7, 67, 
    2, 75, 3, 57, 8, 53, 5,  1, 7, 29, 1, 14, 0, 99, 6, 95, 4, 93, 
    0, 41, 1, 63, 4, 76, 5, 96, 6, 60, 3, 10, 8, 77, 7, 19, 2, 92
  };
  const int q8925[] = {
    9, 9, // Number of jobs and machines
    0, 78, 3, 24, 8, 21, 6, 78, 1, 62, 7,  2, 2, 21, 4, 14, 5,  4, 
    1, 52, 6,  9, 3, 40, 0, 96, 5, 65, 2,  5, 7, 36, 4, 39, 8, 13, 
    7, 79, 5, 30, 2, 20, 0, 35, 3, 93, 1, 38, 6, 11, 4, 73, 8, 18, 
    1, 18, 8, 26, 3, 16, 2, 58, 4, 64, 0, 25, 6, 68, 5, 56, 7, 54, 
    8, 62, 1, 58, 5, 78, 0, 86, 4,  7, 2, 67, 3, 83, 6, 96, 7, 30, 
    1, 72, 4, 56, 3, 56, 0, 67, 7, 53, 6, 43, 8,  4, 5, 26, 2, 38, 
    5, 75, 7, 55, 4, 66, 8, 12, 1, 67, 3, 80, 6, 44, 2, 82, 0, 32, 
    5, 86, 7, 42, 4, 37, 0, 32, 6, 27, 3, 93, 8,  8, 2, 45, 1, 58, 
    1, 82, 0, 27, 6, 95, 3, 15, 4, 20, 8, 51, 2, 53, 7, 50, 5, 92
  };
  const int q8926[] = {
    9, 9, // Number of jobs and machines
    5, 38, 4, 97, 0, 22, 6, 42, 1, 31, 8, 43, 3,  1, 2, 86, 7, 97, 
    2, 84, 8, 82, 4, 38, 1, 92, 6, 30, 7, 97, 3, 80, 5, 61, 0, 22, 
    4, 35, 5, 18, 7, 89, 1, 68, 3, 54, 2, 19, 0, 99, 6, 52, 8, 50, 
    3, 18, 2, 79, 4, 74, 7, 64, 6, 10, 5,  5, 8, 29, 1, 87, 0, 71, 
    5, 38, 2, 46, 1, 50, 4, 12, 3, 35, 6,  1, 8, 58, 0, 53, 7, 37, 
    7, 13, 6, 26, 2, 94, 1, 40, 3, 36, 5, 55, 0, 22, 8, 74, 4, 35, 
    8, 32, 7, 29, 5, 62, 2, 89, 6, 89, 0, 92, 1, 50, 3, 87, 4, 71, 
    2, 36, 4,  3, 6, 54, 7, 59, 0, 82, 3, 36, 8, 16, 5, 38, 1, 18, 
    6,  1, 0, 32, 8, 17, 1, 80, 4, 62, 7, 17, 5, 90, 3, 86, 2, 91
  };
  const int q8927[] = {
    9, 9, // Number of jobs and machines
    6, 86, 0, 68, 5,  2, 8, 57, 7, 69, 2, 12, 4, 81, 3,  9, 1, 50, 
    4, 97, 8, 29, 3,  2, 2, 67, 1, 53, 7, 61, 6, 28, 5, 18, 0, 13, 
    7,  4, 6, 97, 2,  3, 4,  5, 1, 70, 8, 55, 3,  5, 0,  6, 5, 58, 
    5, 19, 7, 29, 1, 47, 6, 61, 8,  4, 3, 38, 2, 26, 4, 40, 0,  4, 
    7, 43, 6, 48, 2, 58, 0,  9, 4, 12, 3, 17, 8, 10, 5, 71, 1, 31, 
    0,  4, 8, 67, 5, 67, 7, 77, 3, 95, 4, 75, 2, 99, 6,  4, 1, 22, 
    6, 98, 2, 19, 7, 70, 0, 89, 1, 89, 5, 96, 8,  5, 4,  3, 3,  2, 
    8, 47, 4,  1, 7, 63, 6, 50, 0, 15, 5, 21, 2, 46, 3, 70, 1, 58, 
    1, 38, 6,  1, 7,  9, 8,  8, 0, 69, 2, 55, 5, 89, 3, 64, 4, 72
  };
  const int q8928[] = {
    9, 9, // Number of jobs and machines
    8, 42, 6, 14, 1, 37, 0, 61, 2, 20, 5, 20, 3, 14, 7,  1, 4, 40, 
    8, 32, 3, 20, 1, 45, 7, 60, 2, 75, 6, 20, 5, 18, 4, 35, 0, 49, 
    3, 36, 1, 39, 2, 92, 5, 83, 7, 60, 0, 14, 4, 89, 8, 88, 6,  9, 
    2, 13, 7, 84, 3, 18, 1, 53, 8,  5, 6, 34, 4, 61, 5, 94, 0, 45, 
    6, 86, 3, 27, 1, 56, 5, 24, 2, 57, 7, 24, 4, 75, 8, 41, 0, 33, 
    7, 77, 8,  1, 1, 63, 4, 58, 2, 33, 3, 31, 0, 13, 5, 32, 6, 35, 
    3, 75, 4, 79, 5, 98, 6, 71, 2,  5, 1, 61, 8, 36, 0, 91, 7, 66, 
    5, 20, 7, 24, 3, 43, 6, 13, 2, 32, 1, 90, 8, 17, 4, 43, 0,  4, 
    3, 63, 2, 16, 0, 77, 5, 50, 4, 93, 6, 58, 7, 63, 1, 81, 8, 65
  };
  const int q8929[] = {
    9, 9, // Number of jobs and machines
    1, 59, 4, 60, 5, 10, 3, 49, 7,  2, 0, 99, 2, 66, 8, 21, 6, 50, 
    0, 65, 1, 98, 6, 17, 8, 82, 4, 43, 3, 94, 7, 92, 5, 18, 2, 61, 
    2, 79, 3, 11, 5, 93, 0, 13, 7, 25, 8,  4, 6, 17, 1, 59, 4, 69, 
    2, 60, 5, 89, 1, 46, 6, 37, 7, 46, 0, 13, 8, 86, 4, 11, 3, 38, 
    6, 88, 5, 62, 7, 15, 1,  8, 2, 85, 4, 48, 3, 49, 8, 57, 0, 21, 
    1, 78, 4,  4, 0, 86, 8, 81, 6, 38, 7, 44, 3, 95, 2,  6, 5, 69, 
    6, 88, 2, 51, 8, 13, 0, 96, 1,  8, 4, 43, 5, 57, 7, 73, 3, 62, 
    1, 19, 5, 72, 4, 28, 7, 94, 2, 68, 0, 60, 8, 17, 6, 56, 3, 89, 
    0, 87, 3, 68, 5, 52, 6, 16, 2, 70, 7, 73, 1, 92, 4, 72, 8, 40
  };
  const int q8930[] = {
    9, 9, // Number of jobs and machines
    6, 61, 0, 88, 4, 18, 7, 29, 8,  5, 5, 88, 3, 28, 2, 41, 1, 24, 
    3, 24, 6, 36, 0, 97, 4, 48, 1, 44, 2, 39, 8, 82, 7, 13, 5, 17, 
    4, 58, 3, 44, 6, 37, 8, 59, 7, 49, 5, 88, 0, 13, 2, 19, 1, 11, 
    3, 36, 8, 20, 6, 90, 2, 24, 1, 51, 0, 87, 5, 19, 4, 25, 7, 62, 
    4, 82, 1, 77, 2, 14, 7, 60, 5,  9, 6, 73, 3, 15, 0, 49, 8, 89, 
    4, 48, 0, 94, 6, 28, 5, 63, 8,  2, 2, 83, 1, 20, 7, 71, 3, 69, 
    4, 65, 1, 96, 0, 76, 6, 25, 2, 13, 3, 58, 8, 39, 7, 16, 5, 70, 
    7, 63, 8,  7, 2, 21, 0, 84, 3, 81, 1, 54, 4, 97, 6, 99, 5, 28, 
    8, 63, 0, 86, 4, 30, 3, 54, 7, 25, 1, 10, 2, 98, 5, 99, 6, 75
  };
  const int q8931[] = {
    9, 9, // Number of jobs and machines
    6, 19, 8,  8, 5, 46, 3, 51, 0, 46, 4, 30, 7, 83, 2, 66, 1, 41, 
    2, 13, 3, 90, 7, 32, 4, 72, 5, 78, 6, 36, 8, 15, 1, 97, 0, 46, 
    1, 40, 4, 29, 5, 51, 7, 19, 8, 71, 2, 11, 3, 39, 0,  6, 6, 32, 
    8, 80, 3, 66, 2, 22, 1, 27, 6, 25, 5, 82, 0, 33, 7, 57, 4, 36, 
    5, 74, 3, 96, 8, 29, 7, 61, 1, 73, 2, 32, 6, 23, 4, 87, 0, 95, 
    0, 91, 5, 13, 4, 53, 1, 67, 3, 65, 8, 16, 6, 85, 2,  8, 7, 95, 
    8, 54, 0, 28, 5, 28, 6, 84, 7, 52, 2, 21, 3, 59, 4, 67, 1,  9, 
    7, 59, 0, 89, 5, 88, 8, 24, 4, 83, 3, 24, 2, 34, 6,  2, 1, 12, 
    1, 35, 6, 33, 4, 97, 2,  3, 5, 96, 7, 14, 8, 44, 3, 13, 0, 77
  };
  const int q8932[] = {
    9, 9, // Number of jobs and machines
    0, 44, 4, 51, 8, 55, 1, 63, 3, 69, 6, 98, 5, 79, 7, 96, 2, 11, 
    1, 86, 7, 46, 2, 75, 6, 48, 8,  8, 0, 88, 5, 70, 4, 27, 3,  6, 
    0, 45, 4, 61, 8, 69, 6, 72, 1,  5, 5, 19, 3, 67, 7, 44, 2, 25, 
    8, 28, 7, 34, 4, 13, 5, 79, 6, 34, 3, 79, 0, 96, 1, 38, 2, 12, 
    2, 84, 6, 68, 3, 40, 5, 92, 0, 85, 4, 11, 1, 40, 8,  7, 7, 89, 
    2, 11, 4, 11, 1, 15, 0, 65, 5, 71, 7, 89, 6, 19, 8, 94, 3, 78, 
    3, 71, 8, 40, 1, 95, 4, 53, 6, 52, 5, 83, 7, 79, 0, 86, 2, 82, 
    8, 11, 7, 18, 1, 57, 2, 42, 6, 55, 3, 53, 5, 68, 4, 82, 0, 66, 
    8, 36, 2, 88, 6, 16, 3,  7, 4, 42, 0, 86, 7, 88, 5, 20, 1, 95
  };
  const int q8933[] = {
    9, 9, // Number of jobs and machines
    1, 45, 4,  8, 0, 73, 6, 38, 3, 95, 5, 32, 8, 94, 7, 61, 2, 62, 
    7, 72, 5, 80, 8, 39, 3, 20, 1, 56, 2,  2, 6, 22, 0, 44, 4, 27, 
    8, 22, 7, 44, 0, 96, 5, 14, 3, 97, 6, 71, 2,  4, 4, 75, 1, 53, 
    8, 50, 4, 26, 0, 38, 7, 96, 2, 44, 5, 52, 1, 44, 3, 91, 6, 81, 
    8, 79, 6, 98, 4, 22, 5, 52, 2, 39, 1, 46, 7, 22, 3, 12, 0, 38, 
    1, 44, 2, 85, 7,  1, 4, 95, 0, 75, 3, 59, 8, 78, 5, 89, 6, 95, 
    4, 88, 0, 37, 2, 26, 1, 13, 5, 64, 7, 95, 6, 15, 3, 75, 8, 51, 
    3, 50, 2, 19, 5, 19, 8, 32, 4,  2, 0, 43, 6, 19, 1, 88, 7, 68, 
    8, 97, 3, 14, 1,  2, 2, 91, 6, 43, 0, 58, 5, 70, 7, 10, 4, 52
  };
  const int q8934[] = {
    9, 9, // Number of jobs and machines
    8, 54, 7, 11, 6, 82, 0, 35, 5, 59, 4, 74, 3, 59, 2, 63, 1, 58, 
    0, 86, 4, 86, 7, 44, 8, 31, 3, 20, 5, 44, 2, 96, 6, 57, 1, 38, 
    0, 42, 3, 84, 1, 80, 2, 48, 7, 45, 5, 46, 4, 51, 6, 78, 8, 39, 
    4, 82, 3, 17, 8, 39, 0, 42, 6, 92, 2, 59, 1, 64, 7, 51, 5, 98, 
    5, 65, 0, 19, 3, 54, 6, 38, 2, 52, 4, 97, 8,  2, 7, 26, 1, 95, 
    3, 94, 2, 92, 6, 73, 5, 32, 1, 61, 8, 31, 0, 90, 4,  9, 7, 15, 
    7, 33, 6, 11, 3, 87, 4, 81, 8, 41, 5, 26, 2, 33, 1, 84, 0, 15, 
    4, 54, 0, 68, 1,  6, 7,  8, 3, 66, 8, 95, 2, 34, 5, 89, 6, 12, 
    0, 30, 8, 52, 1,  8, 2, 82, 3,  6, 7,  7, 5, 62, 4, 77, 6, 60
  };
  const int q8935[] = {
    9, 9, // Number of jobs and machines
    1,  2, 0, 40, 5, 74, 3, 66, 2, 58, 8, 10, 7,  2, 6, 26, 4, 24, 
    3, 38, 7, 54, 1, 90, 8,  8, 0, 74, 4, 60, 5, 41, 2, 54, 6, 70, 
    7, 64, 2, 65, 6, 99, 4, 59, 1, 77, 5, 58, 3, 48, 8, 26, 0, 40, 
    3,  7, 2, 40, 4, 28, 1, 62, 7, 57, 5, 24, 0, 93, 6, 63, 8,  3, 
    1, 57, 2, 83, 7, 76, 8, 25, 4, 32, 5, 16, 6, 10, 3, 19, 0, 80, 
    6, 24, 1, 14, 3, 58, 4, 63, 0, 41, 5, 88, 2, 86, 8, 73, 7, 58, 
    0, 88, 4, 69, 3, 14, 2, 20, 1, 93, 6, 78, 8, 27, 7, 87, 5, 29, 
    6,  4, 0, 32, 4, 13, 8, 93, 1, 85, 2, 32, 7, 98, 5, 59, 3, 52, 
    4, 96, 6, 76, 3, 53, 1, 87, 0, 40, 2, 51, 8, 80, 7, 78, 5, 95
  };
  const int q8936[] = {
    9, 9, // Number of jobs and machines
    5, 38, 2,  5, 7, 27, 6, 81, 3, 95, 4, 66, 0, 35, 1, 68, 8, 10, 
    7, 30, 0, 43, 3, 40, 5, 84, 2, 62, 4, 70, 1, 29, 6, 42, 8, 27, 
    4, 48, 7, 41, 5, 69, 3, 12, 8, 31, 0, 95, 6, 18, 2, 68, 1, 22, 
    4, 26, 7, 60, 5, 34, 8, 24, 3, 23, 6, 24, 1, 97, 0, 59, 2, 34, 
    7, 40, 3, 77, 5, 93, 1, 81, 2, 76, 8, 99, 4, 91, 6, 10, 0, 14, 
    8, 59, 6, 46, 3, 69, 4, 64, 1, 71, 0,  3, 2, 25, 5, 92, 7, 21, 
    5, 80, 6, 23, 4, 90, 1, 64, 7, 95, 0, 51, 8, 83, 2, 59, 3, 67, 
    4, 51, 3, 91, 8, 84, 5, 50, 2,  8, 6, 20, 1, 89, 0, 54, 7, 24, 
    6, 14, 5,  7, 2, 40, 0, 15, 4, 71, 7, 49, 1, 24, 3, 28, 8, 67
  };
  const int q8937[] = {
    9, 9, // Number of jobs and machines
    8,  1, 3, 68, 7, 32, 2, 82, 0, 11, 6, 35, 5, 61, 1, 71, 4, 47, 
    8, 41, 0, 65, 2,  5, 7, 19, 1, 88, 6, 17, 4,  6, 3, 15, 5, 28, 
    8, 80, 1, 90, 7, 33, 4, 70, 0, 48, 5, 11, 2,  7, 3, 40, 6, 23, 
    0,  5, 7, 60, 6, 77, 5, 80, 1, 16, 2, 56, 3, 64, 8, 87, 4, 47, 
    4, 42, 8, 73, 3, 34, 5,  2, 1, 43, 0, 14, 7, 47, 6, 59, 2, 67, 
    5, 87, 6, 20, 3, 27, 0, 38, 4, 44, 7, 69, 1, 76, 2,  3, 8, 41, 
    4, 99, 3,  6, 1, 98, 5, 93, 8, 12, 0, 87, 6, 79, 7, 50, 2, 52, 
    8, 47, 6, 37, 5, 49, 1, 23, 0, 88, 3, 67, 7, 63, 4, 45, 2, 96, 
    0, 51, 5,  1, 4, 15, 8, 77, 3, 85, 7,  1, 6, 64, 1, 12, 2, 17
  };
  const int q8938[] = {
    9, 9, // Number of jobs and machines
    0, 82, 3, 71, 8, 72, 4, 49, 7, 20, 5, 91, 6, 24, 1, 64, 2, 10, 
    7, 25, 3, 87, 6, 95, 1, 31, 5, 59, 8, 43, 2, 40, 0, 67, 4, 69, 
    7, 86, 3, 57, 4, 51, 0, 66, 1, 45, 2, 26, 8, 21, 6, 53, 5, 46, 
    1, 85, 8, 14, 4, 57, 2, 93, 7, 64, 5, 78, 6, 87, 0, 54, 3, 94, 
    3, 41, 0,  6, 1, 88, 7, 38, 2, 74, 6, 63, 8, 31, 5, 57, 4, 98, 
    6, 12, 4, 94, 3, 15, 1, 78, 5, 42, 2, 35, 7, 53, 8, 31, 0, 40, 
    1, 13, 6, 93, 3, 67, 8, 67, 2,  5, 4, 80, 0, 43, 5, 35, 7, 78, 
    6, 34, 5, 91, 2,  5, 3, 47, 1, 41, 7, 74, 8, 52, 4,  6, 0, 33, 
    3, 73, 7, 76, 5, 61, 0, 56, 2, 65, 6, 88, 1, 63, 8, 85, 4, 68
  };
  const int q8939[] = {
    9, 9, // Number of jobs and machines
    0, 59, 4, 32, 6, 80, 5, 17, 1, 27, 2, 26, 8, 47, 3,  5, 7, 91, 
    0, 65, 4, 20, 5, 20, 6,  7, 3, 69, 1, 83, 7, 83, 2, 64, 8, 56, 
    8, 52, 5, 93, 7, 76, 3, 20, 6,  1, 0, 17, 4, 34, 2, 69, 1, 63, 
    4, 67, 7, 87, 1, 23, 2, 26, 8, 48, 3, 74, 5, 62, 0, 92, 6, 71, 
    0,  8, 8, 10, 4, 72, 6, 52, 5, 16, 1, 36, 7, 68, 3, 54, 2, 10, 
    0, 71, 1,  5, 7, 59, 5,  7, 8, 66, 6, 20, 3, 39, 4, 95, 2, 13, 
    7, 23, 6, 63, 1, 78, 3, 33, 5, 28, 4, 26, 2, 57, 8, 76, 0, 30, 
    3, 70, 8, 40, 5, 38, 1, 26, 2, 37, 7, 68, 4, 46, 6, 27, 0, 22, 
    3, 48, 0, 10, 8, 28, 6, 75, 5, 87, 4, 59, 7, 46, 1, 31, 2, 35
  };
  const int q8940[] = {
    9, 9, // Number of jobs and machines
    0, 71, 3, 72, 2,  3, 6, 90, 4, 60, 7, 61, 5, 23, 8, 86, 1, 68, 
    3, 23, 8, 73, 6, 55, 5, 91, 0, 32, 1, 88, 2, 78, 7, 44, 4, 62, 
    3,  9, 1, 94, 2, 59, 7, 28, 0, 29, 8, 21, 5, 84, 4, 99, 6, 35, 
    0, 58, 4, 94, 8, 99, 5, 35, 1, 46, 3, 78, 6, 11, 2,  8, 7, 87, 
    0, 92, 2, 72, 8,  5, 4, 79, 7, 91, 1,  8, 3, 29, 6, 28, 5, 30, 
    4, 91, 3, 49, 8, 45, 1, 29, 0, 65, 7, 31, 6, 19, 2, 31, 5, 21, 
    7, 54, 0, 76, 4,  3, 2, 98, 8, 41, 6, 29, 3, 40, 5, 79, 1, 98, 
    1, 14, 5, 75, 3, 44, 6, 52, 8, 10, 4, 51, 2, 55, 7, 10, 0,  2, 
    4, 10, 5, 55, 1,  1, 2, 39, 0, 79, 8, 45, 7, 25, 3, 74, 6, 80
  };
  const int q8941[] = {
    9, 9, // Number of jobs and machines
    0, 80, 8, 12, 1, 92, 7, 95, 2, 92, 3, 40, 6, 33, 5, 81, 4, 76, 
    1, 18, 4, 37, 5,  4, 3, 46, 2, 60, 0, 14, 8, 30, 7, 10, 6, 31, 
    0,  2, 8, 67, 7,  8, 2, 89, 1, 65, 4, 76, 3, 41, 5, 52, 6, 68, 
    1, 44, 5, 79, 6, 27, 4, 52, 8, 28, 0, 59, 2, 70, 3, 23, 7, 61, 
    3,  3, 4, 76, 5, 65, 7,  3, 8, 60, 0, 61, 6, 35, 2, 53, 1, 39, 
    2, 68, 7, 76, 0, 33, 8, 87, 1, 20, 3, 35, 6, 69, 4,  8, 5, 20, 
    6, 55, 1, 40, 7, 40, 2, 60, 0, 67, 3, 21, 5, 85, 8, 16, 4,  2, 
    6,  7, 4, 80, 0, 50, 5, 72, 7, 62, 8, 29, 2, 11, 3,  9, 1, 63, 
    2, 82, 5, 56, 8, 29, 6, 42, 3, 50, 7, 12, 4, 49, 0, 87, 1,  3
  };
  const int q8942[] = {
    9, 9, // Number of jobs and machines
    2, 66, 5, 62, 0, 50, 4, 50, 3, 90, 1, 92, 7, 49, 8,  7, 6, 63, 
    3, 16, 4, 68, 1, 80, 6, 23, 8, 25, 7, 68, 2, 79, 5, 49, 0, 38, 
    6, 51, 2, 58, 3, 16, 4, 24, 5,  2, 7, 45, 8, 68, 1, 63, 0, 25, 
    1, 86, 2, 90, 0, 38, 4, 91, 3, 58, 5,  9, 6, 31, 7, 74, 8, 85, 
    1, 84, 7, 56, 5, 86, 6,  7, 8,  8, 4,  8, 0, 50, 2,  3, 3, 97, 
    4, 33, 8, 88, 3, 34, 7, 53, 5, 38, 2, 58, 6, 64, 1, 48, 0,  3, 
    0, 14, 5, 64, 7, 96, 2, 46, 8,  2, 1, 37, 3, 69, 6, 13, 4, 89, 
    6, 46, 8, 26, 1,  3, 4, 63, 0, 17, 3, 31, 7, 25, 2, 79, 5, 50, 
    3, 86, 2, 71, 1, 62, 5, 27, 4, 38, 7, 29, 6, 15, 8, 85, 0, 47
  };
  const int q8943[] = {
    9, 9, // Number of jobs and machines
    7, 68, 5, 30, 3, 85, 6, 71, 8, 51, 2, 11, 0, 94, 4, 23, 1, 64, 
    6, 76, 3, 83, 4, 24, 5, 39, 0,  5, 2,  6, 1, 47, 7, 79, 8, 71, 
    3, 54, 0, 69, 1, 64, 5, 97, 2, 91, 7, 15, 4, 95, 6, 58, 8, 33, 
    2, 54, 1, 91, 4, 60, 3, 76, 5,  8, 7, 44, 6,  6, 0, 40, 8, 68, 
    3, 63, 4, 69, 2,  7, 7, 67, 6, 63, 0, 55, 8,  1, 1, 28, 5, 60, 
    0, 48, 5, 68, 2, 50, 7, 82, 8, 43, 3, 63, 6, 16, 4, 38, 1, 36, 
    0, 64, 2, 45, 4, 42, 8, 81, 1, 47, 3, 43, 7, 28, 6, 34, 5, 46, 
    7,  6, 8, 82, 2, 49, 5, 88, 1, 84, 4, 50, 0, 35, 6, 23, 3, 12, 
    5, 87, 1, 13, 7, 27, 2,  9, 3, 41, 4, 82, 6, 74, 0, 61, 8, 19
  };
  const int q8944[] = {
    9, 9, // Number of jobs and machines
    6, 92, 4, 34, 1, 67, 5, 38, 8,  7, 2, 84, 0,  7, 3, 61, 7, 35, 
    6, 86, 2, 28, 1, 16, 3, 69, 5, 74, 7, 19, 0, 88, 8, 29, 4, 68, 
    8, 16, 7, 61, 3, 87, 6, 96, 1, 59, 0, 12, 2, 35, 5, 73, 4,  6, 
    4, 21, 6, 38, 3, 11, 0, 89, 5, 82, 8, 73, 1, 50, 2, 64, 7, 67, 
    5, 77, 1,  5, 2,  9, 7, 14, 8, 18, 4, 19, 3, 34, 0, 79, 6, 67, 
    7, 24, 6, 26, 2, 85, 1, 69, 0, 53, 5, 11, 4, 82, 3, 65, 8, 49, 
    1, 57, 2, 34, 7, 24, 8, 76, 6, 22, 4,  4, 3,  8, 5, 31, 0, 84, 
    8, 21, 3, 47, 4, 21, 6, 95, 0, 94, 5,  2, 7, 94, 2, 60, 1, 84, 
    6, 30, 2, 52, 7, 91, 8, 74, 0, 70, 5, 53, 4,  1, 3, 93, 1, 55
  };
  const int q8945[] = {
    9, 9, // Number of jobs and machines
    3, 64, 6, 56, 0, 80, 5, 30, 1, 31, 8, 76, 2, 44, 7, 59, 4,  8, 
    5,  6, 0, 62, 3,  5, 2, 37, 1, 46, 7, 12, 6, 57, 8,  1, 4, 80, 
    6,  4, 0, 92, 7, 74, 2, 63, 3, 85, 4, 36, 5,  3, 8, 65, 1, 36, 
    6, 27, 1, 35, 5, 18, 7, 40, 0, 77, 3, 13, 4, 55, 2, 37, 8, 73, 
    7, 73, 0, 88, 2, 38, 3, 83, 6, 31, 4, 97, 1, 11, 5, 98, 8,  5, 
    8, 85, 6, 67, 7, 56, 4,  8, 2, 51, 5, 46, 3, 54, 0, 49, 1, 63, 
    0, 86, 6, 83, 4, 88, 3, 36, 7, 30, 8, 39, 1, 89, 5, 74, 2, 10, 
    2, 17, 5, 57, 8, 41, 7, 92, 6, 23, 1, 17, 4, 40, 0, 17, 3,  6, 
    7, 47, 3, 47, 1, 86, 4, 68, 6, 91, 5, 42, 2, 28, 8, 33, 0, 67
  };
  const int q8946[] = {
    9, 9, // Number of jobs and machines
    2, 50, 7, 57, 4, 21, 3, 58, 8, 21, 6, 40, 5, 46, 0, 64, 1, 83, 
    2, 95, 0, 66, 5, 44, 4, 59, 3,  1, 7, 96, 6, 34, 1, 51, 8, 89, 
    8, 78, 1,  9, 2, 14, 3, 59, 7, 31, 0, 65, 4, 28, 6, 10, 5, 60, 
    7, 60, 6, 61, 0, 91, 8, 70, 1, 72, 5, 29, 4, 59, 3, 56, 2, 42, 
    3, 39, 6, 91, 0, 29, 4, 28, 8, 11, 1, 71, 2, 90, 7, 54, 5, 32, 
    3, 15, 2, 74, 6, 72, 5, 75, 7, 56, 1, 92, 8, 87, 0, 24, 4, 10, 
    8, 40, 4, 82, 5, 88, 1, 14, 2, 74, 0, 76, 6, 10, 7, 82, 3, 97, 
    8, 20, 0, 39, 2, 96, 3, 80, 4, 28, 1, 52, 5, 41, 6, 98, 7, 46, 
    8, 96, 1, 37, 3, 15, 0, 90, 6, 62, 7, 46, 2, 42, 5, 74, 4, 64
  };
  const int q8947[] = {
    9, 9, // Number of jobs and machines
    1,  6, 5, 92, 8, 56, 4,  7, 6, 36, 3, 43, 2, 34, 0, 55, 7, 61, 
    3, 78, 2, 40, 0, 25, 5, 48, 1,  1, 7, 86, 8, 40, 6, 47, 4, 75, 
    6, 13, 1, 95, 4, 16, 8, 64, 3, 37, 7, 77, 5, 46, 0, 22, 2, 90, 
    8, 51, 6, 69, 7, 52, 4, 86, 2, 82, 1, 99, 5, 30, 0, 31, 3, 22, 
    5, 65, 8, 24, 6, 85, 3, 15, 2, 61, 7, 37, 1, 37, 4, 82, 0,  5, 
    5, 60, 7, 50, 3, 35, 6,  7, 8,  1, 4, 81, 0, 96, 1, 33, 2, 97, 
    3, 36, 1, 65, 8, 89, 2, 82, 0, 48, 7, 78, 5, 68, 4, 97, 6, 45, 
    5, 33, 8, 63, 3, 86, 1, 24, 4, 58, 0, 32, 7, 94, 6, 68, 2, 87, 
    4, 80, 2,  1, 0, 13, 7, 28, 8, 44, 6, 56, 3, 38, 5, 50, 1, 54
  };
  const int q8948[] = {
    9, 9, // Number of jobs and machines
    3, 16, 5, 25, 8, 65, 6,  7, 1, 42, 4,  3, 2, 77, 7, 23, 0,  7, 
    1,  7, 3, 55, 5, 57, 8,  7, 0, 65, 7, 88, 4, 17, 6, 96, 2, 40, 
    5, 83, 8, 38, 0, 19, 1, 32, 4, 45, 3, 65, 6, 29, 2, 94, 7, 82, 
    2, 92, 0, 45, 5, 27, 6, 97, 4, 72, 8, 12, 1, 65, 7, 29, 3, 19, 
    2, 39, 8, 47, 7, 91, 0, 45, 1, 53, 4, 38, 6, 34, 5, 39, 3, 62, 
    2, 82, 7, 76, 0, 18, 5, 88, 3, 76, 6, 82, 4, 85, 8, 45, 1, 31, 
    6, 79, 7, 94, 0, 97, 8, 70, 3, 91, 1, 57, 4,  3, 2, 30, 5, 42, 
    2, 47, 7, 20, 8, 53, 6, 83, 0, 80, 3, 61, 5, 45, 4, 30, 1, 21, 
    6, 16, 3, 59, 8, 39, 4, 20, 2, 22, 5, 98, 0, 19, 7, 43, 1, 31
  };
  const int q8949[] = {
    9, 9, // Number of jobs and machines
    6, 40, 7, 28, 1, 24, 3, 42, 0, 25, 5, 49, 2, 35, 8, 55, 4, 66, 
    6, 45, 4, 83, 2, 12, 0, 99, 8, 42, 3, 97, 1, 49, 7, 65, 5, 27, 
    8, 39, 4, 31, 3, 65, 0,  4, 6, 82, 2,  3, 5, 76, 7, 12, 1, 58, 
    5, 73, 0, 83, 1,  7, 6, 97, 7, 83, 8, 34, 4, 88, 3, 45, 2, 26, 
    7, 19, 2, 18, 1, 75, 3, 80, 6, 89, 5, 73, 0,  1, 8, 46, 4, 41, 
    3, 58, 1,  5, 2, 41, 6, 65, 5,  6, 4, 36, 8, 86, 0, 31, 7,  9, 
    1, 26, 7, 99, 5,  6, 6, 35, 3, 40, 2, 15, 8,  3, 0, 59, 4, 72, 
    4, 86, 0, 80, 1, 25, 6, 18, 8, 16, 5,  3, 2, 95, 7, 53, 3, 84, 
    1, 92, 7, 53, 5, 71, 2, 88, 8, 76, 3, 64, 0, 76, 4, 71, 6, 60
  };
  const int q8950[] = {
    9, 9, // Number of jobs and machines
    8, 92, 3, 59, 2, 74, 4, 11, 6,  3, 1, 58, 0, 43, 5, 24, 7,  2, 
    0, 65, 7, 33, 2, 94, 3, 38, 1, 69, 4, 20, 8, 98, 5, 83, 6, 54, 
    4, 46, 8, 97, 6, 62, 2, 12, 0, 13, 3, 91, 1, 64, 7, 53, 5, 76, 
    2, 26, 5, 32, 0, 81, 4, 77, 8, 93, 6, 18, 3, 94, 1,  4, 7, 98, 
    5, 76, 0, 55, 6, 57, 8, 36, 1, 49, 3, 24, 2, 15, 7, 23, 4, 28, 
    0, 31, 8, 61, 4,  1, 2, 10, 5, 72, 3, 80, 1, 98, 7, 11, 6, 34, 
    1, 38, 6,  9, 2, 78, 8, 58, 7,  5, 5, 27, 3, 34, 0, 11, 4, 25, 
    7, 71, 2, 25, 5, 12, 8, 28, 6, 26, 4, 69, 0, 20, 1, 22, 3, 34, 
    5, 85, 8, 42, 1, 34, 2, 28, 0, 27, 7, 25, 3, 50, 4, 84, 6, 84
  };
  const int q8951[] = {
    9, 9, // Number of jobs and machines
    4, 33, 0, 25, 3, 16, 8, 59, 2, 56, 6, 63, 7, 51, 1, 77, 5, 49, 
    3, 29, 1, 68, 4, 59, 8, 25, 6,  9, 5, 18, 7, 78, 2, 61, 0, 21, 
    4, 74, 1, 72, 7, 98, 8, 31, 5, 48, 0, 47, 2, 29, 3, 41, 6, 22, 
    1, 41, 5, 43, 0, 16, 2, 90, 4, 16, 8, 58, 6, 54, 3, 40, 7, 54, 
    6, 74, 5,  3, 2, 55, 8, 24, 1, 75, 7, 52, 4,  8, 0, 65, 3, 82, 
    4, 50, 2, 44, 5, 21, 1, 39, 6,  6, 0, 98, 3, 62, 7, 17, 8, 84, 
    4, 56, 1, 15, 0, 11, 8, 54, 2, 48, 7, 24, 3, 94, 5, 12, 6, 85, 
    8, 45, 4, 45, 7, 70, 1, 18, 6, 19, 5, 20, 0, 21, 3, 21, 2, 13, 
    4, 35, 1, 16, 7, 68, 8, 12, 2, 29, 0, 90, 6, 32, 5, 99, 3,  9
  };
  const int q8952[] = {
    9, 9, // Number of jobs and machines
    1, 56, 8,  4, 3,  4, 4, 93, 0, 86, 2, 85, 7, 96, 5, 73, 6,  2, 
    5, 24, 0, 39, 8, 26, 4, 97, 3,  7, 2, 10, 6, 58, 1, 65, 7, 84, 
    5, 16, 1, 13, 4, 81, 7, 22, 0, 37, 3, 14, 2, 57, 6, 66, 8, 94, 
    7, 91, 5, 62, 1, 55, 6, 67, 4, 17, 2, 74, 8,  5, 3, 67, 0, 68, 
    0, 97, 7, 22, 1, 40, 4, 99, 6, 46, 5, 98, 3, 69, 2, 79, 8, 74, 
    3, 76, 6, 81, 1,  6, 7, 30, 8, 29, 4, 83, 5, 72, 0, 86, 2, 62, 
    8, 27, 4,  9, 7, 88, 5, 13, 1, 99, 3, 61, 2, 59, 0, 40, 6, 36, 
    8, 31, 6, 70, 2, 14, 1, 26, 0, 63, 5, 69, 3, 12, 7, 55, 4, 90, 
    1, 61, 7, 94, 4, 68, 8, 98, 5,  4, 0, 59, 3, 50, 6,  6, 2, 92
  };
  const int q8953[] = {
    9, 9, // Number of jobs and machines
    5, 42, 8, 48, 7, 10, 3, 36, 6, 59, 2, 69, 1,  5, 0, 12, 4, 66, 
    1, 50, 4, 60, 7, 19, 0, 29, 5, 11, 6, 83, 3, 99, 2, 34, 8, 15, 
    6, 22, 0, 21, 2, 61, 8, 13, 5,  5, 7,  3, 3,  3, 1, 95, 4,  9, 
    7, 83, 8, 96, 0,  7, 5, 57, 1, 35, 4, 67, 2, 57, 6, 85, 3, 41, 
    8, 34, 6, 32, 4, 44, 7, 94, 2,  2, 3, 60, 1, 96, 5, 77, 0, 66, 
    8, 39, 6, 90, 1, 43, 4, 49, 2, 24, 3, 71, 0,  2, 7, 42, 5,  4, 
    8,  3, 4, 21, 3, 22, 0, 16, 6, 12, 2, 47, 5, 48, 1, 66, 7, 76, 
    4, 61, 6, 61, 5, 11, 8, 11, 0, 54, 7, 96, 1, 69, 2, 23, 3, 54, 
    3, 94, 4, 45, 8,  5, 0, 39, 7, 76, 6, 55, 1, 89, 2, 25, 5, 78
  };
  const int q8954[] = {
    9, 9, // Number of jobs and machines
    3, 54, 4, 60, 2, 26, 5,  2, 7,  7, 1, 52, 0, 78, 8, 53, 6, 24, 
    6, 15, 5, 89, 1, 63, 3, 76, 4, 23, 0, 24, 7, 98, 8, 79, 2, 91, 
    3, 16, 6, 12, 2, 14, 0, 75, 8, 18, 7, 76, 4, 25, 5, 58, 1, 60, 
    5, 81, 8, 94, 3, 98, 2, 96, 0, 89, 7, 72, 6, 64, 4,  6, 1, 80, 
    4, 49, 8, 69, 5, 52, 3, 95, 6, 23, 1, 93, 0, 45, 7, 26, 2, 23, 
    5, 36, 0, 51, 1, 17, 3, 54, 7, 93, 2, 30, 8, 39, 6,  6, 4,  9, 
    2, 88, 8, 75, 3, 92, 0, 53, 6, 70, 1, 43, 5, 44, 7,  7, 4, 95, 
    2, 14, 4, 95, 6, 10, 7, 26, 5, 93, 8,  1, 0, 43, 3, 40, 1, 83, 
    3, 46, 7, 85, 5, 78, 6, 95, 4, 66, 0, 61, 2, 36, 1, 96, 8, 33
  };
  const int q8955[] = {
    9, 9, // Number of jobs and machines
    7, 79, 8, 34, 6, 22, 1, 25, 3, 74, 2, 92, 0, 31, 4,  1, 5,  1, 
    6,  9, 3, 85, 5, 10, 4,  2, 1, 49, 0, 99, 7, 86, 8,  1, 2, 49, 
    4, 44, 1, 24, 7, 21, 5, 55, 0, 50, 8, 43, 6, 56, 2, 34, 3, 18, 
    6, 30, 0, 43, 2, 44, 5, 79, 7, 74, 4, 63, 1, 47, 8, 40, 3,  6, 
    8, 44, 0,  5, 6, 77, 4, 73, 3, 89, 2, 41, 7, 94, 1, 94, 5,  3, 
    4, 55, 1, 94, 6, 66, 8, 98, 5, 93, 3, 24, 7, 66, 0, 27, 2, 43, 
    4, 64, 0, 59, 3, 34, 8, 17, 1, 23, 7, 33, 2, 67, 6,  5, 5, 98, 
    1,  3, 2, 89, 0, 97, 4, 23, 3, 17, 8, 41, 6, 38, 5, 27, 7, 26, 
    7, 20, 6, 62, 1, 13, 3, 90, 5,  8, 2, 42, 8, 13, 0, 11, 4, 36
  };
  const int q8956[] = {
    9, 9, // Number of jobs and machines
    5,  7, 3, 51, 8, 78, 7, 17, 0, 28, 6, 46, 2, 37, 4, 13, 1, 27, 
    8, 77, 3, 54, 6, 76, 4, 11, 1, 16, 0, 65, 2,  2, 5, 71, 7, 82, 
    1, 19, 2, 99, 3, 97, 7, 19, 5, 95, 4, 69, 8, 67, 0, 55, 6, 70, 
    0, 15, 7, 40, 5, 10, 3,  4, 6,  5, 4, 71, 8, 32, 1, 76, 2, 57, 
    7, 86, 4, 42, 1, 62, 5,  2, 8,  1, 6, 89, 3, 73, 0, 68, 2, 14, 
    6, 80, 1, 77, 2,  6, 0, 44, 7, 45, 4, 81, 5, 95, 8, 47, 3, 81, 
    2, 52, 6, 54, 4, 38, 3, 67, 1, 31, 0, 43, 8, 58, 7,  8, 5, 26, 
    6, 36, 7, 33, 4, 49, 8, 60, 0, 74, 3, 84, 2, 84, 5, 62, 1,  9, 
    7, 74, 5,  7, 0, 77, 1, 42, 2,  8, 4, 79, 3, 28, 6, 71, 8, 86
  };
  const int q8957[] = {
    9, 9, // Number of jobs and machines
    0, 26, 2, 99, 3, 45, 8, 94, 5, 94, 4, 99, 7, 49, 6, 53, 1, 69, 
    8, 76, 1, 94, 0, 56, 4, 30, 3, 42, 6, 57, 7, 90, 5, 38, 2, 50, 
    2, 67, 0, 74, 1, 49, 8, 84, 4, 75, 5,  7, 3, 35, 7, 49, 6, 74, 
    4, 40, 5, 48, 2, 94, 6, 66, 3, 52, 7, 73, 8, 35, 1, 55, 0, 32, 
    6, 75, 5, 53, 2, 87, 1, 94, 7,  2, 0, 71, 4, 61, 3, 39, 8, 54, 
    0, 57, 3, 21, 6, 21, 5,  4, 4, 19, 2, 10, 7, 24, 1, 97, 8, 55, 
    8, 24, 4, 29, 0, 37, 2, 56, 1, 39, 6, 37, 5, 22, 7, 41, 3, 72, 
    5,  9, 4, 93, 8, 82, 0, 18, 1, 70, 3, 42, 2,  2, 7, 55, 6, 13, 
    8,  6, 4, 23, 1, 54, 0, 14, 7, 92, 3, 79, 2, 39, 5, 77, 6, 45
  };
  const int q8958[] = {
    9, 9, // Number of jobs and machines
    0, 67, 6, 70, 7,  1, 5, 55, 8, 99, 3, 64, 1, 90, 2, 22, 4, 33, 
    4, 33, 3, 62, 6, 91, 8, 58, 5,  7, 1, 44, 7, 13, 2,  8, 0, 83, 
    4, 20, 3, 95, 1, 24, 2,  9, 6, 25, 8, 37, 5, 91, 7, 26, 0, 81, 
    8, 31, 1, 52, 7,  8, 2, 37, 6, 38, 0, 79, 4, 53, 5, 87, 3, 24, 
    4, 30, 6, 12, 5, 25, 8,  8, 3, 51, 0, 54, 1, 66, 7, 66, 2, 67, 
    6, 55, 1, 21, 4, 68, 2, 11, 5, 85, 8, 21, 7, 89, 3, 42, 0, 25, 
    1,  2, 2, 69, 4, 11, 7, 85, 3, 29, 6, 80, 0, 73, 5, 29, 8,  5, 
    6,  3, 7, 12, 5, 21, 2, 10, 1, 95, 3,  4, 4, 33, 8, 12, 0, 98, 
    6, 55, 2, 97, 7, 51, 3, 66, 5,  3, 1, 49, 4, 33, 8, 36, 0, 38
  };
  const int q8959[] = {
    9, 9, // Number of jobs and machines
    5, 99, 7, 79, 8, 42, 0,  9, 1, 90, 4, 76, 6, 23, 2, 90, 3, 83, 
    6, 72, 0, 50, 5, 42, 2, 27, 1, 67, 8, 60, 7, 13, 4, 18, 3, 19, 
    1, 18, 7, 63, 3, 17, 4, 49, 8, 89, 0, 53, 6, 41, 2, 84, 5, 39, 
    0, 92, 4, 54, 8, 80, 6, 51, 3, 79, 1, 37, 7, 66, 2, 64, 5, 44, 
    7, 91, 3, 35, 8, 75, 1, 99, 4, 92, 6, 90, 0, 26, 5, 75, 2,  3, 
    0, 19, 5, 24, 7, 12, 3, 57, 4, 11, 8, 38, 6, 17, 1, 76, 2,  8, 
    8, 45, 0, 76, 6, 34, 2, 84, 7, 16, 3, 51, 4, 72, 5,  4, 1, 74, 
    0, 59, 8, 15, 7, 69, 5, 59, 3, 71, 1, 36, 2, 20, 4, 63, 6, 65, 
    4, 23, 5, 41, 7, 67, 8, 60, 2, 70, 0, 64, 1, 47, 3, 23, 6, 30
  };
  const int q8960[] = {
    9, 9, // Number of jobs and machines
    0, 71, 2, 40, 8, 49, 4, 35, 6, 98, 1, 90, 7, 28, 5, 37, 3, 59, 
    1, 95, 5,  8, 6, 10, 8, 99, 2, 73, 3,  2, 7, 19, 4, 82, 0, 87, 
    5, 13, 8, 67, 1, 80, 2, 53, 3, 73, 4,  1, 6, 25, 7, 78, 0, 74, 
    1, 79, 4, 97, 8, 86, 2,  8, 0, 38, 5, 50, 6, 21, 7, 23, 3, 85, 
    5, 79, 1,  2, 0, 90, 3,  9, 7, 40, 2, 16, 4, 93, 6, 66, 8, 73, 
    8, 28, 1, 92, 4, 63, 2, 36, 3, 65, 5, 28, 7, 27, 6, 31, 0, 66, 
    6, 38, 5, 43, 4, 69, 7, 25, 3, 23, 1, 61, 0, 29, 8, 76, 2, 12, 
    0, 33, 7, 34, 1, 17, 5, 45, 6, 63, 4, 55, 8, 68, 2, 71, 3, 21, 
    6, 98, 0, 98, 1,  3, 2, 81, 3, 50, 4, 47, 7, 23, 5, 26, 8, 58
  };
  const int q8961[] = {
    9, 9, // Number of jobs and machines
    6, 10, 8, 97, 0, 63, 5, 81, 3, 38, 2, 62, 7, 37, 1, 87, 4, 99, 
    8, 78, 0, 72, 1, 36, 6, 58, 5, 93, 4, 97, 3, 28, 7, 78, 2, 20, 
    7, 73, 4, 74, 3, 13, 1, 43, 2, 22, 6, 85, 0, 57, 8, 90, 5, 44, 
    3, 53, 2, 34, 4, 52, 7, 60, 8, 54, 5, 33, 6, 38, 1, 40, 0,  2, 
    6, 96, 4, 67, 5, 50, 2,  3, 7, 11, 3, 95, 0, 96, 8, 20, 1, 68, 
    5, 54, 3, 83, 1,  9, 4,  1, 6, 70, 0, 98, 7, 53, 8, 16, 2, 86, 
    2, 25, 3, 19, 1, 91, 8, 35, 7, 86, 5, 52, 4, 89, 0, 46, 6, 79, 
    3, 80, 7, 29, 8, 29, 2, 26, 1, 80, 5, 25, 0,  3, 6, 47, 4, 15, 
    1, 72, 0, 41, 8, 34, 7, 24, 5, 56, 6, 17, 3, 55, 4, 31, 2, 71
  };
  const int q8962[] = {
    9, 9, // Number of jobs and machines
    1, 35, 0, 90, 3, 69, 4, 62, 2, 38, 7, 27, 8,  7, 5, 90, 6, 51, 
    4, 87, 8, 84, 0, 11, 2, 58, 6, 43, 5,  7, 1, 58, 7,  4, 3, 98, 
    7, 12, 6, 94, 8, 88, 1,  6, 4, 79, 0, 21, 2, 21, 3, 33, 5,  2, 
    5, 47, 1, 92, 3, 72, 2, 84, 7, 37, 0,  4, 8, 91, 4, 92, 6, 37, 
    6, 46, 1,  9, 5, 53, 7, 32, 4, 83, 8, 71, 2, 87, 3, 78, 0, 97, 
    2, 55, 5, 95, 7, 15, 3, 51, 0, 45, 6, 59, 1, 69, 8, 31, 4, 91, 
    5, 51, 8, 27, 1, 74, 4, 63, 7, 33, 2, 44, 6, 28, 3,  5, 0,  2, 
    5, 79, 0, 53, 3, 16, 8, 26, 4, 46, 6, 67, 2, 12, 7, 55, 1, 87, 
    0, 28, 1, 57, 8, 24, 3, 16, 2, 57, 6, 41, 7, 42, 4, 32, 5, 29
  };
  const int q8963[] = {
    9, 9, // Number of jobs and machines
    7, 41, 0, 55, 8,  6, 3, 13, 6,  3, 2,  9, 5, 49, 4, 21, 1, 17, 
    7, 45, 0, 51, 1,  4, 3,  6, 5, 50, 6, 68, 4,  3, 8, 62, 2, 20, 
    7, 42, 0, 36, 5, 93, 4, 27, 6, 23, 3, 63, 2, 74, 8,  1, 1,  2, 
    5, 32, 1, 33, 6, 14, 4, 65, 2, 97, 0, 54, 8, 26, 7, 39, 3, 53, 
    4, 28, 1, 51, 5, 82, 6, 28, 2, 87, 0, 38, 7, 53, 3, 82, 8, 30, 
    8, 57, 0, 57, 7, 62, 3, 26, 4,  9, 6, 90, 2, 74, 1, 40, 5, 14, 
    7,  9, 0, 84, 6, 71, 1, 20, 4, 60, 2, 51, 3, 73, 5, 93, 8, 95, 
    8, 82, 5, 25, 3, 12, 2, 12, 1, 53, 6, 85, 4, 83, 7, 81, 0, 59, 
    8, 40, 3, 29, 6, 43, 7, 47, 2, 30, 4, 78, 5, 50, 1, 39, 0, 59
  };
  const int q8964[] = {
    9, 9, // Number of jobs and machines
    6, 91, 5, 84, 2, 88, 4,  6, 8, 96, 1, 81, 3, 55, 7, 21, 0, 26, 
    7, 95, 3, 76, 4, 86, 1, 27, 0, 83, 8, 42, 2, 93, 6, 75, 5, 44, 
    0, 32, 1, 36, 5, 80, 6, 88, 7,  2, 4, 98, 3, 70, 8, 70, 2, 73, 
    5, 55, 2, 67, 3, 26, 1, 22, 8,  6, 4, 17, 6,  9, 0, 17, 7, 94, 
    5, 82, 7, 70, 4, 86, 1, 67, 2, 36, 8, 48, 6, 94, 3, 19, 0, 27, 
    4, 83, 2, 69, 3, 59, 0, 55, 6, 11, 8, 48, 7, 83, 5, 68, 1, 75, 
    6, 41, 0,  4, 8, 37, 2, 62, 4, 99, 7, 99, 3, 81, 1, 59, 5, 73, 
    1, 85, 2, 82, 6, 41, 8, 88, 4, 83, 3, 52, 5,  9, 0, 55, 7, 98, 
    6, 43, 0, 79, 7, 50, 3, 22, 2, 57, 4, 24, 5, 92, 8, 44, 1, 80
  };
  const int q8965[] = {
    9, 9, // Number of jobs and machines
    8, 75, 7,  7, 5, 64, 6, 73, 2, 76, 0, 61, 4, 63, 3, 86, 1, 19, 
    2, 51, 4, 56, 6, 58, 0, 91, 5,  9, 8, 74, 7, 42, 1, 99, 3, 43, 
    1, 75, 2, 84, 5, 80, 4, 80, 8, 88, 7, 90, 0, 28, 6, 62, 3, 50, 
    0, 16, 8, 50, 5, 88, 2, 17, 6, 28, 1, 86, 3, 42, 4, 98, 7, 33, 
    5, 70, 3, 85, 0, 34, 1, 72, 2,  5, 4, 90, 6, 52, 8, 55, 7, 64, 
    7, 16, 1, 31, 8,  9, 3, 93, 2, 62, 6, 49, 5, 11, 4, 72, 0, 24, 
    0, 47, 5, 72, 2, 94, 4,  8, 6, 77, 7, 25, 1, 92, 3, 69, 8, 75, 
    1, 99, 2, 17, 8, 68, 5, 83, 7, 73, 6, 49, 4, 20, 0, 19, 3, 74, 
    8, 91, 1, 87, 0, 18, 6, 67, 3, 58, 4, 94, 7, 99, 5,  5, 2, 27
  };
  const int q8966[] = {
    9, 9, // Number of jobs and machines
    3, 98, 4, 60, 0, 82, 6, 28, 2, 31, 5, 51, 7, 99, 1, 93, 8, 57, 
    2, 68, 6, 66, 3, 80, 4, 88, 1,  9, 0,  1, 8, 87, 7, 41, 5, 18, 
    5, 93, 0, 20, 4, 74, 6, 78, 8, 58, 7, 49, 2, 98, 1, 61, 3, 67, 
    0, 63, 6, 12, 4, 76, 2, 27, 1, 39, 7, 77, 3, 20, 5,  2, 8, 57, 
    8, 52, 3,  5, 7,  3, 1, 10, 0, 77, 2, 49, 4, 49, 6, 83, 5, 11, 
    2, 24, 3, 50, 8, 79, 4, 15, 7,  2, 1, 51, 5, 83, 6, 48, 0, 59, 
    5, 27, 7, 54, 3, 57, 4, 49, 1, 42, 2, 73, 8, 40, 0, 97, 6, 39, 
    1,  7, 6, 24, 5, 10, 0, 98, 2, 80, 8, 84, 7, 33, 3, 19, 4, 72, 
    2, 43, 1, 99, 7,  8, 6, 25, 8, 20, 3, 82, 5, 74, 4, 39, 0, 17
  };
  const int q8967[] = {
    9, 9, // Number of jobs and machines
    6, 79, 0, 81, 7, 81, 2, 30, 1, 11, 3, 35, 5, 27, 8, 55, 4, 49, 
    1, 39, 7, 29, 3, 43, 6, 11, 8, 74, 4, 91, 5, 65, 2, 47, 0, 45, 
    3, 14, 7, 32, 0, 68, 5, 10, 2, 63, 8, 23, 1, 60, 6,  6, 4, 80, 
    2, 32, 6,  1, 8,  3, 5, 19, 1, 79, 7, 11, 0,  3, 3, 48, 4,  2, 
    0, 48, 5, 72, 6, 50, 7, 79, 4, 31, 2, 78, 8,  7, 1, 49, 3, 23, 
    2, 93, 5, 77, 1, 23, 7, 16, 3, 65, 8, 85, 6, 73, 4, 38, 0, 94, 
    3, 14, 5, 39, 2, 18, 8, 82, 0,  2, 4, 65, 7, 78, 6,  8, 1, 72, 
    0, 27, 8, 67, 4, 63, 6, 45, 2, 85, 5, 43, 3, 20, 1, 25, 7, 43, 
    3, 26, 8, 50, 4, 43, 2, 78, 6, 80, 7,  2, 5, 23, 0, 30, 1, 54
  };
  const int q8968[] = {
    9, 9, // Number of jobs and machines
    7, 66, 3, 52, 1, 19, 5,  3, 0, 86, 4, 82, 2, 29, 8, 25, 6, 84, 
    3, 91, 8, 32, 2, 80, 6, 34, 4, 55, 7, 54, 0,  5, 5,  9, 1, 77, 
    2, 82, 3, 41, 4, 33, 5, 25, 0, 93, 1, 49, 6, 69, 7, 95, 8, 57, 
    7,  5, 3, 18, 8, 79, 2, 95, 4, 72, 6, 76, 5, 43, 0, 46, 1, 85, 
    7, 11, 1, 75, 3, 71, 4, 46, 5, 19, 2, 45, 6, 40, 0, 47, 8, 53, 
    2, 35, 5, 61, 0, 70, 8, 14, 7, 16, 6, 11, 3, 77, 1, 74, 4, 62, 
    3, 49, 7, 48, 8, 21, 4, 25, 5, 44, 1, 30, 6, 62, 0, 33, 2, 62, 
    8,  5, 7, 12, 1, 53, 4, 59, 6, 70, 2, 68, 0, 76, 3, 85, 5, 87, 
    7, 71, 2, 31, 4, 69, 6, 41, 1, 19, 0, 91, 3, 53, 5, 23, 8,  2
  };
  const int q8969[] = {
    9, 9, // Number of jobs and machines
    2, 85, 4, 54, 6, 15, 1, 50, 0, 97, 5, 39, 7, 47, 3, 71, 8, 97, 
    7, 32, 6, 70, 5, 77, 3, 12, 8, 24, 0,  2, 2, 84, 4, 71, 1, 60, 
    6, 61, 8, 75, 0,  3, 7, 13, 4, 45, 2,  2, 5, 92, 1, 51, 3, 64, 
    2,  9, 6, 86, 1, 79, 0, 31, 5, 16, 8, 60, 4, 40, 7, 33, 3, 53, 
    7,  6, 6, 77, 5, 37, 0, 93, 4, 57, 3, 11, 1, 25, 2, 18, 8,  1, 
    0, 98, 8, 62, 2, 95, 6, 40, 1, 67, 4, 27, 7, 44, 3, 42, 5,  7, 
    3, 57, 2, 12, 8,  7, 0, 90, 1, 52, 5, 84, 6,  5, 7, 86, 4, 38, 
    4, 28, 6, 18, 2, 16, 8, 94, 1,  1, 5, 78, 0, 80, 7, 77, 3, 76, 
    5, 71, 8,  9, 2, 52, 0, 82, 3, 23, 4, 53, 7, 99, 1, 42, 6, 31
  };
  const int q8970[] = {
    9, 9, // Number of jobs and machines
    8, 15, 6, 46, 5, 76, 4, 48, 0, 53, 7, 16, 3, 18, 1, 17, 2, 52, 
    7, 74, 8, 60, 1, 93, 6, 36, 3, 52, 5,  3, 0, 84, 2, 50, 4, 60, 
    8, 57, 4, 44, 0, 81, 6, 90, 2, 46, 1, 98, 5, 99, 7, 20, 3, 90, 
    0, 91, 1, 14, 8, 74, 4, 29, 7, 14, 5, 50, 3, 33, 6, 56, 2, 85, 
    8, 87, 7, 22, 5,  8, 1,  3, 4, 54, 2, 49, 6, 89, 0, 20, 3, 22, 
    4, 27, 2, 99, 3, 46, 5, 12, 0, 87, 6, 70, 1, 85, 8, 71, 7, 64, 
    8, 80, 0, 41, 2, 74, 4, 40, 5, 53, 6, 25, 7, 18, 3, 92, 1, 51, 
    4, 46, 8, 68, 0, 53, 7, 19, 6, 39, 3, 51, 1, 57, 2, 15, 5, 49, 
    3, 28, 0, 44, 1, 63, 6, 63, 4, 29, 2, 36, 5, 32, 7, 63, 8, 38
  };
  const int q8971[] = {
    9, 9, // Number of jobs and machines
    0, 85, 4, 90, 6, 36, 8, 72, 2, 81, 5, 54, 7, 61, 1, 42, 3, 92, 
    4, 64, 7, 16, 5, 29, 8, 98, 6, 50, 2, 48, 3, 18, 1, 42, 0, 64, 
    2, 27, 0, 26, 1, 79, 5, 66, 7, 46, 3, 57, 8, 60, 4, 23, 6, 16, 
    5, 40, 1, 52, 4,  2, 8, 19, 6, 92, 0, 36, 2, 99, 7, 30, 3, 43, 
    0, 45, 4, 51, 2,  2, 7, 98, 6, 10, 1, 34, 3, 14, 5, 67, 8, 81, 
    4, 38, 1, 83, 7, 96, 3, 42, 5,  1, 2, 10, 6, 71, 8, 12, 0, 57, 
    3, 63, 5, 43, 8, 13, 1, 62, 2, 33, 0, 49, 4, 83, 6, 75, 7, 51, 
    7, 51, 4, 56, 3, 35, 6, 11, 0, 73, 8, 34, 1, 32, 5, 36, 2, 43, 
    3, 70, 0, 49, 7, 66, 1, 95, 6, 98, 4, 86, 8, 44, 5, 58, 2, 45
  };
  const int q8972[] = {
    9, 9, // Number of jobs and machines
    3, 15, 0, 31, 4, 63, 7, 41, 5, 89, 6, 70, 2, 38, 1, 88, 8, 10, 
    8, 77, 1, 48, 2, 68, 6, 41, 4, 33, 7, 50, 0, 65, 3, 38, 5, 73, 
    8, 31, 0, 87, 2, 98, 5,  1, 6, 63, 7, 27, 4, 16, 3, 85, 1, 29, 
    1, 28, 2, 58, 0, 29, 8, 62, 3, 97, 6, 63, 5, 16, 7, 90, 4, 29, 
    4,  9, 3, 67, 8, 58, 1, 45, 5, 10, 7, 14, 2, 16, 6, 45, 0, 44, 
    6, 94, 8, 99, 1, 41, 5, 69, 0, 63, 2,  3, 7, 12, 3,  8, 4, 52, 
    3, 66, 2, 94, 8, 69, 7, 47, 4, 18, 6, 18, 1, 24, 0, 18, 5, 19, 
    1, 64, 6, 20, 4, 28, 3, 10, 7, 62, 5, 14, 2, 53, 0, 35, 8, 75, 
    4, 79, 1, 50, 5, 54, 7, 48, 0, 12, 8, 90, 6,  7, 3, 27, 2, 60
  };
  const int q8973[] = {
    9, 9, // Number of jobs and machines
    5, 58, 4, 89, 1, 57, 7, 25, 2, 35, 8, 39, 6, 85, 3, 25, 0, 30, 
    4, 91, 5, 93, 7, 38, 2, 19, 1, 99, 8, 74, 3, 84, 6, 30, 0, 75, 
    3, 72, 1, 98, 4, 58, 8,  2, 2, 89, 6, 99, 0, 78, 5, 35, 7, 78, 
    8,  4, 1, 48, 3,  5, 5, 48, 7, 41, 0, 47, 2, 90, 4, 55, 6, 15, 
    6, 80, 8,  8, 3, 47, 2, 16, 4, 67, 7, 40, 0, 13, 1, 24, 5, 24, 
    2, 75, 1, 85, 8, 31, 4, 91, 7, 91, 0, 58, 3, 74, 5, 99, 6, 43, 
    8, 76, 6, 91, 4, 23, 3, 32, 0, 17, 5, 43, 7,  5, 1, 53, 2, 91, 
    1, 58, 7, 11, 5, 85, 2, 57, 6, 28, 3,  4, 8, 25, 0, 85, 4, 50, 
    2, 17, 0, 77, 4, 78, 3, 18, 7,  7, 6, 81, 8,  9, 1, 57, 5, 48
  };
  const int q8974[] = {
    9, 9, // Number of jobs and machines
    3, 75, 8, 31, 5,  4, 1, 33, 4, 75, 7, 23, 0, 79, 6, 31, 2, 77, 
    0, 85, 1, 85, 4, 68, 5, 39, 2, 26, 8, 75, 7, 21, 6, 57, 3, 58, 
    7, 74, 6, 42, 0, 32, 1, 95, 2, 87, 8, 74, 3, 16, 4, 94, 5, 45, 
    3, 95, 5, 28, 8, 47, 2, 80, 4, 62, 6, 28, 7,  4, 0, 89, 1, 60, 
    0, 44, 8, 63, 4, 61, 3, 82, 5, 60, 2, 51, 7, 99, 1, 15, 6, 73, 
    6, 53, 5, 98, 1, 43, 4, 36, 8, 26, 3, 64, 2, 52, 7, 60, 0, 49, 
    0, 60, 5, 19, 3, 16, 2, 10, 7,  7, 8, 33, 4, 92, 1, 93, 6, 46, 
    8, 64, 5, 38, 6, 24, 4, 38, 3, 25, 2, 36, 7, 22, 1, 86, 0, 19, 
    1, 29, 2, 70, 8, 81, 5, 17, 6, 17, 4, 44, 3, 73, 0, 70, 7, 80
  };
  const int q8975[] = {
    9, 9, // Number of jobs and machines
    7, 16, 1, 59, 6, 67, 5, 34, 8, 60, 4, 97, 3, 11, 0, 78, 2, 35, 
    4, 69, 2, 19, 0, 28, 3, 92, 1, 88, 6, 46, 7, 56, 5, 42, 8, 71, 
    0, 51, 7, 21, 4, 89, 2, 67, 6, 24, 1, 29, 5, 22, 8, 15, 3, 68, 
    4, 97, 0, 14, 5, 16, 3, 23, 7, 81, 1, 57, 6, 43, 8, 61, 2, 59, 
    3, 62, 1, 97, 4, 90, 7, 98, 5, 89, 8, 84, 2, 62, 0, 98, 6, 13, 
    4, 59, 6, 87, 1, 38, 3, 46, 2, 61, 8, 80, 5, 40, 0, 64, 7, 42, 
    4,  5, 5, 98, 3, 24, 0, 45, 6, 70, 8, 80, 7, 58, 1, 71, 2, 19, 
    3, 34, 4, 56, 7, 78, 2, 21, 6, 36, 8,  8, 5, 75, 1, 43, 0, 92, 
    5, 65, 0, 81, 4, 77, 7, 63, 3, 54, 2,  3, 6, 98, 1,  2, 8, 45
  };
  const int q8976[] = {
    9, 9, // Number of jobs and machines
    8, 56, 3, 96, 1, 92, 0,  7, 4, 64, 5, 41, 2, 53, 7, 38, 6, 12, 
    5, 80, 1, 58, 2, 35, 0, 24, 4, 50, 3, 93, 8, 48, 6, 52, 7, 12, 
    6, 16, 8, 46, 7, 52, 3, 39, 4, 72, 1, 49, 2, 33, 0, 96, 5, 88, 
    0, 82, 4, 76, 1, 98, 6,  2, 5, 69, 2, 43, 3, 77, 7, 19, 8, 18, 
    1, 66, 7, 19, 8, 79, 2,  8, 4, 15, 0, 85, 3, 10, 5, 80, 6, 18, 
    3, 46, 1, 89, 7, 73, 2, 58, 0,  7, 4, 84, 5, 55, 8, 92, 6, 58, 
    0, 80, 3, 18, 5, 29, 6, 93, 2, 17, 8, 80, 7, 79, 4,  3, 1, 42, 
    7, 24, 3, 92, 8, 89, 4, 73, 6, 48, 5, 39, 1, 16, 0, 79, 2, 30, 
    1, 31, 6, 67, 4, 45, 8, 97, 5, 98, 2, 87, 0, 78, 7, 69, 3, 87
  };
  const int q8977[] = {
    9, 9, // Number of jobs and machines
    5, 84, 0, 61, 6, 50, 1, 47, 7, 88, 3, 14, 8, 95, 2, 87, 4, 45, 
    0, 61, 7, 49, 8, 77, 2, 10, 4, 60, 5,  4, 3, 53, 6, 57, 1, 79, 
    3, 52, 6, 90, 4, 65, 1, 42, 8, 87, 2, 57, 0, 85, 7, 54, 5, 83, 
    4, 27, 6, 33, 0, 93, 1, 59, 3, 50, 7, 57, 5, 55, 2, 20, 8, 75, 
    3, 53, 1, 35, 4, 35, 7, 93, 2, 82, 6, 76, 8, 86, 5, 58, 0, 68, 
    5, 14, 4, 69, 6, 44, 1, 31, 7, 53, 3, 32, 2,  5, 8, 17, 0, 82, 
    8, 91, 6, 65, 4, 54, 1, 20, 0, 75, 3, 20, 5, 39, 7, 46, 2, 72, 
    8, 55, 3,  2, 5, 94, 1, 76, 4, 87, 2, 60, 6, 61, 7, 63, 0, 93, 
    5, 95, 0, 19, 7, 33, 3, 42, 6, 89, 4, 70, 2, 86, 8, 97, 1, 78
  };
  const int q8978[] = {
    9, 9, // Number of jobs and machines
    8, 75, 2, 60, 5, 45, 6, 86, 0, 73, 3, 78, 1, 60, 4, 46, 7, 99, 
    2, 37, 8, 12, 7,  6, 5, 19, 0, 69, 4, 80, 1, 17, 6, 39, 3,  6, 
    5,  3, 0, 19, 7, 41, 3, 82, 6, 51, 2,  8, 8, 86, 1, 91, 4, 46, 
    2, 60, 8, 99, 0, 76, 1, 72, 5, 16, 7, 22, 3, 88, 4, 60, 6, 99, 
    0, 57, 5, 49, 1, 68, 2, 35, 8, 78, 6, 78, 4, 37, 7, 30, 3,  7, 
    2, 22, 0, 97, 6, 13, 3, 74, 8, 43, 7, 67, 4, 66, 1, 42, 5, 56, 
    3, 69, 2, 39, 7, 85, 1, 12, 5, 94, 6, 39, 4,  4, 0, 94, 8, 42, 
    2, 79, 5,  9, 1, 26, 4, 97, 3, 70, 8, 84, 7, 32, 0, 56, 6, 15, 
    4, 89, 6,  7, 2, 55, 7, 75, 1,  2, 8, 82, 0, 68, 5, 84, 3, 57
  };
  const int q8979[] = {
    9, 9, // Number of jobs and machines
    6, 13, 1, 37, 5, 68, 4, 46, 2, 24, 0, 98, 7, 72, 8, 32, 3, 57, 
    8, 91, 0, 67, 6, 71, 3, 36, 4, 44, 5, 24, 1, 98, 2, 97, 7, 81, 
    2, 30, 0, 44, 7, 72, 6, 47, 4, 97, 5, 86, 8, 15, 3, 81, 1, 20, 
    8, 91, 3, 55, 7, 30, 4, 99, 6, 56, 2, 72, 5, 27, 1, 27, 0, 13, 
    5,  1, 8, 69, 3, 20, 7, 58, 2, 46, 4, 84, 6,  2, 1, 74, 0, 80, 
    0, 24, 5, 86, 4, 67, 7, 62, 2, 40, 1, 49, 8,  8, 6, 82, 3, 89, 
    0,  9, 6, 50, 1,  9, 8, 78, 2, 68, 7, 50, 4, 32, 3, 37, 5, 52, 
    0, 61, 8, 88, 4, 29, 2, 62, 3,  9, 7, 76, 5, 14, 6, 61, 1, 64, 
    1, 36, 7, 68, 2, 18, 5, 29, 3, 85, 8, 37, 0, 82, 4, 52, 6, 49
  };
  const int q8980[] = {
    9, 9, // Number of jobs and machines
    6, 85, 0, 32, 4, 71, 3, 47, 1,  6, 2, 96, 8, 50, 7, 28, 5, 44, 
    7, 34, 4, 17, 5, 82, 2, 95, 1, 37, 8,  3, 0, 15, 6,  6, 3, 24, 
    7, 56, 5, 76, 2, 55, 6, 14, 8, 52, 0, 67, 1, 70, 4,  3, 3, 38, 
    7, 35, 6, 17, 0, 29, 1, 49, 4, 63, 3, 95, 2, 71, 8,  3, 5, 27, 
    7, 15, 1, 93, 0, 41, 2, 89, 3, 35, 4, 99, 8, 98, 6, 63, 5, 80, 
    4,  1, 8, 42, 2, 31, 7, 61, 1, 76, 5, 87, 3, 42, 6, 85, 0,  4, 
    1, 25, 8, 98, 7, 60, 0, 36, 6, 83, 3, 37, 5, 72, 2, 16, 4, 67, 
    8, 60, 1, 39, 6, 10, 7, 78, 5,  9, 0, 96, 2, 38, 4, 53, 3, 26, 
    8,  7, 3, 18, 4, 91, 0, 86, 5, 36, 7, 87, 1, 90, 2, 72, 6, 71
  };
  const int q8981[] = {
    9, 9, // Number of jobs and machines
    7, 44, 8, 77, 0, 14, 4, 31, 2, 61, 5, 33, 1, 13, 6, 90, 3, 10, 
    7, 83, 8, 65, 3, 95, 6, 81, 5, 93, 4, 74, 0, 81, 1, 13, 2, 43, 
    7, 40, 3, 97, 6, 62, 1, 66, 5, 86, 4, 81, 8, 24, 0, 37, 2, 95, 
    6, 14, 1, 98, 0, 73, 2, 76, 5, 51, 8, 40, 3, 75, 7, 45, 4, 76, 
    7, 55, 4, 46, 3, 35, 0,  3, 8, 29, 1, 39, 2, 83, 6, 26, 5, 98, 
    1, 37, 4, 39, 3, 66, 2, 29, 0, 23, 8, 88, 7, 54, 5, 46, 6, 30, 
    7, 13, 2, 59, 0, 70, 4, 48, 3, 99, 8, 60, 1, 70, 5, 44, 6, 87, 
    2, 74, 6, 40, 4, 79, 7,  4, 0, 24, 3, 70, 8, 67, 5, 42, 1, 46, 
    5, 74, 4, 19, 0, 84, 2, 47, 8, 52, 6,  7, 7, 88, 1, 96, 3, 86
  };
  const int q8982[] = {
    9, 9, // Number of jobs and machines
    0, 51, 6,  1, 4, 27, 1, 22, 5, 36, 2, 29, 3, 34, 7, 72, 8, 37, 
    1, 57, 6,  1, 7, 91, 3, 45, 4, 45, 2,  1, 5, 31, 0, 86, 8, 30, 
    5, 49, 4, 42, 3,  7, 2, 61, 8, 85, 1, 46, 7, 37, 6, 77, 0, 44, 
    8,  9, 6, 71, 0, 21, 1, 68, 7, 94, 4, 83, 5, 44, 2, 11, 3, 42, 
    2, 16, 7,  2, 3, 97, 5, 81, 8, 81, 4, 56, 0, 59, 1, 72, 6,  4, 
    8,  6, 1, 23, 3, 49, 0, 85, 7,  2, 2, 22, 4, 99, 5, 61, 6, 48, 
    8, 24, 4, 94, 3, 81, 2, 50, 5, 43, 0, 71, 6, 53, 7, 80, 1, 33, 
    4, 67, 8, 30, 0, 36, 3, 63, 1, 11, 2, 93, 5, 20, 7, 50, 6,  6, 
    5, 42, 1, 31, 3, 29, 4, 84, 2, 61, 6,  9, 7, 14, 8, 48, 0, 27
  };
  const int q8983[] = {
    9, 9, // Number of jobs and machines
    4, 99, 0, 44, 6, 13, 2, 99, 1, 37, 7, 68, 3, 24, 5, 15, 8, 72, 
    0, 76, 7, 38, 3, 66, 5, 87, 1, 71, 6, 35, 2, 22, 8, 66, 4, 58, 
    3, 94, 5, 64, 0, 57, 1,  9, 6, 50, 7, 99, 2, 29, 8, 19, 4, 82, 
    3, 97, 0, 26, 1, 30, 5, 21, 4, 53, 2, 75, 8, 76, 6, 49, 7, 50, 
    2, 68, 1, 92, 8,  7, 5, 36, 7, 99, 4, 75, 0, 53, 6, 11, 3, 55, 
    5, 17, 4, 31, 6, 40, 2, 33, 3, 81, 8, 54, 0, 28, 1, 10, 7,  8, 
    2, 80, 5, 88, 8, 11, 6, 51, 1, 85, 3, 57, 0, 11, 7, 38, 4, 38, 
    4, 54, 3, 77, 1, 25, 8,  1, 6, 14, 7, 68, 5, 82, 2, 92, 0, 58, 
    0, 32, 4, 71, 8, 69, 1, 89, 6, 27, 5, 96, 7, 76, 2, 90, 3, 85
  };
  const int q8984[] = {
    9, 9, // Number of jobs and machines
    1, 50, 8, 87, 4, 16, 6, 32, 5, 57, 7, 46, 2, 53, 0, 66, 3, 32, 
    4, 36, 1, 65, 7, 28, 3, 99, 8,  7, 5, 70, 6, 91, 2, 45, 0, 17, 
    8, 27, 1, 72, 3, 12, 4, 14, 5, 51, 6, 78, 2, 37, 0, 62, 7, 30, 
    3,  6, 7,  3, 6, 95, 1, 95, 8,  2, 2, 38, 5, 52, 0, 85, 4, 73, 
    4, 77, 1, 90, 8, 16, 7, 45, 0,  7, 2, 96, 5, 31, 6, 73, 3, 51, 
    8, 72, 3, 22, 5, 64, 0, 14, 4, 42, 1, 62, 7, 99, 6, 30, 2, 70, 
    7, 66, 4,  2, 5, 97, 1, 34, 8,  8, 0,  1, 6,  3, 3, 43, 2, 36, 
    0, 69, 5, 35, 3, 91, 4,  9, 6,  2, 2, 78, 7, 46, 1, 38, 8, 39, 
    5, 44, 3, 44, 1, 64, 7, 39, 8, 63, 0, 16, 4, 17, 6, 45, 2,  6
  };
  const int q8985[] = {
    9, 9, // Number of jobs and machines
    4,  4, 3, 72, 8, 85, 1, 65, 0, 10, 6, 41, 5,  6, 2, 15, 7, 76, 
    6, 37, 8,  7, 1, 70, 3, 54, 7, 71, 5, 87, 4, 21, 0, 92, 2, 27, 
    6, 86, 4, 44, 2, 33, 3,  6, 5, 59, 8, 42, 7, 56, 1, 90, 0, 23, 
    3,  4, 0, 32, 1, 91, 5, 86, 4,  6, 2, 47, 8,  1, 7, 69, 6, 41, 
    8,  6, 0, 38, 6, 30, 4, 32, 7, 51, 1, 62, 2, 86, 3, 63, 5, 64, 
    7, 50, 3, 21, 1, 12, 2, 27, 6, 17, 5,  5, 4, 98, 8, 38, 0, 14, 
    4, 22, 3, 90, 2,  3, 8, 58, 1, 96, 7, 98, 6, 44, 0, 60, 5, 87, 
    0, 20, 8,  3, 5, 30, 7, 21, 4, 47, 2, 50, 3, 77, 1, 82, 6, 93, 
    2, 20, 5, 54, 7, 71, 3, 19, 6, 44, 8, 38, 0, 97, 4,  2, 1, 46
  };
  const int q8986[] = {
    9, 9, // Number of jobs and machines
    5, 54, 4, 91, 7, 48, 0, 44, 1, 28, 2, 32, 3, 58, 6, 80, 8,  6, 
    7, 29, 4, 29, 1, 20, 6, 51, 8, 40, 2, 66, 5, 88, 0, 56, 3, 23, 
    4, 59, 6, 98, 7, 51, 2, 69, 0, 10, 3, 99, 8, 54, 1, 97, 5, 67, 
    6, 20, 1, 60, 7, 22, 4, 12, 5, 60, 8, 74, 0, 11, 3, 67, 2, 30, 
    0, 52, 1,  3, 7, 63, 5, 72, 3, 27, 6,  8, 4, 66, 8, 87, 2, 65, 
    2, 83, 3, 77, 4, 92, 8, 14, 1,  9, 7, 82, 5,  9, 6, 64, 0, 10, 
    8, 93, 4,  4, 0, 38, 6, 65, 1, 31, 2, 57, 7, 96, 3, 60, 5, 81, 
    3,  1, 7, 92, 8, 49, 5, 68, 2, 21, 0, 53, 4, 62, 6, 21, 1, 13, 
    0, 41, 8, 97, 7, 91, 5, 28, 2, 59, 3, 60, 6, 43, 4, 63, 1, 63
  };
  const int q8987[] = {
    9, 9, // Number of jobs and machines
    0, 43, 7, 19, 8,  9, 1, 63, 3, 44, 5, 55, 6, 36, 2, 15, 4, 84, 
    7,  3, 4,  6, 8,  5, 5, 87, 1, 17, 6, 66, 2, 84, 0, 26, 3, 98, 
    3, 93, 4, 24, 0, 18, 6, 41, 1, 22, 5,  8, 8, 32, 7, 82, 2, 27, 
    1, 44, 0,  2, 4, 67, 2, 11, 8, 26, 6, 65, 7, 89, 3, 66, 5, 99, 
    6, 50, 5, 25, 0,  5, 3,  7, 2, 16, 1, 18, 4, 89, 7, 29, 8, 97, 
    4,  2, 6, 29, 2, 37, 8, 45, 1, 77, 5, 36, 0, 72, 7, 40, 3, 41, 
    0, 57, 1, 51, 4, 38, 8, 51, 7, 68, 3, 55, 5, 99, 6, 14, 2, 29, 
    5,  7, 8, 10, 3, 10, 2, 23, 0, 40, 7, 76, 1, 21, 6, 27, 4, 84, 
    6, 96, 4, 67, 0, 39, 3, 11, 8, 25, 7, 30, 1, 66, 5, 34, 2, 80
  };
  const int q8988[] = {
    9, 9, // Number of jobs and machines
    7, 30, 0, 87, 2, 57, 1, 18, 8, 99, 6, 47, 3, 99, 5, 83, 4, 34, 
    2, 20, 0, 62, 3,  5, 5, 12, 8, 25, 6,  6, 1, 75, 4, 96, 7, 22, 
    3, 72, 0, 71, 1,  5, 8, 20, 5, 33, 7, 65, 4,  7, 6, 30, 2, 51, 
    8, 17, 1, 86, 0, 43, 5, 28, 6, 77, 7, 30, 3, 67, 4, 95, 2, 89, 
    4, 65, 8, 73, 5, 49, 3, 26, 7, 54, 6, 37, 2, 22, 1, 83, 0, 89, 
    1, 64, 8, 10, 5, 22, 2, 96, 6, 37, 3, 51, 0, 76, 4, 94, 7, 74, 
    0, 46, 7, 75, 2, 74, 4, 93, 8, 28, 3, 22, 6, 91, 5, 55, 1, 56, 
    4,  2, 8, 85, 3, 42, 5, 69, 7, 74, 0, 21, 1, 92, 6, 53, 2, 39, 
    3, 26, 6, 63, 2, 25, 7, 94, 1, 80, 8, 92, 0, 91, 4,  7, 5, 51
  };
  const int q8989[] = {
    9, 9, // Number of jobs and machines
    1, 42, 7, 22, 0,  9, 6, 16, 8, 23, 4, 37, 5, 40, 3, 48, 2, 43, 
    7, 33, 0, 65, 5, 87, 4, 60, 2, 19, 1, 14, 3, 20, 8, 87, 6, 89, 
    3, 63, 1, 61, 7, 80, 4, 90, 8, 19, 5, 54, 2, 12, 0, 75, 6,  7, 
    1, 64, 0,  8, 8, 58, 6, 62, 5, 60, 2,  1, 3,  1, 7, 38, 4, 46, 
    8, 31, 2, 97, 3, 14, 6, 52, 5, 63, 4, 98, 0, 18, 1, 64, 7, 91, 
    7, 24, 1, 64, 3, 39, 0, 14, 4, 20, 5, 87, 2, 82, 6, 89, 8, 67, 
    5,  9, 0, 73, 1, 13, 3, 75, 2, 32, 6, 76, 7, 89, 8, 47, 4, 25, 
    4, 25, 0, 57, 5, 81, 8, 83, 3,  5, 7, 99, 6,  7, 1, 69, 2, 62, 
    4, 35, 7, 22, 1, 84, 2, 26, 5, 55, 6, 43, 8, 80, 0, 75, 3,  8
  };
  const int q8990[] = {
    9, 9, // Number of jobs and machines
    8, 32, 2, 78, 5, 10, 7, 80, 3, 72, 1, 89, 6, 35, 4, 43, 0, 78, 
    8, 62, 5, 71, 0, 26, 1, 86, 4, 84, 3, 93, 2, 45, 6, 75, 7, 41, 
    6, 41, 0, 29, 5, 42, 4, 83, 8, 33, 2, 98, 7, 83, 1, 60, 3, 16, 
    6, 52, 1, 68, 5, 31, 8, 41, 7, 63, 0, 65, 3, 57, 2,  3, 4, 45, 
    1, 14, 6, 72, 8, 55, 5, 79, 2, 19, 3, 52, 7, 41, 4, 83, 0, 28, 
    5, 89, 8, 66, 3, 99, 7, 57, 4, 81, 6, 12, 2, 38, 0, 87, 1, 34, 
    1, 10, 6, 91, 4, 62, 0, 38, 7, 71, 8, 21, 2, 19, 3, 67, 5, 31, 
    3, 46, 4, 90, 1, 79, 7, 13, 0, 51, 8, 73, 6, 75, 5, 15, 2, 98, 
    5, 20, 0, 13, 2, 59, 1, 70, 7, 55, 4, 96, 8, 50, 6, 67, 3,  4
  };
  const int q8991[] = {
    9, 9, // Number of jobs and machines
    2, 74, 3, 89, 0, 16, 8, 75, 7, 14, 6, 78, 1, 29, 5, 13, 4,  8, 
    2, 67, 4, 81, 8, 90, 6, 28, 3, 21, 1, 16, 0, 98, 5, 70, 7,  9, 
    5, 83, 6,  7, 1, 35, 7, 83, 2, 47, 0, 48, 8, 69, 4, 72, 3, 74, 
    1, 23, 2, 16, 7, 30, 8, 24, 4, 27, 6, 60, 5, 69, 0, 98, 3, 65, 
    7, 81, 2,  8, 4,  9, 8, 99, 1, 78, 5, 37, 3, 15, 0, 79, 6, 70, 
    5, 33, 3, 37, 8, 72, 0, 16, 4, 53, 7, 51, 1, 63, 6, 20, 2, 83, 
    6, 30, 8, 81, 2, 45, 0, 34, 5, 99, 1, 29, 4, 98, 7, 32, 3, 61, 
    0, 79, 5, 63, 4, 85, 6, 64, 1,  1, 2, 45, 3, 65, 7, 28, 8, 52, 
    7,  5, 0, 18, 1, 20, 3, 73, 8, 89, 2, 91, 6, 92, 5, 30, 4, 44
  };
  const int q8992[] = {
    9, 9, // Number of jobs and machines
    1, 82, 3, 74, 0, 71, 2, 75, 6, 73, 4, 57, 7, 24, 5, 18, 8, 99, 
    1, 15, 7, 33, 0, 37, 2, 76, 5, 54, 3, 75, 6, 96, 4, 58, 8, 86, 
    6, 87, 5, 81, 8, 44, 4, 76, 1, 29, 7, 64, 2,  3, 3, 48, 0, 52, 
    0, 66, 2, 90, 3, 12, 5, 33, 4, 46, 8,  9, 1, 66, 6, 80, 7, 41, 
    5, 30, 6, 12, 1, 23, 4, 39, 7, 14, 3, 81, 8, 72, 2, 24, 0, 13, 
    6, 42, 5, 45, 8, 34, 7,  9, 4, 41, 3, 40, 2, 76, 0, 24, 1, 67, 
    7, 16, 6, 78, 4, 42, 8, 58, 1, 74, 0, 19, 5, 10, 3, 55, 2, 86, 
    8, 54, 6, 10, 5, 41, 3, 48, 2, 72, 1, 77, 7, 77, 0, 73, 4, 92, 
    4, 16, 8, 77, 1, 45, 6, 76, 7,  7, 5, 70, 3, 98, 0, 64, 2, 10
  };
  const int q8993[] = {
    9, 9, // Number of jobs and machines
    0, 35, 2, 66, 5, 96, 3, 45, 7, 45, 4, 82, 6, 17, 8, 68, 1, 27, 
    7, 13, 2, 86, 1, 39, 0, 62, 6, 32, 4, 40, 8, 63, 5, 91, 3, 11, 
    5, 49, 3, 67, 2, 42, 6, 51, 7,  1, 4, 98, 8, 92, 1, 26, 0, 47, 
    6, 97, 2, 38, 3, 82, 8, 54, 1, 38, 0,  8, 4, 81, 5, 60, 7,  1, 
    5, 40, 2, 84, 0, 71, 8, 32, 6, 31, 3, 36, 4, 61, 7, 51, 1, 66, 
    8, 25, 6, 76, 4, 98, 0, 79, 7, 19, 3, 14, 5, 59, 1, 47, 2,  8, 
    5, 55, 1,  5, 0,  1, 3, 51, 8,  3, 7, 63, 6, 20, 4,  1, 2, 32, 
    3, 21, 4, 28, 2, 19, 5, 87, 1, 11, 0, 51, 8, 53, 6, 44, 7, 98, 
    0, 24, 1, 11, 4, 68, 6, 67, 3, 12, 2, 41, 7, 36, 8, 62, 5, 97
  };
  const int q8994[] = {
    9, 9, // Number of jobs and machines
    3, 63, 5, 12, 0,  6, 2, 23, 1, 77, 7, 43, 8, 70, 6, 58, 4, 64, 
    2, 50, 3, 65, 5, 28, 6, 83, 7, 77, 4, 75, 8, 61, 1, 82, 0,  3, 
    1, 28, 5,  4, 4, 10, 6, 12, 2,  3, 8, 32, 7, 39, 3, 65, 0,  1, 
    1, 56, 7, 27, 5, 67, 8, 84, 0, 75, 3, 19, 4, 13, 6, 36, 2, 23, 
    7, 88, 8, 31, 1, 99, 5, 58, 0,  7, 6, 31, 3, 70, 4, 75, 2, 60, 
    7, 93, 3, 66, 1, 31, 5, 31, 4, 17, 0, 59, 2, 64, 8, 57, 6, 26, 
    7, 43, 2,  1, 4, 78, 8, 13, 3, 14, 1,  4, 5, 67, 0, 29, 6, 51, 
    1, 32, 8, 51, 3, 87, 4, 85, 0, 81, 5, 88, 2, 83, 7,  4, 6, 29, 
    1, 52, 5,  5, 8, 69, 0, 52, 6, 40, 4, 13, 7, 57, 3, 15, 2, 89
  };
  const int q8995[] = {
    9, 9, // Number of jobs and machines
    6, 12, 7, 35, 8, 31, 4, 19, 1, 94, 0, 72, 2, 76, 3, 41, 5, 55, 
    7, 33, 2,  5, 0, 76, 4, 52, 6, 61, 8, 73, 1, 83, 5, 98, 3, 91, 
    0, 66, 6, 29, 1, 19, 2, 28, 4, 66, 5, 99, 7, 47, 8, 62, 3, 31, 
    4, 35, 6, 77, 5, 29, 8, 99, 2, 73, 0, 21, 1, 65, 3, 14, 7, 67, 
    1, 39, 5, 69, 2,  2, 8, 46, 4, 78, 6, 49, 7, 71, 0, 66, 3, 85, 
    2, 50, 7, 24, 1, 19, 3, 68, 6, 38, 5, 69, 4, 89, 0, 72, 8, 92, 
    5, 36, 3, 52, 0, 40, 6, 19, 8, 94, 7, 40, 2, 41, 1, 12, 4, 12, 
    2, 35, 6, 93, 1, 60, 3, 87, 7, 34, 4, 85, 8, 51, 5, 15, 0, 34, 
    5, 60, 7, 60, 1,  2, 2, 21, 0, 63, 8, 35, 3,  7, 4, 93, 6, 98
  };
  const int q8996[] = {
    9, 9, // Number of jobs and machines
    7, 55, 0, 75, 1, 93, 6, 58, 3, 42, 5, 73, 4, 76, 8, 77, 2, 34, 
    4, 26, 8, 42, 0, 53, 5, 77, 6, 33, 3, 66, 1,  1, 7, 84, 2, 50, 
    0, 96, 4, 76, 2,  7, 7, 77, 3, 46, 8, 30, 1, 28, 6, 66, 5, 50, 
    3, 15, 7, 99, 0, 87, 2, 35, 5, 22, 6,  1, 8, 40, 4, 83, 1, 80, 
    2, 11, 3, 73, 6, 93, 0, 55, 4, 50, 8, 92, 1, 77, 5, 50, 7, 13, 
    2, 71, 5, 81, 4, 85, 0, 33, 3, 75, 1, 32, 7, 91, 8, 95, 6, 37, 
    2, 70, 4, 55, 1, 35, 5, 61, 3, 82, 0, 19, 8, 11, 6, 17, 7, 75, 
    4, 70, 1, 76, 2, 16, 3, 53, 0, 82, 6, 20, 8, 79, 5,  2, 7, 75, 
    1, 31, 0, 11, 6, 24, 4, 68, 2, 89, 5, 19, 8, 79, 7, 45, 3, 86
  };
  const int q8997[] = {
    9, 9, // Number of jobs and machines
    2, 55, 0, 86, 3,  5, 4, 84, 8, 91, 1, 73, 6, 51, 5, 35, 7, 25, 
    6, 47, 4, 55, 8, 41, 0, 43, 7, 39, 5, 78, 3, 93, 1, 89, 2, 74, 
    8, 91, 2, 25, 4, 61, 5, 88, 1, 75, 0, 48, 6, 49, 7, 76, 3, 90, 
    0,  7, 6, 46, 8, 25, 2, 21, 4, 55, 7, 81, 5, 65, 1, 17, 3, 15, 
    5, 15, 4, 84, 2, 65, 6, 34, 0, 11, 7, 29, 3, 38, 8, 81, 1, 98, 
    3, 17, 7, 65, 6, 60, 0, 29, 2, 57, 8, 12, 1, 26, 5, 67, 4, 59, 
    3, 50, 5, 79, 6, 16, 2, 29, 4, 75, 1, 17, 0, 59, 7, 54, 8,  4, 
    8, 95, 7, 35, 1, 84, 6, 72, 3, 19, 2, 30, 5, 77, 4, 94, 0, 39, 
    3, 39, 0, 81, 4, 16, 8, 41, 5, 64, 6, 87, 2, 60, 7, 75, 1, 56
  };
  const int q8998[] = {
    9, 9, // Number of jobs and machines
    6, 67, 0, 62, 7, 82, 2, 29, 4, 10, 5, 60, 1, 94, 8, 66, 3, 65, 
    2, 16, 1, 39, 6, 91, 0, 68, 4, 69, 7, 61, 5, 21, 8, 85, 3, 64, 
    4, 34, 6, 71, 7, 77, 3, 38, 1,  5, 0, 58, 2, 20, 5, 13, 8, 15, 
    5, 16, 8, 48, 3, 84, 0, 41, 1, 34, 6, 89, 7, 54, 4, 99, 2, 38, 
    1, 50, 4, 69, 6,  6, 7,  4, 0, 65, 3, 55, 8, 52, 5, 47, 2, 15, 
    4, 58, 6, 66, 5, 77, 1, 85, 3, 12, 0, 10, 7, 45, 2,  8, 8, 85, 
    1, 40, 8, 66, 0, 26, 3, 89, 4,  5, 7,  6, 2, 55, 5, 79, 6, 89, 
    3,  9, 8, 34, 0, 30, 6, 19, 5, 86, 2, 52, 4, 99, 1,  9, 7, 40, 
    5, 62, 7, 71, 8, 11, 4, 19, 1, 95, 2, 63, 3, 20, 6,  2, 0, 56
  };
  const int q8999[] = {
    9, 9, // Number of jobs and machines
    7, 23, 1, 48, 6, 80, 3, 85, 8, 37, 4, 49, 0, 38, 2,  7, 5, 42, 
    0, 99, 1, 45, 8, 43, 7, 50, 3, 48, 5, 32, 6, 83, 4, 37, 2, 82, 
    6, 72, 0, 94, 3, 91, 1, 80, 5,  3, 8, 22, 7, 69, 4, 98, 2, 84, 
    4, 29, 0, 39, 1, 94, 2, 95, 5, 73, 7, 12, 6, 20, 8, 87, 3, 64, 
    5, 86, 1, 26, 6, 31, 3, 28, 0, 70, 4, 36, 2, 28, 8, 16, 7, 75, 
    3,  7, 2, 63, 8, 12, 4, 50, 0, 75, 1, 17, 6, 94, 7, 63, 5, 69, 
    6, 84, 8, 84, 5, 64, 1, 85, 4, 81, 7, 30, 0, 96, 2,  4, 3, 82, 
    7, 40, 6, 85, 3, 68, 8,  9, 4, 61, 5, 67, 2, 85, 1, 98, 0, 21, 
    7, 11, 3, 64, 6, 50, 1, 42, 4, 18, 0, 36, 2, 75, 5, 19, 8, 30
  };
  const int q9000[] = {
    9, 9, // Number of jobs and machines
    5, 90, 2,  8, 8, 69, 6, 95, 1, 46, 0, 60, 3, 17, 7, 18, 4, 68, 
    3, 47, 1, 90, 8, 88, 6, 37, 7, 13, 2, 83, 5, 72, 0, 88, 4, 28, 
    6, 74, 8, 28, 3, 17, 7, 53, 4, 83, 1,  4, 2, 10, 5, 22, 0, 99, 
    0, 56, 7, 29, 4,  1, 2, 15, 6,  3, 3, 98, 5, 48, 8, 10, 1, 81, 
    7, 54, 3, 89, 0, 74, 4, 56, 2, 28, 1,  7, 6, 14, 5, 57, 8,  5, 
    6, 84, 8, 22, 4, 31, 0, 93, 5, 35, 3, 52, 2, 46, 1, 82, 7,  2, 
    7, 17, 1, 60, 0, 65, 5, 42, 8, 36, 3, 30, 2, 85, 6, 89, 4, 99, 
    0, 37, 2, 24, 3, 35, 8,  1, 1, 82, 5, 98, 4, 89, 7, 36, 6, 11, 
    3, 56, 2, 56, 7, 64, 0, 99, 4, 79, 5, 42, 6, 36, 8, 81, 1, 65
  };
  const int q9001[] = {
    9, 9, // Number of jobs and machines
    3, 82, 5, 83, 1, 55, 0, 84, 2,  5, 6, 91, 8, 80, 7, 46, 4, 43, 
    3, 53, 2, 40, 8,  2, 4,  7, 6, 92, 7, 90, 0, 46, 5, 44, 1,  1, 
    2, 29, 6, 23, 7, 79, 3, 50, 8, 63, 1, 69, 4, 78, 5, 56, 0, 37, 
    1, 95, 2, 28, 6, 75, 8, 29, 0, 94, 3, 62, 7, 79, 5,  3, 4, 72, 
    4, 44, 8, 97, 7, 59, 3, 64, 1, 72, 5, 66, 6, 49, 0, 82, 2, 85, 
    0, 86, 2, 90, 8, 47, 1, 14, 7, 16, 4, 67, 3, 97, 6, 89, 5, 58, 
    0, 64, 7, 96, 1, 93, 2, 89, 8, 43, 4, 52, 3, 76, 6,  8, 5,  6, 
    6, 87, 0,  4, 4, 96, 3, 15, 7, 17, 2, 70, 5, 68, 1, 34, 8, 27, 
    6, 16, 7, 48, 1,  9, 8, 24, 3, 33, 2, 16, 4, 82, 5, 83, 0, 40
  };
  const int q9002[] = {
    9, 9, // Number of jobs and machines
    1, 17, 3, 65, 5, 40, 6, 69, 2, 40, 8, 97, 7,  1, 4, 44, 0, 25, 
    1, 49, 6, 73, 4, 97, 2, 40, 7, 91, 8, 57, 0, 70, 3, 12, 5, 25, 
    7, 95, 5, 65, 4, 65, 6, 83, 3,  9, 0, 48, 8, 90, 2, 16, 1, 51, 
    0,  7, 1, 90, 8,  5, 4, 97, 6, 90, 3, 34, 2, 76, 7, 46, 5,  8, 
    2, 68, 5, 54, 0, 95, 1, 77, 3, 65, 7, 41, 6, 87, 8, 68, 4, 82, 
    0, 10, 3, 95, 6, 76, 2, 76, 8, 61, 4, 14, 7, 41, 5, 34, 1, 75, 
    8, 95, 5, 30, 7, 70, 4, 53, 1, 96, 6, 60, 2, 19, 0, 97, 3, 66, 
    3,  4, 7, 13, 0, 54, 1, 39, 4, 55, 6, 10, 2, 40, 5, 26, 8, 69, 
    6, 82, 2, 14, 8, 92, 7, 69, 5, 18, 1, 90, 3, 37, 0, 75, 4, 20
  };
  const int q9003[] = {
    9, 9, // Number of jobs and machines
    8,  6, 2, 97, 1, 42, 4, 68, 5, 17, 6, 65, 3, 61, 7, 46, 0, 34, 
    8, 11, 0, 42, 1, 85, 5, 82, 6, 46, 2, 64, 3, 68, 7, 40, 4, 57, 
    8, 32, 7, 96, 3, 42, 2, 99, 5, 15, 4, 58, 1, 41, 0, 63, 6, 24, 
    4, 99, 5, 87, 8, 50, 6, 60, 1, 91, 0, 47, 7, 17, 2, 41, 3,  1, 
    8, 25, 7, 94, 2, 25, 3, 76, 4, 93, 6, 35, 1, 20, 5, 89, 0, 35, 
    6, 61, 3, 86, 7, 20, 8, 32, 4, 69, 2, 67, 5, 20, 0, 20, 1, 14, 
    8, 40, 2, 63, 3, 77, 5, 61, 4, 59, 1, 65, 7, 97, 6, 35, 0,  4, 
    2, 54, 4, 83, 8, 12, 6, 85, 5, 59, 1, 87, 0, 76, 7, 18, 3, 73, 
    7, 49, 6, 33, 3, 33, 1, 57, 5,  3, 8, 82, 2, 39, 0, 10, 4,  8
  };
  const int q9004[] = {
    9, 9, // Number of jobs and machines
    2,  8, 3, 73, 4, 54, 5, 43, 8, 53, 1,  2, 7, 45, 6, 97, 0, 79, 
    2, 18, 0, 32, 7, 29, 3, 57, 1,  8, 4, 31, 6,  1, 5, 53, 8, 92, 
    2, 24, 4, 56, 1, 47, 3, 57, 7, 74, 5, 64, 0, 95, 6, 33, 8, 26, 
    6, 98, 5, 54, 8, 61, 7, 34, 4, 24, 0, 78, 2,  6, 3, 65, 1, 96, 
    1, 69, 4,  1, 7, 51, 8, 81, 5,  8, 6, 12, 2, 88, 0, 29, 3, 45, 
    0, 40, 2, 37, 3, 84, 8, 70, 5, 65, 1, 18, 7, 48, 4, 60, 6, 99, 
    6, 76, 2, 50, 7,  1, 0, 60, 8, 92, 3,  4, 4, 43, 5, 16, 1, 10, 
    8, 18, 5, 19, 3, 22, 6, 10, 0, 88, 4, 95, 7, 90, 1, 84, 2, 35, 
    3, 25, 7, 47, 6, 20, 5, 39, 4, 78, 0,  9, 8, 84, 2, 86, 1, 77
  };
  const int q9005[] = {
    9, 9, // Number of jobs and machines
    6, 50, 1,  8, 4, 62, 3, 95, 5, 96, 7,  1, 0,  8, 2, 80, 8, 54, 
    5, 43, 2, 18, 7, 24, 8, 55, 0, 29, 6, 65, 4, 82, 3, 89, 1, 42, 
    2, 76, 5, 50, 0, 35, 1, 45, 3, 73, 4, 69, 8, 80, 6, 12, 7, 19, 
    3, 39, 8, 65, 6, 44, 7, 39, 4, 29, 1, 51, 5,  9, 0, 99, 2, 59, 
    2, 95, 5, 58, 4, 25, 3, 95, 6, 81, 0, 81, 1, 29, 8,  5, 7, 93, 
    7, 15, 3, 13, 0, 15, 2, 37, 1, 54, 5, 41, 4, 59, 6, 32, 8, 76, 
    0, 89, 5, 60, 3, 57, 6, 33, 2, 47, 8, 45, 1, 24, 7, 11, 4, 44, 
    1, 88, 3,  7, 4, 86, 8, 12, 7, 58, 0, 50, 2, 92, 5, 31, 6, 38, 
    6, 70, 0, 57, 1, 89, 2, 84, 8, 62, 5, 81, 3, 33, 4, 30, 7, 50
  };
  const int q9006[] = {
    9, 9, // Number of jobs and machines
    1, 27, 0, 21, 3, 19, 5, 66, 8,  1, 7, 72, 4, 85, 2, 93, 6, 20, 
    1, 86, 3,  4, 2, 35, 4, 12, 0, 78, 7, 16, 6, 42, 5, 47, 8, 49, 
    7, 53, 2, 61, 4, 12, 6, 44, 0, 63, 5, 59, 8, 12, 1, 18, 3,  5, 
    0,  5, 8, 94, 2, 93, 6, 12, 1, 81, 3, 53, 4, 11, 7, 25, 5, 76, 
    6,  7, 2, 49, 1, 42, 4, 44, 0, 98, 5,  6, 3, 60, 8, 54, 7,  1, 
    6, 67, 4, 32, 2, 40, 5, 96, 1, 66, 8, 57, 7, 53, 0, 59, 3, 60, 
    1,  2, 6, 82, 4, 25, 5, 52, 8, 69, 2,  3, 7, 96, 0, 13, 3,  9, 
    2, 33, 4, 86, 6, 58, 3, 56, 8, 60, 5, 84, 1, 67, 0, 62, 7, 52, 
    6, 43, 7, 29, 4, 61, 1, 45, 3, 58, 2, 33, 5, 27, 8, 73, 0, 33
  };
  const int q9007[] = {
    9, 9, // Number of jobs and machines
    4, 34, 2,  9, 5, 34, 0, 57, 3, 63, 1, 75, 6, 21, 8,  5, 7, 97, 
    1, 44, 8, 63, 4, 50, 7, 81, 2,  1, 3, 71, 6, 75, 5, 32, 0, 34, 
    0, 62, 6, 52, 7, 66, 1, 36, 3, 97, 4, 51, 5, 41, 8,  7, 2, 16, 
    8, 53, 2,  3, 3, 38, 7, 69, 6,  6, 5, 92, 1, 14, 0, 90, 4, 14, 
    8, 74, 2, 19, 7, 13, 4,  2, 5, 40, 6, 90, 0, 49, 1,  7, 3, 50, 
    6, 42, 5, 99, 2, 32, 4, 12, 0, 58, 1, 53, 3, 65, 7, 40, 8, 51, 
    4, 91, 8, 97, 0, 82, 7, 43, 1, 21, 6, 16, 2, 49, 3,  4, 5, 90, 
    0, 13, 5, 89, 4, 22, 8, 35, 3, 93, 2, 56, 1, 37, 6, 67, 7, 35, 
    3, 20, 0, 79, 8, 18, 5, 73, 1, 59, 2,  9, 4, 26, 6,  1, 7, 70
  };
  const int q9008[] = {
    9, 9, // Number of jobs and machines
    7, 43, 2, 69, 6, 89, 3, 16, 5,  4, 8, 32, 1, 35, 4, 35, 0, 40, 
    2, 24, 3, 11, 4, 23, 7, 74, 0, 56, 8, 11, 5, 33, 6, 32, 1, 54, 
    1, 30, 8, 11, 2, 96, 7,  5, 5, 23, 6, 51, 4, 95, 0, 38, 3,  9, 
    4, 29, 3, 10, 5, 98, 1, 33, 7, 48, 0, 75, 8, 78, 2, 94, 6, 46, 
    7, 43, 2, 68, 8, 15, 6, 75, 3, 50, 0,  3, 5, 16, 1,  9, 4, 31, 
    4,  4, 6, 58, 7, 86, 5, 66, 0, 25, 3, 41, 1,  4, 8, 78, 2,  5, 
    8, 53, 3, 38, 2, 68, 1, 10, 7, 58, 0,  1, 4, 60, 5, 22, 6, 21, 
    6,  2, 1, 13, 5, 78, 4, 29, 2, 48, 0, 38, 8, 67, 7, 14, 3, 32, 
    2,  4, 3, 16, 7, 76, 8,  6, 1, 10, 6, 56, 4, 51, 0, 41, 5, 33
  };
  const int q9009[] = {
    9, 9, // Number of jobs and machines
    3, 35, 5, 14, 6, 86, 1, 18, 0, 24, 7, 15, 2, 70, 8, 57, 4, 71, 
    7, 36, 0, 87, 6, 61, 2, 41, 3, 10, 8, 78, 5, 61, 4, 76, 1, 13, 
    8, 79, 2, 23, 1, 27, 0, 58, 6, 77, 3, 77, 5, 50, 7, 80, 4, 41, 
    0, 72, 3, 49, 6,  7, 5, 50, 7, 13, 2, 73, 1, 77, 4, 55, 8, 58, 
    0, 13, 8, 70, 7, 55, 5,  1, 3,  4, 2, 81, 4, 66, 6, 80, 1, 24, 
    0, 86, 6, 87, 2, 94, 4, 60, 5, 85, 7, 58, 1, 94, 3, 77, 8, 58, 
    3, 35, 5, 69, 6, 20, 8, 18, 4, 16, 0, 74, 1, 91, 2, 53, 7, 36, 
    1, 84, 5, 56, 0, 93, 6, 19, 2, 85, 3,  6, 8, 33, 4, 65, 7, 57, 
    8, 78, 4, 14, 1, 66, 3, 24, 7, 69, 2, 96, 6, 44, 0, 22, 5, 23
  };
  const int q9010[] = {
    9, 9, // Number of jobs and machines
    1, 66, 5, 63, 8, 56, 7, 58, 6, 44, 0, 17, 2, 88, 3, 80, 4, 70, 
    1, 20, 6, 99, 5, 84, 8, 62, 7, 68, 3, 79, 2, 36, 4, 99, 0, 94, 
    0, 29, 8, 19, 1, 23, 2, 23, 6, 79, 7, 73, 4, 80, 5, 78, 3, 83, 
    6, 34, 7, 49, 8, 62, 4, 26, 3, 93, 0, 30, 5, 90, 2, 93, 1, 59, 
    4, 98, 5, 98, 1, 70, 6, 46, 0, 73, 7, 85, 2, 88, 8, 61, 3, 39, 
    7, 90, 0, 23, 6, 49, 4, 31, 5, 68, 8, 77, 1, 93, 3, 93, 2, 97, 
    6,  8, 8, 66, 3, 23, 7, 59, 4,  5, 2, 11, 1, 70, 5, 73, 0, 28, 
    0, 12, 2, 81, 8, 50, 1, 49, 4, 44, 6,  1, 5, 45, 7, 32, 3, 45, 
    2, 36, 7, 22, 8,  2, 3, 76, 6, 53, 5, 28, 1, 65, 0, 44, 4, 22
  };
  const int q9011[] = {
    9, 9, // Number of jobs and machines
    5, 83, 3, 95, 7, 18, 6, 69, 4, 76, 8, 71, 0, 59, 2, 75, 1, 14, 
    3, 29, 5, 91, 1, 43, 4, 77, 8, 26, 6, 49, 0, 24, 7, 99, 2, 45, 
    7, 56, 2, 27, 6, 58, 3, 93, 1,  8, 8, 42, 4,  8, 5, 10, 0, 62, 
    7, 55, 2, 76, 6, 58, 4, 36, 5, 91, 0, 49, 3,  9, 8, 25, 1, 98, 
    8, 64, 7, 54, 1, 99, 3, 76, 6, 51, 5, 59, 4, 70, 0, 88, 2,  9, 
    0, 77, 6, 72, 4, 42, 1, 45, 2, 85, 8,  7, 7, 19, 5, 96, 3, 86, 
    4, 83, 7, 65, 1,  7, 3, 74, 6, 99, 0, 57, 2, 45, 8, 74, 5, 76, 
    0, 41, 3, 49, 2, 49, 8,  1, 6, 45, 1, 65, 7, 33, 5,  7, 4, 25, 
    5, 28, 8, 86, 2, 30, 0, 47, 3, 13, 6, 46, 4,  2, 1, 64, 7, 46
  };
  const int q9012[] = {
    9, 9, // Number of jobs and machines
    0, 39, 6, 26, 7, 63, 5, 44, 4, 38, 3,  5, 8, 38, 1, 22, 2, 17, 
    2, 85, 6,  2, 3, 74, 7, 12, 0, 28, 1, 64, 4, 52, 5, 43, 8, 30, 
    7, 48, 8, 90, 0, 78, 4, 93, 1, 30, 5, 80, 6, 45, 2, 89, 3, 52, 
    4, 87, 1, 77, 6, 67, 0,  9, 8, 64, 2,  5, 3, 23, 7,  2, 5, 26, 
    5,  9, 8, 25, 3, 13, 7,  9, 2, 62, 6, 22, 1, 85, 4, 62, 0, 98, 
    7, 53, 4, 96, 1, 79, 5, 67, 6, 23, 2, 50, 8, 24, 0, 29, 3, 75, 
    7, 41, 1, 95, 8, 92, 4, 79, 5, 90, 0, 63, 2, 32, 6, 65, 3, 61, 
    1, 99, 4, 80, 6, 40, 7, 43, 2, 99, 8, 21, 0, 98, 3, 93, 5, 66, 
    6, 93, 7, 20, 8, 81, 3, 24, 5, 52, 2, 99, 0, 33, 4, 88, 1,  4
  };
  const int q9013[] = {
    9, 9, // Number of jobs and machines
    3, 83, 6,  4, 4, 62, 0, 99, 5, 22, 7, 69, 2, 27, 1, 14, 8, 80, 
    2, 64, 1,  4, 6, 77, 0, 60, 7, 28, 3, 36, 5, 39, 4, 92, 8, 43, 
    1, 91, 4, 67, 5, 87, 7, 65, 3, 83, 2,  5, 6, 92, 0, 87, 8,  6, 
    5, 90, 0, 61, 1, 77, 8,  6, 6, 14, 4, 36, 7, 68, 2, 41, 3, 14, 
    8, 32, 5, 19, 0, 44, 4, 61, 3, 33, 6, 82, 2, 90, 1, 96, 7,  3, 
    1, 33, 3, 10, 2,  2, 8, 77, 6,  8, 5, 99, 0, 38, 7, 82, 4, 93, 
    2,  1, 5, 86, 3, 25, 4, 81, 8,  1, 6, 52, 1, 77, 0, 99, 7, 65, 
    8, 74, 1, 62, 5, 11, 4, 99, 7, 34, 6, 42, 3, 84, 0, 58, 2, 49, 
    1, 52, 7, 88, 3, 99, 4, 34, 5, 85, 8, 39, 2, 17, 6, 39, 0, 28
  };
  const int q9014[] = {
    9, 9, // Number of jobs and machines
    6, 27, 1, 21, 7, 66, 5, 70, 8, 61, 3, 98, 4, 21, 0, 71, 2, 46, 
    1, 24, 2, 90, 8,  9, 5, 10, 7, 41, 6, 29, 4, 60, 3, 19, 0, 46, 
    4,  2, 2, 45, 8, 17, 5, 43, 1, 59, 0, 97, 3, 86, 6, 23, 7, 46, 
    2, 41, 1,  9, 8, 31, 4,  3, 3, 44, 6, 95, 7, 10, 5, 41, 0, 77, 
    5, 54, 6, 76, 1, 65, 2, 27, 7, 26, 4, 83, 8, 41, 3,  6, 0, 76, 
    3, 74, 4, 82, 0, 32, 6, 41, 1, 39, 8, 72, 7, 90, 5, 65, 2, 25, 
    3, 51, 6, 78, 8, 11, 4,  5, 2, 21, 1, 42, 7, 39, 5, 94, 0, 36, 
    0, 72, 5, 57, 7, 24, 3, 77, 4,  7, 2, 71, 8, 54, 1, 49, 6, 77, 
    4, 68, 0, 23, 1, 68, 6, 36, 2, 13, 5, 15, 7, 20, 3, 75, 8, 72
  };
  const int q9015[] = {
    9, 9, // Number of jobs and machines
    4, 43, 0, 65, 3, 76, 2, 68, 6, 10, 7, 42, 8, 21, 5,  1, 1, 13, 
    3, 97, 7, 33, 5, 15, 8, 95, 2, 51, 6, 59, 0, 67, 1, 60, 4,  1, 
    1, 18, 7, 70, 6, 45, 4, 14, 5,  6, 8, 20, 0,  7, 2, 22, 3, 33, 
    7,  1, 8,  8, 3, 35, 5, 83, 0, 70, 6, 13, 2, 84, 4, 74, 1, 21, 
    3, 48, 2, 74, 5, 33, 7,  5, 0, 48, 4, 79, 1, 22, 6, 47, 8, 20, 
    7, 24, 8, 21, 4, 96, 1, 55, 3, 91, 0, 31, 2, 45, 6, 51, 5, 96, 
    2, 89, 8, 16, 4, 68, 0,  3, 7, 36, 6, 39, 3, 93, 5, 41, 1, 53, 
    2, 32, 7, 82, 6, 90, 4, 21, 8, 86, 3, 25, 0,  5, 5,  8, 1, 78, 
    4, 72, 0, 94, 8, 16, 7, 31, 3, 51, 5, 14, 1, 53, 6, 97, 2, 62
  };
  const int q9016[] = {
    9, 9, // Number of jobs and machines
    8, 37, 0,  9, 1, 75, 3, 17, 6, 44, 4, 97, 2, 88, 7, 21, 5, 78, 
    6, 47, 3, 51, 4,  6, 5, 79, 2, 35, 0, 57, 7, 93, 8,  8, 1, 62, 
    1, 57, 8, 90, 4, 38, 6, 14, 0, 40, 5, 69, 2, 68, 3, 89, 7, 40, 
    5,  3, 8, 10, 4, 26, 0,  9, 2, 65, 1, 81, 6, 61, 7, 62, 3, 48, 
    4, 39, 2, 35, 5, 86, 7, 47, 8, 19, 1, 75, 0, 32, 6, 94, 3, 54, 
    8, 35, 3, 19, 0,  9, 1, 42, 2, 87, 7, 89, 6, 17, 5, 63, 4, 98, 
    8, 49, 4, 66, 7, 16, 6, 42, 0, 37, 1, 85, 3,  1, 5, 78, 2, 52, 
    8, 58, 3, 44, 7, 64, 6, 75, 1, 18, 4, 12, 2, 58, 0, 49, 5, 28, 
    5, 97, 6, 82, 4, 12, 1, 84, 7, 33, 0, 31, 8, 55, 2, 72, 3, 26
  };
  const int q9017[] = {
    9, 9, // Number of jobs and machines
    3, 25, 8, 67, 0, 76, 6, 99, 4, 86, 1, 51, 7, 97, 2,  4, 5, 79, 
    5, 72, 0, 88, 3, 76, 8, 16, 6, 50, 2, 65, 7, 72, 4,  4, 1, 48, 
    1, 78, 0,  9, 7, 52, 5, 64, 2, 35, 8, 81, 4, 78, 3, 16, 6, 40, 
    2,  8, 7, 66, 0, 34, 6, 40, 4, 63, 3, 27, 1, 52, 8, 80, 5, 71, 
    4, 60, 7, 81, 5,  2, 8, 39, 2, 38, 3, 82, 0, 46, 1, 50, 6, 26, 
    4, 80, 0, 38, 8, 87, 5, 15, 2, 98, 6, 61, 7, 32, 3, 31, 1, 21, 
    0,  5, 5, 21, 2, 26, 1, 52, 4, 92, 3, 98, 8, 61, 6, 74, 7, 67, 
    2, 11, 0, 39, 8,  8, 6, 15, 1, 57, 7, 70, 4, 40, 3, 33, 5,  1, 
    1, 85, 4, 41, 6, 78, 0, 60, 3, 15, 5,  3, 8, 60, 7, 33, 2,  1
  };
  const int q9018[] = {
    9, 9, // Number of jobs and machines
    0, 55, 4, 80, 2, 22, 6, 39, 5, 90, 3, 99, 7, 60, 8, 84, 1, 86, 
    5, 71, 3, 99, 0, 19, 4, 14, 7, 60, 6, 62, 8, 11, 1, 69, 2,  5, 
    1, 77, 7, 33, 5, 18, 3, 26, 4, 52, 6, 34, 2, 56, 8,  6, 0, 23, 
    7, 47, 3, 67, 1, 53, 4, 79, 6, 45, 0, 54, 2, 66, 8, 32, 5, 90, 
    2, 10, 5, 89, 0, 34, 7, 48, 3, 86, 8, 26, 6, 86, 1, 49, 4, 75, 
    1, 33, 7,  3, 4, 30, 0, 44, 6, 18, 8, 27, 3, 38, 5, 17, 2, 14, 
    6, 74, 1, 54, 5, 96, 7, 76, 8, 77, 3, 79, 2, 84, 0, 64, 4, 68, 
    3, 49, 6,  7, 2, 96, 1, 90, 7, 71, 8, 38, 0, 94, 5, 22, 4, 75, 
    4, 22, 0, 43, 1, 74, 5, 27, 6, 22, 7, 51, 8, 48, 2, 10, 3, 48
  };
  const int q9019[] = {
    9, 9, // Number of jobs and machines
    0, 91, 1, 26, 4, 80, 8, 73, 2, 21, 6,  7, 5, 70, 3, 57, 7, 81, 
    0, 90, 4, 30, 8, 81, 7, 39, 1, 55, 2, 22, 5, 16, 6, 90, 3, 14, 
    6, 55, 8, 52, 5, 45, 7, 46, 0, 73, 2, 80, 3, 51, 1, 92, 4, 32, 
    7,  8, 2, 33, 1, 78, 8, 88, 3, 33, 6, 71, 0, 15, 4, 63, 5, 14, 
    6, 14, 7, 16, 8, 11, 1, 71, 0, 30, 4, 19, 2, 52, 5, 44, 3, 54, 
    5, 98, 2, 61, 3, 20, 1, 13, 0, 83, 6, 17, 8, 85, 7, 89, 4, 94, 
    8, 87, 2, 29, 3,  2, 0, 26, 5, 83, 4, 65, 6, 57, 1, 54, 7, 81, 
    1, 26, 5, 66, 7, 73, 0, 47, 3, 27, 8, 87, 2, 77, 4, 91, 6, 14, 
    8, 80, 3, 81, 4, 65, 1, 75, 2, 89, 5, 22, 0, 55, 7, 64, 6, 19
  };
  const int q9020[] = {
    9, 9, // Number of jobs and machines
    3, 96, 7, 14, 1, 60, 2, 16, 0, 35, 8, 48, 5, 78, 6, 42, 4, 44, 
    6, 48, 2, 37, 4, 69, 8, 64, 7, 56, 0, 25, 5, 58, 3, 24, 1, 72, 
    8, 46, 6, 56, 5, 69, 1, 50, 0, 24, 3, 99, 2, 91, 4, 48, 7, 37, 
    3, 43, 4, 87, 0, 32, 8, 48, 1, 87, 6, 72, 2, 64, 7, 81, 5, 85, 
    0, 30, 2, 74, 1, 32, 7, 68, 4,  5, 5, 84, 3, 40, 8, 18, 6,  9, 
    5, 97, 7, 57, 4, 96, 2, 58, 8,  2, 3, 55, 1, 57, 6, 86, 0, 93, 
    3, 93, 6, 35, 1, 66, 0, 41, 7, 32, 2,  7, 4, 60, 8,  4, 5, 87, 
    4, 31, 6, 85, 3, 60, 7, 49, 0, 27, 8, 32, 1, 33, 2, 43, 5, 66, 
    6,  1, 7, 10, 4,  8, 2, 50, 1, 76, 0, 93, 8, 87, 3, 53, 5, 68
  };
  const int q9021[] = {
    9, 9, // Number of jobs and machines
    8, 76, 6, 92, 3, 15, 4, 92, 7, 93, 1, 98, 2, 68, 0, 15, 5, 77, 
    8, 76, 3, 81, 0, 62, 5, 71, 6, 70, 1, 88, 7, 34, 2, 71, 4, 15, 
    4, 13, 5, 32, 1, 96, 2, 14, 7, 50, 3, 91, 6, 75, 8, 71, 0, 84, 
    5, 48, 8, 95, 0, 17, 4, 30, 3, 56, 1, 87, 2, 71, 6, 78, 7, 73, 
    0, 78, 5, 16, 1, 16, 6, 53, 3, 62, 4, 87, 7, 13, 2, 96, 8,  1, 
    8, 44, 1, 63, 7, 33, 0, 11, 5, 35, 6, 48, 3, 96, 2, 90, 4,  3, 
    8, 98, 6, 19, 3,  2, 2, 29, 4, 85, 1, 40, 0, 87, 5, 58, 7, 24, 
    5, 56, 1, 12, 2, 27, 0, 21, 7, 96, 3, 64, 8, 71, 4, 69, 6, 87, 
    0,  8, 2, 35, 3, 37, 6, 17, 5, 77, 7, 74, 1,  5, 8, 42, 4, 72
  };
  const int q9022[] = {
    9, 9, // Number of jobs and machines
    5, 44, 0, 73, 8, 98, 2,  2, 1, 67, 7, 20, 4, 32, 3, 95, 6, 62, 
    5, 33, 4, 77, 1, 39, 0, 89, 7, 20, 6,  9, 2, 55, 3, 30, 8, 40, 
    8, 73, 7, 42, 2, 83, 1, 18, 0, 11, 4, 10, 6, 16, 3, 90, 5, 71, 
    8, 32, 1, 49, 5, 25, 7, 58, 2, 17, 6, 64, 3,  2, 4, 77, 0, 36, 
    7, 97, 3, 18, 2, 50, 1, 18, 6, 33, 4,  2, 0, 26, 5, 16, 8,  6, 
    6, 94, 5, 18, 2, 76, 4, 34, 7, 76, 1, 89, 0, 87, 8,  2, 3, 28, 
    1, 34, 3, 26, 8, 92, 5, 37, 4, 60, 7, 15, 2, 69, 6, 72, 0,  4, 
    6, 80, 0, 51, 1, 47, 3, 85, 2, 74, 8, 10, 5, 72, 7, 80, 4, 26, 
    6, 73, 8, 37, 4, 23, 7,  2, 1, 51, 2, 85, 3, 88, 0, 60, 5, 93
  };
  const int q9023[] = {
    9, 9, // Number of jobs and machines
    3, 57, 8,  7, 6, 70, 2, 96, 0, 78, 5, 38, 7, 44, 4, 41, 1, 37, 
    1, 39, 3, 16, 5, 97, 6, 83, 8, 32, 2, 37, 4, 52, 0, 47, 7, 14, 
    7,  1, 2, 82, 5, 69, 6, 26, 1, 11, 0, 56, 3, 17, 4, 92, 8,  1, 
    0, 21, 5, 15, 6, 20, 8, 73, 1, 84, 2, 28, 3, 66, 7, 46, 4,  5, 
    1,  7, 2, 24, 7, 88, 8, 62, 3, 22, 4, 16, 0, 25, 5, 57, 6, 91, 
    2, 32, 7, 64, 4, 25, 3, 88, 6, 15, 0, 11, 1, 40, 8, 81, 5, 36, 
    0, 95, 1, 92, 7,  8, 2, 67, 3,  7, 8,  6, 4, 29, 6, 94, 5, 87, 
    1, 30, 8, 79, 2, 93, 6, 64, 0, 71, 3, 13, 7, 31, 4, 98, 5, 29, 
    1, 17, 0, 49, 3, 11, 6, 98, 7, 87, 5, 89, 4, 67, 2, 33, 8, 11
  };
  const int q9024[] = {
    9, 9, // Number of jobs and machines
    1, 40, 5, 63, 7, 19, 4, 68, 8, 11, 6, 76, 2, 52, 3, 53, 0, 65, 
    2, 23, 7,  7, 3, 59, 1, 69, 6, 94, 4, 99, 0, 42, 8, 66, 5, 54, 
    0, 37, 4, 76, 3, 93, 1, 63, 6, 37, 5,  7, 8, 30, 2, 25, 7,  4, 
    8, 83, 0, 70, 3, 62, 6, 36, 5, 97, 1, 85, 4, 63, 7, 72, 2, 36, 
    2, 59, 6, 10, 0, 18, 4, 19, 7, 41, 1, 31, 3, 85, 8, 94, 5, 93, 
    5, 32, 3, 45, 0, 36, 2, 34, 6, 76, 7, 32, 4, 84, 1, 80, 8, 50, 
    5,  2, 8, 42, 3,  9, 6, 94, 0, 40, 7, 35, 1, 28, 4, 81, 2, 65, 
    5, 63, 1, 42, 0, 13, 2, 88, 4, 98, 8, 22, 3, 42, 6, 18, 7, 83, 
    3, 59, 7, 93, 0, 61, 4, 83, 5, 78, 2, 96, 6, 13, 1, 21, 8, 16
  };
  const int q9025[] = {
    9, 9, // Number of jobs and machines
    2, 13, 5, 83, 0, 16, 4, 74, 8, 33, 3, 43, 7, 47, 1, 96, 6,  8, 
    0, 46, 4, 78, 6, 90, 2, 43, 3, 97, 8, 45, 7, 29, 1, 86, 5, 32, 
    2, 34, 1, 58, 3, 77, 6,  7, 4, 41, 5, 26, 0, 49, 8, 44, 7, 17, 
    5, 98, 1, 88, 6,  8, 7, 87, 8, 41, 4, 33, 2, 60, 3, 47, 0, 56, 
    6, 13, 4, 53, 0, 49, 2, 58, 1, 57, 8, 71, 3, 14, 5, 75, 7, 42, 
    1,  8, 4, 76, 3, 31, 8, 89, 0, 67, 7, 99, 2, 25, 5, 34, 6, 72, 
    4, 86, 6, 85, 3, 62, 7,  8, 5, 43, 1, 59, 8, 14, 0, 49, 2, 33, 
    0, 22, 6, 14, 8, 51, 3, 89, 7,  1, 4, 42, 5, 23, 1, 91, 2, 50, 
    1,  5, 3, 78, 6, 91, 8, 95, 0, 85, 7,  1, 2, 32, 5, 35, 4, 85
  };
  const int q9026[] = {
    9, 9, // Number of jobs and machines
    3,  4, 4, 32, 1, 82, 7, 46, 0,  4, 6, 22, 8,  6, 5, 41, 2, 58, 
    0, 97, 2, 35, 4, 34, 1, 38, 7,  9, 8, 71, 3, 28, 6, 64, 5,  7, 
    5, 25, 7,  3, 2, 25, 6, 21, 8,  5, 1, 49, 3, 77, 0, 55, 4,  9, 
    1, 12, 6, 22, 4, 81, 7, 90, 0, 67, 2, 78, 3, 99, 8, 37, 5, 66, 
    8, 69, 2, 90, 6, 24, 4,  2, 0, 41, 7, 90, 3, 85, 5, 67, 1, 54, 
    1,  2, 5, 23, 8, 90, 6, 21, 4, 55, 3, 29, 7, 55, 0, 12, 2, 82, 
    3, 43, 8, 16, 7, 92, 4, 95, 2, 13, 0,  4, 5, 27, 1, 26, 6, 83, 
    2, 50, 4,  5, 1, 53, 3, 10, 0, 42, 6, 39, 8, 44, 7, 25, 5, 33, 
    2, 97, 5,  9, 6, 63, 1, 53, 3, 65, 4, 35, 8, 59, 0, 57, 7, 32
  };
  const int q9027[] = {
    9, 9, // Number of jobs and machines
    4, 78, 3, 11, 1, 83, 7, 84, 2, 56, 0, 38, 8, 50, 6, 91, 5, 36, 
    7, 30, 1, 81, 2, 12, 8, 18, 6, 43, 0, 47, 3, 13, 5, 22, 4, 50, 
    6, 74, 2, 39, 5, 18, 1, 28, 0, 41, 7, 63, 4, 85, 3, 21, 8, 13, 
    4,  9, 0,  9, 3, 80, 2, 99, 1, 92, 6,  2, 7, 33, 8, 34, 5, 33, 
    8, 77, 0, 19, 7, 14, 3, 57, 5, 10, 4, 47, 1, 60, 2, 35, 6, 98, 
    5, 89, 6, 46, 1, 35, 3,  3, 2, 68, 4, 75, 8, 17, 7, 31, 0, 38, 
    1, 63, 6, 69, 4, 97, 2, 99, 7, 34, 8, 73, 3, 42, 5, 30, 0, 80, 
    4, 66, 8, 23, 1,  1, 5, 48, 6, 60, 7, 55, 2,  2, 0, 16, 3, 87, 
    2, 94, 4, 63, 7, 59, 1, 91, 0, 26, 3, 75, 8, 67, 5, 98, 6, 83
  };
  const int q9028[] = {
    9, 9, // Number of jobs and machines
    3,  4, 2, 61, 7, 32, 1, 21, 5, 31, 0,  6, 4, 87, 6,  9, 8, 51, 
    6, 91, 5, 62, 8, 46, 4, 83, 0, 71, 3, 96, 2, 71, 7, 10, 1, 78, 
    1, 18, 3, 30, 5, 37, 0, 47, 2,  5, 6, 94, 8, 52, 4, 28, 7, 56, 
    0, 97, 2,  5, 1, 37, 8, 17, 3, 20, 6, 93, 5, 26, 7, 39, 4, 35, 
    8, 61, 0, 51, 2, 28, 3, 43, 6, 75, 7, 68, 4, 45, 5, 77, 1, 43, 
    1,  1, 2, 45, 8, 35, 5, 60, 0, 66, 7,  8, 4,  3, 6, 73, 3, 82, 
    6, 23, 4, 22, 5, 94, 3, 54, 7,  8, 8, 12, 0, 47, 2, 49, 1, 57, 
    3, 72, 0, 21, 8, 32, 5,  5, 1, 62, 6, 32, 2, 30, 7, 75, 4, 59, 
    5, 24, 0, 21, 3, 17, 1, 27, 7, 52, 6, 32, 2, 62, 4, 20, 8, 96
  };
  const int q9029[] = {
    9, 9, // Number of jobs and machines
    5, 49, 8, 59, 6, 67, 4, 55, 3, 58, 1, 53, 0, 45, 2, 98, 7, 70, 
    2, 49, 3, 50, 6, 16, 1, 98, 8, 74, 4, 57, 0, 15, 5, 55, 7, 52, 
    1, 92, 5, 76, 4,  4, 2, 46, 6, 95, 3, 74, 8, 96, 7, 26, 0, 57, 
    3, 94, 7, 65, 1, 40, 2, 52, 6, 58, 0, 57, 5,  1, 8, 12, 4, 53, 
    8, 66, 3, 70, 4, 55, 5, 82, 2, 93, 1, 77, 0, 52, 7, 82, 6, 89, 
    4, 35, 5, 67, 6, 63, 0, 91, 3, 38, 1, 87, 7, 25, 2, 30, 8, 27, 
    6,  1, 5, 49, 3, 58, 4, 22, 8,  4, 2, 41, 0, 32, 1, 66, 7, 21, 
    7, 41, 6, 58, 2, 27, 3,  9, 4, 32, 5, 65, 1, 76, 0, 80, 8, 90, 
    0, 71, 4, 70, 7, 39, 3, 43, 6, 88, 5, 23, 1, 47, 8, 45, 2, 39
  };
  const int q9030[] = {
    9, 9, // Number of jobs and machines
    5, 74, 8, 79, 3,  6, 1, 83, 6, 91, 7, 27, 4, 12, 0, 66, 2, 96, 
    1,  6, 8, 86, 3, 12, 6, 36, 4, 39, 7, 59, 2, 24, 5, 44, 0, 97, 
    0, 55, 3, 16, 7, 22, 1, 22, 4, 47, 8,  2, 5, 77, 6, 63, 2, 33, 
    6, 38, 1, 56, 7, 10, 4, 89, 5, 54, 0, 75, 2, 35, 3, 86, 8,  8, 
    3, 27, 1, 63, 7, 52, 2, 82, 4, 66, 6,  4, 8,  4, 5, 53, 0, 52, 
    4,  6, 6, 59, 7, 82, 2, 90, 0, 37, 3,  9, 1, 65, 8, 46, 5, 68, 
    5, 77, 8, 10, 3, 56, 0,  5, 6, 99, 2, 22, 7, 25, 4, 11, 1, 82, 
    8,  1, 3, 50, 4, 35, 2, 58, 0,  8, 7, 34, 5, 11, 1, 22, 6, 41, 
    7, 31, 5, 23, 2, 24, 3, 72, 8, 54, 6, 94, 1, 59, 0,  6, 4,  8
  };
  const int q9031[] = {
    9, 9, // Number of jobs and machines
    7, 50, 2, 64, 1, 46, 0, 73, 4, 82, 3, 61, 5, 11, 6, 78, 8, 94, 
    6, 95, 1, 97, 5, 80, 0, 23, 2, 27, 3, 98, 7, 73, 4, 78, 8,  8, 
    2, 15, 8, 85, 7, 98, 1, 19, 6, 20, 5, 63, 3, 56, 4, 23, 0, 99, 
    4, 13, 2, 98, 6, 46, 7, 82, 8,  5, 0, 44, 5, 98, 1, 92, 3, 70, 
    6, 33, 7, 93, 1, 70, 4, 76, 5, 25, 8, 51, 0, 73, 3, 16, 2, 99, 
    8, 57, 5, 52, 2, 90, 6, 15, 4, 63, 1, 30, 0, 49, 3, 99, 7, 31, 
    4, 61, 7, 20, 0, 96, 5, 78, 2, 91, 3, 94, 1,  4, 6, 75, 8, 30, 
    1, 91, 4, 24, 5, 54, 7, 77, 6, 66, 2, 39, 8, 17, 0,  7, 3, 24, 
    7, 69, 6, 81, 1, 87, 5, 10, 0, 61, 3, 87, 8, 32, 2, 48, 4, 31
  };
  const int q9032[] = {
    9, 9, // Number of jobs and machines
    0, 28, 7, 75, 1, 27, 3, 29, 6, 68, 8, 41, 5, 21, 2,  7, 4, 43, 
    0, 74, 1, 47, 8, 56, 4, 73, 6, 99, 5, 67, 7, 94, 3, 58, 2, 11, 
    8,  5, 1, 88, 5, 43, 4, 49, 0, 40, 7, 37, 2, 75, 6, 15, 3, 72, 
    6, 77, 4, 54, 1, 85, 8,  3, 2, 20, 5,  3, 7, 15, 0, 81, 3, 98, 
    1, 28, 5, 64, 4, 28, 2, 38, 3, 31, 7, 76, 8, 86, 0, 36, 6, 10, 
    5, 30, 7,  5, 1, 20, 3, 27, 6, 10, 2, 88, 4, 28, 0, 41, 8, 56, 
    5, 79, 1, 63, 7, 28, 2, 14, 3, 23, 0, 49, 6, 32, 4, 79, 8, 75, 
    5, 77, 8, 44, 3, 18, 7, 98, 0, 72, 1, 28, 6, 53, 2, 69, 4,  5, 
    5, 75, 4, 60, 2, 93, 1, 49, 7,  2, 6, 30, 8, 31, 0, 65, 3, 58
  };
  const int q9033[] = {
    9, 9, // Number of jobs and machines
    8, 76, 0, 27, 7, 43, 2, 86, 1, 45, 3, 42, 6, 76, 5, 78, 4, 91, 
    6, 53, 4, 92, 1, 19, 0, 69, 7, 13, 2, 63, 3, 73, 5, 12, 8, 10, 
    0, 91, 3, 40, 4, 59, 8, 34, 7, 97, 5, 13, 6, 28, 2,  3, 1, 80, 
    4, 10, 1, 74, 3, 57, 8, 29, 0, 11, 2, 20, 5, 61, 7, 93, 6,  2, 
    2, 10, 7, 52, 0, 43, 1, 44, 5,  7, 6, 12, 8, 58, 4, 78, 3, 58, 
    6, 15, 2, 43, 0, 50, 5, 35, 8, 41, 7, 32, 1, 34, 4, 87, 3, 24, 
    7, 18, 6, 77, 3, 64, 1, 32, 5, 38, 2, 62, 8, 70, 0, 13, 4, 11, 
    3, 19, 6, 39, 8, 59, 2, 25, 4, 57, 5, 25, 0, 13, 1, 23, 7, 64, 
    0, 81, 1, 27, 7, 94, 3, 27, 4, 36, 8, 36, 5, 44, 6, 61, 2, 35
  };
  const int q9034[] = {
    9, 9, // Number of jobs and machines
    1, 27, 4, 19, 2, 49, 5, 13, 8, 36, 6, 13, 7, 63, 3, 16, 0, 19, 
    7, 76, 6, 17, 0, 75, 8, 39, 3, 16, 4, 27, 5, 45, 1, 55, 2, 55, 
    5, 21, 1, 74, 7, 27, 8, 72, 2, 24, 3,  5, 4, 81, 0, 28, 6, 57, 
    8, 28, 0, 54, 1, 43, 6, 71, 3, 43, 7, 36, 4, 91, 2, 87, 5, 13, 
    4, 26, 1, 67, 2, 89, 6, 13, 8, 80, 0, 55, 7, 93, 5, 76, 3, 37, 
    3, 64, 0, 62, 8, 20, 4, 58, 1, 91, 5, 52, 2, 80, 7,  5, 6,  3, 
    4, 16, 3, 25, 1, 25, 6, 97, 7, 55, 5, 49, 2, 44, 0, 49, 8, 96, 
    2,  2, 4, 57, 0, 44, 3, 11, 1, 18, 8, 63, 7, 58, 6, 15, 5, 37, 
    1, 37, 5,  3, 7, 71, 0, 59, 4,  3, 8, 56, 3, 70, 2, 97, 6, 15
  };
  const int q9035[] = {
    9, 9, // Number of jobs and machines
    4, 87, 7, 28, 2, 87, 3, 12, 0, 73, 8, 89, 5, 35, 6, 83, 1, 41, 
    2, 44, 1, 68, 5, 41, 7, 58, 4, 41, 0, 46, 3, 71, 6, 54, 8,  3, 
    1, 58, 0, 66, 8, 20, 5, 78, 3, 30, 4, 11, 6, 32, 2, 55, 7, 50, 
    7, 35, 1, 71, 4, 80, 6, 17, 8, 21, 2, 58, 3, 33, 0, 52, 5, 41, 
    0, 64, 1, 50, 2, 60, 3, 50, 8,  5, 6, 33, 4, 66, 7, 46, 5, 38, 
    0, 89, 3, 77, 4, 12, 1, 52, 6, 22, 8, 11, 5, 72, 7, 94, 2, 36, 
    1, 74, 7, 92, 8, 73, 2, 60, 5,  6, 0, 34, 4, 18, 3, 95, 6, 18, 
    6, 25, 8, 55, 2, 11, 5, 35, 1, 73, 4, 49, 0, 43, 3,  9, 7, 26, 
    0, 10, 5, 65, 6, 73, 2, 41, 1, 97, 3, 13, 4, 69, 8, 12, 7, 33
  };
  const int q9036[] = {
    9, 9, // Number of jobs and machines
    1, 89, 3, 46, 2, 41, 0, 44, 7,  4, 6, 44, 8, 24, 5, 79, 4, 62, 
    4, 55, 1, 76, 7, 91, 2, 21, 3, 89, 0, 46, 8,  4, 6, 92, 5, 19, 
    2, 42, 7,  8, 0, 11, 3, 54, 4, 77, 6, 24, 8, 38, 5, 68, 1, 23, 
    1, 27, 7, 96, 5, 33, 8, 55, 0, 71, 6, 28, 2, 72, 3, 76, 4, 19, 
    5, 45, 6, 61, 8, 27, 2, 79, 4, 81, 7, 85, 1, 85, 0, 55, 3, 41, 
    0, 49, 1, 46, 3, 86, 4, 59, 2, 47, 6, 41, 7, 74, 5, 52, 8, 98, 
    3, 82, 0, 62, 7, 63, 6, 64, 8, 34, 4, 40, 5, 82, 1, 16, 2, 23, 
    6, 15, 1,  9, 8, 52, 4, 31, 3, 63, 2, 23, 0, 57, 5, 26, 7, 36, 
    4, 55, 1,  3, 7, 57, 6, 58, 2, 39, 8, 72, 5, 56, 3, 14, 0, 82
  };
  const int q9037[] = {
    9, 9, // Number of jobs and machines
    7, 42, 4, 23, 1, 43, 0,  8, 6, 72, 2, 22, 8, 35, 5, 19, 3, 27, 
    8,  7, 0, 82, 1, 99, 7, 51, 3, 89, 4, 95, 2, 66, 6, 60, 5, 74, 
    1, 88, 4, 42, 3, 44, 5, 59, 7, 62, 2, 92, 6, 76, 8, 27, 0, 61, 
    2, 55, 8, 80, 6, 92, 7, 98, 4, 26, 0, 57, 1, 18, 5, 76, 3,  2, 
    2, 61, 6, 22, 5, 87, 1, 21, 0, 28, 7, 74, 8, 67, 3, 79, 4, 32, 
    3, 80, 6, 60, 4, 48, 7, 49, 8, 21, 1, 25, 5, 26, 2, 77, 0, 82, 
    2, 59, 6, 27, 7, 16, 1, 96, 8, 10, 5,  2, 0, 78, 4, 81, 3, 58, 
    2, 29, 4, 16, 3, 79, 6, 56, 8, 91, 1, 12, 7, 41, 0, 56, 5, 15, 
    7, 63, 0, 61, 4, 69, 1, 42, 2,  2, 8, 50, 3, 72, 6, 94, 5, 62
  };
  const int q9038[] = {
    9, 9, // Number of jobs and machines
    8, 59, 3, 91, 0, 36, 7, 96, 4, 76, 1, 36, 2, 45, 6, 79, 5, 13, 
    3, 69, 2, 67, 1, 35, 8, 96, 0, 50, 7, 64, 4,  3, 5, 19, 6, 10, 
    4, 24, 3, 39, 2, 54, 7, 33, 1, 85, 5, 93, 6, 35, 8, 77, 0, 39, 
    8, 52, 4, 79, 0, 15, 6, 21, 2, 13, 5,  4, 3, 19, 7,  4, 1, 48, 
    7, 71, 8, 78, 2, 78, 5, 88, 4, 31, 3,  5, 0, 29, 6, 12, 1, 24, 
    8, 20, 4, 76, 1, 92, 3, 54, 6, 34, 7, 25, 2, 45, 5, 96, 0, 30, 
    5, 12, 7, 32, 2, 85, 3, 79, 0, 26, 4, 13, 6, 76, 1, 43, 8, 70, 
    5, 97, 8, 94, 2, 41, 7, 80, 4, 90, 3,  6, 1, 80, 6, 29, 0, 78, 
    5, 70, 2, 87, 0, 85, 3, 31, 6, 71, 7, 53, 1, 66, 8, 30, 4, 53
  };
  const int q9039[] = {
    9, 9, // Number of jobs and machines
    4, 64, 5,  9, 3,  2, 8, 78, 2, 26, 6, 82, 1,  3, 0, 79, 7, 33, 
    8, 37, 6, 70, 5, 11, 4, 34, 7, 23, 0, 62, 3, 21, 2, 29, 1, 79, 
    0, 65, 3, 70, 1, 54, 7, 74, 2, 76, 4, 75, 6, 36, 5, 28, 8, 37, 
    0, 65, 8, 48, 7,  7, 5, 18, 1, 41, 3,  6, 2, 93, 4, 55, 6, 90, 
    6, 53, 7, 61, 0, 62, 3,  5, 8, 25, 4, 38, 1, 31, 2, 48, 5, 91, 
    1, 37, 3, 23, 2, 77, 0, 29, 5, 13, 4, 14, 6, 40, 8, 99, 7, 89, 
    6, 95, 7, 26, 0, 15, 2, 64, 5, 52, 3, 51, 4, 11, 8,  2, 1, 87, 
    5, 36, 0, 49, 6, 65, 2, 38, 7, 62, 4, 47, 1, 19, 8, 93, 3, 11, 
    4, 91, 2, 30, 8, 42, 0, 36, 1, 16, 7, 51, 3, 54, 5, 73, 6, 99
  };
  const int q9040[] = {
    9, 9, // Number of jobs and machines
    3, 21, 6, 25, 8, 96, 2, 32, 5, 13, 7, 96, 0, 93, 1, 13, 4, 11, 
    2, 57, 1, 39, 5, 26, 4, 44, 7, 76, 6, 44, 0, 84, 8, 14, 3, 72, 
    4, 91, 1, 66, 5, 99, 3, 76, 2,  3, 0, 97, 8, 61, 6, 49, 7, 66, 
    1,  6, 6, 16, 5, 35, 4, 47, 0, 43, 2, 54, 8, 95, 7, 95, 3, 66, 
    4, 58, 6, 18, 1, 51, 3, 17, 0,  3, 2, 47, 5, 56, 8, 41, 7, 35, 
    2, 35, 7, 59, 5, 95, 8, 80, 1, 58, 6,  8, 3, 67, 4, 73, 0, 51, 
    3, 27, 6, 13, 4, 16, 1, 82, 7, 14, 8, 74, 0, 12, 5, 20, 2, 19, 
    2, 69, 6, 59, 0, 64, 1, 96, 3, 73, 7, 40, 8, 62, 4, 81, 5, 42, 
    5, 28, 0, 76, 6, 58, 1, 83, 2, 33, 3,  9, 4, 86, 8,  9, 7, 17
  };
  const int q9041[] = {
    9, 9, // Number of jobs and machines
    8, 57, 0, 76, 2, 23, 5, 57, 7, 80, 4, 55, 6, 64, 3, 73, 1, 46, 
    5, 11, 7, 11, 1, 70, 8, 49, 0, 43, 6, 82, 2, 13, 4,  6, 3, 94, 
    6, 83, 2, 68, 1, 61, 4, 63, 3, 14, 5, 52, 8, 84, 0, 45, 7, 61, 
    1, 78, 0, 15, 3, 62, 4, 49, 2, 62, 6, 50, 8,  3, 5, 78, 7, 13, 
    5, 32, 7, 21, 4, 35, 3, 36, 1, 45, 8, 92, 2, 89, 6, 65, 0, 71, 
    8, 98, 1, 36, 4, 73, 7, 24, 2, 89, 0, 55, 5, 62, 6, 24, 3, 95, 
    1, 86, 8, 26, 2, 56, 7, 26, 6, 61, 5, 37, 4, 78, 0, 34, 3, 42, 
    5, 85, 0, 88, 7, 32, 2, 87, 8,  8, 3,  3, 6,  6, 4, 14, 1, 37, 
    0, 60, 4,  9, 2, 99, 3, 75, 1, 80, 8, 54, 7, 99, 6,  6, 5, 62
  };
  const int q9042[] = {
    9, 9, // Number of jobs and machines
    5, 24, 6, 28, 7, 21, 2, 55, 3, 28, 0, 36, 4, 58, 8, 65, 1, 33, 
    2, 62, 0, 33, 4, 16, 6, 21, 5, 69, 8, 72, 3,  2, 1, 90, 7, 82, 
    2, 96, 0, 38, 4, 39, 1, 44, 3, 56, 7, 21, 6, 53, 8, 31, 5, 12, 
    0,  3, 6, 64, 7, 75, 8, 50, 5, 77, 2, 90, 3,  4, 4, 18, 1, 86, 
    5, 54, 7, 79, 0, 32, 6, 72, 4, 40, 3,  3, 8, 85, 1, 86, 2, 93, 
    3, 42, 5, 55, 0, 52, 2, 19, 4, 85, 8, 68, 1, 94, 6, 36, 7, 59, 
    6, 86, 4,  4, 1,  1, 5, 86, 7, 53, 2, 90, 8, 74, 3, 56, 0, 39, 
    0, 52, 3, 84, 5, 28, 7, 49, 4, 24, 1, 28, 8, 97, 6, 31, 2, 11, 
    8, 43, 3, 24, 7, 20, 5, 78, 2,  4, 1, 73, 4, 17, 6, 24, 0, 18
  };
  const int q9043[] = {
    9, 9, // Number of jobs and machines
    8, 18, 6, 13, 7, 58, 3, 19, 5, 41, 1, 18, 4, 81, 2, 65, 0,  9, 
    8, 70, 7, 59, 0,  7, 2, 36, 5, 12, 3, 42, 6, 69, 4, 65, 1, 91, 
    1, 76, 2, 73, 7, 45, 8, 51, 3, 89, 5, 77, 4, 12, 6, 44, 0, 16, 
    5,  9, 8, 37, 7, 64, 6, 51, 1, 78, 4, 57, 0, 45, 3, 94, 2, 81, 
    5, 82, 6,  6, 3, 48, 0, 78, 4, 70, 8, 23, 7, 50, 1, 63, 2, 21, 
    2, 70, 3, 47, 4, 21, 0, 59, 5, 52, 1, 33, 8,  4, 6, 70, 7, 39, 
    6, 67, 0, 18, 2, 58, 5, 93, 4, 53, 7, 24, 8, 41, 1, 91, 3, 99, 
    8, 95, 7, 76, 2, 88, 3, 55, 4, 76, 5,  9, 6, 50, 1, 63, 0, 92, 
    0, 77, 5, 89, 8, 38, 6, 37, 7, 75, 3, 96, 2, 92, 1, 39, 4, 59
  };
  const int q9044[] = {
    9, 9, // Number of jobs and machines
    3, 59, 8, 18, 2, 88, 4, 81, 5, 51, 0, 17, 7, 92, 1, 66, 6, 58, 
    6, 45, 5,  7, 1, 36, 3, 22, 7, 84, 8, 31, 4, 16, 0, 42, 2, 16, 
    2, 82, 4, 60, 6, 42, 8, 44, 7, 66, 3, 85, 0, 37, 5, 98, 1, 11, 
    5, 94, 0, 22, 2, 17, 3, 83, 7, 81, 8, 64, 1, 23, 4, 71, 6, 83, 
    3,  4, 5, 91, 2, 23, 6, 36, 7, 90, 0, 33, 4,  4, 1, 94, 8, 83, 
    7, 74, 3,  2, 1, 49, 4, 93, 8, 18, 5, 96, 6, 88, 0, 47, 2, 78, 
    5, 96, 3,  7, 1, 56, 2,  9, 6, 97, 4, 84, 7,  8, 0, 90, 8, 48, 
    0, 93, 7, 73, 5, 35, 8, 95, 4, 38, 1, 12, 3, 18, 6, 64, 2, 14, 
    6, 91, 4, 27, 8, 32, 1, 20, 7, 73, 2, 88, 5, 20, 0, 31, 3, 60
  };
  const int q9045[] = {
    9, 9, // Number of jobs and machines
    3, 84, 8, 69, 1, 44, 6, 22, 4, 61, 5, 17, 0, 31, 7, 61, 2, 58, 
    6, 67, 1, 47, 5, 45, 4, 54, 0, 33, 2, 34, 7, 10, 3, 93, 8, 70, 
    8, 42, 3, 73, 7, 74, 5, 12, 2, 87, 4, 32, 6, 68, 1, 64, 0, 14, 
    8, 62, 5, 42, 4, 75, 0, 36, 3, 59, 1, 11, 2, 51, 6,  4, 7, 35, 
    6, 72, 5, 59, 0,  4, 7, 25, 8, 83, 1, 89, 3, 43, 2, 18, 4, 94, 
    2, 51, 1, 87, 8, 46, 3, 60, 5,  1, 0, 14, 7, 96, 4, 68, 6, 74, 
    4, 61, 5, 92, 7, 76, 0, 30, 2, 98, 1, 60, 3,  7, 6,  7, 8, 96, 
    8,  4, 6, 22, 2, 50, 1, 52, 0, 72, 4, 71, 7, 99, 5, 35, 3, 94, 
    3, 14, 4, 40, 7, 42, 5, 79, 0,  2, 1, 77, 2, 96, 8, 14, 6, 83
  };
  const int q9046[] = {
    9, 9, // Number of jobs and machines
    3, 80, 6, 27, 8, 46, 0, 74, 1, 41, 4, 38, 5, 43, 2, 81, 7, 74, 
    4, 78, 1, 58, 7, 24, 0, 59, 8, 89, 6, 22, 2, 10, 3, 99, 5, 11, 
    7, 61, 2, 15, 3, 14, 8, 41, 1, 77, 6,  9, 5, 94, 4,  8, 0, 24, 
    5, 36, 0, 57, 2, 23, 4, 23, 3, 52, 1, 80, 6, 74, 8, 67, 7, 83, 
    0, 69, 2, 40, 1, 12, 4, 24, 8, 96, 3, 35, 5, 80, 7, 79, 6, 39, 
    6, 33, 1, 23, 7, 37, 3, 29, 8, 27, 5, 75, 0, 73, 4, 59, 2, 94, 
    7, 92, 1, 11, 2, 46, 8, 78, 0, 90, 5, 43, 6, 45, 3, 19, 4, 82, 
    8, 86, 5, 45, 1, 81, 2,  8, 6, 33, 0, 68, 7, 36, 4, 41, 3, 84, 
    7, 47, 6, 32, 2, 94, 4, 45, 0, 40, 3, 98, 5, 96, 8, 34, 1, 25
  };
  const int q9047[] = {
    9, 9, // Number of jobs and machines
    7, 57, 8,  9, 1, 41, 5, 55, 0, 22, 4, 78, 2, 51, 6, 72, 3, 55, 
    7, 80, 6, 20, 5,  9, 0, 90, 8, 52, 3, 79, 1, 55, 2, 35, 4, 16, 
    5, 11, 4, 65, 0, 81, 7, 31, 3, 99, 2, 57, 8,  8, 1, 66, 6, 77, 
    1, 23, 2, 84, 5,  1, 8, 10, 4, 42, 3,  2, 6, 33, 0, 35, 7, 36, 
    3, 71, 5, 33, 6, 62, 0, 91, 8, 26, 4, 97, 7, 57, 2, 48, 1, 32, 
    0, 27, 1, 40, 5, 21, 7, 17, 6, 63, 3, 43, 2, 64, 8, 57, 4, 59, 
    4, 86, 3,  6, 8, 50, 5, 15, 6, 28, 1, 53, 7, 46, 2,  4, 0, 64, 
    4, 49, 7,  9, 2, 88, 0, 24, 5, 50, 6,  5, 8, 94, 1, 90, 3, 35, 
    0,  3, 3, 40, 6, 50, 2, 32, 7, 48, 8, 96, 1, 39, 4, 58, 5, 22
  };
  const int q9048[] = {
    9, 9, // Number of jobs and machines
    6, 95, 7, 25, 0, 17, 5, 27, 8, 81, 2, 55, 4, 60, 1, 47, 3, 63, 
    3, 77, 2, 31, 1, 99, 0, 44, 5, 96, 8, 39, 4, 38, 7, 72, 6, 52, 
    4, 11, 5, 77, 8, 33, 1,  8, 7, 82, 0, 98, 2, 25, 6, 31, 3, 42, 
    8, 63, 2, 79, 6, 53, 4, 83, 0, 66, 5, 59, 3, 36, 1, 22, 7, 58, 
    2, 61, 5, 56, 8, 22, 7, 16, 3, 17, 4, 13, 1, 57, 6, 48, 0, 89, 
    6, 88, 0, 59, 4, 90, 1, 30, 7, 35, 8,  1, 3, 33, 2, 48, 5, 18, 
    0, 31, 7, 14, 1, 35, 2, 31, 8,  3, 5, 84, 4, 19, 6, 53, 3, 51, 
    4,  6, 6, 34, 2, 69, 3,  5, 7, 37, 1, 63, 5, 50, 0, 70, 8, 45, 
    2, 54, 7, 71, 5, 33, 1, 66, 0, 64, 6, 85, 8, 51, 4, 76, 3, 87
  };
  const int q9049[] = {
    9, 9, // Number of jobs and machines
    1, 15, 6, 83, 4, 53, 3, 55, 8, 65, 2, 91, 5, 44, 0, 18, 7, 24, 
    6, 32, 2, 95, 1, 37, 8, 38, 7, 84, 3, 47, 4, 12, 5, 25, 0, 22, 
    0, 66, 3, 34, 5,  2, 6, 10, 8, 23, 1, 89, 7, 86, 2, 48, 4, 74, 
    1, 33, 6, 42, 8, 44, 2, 40, 0, 51, 4, 13, 5, 57, 7, 16, 3, 91, 
    6, 42, 3, 33, 4, 51, 7, 89, 0,  6, 1, 46, 2, 72, 8, 63, 5, 97, 
    2,  3, 1, 36, 5, 58, 6, 11, 8, 23, 4, 71, 7, 69, 0, 55, 3, 14, 
    4, 71, 0, 18, 7, 26, 5, 78, 6, 29, 1, 45, 2, 15, 8, 66, 3, 30, 
    7, 78, 0, 78, 8, 39, 5,  6, 3, 28, 6, 97, 1, 87, 4, 22, 2, 27, 
    2, 84, 0, 84, 3, 31, 8, 85, 6, 42, 1, 73, 5,  5, 7, 51, 4, 48
  };
  const int q9050[] = {
    9, 9, // Number of jobs and machines
    8, 53, 1,  5, 6, 41, 2, 96, 3, 83, 5, 91, 7, 87, 0, 64, 4, 42, 
    1, 98, 0, 44, 6, 30, 7, 22, 3, 48, 2, 67, 4, 83, 5, 17, 8, 96, 
    4, 44, 5, 31, 0, 88, 2, 13, 7,  7, 3, 32, 8, 52, 1, 26, 6,  3, 
    4, 16, 8, 78, 5, 81, 6, 43, 7, 92, 3, 46, 0, 90, 2, 93, 1, 63, 
    6, 18, 8, 33, 5, 12, 2, 67, 4, 24, 1, 21, 7, 74, 0, 10, 3, 48, 
    3, 37, 1, 39, 8,  8, 0, 18, 7, 49, 4, 16, 6, 72, 5, 82, 2,  5, 
    2, 84, 8, 11, 0, 76, 5,  2, 4, 31, 3, 64, 7, 87, 1, 74, 6, 35, 
    1, 35, 3, 49, 6, 39, 8, 79, 2, 89, 0, 13, 5, 68, 7, 14, 4, 42, 
    8, 52, 2, 74, 3, 72, 7, 70, 5, 17, 4, 33, 1,  6, 0, 15, 6, 89
  };
  const int q9051[] = {
    9, 9, // Number of jobs and machines
    5, 32, 3, 65, 0, 24, 6, 63, 8, 53, 7, 25, 2, 29, 4, 19, 1, 36, 
    7, 62, 2, 40, 6, 23, 5, 12, 8, 38, 4, 79, 0, 52, 3, 44, 1, 85, 
    0, 96, 3, 42, 7, 29, 8, 39, 5, 17, 2, 25, 6, 91, 1, 59, 4,  8, 
    6, 69, 8, 82, 2, 75, 4, 90, 3, 22, 1, 42, 0, 88, 7, 36, 5, 53, 
    5, 37, 0, 55, 4, 11, 6, 54, 7, 11, 1,  5, 2, 99, 3, 34, 8, 23, 
    1, 76, 5,  5, 8, 37, 4, 26, 7, 82, 0, 86, 2, 21, 3, 68, 6, 43, 
    5, 91, 1, 21, 0, 69, 2, 97, 8, 21, 4, 80, 3, 90, 7, 29, 6, 73, 
    8, 81, 6, 79, 4, 72, 5, 42, 0, 37, 1, 80, 7, 76, 2,  8, 3, 52, 
    2, 38, 8, 64, 5, 92, 7, 13, 0, 74, 1, 81, 4, 98, 6, 11, 3, 27
  };
  const int q9052[] = {
    9, 9, // Number of jobs and machines
    0, 73, 1, 76, 3,  4, 7, 89, 6, 64, 2, 25, 5, 58, 8,  8, 4, 83, 
    0, 23, 7, 36, 1, 77, 2, 28, 6, 92, 4, 95, 5, 94, 3, 46, 8, 99, 
    5,  1, 3, 84, 0, 36, 1, 19, 2, 93, 8, 15, 4, 76, 6, 62, 7, 40, 
    4, 57, 5, 58, 2, 32, 1, 70, 3, 10, 0, 29, 6, 84, 8, 96, 7, 58, 
    0,  3, 4, 13, 6, 62, 2,  1, 5, 45, 8, 96, 7, 38, 1, 49, 3, 41, 
    7,  8, 1, 39, 3, 29, 8, 97, 6, 91, 0, 93, 5, 26, 2, 88, 4, 83, 
    1, 92, 0, 53, 4, 68, 6, 38, 7,  3, 2,  5, 5, 72, 8, 43, 3, 61, 
    3, 72, 6, 23, 0, 27, 7, 63, 4, 68, 2, 68, 5, 63, 1, 45, 8, 53, 
    5, 54, 3, 44, 2, 62, 1, 31, 0, 37, 8, 82, 6, 21, 4,  7, 7, 91
  };
  const int q9053[] = {
    9, 9, // Number of jobs and machines
    5, 13, 0, 96, 6, 33, 4, 65, 8,  4, 7, 41, 2, 58, 3, 48, 1,  2, 
    2, 81, 3, 13, 6, 95, 4, 32, 5, 78, 0, 56, 8, 62, 1, 51, 7, 85, 
    6, 35, 7, 28, 3, 25, 4, 82, 2, 61, 8,  8, 1,  2, 0, 37, 5, 63, 
    5, 47, 0, 78, 1, 36, 8, 78, 2, 26, 3, 50, 4, 25, 7, 94, 6, 56, 
    5, 14, 6, 68, 7, 74, 8, 52, 3, 33, 2,  9, 1, 98, 4,  5, 0, 54, 
    4, 52, 5, 54, 6, 17, 8, 15, 0, 72, 1, 17, 2,  4, 7, 60, 3, 37, 
    4, 10, 0, 89, 8, 88, 5, 14, 3,  7, 2, 37, 7, 66, 1, 47, 6, 85, 
    8, 81, 7, 95, 2, 40, 4, 12, 3, 33, 5, 22, 0, 39, 6, 33, 1, 11, 
    7, 37, 5, 47, 4, 40, 0, 33, 8, 51, 2,  2, 3, 42, 6, 56, 1, 61
  };
  const int q9054[] = {
    9, 9, // Number of jobs and machines
    8, 47, 2,  5, 0, 97, 1, 34, 3, 69, 7, 74, 4, 29, 6,  6, 5, 38, 
    8, 90, 4, 71, 6, 51, 3, 99, 5, 30, 1,  2, 2, 94, 7, 64, 0,  3, 
    5, 47, 7, 13, 3, 54, 1, 14, 0, 57, 6, 37, 2, 71, 8, 38, 4, 84, 
    2, 92, 4, 72, 8, 79, 7, 95, 6, 10, 0, 20, 5, 46, 1, 33, 3,  2, 
    2, 62, 8, 48, 6, 27, 7, 35, 3, 54, 5, 67, 1, 38, 4, 81, 0, 57, 
    3, 48, 6,  6, 4,  8, 5, 45, 1, 84, 0, 99, 8, 73, 7, 85, 2, 95, 
    3, 29, 6, 26, 7, 46, 0, 80, 4, 18, 2, 89, 8, 18, 5, 14, 1, 81, 
    3, 21, 1, 66, 2, 37, 5, 99, 6, 12, 8, 92, 0, 85, 4, 27, 7, 69, 
    6, 77, 4,  4, 7, 96, 8, 59, 2,  8, 5, 77, 0,  5, 1, 38, 3, 92
  };
  const int q9055[] = {
    9, 9, // Number of jobs and machines
    1, 17, 8, 53, 4, 91, 0, 20, 2, 14, 3, 87, 7, 14, 6,  4, 5, 33, 
    6, 82, 4, 33, 5, 16, 2, 26, 8, 68, 3, 74, 7, 23, 1, 61, 0, 69, 
    3, 38, 6, 89, 1, 58, 8, 38, 4, 64, 7, 97, 0, 79, 2, 32, 5, 44, 
    5, 22, 1, 32, 4, 27, 0, 42, 6, 15, 3,  5, 8, 76, 7, 72, 2, 15, 
    0, 65, 5, 39, 8, 74, 1, 95, 7,  9, 2, 96, 6, 59, 3, 48, 4, 18, 
    7, 45, 3, 25, 4, 84, 6, 37, 8, 25, 2, 79, 5, 75, 0, 95, 1, 59, 
    4, 37, 6, 84, 3, 70, 7, 94, 5, 66, 1, 71, 0, 63, 8, 23, 2, 54, 
    0, 73, 1, 78, 5, 80, 4, 53, 2, 12, 6, 11, 3, 57, 8, 27, 7, 41, 
    6, 46, 8, 26, 5, 96, 0,  6, 1, 82, 4, 82, 2, 67, 7, 47, 3, 98
  };
  const int q9056[] = {
    9, 9, // Number of jobs and machines
    8, 70, 5, 12, 6, 74, 3, 45, 0, 93, 1, 78, 4, 72, 7, 21, 2, 71, 
    1, 76, 0, 53, 5, 82, 3, 43, 4,  4, 7, 99, 6, 92, 8, 43, 2, 21, 
    6, 22, 4, 14, 7,  4, 2, 56, 5,  4, 8, 18, 0, 31, 1, 62, 3, 81, 
    8, 91, 3, 71, 6, 37, 1, 71, 5, 65, 0, 54, 2,  7, 4, 50, 7, 67, 
    2, 31, 0, 26, 6, 80, 5, 90, 7, 28, 3,  3, 4, 63, 8, 34, 1, 50, 
    6, 75, 5, 54, 3, 23, 0, 63, 2, 73, 4, 11, 8, 36, 1, 42, 7, 99, 
    6, 17, 1, 25, 8, 71, 2, 46, 7, 58, 5, 24, 4, 59, 0, 99, 3, 11, 
    5,  3, 4,  6, 2, 82, 6, 45, 7, 87, 8, 59, 1, 53, 3, 31, 0, 96, 
    4,  8, 6, 37, 8, 21, 5, 13, 1, 81, 2, 86, 3,  1, 0, 60, 7, 73
  };
  const int q9057[] = {
    9, 9, // Number of jobs and machines
    1, 21, 6, 99, 0, 48, 8, 21, 5, 83, 7, 31, 2, 59, 4, 69, 3, 15, 
    4, 64, 5,  2, 0, 53, 1, 54, 6, 12, 7, 24, 8, 23, 3, 14, 2, 35, 
    7, 82, 4, 98, 0,  4, 1, 80, 6,  8, 3, 48, 5, 26, 8, 54, 2,  2, 
    5, 19, 2, 80, 6, 16, 1, 50, 0, 11, 7,  9, 4, 93, 8, 42, 3, 34, 
    6, 60, 4, 85, 0, 83, 2, 64, 7, 11, 8, 93, 3, 15, 5, 76, 1, 26, 
    3, 26, 2, 38, 5, 61, 0, 50, 1, 70, 8, 97, 4, 29, 6, 10, 7, 91, 
    1, 17, 5, 78, 3, 93, 8, 30, 4, 77, 7, 62, 2, 49, 6, 45, 0, 90, 
    5, 79, 2, 85, 1, 69, 3, 45, 4, 47, 0, 29, 7, 67, 6, 31, 8,  4, 
    2, 42, 7, 30, 0,  6, 4, 31, 5, 39, 6, 83, 3, 80, 8, 57, 1, 48
  };
  const int q9058[] = {
    9, 9, // Number of jobs and machines
    6, 66, 3, 42, 7, 41, 2, 26, 1, 86, 5, 11, 0, 77, 8, 38, 4, 27, 
    3, 54, 2, 37, 5, 14, 1, 40, 0, 50, 6, 11, 7, 13, 8, 92, 4, 36, 
    1, 34, 0, 47, 7, 59, 4, 95, 8, 74, 2, 56, 5, 56, 6, 18, 3, 67, 
    4, 84, 3, 21, 0, 47, 8, 54, 2, 69, 6, 94, 7, 70, 1,  5, 5, 98, 
    0, 22, 3, 99, 7, 96, 2, 50, 1, 25, 4, 32, 6, 32, 8, 82, 5, 95, 
    7, 29, 8, 17, 6, 95, 2, 60, 3, 41, 0, 43, 1,  8, 5, 53, 4,  8, 
    5, 57, 4, 24, 8, 66, 2, 65, 6, 30, 3, 58, 0,  8, 1, 24, 7, 22, 
    0, 81, 6,  4, 1, 82, 7, 55, 8, 90, 5, 80, 3, 11, 4, 40, 2, 50, 
    5, 36, 7, 89, 2, 69, 6,  9, 8, 70, 3, 83, 1, 76, 0, 53, 4, 22
  };
  const int q9059[] = {
    9, 9, // Number of jobs and machines
    8, 19, 0, 81, 1, 26, 7, 29, 4, 84, 6, 98, 5, 34, 2,  6, 3, 79, 
    4, 35, 5, 34, 2, 97, 0, 51, 7, 64, 8, 73, 1, 78, 6, 86, 3, 23, 
    1, 46, 2, 98, 3, 80, 0, 61, 4, 22, 5, 85, 7, 27, 8, 39, 6, 96, 
    3, 35, 7, 14, 4, 46, 1, 89, 6, 33, 0, 60, 2, 32, 5, 13, 8, 46, 
    1, 17, 4,  8, 2, 75, 7, 85, 8, 73, 0, 43, 3, 30, 5, 91, 6, 93, 
    8, 68, 0, 25, 1, 84, 6, 43, 3, 44, 4, 88, 5, 40, 7, 77, 2, 79, 
    6, 21, 7, 70, 8, 65, 4, 71, 0, 40, 2, 82, 5, 60, 3, 60, 1, 13, 
    2, 36, 4, 26, 6, 83, 5, 77, 0, 88, 3, 75, 7, 66, 1, 18, 8, 25, 
    3, 81, 8, 33, 6, 47, 0, 72, 1, 81, 5, 53, 4, 28, 2, 14, 7, 73
  };
  const int q9060[] = {
    9, 9, // Number of jobs and machines
    1, 98, 5,  6, 6, 10, 8, 74, 4, 97, 0, 51, 3, 61, 7, 93, 2, 72, 
    1, 76, 2,  2, 6, 22, 8, 87, 4,  2, 7, 24, 0, 70, 5, 33, 3, 52, 
    2, 32, 1,  5, 0, 22, 5,  4, 4, 16, 3, 15, 6, 41, 8, 58, 7, 83, 
    5, 73, 2, 71, 3, 95, 1, 41, 4, 35, 8, 54, 7, 67, 6, 44, 0, 51, 
    1, 37, 2, 15, 5, 85, 7, 95, 4, 67, 3, 56, 6, 52, 0, 28, 8, 18, 
    8, 79, 6, 49, 5,  9, 4, 59, 2, 67, 1, 75, 0, 25, 3, 31, 7, 97, 
    1, 59, 0, 62, 4, 60, 7, 52, 6, 95, 2, 30, 3, 80, 8,  4, 5, 56, 
    3,  5, 4, 89, 0, 57, 2, 84, 8, 71, 7, 84, 1,  5, 6, 71, 5, 25, 
    4, 19, 7, 69, 1, 14, 2, 39, 5, 97, 8,  9, 6, 47, 0, 92, 3, 34
  };
  const int q9061[] = {
    9, 9, // Number of jobs and machines
    2, 20, 7, 50, 4, 29, 3, 86, 0, 65, 8,  8, 5, 11, 1, 45, 6, 41, 
    5, 13, 8, 68, 6, 65, 0, 60, 3, 75, 7, 62, 1, 29, 2, 57, 4,  5, 
    7, 50, 1, 28, 3, 19, 4,  5, 8, 29, 2, 40, 6, 65, 0, 26, 5, 77, 
    3, 19, 2, 29, 7, 42, 5, 20, 6, 79, 8,  9, 4, 80, 1, 12, 0, 51, 
    4, 55, 1, 80, 2, 78, 8,  5, 6, 75, 0, 21, 3, 14, 7,  9, 5, 59, 
    4, 48, 3, 14, 1, 58, 5, 13, 6, 23, 0, 51, 2, 89, 7, 40, 8, 83, 
    8, 34, 3, 89, 1, 23, 4, 19, 7, 52, 2, 96, 6, 45, 5, 48, 0, 31, 
    7, 23, 1, 30, 4, 18, 6, 56, 8, 79, 0, 39, 2, 49, 5, 49, 3, 41, 
    3, 15, 4, 79, 5, 76, 8, 50, 1, 66, 6, 70, 0,  7, 2,  2, 7,  9
  };
  const int q9062[] = {
    9, 9, // Number of jobs and machines
    0, 95, 3, 77, 6, 80, 7, 43, 8, 83, 4, 62, 5,  7, 1, 67, 2, 76, 
    8, 33, 3, 81, 2, 58, 5, 14, 4, 61, 7, 72, 0, 45, 6, 62, 1, 59, 
    3, 36, 5, 43, 0, 11, 8, 88, 4, 50, 6, 43, 2, 72, 1, 46, 7, 58, 
    1, 52, 2, 60, 3, 34, 4, 42, 6, 19, 0, 94, 7, 60, 8, 53, 5, 72, 
    2,  4, 0,  8, 1, 33, 7, 96, 4, 34, 3,  5, 5, 24, 6, 18, 8, 45, 
    5, 17, 7, 27, 8, 82, 6, 38, 2, 88, 1, 47, 4, 24, 3, 59, 0,  2, 
    2, 93, 4, 70, 1, 49, 3, 97, 6, 29, 0, 96, 5, 91, 8, 77, 7,  3, 
    4, 63, 0, 74, 6, 68, 7, 58, 2, 53, 1, 86, 8, 73, 3, 99, 5, 18, 
    1, 48, 5, 58, 8, 18, 4, 46, 6, 45, 0, 53, 3, 68, 2,  3, 7, 30
  };
  const int q9063[] = {
    9, 9, // Number of jobs and machines
    7, 59, 5, 39, 8, 64, 6, 80, 0, 59, 2, 43, 4, 80, 1, 68, 3, 25, 
    6, 14, 3, 89, 7, 11, 8, 69, 4, 25, 0, 53, 2, 13, 5,  8, 1,  4, 
    5, 97, 0, 64, 3, 77, 2, 85, 1, 70, 7, 69, 8, 55, 6, 24, 4, 37, 
    1, 99, 2, 60, 4, 23, 3, 56, 8, 66, 5, 17, 7, 79, 0, 34, 6, 57, 
    6, 86, 5, 71, 0, 12, 2, 13, 1, 16, 8, 17, 3, 98, 7, 31, 4,  2, 
    4, 63, 7, 22, 0, 20, 8, 29, 2, 98, 1, 61, 3, 16, 6, 57, 5, 13, 
    1, 58, 3, 84, 8, 63, 5,  9, 0, 84, 2, 52, 6, 99, 4, 15, 7, 65, 
    4, 55, 6, 67, 5, 74, 3, 79, 0, 23, 8, 82, 1, 83, 2, 40, 7, 78, 
    8, 13, 1, 52, 5, 77, 3, 76, 7, 81, 0, 91, 6, 92, 4, 34, 2, 91
  };
  const int q9064[] = {
    9, 9, // Number of jobs and machines
    1, 56, 8, 66, 7, 98, 3, 97, 5, 54, 0, 46, 6, 40, 4, 72, 2,  4, 
    6, 92, 4, 99, 3, 17, 0, 53, 1, 14, 2, 59, 7, 44, 5, 33, 8, 43, 
    7, 55, 6, 46, 4, 62, 1, 61, 8, 43, 3, 74, 0, 62, 2, 76, 5,  5, 
    0, 41, 5, 13, 7, 32, 2, 60, 6, 50, 1, 42, 8, 69, 4, 84, 3, 94, 
    8, 71, 0, 90, 3, 47, 6, 34, 5,  2, 2, 81, 7, 46, 4, 20, 1, 24, 
    6, 31, 1, 78, 4, 25, 5,  8, 2, 11, 8, 79, 3, 97, 7, 27, 0, 77, 
    0, 91, 7, 43, 6, 30, 2, 21, 1, 23, 5, 43, 8, 46, 4, 37, 3, 43, 
    2, 61, 6, 81, 0, 32, 7, 23, 8,  8, 1, 37, 3, 65, 4, 57, 5, 24, 
    6, 13, 8, 16, 0,  2, 4, 85, 5, 55, 3, 91, 7, 85, 2, 99, 1, 32
  };
  const int q9065[] = {
    9, 9, // Number of jobs and machines
    6,  5, 4, 67, 1, 96, 7, 55, 8, 12, 0, 46, 3, 49, 5, 45, 2, 40, 
    2, 90, 1, 10, 0, 65, 4, 88, 7, 13, 8, 64, 6, 94, 5, 28, 3, 49, 
    1, 62, 2, 48, 4, 56, 8, 83, 0, 87, 5, 42, 7, 22, 3, 51, 6, 40, 
    1, 78, 0, 76, 5, 32, 3, 86, 2, 55, 8, 98, 4,  8, 7, 51, 6, 18, 
    4, 82, 5, 85, 8,  4, 1, 36, 2, 42, 0, 12, 6, 91, 7, 90, 3, 48, 
    8,  9, 7, 25, 4, 57, 5, 43, 1, 73, 3, 98, 0,  6, 6, 48, 2, 98, 
    3, 89, 6, 32, 5, 28, 2, 93, 8, 34, 1, 48, 4, 19, 7, 58, 0,  5, 
    8, 10, 2, 55, 3, 77, 7, 71, 5, 91, 0, 16, 6, 73, 1, 51, 4, 59, 
    7, 24, 0, 22, 8, 34, 1, 80, 2, 52, 5, 81, 3, 48, 6, 76, 4, 22
  };
  const int q9066[] = {
    9, 9, // Number of jobs and machines
    3, 26, 2, 29, 8, 81, 5, 39, 7, 69, 1, 17, 4, 29, 6, 26, 0, 31, 
    3, 38, 2, 95, 0, 95, 5, 68, 8, 31, 1, 92, 7, 73, 6, 13, 4,  9, 
    6, 79, 0, 75, 7, 68, 5, 72, 4, 14, 8, 27, 1, 36, 3, 34, 2, 56, 
    6, 75, 3, 39, 8, 19, 0, 56, 4, 57, 7, 85, 5, 11, 1, 42, 2, 50, 
    3,  4, 2, 33, 0, 11, 8, 25, 7,  5, 1, 19, 4, 29, 6, 45, 5, 63, 
    0, 63, 1, 84, 2, 20, 4, 17, 5, 19, 8, 22, 3, 33, 7, 93, 6, 27, 
    6, 19, 0, 40, 4, 46, 3, 27, 5, 33, 8, 98, 7, 91, 2, 74, 1, 41, 
    8, 68, 5, 59, 3, 47, 4, 96, 0, 85, 2,  7, 1, 66, 6, 66, 7, 86, 
    5, 80, 6, 64, 3, 10, 0, 75, 7,  7, 4, 29, 8, 91, 1, 94, 2, 45
  };
  const int q9067[] = {
    9, 9, // Number of jobs and machines
    7, 87, 5,  5, 8, 37, 4, 81, 1, 51, 0, 47, 3, 27, 2, 93, 6, 99, 
    5, 67, 6, 66, 7, 78, 0, 68, 2, 94, 4, 35, 1, 82, 8, 52, 3, 92, 
    1,  8, 8, 87, 6, 47, 4, 10, 2, 90, 7,  4, 0,  6, 5, 19, 3, 68, 
    1, 92, 4, 38, 8, 33, 0, 22, 7,  1, 3, 17, 6, 52, 2, 16, 5, 84, 
    1, 42, 6, 11, 4, 58, 7, 28, 3, 94, 0, 74, 8, 39, 2, 95, 5, 67, 
    6, 62, 5, 14, 3, 48, 1, 79, 0, 42, 8, 34, 4, 49, 2, 76, 7, 48, 
    2, 90, 8, 69, 1, 54, 5, 49, 6, 41, 0, 50, 4, 43, 7, 97, 3, 19, 
    8, 33, 5, 98, 7, 89, 1, 17, 6,  5, 2, 85, 3, 89, 0, 20, 4, 99, 
    3, 57, 7, 91, 6, 20, 4, 20, 5, 18, 2, 71, 1, 71, 0, 81, 8, 65
  };
  const int q9068[] = {
    9, 9, // Number of jobs and machines
    7, 11, 0, 14, 4, 40, 5, 32, 2, 14, 8, 74, 1, 90, 6, 49, 3, 42, 
    3, 42, 0, 39, 6, 59, 8, 69, 7, 24, 2, 72, 4,  2, 1, 25, 5, 48, 
    6, 66, 2, 44, 8, 39, 4, 15, 1, 89, 3, 53, 7, 79, 0,  6, 5, 81, 
    3, 91, 0, 21, 4, 29, 6, 74, 1, 68, 2, 87, 8, 11, 5, 18, 7,  6, 
    5, 18, 2, 12, 4, 68, 6, 19, 3, 56, 0, 15, 1, 29, 8, 92, 7, 53, 
    1, 49, 8, 47, 3, 84, 7, 92, 5, 86, 0, 47, 2, 43, 6, 39, 4, 56, 
    8, 30, 4, 98, 3,  8, 0, 99, 5,  1, 1, 34, 6, 16, 2, 15, 7, 41, 
    5,  4, 1, 66, 4, 71, 7, 27, 0, 73, 2, 13, 8, 29, 6, 69, 3, 68, 
    7, 35, 3, 20, 4, 16, 1,  1, 8,  8, 5, 15, 0, 87, 6, 23, 2, 40
  };
  const int q9069[] = {
    9, 9, // Number of jobs and machines
    8, 38, 5, 23, 0, 45, 3, 36, 7,  1, 4, 86, 1, 38, 6, 68, 2, 62, 
    6, 20, 5, 29, 4, 48, 2, 52, 3, 39, 0, 26, 8, 77, 1, 83, 7, 16, 
    3,  4, 0, 15, 4, 45, 1,  9, 2, 72, 8, 95, 5,  8, 7, 62, 6, 98, 
    4, 67, 2, 49, 5, 22, 1, 44, 0, 86, 7, 19, 3, 93, 6, 54, 8, 10, 
    6, 36, 1, 64, 4, 91, 7, 10, 8, 87, 2, 55, 5, 23, 3, 47, 0, 70, 
    5, 52, 3, 19, 0,  1, 4, 79, 8, 87, 1, 59, 6, 12, 2, 99, 7, 34, 
    0, 90, 8, 89, 1, 38, 3, 33, 2, 81, 6, 62, 5, 10, 4, 72, 7, 13, 
    4, 23, 7, 56, 6, 98, 3,  5, 2, 47, 8,  5, 5, 87, 0, 57, 1, 82, 
    8, 60, 0, 84, 7, 75, 4, 17, 5, 44, 3, 39, 2, 94, 1, 85, 6, 46
  };
  const int q9070[] = {
    9, 9, // Number of jobs and machines
    3, 68, 7, 57, 1, 19, 5,  1, 2, 56, 6, 46, 0, 58, 4, 27, 8, 18, 
    6, 50, 4, 87, 3, 61, 7, 75, 8, 69, 1, 62, 0,  1, 5, 21, 2,  4, 
    6, 79, 7, 65, 4, 75, 5,  3, 3, 22, 8, 30, 0,  1, 2, 88, 1, 56, 
    7, 81, 2, 65, 1, 82, 5, 68, 6,  3, 3, 73, 0, 42, 8, 36, 4, 34, 
    3, 40, 7, 70, 0, 89, 6, 68, 1, 89, 2, 61, 5,  3, 8, 76, 4, 59, 
    3, 67, 0, 67, 7,  3, 1,  7, 4, 18, 8, 12, 5, 99, 2, 50, 6,  7, 
    8, 49, 7, 22, 6, 38, 2, 15, 5, 43, 0, 25, 1, 39, 3, 73, 4, 29, 
    4, 59, 3, 75, 6, 61, 5, 57, 7, 54, 8, 75, 1, 62, 2, 30, 0, 47, 
    0, 30, 8, 46, 6, 38, 7, 75, 2, 71, 1, 53, 4, 32, 3, 19, 5, 69
  };
  const int q9071[] = {
    9, 9, // Number of jobs and machines
    0, 82, 3, 62, 8, 75, 7, 99, 1, 41, 4, 84, 2, 42, 6, 93, 5, 63, 
    0, 77, 4, 42, 7, 40, 5, 35, 3, 81, 6, 31, 1, 90, 2, 30, 8, 34, 
    0, 16, 8, 31, 3, 64, 5, 40, 2, 20, 6, 76, 7, 32, 4, 53, 1, 97, 
    4, 44, 0, 59, 7, 67, 5, 15, 6, 12, 2,  1, 1, 67, 3, 85, 8, 88, 
    8, 74, 3,  1, 1, 56, 7, 94, 5, 86, 6, 89, 4, 71, 2, 29, 0, 65, 
    6, 10, 5, 47, 8, 28, 1, 37, 7, 93, 4, 47, 0, 89, 2, 42, 3, 40, 
    1, 13, 7,  4, 5, 71, 0, 25, 2, 70, 4, 80, 8, 18, 3, 90, 6, 76, 
    4, 54, 2, 45, 8,  6, 5, 16, 7, 47, 6, 96, 3, 74, 0,  5, 1, 66, 
    8, 10, 0,  9, 4, 32, 2, 88, 7, 90, 6, 95, 1, 38, 5, 75, 3, 23
  };
  const int q9072[] = {
    9, 9, // Number of jobs and machines
    1, 92, 7, 38, 4, 34, 8, 68, 0, 87, 6, 15, 3, 34, 2, 57, 5, 98, 
    2, 14, 7, 33, 4, 67, 3, 67, 6, 74, 8, 55, 5, 25, 0, 74, 1, 54, 
    4, 37, 6, 10, 3, 12, 5, 59, 7, 90, 0, 65, 1,  1, 2,  9, 8, 52, 
    4, 70, 6, 58, 3, 26, 8,  3, 0, 41, 2, 41, 7, 32, 5, 18, 1,  4, 
    4, 89, 0, 46, 6, 97, 1, 69, 2, 56, 7, 27, 8, 47, 3, 55, 5, 11, 
    1, 35, 3, 37, 5, 62, 0, 42, 4,  3, 7,  1, 2, 76, 6, 15, 8, 99, 
    2, 72, 6, 51, 5, 58, 8, 94, 4, 90, 7, 85, 1, 44, 0, 13, 3, 62, 
    8, 53, 2, 90, 4, 51, 7, 45, 0,  5, 3, 94, 1, 14, 6, 64, 5,  9, 
    0, 62, 5, 81, 4, 29, 7, 69, 3, 63, 2, 51, 8, 60, 1, 95, 6, 24
  };
  const int q9073[] = {
    9, 9, // Number of jobs and machines
    8, 70, 2, 42, 6, 38, 4, 43, 7, 79, 5, 77, 0, 34, 1, 44, 3, 11, 
    2, 24, 0,  3, 1,  5, 5, 85, 8, 95, 3,  2, 4, 77, 7, 42, 6, 76, 
    6, 47, 0, 72, 5, 37, 2, 36, 7, 40, 3, 24, 4,  9, 1, 99, 8, 51, 
    2, 32, 1, 95, 4, 56, 0, 11, 8, 59, 3, 17, 7, 31, 6, 47, 5, 73, 
    2, 52, 0, 29, 5, 27, 8, 65, 7, 56, 3, 26, 4, 88, 1, 20, 6, 68, 
    4, 79, 6, 12, 7, 69, 8, 75, 5, 36, 3, 22, 2,  4, 1, 75, 0, 33, 
    8,  8, 3, 29, 6, 18, 2, 28, 1,  7, 5, 60, 7, 56, 0, 16, 4, 37, 
    5, 37, 2, 10, 7, 60, 4, 61, 3, 80, 0, 19, 6,  6, 1, 36, 8, 21, 
    3, 72, 2, 45, 6, 94, 4, 79, 8, 29, 5, 72, 0, 64, 1, 73, 7, 89
  };
  const int q9074[] = {
    9, 9, // Number of jobs and machines
    0, 22, 6, 35, 3, 75, 1, 93, 7, 90, 2, 36, 4, 46, 8, 34, 5, 46, 
    8, 24, 0, 12, 7, 91, 5, 77, 3, 75, 2, 34, 1, 26, 6, 68, 4, 98, 
    1,  8, 4, 29, 3, 35, 0, 32, 8, 48, 5,  2, 2, 27, 7, 46, 6, 22, 
    8, 57, 0, 32, 1, 92, 7, 68, 3, 92, 2, 42, 6, 44, 5, 10, 4, 21, 
    1, 30, 8, 71, 4, 13, 3,  5, 6, 55, 0, 35, 2, 75, 5, 24, 7, 61, 
    4, 30, 2, 44, 3, 15, 1, 30, 6, 60, 5, 85, 8, 69, 7, 86, 0, 85, 
    0, 47, 5,  2, 8, 80, 3, 67, 2, 44, 7, 29, 1, 43, 4, 97, 6, 87, 
    5, 67, 4, 85, 7, 11, 1, 60, 3, 83, 6, 79, 0,  2, 2, 37, 8, 10, 
    8, 46, 1, 22, 4, 16, 2, 39, 6, 14, 7, 66, 5, 20, 0, 53, 3, 99
  };
  const int q9075[] = {
    9, 9, // Number of jobs and machines
    5, 23, 8, 21, 3, 97, 2, 73, 4, 32, 1, 24, 6, 49, 7, 62, 0, 95, 
    3, 19, 1, 37, 4, 69, 6, 63, 8, 98, 0, 83, 7, 25, 5, 83, 2, 23, 
    2, 90, 4, 78, 1, 33, 5, 20, 6, 62, 8, 62, 0, 93, 7, 68, 3, 53, 
    1, 53, 4, 24, 5, 79, 2, 46, 6, 10, 0, 67, 3,  4, 8, 44, 7, 11, 
    0, 82, 3,  4, 7, 82, 2, 93, 8,  9, 4, 19, 5, 61, 6,  7, 1, 78, 
    0, 48, 2,  3, 4, 45, 8, 30, 5, 50, 6, 75, 7, 73, 3,  6, 1, 18, 
    8, 99, 5, 76, 1, 90, 4,  6, 0, 91, 7, 31, 2, 45, 6, 87, 3, 86, 
    7,  2, 4,  5, 1, 66, 0, 53, 6,  2, 2, 48, 8, 75, 3, 42, 5, 67, 
    7, 57, 3, 85, 2, 17, 5, 11, 0, 33, 8, 41, 6, 69, 4,  1, 1, 19
  };
  const int q9076[] = {
    9, 9, // Number of jobs and machines
    2, 89, 1, 44, 8, 87, 4, 52, 7, 92, 3,  4, 6, 61, 5, 67, 0,  5, 
    1, 80, 5, 45, 3, 17, 6, 29, 4, 29, 8, 56, 7, 42, 2, 63, 0, 14, 
    4,  9, 5, 31, 8,  7, 6, 98, 1, 83, 2, 27, 3, 43, 7, 50, 0,  7, 
    2, 84, 0, 40, 5, 51, 8, 96, 7, 73, 4, 57, 3, 83, 6,  8, 1, 51, 
    0, 99, 6, 95, 4, 84, 5, 74, 8, 79, 7, 58, 2, 20, 1, 18, 3, 50, 
    6, 42, 7, 58, 5, 40, 4, 21, 8, 65, 1, 79, 3, 70, 0, 58, 2, 65, 
    6,  8, 8, 47, 7, 66, 5, 31, 3, 74, 1, 57, 2, 90, 0, 82, 4, 17, 
    1, 33, 0, 88, 7, 91, 5,  8, 2, 16, 3,  7, 4,  5, 8, 99, 6, 51, 
    3, 38, 2, 61, 5,  8, 0, 19, 1, 85, 8, 84, 6,  6, 4, 32, 7, 80
  };
  const int q9077[] = {
    9, 9, // Number of jobs and machines
    3, 96, 1, 49, 0, 34, 4, 44, 8, 62, 5, 37, 2, 43, 6, 98, 7, 21, 
    8, 13, 5, 58, 7, 43, 2, 84, 6, 39, 1, 80, 0, 10, 3, 71, 4, 51, 
    0, 89, 2, 19, 8,  7, 5, 49, 7,  8, 4, 37, 6, 24, 1, 92, 3, 17, 
    6, 85, 8, 24, 0, 83, 5, 71, 4, 27, 3, 68, 2, 12, 7, 70, 1, 39, 
    0, 28, 6, 92, 3, 40, 4, 39, 8, 31, 7, 48, 5, 57, 1, 56, 2, 89, 
    5, 26, 0, 84, 8, 81, 4, 59, 3, 73, 2, 54, 1,  1, 6, 12, 7, 15, 
    4, 47, 3, 95, 0, 27, 8, 47, 2, 42, 1, 97, 6, 50, 5, 52, 7, 48, 
    0, 88, 8,  9, 3, 60, 1, 32, 6,  7, 2, 17, 7, 38, 4, 77, 5, 11, 
    6, 48, 5, 45, 1, 20, 4, 60, 0,  3, 7, 41, 3, 56, 8, 55, 2, 70
  };
  const int q9078[] = {
    9, 9, // Number of jobs and machines
    5,  8, 3, 99, 0, 37, 7, 11, 8, 96, 4, 23, 2, 93, 1, 43, 6, 18, 
    4, 21, 5, 46, 0, 63, 2, 26, 8, 14, 6, 48, 1, 83, 7, 36, 3, 50, 
    8, 79, 6, 59, 2, 98, 3, 98, 4, 93, 7, 37, 0, 92, 5,  6, 1, 65, 
    6, 76, 7, 15, 4, 50, 0, 86, 1, 58, 3, 59, 5, 71, 2, 62, 8,  9, 
    6, 16, 1,  3, 8, 69, 3, 77, 5,  2, 2, 39, 7, 20, 4, 82, 0, 39, 
    0, 62, 1, 51, 4, 19, 8, 21, 3, 35, 2, 67, 6,  6, 7, 15, 5, 27, 
    8, 32, 2, 52, 7, 46, 6, 51, 4, 51, 5, 79, 1,  1, 0, 92, 3, 58, 
    6, 58, 0, 47, 3, 77, 2, 74, 1, 26, 5, 46, 8,  2, 7, 94, 4, 89, 
    0, 88, 4, 47, 6,  6, 3, 79, 1, 34, 8, 21, 2,  9, 7, 19, 5, 38
  };
  const int q9079[] = {
    9, 9, // Number of jobs and machines
    6, 69, 0,  4, 5, 94, 8, 39, 2, 61, 1, 79, 4, 84, 3, 27, 7, 78, 
    3, 35, 4, 56, 8, 64, 5, 58, 6, 74, 1, 37, 2, 93, 0, 47, 7,  6, 
    0, 36, 8, 75, 6, 60, 3, 96, 2,  8, 7, 78, 4, 11, 5, 27, 1, 26, 
    2, 54, 8, 40, 7, 48, 4, 28, 1,  9, 5, 18, 6, 10, 0, 16, 3, 80, 
    1, 13, 0, 15, 5, 85, 8, 31, 7, 10, 4, 90, 6, 96, 3, 92, 2, 45, 
    7, 51, 1, 37, 5, 55, 6,  3, 3, 22, 8, 15, 4, 45, 0, 47, 2, 34, 
    2, 95, 8, 22, 5, 92, 4, 41, 6, 29, 7, 18, 0, 74, 3, 87, 1, 75, 
    1, 77, 5, 36, 0, 45, 7, 42, 2, 29, 4, 44, 3, 31, 6, 90, 8, 43, 
    0, 71, 7, 30, 1, 18, 8, 11, 2, 79, 4,  2, 3, 63, 5, 70, 6, 75
  };
  const int q9080[] = {
    9, 9, // Number of jobs and machines
    2, 11, 6, 37, 5, 28, 8,  6, 1, 92, 7,  7, 4, 57, 0, 95, 3, 99, 
    0, 36, 3, 98, 6, 36, 8, 66, 7, 40, 5, 22, 1, 61, 4, 64, 2, 33, 
    3, 93, 8, 60, 0, 52, 7, 95, 6, 59, 5, 96, 2, 84, 1, 88, 4,  4, 
    2, 96, 3, 35, 5, 52, 8, 60, 6, 90, 4, 68, 0, 55, 7, 17, 1, 12, 
    7, 79, 4,  4, 1, 85, 8, 85, 6, 23, 0, 50, 5, 73, 3, 36, 2, 44, 
    6, 59, 4, 83, 5, 13, 8, 54, 7, 33, 2, 62, 1, 72, 0, 50, 3, 95, 
    5, 21, 7, 79, 8, 51, 3, 83, 1, 41, 0, 34, 4, 13, 2, 24, 6, 23, 
    8, 28, 4, 79, 2, 92, 5, 92, 0, 92, 1, 65, 6, 84, 3, 57, 7, 43, 
    0, 14, 7, 61, 3, 44, 1,  8, 5, 31, 2, 18, 6, 21, 8, 93, 4, 48
  };
  const int q9081[] = {
    9, 9, // Number of jobs and machines
    6, 47, 3, 61, 5, 63, 2, 33, 0, 45, 4, 42, 8, 12, 1, 58, 7, 69, 
    6, 63, 0,  6, 7, 20, 4,  5, 8, 26, 3, 40, 5, 22, 1, 50, 2, 15, 
    4, 71, 3, 14, 0, 19, 8, 22, 7, 93, 1, 47, 6, 88, 5, 23, 2,  1, 
    1, 58, 0, 70, 5, 89, 8, 88, 7, 13, 2, 54, 3, 24, 6, 81, 4, 18, 
    5, 68, 6, 25, 0, 29, 8, 91, 4, 13, 3, 57, 2, 94, 1,  6, 7, 45, 
    7, 27, 3, 11, 5, 44, 0, 35, 1, 53, 8, 59, 6, 68, 4, 85, 2, 63, 
    3, 25, 0,  4, 5, 19, 4, 53, 8,  7, 7,  6, 1, 12, 2, 77, 6, 68, 
    3, 63, 8, 80, 2, 91, 5, 92, 1, 33, 4, 21, 6, 89, 0, 58, 7, 53, 
    8, 81, 4, 82, 0, 45, 6, 92, 2, 91, 7, 40, 1, 85, 5, 42, 3, 42
  };
  const int q9082[] = {
    9, 9, // Number of jobs and machines
    7, 24, 0, 80, 6, 81, 5, 98, 2, 94, 1, 59, 8,  1, 3, 16, 4, 81, 
    8, 49, 0, 58, 7, 30, 4, 84, 6,  9, 3, 32, 1, 31, 2,  5, 5, 21, 
    8, 91, 1, 55, 5, 18, 6, 64, 7, 67, 3, 30, 4, 16, 0, 11, 2, 37, 
    1, 18, 4, 42, 2, 37, 6, 28, 7, 28, 5, 95, 3,  6, 0, 13, 8,  8, 
    0, 89, 8, 12, 1, 18, 4, 20, 3, 82, 2, 19, 5, 76, 7, 38, 6, 46, 
    0, 90, 1, 95, 8, 70, 3,  7, 2, 81, 5, 59, 4, 89, 6, 97, 7, 59, 
    2, 93, 1, 50, 5, 15, 4,  7, 7, 31, 8, 43, 6, 28, 3, 22, 0, 82, 
    7, 32, 2, 93, 0, 64, 3, 89, 8, 37, 5, 89, 4, 73, 6, 38, 1, 60, 
    3, 85, 4, 34, 2, 59, 6, 37, 1, 52, 8, 79, 5,  3, 7, 76, 0, 91
  };
  const int q9083[] = {
    9, 9, // Number of jobs and machines
    4,  7, 5, 67, 2, 30, 8, 38, 6, 61, 7, 49, 3, 26, 1, 96, 0, 74, 
    5, 91, 1,  7, 7, 75, 0, 39, 2, 66, 3, 86, 8, 25, 6, 48, 4, 69, 
    5, 93, 8, 74, 1, 88, 7, 76, 4, 92, 2, 32, 6, 82, 0, 46, 3, 27, 
    0, 37, 4, 16, 7, 97, 2, 15, 8, 53, 5, 24, 1, 57, 3, 24, 6, 56, 
    4, 83, 6, 89, 0, 54, 1, 83, 7, 81, 8, 61, 2, 39, 3, 80, 5, 99, 
    6, 18, 0, 94, 5, 83, 4, 14, 3, 34, 2,  7, 8, 59, 1, 67, 7, 42, 
    4, 38, 1, 39, 0, 72, 5, 34, 3, 25, 8, 98, 2, 27, 7, 12, 6, 99, 
    0,  1, 1, 52, 7, 54, 6,  1, 2, 60, 4, 38, 5, 97, 3, 61, 8, 53, 
    2, 83, 6, 83, 5, 62, 8,  7, 1, 46, 0, 30, 4,  7, 7, 73, 3,  9
  };
  const int q9084[] = {
    9, 9, // Number of jobs and machines
    4, 93, 2, 76, 1, 55, 3, 72, 5, 22, 6, 77, 8,  1, 0, 86, 7, 90, 
    6,  8, 2, 77, 4, 18, 3, 75, 7, 29, 5, 83, 8, 43, 1, 91, 0, 36, 
    1, 73, 3, 64, 7, 73, 5, 53, 0, 90, 6, 15, 4, 92, 2, 39, 8, 85, 
    0, 92, 8, 48, 7, 36, 3, 59, 1, 58, 5, 26, 6, 71, 2, 79, 4, 58, 
    4, 67, 7, 16, 6, 56, 0, 38, 2, 41, 3, 62, 1, 13, 8, 70, 5, 63, 
    4, 99, 3, 12, 1,  2, 0, 73, 5, 68, 7, 35, 6, 76, 2, 93, 8, 99, 
    2, 34, 0, 16, 5, 29, 4, 60, 8, 10, 3, 83, 1, 68, 7, 44, 6, 29, 
    4, 95, 3, 68, 2, 71, 1,  8, 5, 35, 6, 76, 7, 54, 8, 79, 0, 94, 
    4,  9, 3, 63, 2, 55, 8, 83, 5, 39, 7, 32, 6, 17, 1,  4, 0, 13
  };
  const int q9085[] = {
    9, 9, // Number of jobs and machines
    5,  8, 2, 48, 8, 54, 1, 11, 7, 45, 6, 24, 3, 13, 4, 77, 0, 86, 
    6, 92, 8, 71, 2, 45, 1, 65, 7, 99, 3, 94, 5, 41, 4, 77, 0, 56, 
    3, 74, 5, 40, 0, 98, 7, 22, 6, 91, 8,  6, 2,  1, 4, 34, 1, 47, 
    0, 90, 1, 54, 2, 29, 5, 28, 3, 12, 6, 34, 4, 92, 7, 75, 8, 45, 
    1, 39, 5,  5, 8, 42, 3, 32, 7, 94, 2, 64, 4, 47, 0, 80, 6, 58, 
    1, 62, 2,  3, 3, 90, 4, 84, 5, 58, 0, 10, 8, 66, 6,  5, 7, 33, 
    8, 14, 1, 95, 2, 63, 6, 95, 0, 58, 3, 24, 7, 97, 4, 10, 5, 97, 
    1, 47, 4, 73, 5, 62, 8, 14, 3, 24, 2, 98, 0, 76, 6, 32, 7, 19, 
    7,  2, 1, 22, 5, 61, 3, 72, 8, 81, 2, 84, 6, 54, 4, 47, 0, 43
  };
  const int q9086[] = {
    9, 9, // Number of jobs and machines
    4,  9, 8,  2, 6, 39, 3, 81, 2, 99, 0, 35, 5, 89, 1, 60, 7, 80, 
    3,  3, 5, 58, 7, 88, 2, 53, 1, 12, 0, 91, 8, 67, 6, 42, 4, 99, 
    8, 81, 2, 46, 5, 82, 4, 75, 0, 43, 6, 25, 3, 30, 7, 43, 1, 91, 
    6, 48, 4, 28, 1, 17, 2, 20, 0, 76, 5, 74, 3, 53, 8, 25, 7, 75, 
    3, 92, 0, 40, 2, 92, 6, 91, 8, 76, 1, 46, 4, 34, 7, 19, 5, 93, 
    4, 95, 0, 74, 2, 91, 8, 62, 7,  1, 6, 11, 3, 45, 1, 44, 5, 16, 
    5, 76, 8, 20, 6, 48, 0, 87, 7, 36, 1, 19, 2, 69, 4, 50, 3, 49, 
    3, 81, 2, 96, 1, 96, 6, 74, 5,  2, 0,  9, 4, 94, 7,  8, 8, 97, 
    1,  8, 5,  7, 0, 10, 3, 22, 7, 47, 8, 58, 2, 76, 6, 74, 4, 37
  };
  const int q9087[] = {
    9, 9, // Number of jobs and machines
    8, 46, 3, 97, 6, 68, 5, 42, 2, 92, 7, 76, 1, 12, 4,  3, 0, 30, 
    6,  9, 1, 27, 2,  6, 8, 37, 0,  2, 4, 27, 3, 89, 7, 97, 5, 39, 
    3,  2, 2, 22, 6, 54, 0, 50, 1, 96, 5, 30, 4, 98, 7, 10, 8, 83, 
    0, 60, 4, 29, 3, 38, 5, 57, 6, 81, 2, 39, 7, 69, 1, 83, 8, 81, 
    2, 59, 3, 31, 1, 21, 6, 21, 0, 61, 7,  7, 4, 97, 5, 35, 8,  2, 
    6,  3, 3, 17, 4, 28, 5, 64, 1, 95, 2, 81, 8, 46, 0, 17, 7, 53, 
    5, 21, 2, 84, 4, 37, 0,  5, 8,  8, 6, 79, 7, 24, 1, 96, 3, 55, 
    5, 43, 0, 13, 3, 23, 4, 12, 8, 18, 2, 35, 7, 55, 6,  7, 1, 38, 
    2, 61, 5, 37, 0, 79, 1, 96, 7, 66, 3, 46, 6, 11, 8, 73, 4, 87
  };
  const int q9088[] = {
    9, 9, // Number of jobs and machines
    5,  6, 7,  9, 4, 59, 1,  6, 8, 29, 6, 59, 3, 91, 2, 15, 0, 63, 
    5,  8, 1, 47, 7, 55, 6, 82, 3, 44, 4, 10, 0, 99, 2, 44, 8, 30, 
    8, 89, 2, 48, 7,  2, 0, 88, 6, 99, 5,  6, 1, 97, 3, 37, 4, 14, 
    2, 65, 6, 52, 7, 86, 1, 64, 3, 65, 0, 35, 8, 13, 5, 85, 4, 61, 
    0, 48, 3,  7, 1, 29, 4, 84, 6, 72, 8, 22, 7, 80, 5, 25, 2, 12, 
    8, 99, 3, 49, 7, 19, 1,  6, 2, 62, 4, 79, 5, 11, 0, 37, 6, 43, 
    7, 32, 5, 12, 0, 59, 6, 33, 8, 59, 1, 85, 2, 18, 3, 91, 4,  8, 
    5,  5, 6, 65, 2, 23, 0, 80, 8, 50, 3, 40, 7, 30, 4, 46, 1, 75, 
    7,  1, 8, 48, 5, 85, 1, 73, 3, 69, 0, 15, 4, 36, 6, 87, 2, 89
  };
  const int q9089[] = {
    9, 9, // Number of jobs and machines
    8, 68, 3, 73, 5,  4, 0,  7, 4, 81, 2, 77, 7,  3, 1, 54, 6, 16, 
    3, 76, 2, 56, 1, 48, 4, 89, 7, 20, 8, 70, 5, 41, 6, 30, 0, 29, 
    5, 40, 3, 99, 1, 85, 8, 67, 7, 25, 4, 28, 6, 99, 2, 33, 0, 29, 
    1, 68, 4, 20, 3, 59, 7, 90, 8, 79, 2, 93, 5, 10, 6, 16, 0, 85, 
    8, 76, 0, 81, 1, 28, 6, 39, 4, 15, 5, 84, 7, 26, 2,  8, 3, 54, 
    7, 61, 1, 22, 0, 94, 4, 12, 3,  7, 5, 27, 8, 74, 6,  3, 2, 25, 
    3, 61, 7, 71, 0, 64, 4,  9, 5, 50, 8,  3, 6, 24, 1, 12, 2, 54, 
    3, 81, 0, 96, 2, 68, 7, 80, 8, 83, 1, 26, 5, 64, 4, 91, 6, 65, 
    5, 25, 3,  7, 7, 86, 8, 34, 0, 88, 2, 80, 6, 10, 1, 44, 4, 79
  };
  const int q9090[] = {
    9, 9, // Number of jobs and machines
    1, 32, 8, 22, 4, 84, 3, 13, 2, 63, 6, 15, 0, 34, 5, 51, 7,  4, 
    1, 87, 7, 69, 5, 81, 6, 94, 0, 93, 8, 95, 4, 58, 3, 50, 2, 43, 
    6, 86, 7,  8, 4, 50, 2, 67, 3, 90, 5, 79, 8, 62, 0, 70, 1, 44, 
    8, 46, 4,  4, 7, 50, 1, 40, 5, 58, 6, 84, 2, 27, 0, 50, 3, 55, 
    1, 23, 8, 99, 2, 26, 0, 51, 6, 60, 4, 61, 3, 86, 7, 41, 5, 97, 
    6, 86, 8, 21, 5, 34, 1, 32, 7, 22, 3, 45, 0,  5, 2, 44, 4, 90, 
    4, 62, 8, 98, 5, 53, 0, 45, 6, 63, 2, 73, 1,  4, 7, 18, 3, 75, 
    7, 81, 2, 65, 1, 75, 3, 32, 8, 57, 4, 83, 6, 63, 0, 13, 5, 34, 
    0, 56, 3, 39, 6, 11, 8, 75, 5,  2, 4,  6, 7,  3, 1, 95, 2, 27
  };
  const int q9091[] = {
    9, 9, // Number of jobs and machines
    6, 65, 7, 26, 3, 76, 0, 57, 1, 22, 4, 90, 8, 85, 5, 17, 2,  7, 
    3, 45, 6, 51, 7, 50, 1, 44, 0, 48, 2, 25, 5, 80, 4, 93, 8, 38, 
    5, 18, 1, 97, 7, 66, 8, 11, 4, 82, 2, 53, 3, 67, 6, 44, 0, 96, 
    4, 81, 1, 57, 3, 39, 8, 15, 6, 24, 5, 81, 0, 13, 7, 91, 2, 49, 
    3, 87, 6, 80, 5, 61, 1, 16, 4, 17, 2, 52, 8, 61, 0, 49, 7, 85, 
    1, 32, 5, 63, 7, 33, 4, 15, 6,  5, 0, 62, 2,  3, 8, 58, 3, 87, 
    1, 21, 4, 81, 2, 95, 5, 33, 3, 63, 6, 65, 0, 62, 8, 76, 7, 89, 
    7, 57, 1,  5, 3, 94, 2, 98, 4, 76, 0,  3, 6, 42, 5, 71, 8, 11, 
    7, 76, 8,  5, 5, 92, 6, 41, 2, 88, 4,  3, 0, 92, 1, 69, 3, 66
  };
  const int q9092[] = {
    9, 9, // Number of jobs and machines
    8, 58, 5, 86, 4, 76, 1, 76, 2, 71, 6,  4, 7, 10, 0, 33, 3, 59, 
    0, 66, 5, 85, 4,  7, 7, 17, 8, 46, 3, 13, 1, 22, 6,  3, 2, 91, 
    0, 64, 5, 90, 1, 84, 3, 68, 8, 75, 2, 81, 7, 40, 4, 49, 6, 60, 
    4, 55, 6, 24, 0, 63, 8, 14, 5, 72, 7, 17, 2, 63, 3,  1, 1, 10, 
    1, 31, 6,  3, 5, 42, 8, 74, 3, 55, 2, 50, 4, 47, 7,  7, 0, 64, 
    2, 54, 0, 84, 8,  4, 1, 19, 4, 74, 6, 55, 5, 17, 3, 24, 7, 98, 
    6, 61, 1, 34, 2, 98, 0,  5, 7, 86, 4, 61, 8, 77, 5, 72, 3, 59, 
    6, 10, 5, 79, 1, 48, 7, 10, 8, 96, 3, 37, 4, 44, 0, 71, 2, 73, 
    6, 83, 0, 68, 7, 79, 3, 36, 2, 23, 8,  6, 4, 23, 1, 32, 5, 34
  };
  const int q9093[] = {
    9, 9, // Number of jobs and machines
    2, 99, 5, 49, 3, 75, 1,  2, 7, 28, 6, 53, 8, 59, 4, 41, 0, 70, 
    2, 59, 8, 40, 3, 79, 7, 82, 1, 63, 0, 95, 4, 49, 6, 48, 5, 34, 
    3, 66, 2, 61, 7, 91, 0, 11, 6, 98, 5, 77, 4, 26, 8, 25, 1, 28, 
    7, 65, 5, 86, 0,  5, 1, 20, 2,  7, 3, 17, 6, 58, 8,  1, 4, 89, 
    7, 27, 8, 23, 1, 97, 4, 36, 6, 76, 3, 32, 0, 30, 2, 71, 5, 85, 
    6, 74, 5, 79, 1, 85, 7, 35, 8,  6, 3, 10, 4, 50, 2, 53, 0, 33, 
    4, 90, 5, 12, 0, 66, 1, 50, 3,  3, 8,  7, 6, 40, 7, 61, 2, 39, 
    3, 79, 0, 54, 6, 52, 4, 22, 2,  4, 7, 51, 1, 78, 8, 54, 5, 80, 
    0, 39, 1, 85, 7, 86, 4, 37, 5, 23, 6, 64, 2, 81, 8, 50, 3, 42
  };
  const int q9094[] = {
    9, 9, // Number of jobs and machines
    5, 51, 2, 66, 0, 52, 6, 83, 1, 49, 8, 75, 7, 75, 4, 93, 3, 60, 
    6, 28, 3, 27, 7, 36, 5, 43, 2, 68, 0, 89, 8, 80, 4, 14, 1, 64, 
    8, 61, 1, 62, 6, 46, 4, 88, 3, 45, 0, 72, 2, 26, 7, 75, 5, 23, 
    5, 12, 7, 87, 1, 77, 3, 41, 6, 35, 8, 22, 4, 14, 0, 57, 2, 49, 
    3, 70, 1, 82, 0, 95, 5, 49, 4, 74, 7, 25, 2, 46, 8, 94, 6, 46, 
    0, 50, 2, 14, 7, 96, 8, 26, 3, 39, 4, 55, 5, 80, 1, 12, 6, 49, 
    8, 46, 3, 21, 0, 98, 7, 23, 5, 15, 4, 23, 1, 20, 6, 35, 2, 53, 
    1, 69, 5, 62, 6, 14, 7, 42, 0, 77, 8, 27, 3, 85, 4, 98, 2,  2, 
    7, 45, 4, 48, 0, 51, 5, 65, 8, 21, 3, 23, 2, 65, 1, 21, 6, 67
  };
  const int q9095[] = {
    9, 9, // Number of jobs and machines
    7, 74, 0, 86, 6, 21, 1, 53, 8, 27, 5, 30, 4, 77, 2, 99, 3, 28, 
    5, 26, 2, 16, 1, 37, 4, 87, 0, 86, 6, 83, 7, 21, 3, 55, 8, 60, 
    8, 22, 2,  9, 1, 45, 5, 96, 7, 34, 3, 27, 4, 75, 0, 58, 6, 21, 
    4, 28, 3,  6, 6, 41, 5, 38, 7, 18, 1, 78, 0, 25, 8, 70, 2, 51, 
    6, 47, 4,  3, 5, 71, 2, 35, 3, 13, 8, 40, 0, 28, 7, 74, 1, 60, 
    4, 69, 3, 53, 8,  6, 2, 68, 7, 89, 0, 54, 6, 78, 1, 18, 5, 13, 
    4, 50, 6,  7, 3, 92, 8, 84, 0, 90, 2, 68, 5, 31, 7, 57, 1, 48, 
    8, 36, 0,  3, 5,  7, 7, 29, 3, 71, 6, 35, 1, 25, 4, 49, 2, 89, 
    2, 26, 0, 28, 6, 43, 5, 25, 7, 81, 1, 70, 8, 57, 4, 67, 3, 75
  };
  const int q9096[] = {
    9, 9, // Number of jobs and machines
    6, 85, 7, 77, 3, 15, 2, 48, 0, 34, 4, 41, 8, 49, 1, 91, 5, 21, 
    5, 66, 3, 15, 6, 88, 0, 75, 7, 17, 8, 63, 1, 98, 2, 41, 4, 38, 
    7, 24, 6, 52, 5, 78, 4, 84, 0, 47, 1, 80, 3,  8, 2, 72, 8, 66, 
    8,  2, 3, 15, 6, 38, 4, 17, 7, 97, 1, 19, 0, 66, 5, 97, 2, 83, 
    6, 97, 5,  9, 0, 72, 3, 43, 7, 97, 2, 42, 8, 54, 1, 84, 4,  2, 
    7, 34, 5, 65, 4, 63, 6, 62, 2, 43, 3, 80, 0, 68, 1, 84, 8, 94, 
    6,  7, 0, 23, 3, 37, 5, 49, 8, 95, 4, 79, 7, 98, 2, 84, 1, 35, 
    0, 43, 8, 61, 6, 44, 5, 13, 4,  6, 7, 20, 1,  5, 3, 96, 2,  9, 
    0,  8, 7, 32, 4, 28, 5, 59, 8, 15, 6, 58, 2, 65, 3, 24, 1, 23
  };
  const int q9097[] = {
    9, 9, // Number of jobs and machines
    8, 72, 1, 30, 3, 23, 5, 99, 2, 79, 0, 46, 4,  8, 6,  3, 7, 50, 
    5, 34, 0, 88, 6, 75, 4, 10, 8, 99, 3, 14, 7, 41, 1, 87, 2, 73, 
    8, 96, 4, 19, 3, 98, 6,  6, 5, 99, 1, 35, 7,  7, 2, 33, 0, 26, 
    3, 51, 8, 46, 7, 61, 4, 26, 6,  6, 1, 78, 0, 27, 5, 70, 2, 95, 
    2, 21, 7, 18, 5, 69, 8,  7, 6, 78, 1, 35, 3, 46, 0, 26, 4, 36, 
    7,  7, 6, 94, 0,  6, 4, 62, 1, 13, 2, 82, 5, 65, 8, 20, 3, 95, 
    2, 76, 7,  8, 1, 80, 8, 47, 5, 71, 0, 80, 3, 62, 4, 47, 6, 38, 
    0, 41, 5, 84, 8, 51, 6, 73, 3, 28, 7, 67, 1, 57, 4, 67, 2,  3, 
    0, 39, 8, 20, 6, 20, 1, 43, 3, 36, 4, 27, 7, 64, 2, 23, 5, 97
  };
  const int q9098[] = {
    9, 9, // Number of jobs and machines
    2, 53, 7, 73, 4, 46, 0, 94, 6, 15, 3, 46, 1, 14, 5, 93, 8, 19, 
    2, 42, 3, 18, 1, 75, 8, 16, 6, 10, 7, 94, 5, 85, 4, 17, 0,  5, 
    6, 24, 3, 21, 4, 82, 8, 37, 5, 87, 1, 31, 0, 36, 2, 16, 7, 57, 
    3, 13, 5, 29, 0, 14, 6, 66, 8, 34, 4, 19, 7, 40, 2, 63, 1, 14, 
    4, 71, 7, 77, 8, 40, 0, 75, 2, 65, 1, 58, 6, 82, 5,  2, 3, 70, 
    1, 75, 3, 99, 8,  2, 5, 24, 0, 86, 4, 19, 7, 74, 2, 89, 6, 24, 
    2, 31, 5, 26, 7, 81, 6, 89, 0,  5, 8, 39, 3, 40, 1,  8, 4, 64, 
    7, 53, 1, 44, 4, 84, 0, 87, 2, 83, 3, 30, 5, 45, 8, 80, 6, 30, 
    0,  3, 8, 80, 4, 38, 6, 86, 3, 74, 7, 89, 1, 61, 5, 89, 2,  2
  };
  const int q9099[] = {
    9, 9, // Number of jobs and machines
    2, 30, 1, 40, 0, 50, 4, 15, 8, 44, 6, 52, 7, 30, 3, 11, 5, 60, 
    1,  8, 0, 38, 4, 22, 7, 72, 5, 17, 6, 92, 3, 13, 2, 50, 8, 69, 
    8, 91, 2, 37, 4,  1, 6, 31, 1, 97, 7, 26, 5, 74, 3, 53, 0, 56, 
    4, 49, 5, 61, 7, 47, 8, 16, 6, 50, 2, 13, 1, 72, 3, 10, 0,  6, 
    7, 10, 1, 10, 8,  6, 5,  8, 4, 89, 0, 84, 6, 20, 3, 44, 2, 33, 
    8,  3, 1, 66, 2, 99, 6, 37, 3, 88, 4, 96, 0,  6, 5, 38, 7, 60, 
    7, 22, 1, 69, 8, 88, 2, 52, 5, 33, 3, 74, 4, 64, 6, 47, 0, 39, 
    2,  3, 0, 11, 1, 92, 8,  8, 6, 57, 5, 62, 3, 94, 4, 63, 7, 49, 
    6, 85, 3, 65, 2, 74, 4, 17, 5, 11, 1, 52, 8, 15, 0, 78, 7, 33
  };
  const int q9100[] = {
    9, 9, // Number of jobs and machines
    1, 93, 5, 48, 8, 17, 6,  6, 4, 88, 0, 71, 7, 99, 2, 77, 3, 50, 
    2, 59, 3, 69, 5, 49, 8,  7, 1, 36, 0, 16, 7, 95, 4, 45, 6, 79, 
    1, 50, 3, 64, 7, 91, 6, 13, 8, 91, 5, 87, 0, 43, 2, 97, 4, 93, 
    6, 11, 5, 10, 2, 25, 7, 74, 4, 92, 3,  9, 8, 48, 0, 53, 1, 10, 
    6, 79, 2, 51, 8, 61, 5, 25, 3, 82, 7,  6, 4, 93, 1, 32, 0, 46, 
    7, 24, 4, 98, 8, 42, 1, 43, 2, 36, 5, 19, 6, 51, 0, 59, 3, 89, 
    3, 48, 5, 60, 8, 19, 0, 52, 1, 99, 2,  3, 4,  6, 6, 79, 7, 94, 
    6, 27, 3, 92, 1,  1, 0, 22, 8, 28, 7, 73, 2, 57, 4, 30, 5, 45, 
    5, 33, 4, 68, 1, 49, 2, 96, 7, 19, 8, 42, 6, 96, 3, 31, 0, 89
  };
  const int q9101[] = {
    9, 9, // Number of jobs and machines
    0, 43, 5, 39, 8, 90, 3, 54, 6, 83, 7, 64, 1, 24, 4, 28, 2, 20, 
    0, 49, 5, 51, 6, 25, 1, 72, 4, 73, 2, 23, 7, 34, 8, 98, 3, 12, 
    5, 54, 7, 14, 4, 89, 3,  4, 6, 92, 1, 41, 8,  9, 0, 34, 2, 59, 
    4, 28, 7, 47, 3, 79, 0, 89, 8,  8, 5, 62, 6, 80, 2, 31, 1, 17, 
    6, 45, 5, 42, 2, 13, 0, 85, 3, 64, 1, 46, 7, 48, 4, 69, 8, 76, 
    0, 68, 1, 44, 5, 12, 2, 69, 6, 96, 8, 70, 7, 70, 4, 20, 3, 43, 
    1, 82, 4, 44, 8, 32, 7, 21, 5, 71, 6, 46, 0, 30, 3,  5, 2, 40, 
    3, 96, 8, 18, 6, 10, 4, 89, 5, 51, 1, 39, 0, 39, 7, 54, 2, 24, 
    6, 13, 3, 25, 0, 66, 7, 23, 1, 80, 8, 22, 2, 30, 5, 63, 4, 46
  };
  const int q9102[] = {
    9, 9, // Number of jobs and machines
    1, 67, 6, 28, 3,  2, 7, 89, 5, 34, 4, 59, 8, 44, 2, 64, 0, 42, 
    4, 72, 0, 56, 7, 50, 8, 63, 2, 88, 5, 98, 6, 75, 3, 68, 1, 42, 
    2, 90, 5, 89, 3, 40, 1, 38, 8, 40, 7, 57, 0, 29, 4, 72, 6, 44, 
    2, 77, 3, 80, 7, 49, 1, 94, 8,  8, 4,  5, 6, 40, 5, 47, 0,  5, 
    6, 30, 1, 68, 5, 20, 8, 69, 0, 85, 3,  2, 4, 45, 7, 68, 2, 56, 
    2, 49, 3, 73, 1,  4, 5,  5, 6, 32, 7, 95, 0, 46, 8, 71, 4,  8, 
    2, 96, 0, 86, 6, 35, 1, 71, 4, 17, 8, 19, 7, 61, 5, 56, 3,  7, 
    7, 76, 6, 87, 4,  9, 8,  2, 1, 78, 5, 18, 2, 83, 0, 23, 3, 52, 
    4, 22, 6, 77, 7, 24, 1, 91, 3, 93, 0,  7, 8, 18, 5, 73, 2, 49
  };
  const int q9103[] = {
    9, 9, // Number of jobs and machines
    0, 90, 8, 26, 5, 24, 3, 19, 7, 28, 1, 54, 2, 92, 6, 60, 4, 26, 
    3,  2, 1, 23, 5, 15, 0, 96, 4, 27, 6, 75, 8, 64, 2, 19, 7, 96, 
    8, 22, 6, 84, 0, 67, 4, 60, 2,  4, 3, 19, 1, 74, 5, 40, 7, 88, 
    4, 60, 0, 20, 7, 41, 2, 56, 5, 43, 8,  1, 1, 33, 3, 70, 6, 87, 
    4, 26, 7, 20, 8, 36, 3, 78, 5, 34, 2, 13, 0, 24, 1, 51, 6, 94, 
    8,  2, 7, 53, 0, 80, 6, 27, 1,  4, 2, 95, 4, 73, 3, 84, 5, 11, 
    5, 34, 4, 99, 3, 59, 6, 46, 2, 79, 0, 30, 1, 16, 8,  2, 7, 84, 
    4, 28, 2, 13, 5, 10, 8, 51, 3, 26, 6, 22, 7, 63, 1, 63, 0, 62, 
    3, 78, 5, 52, 2, 87, 8, 61, 0, 53, 4, 70, 1, 66, 7, 95, 6, 21
  };
  const int q9104[] = {
    9, 9, // Number of jobs and machines
    0, 81, 6, 19, 8, 56, 5, 81, 7, 33, 4,  7, 1, 49, 2,  5, 3, 28, 
    6, 79, 8, 82, 1, 15, 5, 40, 0, 59, 2, 79, 3, 26, 4, 33, 7, 77, 
    0, 84, 7, 85, 5, 86, 8, 43, 2,  6, 6, 73, 3, 11, 4, 95, 1, 16, 
    5,  4, 4, 87, 6, 82, 3, 97, 8, 85, 1,  9, 7, 47, 0, 91, 2, 89, 
    5, 34, 6, 57, 8, 84, 3, 18, 7, 64, 1, 40, 2, 58, 4,  1, 0, 27, 
    7, 43, 1, 80, 5, 88, 0, 85, 4, 86, 8, 38, 3, 24, 2, 26, 6,  3, 
    6, 73, 2, 10, 1, 51, 3, 31, 5, 39, 8, 74, 4, 44, 0, 27, 7, 30, 
    8, 37, 3,  9, 0, 74, 2, 92, 4, 97, 1, 79, 6, 18, 7, 32, 5, 14, 
    8, 34, 3, 73, 6, 33, 0,  1, 1, 50, 5, 19, 7, 11, 4, 39, 2, 37
  };
  const int q9105[] = {
    9, 9, // Number of jobs and machines
    4,  7, 0, 87, 2, 43, 1, 57, 7, 89, 3, 54, 5, 59, 8, 50, 6, 29, 
    0, 56, 4, 69, 3, 47, 1, 45, 7, 73, 8, 40, 2, 90, 5, 41, 6, 13, 
    3, 89, 4, 53, 0, 21, 5, 45, 7, 62, 6, 53, 8, 50, 2, 34, 1, 14, 
    7,  7, 8,  8, 1, 71, 3, 34, 2, 13, 5, 57, 0,  8, 6, 53, 4, 86, 
    5, 12, 0, 40, 2,  2, 3,  6, 1, 99, 7, 10, 4,  5, 6, 83, 8, 65, 
    0, 10, 6, 14, 2, 27, 3, 75, 8, 69, 4, 90, 7, 94, 5, 36, 1, 71, 
    3, 59, 2, 68, 0, 45, 6, 86, 1, 19, 8, 84, 5, 22, 7, 24, 4, 56, 
    2, 37, 8, 82, 5, 98, 0, 26, 7, 53, 1, 77, 3, 17, 4, 73, 6, 61, 
    1, 24, 0,  5, 5, 95, 6, 59, 7, 74, 3, 10, 2, 26, 8, 54, 4,  3
  };
  const int q9106[] = {
    9, 9, // Number of jobs and machines
    0, 58, 4, 65, 2, 76, 5, 77, 1, 51, 8,  1, 6, 23, 3, 10, 7, 45, 
    4, 18, 0, 15, 8, 90, 1, 38, 7, 57, 2, 51, 6, 28, 5, 58, 3, 16, 
    4, 90, 7,  9, 0, 37, 3, 29, 2,  9, 8, 17, 5,  7, 1, 79, 6, 39, 
    2, 33, 0, 16, 5, 82, 4, 55, 8, 38, 7, 82, 3, 31, 1, 80, 6, 72, 
    4, 75, 1, 51, 8, 40, 5, 61, 6, 89, 3, 87, 7,  4, 0, 35, 2, 89, 
    3, 73, 2, 43, 4, 17, 0, 33, 6, 60, 5,  2, 7, 59, 1, 32, 8, 43, 
    0, 32, 1, 81, 3,  9, 5,  6, 7, 17, 8, 29, 6, 56, 4, 85, 2, 10, 
    2, 63, 6, 21, 3, 34, 8, 26, 0, 92, 5,  6, 7,  4, 1, 83, 4, 33, 
    4, 51, 5, 77, 2, 25, 8, 93, 7, 37, 0, 50, 1, 38, 3, 64, 6,  9
  };
  const int q9107[] = {
    9, 9, // Number of jobs and machines
    0, 45, 5, 17, 8, 34, 3, 46, 7, 57, 4, 82, 2, 22, 1, 52, 6, 14, 
    0, 25, 1, 54, 8, 44, 3, 81, 7, 37, 6, 33, 5, 26, 2, 30, 4, 73, 
    7, 41, 8, 53, 6, 84, 0, 34, 1, 70, 4, 65, 5, 75, 3, 34, 2, 70, 
    6, 65, 5, 42, 7, 82, 1, 49, 0, 56, 8, 83, 3, 60, 4, 14, 2,  1, 
    1,  5, 6,  2, 7,  5, 2, 43, 5, 66, 8, 42, 3, 46, 4, 69, 0, 20, 
    3, 63, 8,  8, 1,  9, 7,  8, 0,  1, 4, 46, 6, 81, 2, 66, 5, 42, 
    3, 25, 8, 83, 7, 61, 5, 75, 1, 17, 4, 80, 6,  6, 2, 92, 0, 76, 
    6, 14, 4, 69, 0, 83, 3, 42, 5, 84, 8, 37, 7, 62, 1, 84, 2, 95, 
    0, 85, 4, 58, 8, 53, 6, 97, 1, 31, 7,  5, 5, 65, 3, 48, 2, 45
  };
  const int q9108[] = {
    9, 9, // Number of jobs and machines
    2, 16, 7, 15, 4, 19, 8, 56, 5, 80, 6,  9, 1, 55, 3,  5, 0,  7, 
    7, 36, 1, 83, 0, 36, 2, 74, 5, 36, 8, 51, 6, 20, 4, 92, 3, 18, 
    8,  8, 6, 41, 5, 12, 1, 52, 4, 56, 3, 53, 2,  3, 7,  5, 0, 80, 
    4, 31, 8, 57, 3, 92, 1, 89, 6, 48, 5, 92, 7, 34, 0, 78, 2, 42, 
    8, 12, 5, 25, 4, 50, 7, 84, 0, 28, 1, 23, 3, 35, 2, 61, 6, 79, 
    6,  9, 1, 56, 3, 16, 5, 10, 0, 99, 7, 28, 2, 81, 8, 93, 4,  4, 
    6,  3, 2, 85, 7, 56, 4, 97, 5, 69, 0, 89, 3, 24, 8, 52, 1, 70, 
    1, 82, 0,  3, 2, 17, 4, 42, 5, 48, 7, 43, 6, 82, 3, 27, 8, 56, 
    3, 67, 8, 89, 0, 38, 1, 48, 7, 91, 5, 25, 6, 91, 4,  1, 2,  6
  };
  const int q9109[] = {
    9, 9, // Number of jobs and machines
    2, 25, 4, 15, 6, 23, 7, 49, 1, 98, 8,  7, 5, 36, 3,  2, 0,  6, 
    7, 19, 1, 60, 8, 57, 6, 25, 4, 20, 0,  1, 3, 53, 5, 31, 2, 26, 
    8,  4, 4, 20, 2, 88, 0, 22, 5, 64, 6, 54, 7, 16, 3, 87, 1, 93, 
    2, 60, 7,  1, 8, 82, 4, 90, 0, 77, 6, 69, 5, 46, 1, 92, 3, 51, 
    1, 29, 8, 80, 5, 22, 0, 13, 4, 11, 6, 11, 7, 74, 3, 84, 2, 77, 
    7, 27, 4,  7, 3, 77, 5, 57, 6, 96, 2, 19, 1, 73, 8, 33, 0,  5, 
    6, 78, 2, 55, 3, 63, 0, 48, 5, 59, 4, 58, 1, 69, 7, 27, 8, 92, 
    3, 55, 8, 95, 6, 84, 5, 79, 1,  9, 7, 86, 4, 95, 0, 78, 2, 88, 
    5, 60, 8, 89, 4, 70, 6, 63, 1, 92, 3, 48, 7, 34, 0, 33, 2, 68
  };
  const int q9110[] = {
    9, 9, // Number of jobs and machines
    1, 30, 4, 27, 2, 17, 0, 38, 5, 94, 8, 54, 6,  5, 7,  4, 3, 73, 
    4, 11, 1, 84, 6, 92, 0, 48, 8, 25, 2, 99, 7, 71, 5, 90, 3, 82, 
    7, 18, 6, 89, 2, 79, 4, 30, 0, 58, 3, 51, 1, 58, 8, 37, 5, 45, 
    4, 24, 0, 84, 2, 61, 6, 88, 8, 32, 7, 33, 3, 37, 1, 88, 5, 12, 
    8, 58, 5, 82, 0, 64, 6, 12, 7, 99, 3, 28, 2, 81, 4, 90, 1, 57, 
    7, 79, 0, 98, 1, 72, 5, 85, 8, 19, 2, 89, 6, 52, 3, 75, 4, 49, 
    3, 91, 1, 54, 4,  5, 2, 41, 6, 38, 0, 53, 8, 44, 5, 96, 7, 57, 
    0, 82, 2, 70, 6, 30, 5,  4, 7, 56, 1, 84, 4, 17, 8, 98, 3, 53, 
    1, 12, 5, 61, 4, 31, 2, 24, 0, 73, 3, 15, 7, 63, 8, 90, 6,  1
  };
  const int q9111[] = {
    9, 9, // Number of jobs and machines
    6, 38, 3, 68, 5, 77, 8, 49, 4,  3, 0, 33, 2, 13, 7, 60, 1, 95, 
    3, 83, 4, 97, 5, 48, 7,  9, 1, 67, 6, 18, 0, 13, 8, 58, 2, 60, 
    3, 98, 6, 14, 7, 47, 2, 23, 5, 74, 4, 36, 8, 43, 0, 67, 1, 37, 
    3,  8, 4, 29, 2, 10, 8,  5, 5, 70, 1, 65, 7, 53, 6,  4, 0, 64, 
    3, 36, 1, 45, 4, 66, 6, 93, 5, 30, 2, 30, 7, 11, 0, 68, 8, 87, 
    5, 77, 1, 21, 3, 35, 8, 72, 7, 24, 0, 80, 2, 91, 4, 32, 6, 24, 
    8, 14, 5, 49, 1, 77, 7, 10, 0, 57, 6,  6, 2, 55, 3, 83, 4, 22, 
    2, 82, 7, 95, 1, 87, 4,  8, 5,  8, 0, 33, 6, 98, 8, 17, 3, 34, 
    8,  4, 2, 51, 0, 95, 3, 90, 1, 75, 6, 76, 7, 80, 5, 95, 4, 29
  };
  const int q9112[] = {
    9, 9, // Number of jobs and machines
    5,  5, 0, 92, 2, 38, 8, 54, 4, 13, 1, 29, 6,  7, 7,  1, 3, 85, 
    1, 75, 4,  4, 6, 87, 0, 49, 3, 66, 8, 31, 7, 72, 2,  7, 5, 28, 
    1, 45, 2, 19, 3, 68, 8, 74, 4, 45, 5, 15, 7, 59, 6,  1, 0, 51, 
    7, 77, 5, 74, 2, 89, 8, 80, 6, 89, 1, 55, 0, 51, 4, 85, 3, 87, 
    2, 86, 1, 58, 6,  1, 7, 34, 8, 69, 3, 13, 0, 43, 5, 39, 4, 18, 
    8, 43, 2, 65, 6, 21, 0, 31, 4, 87, 1,  5, 5, 42, 7, 50, 3, 80, 
    2, 77, 3, 25, 5,  6, 1, 35, 6, 76, 0, 78, 8, 19, 4, 13, 7, 95, 
    1, 78, 3, 59, 8, 48, 2, 33, 5, 73, 4, 74, 7,  8, 0, 57, 6, 57, 
    1, 73, 6, 39, 0, 56, 4, 76, 2, 79, 5, 55, 3, 71, 7, 88, 8, 19
  };
  const int q9113[] = {
    9, 9, // Number of jobs and machines
    0, 23, 6, 34, 2, 22, 4, 68, 1, 97, 7, 67, 5, 15, 8, 15, 3, 73, 
    0, 91, 2,  9, 1, 83, 7, 64, 4, 99, 6, 12, 5,  1, 8, 83, 3, 77, 
    6, 80, 0, 78, 3, 31, 7, 44, 2,  7, 8, 63, 5, 88, 4, 45, 1, 89, 
    2, 21, 1, 57, 3, 69, 8, 96, 0, 54, 7, 29, 5, 71, 4, 41, 6, 82, 
    8, 31, 6, 79, 3, 78, 0, 36, 5, 77, 7, 20, 4, 77, 2, 39, 1, 64, 
    4, 60, 1, 66, 3, 68, 8, 82, 0, 66, 7, 97, 6, 30, 5, 93, 2, 83, 
    8,  1, 7, 21, 2,  3, 1, 46, 5, 76, 4, 95, 0, 18, 3, 28, 6, 38, 
    7, 36, 6, 61, 5, 42, 8, 34, 2, 79, 1, 37, 0, 42, 3, 88, 4, 79, 
    8, 28, 0, 58, 1, 77, 2, 20, 5, 81, 4, 21, 3, 29, 6, 64, 7, 61
  };
  const int q9114[] = {
    9, 9, // Number of jobs and machines
    6, 88, 0, 57, 1, 79, 2, 83, 4, 17, 7, 71, 8, 88, 3,  3, 5, 39, 
    2, 42, 6, 79, 0, 11, 7, 57, 3,  1, 1, 70, 5, 44, 8, 32, 4, 50, 
    1, 77, 4, 36, 0, 37, 2, 67, 7, 72, 8, 90, 3,  4, 6, 87, 5, 83, 
    7, 26, 1, 65, 0, 53, 6, 82, 8, 69, 2, 48, 3, 30, 4, 85, 5, 87, 
    2, 31, 5, 97, 4, 58, 7, 60, 3, 62, 1, 27, 6, 99, 0, 53, 8, 90, 
    3,  7, 6, 84, 7, 45, 0, 43, 8, 80, 1, 57, 2, 51, 5, 13, 4, 61, 
    1, 28, 8, 86, 3, 73, 2,  7, 7, 33, 4,  9, 5, 66, 6, 27, 0, 29, 
    4, 54, 3, 74, 5, 85, 6, 48, 2, 85, 7, 40, 1, 94, 8, 29, 0, 59, 
    6, 71, 8, 31, 1, 17, 2, 35, 7, 11, 0, 88, 3,  5, 4, 39, 5, 93
  };
  const int q9115[] = {
    9, 9, // Number of jobs and machines
    5, 86, 7, 24, 6, 44, 2, 85, 3,  7, 4, 80, 0, 77, 1,  4, 8, 24, 
    4, 80, 3, 85, 1, 87, 7, 65, 0, 85, 2, 25, 8, 96, 6, 63, 5, 42, 
    3, 29, 7, 31, 8, 96, 5, 29, 0, 17, 4, 96, 2, 53, 6, 15, 1, 21, 
    2, 10, 8, 36, 3,  5, 0, 93, 6, 53, 5, 21, 4, 35, 1, 72, 7, 36, 
    6, 82, 3, 12, 2, 50, 4, 55, 7, 23, 0,  2, 5, 29, 8, 98, 1, 56, 
    5,  9, 8, 74, 2, 64, 4, 68, 6,  1, 0, 60, 7, 13, 3, 87, 1, 40, 
    4, 98, 6, 95, 0, 46, 7,  3, 8, 94, 5, 78, 3, 41, 2, 65, 1, 99, 
    8, 88, 5, 68, 1, 57, 4, 76, 0, 31, 7, 42, 2, 13, 6, 60, 3, 36, 
    8, 61, 1,  3, 2, 65, 3, 68, 4, 34, 6, 45, 7, 80, 0, 63, 5, 37
  };
  const int q9116[] = {
    9, 9, // Number of jobs and machines
    3, 23, 0, 97, 1, 93, 5, 42, 7, 63, 4, 56, 6, 60, 8, 91, 2, 83, 
    7, 58, 6, 13, 2, 27, 1, 42, 0, 71, 5, 29, 3, 84, 8,  4, 4, 59, 
    3, 42, 0, 85, 1, 17, 4, 67, 5, 48, 8, 10, 6, 78, 7, 14, 2, 94, 
    4,  4, 0, 97, 3, 24, 7, 70, 6, 44, 8, 81, 1, 86, 2, 36, 5, 57, 
    5, 81, 0, 94, 4, 56, 7, 69, 8, 45, 6, 48, 1, 20, 3, 28, 2, 28, 
    5, 22, 1, 56, 3, 95, 0, 69, 4, 89, 7, 42, 2,  3, 6, 73, 8, 36, 
    6, 15, 0, 60, 1, 68, 2, 94, 5, 15, 4, 98, 3, 12, 8, 60, 7, 10, 
    8, 78, 1, 13, 6, 80, 7, 38, 3, 13, 5, 37, 4, 76, 0, 77, 2, 68, 
    6, 69, 5,  9, 4, 67, 3,  7, 8, 25, 2, 96, 0, 20, 1, 11, 7, 57
  };
  const int q9117[] = {
    9, 9, // Number of jobs and machines
    7, 64, 3, 14, 6, 78, 8, 35, 5, 35, 0, 65, 4, 31, 1, 66, 2, 38, 
    1, 90, 5, 29, 8, 83, 6, 64, 3, 41, 0, 19, 7, 78, 4, 79, 2,  8, 
    7, 77, 3, 48, 2, 57, 4, 62, 8, 71, 6, 45, 0, 62, 1, 84, 5, 56, 
    3, 83, 0, 82, 2, 75, 1, 56, 6, 66, 5, 69, 4, 58, 7, 56, 8, 95, 
    2, 64, 6, 18, 8, 35, 0, 22, 5, 78, 4, 89, 3, 51, 1, 72, 7, 18, 
    7,  8, 8, 89, 5, 75, 6, 54, 2, 55, 1, 80, 0, 17, 3, 12, 4,  8, 
    0, 52, 7, 78, 3, 63, 2, 86, 8, 95, 4, 42, 6, 85, 1, 90, 5, 40, 
    8, 28, 3, 85, 2, 30, 7, 89, 4, 44, 5, 86, 1, 71, 0, 19, 6, 95, 
    1, 60, 2, 60, 7, 19, 4, 88, 3, 82, 5, 75, 0, 11, 8, 90, 6,  5
  };
  const int q9118[] = {
    9, 9, // Number of jobs and machines
    3,  6, 6, 93, 0, 18, 1, 30, 2, 18, 4, 86, 7, 89, 5, 83, 8,  7, 
    2, 36, 5, 35, 4, 28, 1, 93, 8, 29, 0, 29, 3, 29, 7, 11, 6, 68, 
    5, 54, 3, 54, 2, 19, 4, 34, 1,  4, 6, 33, 8, 67, 7, 15, 0, 47, 
    0,  5, 6,  5, 4, 13, 1, 34, 5, 37, 2, 60, 3, 72, 8, 93, 7, 23, 
    3, 10, 5, 50, 6, 87, 1, 48, 7, 23, 4, 80, 2, 92, 0, 13, 8, 42, 
    2, 27, 3, 30, 7,  9, 5, 96, 6, 35, 1, 86, 8, 40, 4, 69, 0, 29, 
    2, 48, 6, 69, 4, 86, 1, 47, 8, 17, 5, 54, 0,  5, 3,  4, 7, 80, 
    4, 11, 0, 10, 6,  1, 8, 78, 3, 96, 5, 18, 7, 79, 1, 91, 2, 91, 
    1, 70, 6, 66, 3, 95, 8, 74, 4,  8, 5, 12, 7, 36, 2, 22, 0,  1
  };
  const int q9119[] = {
    9, 9, // Number of jobs and machines
    3, 47, 0, 45, 2,  4, 1, 24, 4, 62, 5, 64, 6, 34, 7,  6, 8, 98, 
    3, 11, 0,  1, 1,  9, 2, 50, 7, 39, 4, 32, 8, 11, 5, 74, 6, 85, 
    0, 81, 7, 16, 6, 57, 2, 38, 4, 64, 3, 53, 8, 52, 1,  5, 5,  5, 
    7, 84, 6, 51, 8, 32, 0, 56, 1, 42, 4, 35, 5,  2, 3, 81, 2, 37, 
    1, 69, 8, 13, 6,  7, 4, 16, 0, 92, 5,  1, 7, 22, 2, 39, 3, 34, 
    1, 23, 3, 68, 6, 17, 2, 38, 4, 19, 8, 17, 0, 68, 7, 46, 5, 55, 
    5, 69, 7, 28, 2, 66, 3, 96, 0, 23, 4, 38, 6, 84, 1, 97, 8, 71, 
    6,  3, 4, 30, 8, 79, 0, 90, 3, 51, 1,  3, 5, 68, 7,  7, 2, 38, 
    3, 74, 1, 81, 4, 63, 8, 50, 0, 37, 2, 68, 5, 24, 7, 69, 6, 19
  };
  const int q9120[] = {
    9, 9, // Number of jobs and machines
    5, 91, 0, 94, 1, 52, 7, 92, 4, 29, 6, 60, 8,  3, 3, 31, 2, 82, 
    3, 12, 7, 97, 0, 70, 1, 73, 5, 71, 6, 86, 8,  4, 2,  4, 4, 36, 
    6,  3, 0, 65, 3, 94, 8, 22, 1, 97, 2, 56, 4, 77, 7, 86, 5, 95, 
    3, 27, 0, 12, 8, 37, 1, 98, 5, 67, 4, 22, 7, 53, 2,  1, 6, 22, 
    3, 59, 8, 50, 6, 31, 2, 23, 4,  9, 0, 87, 7, 41, 1, 26, 5, 37, 
    8, 43, 7, 94, 6, 21, 0, 37, 5, 30, 2, 19, 3, 68, 4, 93, 1, 30, 
    8, 99, 1, 87, 3, 58, 6,  9, 2, 97, 4, 34, 7, 14, 5, 71, 0,  9, 
    0,  1, 4, 45, 8, 49, 1, 81, 2, 84, 3, 96, 5, 33, 7, 41, 6, 76, 
    5, 60, 3, 16, 4, 62, 1,  8, 6, 40, 2, 73, 7,  4, 0,  9, 8, 65
  };
  const int q9121[] = {
    9, 9, // Number of jobs and machines
    8,  4, 2, 38, 1, 39, 7, 50, 5, 13, 6, 33, 4, 79, 0, 13, 3, 10, 
    7, 37, 3, 86, 4, 81, 5, 24, 2, 62, 1,  4, 0, 12, 6, 63, 8, 53, 
    3, 85, 5, 14, 6, 78, 8, 80, 0, 95, 1,  7, 2, 78, 4, 89, 7, 84, 
    3, 86, 8, 86, 6, 66, 7, 51, 1, 27, 4, 84, 0, 63, 5, 30, 2, 88, 
    4,  9, 8, 30, 1, 94, 5, 39, 2, 40, 3, 16, 6, 93, 7,  4, 0, 44, 
    1, 86, 4, 38, 3, 91, 8,  1, 6, 38, 7, 41, 5, 65, 0, 50, 2, 88, 
    2, 70, 7, 35, 4, 24, 3, 27, 6, 60, 0, 33, 1, 97, 8, 34, 5, 52, 
    4, 84, 2, 89, 3, 88, 5, 16, 7, 30, 6, 79, 1, 23, 0, 57, 8, 10, 
    5, 14, 8, 73, 6, 66, 0, 56, 4, 68, 7, 21, 1, 35, 3, 13, 2, 30
  };
  const int q9122[] = {
    9, 9, // Number of jobs and machines
    4, 89, 8, 60, 1, 85, 7, 58, 0, 99, 3, 50, 6, 62, 5, 55, 2,  2, 
    3, 43, 6, 40, 8, 32, 0, 22, 5, 48, 1, 47, 2, 34, 7, 78, 4, 10, 
    0, 38, 8, 47, 2,  9, 3, 71, 7, 70, 5, 99, 1, 63, 6, 82, 4, 69, 
    7, 16, 5, 61, 6, 11, 2, 16, 8, 50, 3, 63, 0, 72, 1, 12, 4, 94, 
    0, 29, 7, 77, 1,  2, 5, 24, 8, 66, 6,  5, 2, 61, 3, 55, 4, 64, 
    2,  5, 7, 12, 4,  2, 6, 29, 8, 59, 0, 62, 5, 11, 3, 82, 1, 60, 
    1, 41, 5, 58, 8, 43, 3, 11, 7, 28, 2, 45, 6, 35, 0, 24, 4, 14, 
    3, 22, 1,  8, 4, 44, 5, 53, 8,  7, 6, 86, 7, 99, 0, 81, 2, 13, 
    3, 11, 8, 23, 6, 59, 0, 98, 2, 38, 1, 71, 4, 24, 5, 26, 7, 67
  };
  const int q9123[] = {
    9, 9, // Number of jobs and machines
    3, 46, 2, 20, 6, 16, 8, 31, 5, 84, 0, 79, 1,  3, 7, 10, 4, 13, 
    5, 86, 1,  1, 0, 58, 6, 63, 7, 69, 3,  6, 4, 58, 8, 35, 2, 73, 
    1, 44, 7, 95, 5, 85, 8, 12, 6, 33, 3, 91, 4, 29, 0, 78, 2,  5, 
    5, 47, 2, 44, 8, 49, 7,  5, 1, 99, 0, 89, 3, 94, 6, 75, 4, 59, 
    7, 28, 4, 55, 2, 21, 5, 98, 8, 50, 0, 72, 3, 21, 6, 47, 1,  4, 
    8, 39, 2, 76, 6, 16, 5, 94, 7, 55, 1, 45, 4, 95, 0, 76, 3, 60, 
    3, 75, 4, 59, 0, 32, 2, 28, 8, 85, 7, 90, 5, 98, 1, 72, 6, 92, 
    6, 86, 7, 91, 8, 90, 0, 21, 5, 93, 4, 43, 2,  2, 3, 43, 1,  6, 
    4,  1, 2, 95, 1, 13, 3, 95, 0, 95, 8, 32, 5, 93, 7, 44, 6,  4
  };
  const int q9124[] = {
    9, 9, // Number of jobs and machines
    2, 40, 0,  6, 6, 40, 8, 47, 1, 79, 4, 77, 5, 18, 7, 52, 3, 27, 
    7, 42, 1, 30, 4, 77, 2, 16, 0, 87, 6, 51, 8, 37, 5, 86, 3, 17, 
    0, 72, 2, 18, 6, 93, 1, 51, 4, 62, 5, 69, 3, 68, 8, 57, 7, 97, 
    7, 66, 3,  6, 2, 33, 4, 88, 5, 32, 8, 61, 6, 39, 1, 24, 0, 21, 
    4, 89, 6, 32, 5, 35, 1, 46, 3, 11, 2, 47, 7, 34, 8, 14, 0, 90, 
    5, 89, 3, 28, 4, 98, 1,  4, 2, 65, 0,  1, 6, 61, 7,  9, 8, 31, 
    1, 50, 0, 54, 3, 83, 7, 91, 6, 19, 8, 27, 2, 35, 4, 33, 5, 49, 
    1, 27, 5, 51, 6, 26, 7, 74, 8, 74, 4, 70, 0, 41, 2, 50, 3, 81, 
    3, 37, 1,  9, 5, 11, 0, 29, 2, 98, 8, 60, 4, 73, 6, 26, 7, 91
  };
  const int q9125[] = {
    9, 9, // Number of jobs and machines
    5, 71, 4, 78, 1, 37, 6, 10, 8, 38, 2, 81, 7, 98, 0, 75, 3, 26, 
    1, 44, 2, 42, 7, 36, 6, 18, 3, 99, 5, 57, 0, 43, 4, 80, 8, 71, 
    2, 11, 1, 66, 0, 83, 8, 40, 4, 66, 7, 11, 3, 50, 6, 74, 5, 33, 
    5, 94, 3, 54, 1, 23, 2, 30, 0, 22, 4, 87, 7, 12, 8, 88, 6, 23, 
    0, 48, 3, 55, 6, 80, 5, 96, 2, 66, 8, 76, 7, 76, 4, 90, 1, 13, 
    1, 43, 3, 62, 5,  7, 8, 55, 6, 19, 0, 26, 4, 19, 7, 44, 2, 56, 
    0, 70, 1, 29, 3, 37, 8, 14, 5, 32, 6, 80, 2, 48, 7, 25, 4, 40, 
    7, 54, 0,  6, 8, 82, 4, 52, 5, 93, 3, 52, 2, 64, 1, 98, 6, 73, 
    6, 64, 3, 13, 2, 21, 1, 84, 5, 22, 7, 13, 4, 33, 8, 37, 0, 73
  };
  const int q9126[] = {
    9, 9, // Number of jobs and machines
    5, 55, 7, 37, 0, 57, 4, 44, 8, 30, 3, 93, 1, 60, 2, 18, 6, 47, 
    4, 62, 7, 19, 5, 35, 6, 97, 8, 94, 1, 32, 0, 37, 2, 83, 3, 55, 
    5, 10, 4, 69, 2, 67, 3, 43, 0, 82, 6, 20, 8, 75, 1, 13, 7, 98, 
    2, 94, 4, 22, 0,  8, 7, 88, 3, 51, 1, 49, 8, 56, 6, 46, 5, 78, 
    6, 96, 2, 15, 5, 48, 7, 34, 3, 96, 8, 11, 1,  9, 4, 57, 0, 29, 
    4,  8, 1, 69, 8, 49, 2, 81, 7, 45, 6, 34, 3,  4, 5, 80, 0, 97, 
    3, 37, 8, 67, 2, 62, 6, 64, 1, 18, 0, 74, 7, 45, 4,  2, 5, 88, 
    6, 72, 0, 11, 5, 85, 4,  1, 1, 93, 7, 25, 2, 56, 3, 36, 8, 70, 
    7, 94, 5, 18, 6,  6, 0, 49, 2, 95, 3, 72, 4, 66, 1, 66, 8, 56
  };
  const int q9127[] = {
    9, 9, // Number of jobs and machines
    3, 67, 0, 17, 8, 60, 6, 55, 1, 61, 5, 96, 2, 16, 4, 10, 7, 20, 
    8, 79, 5, 53, 1, 92, 2, 34, 4, 76, 0, 85, 6, 35, 3, 47, 7, 49, 
    2, 68, 5, 36, 4, 67, 0, 27, 3, 26, 8, 40, 6, 27, 1, 68, 7, 70, 
    8, 40, 1, 72, 2, 15, 7, 79, 4, 32, 3, 96, 6, 35, 5, 65, 0, 67, 
    2, 76, 0, 38, 3, 61, 8, 95, 1, 48, 6, 77, 4, 98, 5, 62, 7, 76, 
    1, 13, 8, 94, 0, 84, 2, 81, 7, 12, 5, 36, 4, 92, 3,  2, 6, 43, 
    0, 34, 6, 76, 5, 10, 8, 26, 1, 75, 4, 96, 7,  6, 3, 74, 2, 35, 
    0, 26, 7, 81, 8, 23, 1, 24, 3, 86, 4, 36, 6, 84, 5, 69, 2, 71, 
    5, 73, 2, 25, 8, 86, 3, 68, 1,  3, 6, 63, 7, 48, 0, 21, 4, 47
  };
  const int q9128[] = {
    9, 9, // Number of jobs and machines
    0, 16, 6, 25, 2, 14, 3, 59, 8, 96, 1,  7, 7,  5, 5, 45, 4, 33, 
    4, 45, 8, 95, 1, 59, 5, 20, 7, 27, 3, 63, 2, 31, 6, 13, 0, 78, 
    5, 39, 0, 79, 4, 87, 2, 43, 3, 80, 1, 79, 7, 67, 8, 58, 6,  3, 
    4, 57, 8, 54, 7, 14, 5, 34, 6, 32, 2,  7, 3, 67, 0, 48, 1, 79, 
    8, 23, 5, 51, 6, 16, 7, 32, 4, 10, 2, 95, 3, 97, 0, 34, 1, 75, 
    6, 70, 3, 65, 7, 93, 1, 14, 4, 65, 0, 62, 5, 84, 8, 76, 2, 13, 
    4, 89, 5, 40, 2, 93, 8, 10, 6, 49, 1,  5, 0, 92, 7, 78, 3, 39, 
    1, 59, 6, 99, 7, 16, 8, 24, 4, 11, 2,  5, 5, 42, 3, 61, 0, 88, 
    3, 48, 1, 52, 5, 26, 2, 53, 8, 92, 7, 87, 4, 95, 0, 74, 6, 58
  };
  const int q9129[] = {
    9, 9, // Number of jobs and machines
    0, 33, 5, 33, 6, 77, 8, 47, 1, 25, 3, 30, 7, 93, 4, 75, 2,  8, 
    0, 87, 4, 84, 7,  1, 5, 86, 1, 79, 8, 63, 3, 53, 2, 89, 6, 82, 
    0, 86, 2,  6, 6, 50, 4, 79, 1, 10, 5, 98, 8, 19, 3, 24, 7, 13, 
    3, 62, 0, 77, 2, 47, 7, 81, 8, 66, 6, 41, 5, 38, 4, 21, 1, 14, 
    1, 38, 0, 46, 7, 38, 5, 54, 2,  2, 8, 50, 6, 93, 4, 93, 3,  3, 
    7, 54, 4, 28, 6, 48, 3, 78, 2, 72, 8, 14, 1, 90, 5, 24, 0, 98, 
    5, 73, 1, 49, 8, 98, 3,  7, 0, 49, 4, 33, 6,  1, 7, 63, 2, 99, 
    3, 74, 6, 17, 0,  4, 1, 65, 2, 87, 7, 31, 8, 93, 5, 69, 4, 19, 
    7, 36, 5,  3, 3, 39, 0, 12, 1, 25, 2, 59, 8, 91, 6,  5, 4, 79
  };
  const int q9130[] = {
    9, 9, // Number of jobs and machines
    2, 71, 4, 91, 7, 52, 1, 74, 6, 19, 5, 80, 3, 16, 0, 98, 8, 96, 
    1,  8, 7, 19, 8, 81, 2, 10, 0, 10, 3, 62, 5, 32, 4, 64, 6, 97, 
    7, 46, 3, 65, 4, 54, 1, 80, 5, 81, 6, 59, 8, 70, 2,  9, 0, 12, 
    6, 27, 4, 45, 5, 21, 8, 57, 3, 94, 2, 59, 1, 37, 7, 10, 0, 98, 
    7, 68, 4,  3, 3, 13, 0, 21, 1, 24, 2, 66, 8,  9, 5, 90, 6, 68, 
    5, 12, 8, 94, 2,  4, 4, 46, 6, 57, 1, 23, 3, 26, 7, 46, 0, 84, 
    7, 56, 5, 54, 3, 47, 1, 37, 0, 26, 6, 83, 2, 12, 4, 93, 8, 13, 
    2, 25, 7, 72, 6, 74, 1, 75, 8, 30, 0, 28, 5, 54, 4, 70, 3, 43, 
    3, 49, 8, 48, 6, 68, 1, 47, 7, 85, 0, 61, 2, 89, 5,  9, 4, 65
  };
  const int q9131[] = {
    9, 9, // Number of jobs and machines
    3, 27, 1, 24, 4, 41, 5,  1, 8,  2, 2, 77, 6, 17, 0, 59, 7, 58, 
    2, 85, 7, 99, 0, 21, 6, 45, 3,  1, 8,  8, 5, 99, 4, 10, 1, 29, 
    5, 13, 6, 78, 1, 13, 7, 75, 0, 24, 4, 28, 2, 62, 3, 52, 8, 40, 
    3, 80, 5, 22, 7, 26, 6, 83, 1, 32, 2, 74, 0, 33, 4, 21, 8, 37, 
    6, 20, 2, 87, 5, 55, 3, 22, 0, 32, 7, 99, 8, 15, 1, 61, 4, 23, 
    5, 68, 6, 87, 8, 90, 4, 63, 7, 12, 3, 11, 2, 48, 0, 71, 1, 78, 
    2, 23, 4, 61, 8, 10, 7, 24, 1, 73, 6, 28, 0, 68, 5,  3, 3, 91, 
    3, 64, 4, 12, 7,  8, 2, 96, 8, 93, 0, 98, 1, 57, 5,  9, 6, 48, 
    0, 41, 2, 21, 6, 38, 5,  6, 3,  2, 7, 91, 1, 69, 8, 80, 4,  7
  };
  const int q9132[] = {
    9, 9, // Number of jobs and machines
    1, 13, 0, 68, 3, 94, 5, 12, 2, 57, 8, 22, 6,  8, 4, 51, 7, 90, 
    6, 12, 5, 16, 0, 37, 8, 84, 1, 72, 3, 77, 4, 55, 7, 91, 2, 59, 
    1, 42, 2, 23, 4, 90, 0, 72, 7, 87, 6, 51, 5, 62, 8, 94, 3, 44, 
    2, 21, 5, 53, 6, 57, 4, 75, 1, 53, 8, 87, 7, 33, 3, 71, 0, 32, 
    2, 89, 8, 33, 1,  2, 3, 48, 5, 37, 4, 98, 0, 88, 6, 55, 7, 32, 
    2, 65, 3, 48, 8, 22, 6, 59, 1, 44, 4, 32, 7, 14, 5, 65, 0, 10, 
    8,  3, 0, 72, 7, 37, 2,  5, 1, 93, 5, 14, 3, 28, 6,  5, 4, 97, 
    3, 26, 8, 80, 0, 98, 5,  9, 1,  4, 7, 80, 4, 98, 6, 62, 2, 53, 
    0, 28, 2, 65, 4, 35, 1,  2, 7, 60, 8, 10, 5, 61, 6,  4, 3,  6
  };
  const int q9133[] = {
    9, 9, // Number of jobs and machines
    3,  4, 8, 81, 6, 84, 0, 94, 4, 75, 1, 41, 5, 74, 2, 83, 7, 61, 
    2, 47, 1, 19, 4, 70, 7, 97, 0, 56, 6, 66, 3, 55, 8, 93, 5, 48, 
    3, 37, 4, 97, 6, 71, 8, 10, 2, 56, 7, 13, 5, 28, 0, 18, 1, 17, 
    0, 36, 7, 51, 3, 38, 6, 89, 4, 35, 8, 63, 5, 76, 2, 80, 1, 40, 
    8, 47, 2, 72, 4, 93, 1, 94, 0, 20, 3, 31, 5, 30, 7, 21, 6, 88, 
    7, 25, 2, 83, 3, 40, 5, 39, 4, 34, 8, 57, 0, 98, 6,  8, 1, 94, 
    8, 72, 2, 18, 4, 82, 6, 90, 3, 63, 1, 31, 5, 32, 7, 12, 0, 94, 
    6, 79, 1, 50, 7, 21, 3,  5, 0, 76, 2, 33, 4, 38, 8,  8, 5, 44, 
    3, 78, 0, 17, 4,  8, 5,  8, 2, 83, 1, 52, 7, 14, 6, 71, 8, 80
  };
  const int q9134[] = {
    9, 9, // Number of jobs and machines
    4, 25, 8, 21, 3, 87, 6, 93, 1, 79, 2,  7, 5, 92, 0, 74, 7, 30, 
    8, 58, 5, 47, 3, 50, 1, 30, 0, 91, 7,  2, 6, 79, 4, 57, 2, 78, 
    1, 72, 8, 17, 5, 14, 2, 59, 4, 18, 6, 75, 0, 70, 7, 21, 3, 75, 
    8, 99, 4, 77, 5, 46, 1, 17, 2,  1, 3, 60, 6, 75, 7, 94, 0, 11, 
    0, 17, 8, 99, 2, 87, 1, 82, 7, 54, 4, 46, 3, 29, 5, 30, 6,  9, 
    4, 60, 8, 99, 3,  4, 2, 80, 6, 64, 5, 15, 7, 33, 0, 91, 1, 76, 
    7, 11, 5, 55, 4, 27, 6, 26, 1, 11, 0, 77, 3, 10, 2, 57, 8, 15, 
    0, 43, 3, 15, 8, 99, 4, 48, 7,  5, 6, 85, 2, 65, 1, 99, 5, 49, 
    1,  6, 6, 86, 3, 98, 8, 87, 0, 36, 2, 10, 7,  8, 5, 58, 4, 20
  };
  const int q9135[] = {
    9, 9, // Number of jobs and machines
    8, 84, 1, 85, 5, 80, 2, 82, 0, 91, 6, 48, 4, 64, 7, 77, 3,  7, 
    4, 11, 1, 68, 8, 94, 5, 71, 2,  5, 7, 24, 0, 14, 3, 86, 6, 88, 
    7, 78, 5, 88, 3, 56, 0, 70, 4, 76, 6, 52, 1, 52, 2, 27, 8,  4, 
    0, 28, 2, 95, 4, 93, 8,  7, 5, 49, 6, 16, 3, 20, 1, 88, 7, 32, 
    4, 30, 5, 11, 6, 53, 3, 33, 7, 65, 0, 71, 8, 67, 1, 99, 2, 78, 
    1, 31, 6, 49, 0, 43, 8, 33, 7,  6, 2, 84, 4, 73, 5, 54, 3, 39, 
    0, 24, 5, 96, 1, 69, 6, 89, 3, 41, 4, 34, 8, 97, 7, 99, 2,  4, 
    4, 56, 8, 60, 0,  9, 3, 51, 2, 99, 6, 47, 5,  7, 1, 14, 7, 13, 
    4, 30, 3, 26, 0, 99, 7, 26, 8, 86, 2, 94, 1, 95, 6, 59, 5,  6
  };
  const int q9136[] = {
    9, 9, // Number of jobs and machines
    1, 15, 7, 43, 0, 20, 8,  6, 2, 36, 6, 70, 4, 71, 3, 18, 5, 49, 
    6, 19, 7,  6, 8, 94, 0, 52, 3, 10, 2, 68, 5, 43, 4,  6, 1, 33, 
    5, 60, 0, 31, 1, 55, 4, 58, 6, 30, 3, 80, 2, 64, 8, 92, 7, 26, 
    3, 52, 7, 88, 1, 13, 2, 49, 8,  6, 5, 43, 6, 51, 0, 50, 4,  4, 
    2, 35, 8, 38, 0, 89, 1, 37, 4, 34, 6, 28, 7, 31, 5, 32, 3, 98, 
    5, 79, 8, 56, 3, 55, 4, 69, 1, 84, 0, 66, 6,  7, 7, 45, 2,  5, 
    4, 93, 5, 10, 0, 96, 2, 98, 6, 31, 3, 22, 8, 71, 7, 77, 1, 35, 
    8, 46, 4, 31, 5, 25, 6, 33, 0, 38, 7, 93, 3, 31, 2, 13, 1, 29, 
    4,  3, 1, 45, 0, 45, 6, 41, 2, 17, 7, 32, 5, 83, 8, 99, 3, 12
  };
  const int q9137[] = {
    9, 9, // Number of jobs and machines
    4, 61, 2, 93, 0, 33, 8,  6, 5, 14, 7, 21, 1, 99, 6, 86, 3, 19, 
    2, 43, 1, 66, 0, 42, 7, 63, 4, 19, 3, 15, 8, 64, 6, 43, 5, 46, 
    0, 45, 3, 67, 2, 48, 7, 69, 6, 60, 5, 73, 4, 20, 1, 68, 8, 81, 
    3, 70, 5, 84, 2, 88, 7, 49, 1, 81, 8, 13, 0, 83, 6, 18, 4, 66, 
    7, 77, 2, 89, 1, 74, 0, 52, 8, 36, 3, 54, 4, 61, 5, 65, 6, 23, 
    7, 77, 2, 74, 5, 74, 0,  5, 1, 74, 4, 21, 3, 66, 6, 99, 8, 84, 
    7, 53, 4, 82, 1, 13, 5,  6, 3, 25, 0, 91, 6, 48, 2,  3, 8, 62, 
    2, 50, 6, 79, 0, 17, 1, 90, 7, 64, 8, 79, 4, 26, 3, 57, 5, 66, 
    4, 53, 8, 17, 2, 32, 1, 15, 7, 82, 6, 99, 5, 86, 3, 54, 0, 82
  };
  const int q9138[] = {
    9, 9, // Number of jobs and machines
    8, 69, 1,  9, 6, 76, 7, 80, 2, 74, 3, 71, 0, 87, 5,  3, 4, 59, 
    8, 47, 7, 83, 0, 38, 4, 70, 6, 79, 3, 41, 2, 99, 5, 37, 1, 42, 
    7, 39, 0, 78, 2, 14, 6, 71, 8, 16, 5, 72, 1, 96, 4, 24, 3, 24, 
    2, 51, 8, 76, 6, 70, 7, 40, 3, 22, 4, 74, 0, 32, 1,  5, 5, 39, 
    2,  5, 5, 58, 3, 58, 0, 56, 7, 79, 1, 22, 8, 40, 6, 15, 4, 32, 
    7,  8, 4, 17, 6, 95, 1, 30, 3, 43, 8, 83, 2,  9, 5, 82, 0, 47, 
    7, 41, 6, 14, 4, 45, 0, 71, 1, 29, 5, 87, 3, 78, 2,  6, 8, 90, 
    6, 87, 8, 77, 2, 64, 0, 17, 1, 10, 5, 41, 3, 40, 7, 92, 4, 21, 
    4, 26, 5, 25, 6, 90, 3, 91, 8, 19, 0,  8, 1, 72, 2, 55, 7, 32
  };
  const int q9139[] = {
    9, 9, // Number of jobs and machines
    3, 89, 2, 70, 0, 65, 5, 53, 8, 89, 4, 84, 6,  8, 7, 62, 1, 59, 
    5, 65, 6, 51, 2, 30, 7, 21, 0, 15, 4, 43, 8,  4, 3, 92, 1, 59, 
    4, 62, 0, 37, 5, 91, 3, 35, 1, 87, 8, 51, 2, 27, 7, 96, 6, 93, 
    1, 88, 5,  7, 2, 55, 7, 63, 8,  8, 3, 98, 6, 26, 0, 40, 4, 21, 
    4, 10, 1, 91, 7, 95, 5, 11, 3, 86, 8, 70, 6, 65, 0, 43, 2, 72, 
    7, 64, 4, 73, 0, 73, 5, 77, 1, 93, 3, 31, 6, 62, 2,  6, 8, 25, 
    6, 24, 1, 67, 8, 50, 7, 68, 0,  1, 4, 86, 5, 25, 3, 45, 2, 45, 
    4, 45, 8, 32, 6, 45, 2, 95, 5, 87, 0, 69, 1, 89, 3, 19, 7, 48, 
    0, 27, 3, 69, 2, 86, 8, 80, 4,  7, 7, 78, 6,  6, 1, 42, 5, 25
  };
  const int q9140[] = {
    9, 9, // Number of jobs and machines
    7, 26, 8, 93, 1, 47, 5, 50, 2, 24, 4, 44, 0, 20, 6, 71, 3, 37, 
    0, 34, 2, 51, 8, 27, 7, 87, 3, 11, 1, 90, 6, 44, 4, 86, 5, 82, 
    2, 47, 5,  9, 0,  5, 7, 94, 4, 74, 8, 19, 6,  2, 1, 36, 3, 69, 
    6, 57, 0, 56, 5, 22, 8, 76, 7, 57, 3, 49, 4, 61, 1, 87, 2, 35, 
    2, 78, 1,  2, 6, 89, 8, 36, 7, 33, 3, 49, 0, 31, 5, 79, 4, 21, 
    6, 93, 5, 18, 2, 25, 4, 20, 8, 88, 0,  4, 7, 64, 3, 49, 1, 70, 
    7, 88, 0, 67, 6, 69, 8, 30, 2, 45, 5, 83, 4, 99, 1, 51, 3, 87, 
    0,  3, 6, 45, 3, 63, 4, 41, 2, 57, 7, 69, 1,  4, 5, 78, 8, 67, 
    7, 14, 5, 85, 3, 63, 4, 23, 2, 33, 1, 75, 6, 75, 0, 15, 8, 14
  };
  const int q9141[] = {
    9, 9, // Number of jobs and machines
    8, 46, 0, 94, 6, 88, 4, 70, 5, 58, 3, 22, 7, 60, 1, 62, 2, 76, 
    2, 31, 0, 86, 7, 36, 1, 46, 3, 34, 4, 61, 8,  8, 5, 64, 6,  5, 
    0, 41, 5, 46, 7, 76, 8, 57, 6,  4, 1, 84, 2, 90, 4,  4, 3, 61, 
    6, 56, 4, 48, 0,  5, 8, 31, 7, 72, 2, 39, 1,  3, 5, 91, 3, 92, 
    2, 71, 0, 66, 3, 56, 5, 59, 7, 74, 4, 10, 1, 21, 6, 38, 8, 73, 
    2, 86, 6, 21, 7, 41, 0, 35, 8, 43, 1, 65, 3,  6, 5, 77, 4, 35, 
    3, 52, 2, 50, 7, 88, 4, 96, 6,  9, 8, 58, 5, 42, 1, 96, 0, 66, 
    7, 67, 1, 39, 6, 33, 3, 57, 0, 97, 4, 47, 8, 10, 2, 70, 5, 33, 
    0, 84, 1, 93, 8, 96, 4, 77, 5, 48, 7, 38, 6, 20, 2, 56, 3, 31
  };
  const int q9142[] = {
    9, 9, // Number of jobs and machines
    6, 56, 5, 13, 4, 51, 0, 34, 3, 60, 2, 61, 1, 65, 7, 81, 8, 70, 
    2, 96, 7, 69, 8, 76, 6, 38, 3, 87, 1,  6, 0, 22, 4, 79, 5, 74, 
    2, 13, 5,  4, 6, 33, 4, 50, 7, 75, 1, 63, 0, 31, 8, 56, 3,  5, 
    4, 35, 1, 36, 7, 78, 3, 70, 5, 13, 0, 65, 6, 32, 2, 62, 8, 29, 
    0, 25, 8, 66, 5, 93, 7, 90, 3,  9, 2, 52, 1, 47, 4, 97, 6, 27, 
    5, 21, 4, 42, 0,  9, 8, 26, 6, 78, 7, 46, 2, 33, 3,  2, 1, 30, 
    4, 44, 3, 55, 0, 80, 5, 54, 2, 99, 1, 63, 8, 63, 6, 86, 7, 24, 
    0, 39, 3, 91, 4, 61, 8, 48, 1, 29, 5, 46, 2, 48, 7, 38, 6, 93, 
    5, 32, 6, 91, 4, 17, 7,  8, 3, 81, 2, 78, 8, 56, 0,  3, 1, 53
  };
  const int q9143[] = {
    9, 9, // Number of jobs and machines
    6, 44, 5, 64, 7,  7, 2,  7, 4, 91, 3, 78, 8, 14, 1, 74, 0, 19, 
    3, 99, 0, 83, 2, 53, 5, 22, 7, 72, 6, 37, 4,  2, 8, 17, 1, 75, 
    1,  7, 7, 15, 6, 97, 3, 16, 0, 26, 8, 85, 2, 54, 5, 65, 4, 75, 
    8, 32, 0, 67, 2, 61, 3, 35, 7, 32, 4, 76, 6, 73, 5, 49, 1, 99, 
    8, 31, 7,  5, 0, 61, 2, 25, 4, 88, 5, 15, 1,  5, 3, 21, 6, 61, 
    0, 74, 3, 78, 2, 13, 7, 41, 8, 12, 6, 57, 5, 57, 4, 45, 1, 14, 
    3, 66, 2, 53, 6, 37, 0, 22, 7, 59, 8, 74, 5, 79, 4, 58, 1, 41, 
    0, 66, 1, 15, 6, 34, 7, 17, 3, 93, 8, 33, 4, 74, 5, 66, 2, 17, 
    2, 49, 0, 65, 1, 52, 7, 45, 4, 15, 6, 63, 8, 84, 5, 79, 3, 32
  };
  const int q9144[] = {
    9, 9, // Number of jobs and machines
    3, 51, 1, 68, 8,  1, 6, 89, 2, 58, 4,  2, 0, 50, 7, 72, 5, 87, 
    2, 98, 7, 37, 4, 48, 5, 53, 3, 25, 6, 50, 0, 48, 8, 21, 1,  5, 
    6, 35, 2, 21, 4, 87, 7, 81, 5, 87, 1,  2, 8, 66, 3, 33, 0, 75, 
    0, 45, 2, 99, 6, 10, 1, 74, 8, 66, 7, 18, 4,  1, 3, 95, 5,  8, 
    4,  1, 3, 77, 6, 70, 8, 15, 1, 70, 0, 19, 5, 75, 2, 78, 7, 10, 
    0, 25, 2, 79, 7, 35, 5, 63, 8, 25, 1, 18, 6, 75, 4, 81, 3,  1, 
    6, 60, 8,  2, 7, 43, 0, 56, 1, 24, 5, 41, 2, 96, 3, 75, 4, 82, 
    5, 91, 4, 81, 1, 11, 3, 64, 0, 36, 8, 14, 6, 52, 2, 88, 7, 87, 
    0, 93, 4, 24, 5, 26, 6, 37, 7, 55, 2, 82, 8, 40, 1, 33, 3, 13
  };
  const int q9145[] = {
    9, 9, // Number of jobs and machines
    4, 25, 8, 92, 1, 61, 6, 11, 3, 65, 7, 68, 0, 88, 2, 77, 5, 98, 
    2, 96, 6, 22, 3, 88, 0, 80, 7, 98, 5,  3, 8, 32, 1,  2, 4, 86, 
    7, 49, 1, 98, 0, 58, 3, 65, 6, 55, 4, 91, 5, 66, 2, 15, 8, 11, 
    8, 20, 3, 97, 0, 64, 2, 83, 7,  8, 4, 90, 1, 15, 5, 53, 6, 92, 
    0,  7, 1, 75, 4, 17, 8, 72, 6, 33, 7, 45, 2, 23, 3, 85, 5, 84, 
    7, 94, 6, 37, 1, 34, 2, 75, 0, 49, 3, 24, 4, 35, 8, 97, 5, 27, 
    4, 41, 3, 39, 1,  2, 0, 15, 2, 58, 6, 86, 7, 89, 5, 88, 8, 90, 
    6, 77, 5, 33, 0, 48, 1,  7, 7, 85, 4, 34, 2, 29, 3, 21, 8, 64, 
    3, 23, 4, 79, 8, 28, 7,  2, 5, 33, 0, 93, 6, 14, 1, 95, 2, 79
  };
  const int q9146[] = {
    9, 9, // Number of jobs and machines
    3, 44, 2,  2, 1, 87, 7, 39, 0, 73, 5, 38, 8, 55, 4, 63, 6, 10, 
    0,  2, 8, 93, 4, 27, 5, 89, 6,  6, 7, 44, 2, 86, 3, 54, 1, 75, 
    4, 36, 3, 61, 5, 24, 1, 15, 7, 20, 0, 17, 8, 92, 6, 56, 2, 72, 
    2, 90, 6, 46, 4, 24, 0, 83, 5, 42, 8, 95, 1, 39, 3, 52, 7, 68, 
    8, 38, 5, 67, 3, 47, 1, 19, 6, 79, 2, 67, 7, 16, 0,  5, 4, 75, 
    3,  3, 5, 34, 1, 30, 6, 25, 8,  8, 7, 98, 2, 81, 0, 43, 4, 87, 
    7, 49, 6, 22, 0, 10, 5, 96, 8, 86, 3, 99, 4, 95, 1, 88, 2, 52, 
    0, 87, 1, 72, 2, 15, 5, 10, 3, 25, 4, 34, 7, 86, 6, 72, 8,  7, 
    8, 44, 4, 63, 0, 30, 3, 90, 2, 50, 7, 28, 6, 96, 1, 84, 5, 81
  };
  const int q9147[] = {
    9, 9, // Number of jobs and machines
    2, 18, 3, 98, 0, 33, 1, 26, 5, 47, 4, 81, 8, 40, 6, 46, 7, 56, 
    5, 90, 0, 74, 6, 21, 3,  1, 1, 11, 7,  1, 2, 13, 4, 58, 8, 99, 
    6, 82, 4, 72, 1, 47, 7,  9, 5,  9, 3, 81, 0,  2, 2, 36, 8, 53, 
    6, 23, 4, 92, 7, 98, 1, 92, 0, 21, 8, 96, 3, 80, 5, 91, 2, 21, 
    0, 37, 3, 57, 6, 96, 4, 18, 2,  5, 1, 96, 8, 13, 7, 88, 5, 46, 
    6,  9, 5, 35, 4, 44, 7, 80, 0, 34, 2, 25, 3, 68, 8, 99, 1, 10, 
    7,  7, 3, 58, 4, 21, 2, 96, 1, 45, 6, 64, 8, 79, 5, 69, 0, 59, 
    5, 70, 0, 42, 1, 36, 7, 58, 4, 71, 2, 99, 6, 89, 8, 39, 3, 72, 
    0, 26, 4, 52, 6, 19, 5, 80, 8, 97, 1,  8, 2, 56, 7, 99, 3, 29
  };
  const int q9148[] = {
    9, 9, // Number of jobs and machines
    8, 32, 0, 74, 1, 97, 6, 69, 7, 59, 3, 97, 4,  1, 2, 76, 5, 70, 
    5, 40, 3, 91, 2, 85, 8, 15, 1, 42, 6, 77, 0, 46, 7, 10, 4, 52, 
    6, 19, 1, 29, 8, 74, 3, 83, 4, 63, 2, 61, 7, 58, 0, 29, 5,  9, 
    2, 59, 0, 40, 7, 60, 1, 54, 3, 67, 8, 72, 4, 52, 5, 16, 6, 23, 
    0, 37, 6, 88, 4, 50, 5, 55, 7, 28, 2, 43, 8, 42, 1,  1, 3, 92, 
    0, 22, 8, 99, 4, 57, 6, 20, 5, 22, 7, 91, 1, 15, 3, 95, 2, 80, 
    1, 40, 6, 63, 8, 45, 0, 95, 4, 83, 2,  5, 3, 70, 7, 37, 5, 12, 
    5, 37, 0, 85, 3, 11, 4,  7, 1, 98, 8, 26, 7, 12, 2, 91, 6, 54, 
    7, 71, 2, 76, 5, 90, 0, 22, 6, 63, 4, 70, 1, 89, 3,  3, 8, 70
  };
  const int q9149[] = {
    9, 9, // Number of jobs and machines
    8, 57, 2,  5, 6, 43, 7, 91, 1, 56, 5, 93, 0, 40, 4, 73, 3, 67, 
    8, 51, 4, 64, 7, 66, 1, 16, 6, 77, 3, 22, 2, 73, 0, 75, 5,  8, 
    8, 43, 0, 66, 7, 49, 4,  2, 6, 70, 5, 46, 1,  3, 2, 60, 3, 31, 
    2, 58, 0, 98, 5, 62, 8,  2, 7, 51, 3, 79, 4, 59, 1, 53, 6, 95, 
    3, 72, 7, 90, 2, 25, 6, 18, 8, 87, 4, 59, 5, 49, 0,  8, 1, 51, 
    7, 17, 8, 95, 2, 20, 0, 63, 6, 68, 3, 60, 5, 98, 1, 12, 4, 43, 
    2, 88, 4, 30, 7, 65, 3, 92, 6, 46, 8,  1, 5, 73, 1, 35, 0, 83, 
    1, 54, 2,  6, 3,  8, 0,  7, 5, 43, 4, 72, 6, 45, 7, 91, 8, 29, 
    4, 41, 0, 17, 8, 76, 6, 50, 2, 81, 3, 71, 5,  6, 1, 83, 7, 74
  };
  const int q9150[] = {
    9, 9, // Number of jobs and machines
    0, 94, 5, 83, 3,  7, 2, 48, 1, 18, 7, 34, 8, 79, 4, 87, 6,  3, 
    8, 23, 1, 32, 2, 21, 4, 85, 3, 74, 0, 46, 5, 10, 7,  9, 6, 15, 
    5, 40, 7,  2, 0, 62, 6, 10, 8,  7, 3, 30, 1, 40, 2, 37, 4,  8, 
    2, 13, 4, 23, 5, 43, 1, 57, 0, 22, 7, 10, 8, 68, 6, 69, 3, 54, 
    6, 46, 7, 58, 3, 85, 0, 50, 1, 95, 8, 37, 4, 19, 2, 95, 5,  1, 
    4, 40, 5,  4, 3,  7, 1, 21, 6,  7, 2, 87, 0, 78, 8, 65, 7, 74, 
    5, 92, 3, 97, 8, 37, 7, 83, 4, 74, 2, 80, 6, 93, 1, 57, 0,  2, 
    1, 37, 5, 92, 0, 99, 6, 28, 8, 74, 4,  5, 2, 29, 7, 34, 3, 29, 
    2, 26, 6, 34, 0, 72, 8, 94, 7, 16, 5,  6, 1, 19, 3, 37, 4, 55
  };
  const int q9151[] = {
    9, 9, // Number of jobs and machines
    0, 78, 2, 72, 5, 36, 4, 32, 8, 82, 6, 29, 1, 13, 7,  8, 3, 62, 
    7, 16, 6, 37, 4, 25, 5, 22, 1, 81, 2, 94, 8, 28, 0, 98, 3, 59, 
    2, 87, 8,  2, 0, 68, 7, 73, 1, 78, 4, 83, 3, 50, 6, 73, 5, 29, 
    0,  6, 4, 17, 3, 56, 5, 67, 6, 18, 1, 92, 8, 75, 7, 19, 2, 26, 
    2, 47, 0, 83, 7, 29, 4, 84, 8, 21, 6, 95, 5, 55, 1, 98, 3, 85, 
    7, 80, 8, 76, 4, 24, 3, 71, 6, 78, 2, 10, 5, 17, 0, 60, 1, 61, 
    1, 58, 8, 40, 6, 40, 5, 98, 7, 52, 3, 34, 2, 41, 0, 32, 4, 99, 
    1, 91, 5, 14, 0, 40, 4, 38, 2, 10, 6, 80, 8,  7, 3, 11, 7, 97, 
    4, 79, 3, 82, 5, 59, 7, 92, 1, 74, 2, 69, 0, 98, 6, 45, 8, 19
  };
  const int q9152[] = {
    9, 9, // Number of jobs and machines
    6, 83, 0,  8, 1, 44, 7, 73, 4,  7, 3, 26, 8, 56, 2, 36, 5, 67, 
    1, 68, 3, 53, 7, 63, 4, 28, 5, 90, 6, 52, 0, 50, 8, 29, 2, 97, 
    5, 56, 3, 75, 2, 32, 8, 72, 1, 31, 6, 81, 7, 94, 0, 27, 4, 53, 
    5, 61, 7, 31, 1, 94, 2, 95, 8, 47, 4, 30, 0, 17, 6, 97, 3, 91, 
    8, 10, 3, 75, 7, 42, 5, 81, 2, 50, 6, 95, 1, 57, 0, 71, 4, 60, 
    2, 54, 7, 19, 8, 27, 1, 14, 5, 84, 0, 25, 6, 70, 4, 50, 3, 29, 
    3, 22, 5, 92, 8, 75, 2, 27, 1, 17, 6, 49, 4, 70, 7, 48, 0, 22, 
    1, 48, 5, 62, 7, 19, 8,  9, 3, 71, 4, 91, 6, 48, 2, 57, 0, 49, 
    3, 83, 5,  4, 8, 83, 4, 77, 1, 73, 6, 46, 2,  3, 0, 92, 7, 35
  };
  const int q9153[] = {
    9, 9, // Number of jobs and machines
    1, 93, 8, 97, 0, 56, 7, 98, 2, 29, 6, 10, 5, 51, 3, 39, 4, 64, 
    2, 15, 5, 10, 4, 10, 6,  1, 3, 15, 0, 31, 8, 78, 1, 92, 7, 29, 
    3, 48, 5, 28, 7,  6, 6, 13, 0, 33, 8, 24, 1,  9, 2, 37, 4, 82, 
    0, 78, 2, 11, 1,  6, 7,  6, 5, 97, 6, 94, 4, 80, 3, 71, 8, 29, 
    7, 63, 6, 58, 3, 49, 0, 75, 8, 78, 1,  1, 5, 17, 2, 20, 4, 17, 
    1, 17, 4, 44, 8, 94, 7, 91, 5, 44, 6, 39, 0,  6, 2, 54, 3, 31, 
    2, 40, 3,  8, 8, 14, 6, 26, 1, 80, 7, 46, 5,  8, 4, 89, 0, 32, 
    7, 37, 4,  6, 1, 53, 0,  8, 2, 20, 6, 14, 8, 58, 5, 88, 3, 41, 
    2, 99, 3, 63, 7, 32, 8, 35, 4, 27, 0, 22, 6, 40, 1, 96, 5, 42
  };
  const int q9154[] = {
    9, 9, // Number of jobs and machines
    1, 53, 6, 54, 4, 33, 7, 31, 5, 95, 0, 75, 3, 79, 2, 46, 8,  8, 
    8, 53, 2, 76, 7, 93, 1, 53, 0, 48, 5, 82, 4, 35, 3, 10, 6,  2, 
    1, 14, 5, 65, 3, 44, 6, 40, 0, 16, 7, 12, 4, 99, 2, 98, 8, 94, 
    5, 34, 2,  4, 6, 69, 8, 78, 1, 28, 3, 76, 7, 27, 0, 81, 4, 88, 
    0, 56, 7, 79, 5, 78, 6, 61, 3, 77, 4, 55, 8, 87, 1, 72, 2, 18, 
    6, 55, 4, 66, 3, 57, 2, 26, 5, 23, 8, 66, 0, 81, 1, 36, 7,  6, 
    3, 94, 1, 54, 7, 52, 8, 60, 6, 49, 4, 22, 5, 93, 0, 30, 2, 91, 
    8, 88, 5, 47, 6, 67, 1, 74, 4,  1, 7, 38, 3, 60, 0, 39, 2, 51, 
    0, 17, 2, 32, 7, 94, 6, 66, 5, 64, 4, 91, 1, 95, 8, 81, 3, 67
  };
  const int q9155[] = {
    9, 9, // Number of jobs and machines
    2, 48, 3, 95, 5,  7, 1, 97, 8, 54, 7, 81, 4, 71, 0, 36, 6, 85, 
    1, 21, 3, 85, 2, 66, 7, 99, 8, 53, 0, 53, 4, 26, 5, 17, 6, 83, 
    0, 97, 6, 98, 8, 48, 7, 11, 3, 32, 1, 92, 2, 42, 4,  6, 5, 17, 
    2, 33, 6, 33, 0, 82, 5, 71, 8, 36, 4, 55, 7, 56, 1, 84, 3, 70, 
    8, 31, 3, 92, 0, 18, 2, 36, 4, 17, 6, 54, 5,  2, 7, 73, 1, 24, 
    2,  5, 5, 86, 1, 91, 7, 29, 8, 23, 6, 57, 0, 30, 4, 41, 3, 76, 
    7, 45, 5, 89, 8, 40, 3, 24, 2, 47, 1, 56, 6,  9, 0, 62, 4, 27, 
    8, 53, 5, 33, 2, 93, 4, 44, 6,  9, 7, 45, 1, 24, 3, 80, 0, 89, 
    8, 51, 6, 27, 3, 89, 7, 97, 1, 11, 2, 31, 4, 17, 5, 34, 0, 32
  };
  const int q9156[] = {
    9, 9, // Number of jobs and machines
    7, 67, 1, 73, 4, 36, 6, 92, 5, 27, 2, 64, 3, 59, 0, 33, 8, 75, 
    7, 48, 8, 91, 3, 92, 5, 85, 0, 47, 1, 94, 6, 51, 4, 22, 2, 23, 
    2, 24, 1, 34, 6,  7, 3, 45, 7, 99, 0, 23, 5,  1, 8, 66, 4, 57, 
    3, 75, 1,  7, 0, 36, 5, 22, 6, 24, 8, 46, 2, 65, 4, 15, 7,  5, 
    3,  7, 8, 73, 6, 25, 5, 30, 4, 48, 2,  8, 7, 25, 1, 92, 0,  8, 
    6, 12, 4, 91, 3, 26, 8, 73, 2, 10, 7, 59, 5, 89, 0, 82, 1, 13, 
    5, 52, 4, 19, 1, 96, 0, 24, 6, 24, 8, 57, 2, 54, 3, 58, 7, 26, 
    4,  8, 3, 66, 0, 66, 7, 38, 1, 28, 2, 25, 5, 94, 6, 62, 8, 57, 
    3, 49, 7, 95, 5, 14, 8, 17, 1, 53, 4, 43, 0, 77, 6, 19, 2, 85
  };
  const int q9157[] = {
    9, 9, // Number of jobs and machines
    4, 99, 6, 65, 1, 24, 0, 37, 5, 52, 7, 78, 3, 70, 2, 11, 8, 58, 
    1, 67, 3, 28, 8, 32, 2, 23, 5, 55, 7,  3, 4, 72, 0, 80, 6, 67, 
    1, 72, 6, 98, 7, 13, 2, 13, 8, 31, 4, 51, 0, 83, 3, 97, 5, 59, 
    3, 61, 7, 73, 2, 37, 4, 68, 0, 81, 1, 43, 8, 97, 5, 90, 6, 56, 
    3, 98, 5, 68, 7, 93, 8, 76, 4, 40, 1, 93, 6, 76, 2, 70, 0, 52, 
    6, 32, 4, 95, 0, 32, 2, 47, 7, 53, 3, 55, 5, 90, 1, 75, 8, 96, 
    3, 86, 7, 97, 8, 69, 2, 39, 5, 34, 4, 34, 1, 62, 0, 50, 6, 13, 
    0,  6, 7, 87, 6, 26, 5, 94, 4, 36, 1, 80, 2, 77, 3, 71, 8, 24, 
    3, 66, 6, 95, 4, 54, 5, 17, 7, 15, 2, 22, 8, 19, 1, 68, 0, 75
  };
  const int q9158[] = {
    9, 9, // Number of jobs and machines
    8, 84, 4, 14, 7, 68, 3, 29, 2, 52, 0, 36, 6, 43, 5,  2, 1, 64, 
    2, 38, 3, 87, 8, 99, 5, 47, 1, 61, 0, 76, 6, 99, 7, 98, 4, 62, 
    0, 98, 7, 80, 3, 49, 8, 60, 4, 26, 1, 23, 6, 68, 2, 52, 5, 24, 
    0, 59, 5, 91, 2, 48, 6,  5, 4,  6, 7, 61, 1, 88, 3, 78, 8, 16, 
    5, 20, 6, 67, 2, 47, 1, 60, 8, 74, 0, 61, 3, 92, 4, 30, 7, 90, 
    8, 57, 1, 77, 5,  7, 3,  2, 7, 67, 0, 60, 2,  4, 4, 78, 6,  4, 
    8, 98, 7, 65, 6, 67, 2, 49, 0, 90, 5, 88, 1, 96, 3, 27, 4, 66, 
    6, 28, 4, 56, 3, 63, 2, 58, 1,  8, 8, 59, 5, 53, 0, 74, 7, 45, 
    2, 20, 0, 41, 8, 60, 3,  4, 4, 19, 6, 63, 5, 48, 1, 42, 7, 65
  };
  const int q9159[] = {
    9, 9, // Number of jobs and machines
    5, 15, 0, 15, 2, 75, 4, 50, 6, 58, 7, 86, 1, 57, 3, 65, 8, 71, 
    4, 79, 2, 90, 1, 47, 3, 15, 7,  5, 0, 55, 5, 94, 6, 37, 8, 29, 
    4, 90, 3, 90, 6, 52, 7, 95, 5,  8, 8, 18, 1, 39, 0, 10, 2, 77, 
    6, 41, 4, 61, 1, 37, 3, 89, 8, 26, 5, 16, 0, 79, 2, 38, 7, 57, 
    4, 35, 7, 42, 1, 43, 8, 18, 2, 13, 3, 83, 5, 80, 6, 72, 0, 97, 
    8, 69, 2, 41, 7, 43, 6, 47, 0, 22, 1, 30, 4, 23, 3, 15, 5, 44, 
    1, 13, 2, 12, 7, 83, 8,  2, 0, 68, 5, 54, 6, 94, 3, 18, 4, 15, 
    2, 42, 1, 50, 6, 25, 5, 65, 4, 79, 3,  2, 0,  4, 8, 60, 7, 53, 
    4, 82, 0, 13, 7, 92, 5, 58, 2, 67, 8, 82, 3, 18, 6,  7, 1, 82
  };
  const int q9160[] = {
    9, 9, // Number of jobs and machines
    5, 76, 8, 86, 6, 39, 1, 11, 2, 15, 3, 49, 0, 63, 7, 63, 4, 82, 
    3, 70, 0, 40, 7, 24, 6, 73, 1, 57, 8,  8, 5, 25, 2,  9, 4, 15, 
    8, 41, 7, 92, 3, 14, 0, 65, 4, 87, 6, 99, 5, 76, 2, 48, 1, 37, 
    3, 46, 2,  4, 6, 59, 7, 91, 8,  6, 5,  2, 1,  9, 4, 84, 0, 74, 
    4, 84, 2, 72, 0, 64, 7,  7, 8, 91, 5,  3, 3, 23, 1, 17, 6, 15, 
    6, 13, 8, 77, 7,  9, 1, 46, 5, 95, 2, 94, 0, 95, 4, 65, 3, 77, 
    6, 87, 0, 13, 3, 65, 8, 86, 4, 10, 1, 87, 7, 28, 5, 16, 2,  6, 
    3, 82, 2, 16, 7, 75, 4, 73, 5, 97, 0, 56, 6,  3, 8,  9, 1, 69, 
    4, 72, 2, 83, 3, 86, 1, 47, 7, 69, 5, 21, 0, 20, 8, 66, 6, 31
  };
  const int q9161[] = {
    9, 9, // Number of jobs and machines
    3, 50, 6, 46, 2, 75, 0, 60, 5, 87, 1, 65, 8, 23, 4, 86, 7, 80, 
    2, 89, 4, 75, 8, 98, 3, 12, 7, 15, 6, 56, 5, 44, 1, 61, 0, 66, 
    6, 58, 1, 32, 4,  4, 0, 35, 3,  6, 8, 91, 7, 60, 5,  6, 2, 47, 
    4, 24, 7, 93, 2, 73, 3, 78, 5, 16, 0, 60, 6, 27, 1, 73, 8, 51, 
    7, 82, 8, 32, 3, 67, 4,  6, 5, 94, 2, 52, 0, 67, 1, 44, 6, 21, 
    8, 90, 0,  4, 7, 53, 5, 75, 3, 64, 4, 68, 2, 10, 1, 87, 6, 45, 
    7, 79, 5, 51, 3, 31, 1, 81, 0, 28, 8, 98, 6, 90, 2, 21, 4, 27, 
    2, 51, 3, 51, 7, 10, 4, 27, 6, 32, 0, 71, 5, 45, 8, 23, 1, 62, 
    1, 49, 6, 13, 8, 81, 2, 31, 0, 29, 7, 53, 5, 70, 4, 72, 3,  8
  };
  const int q9162[] = {
    9, 9, // Number of jobs and machines
    4, 61, 2, 28, 6, 55, 8, 50, 1, 77, 5,  9, 7, 60, 3, 46, 0, 95, 
    8, 51, 4, 57, 0, 35, 7, 27, 6, 81, 1,  5, 5, 51, 2, 80, 3, 63, 
    1,  7, 3,  8, 5, 32, 4,  8, 6, 68, 0, 96, 7, 37, 8, 90, 2, 26, 
    3, 25, 0, 24, 5, 76, 8, 74, 4, 17, 1, 82, 7, 42, 6,  1, 2, 72, 
    2, 97, 5, 14, 1, 82, 6, 99, 7, 78, 0, 21, 3, 38, 4, 36, 8, 38, 
    2, 17, 3, 81, 0, 76, 8, 38, 1, 86, 6, 55, 4, 97, 7, 59, 5, 26, 
    8, 41, 3, 69, 4, 16, 7, 32, 0, 85, 2, 87, 1, 99, 6, 30, 5, 56, 
    4, 38, 5, 37, 7,  5, 0, 87, 6, 91, 1, 60, 2, 10, 3, 17, 8, 20, 
    4, 93, 3, 60, 5, 78, 0, 93, 8, 43, 7, 70, 1, 55, 2, 24, 6, 86
  };
  const int q9163[] = {
    9, 9, // Number of jobs and machines
    4, 46, 7, 25, 2, 85, 0, 21, 8,  9, 1, 82, 3, 59, 6, 29, 5, 23, 
    0, 42, 2, 37, 8, 30, 4, 10, 6, 66, 7, 46, 5, 37, 1, 57, 3,  6, 
    2, 59, 3, 77, 0, 64, 4, 16, 1, 51, 8, 37, 7, 19, 5, 75, 6, 68, 
    8, 26, 1, 26, 3, 72, 0,  1, 6, 44, 7, 41, 2, 19, 5,  7, 4,  1, 
    7, 16, 1, 49, 5, 84, 2, 87, 3,  1, 0, 32, 4, 76, 6, 83, 8, 18, 
    0, 81, 5, 84, 8, 30, 1, 48, 6,  7, 2, 32, 7, 83, 4, 80, 3, 90, 
    7, 94, 2, 51, 5, 41, 1, 89, 6, 37, 4, 95, 0, 44, 3, 10, 8, 29, 
    7, 40, 3, 95, 2, 31, 8, 59, 6, 98, 1, 11, 4, 67, 5, 30, 0,  4, 
    4, 93, 3, 36, 0,  5, 7, 69, 1, 16, 2, 26, 6, 24, 5, 73, 8, 54
  };
  const int q9164[] = {
    9, 9, // Number of jobs and machines
    6, 70, 0, 62, 4, 17, 7, 21, 1, 84, 5, 21, 2, 82, 3, 61, 8, 92, 
    3, 98, 7,  9, 2, 15, 4, 19, 8, 87, 0, 62, 5,  2, 6, 20, 1, 30, 
    3, 69, 4, 31, 2, 38, 7, 46, 6,  4, 1, 82, 0, 42, 5, 10, 8, 86, 
    7, 12, 4, 25, 2, 91, 1, 47, 3, 13, 8, 61, 6, 43, 5, 25, 0, 63, 
    3, 46, 8, 99, 6, 58, 2, 13, 5, 87, 7, 69, 4, 60, 1, 25, 0, 28, 
    7, 84, 4, 69, 6, 89, 1, 21, 0, 52, 8, 68, 3,  7, 2, 23, 5, 30, 
    4, 26, 8, 60, 1, 44, 6, 57, 5, 43, 2, 43, 7, 62, 3,  3, 0, 73, 
    7, 53, 8, 34, 2, 26, 3, 65, 5, 62, 4, 37, 1, 20, 6, 33, 0, 37, 
    1, 57, 6, 64, 7, 90, 4, 72, 3, 99, 2, 36, 5, 92, 0, 95, 8, 63
  };
  const int q9165[] = {
    9, 9, // Number of jobs and machines
    5, 29, 6, 35, 8, 97, 2, 56, 4, 53, 0, 64, 1, 95, 3, 45, 7, 21, 
    7, 21, 8, 56, 0, 77, 5, 32, 4, 62, 1, 30, 2, 51, 6, 90, 3, 78, 
    5, 11, 0, 25, 2, 42, 6, 90, 1, 65, 7, 90, 3, 70, 8, 87, 4, 79, 
    4, 14, 7, 28, 6, 65, 3, 76, 5, 68, 1, 69, 2,  3, 8, 79, 0, 45, 
    7, 82, 1, 52, 5,  2, 3, 28, 8, 53, 0, 56, 6, 10, 4,  9, 2, 30, 
    7, 76, 6, 64, 2, 68, 0, 88, 1, 40, 3, 23, 5, 61, 4, 78, 8, 35, 
    6, 74, 3, 55, 1, 62, 8, 91, 2, 30, 4, 40, 5, 66, 7, 54, 0, 68, 
    3, 15, 2, 39, 1, 24, 0, 11, 5, 59, 7, 79, 4, 86, 6, 32, 8, 21, 
    3, 62, 8, 95, 4, 13, 6, 61, 2, 55, 5, 20, 0, 81, 7, 26, 1, 51
  };
  const int q9166[] = {
    9, 9, // Number of jobs and machines
    5, 99, 8, 62, 7, 10, 4,  5, 0,  6, 1, 11, 3, 10, 2,  7, 6, 22, 
    3, 91, 8, 41, 1, 54, 2, 88, 4, 83, 7, 88, 5, 37, 0, 98, 6, 34, 
    1, 85, 7, 27, 0, 63, 3, 93, 6, 87, 2, 42, 4, 59, 8, 18, 5, 99, 
    5, 18, 8, 65, 6, 59, 3, 10, 0, 90, 1, 41, 4,  6, 2, 66, 7, 75, 
    1, 20, 0, 89, 5, 31, 8, 24, 3, 40, 2, 65, 7, 82, 6, 18, 4,  6, 
    6, 21, 0, 55, 8, 54, 4, 26, 3, 39, 5, 19, 2, 12, 1, 64, 7, 96, 
    7, 79, 4, 33, 3, 28, 1, 28, 8, 13, 5, 53, 2, 41, 6, 59, 0, 14, 
    3, 58, 0, 67, 8,  9, 4, 69, 7, 79, 5, 94, 6, 81, 2, 17, 1, 23, 
    2,  5, 7, 94, 5, 94, 8, 52, 0, 66, 3,  9, 4,  5, 6, 91, 1, 84
  };
  const int q9167[] = {
    9, 9, // Number of jobs and machines
    4, 77, 0, 29, 5, 86, 3,  6, 1, 55, 7, 14, 8, 99, 2, 33, 6, 26, 
    1, 46, 4, 45, 3, 28, 2, 65, 5, 14, 6, 94, 8, 51, 7, 92, 0, 24, 
    1, 79, 0, 64, 8, 60, 4, 48, 5, 73, 7, 80, 2, 88, 3, 77, 6, 23, 
    7, 69, 0, 89, 2, 59, 3, 30, 5, 52, 6, 97, 4, 92, 1, 18, 8, 49, 
    3, 73, 1, 80, 7, 11, 4,  4, 6, 34, 0, 27, 5, 37, 2, 35, 8, 96, 
    5, 83, 2, 58, 3, 36, 8,  2, 0, 38, 4, 21, 7, 74, 6, 73, 1,  4, 
    1, 87, 7, 65, 8, 50, 2, 59, 3, 40, 4, 67, 0,  8, 5, 94, 6, 89, 
    1, 60, 6, 74, 7, 48, 3, 12, 4, 78, 8, 62, 2, 98, 5, 92, 0, 59, 
    0, 18, 4, 79, 2, 41, 6, 99, 5, 89, 1, 57, 8,  4, 7, 35, 3, 20
  };
  const int q9168[] = {
    9, 9, // Number of jobs and machines
    7, 26, 4, 19, 1, 37, 6, 84, 0, 68, 3, 13, 5, 80, 2, 28, 8, 27, 
    1, 11, 0, 20, 6, 22, 2, 68, 8, 88, 7, 63, 3, 13, 4, 89, 5, 31, 
    8, 95, 3, 96, 6, 49, 7, 52, 4, 91, 2, 63, 0, 49, 1,  2, 5, 90, 
    6,  1, 4, 75, 5, 56, 1, 23, 3, 70, 0, 43, 8, 13, 2, 84, 7,  2, 
    5,  2, 2, 74, 0, 44, 3, 64, 4, 13, 8, 91, 6, 64, 7, 75, 1, 38, 
    2, 53, 1, 36, 0, 64, 3, 97, 4, 25, 7,  1, 5, 49, 8, 14, 6, 37, 
    2, 53, 3, 37, 5, 22, 4, 85, 8, 67, 0, 11, 1, 62, 6, 71, 7, 61, 
    8, 76, 4, 32, 6, 78, 3, 42, 7, 33, 0, 52, 1, 76, 5, 61, 2, 81, 
    5, 61, 7, 24, 8, 82, 4, 48, 1, 48, 2, 14, 3, 90, 6, 66, 0, 31
  };
  const int q9169[] = {
    9, 9, // Number of jobs and machines
    3, 86, 0, 53, 5, 33, 8, 11, 2, 88, 7, 65, 6, 45, 1, 96, 4,  5, 
    2, 99, 3, 16, 0, 92, 8, 76, 4, 85, 5, 65, 6, 78, 7, 51, 1, 40, 
    1, 77, 3, 42, 8, 40, 5, 70, 4, 85, 0, 26, 2, 65, 7, 63, 6, 67, 
    5, 78, 1, 69, 6, 61, 3, 79, 7, 98, 8, 12, 4, 30, 0, 19, 2, 69, 
    4, 31, 8, 25, 2, 14, 1, 23, 0, 84, 3, 15, 6, 73, 5, 93, 7, 83, 
    1, 48, 7, 78, 5, 65, 4, 33, 3, 20, 2, 77, 0, 84, 8, 24, 6, 62, 
    3, 97, 4, 21, 2, 53, 8, 38, 5, 97, 6, 59, 0, 90, 1, 78, 7, 13, 
    1, 37, 5, 64, 7, 31, 6, 90, 3, 57, 4, 31, 2,  2, 8, 19, 0, 46, 
    3, 90, 7, 49, 4,  3, 2,  3, 1, 73, 6, 53, 8,  3, 0, 67, 5, 21
  };
  const int q9170[] = {
    9, 9, // Number of jobs and machines
    7, 34, 1, 16, 2,  6, 0, 44, 8, 12, 3, 29, 5, 77, 4, 57, 6,  2, 
    7, 29, 8,  9, 6, 53, 0,  9, 5, 62, 3, 46, 4, 94, 2, 13, 1, 46, 
    5, 56, 8,  4, 1, 48, 6, 78, 4, 31, 2, 65, 3, 25, 7, 17, 0, 12, 
    7, 69, 5, 38, 4, 80, 0, 83, 6, 96, 3, 48, 1, 56, 2, 33, 8, 14, 
    0, 83, 8,  1, 4,  7, 3, 64, 5, 91, 2, 78, 6, 43, 1,  6, 7, 29, 
    0, 39, 7, 30, 1, 14, 8, 94, 3, 96, 5, 25, 2, 18, 6, 97, 4, 88, 
    6, 78, 8, 27, 4, 34, 2, 34, 7, 35, 5, 93, 1,  1, 3, 89, 0, 55, 
    6, 13, 0, 47, 1, 32, 8, 53, 5,  5, 7, 90, 4,  8, 2,  5, 3, 32, 
    1, 83, 4,  2, 3, 24, 7, 53, 2, 70, 0, 74, 8, 87, 6, 74, 5, 11
  };
  const int q9171[] = {
    9, 9, // Number of jobs and machines
    6, 81, 3, 92, 5, 79, 8, 39, 7, 27, 2, 49, 0, 75, 4, 39, 1,  8, 
    4, 69, 2, 44, 3, 23, 1, 86, 6, 41, 5, 12, 8, 18, 0, 67, 7, 73, 
    2, 92, 1, 50, 7,  3, 8,  9, 5, 88, 4, 27, 0, 64, 6, 50, 3, 39, 
    0, 36, 1, 74, 7, 48, 4, 64, 3, 11, 5, 54, 8, 66, 6, 35, 2, 53, 
    1, 50, 2, 36, 6, 20, 0, 58, 7, 37, 5, 47, 3,  6, 4, 65, 8, 45, 
    4, 71, 8, 61, 3, 40, 7, 26, 2, 82, 1, 29, 6, 63, 0, 61, 5, 65, 
    1, 18, 0, 52, 5,  6, 4, 14, 3, 64, 6, 44, 8, 16, 2,  5, 7, 42, 
    1, 98, 6, 94, 0, 63, 3, 15, 2, 37, 4,  4, 8, 66, 5, 51, 7, 35, 
    0,  1, 1, 61, 6, 77, 4, 80, 2, 43, 7, 42, 3, 23, 5, 69, 8, 65
  };
  const int q9172[] = {
    9, 9, // Number of jobs and machines
    4,  9, 0, 45, 7,  8, 1, 53, 2, 83, 5, 95, 8, 58, 6, 16, 3, 28, 
    2, 47, 3, 40, 6, 48, 7, 80, 0,  6, 5, 18, 4, 62, 1, 38, 8, 32, 
    8, 31, 3, 67, 0, 14, 5, 37, 1, 41, 7, 22, 4, 14, 2, 80, 6, 44, 
    1, 56, 7, 50, 6, 65, 5, 12, 0, 65, 8, 14, 2, 45, 3, 66, 4, 21, 
    3, 98, 6, 86, 0, 21, 4, 71, 1, 94, 2, 16, 5, 95, 8, 37, 7, 99, 
    3, 79, 7, 15, 0, 17, 4, 58, 5, 32, 1, 51, 8,  1, 6, 66, 2, 45, 
    6,  8, 0, 64, 8, 45, 7, 20, 3, 88, 4, 45, 2, 80, 1, 98, 5, 97, 
    1, 55, 4, 87, 7, 20, 5,  3, 2, 83, 0, 87, 8, 61, 3, 77, 6, 22, 
    5, 29, 0, 87, 7, 68, 6, 12, 3, 32, 1, 15, 4, 44, 8, 68, 2, 15
  };
  const int q9173[] = {
    9, 9, // Number of jobs and machines
    6,  2, 8, 45, 1, 76, 5, 94, 4, 15, 3, 12, 2,  6, 7, 85, 0, 69, 
    1,  3, 0, 78, 4, 34, 8, 62, 7, 21, 3, 44, 6,  6, 5,  4, 2,  7, 
    7, 83, 4, 17, 8, 11, 2, 32, 1, 57, 0,  8, 3, 91, 5, 62, 6, 68, 
    0, 64, 4, 75, 5, 45, 2, 84, 6, 60, 3, 45, 1, 76, 8, 27, 7, 15, 
    2, 61, 0, 22, 4, 13, 7, 85, 8,  5, 3, 73, 6, 51, 5, 20, 1,  6, 
    7, 18, 4, 17, 3,  3, 0, 99, 5, 65, 8, 55, 1, 55, 6, 39, 2,  9, 
    2, 15, 5, 90, 6, 27, 0,  5, 7, 11, 4,  1, 3, 86, 1, 73, 8,  7, 
    4,  6, 7, 17, 2, 51, 8, 45, 6, 82, 3, 17, 1, 68, 5, 33, 0, 67, 
    2, 51, 3, 82, 5, 57, 7, 20, 6, 41, 4, 63, 8,  3, 1, 71, 0, 59
  };
  const int q9174[] = {
    9, 9, // Number of jobs and machines
    6,  4, 1, 70, 5, 71, 0, 75, 8, 74, 2, 46, 4,  7, 3, 83, 7, 63, 
    7, 76, 4,  1, 0, 65, 6, 28, 5, 74, 2, 77, 1, 48, 3, 19, 8, 95, 
    0, 83, 4,  8, 7,  2, 3, 96, 5, 42, 2, 24, 8, 56, 1, 64, 6, 35, 
    8, 67, 1, 34, 7, 52, 0, 36, 4, 44, 3, 11, 6, 60, 2, 99, 5, 51, 
    6,  1, 3, 49, 0, 73, 2, 14, 7, 89, 1,  8, 5, 52, 8, 24, 4,  6, 
    5, 96, 4, 31, 2, 50, 8, 88, 1, 97, 6, 22, 7, 73, 3, 83, 0, 19, 
    7, 77, 3, 42, 0, 98, 4, 46, 8,  1, 1, 51, 6, 93, 5, 52, 2, 86, 
    6, 19, 8,  1, 4, 56, 5, 10, 2, 53, 7,  5, 3, 98, 1, 77, 0, 64, 
    1,  1, 7, 21, 4, 65, 8, 46, 0, 80, 6, 50, 2, 10, 5, 36, 3, 30
  };
  const int q9175[] = {
    9, 9, // Number of jobs and machines
    5,  9, 6, 59, 8, 73, 1, 80, 4, 62, 7, 62, 3, 56, 2, 83, 0,  1, 
    2, 51, 7, 22, 3, 40, 1, 26, 0, 39, 5, 68, 4, 37, 8,  9, 6, 20, 
    3, 18, 6, 65, 4, 14, 5, 93, 2,  3, 0, 51, 7, 39, 8,  9, 1, 78, 
    8, 17, 4,  4, 7, 17, 2, 11, 5, 58, 3, 92, 1, 10, 6, 33, 0, 50, 
    2, 16, 1, 62, 8, 78, 5, 69, 0, 61, 3, 31, 6, 63, 4, 57, 7, 53, 
    3, 13, 0, 77, 2, 30, 5, 25, 4, 84, 8, 58, 6, 96, 7, 37, 1, 38, 
    5, 96, 7, 82, 4,  9, 8, 61, 1, 87, 3, 63, 2, 62, 6, 69, 0, 28, 
    4, 69, 2, 26, 6, 65, 1, 80, 3, 31, 8, 65, 5, 74, 0,  5, 7, 59, 
    7, 31, 2, 22, 6, 23, 8, 59, 3, 75, 1, 61, 0, 99, 5, 50, 4, 13
  };
  const int q9176[] = {
    9, 9, // Number of jobs and machines
    1, 99, 6, 58, 4, 76, 7, 37, 0, 37, 2, 67, 8, 76, 5, 63, 3, 66, 
    8, 53, 4, 75, 7, 12, 5, 69, 3, 56, 2, 87, 0, 12, 1, 85, 6, 30, 
    7, 13, 4, 21, 8, 94, 1, 93, 3, 98, 0, 72, 6, 27, 5, 52, 2, 83, 
    8, 60, 5, 95, 4, 17, 7, 88, 6, 24, 0, 85, 3, 37, 1, 75, 2, 65, 
    8,  6, 0, 34, 1, 23, 7, 42, 5, 95, 2, 29, 6, 15, 4, 60, 3, 61, 
    4, 60, 6, 96, 0, 43, 5, 82, 3, 41, 7, 86, 8, 66, 1, 59, 2, 54, 
    7,  3, 8,  7, 2, 89, 5, 80, 3, 70, 4, 75, 1, 79, 0, 19, 6, 45, 
    7, 22, 0, 63, 2, 26, 3, 30, 4, 69, 1, 18, 5,  6, 8, 16, 6, 81, 
    5, 41, 1, 38, 4, 27, 3, 29, 2, 10, 0, 39, 6, 22, 8, 23, 7, 22
  };
  const int q9177[] = {
    9, 9, // Number of jobs and machines
    2, 59, 8, 50, 7, 43, 6, 14, 3, 14, 4, 26, 5, 44, 0, 17, 1, 16, 
    6, 48, 4, 23, 2, 18, 3, 61, 0, 69, 5, 54, 8,  1, 7, 58, 1, 66, 
    0, 98, 4, 69, 7, 70, 6, 92, 5, 47, 1, 55, 2, 42, 3, 28, 8,  7, 
    6, 14, 1, 88, 5, 18, 0, 13, 8, 70, 2,  7, 4,  6, 7, 78, 3,  9, 
    4, 69, 6, 54, 7, 46, 3, 84, 1, 75, 8, 99, 0, 34, 5,  5, 2,  6, 
    3, 18, 0, 43, 8, 70, 6, 18, 2, 56, 1, 47, 7, 76, 5, 42, 4, 97, 
    3, 84, 5, 47, 4, 88, 8, 69, 1, 87, 0, 32, 7, 52, 6, 72, 2, 51, 
    2, 63, 0, 58, 4, 41, 8,  2, 6, 41, 1, 83, 3, 90, 5, 21, 7, 74, 
    3,  1, 4, 50, 7, 88, 0, 34, 5, 94, 1, 25, 8, 92, 6, 35, 2, 14
  };
  const int q9178[] = {
    9, 9, // Number of jobs and machines
    2, 46, 1, 51, 3, 66, 8, 38, 7, 84, 0, 88, 4, 24, 5, 24, 6, 94, 
    0, 95, 5, 56, 2, 39, 8, 33, 6, 27, 4, 87, 1, 94, 3, 26, 7, 11, 
    4,  2, 5, 45, 2, 37, 8, 58, 7, 97, 3, 95, 1, 60, 0, 25, 6, 22, 
    0, 48, 6, 35, 8, 64, 3, 40, 4, 64, 2,  4, 7, 39, 5, 41, 1, 50, 
    4, 48, 7, 66, 0, 97, 2,  2, 3, 62, 5, 20, 6, 18, 1, 67, 8, 26, 
    4, 70, 5, 82, 0, 30, 1, 24, 7, 97, 8, 11, 2, 74, 6, 37, 3, 57, 
    2, 22, 7, 55, 1, 85, 8, 73, 0,  4, 3,  2, 6, 68, 5, 53, 4, 62, 
    6, 57, 1, 45, 5, 90, 4, 62, 8, 77, 0, 21, 7, 12, 3, 90, 2, 24, 
    0, 30, 1, 89, 2, 51, 7, 20, 6, 66, 5, 58, 4, 96, 3, 63, 8, 85
  };
  const int q9179[] = {
    9, 9, // Number of jobs and machines
    3, 49, 6, 81, 2, 20, 4, 50, 5, 19, 0, 88, 8, 59, 1, 57, 7, 74, 
    8, 48, 5, 40, 7, 20, 4, 97, 1, 96, 0, 66, 2, 55, 6, 22, 3, 38, 
    2,  6, 8, 86, 0, 66, 1, 52, 6, 19, 5, 34, 4,  2, 3, 61, 7, 78, 
    3, 21, 1, 16, 7, 10, 8, 26, 0,  8, 6, 80, 5, 10, 4, 86, 2, 36, 
    0, 48, 3, 42, 4, 70, 2, 90, 8, 43, 1, 74, 6, 48, 5,  3, 7, 34, 
    4, 10, 0, 23, 8, 20, 3, 63, 6, 20, 7, 54, 5, 43, 1, 82, 2, 98, 
    6, 91, 2, 88, 7, 62, 8, 45, 1, 20, 0,  6, 5, 85, 3, 19, 4, 35, 
    5, 81, 7, 32, 1, 85, 3, 87, 6, 29, 8, 69, 2, 96, 0, 73, 4, 41, 
    6, 66, 5, 53, 1,  6, 2, 68, 0, 10, 3, 63, 8, 31, 7,  6, 4, 25
  };
  const int q9180[] = {
    9, 9, // Number of jobs and machines
    0, 85, 6, 93, 7, 49, 2, 47, 8, 43, 4, 74, 3, 99, 5, 19, 1, 59, 
    6, 80, 8, 56, 0, 97, 4,  4, 2, 68, 1, 34, 7, 96, 3,  9, 5, 68, 
    5, 50, 7, 58, 0, 42, 3, 10, 6, 58, 1, 70, 4,  3, 8, 63, 2, 27, 
    6, 89, 0, 85, 7,  1, 5, 16, 3,  7, 1, 13, 2, 12, 4, 18, 8, 21, 
    8, 40, 6, 74, 7, 10, 5, 32, 1, 48, 4, 25, 0, 81, 2, 92, 3, 51, 
    5, 47, 3, 54, 8,  2, 1, 42, 0, 79, 4, 43, 7, 64, 6, 83, 2, 25, 
    6, 16, 0, 14, 7, 72, 4, 16, 8, 87, 2, 60, 5, 96, 3,  9, 1, 97, 
    3, 21, 5, 21, 0, 54, 2, 70, 1, 48, 6, 80, 4, 83, 7, 68, 8, 74, 
    3, 47, 6, 25, 0, 27, 1, 36, 2, 54, 8, 86, 4, 92, 5, 15, 7, 47
  };
  const int q9181[] = {
    9, 9, // Number of jobs and machines
    1, 82, 5, 46, 3, 48, 0, 40, 8,  5, 7, 68, 2, 77, 4, 73, 6, 57, 
    1, 40, 0, 22, 3, 28, 4, 52, 7, 90, 2, 44, 6, 89, 5, 84, 8, 55, 
    0, 60, 7, 90, 6, 63, 2, 16, 4, 90, 5, 24, 1, 24, 3, 99, 8, 40, 
    8, 70, 0, 36, 4, 67, 7, 21, 3, 31, 5, 94, 1, 88, 6, 48, 2, 56, 
    4, 36, 8, 53, 0, 71, 2, 39, 7, 15, 5, 59, 1, 48, 6, 65, 3, 54, 
    1, 40, 0,  9, 2, 54, 4, 26, 7, 95, 8, 29, 3, 66, 5, 54, 6,  9, 
    6,  7, 8,  4, 0, 94, 1, 81, 2, 98, 4, 32, 7, 33, 5, 98, 3, 65, 
    2, 52, 3, 18, 7, 54, 5, 95, 0,  6, 1, 84, 6, 35, 4, 99, 8, 37, 
    6, 78, 7, 63, 2, 63, 0,  5, 1, 31, 3, 52, 8,  5, 5, 47, 4,  3
  };
  const int q9182[] = {
    9, 9, // Number of jobs and machines
    3, 34, 0, 91, 6, 78, 5, 86, 4, 24, 1, 83, 2, 59, 7, 18, 8, 81, 
    7, 38, 1, 67, 2, 96, 3, 77, 5, 63, 4, 16, 6, 24, 0, 74, 8, 11, 
    1, 56, 4, 41, 7, 30, 3, 23, 5, 78, 2,  1, 6, 23, 8, 53, 0, 74, 
    0, 60, 4, 47, 2,  7, 8, 27, 5, 96, 3, 18, 1, 55, 6, 57, 7, 54, 
    0, 54, 6, 63, 4, 63, 3, 39, 5, 57, 7,  2, 1, 56, 8, 53, 2, 72, 
    8, 59, 6, 87, 2, 77, 3, 59, 5, 73, 0, 95, 4, 64, 7, 39, 1, 54, 
    4, 89, 8, 98, 0, 34, 3, 35, 6, 50, 2, 35, 5, 93, 7, 96, 1, 77, 
    3, 81, 6, 12, 8,  3, 7, 91, 4, 94, 5, 12, 2, 78, 0, 37, 1, 16, 
    7, 46, 6, 60, 2, 90, 8, 75, 1, 52, 3, 10, 5, 74, 0, 38, 4, 91
  };
  const int q9183[] = {
    9, 9, // Number of jobs and machines
    4, 99, 7, 91, 5, 90, 8, 96, 3, 93, 1, 26, 0, 99, 2, 91, 6, 79, 
    4, 30, 3, 33, 1, 57, 8, 37, 5, 87, 7, 45, 6, 91, 0,  2, 2, 34, 
    0, 72, 3, 78, 4,  6, 8, 60, 1, 10, 6, 98, 2, 62, 5, 16, 7,  3, 
    6, 94, 4, 81, 2, 19, 1, 50, 8, 96, 5, 71, 7, 58, 3, 53, 0, 21, 
    8, 90, 1, 97, 7,  6, 2, 10, 0, 61, 5,  6, 6, 51, 4, 58, 3, 76, 
    0, 59, 4, 69, 2, 97, 5, 60, 1, 49, 3, 27, 6, 61, 8, 31, 7, 11, 
    2, 41, 8, 77, 3, 34, 0, 56, 7, 90, 5, 87, 6, 95, 1, 80, 4, 16, 
    3, 48, 6,  6, 2, 79, 0, 15, 5, 90, 4, 55, 8, 74, 7, 87, 1, 21, 
    8, 85, 0, 57, 5, 61, 2,  6, 7, 14, 6, 71, 3, 54, 4, 86, 1, 59
  };
  const int q9184[] = {
    9, 9, // Number of jobs and machines
    7, 31, 6, 16, 0, 36, 2, 31, 4,  4, 8, 40, 3, 95, 1, 19, 5, 70, 
    2,  8, 7, 38, 1,  1, 6, 74, 5, 47, 3, 66, 4, 94, 0, 93, 8, 34, 
    1, 80, 5, 14, 6, 76, 0, 91, 4, 49, 8, 93, 7, 74, 2, 14, 3, 43, 
    6, 55, 5,  5, 3, 46, 7, 32, 1, 19, 8, 32, 2, 51, 4, 22, 0, 52, 
    2, 21, 1,  3, 8, 91, 3, 65, 0, 84, 5, 85, 7, 60, 6, 92, 4, 32, 
    6, 58, 5, 54, 2, 73, 1, 60, 0, 49, 4, 66, 3, 17, 7, 93, 8, 75, 
    4, 71, 5, 46, 6, 42, 2, 52, 0, 82, 8,  9, 3, 90, 7, 96, 1, 47, 
    8, 86, 4, 81, 0, 79, 5, 54, 6, 85, 2, 64, 7, 73, 3, 11, 1, 31, 
    3, 88, 7, 46, 8,  4, 4, 90, 2, 74, 6, 56, 1, 47, 5, 99, 0, 28
  };
  const int q9185[] = {
    9, 9, // Number of jobs and machines
    5, 13, 0, 77, 2, 77, 1, 64, 7, 13, 8, 78, 6, 46, 3, 39, 4, 51, 
    7, 73, 2, 61, 0,  5, 8, 16, 6, 84, 4, 84, 5, 57, 3, 89, 1, 40, 
    0, 87, 3, 93, 2, 16, 1, 23, 5, 39, 4, 59, 7, 71, 8, 97, 6, 36, 
    6, 30, 4, 35, 5, 79, 1, 74, 8, 49, 0, 30, 3, 48, 2, 44, 7, 61, 
    0, 73, 1, 17, 7, 34, 2, 30, 5, 50, 3, 34, 4, 58, 6, 15, 8, 55, 
    1, 55, 0, 57, 4, 89, 2, 20, 5, 93, 7, 46, 8, 93, 6, 67, 3, 85, 
    3, 51, 4, 41, 2, 94, 7, 85, 5,  7, 8, 19, 6, 97, 1, 69, 0, 66, 
    2, 58, 8, 49, 6, 31, 3, 90, 0, 34, 5, 60, 7, 14, 4, 54, 1, 41, 
    3, 99, 6, 74, 8, 41, 0, 74, 4, 45, 7, 16, 2,  7, 1, 36, 5, 66
  };
  const int q9186[] = {
    9, 9, // Number of jobs and machines
    4, 81, 3, 47, 7, 14, 5, 29, 6,  6, 8, 93, 2, 69, 0, 49, 1, 35, 
    5, 96, 8, 72, 1, 33, 4, 96, 6, 24, 2, 68, 7, 39, 3, 75, 0, 32, 
    6, 13, 8, 35, 2, 69, 5, 94, 7, 23, 0, 40, 4, 41, 3, 24, 1, 68, 
    5, 73, 4, 61, 7, 15, 0, 63, 6, 17, 2, 14, 1, 74, 3, 85, 8, 74, 
    2, 79, 4, 91, 8,  8, 7, 93, 6, 23, 5, 81, 1, 31, 3, 37, 0, 68, 
    3, 72, 2, 79, 8, 17, 4, 92, 7, 36, 5,  5, 1, 23, 6, 88, 0, 77, 
    7, 54, 2, 81, 0, 89, 8, 14, 5, 19, 3, 60, 4, 93, 6, 33, 1,  8, 
    8, 24, 5, 62, 7, 10, 1, 41, 4, 19, 0, 99, 3, 98, 6, 51, 2, 77, 
    5, 90, 1, 93, 8, 70, 6, 91, 4, 23, 0, 28, 7, 65, 2,  6, 3, 40
  };
  const int q9187[] = {
    9, 9, // Number of jobs and machines
    5, 87, 0,  8, 1, 37, 7, 82, 3, 78, 4, 46, 8, 35, 6, 32, 2, 82, 
    7, 34, 1, 72, 4,  3, 6, 49, 8, 54, 5, 78, 0, 86, 3,  7, 2, 70, 
    1, 93, 0, 98, 7, 85, 6, 51, 3, 99, 2,  8, 8, 83, 5, 61, 4, 19, 
    6, 69, 5, 33, 1, 42, 3, 96, 8, 24, 4, 23, 0, 99, 2, 33, 7, 28, 
    5, 56, 2, 68, 4, 54, 7, 98, 8, 35, 3, 74, 6, 84, 0, 71, 1, 24, 
    2, 79, 7, 94, 0, 62, 6, 84, 5,  7, 4, 12, 3, 78, 8, 22, 1, 52, 
    6,  1, 0, 83, 1, 95, 8, 42, 7, 95, 4, 53, 2, 34, 5, 40, 3, 84, 
    6,  8, 3, 24, 8, 68, 7, 96, 5, 81, 0, 16, 4, 86, 2, 74, 1, 60, 
    7, 50, 6, 55, 3,  1, 8, 37, 0, 78, 1, 71, 5, 96, 2, 25, 4, 75
  };
  const int q9188[] = {
    9, 9, // Number of jobs and machines
    4, 67, 8, 75, 0, 66, 5, 26, 1, 76, 2, 72, 7, 22, 3, 15, 6, 28, 
    1, 70, 6, 48, 3, 55, 2, 44, 4, 18, 5, 42, 0, 21, 8, 14, 7, 52, 
    2, 52, 1, 82, 8, 77, 4, 51, 5, 60, 3, 45, 0, 74, 6, 14, 7, 23, 
    0, 39, 2, 23, 8, 24, 3, 44, 6,  3, 7, 82, 4, 85, 5, 79, 1, 95, 
    3, 77, 1, 83, 8,  7, 7, 75, 5, 50, 4, 42, 6, 72, 0, 61, 2, 39, 
    7, 74, 2, 65, 3, 93, 6, 17, 0, 94, 8, 87, 1, 57, 4,  5, 5, 73, 
    3, 87, 0, 25, 2, 74, 7, 38, 1, 67, 6, 36, 5, 45, 4, 38, 8, 84, 
    3, 93, 5, 84, 1, 48, 7, 18, 4, 63, 2, 12, 6, 55, 8,  5, 0, 90, 
    0, 50, 7, 61, 4, 50, 8, 55, 3, 55, 5, 46, 6, 83, 1, 81, 2, 21
  };
  const int q9189[] = {
    9, 9, // Number of jobs and machines
    4, 22, 6, 38, 1,  2, 2, 35, 5, 36, 0,  5, 3, 81, 8,  1, 7, 71, 
    3, 88, 4, 33, 7,  7, 0, 13, 2, 82, 8, 22, 1, 97, 6, 24, 5,  1, 
    2, 75, 3, 13, 7, 23, 4, 34, 5, 67, 1, 68, 8, 40, 6, 87, 0, 47, 
    4, 40, 1, 47, 5, 35, 8, 95, 7,  8, 2, 91, 6, 91, 0, 93, 3, 51, 
    7, 54, 8, 14, 1, 34, 3, 58, 6, 81, 2, 88, 0, 18, 5, 95, 4, 81, 
    4, 48, 1, 79, 6, 76, 0, 66, 7, 65, 3, 76, 2, 68, 8, 57, 5, 50, 
    5, 57, 6, 63, 2, 80, 7, 51, 8, 50, 0, 85, 4, 95, 1, 66, 3, 11, 
    5, 42, 3, 41, 6, 32, 2, 85, 8, 95, 7, 74, 1, 17, 4, 84, 0, 70, 
    1, 56, 3, 68, 6, 61, 7, 74, 2, 53, 8, 53, 5, 89, 4, 86, 0, 33
  };
  const int q9190[] = {
    9, 9, // Number of jobs and machines
    6, 58, 5, 52, 8, 66, 7, 97, 4, 95, 3, 49, 0, 94, 2, 89, 1, 74, 
    1, 57, 2, 29, 3, 21, 7, 12, 4, 65, 8, 96, 0, 65, 5,  2, 6, 56, 
    2, 13, 3, 59, 4, 84, 7, 17, 6, 60, 0, 64, 5, 74, 1, 29, 8, 91, 
    0, 97, 3, 98, 5, 52, 6, 46, 8, 61, 4, 14, 7, 77, 2,  3, 1, 14, 
    7, 75, 1,  6, 3, 89, 8, 98, 5, 20, 4, 78, 6, 69, 0, 73, 2, 94, 
    8, 11, 6, 26, 2,  6, 5, 36, 3, 17, 0, 97, 1, 56, 7, 64, 4, 18, 
    1, 72, 2, 23, 5, 49, 7, 94, 3, 81, 8, 96, 6, 29, 4, 34, 0, 48, 
    0, 15, 1, 17, 5, 42, 2, 71, 3, 57, 8, 31, 7, 33, 6, 40, 4, 30, 
    7, 39, 5, 25, 6, 13, 4, 31, 8, 49, 0, 30, 2, 90, 3, 81, 1, 25
  };
  const int q9191[] = {
    9, 9, // Number of jobs and machines
    2, 44, 6,  6, 8, 96, 7, 34, 0, 24, 1, 65, 3,  7, 5, 63, 4, 61, 
    4,  8, 1,  9, 2, 33, 7,  8, 0, 17, 8, 75, 3, 82, 6, 65, 5, 14, 
    2, 50, 1,  3, 0, 28, 4, 18, 8, 36, 6, 44, 7, 41, 3, 36, 5, 43, 
    4, 32, 5, 57, 0,  8, 7, 29, 8, 96, 6, 29, 2, 81, 3, 73, 1, 23, 
    8, 75, 7, 57, 2, 11, 5, 17, 1, 71, 3, 43, 6, 54, 4,  5, 0, 26, 
    2, 13, 7, 87, 6, 87, 5, 84, 3, 41, 1, 85, 0, 20, 8, 89, 4, 26, 
    7, 18, 2, 49, 3,  8, 6, 72, 5, 93, 8, 23, 0, 89, 1, 66, 4, 15, 
    1,  6, 3, 54, 5, 45, 8, 52, 4, 79, 6, 18, 2, 46, 0, 44, 7,  2, 
    6,  1, 3, 80, 2, 62, 7, 80, 8, 94, 5, 31, 0, 70, 1, 42, 4, 87
  };
  const int q9192[] = {
    9, 9, // Number of jobs and machines
    2, 17, 5, 48, 1, 67, 6, 84, 3, 53, 7, 94, 0, 99, 8, 18, 4, 32, 
    8, 60, 7, 57, 4, 40, 2, 38, 6, 99, 1, 12, 5, 62, 3, 78, 0, 13, 
    0, 62, 7, 47, 8, 71, 5, 80, 4, 17, 6, 13, 2, 69, 1, 28, 3, 60, 
    8, 28, 3, 60, 1, 46, 7, 96, 4, 87, 0, 59, 6, 79, 5, 35, 2,  2, 
    8, 62, 1, 39, 5,  5, 2, 29, 4, 94, 0, 38, 3, 48, 6, 72, 7,  1, 
    7, 13, 6, 39, 5, 37, 8, 65, 0, 15, 3,  1, 2, 37, 4, 21, 1, 33, 
    1, 93, 6,  1, 4, 93, 2, 82, 0, 52, 5, 93, 7, 89, 3, 68, 8, 99, 
    1, 47, 0, 94, 5, 74, 3, 57, 8, 58, 6, 14, 4, 44, 2, 19, 7, 16, 
    2, 90, 3, 57, 7, 91, 5, 91, 4, 36, 1, 59, 0,  3, 8, 95, 6, 85
  };
  const int q9193[] = {
    9, 9, // Number of jobs and machines
    4, 48, 5, 22, 7, 86, 6, 98, 0, 36, 1, 26, 2, 26, 8, 13, 3, 63, 
    5, 71, 0, 14, 4, 39, 6, 82, 8, 75, 3, 52, 2, 94, 7, 17, 1,  8, 
    3, 36, 6, 38, 8, 98, 0, 44, 2, 95, 5, 19, 1, 91, 7, 81, 4, 68, 
    8, 33, 1, 99, 3, 61, 5, 15, 6, 26, 0, 64, 7, 47, 2, 13, 4, 68, 
    3,  2, 0, 85, 6, 46, 4, 23, 1, 91, 8, 86, 5,  4, 7, 36, 2, 94, 
    2,  4, 0, 82, 6, 17, 7, 16, 8, 62, 4, 27, 5, 34, 1, 58, 3, 51, 
    5,  3, 6, 95, 3, 17, 4, 88, 1, 94, 0, 74, 8, 41, 7, 82, 2, 41, 
    1, 32, 6, 73, 8, 13, 4, 94, 3, 76, 2, 35, 5, 97, 0, 16, 7, 48, 
    8, 64, 4, 36, 3, 17, 7,  9, 6, 21, 5, 22, 1, 89, 2, 93, 0,  8
  };
  const int q9194[] = {
    9, 9, // Number of jobs and machines
    0, 98, 7, 73, 4, 47, 6, 14, 2, 73, 3, 25, 1, 62, 8, 39, 5,  5, 
    1,  8, 0, 29, 4, 28, 6, 19, 5, 37, 8, 70, 2, 41, 7, 92, 3, 34, 
    6, 54, 8, 47, 0, 41, 2, 47, 3,  7, 7, 97, 5, 37, 1, 23, 4, 54, 
    1, 79, 5, 78, 8, 69, 3,  8, 6, 11, 0, 43, 4, 43, 2, 51, 7, 60, 
    5, 68, 6, 15, 3, 18, 1, 54, 8, 27, 4, 44, 2, 32, 7, 50, 0, 27, 
    7, 72, 2, 58, 8, 91, 4,  8, 1, 65, 0,  2, 5, 51, 3, 17, 6, 33, 
    4, 23, 8, 79, 6, 50, 1,  2, 3, 84, 5, 57, 0, 31, 7, 56, 2, 79, 
    3, 63, 5, 71, 1,  6, 7, 38, 2, 40, 0, 29, 4, 25, 8, 33, 6, 95, 
    7, 42, 2, 26, 8, 71, 4, 72, 0,  3, 6,  2, 1, 58, 3, 33, 5, 70
  };
  const int q9195[] = {
    9, 9, // Number of jobs and machines
    0,  8, 4, 59, 6, 62, 8, 40, 3, 12, 2, 21, 1, 98, 7, 37, 5, 89, 
    2, 38, 1, 35, 8, 88, 7, 69, 3, 99, 4, 51, 6, 27, 5, 26, 0, 15, 
    5, 16, 1, 90, 3, 46, 8, 20, 2, 36, 6, 44, 4, 11, 0, 91, 7, 37, 
    0, 84, 3, 84, 4, 60, 2,  4, 1, 32, 6,  3, 7, 13, 8, 63, 5, 51, 
    7, 47, 4, 95, 3, 23, 1, 87, 2,  1, 5, 20, 0,  7, 8, 71, 6, 95, 
    6, 18, 1, 93, 4, 80, 2, 73, 7, 96, 0, 90, 3, 46, 8, 31, 5, 87, 
    3, 86, 6, 43, 8, 33, 0, 97, 5, 59, 2, 83, 7, 27, 1, 38, 4, 99, 
    1, 25, 5,  3, 0, 19, 6, 56, 3, 34, 7, 64, 8, 97, 4, 37, 2, 45, 
    4, 75, 3, 19, 8, 36, 7, 61, 1,  8, 6,  2, 2, 37, 0, 62, 5, 74
  };
  const int q9196[] = {
    9, 9, // Number of jobs and machines
    5, 12, 1, 32, 6, 39, 7, 45, 8, 96, 2, 41, 0, 98, 4, 15, 3, 13, 
    6, 19, 4, 65, 2, 84, 3, 35, 1, 61, 5, 20, 7, 33, 0, 49, 8, 82, 
    7, 17, 3, 38, 4, 19, 6, 86, 0, 10, 8, 93, 1, 67, 2, 55, 5, 62, 
    1, 14, 8, 29, 5,  3, 6, 17, 3, 59, 0, 30, 2, 25, 7, 95, 4, 37, 
    1, 64, 0, 52, 2, 44, 5, 76, 3, 19, 4, 21, 7, 85, 8, 17, 6, 88, 
    0, 35, 8, 73, 7, 86, 1, 79, 2, 88, 6,  9, 4, 34, 3, 50, 5, 32, 
    0, 23, 5, 94, 7, 11, 2, 65, 6, 78, 3, 92, 4, 24, 1, 89, 8,  5, 
    4, 93, 6,  7, 3, 22, 1, 13, 7, 76, 8, 17, 5, 66, 0, 74, 2, 67, 
    1, 71, 8,  3, 5, 72, 2, 82, 3, 90, 6, 35, 7, 28, 0, 52, 4, 48
  };
  const int q9197[] = {
    9, 9, // Number of jobs and machines
    8, 16, 0, 48, 7, 80, 6, 75, 2, 38, 4,  5, 3, 36, 1, 48, 5, 86, 
    7, 97, 2, 37, 5, 37, 8,  2, 4, 76, 0, 75, 6, 59, 1, 41, 3, 15, 
    6, 12, 0, 31, 1, 98, 4, 94, 2, 53, 8, 26, 3, 43, 5, 60, 7,  6, 
    3,  8, 7,  4, 1,  7, 8, 74, 0, 18, 2, 16, 6, 57, 4, 84, 5, 10, 
    6, 97, 5, 28, 4, 50, 7, 18, 1, 90, 2, 49, 0, 36, 8, 81, 3, 57, 
    5,  1, 1, 13, 2, 71, 0, 68, 3, 40, 7, 99, 8, 34, 6, 61, 4, 66, 
    0, 98, 5, 97, 1, 87, 3, 96, 6, 33, 8, 50, 7, 90, 4, 19, 2, 84, 
    5, 29, 6, 14, 0, 70, 7, 52, 3, 51, 4, 61, 2, 32, 8, 19, 1, 77, 
    3, 99, 8, 21, 5, 78, 7, 56, 4, 62, 1, 59, 6, 17, 0, 97, 2, 82
  };
  const int q9198[] = {
    9, 9, // Number of jobs and machines
    2, 35, 6, 51, 8, 50, 1, 18, 0, 60, 5, 21, 3, 23, 7, 34, 4,  8, 
    3,  1, 8, 78, 0, 21, 7, 12, 6, 33, 5, 95, 2, 72, 4, 44, 1, 54, 
    4, 39, 7, 47, 2, 44, 6, 14, 3, 26, 1, 25, 5, 87, 8, 86, 0, 17, 
    3, 17, 4, 98, 1, 36, 0, 83, 2, 96, 7, 45, 5, 67, 6, 66, 8, 93, 
    1, 39, 0, 75, 2, 96, 3, 13, 7, 75, 8, 53, 6, 77, 4, 31, 5, 72, 
    8, 28, 7, 44, 6,  9, 1, 45, 5, 76, 4, 75, 3, 53, 2, 13, 0, 90, 
    6, 83, 7,  2, 8, 57, 2, 12, 1, 65, 0, 54, 5, 36, 4, 99, 3, 73, 
    3, 79, 6, 35, 8, 14, 7, 22, 5, 87, 1, 68, 4, 89, 2, 62, 0,  5, 
    2, 57, 0, 41, 6, 41, 5, 50, 3, 18, 8, 66, 1, 80, 4, 39, 7, 83
  };
  const int q9199[] = {
    9, 9, // Number of jobs and machines
    0, 85, 6, 16, 8, 61, 3, 12, 5, 78, 4, 71, 1, 30, 2, 27, 7, 33, 
    1, 43, 8, 74, 6,  3, 7, 47, 5,  9, 2, 69, 0, 85, 4, 15, 3, 47, 
    2, 78, 1, 86, 3, 30, 0, 77, 5, 50, 7, 50, 6, 82, 8, 63, 4, 92, 
    0, 27, 8, 10, 4, 38, 3, 18, 2, 87, 5, 84, 7, 45, 1, 29, 6, 38, 
    5, 52, 3, 80, 0, 54, 6, 48, 2, 67, 1, 34, 4, 13, 7, 40, 8, 24, 
    7, 35, 0, 42, 6, 29, 8, 52, 5,  9, 1, 44, 3, 26, 2, 57, 4, 50, 
    7, 31, 2, 90, 1, 85, 8, 55, 6, 10, 4, 49, 5, 67, 3, 28, 0, 53, 
    2, 71, 1, 54, 6, 39, 8,  8, 4, 94, 5, 54, 7, 64, 3,  3, 0, 57, 
    6, 76, 0, 12, 7, 82, 8, 90, 2, 79, 4, 30, 5, 26, 1, 91, 3, 34
  };
  const int q9200[] = {
    9, 9, // Number of jobs and machines
    6, 63, 7, 29, 0, 86, 8, 29, 3, 92, 1, 78, 5, 63, 4, 64, 2, 73, 
    5, 49, 3, 67, 4, 95, 0, 57, 7, 56, 6, 15, 1, 48, 8, 69, 2,  4, 
    5, 98, 4, 87, 7, 19, 2, 70, 3, 51, 0,  5, 8,  4, 6, 86, 1, 29, 
    8, 35, 0, 35, 1, 48, 7, 85, 6, 27, 4, 33, 3,  1, 5, 83, 2, 98, 
    1, 84, 6, 41, 7, 29, 4, 87, 3,  9, 8, 67, 0, 73, 2, 60, 5, 46, 
    6, 74, 0,  1, 3, 18, 2,  8, 8,  7, 1, 26, 5, 87, 7, 20, 4, 42, 
    5, 39, 3, 66, 2, 59, 6, 36, 0, 14, 7, 73, 4, 71, 8, 11, 1, 48, 
    1, 71, 8, 89, 6, 40, 5, 12, 0, 88, 4, 43, 2, 13, 3, 28, 7, 31, 
    2, 76, 6, 23, 0, 95, 8, 85, 4, 91, 3, 67, 1, 95, 7,  5, 5, 86
  };
  const int q9201[] = {
    9, 9, // Number of jobs and machines
    0, 38, 5, 29, 1, 67, 4, 67, 6, 13, 3, 92, 2, 94, 8, 70, 7, 15, 
    4, 45, 1, 84, 3, 14, 6, 20, 2, 92, 7, 71, 5, 85, 0, 43, 8, 88, 
    2, 84, 4, 46, 0, 32, 3, 31, 8, 21, 1, 39, 5, 85, 7, 45, 6, 77, 
    4, 21, 6, 74, 3, 53, 5,  2, 8, 79, 0, 54, 7, 15, 2, 83, 1, 15, 
    2, 59, 1, 40, 7, 28, 5, 94, 8, 33, 0, 62, 6, 94, 4, 26, 3, 97, 
    8, 16, 2, 31, 0, 66, 3, 58, 7, 51, 5, 38, 1, 90, 6, 35, 4, 73, 
    0, 41, 4, 77, 8, 76, 7, 49, 2, 89, 6, 52, 3, 17, 5, 57, 1, 12, 
    6, 77, 2, 48, 4, 16, 1, 71, 8, 29, 3, 42, 0, 33, 7, 83, 5, 33, 
    5, 51, 4,  3, 6, 79, 3, 60, 1,  5, 8, 80, 2,  5, 0, 85, 7, 74
  };
  const int q9202[] = {
    9, 9, // Number of jobs and machines
    3, 95, 1, 97, 7, 56, 6, 80, 8,  7, 2, 41, 0, 24, 4, 35, 5, 31, 
    5, 98, 3, 30, 6,  1, 7, 73, 1, 27, 0, 45, 2, 43, 4, 97, 8, 55, 
    4, 71, 2, 32, 8, 54, 5, 59, 3, 63, 1, 41, 6, 67, 0, 40, 7, 86, 
    3, 59, 1, 79, 8, 24, 7, 94, 5, 46, 2, 78, 4, 45, 0, 55, 6, 28, 
    2, 45, 1, 11, 5, 17, 8,  4, 4, 66, 7, 81, 3, 21, 0, 57, 6, 57, 
    1, 16, 7, 99, 3, 88, 2, 69, 4, 90, 6, 47, 8, 80, 5, 97, 0, 52, 
    0, 67, 2, 81, 1, 32, 3, 70, 4, 74, 5, 86, 6,  5, 7,  5, 8, 60, 
    6,  6, 3, 59, 4, 72, 2, 50, 5, 28, 1, 54, 7, 60, 0, 93, 8, 57, 
    3, 83, 4, 67, 0, 44, 8,  9, 7, 72, 5, 43, 2, 66, 1, 58, 6, 43
  };
  const int q9203[] = {
    9, 9, // Number of jobs and machines
    1,  5, 8, 17, 4, 22, 6, 41, 7, 79, 2, 78, 3, 69, 0, 84, 5, 57, 
    7, 98, 8,  7, 0, 50, 5, 22, 6, 85, 4, 51, 3, 78, 1, 31, 2, 60, 
    3, 47, 5, 56, 6, 24, 8, 10, 4, 11, 7, 54, 1,  5, 0, 54, 2, 94, 
    6,  4, 1, 71, 7, 16, 4, 38, 5, 39, 8,  1, 3, 97, 2, 74, 0, 11, 
    5, 32, 4, 25, 1, 57, 0, 82, 8, 96, 6, 51, 2, 99, 7, 29, 3, 10, 
    0, 34, 6, 47, 7,  6, 1,  7, 3, 25, 2, 85, 4, 74, 5, 74, 8, 34, 
    4, 94, 6, 64, 2, 92, 3, 25, 7, 32, 1, 53, 5, 99, 0, 66, 8,  7, 
    3, 53, 7, 42, 1, 78, 4, 67, 8, 66, 5, 78, 2, 16, 6, 57, 0,  7, 
    3, 15, 5, 12, 6, 64, 0, 15, 2, 62, 1, 66, 4, 17, 8, 25, 7, 94
  };
  const int q9204[] = {
    9, 9, // Number of jobs and machines
    5, 63, 4, 74, 1, 99, 6, 80, 7, 40, 3, 11, 8, 64, 0, 11, 2, 67, 
    0, 79, 6, 49, 2, 10, 7,  5, 5, 30, 8, 39, 3,  2, 4, 75, 1, 98, 
    8, 88, 2, 17, 1, 31, 6, 54, 3, 13, 0, 82, 4, 37, 5, 47, 7, 32, 
    7, 82, 4, 26, 3, 50, 8, 75, 1, 34, 6, 73, 5, 49, 0, 11, 2, 80, 
    0, 88, 2, 88, 1, 90, 7, 65, 4, 55, 5, 18, 8, 31, 3, 33, 6, 98, 
    7, 68, 3,  5, 1, 41, 5, 18, 2, 38, 6, 31, 4, 53, 0, 63, 8, 46, 
    8, 92, 7, 55, 1, 51, 4,  3, 3, 84, 6, 54, 2, 60, 0, 86, 5, 32, 
    4, 72, 3, 17, 8, 58, 6, 12, 5, 25, 1, 96, 0, 12, 2, 65, 7, 10, 
    4, 34, 3, 10, 6, 45, 2, 39, 7, 31, 0, 55, 1, 92, 5, 75, 8, 21
  };
  const int q9205[] = {
    9, 9, // Number of jobs and machines
    6, 54, 4, 18, 8, 19, 5, 66, 3, 54, 1, 50, 2, 68, 0, 77, 7, 99, 
    7, 15, 5, 90, 6,  4, 0, 92, 4, 52, 2, 77, 1, 61, 3, 16, 8, 81, 
    7, 12, 0, 62, 5,  1, 2, 29, 3, 75, 6, 59, 4, 18, 1, 81, 8, 59, 
    0, 67, 2, 99, 4, 51, 1, 47, 6, 52, 8, 30, 7, 31, 5, 68, 3,  5, 
    7, 25, 6,  2, 5, 73, 2, 23, 8, 73, 3,  7, 1, 77, 4, 49, 0, 32, 
    0, 63, 4, 84, 6, 43, 3, 21, 7, 77, 1, 82, 2, 12, 5, 17, 8, 31, 
    8, 37, 5,  1, 0, 51, 7, 13, 4, 22, 1, 36, 6, 98, 3, 21, 2, 44, 
    1, 95, 8, 22, 3, 79, 2, 58, 5, 86, 6, 91, 0, 17, 4,  8, 7, 80, 
    8, 60, 0, 42, 1, 66, 5, 15, 4, 53, 2, 50, 3, 41, 6, 35, 7, 90
  };
  const int q9206[] = {
    9, 9, // Number of jobs and machines
    5, 20, 3, 98, 8, 35, 4, 70, 0, 41, 1, 45, 2, 76, 6,  8, 7, 86, 
    2, 10, 5, 57, 7, 94, 1, 45, 6,  9, 8, 18, 0, 79, 4, 37, 3,  4, 
    6, 54, 4, 72, 3, 59, 5, 80, 8, 39, 0, 39, 7, 46, 2, 75, 1, 89, 
    7, 34, 1,  3, 6, 57, 5, 46, 0, 66, 3, 22, 8, 11, 4, 40, 2, 88, 
    3, 71, 4, 49, 0, 14, 1, 17, 5, 33, 7, 29, 6, 72, 8, 75, 2, 42, 
    3, 88, 7, 89, 0, 33, 4, 23, 6, 86, 2, 50, 5, 99, 1, 73, 8, 24, 
    8,  3, 3, 72, 0, 35, 6, 13, 5, 68, 1, 25, 4, 62, 2, 24, 7, 48, 
    1, 41, 2, 56, 0, 24, 8, 30, 4, 68, 5,  7, 6, 92, 3, 93, 7, 90, 
    4, 73, 0, 75, 6, 78, 3, 71, 7, 12, 1, 63, 2, 86, 5, 12, 8, 52
  };
  const int q9207[] = {
    9, 9, // Number of jobs and machines
    0, 82, 1, 38, 7, 10, 6, 99, 3, 60, 5, 36, 8,  8, 2, 23, 4, 18, 
    6, 60, 3,  3, 5, 50, 0,  4, 2, 60, 7, 59, 8, 39, 1, 97, 4, 80, 
    1, 57, 5, 33, 2, 55, 4,  1, 7,  3, 0, 84, 3,  5, 8, 34, 6, 56, 
    1,  8, 7, 60, 3, 47, 8, 75, 6, 63, 4, 75, 5, 48, 0, 55, 2, 36, 
    8, 74, 5, 36, 3, 30, 0, 70, 4,  8, 6,  5, 2, 75, 7, 88, 1, 27, 
    4, 76, 7, 79, 0, 30, 6, 52, 5, 23, 2, 86, 1,  6, 8, 41, 3, 68, 
    2, 47, 7, 72, 6, 82, 0, 70, 8, 20, 1, 65, 4, 56, 3, 25, 5, 80, 
    8, 49, 1, 62, 5, 34, 6, 98, 3,  9, 4, 25, 2, 63, 7, 37, 0, 76, 
    7, 87, 0, 23, 3, 56, 5, 93, 2, 16, 8, 92, 6, 69, 4, 35, 1,  6
  };
  const int q9208[] = {
    9, 9, // Number of jobs and machines
    0, 60, 7, 53, 4,  2, 6,  3, 1, 76, 2, 85, 3,  3, 5, 64, 8, 89, 
    4, 17, 7, 55, 3,  2, 0, 59, 6, 77, 5, 49, 1, 65, 8, 59, 2, 62, 
    8, 24, 0, 83, 6, 33, 3,  3, 7, 50, 4, 49, 5, 35, 1, 12, 2, 51, 
    4, 91, 1, 68, 7, 79, 5,  2, 8, 70, 2, 68, 6, 52, 0, 55, 3, 30, 
    7, 46, 1, 84, 0,  7, 4, 81, 3, 27, 8,  7, 5, 40, 2, 84, 6, 26, 
    3, 96, 1, 10, 5, 24, 8, 93, 7, 93, 2, 13, 6, 72, 4, 85, 0, 63, 
    6, 39, 1, 37, 4,  8, 0, 81, 3, 78, 2, 40, 7, 67, 8, 94, 5, 18, 
    1, 41, 3, 86, 8, 86, 5, 88, 4, 18, 7, 72, 2, 65, 6, 39, 0, 95, 
    5, 28, 7, 48, 8, 35, 6, 26, 1, 97, 4, 78, 0, 12, 3, 94, 2, 44
  };
  const int q9209[] = {
    9, 9, // Number of jobs and machines
    2, 38, 7, 93, 4, 74, 3, 43, 5, 12, 8,  9, 6, 12, 1, 60, 0,  1, 
    0, 10, 3, 66, 2, 20, 7, 41, 6,  4, 4, 47, 1, 94, 8, 89, 5, 49, 
    4, 92, 5, 60, 8, 58, 1, 75, 0, 50, 7, 40, 3, 26, 6, 75, 2,  1, 
    7, 63, 3, 45, 8, 34, 4, 12, 5, 69, 6, 28, 1, 19, 2, 37, 0, 98, 
    7,  6, 1, 64, 0, 42, 2, 40, 4, 96, 8, 76, 3, 85, 6, 40, 5, 68, 
    3, 53, 0, 26, 1, 32, 4, 52, 8, 71, 7,  9, 2, 76, 6, 56, 5, 33, 
    0, 43, 7, 80, 3, 77, 1, 16, 8, 16, 4, 51, 5,  3, 2, 70, 6, 46, 
    6, 34, 5, 78, 3, 15, 0, 80, 1, 42, 8,  4, 7, 24, 4,  4, 2, 57, 
    4, 36, 5, 61, 8, 74, 0, 76, 3, 44, 7, 62, 2, 75, 6, 67, 1, 90
  };
  const int q9210[] = {
    9, 9, // Number of jobs and machines
    2, 71, 3, 88, 1, 27, 5, 37, 8, 91, 7,  1, 6,  6, 0, 67, 4, 29, 
    3, 63, 7, 62, 4, 74, 6, 89, 2, 49, 8, 34, 5, 80, 1, 58, 0, 59, 
    8, 38, 3, 82, 5, 15, 6, 22, 2, 89, 4, 35, 0, 33, 7, 15, 1, 60, 
    3, 58, 8, 38, 4, 39, 5, 92, 1, 80, 2, 10, 7, 15, 6, 90, 0, 92, 
    1, 85, 2, 30, 6, 15, 5, 67, 7, 95, 8, 76, 3,  9, 4, 29, 0, 82, 
    7, 73, 8, 58, 5, 84, 3, 47, 4, 98, 1, 52, 6, 69, 0, 19, 2, 54, 
    8,  1, 6, 27, 3, 42, 2, 48, 7, 89, 1, 74, 5, 27, 4, 27, 0, 52, 
    1, 81, 5, 88, 0, 82, 7, 15, 2, 32, 3, 70, 4, 99, 6, 51, 8, 44, 
    0, 11, 1, 38, 8, 44, 2, 51, 7, 33, 3, 74, 5, 19, 4,  8, 6, 24
  };
  const int q9211[] = {
    9, 9, // Number of jobs and machines
    0, 64, 1, 82, 6, 25, 3, 65, 5, 83, 7, 34, 8, 90, 4, 50, 2, 28, 
    8, 15, 6, 65, 2, 38, 1, 32, 5, 87, 4, 36, 0,  1, 7, 46, 3, 77, 
    5, 75, 6, 18, 4, 38, 1, 89, 3, 93, 0, 40, 8, 62, 7, 70, 2, 11, 
    1, 86, 3, 24, 7, 14, 0, 25, 8, 22, 6, 95, 2, 83, 4, 56, 5, 31, 
    8, 90, 2, 73, 3, 53, 1,  7, 6, 18, 7, 57, 0, 26, 5, 34, 4, 55, 
    3,  6, 0, 19, 5, 99, 1, 56, 4, 61, 2, 63, 6, 34, 8, 94, 7, 17, 
    4, 22, 7, 70, 8, 46, 1, 76, 0, 50, 5, 11, 3, 36, 2, 63, 6, 59, 
    7, 58, 5, 71, 1, 26, 6,  9, 8, 35, 4, 47, 2, 28, 0, 11, 3, 73, 
    5, 63, 2, 95, 0, 42, 3, 85, 8, 53, 7, 63, 6, 61, 4, 58, 1, 47
  };
  const int q9212[] = {
    9, 9, // Number of jobs and machines
    1,  2, 0, 98, 2, 27, 4, 54, 6, 18, 8, 41, 3, 14, 5, 33, 7, 16, 
    7,  1, 6, 97, 3, 18, 1, 49, 0, 46, 2, 78, 4, 49, 5, 60, 8, 73, 
    1, 55, 5, 23, 2,  6, 3,  1, 0, 79, 7, 31, 8, 91, 4, 82, 6, 89, 
    1, 95, 2, 82, 4, 25, 0,  2, 8, 64, 5, 41, 7, 68, 6, 98, 3, 76, 
    0, 74, 5, 67, 6, 71, 2, 87, 8, 94, 7, 48, 3, 35, 1, 72, 4,  6, 
    2, 54, 1, 46, 5, 91, 4, 52, 0, 22, 7,  8, 3, 93, 8, 81, 6, 15, 
    8, 52, 5, 63, 3, 61, 0,  1, 4, 89, 6, 82, 2,  8, 1, 32, 7, 50, 
    6, 68, 0, 85, 3, 68, 2, 34, 4, 95, 5, 42, 1,  6, 8, 14, 7, 66, 
    0,  1, 2,  7, 7, 66, 4, 13, 5, 26, 1, 31, 3, 31, 6,  6, 8, 99
  };
  const int q9213[] = {
    9, 9, // Number of jobs and machines
    8, 47, 2, 36, 0, 21, 6, 13, 5, 82, 3, 98, 7, 51, 1, 10, 4, 16, 
    5, 93, 0, 61, 8, 73, 4,  5, 3, 86, 1, 42, 6,  1, 7, 80, 2,  7, 
    4, 90, 6, 82, 8, 52, 2, 70, 5, 99, 0, 24, 7, 16, 3, 64, 1, 84, 
    0,  2, 6, 42, 5, 53, 8, 65, 2, 38, 7, 12, 4, 63, 3, 28, 1, 27, 
    2, 43, 5, 53, 4,  7, 3, 43, 6, 38, 1, 76, 0, 90, 8, 53, 7, 52, 
    1, 42, 6, 83, 8, 14, 2, 10, 4, 79, 0, 70, 5, 42, 3, 19, 7, 21, 
    7, 26, 0, 47, 4, 34, 2,  9, 6, 14, 5, 14, 1, 93, 3, 52, 8, 68, 
    1, 42, 3, 69, 0,  6, 6, 71, 8, 55, 4, 15, 2, 21, 7, 26, 5,  4, 
    7, 75, 2, 69, 8, 40, 3, 90, 4, 21, 1, 26, 6, 43, 5, 37, 0, 33
  };
  const int q9214[] = {
    9, 9, // Number of jobs and machines
    7, 47, 4,  7, 1, 40, 5, 72, 6, 33, 3, 98, 0, 39, 2, 66, 8, 70, 
    1,  5, 0, 81, 7, 96, 8, 40, 5, 72, 3, 20, 6, 16, 2, 91, 4, 89, 
    8, 11, 1, 23, 7, 17, 5, 94, 6, 71, 2, 98, 4, 16, 0, 43, 3, 88, 
    0,  4, 6, 41, 4, 76, 3, 20, 5,  7, 8, 16, 1, 62, 7, 26, 2, 58, 
    0, 47, 7, 22, 4, 97, 1, 40, 6, 78, 5, 89, 3, 21, 8, 89, 2, 86, 
    1, 88, 2, 98, 5, 35, 3, 15, 7, 66, 4,  7, 0, 56, 6, 24, 8, 13, 
    0, 74, 5, 72, 4, 44, 8, 38, 3, 55, 6,  7, 7, 75, 1, 45, 2, 20, 
    6, 95, 2, 99, 5, 29, 4, 66, 1, 43, 3, 28, 8, 87, 0, 56, 7, 79, 
    5, 17, 8, 67, 1, 79, 0, 69, 3, 33, 2,  3, 7,  2, 6, 47, 4, 31
  };
  const int q9215[] = {
    9, 9, // Number of jobs and machines
    3, 38, 1, 22, 5, 16, 4, 35, 6, 44, 2, 96, 8, 90, 0, 97, 7, 18, 
    1,  9, 5, 46, 7,  8, 4, 20, 3, 77, 6, 54, 0,  9, 2, 80, 8, 85, 
    2, 88, 7, 33, 0, 46, 3, 85, 1, 84, 6, 97, 8, 75, 5, 65, 4, 65, 
    5, 82, 4,  5, 2, 72, 1, 35, 7, 19, 3, 70, 0, 75, 8, 39, 6, 10, 
    1, 32, 2, 15, 6,  5, 8, 69, 4, 36, 5, 90, 3, 54, 0,  6, 7, 83, 
    6, 25, 4, 30, 7, 85, 3, 27, 0, 30, 1, 19, 5, 47, 8, 62, 2, 58, 
    2,  8, 1, 90, 5, 54, 0, 27, 8, 47, 7, 76, 4, 19, 6, 95, 3, 62, 
    8, 79, 4, 81, 1, 98, 5, 37, 2, 38, 6, 83, 7, 44, 0, 12, 3, 20, 
    6, 75, 0, 20, 1, 68, 7, 19, 5, 59, 4, 95, 2, 96, 3, 93, 8, 92
  };
  const int q9216[] = {
    9, 9, // Number of jobs and machines
    1, 55, 3, 62, 4, 78, 6, 75, 0, 18, 8, 62, 2, 19, 5, 88, 7, 32, 
    4, 90, 7, 94, 3, 92, 1, 80, 5, 69, 6, 32, 8, 28, 2, 26, 0, 27, 
    7, 26, 5, 89, 0, 81, 6, 20, 3, 83, 4, 46, 1, 76, 2,  7, 8, 20, 
    5, 25, 0, 19, 1, 10, 3, 32, 7, 72, 6, 51, 8, 85, 2, 36, 4, 71, 
    0, 92, 8, 60, 3, 75, 5, 90, 6, 91, 2, 61, 7, 66, 1, 28, 4, 27, 
    3, 40, 5, 31, 0, 86, 6, 51, 2, 43, 1, 18, 7, 56, 4, 44, 8, 44, 
    0, 55, 6, 83, 1, 61, 4, 43, 5, 76, 8,  8, 2, 60, 3, 63, 7,  4, 
    2, 13, 1, 90, 3, 48, 5, 62, 8, 56, 7, 25, 6, 95, 0, 37, 4, 95, 
    8, 52, 2, 33, 4, 33, 3, 77, 6, 10, 0, 13, 7, 28, 5, 95, 1, 92
  };
  const int q9217[] = {
    9, 9, // Number of jobs and machines
    0,  8, 4,  4, 2, 64, 7, 58, 1, 44, 6, 17, 5, 90, 8, 48, 3, 88, 
    5, 81, 0, 59, 4,  4, 7, 86, 1, 36, 2, 47, 8, 42, 3, 85, 6, 29, 
    5,  7, 6, 87, 7, 94, 3, 98, 8, 58, 0, 99, 1, 39, 4, 56, 2,  4, 
    2, 85, 3, 21, 8, 74, 6, 87, 7, 41, 5, 51, 0, 55, 1, 88, 4, 44, 
    2,  2, 3, 25, 0, 54, 8, 84, 4, 43, 7, 29, 6, 47, 5,  1, 1, 60, 
    3, 98, 1, 44, 5, 37, 2, 56, 7, 84, 0, 57, 4, 43, 6, 39, 8, 39, 
    0, 67, 7, 53, 3, 83, 1, 78, 8, 74, 5, 81, 2,  3, 6, 23, 4, 97, 
    7, 78, 0, 37, 1, 65, 3, 99, 6, 14, 2, 37, 5, 34, 8, 19, 4, 97, 
    8, 85, 3, 29, 6, 73, 7, 66, 4, 56, 0, 68, 2, 38, 5, 94, 1, 21
  };
  const int q9218[] = {
    9, 9, // Number of jobs and machines
    8, 95, 4, 35, 2, 33, 6, 48, 0, 13, 3, 16, 5, 34, 7, 98, 1, 89, 
    3, 40, 0, 10, 7, 70, 2,  6, 5, 69, 6, 40, 1, 30, 8, 14, 4, 17, 
    2, 49, 1, 95, 0, 75, 4, 53, 5, 27, 8, 17, 3, 82, 7, 67, 6, 56, 
    3, 74, 6, 12, 5, 78, 8, 37, 4, 80, 7, 24, 2,  3, 1, 12, 0, 85, 
    1, 58, 0, 26, 3, 21, 5, 65, 2, 15, 4, 91, 7, 79, 6, 28, 8,  4, 
    7, 16, 1, 82, 0, 85, 8, 22, 4, 92, 3,  4, 6, 86, 2, 77, 5, 98, 
    6, 14, 2, 65, 4,  2, 5, 91, 1, 77, 8, 88, 3, 61, 7, 98, 0, 63, 
    0, 67, 2, 81, 4, 75, 6, 59, 5, 57, 1, 89, 8, 97, 7, 59, 3, 10, 
    2, 30, 5, 49, 1, 89, 6, 68, 7, 43, 3, 62, 4,  1, 8, 65, 0, 64
  };
  const int q9219[] = {
    9, 9, // Number of jobs and machines
    6, 62, 7, 18, 8, 53, 0, 17, 4, 50, 3, 31, 1, 51, 2, 23, 5, 84, 
    4, 58, 5, 76, 1, 84, 7, 71, 3, 29, 8, 53, 0, 22, 2, 76, 6, 88, 
    7, 46, 3, 89, 8, 97, 0, 18, 2, 10, 1, 12, 4, 70, 5, 36, 6, 36, 
    4, 99, 3, 77, 5, 54, 1, 76, 2, 68, 8, 28, 0, 68, 6, 55, 7, 19, 
    5, 15, 4,  4, 0, 63, 1, 31, 2, 70, 7, 25, 3,  3, 6, 95, 8, 73, 
    5, 83, 7, 96, 2, 87, 0, 73, 6,  5, 8, 59, 4, 45, 1, 88, 3, 41, 
    0, 71, 8, 69, 1,  1, 2, 27, 4, 18, 3,  5, 6,  7, 7, 70, 5, 62, 
    2,  8, 6, 29, 0,  3, 4, 39, 8, 46, 5, 26, 1, 51, 3, 63, 7, 99, 
    1, 87, 8, 14, 7, 26, 0, 52, 6, 79, 4, 29, 5, 83, 2, 80, 3, 91
  };
  const int q9220[] = {
    9, 9, // Number of jobs and machines
    1, 48, 5, 23, 6, 54, 3, 55, 7, 57, 0, 86, 2, 99, 8, 71, 4,  3, 
    0, 84, 8, 90, 5, 15, 4, 17, 7, 63, 2, 27, 3, 14, 1,  3, 6, 31, 
    3, 79, 4, 67, 8, 41, 2, 67, 1, 77, 0, 36, 6, 98, 5, 57, 7, 22, 
    4,  1, 7, 88, 1, 60, 8, 32, 6, 42, 2, 29, 5, 99, 3, 36, 0,  7, 
    3, 99, 5, 68, 7, 93, 8, 45, 1, 36, 4, 82, 0, 72, 6, 56, 2, 70, 
    6, 70, 8, 72, 7,  7, 1, 45, 5, 86, 2, 92, 0,  3, 4, 23, 3, 46, 
    6, 24, 4, 54, 7, 47, 1, 55, 5, 88, 0, 29, 3, 50, 8, 86, 2, 90, 
    6, 98, 1, 40, 4, 87, 7, 19, 8, 39, 0, 56, 3, 14, 5, 15, 2, 36, 
    8, 69, 6, 32, 5, 47, 2,  5, 0, 37, 3, 54, 1, 81, 7, 66, 4, 83
  };
  const int q9221[] = {
    9, 9, // Number of jobs and machines
    2, 74, 4, 71, 5, 78, 8, 56, 6, 60, 7, 84, 1, 66, 0, 54, 3, 86, 
    5, 87, 6, 53, 0, 87, 7, 54, 2, 23, 3, 56, 1, 32, 4,  7, 8,  8, 
    6, 18, 7, 52, 4, 68, 5, 49, 2, 21, 1, 49, 0, 60, 3,  1, 8, 21, 
    1, 62, 5, 38, 0, 66, 8, 72, 3, 63, 4, 99, 2, 19, 7, 30, 6, 56, 
    6, 38, 8, 31, 2, 31, 7,  9, 3, 35, 0, 48, 4, 66, 1, 46, 5,  9, 
    0, 19, 6, 39, 8, 35, 7, 51, 2, 69, 4, 43, 5, 97, 1, 32, 3, 70, 
    1, 74, 6, 92, 7, 74, 5, 61, 2, 56, 0, 61, 3, 72, 8, 12, 4, 77, 
    6, 17, 0, 49, 8, 73, 1, 15, 5, 95, 3, 38, 2,  4, 7, 47, 4, 98, 
    7, 58, 2, 41, 3, 43, 0, 28, 1, 40, 8, 54, 4, 35, 5,  6, 6, 17
  };
  const int q9222[] = {
    9, 9, // Number of jobs and machines
    7, 74, 6, 84, 0, 36, 4, 10, 1, 37, 5, 72, 3, 10, 2, 53, 8, 75, 
    7, 52, 0, 65, 2, 31, 5, 20, 3,  3, 4,  2, 6, 95, 1, 68, 8, 81, 
    4,  3, 8, 71, 1, 68, 3, 89, 2, 26, 7, 99, 5,  1, 0, 45, 6,  9, 
    2, 67, 0, 74, 4, 55, 8, 46, 6, 91, 1, 34, 5, 39, 3, 24, 7, 80, 
    6, 65, 5, 53, 1, 45, 4, 34, 2, 46, 8, 26, 3, 89, 7, 38, 0, 72, 
    7, 32, 5,  4, 6, 26, 0, 22, 8, 27, 4, 87, 2, 52, 1, 88, 3, 47, 
    3, 29, 6, 84, 8, 28, 4, 34, 7, 20, 2, 94, 0, 81, 1, 31, 5, 69, 
    2, 32, 5, 67, 7, 59, 6, 14, 3, 58, 8, 16, 1, 78, 0,  3, 4, 73, 
    7, 10, 8, 49, 5, 30, 0, 92, 3, 29, 2, 46, 4, 34, 1, 88, 6, 69
  };
  const int q9223[] = {
    9, 9, // Number of jobs and machines
    1, 48, 8, 31, 7, 23, 4, 61, 5, 23, 0, 65, 3, 48, 2, 70, 6, 68, 
    7, 52, 5, 71, 0, 36, 4, 99, 2,  4, 8, 21, 1, 92, 6, 62, 3, 67, 
    2, 62, 7, 59, 8, 86, 1, 11, 6, 12, 5, 48, 0, 82, 3, 32, 4, 31, 
    6, 65, 7, 55, 1, 68, 5, 18, 8, 34, 3, 80, 4,  6, 0, 70, 2, 80, 
    1,  6, 5, 51, 4, 33, 8, 10, 6, 63, 3, 75, 7, 56, 2, 15, 0, 68, 
    2, 58, 0, 99, 7, 75, 3, 51, 5, 18, 1, 58, 4, 47, 8, 70, 6, 97, 
    3, 58, 8, 71, 7, 21, 6, 16, 4, 49, 5, 23, 0, 33, 1, 53, 2, 53, 
    7, 38, 2, 19, 1, 26, 4, 45, 0, 44, 5, 52, 3, 36, 8, 87, 6, 10, 
    4, 24, 5, 86, 2,  2, 3, 40, 0, 37, 6, 19, 7, 44, 8, 60, 1, 83
  };
  const int q9224[] = {
    9, 9, // Number of jobs and machines
    1, 93, 2, 54, 7, 11, 3, 51, 5, 29, 8, 41, 4, 30, 6,  9, 0,  6, 
    5, 59, 1, 75, 2, 19, 7, 23, 4, 32, 3, 56, 8, 70, 6, 14, 0, 61, 
    7, 28, 6, 65, 3, 83, 5, 76, 0, 61, 8, 91, 4, 72, 2, 47, 1, 41, 
    2, 35, 4, 61, 6, 13, 1, 72, 0, 23, 3,  5, 8,  5, 5, 96, 7, 17, 
    5, 56, 1, 29, 4, 65, 6,  6, 8, 73, 7, 12, 3, 83, 0, 24, 2,  9, 
    3, 65, 0, 78, 5, 66, 1, 33, 6, 83, 8, 11, 4,  4, 2,  8, 7,  7, 
    1, 81, 6, 63, 3,  8, 4, 17, 8, 54, 0, 72, 2,  4, 5,  3, 7, 16, 
    3, 16, 0, 29, 8, 79, 2, 78, 1, 79, 4, 88, 5, 31, 6,  8, 7, 14, 
    4, 52, 5, 58, 8,  5, 2, 84, 6, 30, 0, 12, 7, 12, 1, 17, 3, 19
  };
  const int q9225[] = {
    9, 9, // Number of jobs and machines
    4, 85, 1, 35, 6, 59, 2, 17, 0, 59, 8, 93, 5, 90, 3, 51, 7, 17, 
    6, 31, 2,  1, 8, 67, 0, 28, 7, 84, 1,  7, 4, 88, 3, 58, 5, 57, 
    0, 32, 5, 17, 1, 96, 8, 35, 3, 19, 6, 21, 4, 36, 2, 50, 7, 72, 
    8, 24, 5, 59, 3, 65, 6, 51, 2, 14, 7,  1, 4, 82, 0, 85, 1, 24, 
    1, 31, 3, 34, 0, 95, 5, 16, 6, 49, 8, 94, 7, 40, 4, 24, 2, 48, 
    6, 69, 5,  8, 2,  1, 7, 60, 0, 68, 8,  9, 3, 79, 1, 48, 4, 39, 
    3, 99, 0, 89, 1,  2, 2, 20, 5, 77, 4,  4, 7,  5, 8, 91, 6, 13, 
    7, 34, 5, 44, 3, 46, 8, 53, 4, 13, 0, 91, 2, 13, 1, 15, 6, 59, 
    8, 12, 5, 39, 7, 20, 1, 72, 0, 73, 2, 81, 3, 60, 4, 89, 6, 52
  };
  const int q9226[] = {
    9, 9, // Number of jobs and machines
    6, 48, 7, 60, 5, 53, 3, 25, 1, 54, 8, 41, 0, 58, 2, 90, 4, 92, 
    6, 58, 8, 61, 3, 35, 7, 24, 4, 49, 2, 53, 0, 18, 5, 49, 1, 74, 
    5, 25, 3, 91, 1, 84, 4, 23, 7, 92, 6, 69, 2, 78, 8, 54, 0,  6, 
    3,  3, 6, 56, 4, 56, 2, 86, 1, 38, 8, 77, 7, 66, 5, 67, 0,  6, 
    0, 73, 2, 70, 6, 19, 7, 13, 8, 61, 3, 86, 5, 72, 4, 55, 1, 16, 
    7, 76, 3, 52, 8, 52, 0, 77, 2, 37, 1, 89, 6, 25, 5, 27, 4, 80, 
    8, 30, 6, 15, 3, 37, 0, 81, 2, 61, 7, 12, 4, 12, 1, 70, 5, 45, 
    8, 27, 0, 36, 3,  1, 1, 89, 5, 53, 2, 32, 6, 98, 7, 37, 4,  5, 
    0, 82, 5, 80, 2, 73, 3, 60, 8, 52, 7, 30, 4, 22, 1,  6, 6, 69
  };
  const int q9227[] = {
    9, 9, // Number of jobs and machines
    0, 21, 5, 94, 4, 17, 3, 27, 6, 51, 1, 29, 7, 18, 8, 51, 2, 65, 
    2, 68, 7,  8, 3, 94, 1, 45, 6, 85, 0, 98, 4, 20, 8, 24, 5, 54, 
    5, 27, 2, 84, 7, 99, 3, 73, 0, 17, 6, 68, 8, 75, 1, 30, 4, 55, 
    1, 66, 2, 82, 0, 70, 8, 87, 6, 28, 3, 41, 4, 67, 5, 30, 7, 49, 
    4, 26, 1, 97, 7, 77, 0, 22, 3, 60, 2, 31, 6, 23, 8, 53, 5, 77, 
    0, 68, 4, 51, 5, 15, 6, 37, 3, 77, 7, 26, 2, 47, 1, 25, 8, 61, 
    0, 58, 2, 80, 1, 45, 4, 40, 5, 28, 8, 63, 6, 49, 7, 42, 3, 73, 
    3, 86, 8, 83, 0, 63, 5, 39, 1, 85, 4, 96, 7, 72, 6, 91, 2, 95, 
    6, 41, 8,  5, 0, 94, 3, 85, 4, 34, 5, 29, 7, 44, 1, 87, 2,  4
  };
  const int q9228[] = {
    9, 9, // Number of jobs and machines
    5, 48, 6, 55, 7, 34, 8, 72, 3, 86, 0, 62, 4, 11, 1, 18, 2, 91, 
    6, 65, 2, 34, 3, 36, 1, 43, 5, 93, 7, 90, 8, 82, 0, 77, 4, 43, 
    6, 65, 0, 11, 7, 47, 5, 33, 2, 44, 8, 76, 1, 13, 4, 69, 3, 32, 
    2, 47, 5, 50, 8, 20, 0, 88, 1,  7, 4, 26, 6, 27, 3,  9, 7, 13, 
    4, 89, 6, 59, 8, 79, 7, 37, 0, 61, 3, 13, 1, 95, 2, 68, 5, 41, 
    4, 80, 1, 52, 8, 55, 0, 43, 7, 45, 3, 49, 2, 13, 6, 90, 5, 91, 
    5, 94, 2, 90, 7, 88, 0, 43, 1, 82, 6, 22, 8, 54, 4, 64, 3, 11, 
    2,  3, 5,  8, 3, 73, 7, 51, 4, 27, 1, 13, 6, 22, 0, 28, 8, 31, 
    6, 48, 8, 36, 1, 17, 7, 81, 0, 20, 5,  3, 3, 74, 4, 96, 2, 65
  };
  const int q9229[] = {
    9, 9, // Number of jobs and machines
    3, 95, 1, 36, 7, 73, 6, 12, 5, 55, 2, 26, 8, 40, 4, 33, 0, 90, 
    0,  2, 4, 58, 1, 55, 7,  4, 2, 32, 3, 14, 8, 73, 6, 31, 5, 94, 
    7, 59, 0, 94, 5, 53, 8, 95, 1, 66, 2, 77, 6, 20, 4, 82, 3, 83, 
    0, 33, 1, 49, 8, 93, 6, 99, 5, 58, 3, 75, 4, 64, 2, 36, 7,  2, 
    7,  7, 8, 36, 4, 33, 5, 25, 2, 61, 6, 83, 3,  6, 0, 74, 1, 99, 
    7, 30, 8,  7, 6, 69, 0, 33, 4, 59, 2, 82, 1, 69, 3,  9, 5, 54, 
    1, 61, 8, 39, 5, 92, 2, 22, 4, 88, 3, 48, 7, 96, 6, 61, 0,  5, 
    5, 79, 2, 41, 8,  5, 6,  4, 4, 24, 3, 46, 7, 77, 1, 88, 0, 75, 
    4,  6, 3, 59, 0, 57, 5, 54, 1, 29, 7, 73, 6, 20, 2, 37, 8, 43
  };
  const int q9230[] = {
    9, 9, // Number of jobs and machines
    1, 74, 8, 39, 4, 42, 6, 81, 3, 50, 2, 55, 7, 86, 0, 51, 5, 86, 
    1, 41, 7, 54, 0,  1, 3, 52, 2, 78, 6, 53, 4,  4, 8, 52, 5, 72, 
    5, 91, 1, 96, 8, 56, 4, 78, 7, 86, 6, 68, 3, 38, 0, 74, 2, 14, 
    6, 75, 3, 37, 5, 38, 8, 72, 4, 27, 2, 75, 0, 74, 1,  9, 7, 77, 
    6, 52, 0, 63, 5, 92, 7,  4, 3, 67, 8, 64, 1, 24, 4, 78, 2, 11, 
    1, 89, 4, 38, 0, 60, 3, 49, 2, 96, 5, 41, 7, 99, 8, 46, 6, 50, 
    3,  6, 5, 36, 2,  3, 4, 15, 8, 94, 1, 70, 6, 38, 7, 53, 0, 26, 
    5, 27, 1,  8, 6, 28, 2, 23, 7, 55, 3, 84, 0, 57, 4, 44, 8, 79, 
    5, 90, 1, 36, 8, 80, 7, 33, 2, 20, 3, 57, 0, 62, 6, 56, 4, 17
  };
  const int q9231[] = {
    9, 9, // Number of jobs and machines
    0, 17, 3, 98, 7, 54, 5, 20, 8, 14, 6, 14, 1, 20, 2, 21, 4, 47, 
    8,  3, 7, 17, 0, 15, 2, 85, 4, 92, 3, 77, 5, 40, 6, 55, 1, 67, 
    3, 80, 6, 99, 1, 54, 2, 23, 7, 17, 4, 52, 0, 71, 8, 26, 5, 11, 
    4,  9, 1, 32, 3, 90, 0, 29, 2, 22, 5,  5, 7, 53, 8, 49, 6, 64, 
    6, 29, 7, 95, 5, 33, 8, 73, 2, 25, 3, 22, 4, 62, 1, 38, 0, 14, 
    7, 28, 3, 56, 4, 67, 0, 88, 2,  6, 6, 28, 1, 82, 5, 54, 8, 95, 
    5,  6, 4, 60, 0, 84, 8, 46, 7, 58, 1, 94, 2, 93, 3, 69, 6, 79, 
    7, 73, 2, 96, 5, 80, 8, 51, 1, 96, 4, 65, 6, 36, 3, 76, 0, 12, 
    1, 44, 8, 20, 0, 42, 2, 15, 6,  2, 4,  4, 3, 29, 5, 60, 7, 11
  };
  const int q9232[] = {
    9, 9, // Number of jobs and machines
    6, 90, 2, 17, 0, 10, 5, 80, 3, 54, 8, 91, 4, 12, 1, 97, 7, 76, 
    3, 63, 7, 75, 1, 56, 2, 99, 6,  4, 0, 87, 5, 83, 4, 33, 8, 29, 
    1, 19, 5, 94, 8, 74, 0, 76, 3,  4, 2, 47, 6, 67, 7, 29, 4, 49, 
    8, 99, 2, 36, 0, 65, 5, 48, 4, 66, 7, 17, 1,  4, 3, 11, 6, 38, 
    7, 99, 1, 58, 6, 75, 0,  6, 4, 18, 5, 27, 8, 63, 3, 11, 2, 11, 
    0, 83, 7, 18, 8, 27, 4, 84, 1, 25, 5, 82, 6, 16, 2, 23, 3, 21, 
    2, 96, 5, 44, 8,  6, 0, 27, 6, 89, 4, 30, 7, 45, 1, 42, 3, 61, 
    3, 79, 2, 97, 7, 57, 8, 77, 4, 37, 6, 40, 0, 71, 1, 14, 5, 59, 
    2, 32, 3, 93, 6, 84, 7, 51, 8, 18, 0, 11, 5, 92, 1, 26, 4, 12
  };
  const int q9233[] = {
    9, 9, // Number of jobs and machines
    8, 24, 7, 25, 0, 70, 5, 81, 6, 81, 1, 64, 4, 61, 2, 53, 3, 28, 
    7, 44, 4, 27, 3,  9, 8, 71, 5, 49, 6, 26, 0,  8, 2, 57, 1, 32, 
    4, 73, 8, 53, 0,  1, 1, 44, 6, 53, 5, 41, 2, 57, 7, 90, 3, 13, 
    8,  3, 4, 81, 0, 94, 5, 26, 1, 65, 3, 96, 2, 54, 6,  5, 7, 70, 
    0, 58, 7, 36, 1, 36, 8,  2, 4, 52, 5, 81, 3, 64, 2, 29, 6, 65, 
    1, 61, 5, 73, 8, 11, 3, 23, 7, 99, 0, 42, 2, 85, 6, 43, 4, 26, 
    5, 88, 6, 48, 3, 36, 8, 70, 2, 85, 4, 71, 7, 83, 1, 17, 0, 37, 
    5, 67, 7, 45, 0, 15, 3, 72, 6, 90, 8, 48, 2, 33, 1, 64, 4, 71, 
    0, 83, 5, 90, 2, 38, 7, 41, 4,  7, 1, 41, 3, 12, 6, 34, 8, 19
  };
  const int q9234[] = {
    9, 9, // Number of jobs and machines
    6, 18, 0, 12, 8, 10, 7, 83, 1, 92, 4,  5, 5, 82, 3, 30, 2, 96, 
    0, 87, 3, 35, 7, 48, 4, 26, 5, 87, 8, 48, 6, 15, 1, 19, 2, 58, 
    0, 38, 5, 48, 2, 90, 7, 23, 8, 98, 1, 67, 4, 19, 3, 90, 6,  4, 
    1, 54, 2, 38, 5, 66, 6, 11, 3, 45, 0, 50, 4, 71, 7, 14, 8, 60, 
    4, 15, 5,  3, 2, 80, 6,  8, 1, 41, 7,  2, 0, 15, 8, 31, 3, 61, 
    2, 18, 6, 20, 4,  7, 7, 82, 0, 89, 1,  1, 5,  7, 8, 66, 3, 43, 
    3, 70, 7, 47, 2, 46, 1, 93, 6, 65, 8, 80, 0, 18, 5, 96, 4, 48, 
    1, 36, 5, 37, 2, 84, 4,  3, 6, 13, 7, 27, 3, 13, 8, 26, 0, 84, 
    6, 18, 4, 18, 7, 32, 1, 68, 2, 22, 5, 82, 0, 45, 3, 53, 8, 36
  };
  const int q9235[] = {
    9, 9, // Number of jobs and machines
    6, 17, 5, 67, 2, 16, 4, 24, 3, 51, 7, 91, 1, 67, 0, 39, 8, 76, 
    1, 81, 6, 33, 8, 81, 0, 98, 5, 65, 4, 52, 7, 70, 2,  3, 3, 81, 
    8, 58, 5, 76, 2, 12, 6, 55, 1, 30, 3, 76, 0, 48, 7, 61, 4,  3, 
    1,  4, 0, 64, 5, 52, 2, 57, 7, 32, 8,  7, 3, 44, 4, 97, 6, 28, 
    1, 63, 4, 59, 3, 78, 0, 45, 5, 74, 2, 96, 6, 48, 7, 25, 8, 93, 
    2, 23, 7,  5, 0, 31, 4, 10, 1, 35, 3, 47, 5, 81, 8, 82, 6, 42, 
    1, 97, 0, 40, 2, 69, 4, 60, 8, 81, 6, 88, 5, 23, 7, 41, 3, 43, 
    0, 42, 5, 68, 2, 16, 8, 89, 1, 44, 7, 73, 3, 19, 4, 82, 6, 31, 
    3, 78, 6, 86, 7,  8, 5, 96, 4, 34, 2, 63, 8, 24, 0, 93, 1, 79
  };
  const int q9236[] = {
    9, 9, // Number of jobs and machines
    3, 94, 8, 45, 5,  8, 6, 15, 7, 19, 4,  9, 0, 75, 1, 64, 2, 62, 
    7, 41, 1, 64, 4,  3, 6, 56, 5, 24, 3, 34, 2, 22, 8, 83, 0,  7, 
    1, 27, 5, 34, 2, 90, 7, 43, 3, 18, 0, 70, 8, 76, 6, 49, 4, 36, 
    6, 58, 2, 75, 7, 68, 5, 73, 0, 84, 4, 86, 8, 98, 3, 26, 1, 61, 
    4, 23, 1, 73, 2, 50, 7, 50, 0,  1, 8, 47, 3, 65, 5, 10, 6, 12, 
    6, 82, 5, 25, 7,  2, 4, 77, 3, 96, 0, 83, 8, 56, 2, 12, 1, 16, 
    8, 76, 2, 12, 5, 78, 4,  2, 6, 38, 1, 25, 0, 15, 7, 70, 3, 68, 
    6, 32, 5, 52, 7,  4, 4, 41, 0, 79, 2, 69, 8, 38, 3, 13, 1, 51, 
    8, 44, 5, 46, 0,  3, 7, 45, 2, 60, 3, 77, 6, 69, 4, 90, 1, 73
  };
  const int q9237[] = {
    9, 9, // Number of jobs and machines
    5, 41, 0, 66, 8, 77, 2, 18, 4, 27, 3, 44, 6,  3, 1, 93, 7, 30, 
    3, 81, 1, 31, 8,  8, 5, 26, 7, 27, 6, 19, 2, 97, 0, 54, 4,  7, 
    5, 19, 2, 63, 7, 47, 8, 86, 3, 22, 1, 34, 0, 50, 6,  4, 4, 26, 
    1, 77, 4,  4, 0, 23, 8,  7, 6, 70, 7, 79, 5, 92, 2, 71, 3, 72, 
    4, 71, 6, 86, 5, 17, 8,  6, 7, 13, 2, 26, 3, 82, 1, 76, 0, 71, 
    3, 73, 0, 23, 1, 63, 5, 32, 6, 42, 4,  9, 2, 19, 7, 81, 8, 81, 
    4, 87, 5, 59, 8, 85, 6, 68, 2, 33, 3, 40, 1, 59, 0, 52, 7, 58, 
    8, 26, 7, 32, 4,  6, 5, 43, 2, 69, 0, 48, 1, 35, 6,  6, 3, 59, 
    5, 27, 8, 26, 0, 48, 4, 89, 2, 30, 1,  5, 3,  5, 7, 57, 6, 32
  };
  const int q9238[] = {
    9, 9, // Number of jobs and machines
    6, 48, 3, 91, 2, 24, 4, 67, 1, 75, 7, 67, 5, 96, 0, 77, 8, 87, 
    0, 92, 1, 52, 2, 55, 6, 64, 5,  2, 8, 96, 3, 37, 7, 94, 4,  6, 
    3,  9, 5, 84, 2, 75, 4, 54, 6, 64, 7, 38, 8, 14, 1, 13, 0, 43, 
    8, 27, 2, 93, 0, 70, 3,  5, 1, 36, 6, 26, 5, 56, 4, 60, 7, 91, 
    6,  1, 4, 34, 0, 58, 3, 10, 2, 77, 7, 51, 5, 92, 1, 70, 8, 78, 
    0, 63, 1, 16, 7, 51, 3,  7, 2, 20, 8, 87, 4, 33, 5, 30, 6, 44, 
    7, 92, 6, 69, 2, 49, 1, 80, 0, 79, 5, 16, 3, 75, 4, 59, 8, 18, 
    7, 11, 4, 18, 1, 15, 5, 73, 6, 75, 0, 65, 2, 46, 3, 10, 8, 21, 
    8, 42, 5, 56, 2, 88, 7, 16, 0,  9, 6, 44, 3, 41, 1, 13, 4, 76
  };
  const int q9239[] = {
    9, 9, // Number of jobs and machines
    4, 55, 8, 33, 2,  9, 1, 18, 6, 85, 3, 25, 5, 78, 0, 80, 7, 99, 
    8, 13, 6, 19, 0, 24, 2, 73, 4, 56, 1, 80, 7, 73, 3, 32, 5, 91, 
    5, 90, 8, 49, 4, 36, 0, 68, 3, 80, 7, 49, 6, 96, 2, 54, 1, 87, 
    0, 88, 8, 98, 3, 70, 1, 55, 6, 49, 2, 95, 4, 58, 7, 99, 5, 77, 
    8, 74, 7, 69, 5, 29, 1,  3, 4, 77, 3, 39, 0, 90, 6, 69, 2, 99, 
    5, 57, 0,  4, 2, 56, 4, 96, 8, 28, 1, 81, 7, 36, 3, 50, 6, 92, 
    5, 38, 0, 15, 6, 68, 7, 51, 2, 70, 4, 53, 3, 75, 1, 18, 8, 76, 
    7, 22, 3, 31, 1,  1, 0,  3, 4, 90, 5, 97, 6, 14, 8, 55, 2, 17, 
    5, 42, 3, 48, 8,  8, 1, 38, 6, 98, 0, 34, 7, 43, 2,  2, 4, 20
  };
  const int q9240[] = {
    9, 9, // Number of jobs and machines
    0, 92, 4, 16, 2, 11, 3, 71, 8, 95, 7, 23, 6, 63, 1, 56, 5, 77, 
    8, 70, 6, 47, 1, 58, 2, 96, 4, 96, 0, 98, 5, 15, 3, 42, 7, 21, 
    6, 32, 0, 67, 1, 25, 4,  1, 5, 84, 8, 43, 7, 54, 2, 24, 3, 77, 
    5, 79, 4, 21, 0, 98, 1, 87, 8, 79, 2, 82, 7, 63, 6, 55, 3,  1, 
    2, 22, 8, 41, 3, 94, 5, 33, 6, 41, 1, 34, 0, 98, 4, 16, 7, 79, 
    6, 16, 7, 50, 2, 37, 3, 89, 5,  6, 0,  1, 4, 80, 8, 69, 1, 53, 
    1, 57, 7, 57, 0, 22, 2,  1, 8, 26, 3,  7, 4,  4, 6, 25, 5, 43, 
    0, 76, 5, 35, 6,  5, 8, 86, 3, 81, 7, 33, 1, 18, 2,  4, 4, 75, 
    4, 14, 8, 20, 6, 37, 7, 28, 3, 92, 5, 44, 1, 51, 2,  1, 0, 46
  };
  const int q9241[] = {
    9, 9, // Number of jobs and machines
    0, 61, 6, 50, 1, 28, 7, 23, 2, 39, 3, 68, 5, 30, 8, 74, 4, 57, 
    8, 76, 1, 92, 2,  8, 7, 39, 0,  4, 3, 15, 4, 17, 5, 48, 6, 80, 
    3, 96, 7, 92, 6, 41, 0, 83, 1, 29, 2, 11, 4, 61, 5, 20, 8, 44, 
    4, 68, 3, 49, 7, 87, 2, 67, 1, 84, 5, 52, 8, 91, 6, 52, 0, 87, 
    8, 95, 7, 58, 2, 48, 5, 24, 0, 13, 3, 83, 6, 29, 1, 51, 4, 10, 
    5, 30, 6, 31, 3,  6, 8, 31, 1, 15, 0, 89, 4, 22, 2, 10, 7, 44, 
    2, 89, 7, 68, 8, 58, 3, 81, 1, 96, 0, 20, 4, 40, 6, 33, 5, 32, 
    7,  5, 6, 35, 0, 80, 2, 76, 1, 51, 5, 86, 8, 21, 3, 72, 4, 49, 
    3, 60, 1, 16, 2, 94, 4,  6, 7, 57, 8, 76, 6, 65, 5, 41, 0, 62
  };
  const int q9242[] = {
    9, 9, // Number of jobs and machines
    0, 90, 4, 38, 5, 81, 2, 22, 8, 28, 7, 33, 3, 59, 1,  2, 6, 32, 
    8, 75, 2, 17, 6, 47, 3, 14, 4, 88, 1, 22, 5, 48, 7, 38, 0, 95, 
    7, 58, 6, 16, 8, 62, 5, 79, 4, 13, 2, 99, 0, 56, 3, 41, 1, 37, 
    3, 77, 0, 47, 6, 19, 5,  7, 1, 31, 7, 72, 4, 46, 8, 76, 2, 63, 
    7, 48, 8, 88, 2,  3, 3,  6, 4, 40, 0, 81, 6, 19, 5, 50, 1, 67, 
    2, 77, 5, 65, 1,  5, 7, 88, 4,  5, 3, 81, 8, 93, 6, 16, 0, 56, 
    8, 55, 3, 84, 5, 45, 0, 74, 2, 42, 1, 77, 7, 22, 6,  4, 4, 15, 
    1,  7, 4, 27, 6, 39, 3, 75, 0, 25, 8, 80, 7, 79, 2, 59, 5, 15, 
    4, 55, 3, 64, 5, 18, 1, 98, 0,  7, 7, 30, 8, 67, 2, 82, 6, 58
  };
  const int q9243[] = {
    9, 9, // Number of jobs and machines
    3, 57, 1, 38, 4, 39, 5, 80, 8, 58, 0, 73, 2, 55, 6, 28, 7,  8, 
    0, 72, 2, 28, 3, 96, 1, 49, 7, 17, 5, 68, 4, 40, 8, 57, 6, 35, 
    2, 26, 1, 49, 8, 76, 4, 84, 0, 50, 5, 54, 3, 26, 7, 94, 6, 38, 
    3, 76, 8, 19, 6, 98, 7, 59, 0, 48, 2, 92, 5, 46, 1, 59, 4,  4, 
    4, 40, 8, 68, 7,  6, 0, 67, 5,  1, 1, 56, 3, 12, 2, 37, 6, 36, 
    8, 19, 4, 13, 3, 86, 7, 98, 5, 65, 2, 87, 6, 49, 1, 69, 0, 52, 
    7, 36, 0, 84, 3,  7, 6, 31, 2, 37, 4, 79, 8, 83, 1, 84, 5, 78, 
    7, 52, 2, 80, 3, 86, 1, 91, 6, 26, 4, 42, 5, 96, 8, 81, 0, 92, 
    1, 28, 0, 78, 3, 89, 8, 80, 7, 94, 2, 93, 6, 78, 4, 57, 5, 34
  };
  const int q9244[] = {
    9, 9, // Number of jobs and machines
    4, 34, 2, 25, 3, 36, 1, 58, 6, 82, 8, 49, 0, 41, 5, 22, 7,  2, 
    1, 73, 3, 42, 2, 32, 6, 95, 8, 25, 7, 65, 0, 40, 4, 63, 5,  9, 
    6, 89, 0, 62, 2, 80, 1, 94, 3, 16, 5, 21, 4, 97, 7, 30, 8, 85, 
    2, 34, 4,  3, 0,  3, 7, 48, 6, 93, 1,  9, 8, 62, 5, 50, 3, 86, 
    1, 31, 4, 30, 0, 85, 6, 12, 7, 54, 5, 98, 8, 84, 2, 33, 3, 50, 
    5, 91, 4, 69, 6, 77, 8, 57, 1,  2, 0, 17, 3, 58, 2, 77, 7, 57, 
    7, 37, 5,  3, 4, 24, 0, 11, 1, 25, 8, 19, 6, 23, 3, 58, 2, 41, 
    7,  8, 6,  6, 1,  5, 8,  5, 2, 73, 5, 19, 0, 73, 3, 43, 4, 78, 
    6, 56, 4,  9, 3, 65, 1, 39, 0,  4, 5, 29, 8, 43, 7, 90, 2, 92
  };
  const int q9245[] = {
    9, 9, // Number of jobs and machines
    2, 72, 8, 11, 7, 74, 1, 46, 6, 34, 5,  5, 4, 80, 3, 70, 0, 64, 
    0, 34, 8, 45, 2, 97, 4, 29, 5, 36, 3, 73, 7, 31, 6, 52, 1, 21, 
    4, 36, 2, 91, 8,  7, 1, 67, 6, 93, 7, 45, 3, 53, 0, 19, 5, 43, 
    4, 63, 2, 91, 6, 21, 0, 34, 8,  7, 3, 18, 5, 30, 1, 79, 7, 88, 
    7,  5, 5, 62, 8,  4, 6, 66, 1, 54, 4, 24, 3, 24, 0,  2, 2, 65, 
    3, 23, 7, 12, 4, 78, 0, 46, 5, 86, 2, 58, 6, 56, 1, 85, 8, 28, 
    0, 16, 7, 56, 3, 95, 1, 92, 8, 50, 6, 21, 4, 20, 2, 24, 5, 67, 
    8, 96, 4, 49, 3, 93, 0,  5, 2, 35, 1, 76, 5, 36, 7, 10, 6,  7, 
    7, 48, 3, 93, 6, 81, 5, 75, 4, 19, 1, 77, 2, 63, 0, 20, 8, 96
  };
  const int q9246[] = {
    9, 9, // Number of jobs and machines
    3, 62, 0, 48, 7, 19, 5, 73, 4, 18, 8, 76, 6, 87, 2, 16, 1, 58, 
    0, 60, 1, 64, 5, 22, 4, 89, 3,  2, 6, 96, 7, 96, 8, 25, 2, 34, 
    1,  3, 5, 44, 4, 19, 7, 95, 0, 24, 3, 62, 2, 37, 8, 57, 6, 49, 
    1, 31, 0, 35, 2, 69, 6, 84, 4, 79, 7,  8, 3, 17, 5, 30, 8, 46, 
    5, 32, 6, 59, 8, 94, 3, 16, 4, 36, 1, 72, 2, 78, 7, 28, 0, 78, 
    1, 69, 7, 62, 8, 57, 0, 75, 5, 69, 4, 48, 3, 20, 2, 98, 6, 96, 
    2, 97, 3, 62, 7, 18, 4, 24, 6, 69, 5, 81, 8,  8, 0, 72, 1, 84, 
    4, 94, 5, 59, 2, 71, 6, 19, 8,  9, 1,  1, 0, 60, 3, 27, 7, 41, 
    1, 91, 8, 72, 0, 75, 4, 20, 6, 73, 2, 92, 5, 94, 3, 86, 7, 66
  };
  const int q9247[] = {
    9, 9, // Number of jobs and machines
    4, 92, 7, 93, 8, 13, 5,  4, 0, 24, 3, 62, 1, 42, 6, 27, 2, 34, 
    4, 80, 8, 61, 0, 49, 6, 59, 5, 34, 2, 83, 7, 19, 1, 45, 3, 58, 
    0, 95, 6, 82, 4, 66, 1, 13, 7, 55, 5,  7, 2, 34, 8, 52, 3, 72, 
    0,  1, 1, 99, 3, 30, 4, 24, 6, 96, 2, 97, 8, 67, 5, 43, 7, 58, 
    8, 76, 7, 21, 0, 87, 3, 87, 1, 98, 2, 44, 5, 56, 4, 52, 6, 42, 
    6, 80, 8, 49, 1, 18, 2, 13, 4, 66, 0, 48, 7, 37, 5, 44, 3, 10, 
    7, 89, 1, 73, 8, 93, 5, 52, 4, 22, 6, 42, 2, 82, 3, 86, 0, 52, 
    4, 99, 6, 89, 1, 96, 7, 65, 3, 22, 2, 58, 5, 77, 0, 53, 8, 70, 
    2,  8, 3, 12, 5, 62, 0, 60, 6, 73, 7, 25, 8, 44, 1,  5, 4, 21
  };
  const int q9248[] = {
    9, 9, // Number of jobs and machines
    7, 14, 2, 48, 8, 36, 6, 68, 0, 93, 5, 86, 4, 36, 3, 21, 1, 51, 
    8, 51, 6, 62, 2, 83, 7, 91, 1, 52, 0, 81, 3, 21, 4, 97, 5, 67, 
    2, 26, 4, 79, 7, 53, 5, 43, 0, 32, 6, 33, 1,  7, 3, 47, 8, 94, 
    2, 85, 8, 72, 1, 44, 3, 24, 7, 73, 5, 85, 4, 56, 0, 70, 6, 91, 
    5, 38, 0, 87, 2, 97, 1, 85, 6,  7, 7, 62, 4, 53, 3, 81, 8, 59, 
    1, 53, 4, 79, 0, 90, 2, 40, 5, 21, 7, 97, 3,  9, 6, 46, 8, 13, 
    2, 22, 8, 17, 4, 41, 3, 69, 1, 55, 0, 73, 6, 46, 5, 55, 7, 51, 
    1, 46, 7, 70, 8, 42, 0, 63, 6, 12, 5, 69, 2, 76, 3,  1, 4, 81, 
    8, 92, 0, 86, 6, 82, 3, 47, 2, 90, 4, 76, 1, 81, 7, 35, 5, 54
  };
  const int q9249[] = {
    9, 9, // Number of jobs and machines
    0, 93, 6, 82, 8, 65, 7,  1, 3, 93, 2, 16, 5, 38, 1, 26, 4, 63, 
    0, 91, 7, 52, 8, 42, 3, 99, 4, 59, 1, 18, 2, 86, 5, 87, 6, 58, 
    5, 14, 6, 26, 4, 56, 3, 94, 8, 23, 1, 41, 0, 10, 7,  3, 2, 46, 
    6,  8, 3,  5, 7, 31, 8, 78, 1,  2, 5,  8, 4, 26, 2, 88, 0, 20, 
    1, 75, 4, 97, 0, 49, 8, 35, 2, 46, 5, 34, 6, 29, 7, 25, 3, 35, 
    1, 50, 3, 34, 4, 43, 5, 85, 6, 92, 2, 86, 7,  2, 0, 80, 8, 80, 
    4, 77, 6, 85, 3, 28, 8, 53, 2, 47, 7, 66, 5, 79, 1, 75, 0, 82, 
    1,  1, 7, 86, 0, 46, 3, 12, 5, 54, 8,  7, 6,  4, 2, 52, 4, 72, 
    2,  7, 0, 39, 5, 73, 3, 36, 1, 78, 4, 25, 7,  2, 8, 80, 6, 42
  };
  const int q9250[] = {
    9, 9, // Number of jobs and machines
    5, 49, 0,  6, 7, 30, 3, 36, 6, 93, 1, 33, 2, 92, 8, 31, 4,  3, 
    7, 42, 1, 16, 8, 42, 3, 95, 5, 14, 2, 15, 0, 89, 6, 16, 4, 44, 
    1, 71, 8, 95, 5, 48, 6, 13, 3, 92, 7, 50, 0, 48, 2, 82, 4, 75, 
    2,  3, 1, 52, 8, 44, 4, 68, 0,  5, 3, 83, 5, 10, 6, 74, 7, 28, 
    5, 94, 0, 27, 8, 33, 2, 66, 6, 48, 4, 10, 7, 27, 1, 93, 3, 26, 
    1, 96, 8, 23, 2, 74, 5, 92, 0, 29, 3, 71, 4, 64, 6, 34, 7, 78, 
    5, 64, 0, 11, 4, 86, 7, 43, 3, 13, 8,  3, 6, 30, 2,  3, 1, 52, 
    6, 47, 7, 63, 3, 11, 4,  3, 0, 59, 2, 38, 1, 82, 8, 28, 5, 77, 
    4, 35, 2, 40, 5, 90, 6, 11, 3, 16, 8, 18, 1, 38, 7, 85, 0, 37
  };
  const int q9251[] = {
    9, 9, // Number of jobs and machines
    3, 86, 4, 44, 2, 12, 8, 26, 0, 22, 7,  1, 5, 70, 1, 85, 6,  7, 
    0, 96, 3,  5, 7, 66, 6, 28, 5, 89, 4, 12, 1, 86, 8, 98, 2, 97, 
    6, 65, 7, 18, 4, 73, 8, 41, 1, 85, 0, 61, 2, 76, 3, 23, 5, 40, 
    6, 30, 8,  4, 7, 27, 1,  5, 5,  6, 0, 19, 3, 86, 4, 93, 2, 68, 
    8, 75, 5, 66, 1, 46, 3, 59, 7, 30, 6, 44, 4, 45, 2, 26, 0, 47, 
    1, 58, 0, 98, 7, 41, 3, 39, 2, 76, 6, 20, 4, 66, 5, 69, 8, 38, 
    0, 45, 8, 77, 4,  6, 6, 53, 7, 46, 1, 95, 3, 71, 2, 89, 5, 96, 
    0,  9, 7, 14, 6, 51, 8, 88, 2, 80, 5, 40, 3,  9, 1, 20, 4, 86, 
    4, 71, 5, 74, 3, 57, 8, 73, 0, 90, 6, 20, 1, 38, 2, 22, 7, 20
  };
  const int q9252[] = {
    9, 9, // Number of jobs and machines
    6, 33, 3, 52, 5, 64, 2, 96, 7, 54, 8, 95, 0,  9, 4,  2, 1, 14, 
    5, 37, 7, 22, 1, 54, 8, 64, 2, 29, 0,  4, 3, 44, 6, 49, 4,  9, 
    5, 59, 2, 92, 0, 26, 8, 81, 1, 65, 3, 22, 7, 85, 6, 32, 4, 82, 
    4, 65, 3,  1, 2, 22, 5, 69, 0, 52, 1, 78, 8, 58, 7, 40, 6, 77, 
    0, 77, 6, 20, 4, 77, 3, 49, 5, 55, 7, 14, 1, 39, 8, 98, 2, 27, 
    7, 91, 3, 71, 2,  7, 5, 55, 6, 32, 4, 38, 1, 15, 0, 56, 8, 22, 
    1, 31, 0, 70, 2, 67, 8, 97, 6, 42, 3, 70, 4, 23, 7, 37, 5, 94, 
    2, 14, 4, 73, 6, 24, 3, 89, 8, 86, 5, 55, 7, 19, 0, 45, 1, 41, 
    5,  5, 7, 89, 2,  4, 0, 56, 8, 98, 3, 43, 1, 76, 4, 58, 6, 46
  };
  const int q9253[] = {
    9, 9, // Number of jobs and machines
    2, 21, 4, 44, 1, 38, 6, 21, 3, 81, 8, 90, 7, 71, 0, 39, 5, 89, 
    5, 12, 6, 63, 7, 78, 8, 14, 2, 70, 0, 89, 1, 62, 3, 34, 4, 50, 
    4, 81, 1, 88, 2, 31, 0, 34, 6,  9, 3, 77, 8, 10, 7, 38, 5, 13, 
    0,  2, 5, 11, 7, 78, 3, 97, 2, 60, 1, 79, 8, 89, 6, 73, 4, 90, 
    8,  5, 3, 69, 4, 31, 6, 53, 7, 22, 1, 11, 2, 31, 5, 41, 0, 91, 
    7, 11, 5,  4, 3, 34, 0, 81, 2, 88, 8,  5, 4, 39, 1, 81, 6, 79, 
    5,  7, 4, 99, 6, 32, 3,  8, 7,  3, 0, 74, 2, 52, 1, 45, 8, 52, 
    2, 85, 4, 73, 5,  3, 1, 79, 7, 10, 6, 45, 8, 54, 3, 78, 0, 99, 
    1, 56, 5, 99, 2, 77, 8, 95, 0,  2, 4, 63, 3, 39, 6, 19, 7, 95
  };
  const int q9254[] = {
    9, 9, // Number of jobs and machines
    1,  8, 5, 56, 4, 56, 0, 80, 2, 89, 6, 41, 8, 19, 7, 47, 3, 64, 
    5,  7, 8, 66, 1,  5, 4, 24, 6, 26, 3, 48, 0, 22, 7, 66, 2, 88, 
    6,  5, 8, 66, 7, 98, 5, 20, 2, 47, 4, 21, 3, 60, 0, 54, 1, 77, 
    0, 58, 6, 77, 1, 19, 5, 61, 8, 34, 3, 69, 7, 73, 2, 45, 4, 57, 
    1, 80, 5, 29, 7, 90, 3, 92, 6, 92, 2, 42, 0, 73, 8,  7, 4, 45, 
    3, 82, 7, 40, 2, 62, 1, 61, 4, 72, 5, 72, 8, 81, 6, 63, 0,  2, 
    4, 71, 6, 26, 8, 25, 7, 90, 2, 67, 1, 14, 5, 59, 0, 87, 3, 43, 
    6, 48, 7,  3, 0, 61, 2, 69, 3, 42, 1, 18, 5, 35, 4, 24, 8, 37, 
    0, 46, 6, 17, 8, 96, 2, 35, 7, 19, 3, 28, 5, 44, 4, 43, 1, 80
  };
  const int q9255[] = {
    9, 9, // Number of jobs and machines
    3, 80, 6, 77, 7, 40, 4, 55, 5, 27, 2, 91, 8, 84, 0, 43, 1, 85, 
    1, 56, 5, 44, 7, 52, 0, 82, 2, 38, 4, 92, 3, 45, 8, 45, 6, 91, 
    3, 13, 7, 36, 2, 72, 5, 54, 4, 51, 1, 81, 6, 57, 8, 29, 0, 27, 
    2, 54, 4, 13, 7, 54, 1, 58, 6, 64, 0, 38, 3, 25, 5, 74, 8, 96, 
    2, 71, 5, 43, 4, 43, 3, 66, 6, 22, 1,  3, 8, 40, 0, 46, 7, 15, 
    8, 59, 1,  3, 3, 13, 2, 54, 0, 86, 7, 72, 6, 53, 5, 44, 4, 66, 
    1, 86, 4, 20, 8, 95, 0, 21, 2, 98, 7, 43, 5, 52, 3, 15, 6, 48, 
    6, 51, 1,  8, 2,  6, 7, 91, 8, 10, 3,  6, 4, 77, 5, 81, 0, 31, 
    4, 97, 3, 97, 6, 40, 1, 67, 5, 11, 0, 77, 2, 97, 7, 67, 8, 50
  };
  const int q9256[] = {
    9, 9, // Number of jobs and machines
    8, 61, 7,  7, 3, 51, 6,  8, 4, 18, 0, 21, 5, 63, 1, 58, 2,  2, 
    2, 14, 5, 93, 4, 82, 7, 93, 3, 68, 0, 10, 6, 35, 1, 68, 8, 10, 
    4, 13, 7, 90, 0, 94, 3,  5, 5, 13, 8, 60, 6, 33, 1, 82, 2, 46, 
    0, 21, 7, 89, 8, 58, 6, 85, 3, 71, 2, 45, 1, 54, 4, 64, 5, 69, 
    0, 15, 6, 17, 2, 34, 1, 85, 4, 34, 8, 95, 7, 36, 3, 56, 5, 31, 
    3, 21, 2, 24, 4, 50, 6, 43, 5, 84, 1, 77, 0, 16, 7, 47, 8,  2, 
    1, 71, 7, 70, 4, 50, 8, 86, 2, 83, 5, 78, 0, 44, 3, 74, 6, 29, 
    1, 60, 5, 83, 8, 36, 4, 79, 2, 66, 6, 16, 3, 50, 0, 31, 7, 72, 
    7, 67, 8, 25, 1, 15, 2, 13, 5, 47, 4, 72, 6, 32, 0, 83, 3, 93
  };
  const int q9257[] = {
    9, 9, // Number of jobs and machines
    7, 20, 5, 78, 8, 41, 4, 48, 1, 10, 6, 71, 2,  3, 3, 79, 0, 98, 
    2, 93, 8, 44, 7,  2, 3, 37, 6, 34, 1, 86, 5, 21, 0, 76, 4, 47, 
    2, 39, 6, 77, 0, 81, 1, 79, 7,  7, 5, 75, 8, 90, 4, 29, 3, 72, 
    5, 46, 7, 31, 4, 32, 0, 39, 2, 32, 8, 56, 3, 26, 6, 68, 1, 57, 
    3, 60, 8, 20, 1, 92, 2, 58, 6, 63, 0, 59, 4, 76, 5, 76, 7, 15, 
    5, 67, 8, 22, 6, 59, 2, 16, 0, 11, 4, 97, 7, 13, 3, 35, 1, 17, 
    6, 30, 8, 96, 1, 24, 7, 29, 2, 51, 5, 49, 4, 77, 3, 37, 0, 94, 
    2, 29, 5, 45, 0, 34, 8, 67, 6, 42, 7, 22, 4, 87, 3,  6, 1, 78, 
    5, 19, 1, 26, 6, 88, 7, 49, 3, 67, 4, 43, 0, 13, 8, 25, 2, 89
  };
  const int q9258[] = {
    9, 9, // Number of jobs and machines
    0, 71, 1, 76, 2, 84, 4,  3, 5,  1, 6, 66, 3,  7, 8, 84, 7, 21, 
    6, 28, 4, 18, 7,  2, 5, 26, 1, 13, 8, 70, 3, 33, 2, 49, 0, 12, 
    1, 60, 4, 38, 5, 35, 7, 24, 8, 98, 3,  2, 2, 49, 0, 46, 6, 47, 
    5, 99, 3, 32, 7, 93, 2, 87, 4, 35, 0, 54, 8, 48, 6, 67, 1, 60, 
    2, 87, 3, 57, 0, 26, 5, 20, 1, 15, 8, 66, 4, 27, 7, 51, 6, 86, 
    3, 79, 2, 35, 7, 94, 6, 38, 0, 58, 4, 18, 8, 56, 5, 55, 1, 39, 
    8, 39, 6, 44, 1,  6, 3, 80, 2, 12, 0, 65, 4, 89, 7, 82, 5, 41, 
    0, 42, 5, 80, 4, 11, 2, 20, 8,  3, 6, 63, 7, 23, 1, 27, 3, 99, 
    4, 55, 2, 10, 7, 45, 3, 43, 1,  8, 0,  3, 6, 66, 5, 21, 8, 13
  };
  const int q9259[] = {
    9, 9, // Number of jobs and machines
    8, 68, 7, 57, 6, 52, 2, 63, 3, 10, 0, 13, 5, 87, 1, 24, 4, 65, 
    7, 74, 5, 43, 6, 57, 8, 58, 2, 58, 4, 26, 3, 88, 1, 23, 0, 73, 
    5, 70, 8, 44, 7, 78, 1, 50, 3, 58, 6, 21, 0, 25, 2, 29, 4,  8, 
    3, 17, 6, 32, 0, 38, 1, 87, 4, 58, 8, 27, 7, 35, 5, 78, 2, 43, 
    1, 31, 5,  8, 7, 16, 0,  7, 6,  6, 3, 70, 4, 74, 8, 20, 2, 64, 
    0, 92, 8, 65, 1, 25, 3, 53, 5, 66, 6, 83, 2, 85, 7, 92, 4,  7, 
    3, 52, 1, 18, 2, 19, 8, 41, 6, 88, 4, 44, 7, 35, 0,  7, 5, 42, 
    8, 98, 5,  7, 0,  5, 4, 69, 1, 52, 3, 48, 6, 39, 7, 18, 2, 99, 
    4, 66, 5, 67, 0, 65, 7, 27, 6,  9, 2, 29, 8, 20, 1, 96, 3, 87
  };
  const int q9260[] = {
    9, 9, // Number of jobs and machines
    3, 20, 5, 73, 0, 92, 1, 38, 6, 80, 7, 58, 4, 92, 2, 33, 8, 51, 
    8, 83, 2, 29, 5, 28, 1, 39, 7, 38, 4, 85, 6, 27, 3, 76, 0, 82, 
    8, 13, 0,  5, 3, 24, 4, 56, 5, 87, 7, 18, 6, 34, 1, 38, 2, 13, 
    1, 71, 4, 11, 5, 35, 7, 47, 6, 26, 3, 90, 0, 79, 8, 71, 2, 70, 
    1, 10, 3, 73, 7, 97, 8, 39, 0, 30, 6, 18, 2,  6, 5,  1, 4, 82, 
    3, 64, 6, 18, 4,  8, 5, 25, 0, 72, 7, 40, 8, 35, 1, 98, 2, 52, 
    7, 61, 1, 23, 2, 14, 8, 64, 0, 16, 3, 50, 4,  1, 5, 13, 6, 95, 
    1, 34, 0, 90, 7, 60, 4, 23, 6, 42, 2, 58, 5, 60, 3, 32, 8, 93, 
    3,  1, 8,  8, 7, 86, 6, 18, 0, 91, 1, 95, 5, 67, 4, 34, 2, 17
  };
  const int q9261[] = {
    9, 9, // Number of jobs and machines
    5, 25, 2, 95, 4, 33, 1, 38, 7, 70, 8, 31, 0, 87, 6, 52, 3, 26, 
    7, 36, 8, 52, 5, 11, 6, 81, 4, 77, 0, 53, 3, 12, 2, 92, 1, 32, 
    6, 70, 5, 84, 2, 18, 7, 20, 4, 30, 3,  8, 8, 16, 0, 83, 1, 23, 
    7, 14, 6, 92, 1, 83, 8, 63, 4, 73, 3,  3, 2, 41, 0, 60, 5, 56, 
    6, 58, 2, 52, 3, 31, 1, 91, 0, 67, 7, 14, 8, 70, 4, 60, 5, 41, 
    6, 59, 0, 81, 5, 84, 3, 94, 4, 12, 2, 65, 1, 86, 7,  3, 8, 52, 
    4, 14, 0,  5, 7, 55, 6, 98, 3, 24, 1, 88, 5, 91, 2, 22, 8, 23, 
    1, 70, 0, 96, 5, 12, 6, 75, 7, 70, 3, 60, 4, 35, 2, 83, 8, 35, 
    2, 67, 6, 12, 8, 91, 7, 11, 3, 12, 5, 72, 4, 36, 0, 43, 1, 33
  };
  const int q9262[] = {
    9, 9, // Number of jobs and machines
    1, 64, 0, 23, 2, 91, 8, 53, 4, 81, 5, 40, 7, 87, 3, 54, 6, 21, 
    1, 29, 3, 84, 6, 27, 5, 38, 0,  5, 4, 95, 7,  1, 8, 37, 2, 46, 
    0, 47, 4, 57, 8, 28, 5, 18, 2, 61, 3, 26, 1, 37, 7,  1, 6,  6, 
    4, 43, 6, 33, 7, 71, 3, 38, 8, 82, 2, 54, 1, 45, 0, 33, 5, 84, 
    1, 75, 7, 50, 2, 91, 3, 25, 4, 37, 6, 43, 8, 11, 5, 41, 0, 27, 
    6, 63, 5, 63, 8, 75, 0, 32, 2, 90, 4, 66, 3, 54, 7, 56, 1, 85, 
    6, 39, 0, 76, 1, 60, 3, 85, 7, 72, 5,  1, 8, 74, 2, 55, 4, 84, 
    4, 58, 5,  3, 8, 14, 3, 92, 7, 19, 6, 92, 2, 98, 1, 62, 0, 71, 
    8, 34, 6, 61, 1, 26, 3, 34, 2, 23, 7, 43, 4, 62, 0, 95, 5, 88
  };
  const int q9263[] = {
    9, 9, // Number of jobs and machines
    1, 81, 4, 58, 5, 30, 2, 54, 6, 18, 3, 23, 7, 13, 8, 78, 0, 79, 
    4, 27, 1, 73, 0, 25, 2, 28, 7, 57, 5, 67, 6, 70, 3, 66, 8, 86, 
    7, 46, 0, 31, 4, 68, 1, 54, 8, 30, 5, 24, 3, 91, 6, 59, 2, 49, 
    6, 31, 8, 88, 2, 75, 3, 37, 1, 36, 5, 53, 0, 40, 4, 32, 7, 96, 
    7, 12, 6, 91, 2,  9, 3,  2, 1, 82, 0, 87, 5, 22, 8, 68, 4, 32, 
    7, 10, 5, 35, 4, 89, 1,  1, 0, 78, 2, 78, 3, 85, 6, 40, 8, 72, 
    7, 36, 1, 46, 0, 26, 3, 92, 8, 11, 4, 48, 2, 15, 5, 48, 6, 18, 
    4,  5, 7, 25, 0, 15, 6, 38, 3,  9, 2, 98, 8, 69, 5, 54, 1, 43, 
    8, 52, 6, 87, 4, 18, 7, 56, 0, 23, 3,  8, 2, 25, 5, 53, 1, 30
  };
  const int q9264[] = {
    9, 9, // Number of jobs and machines
    3, 87, 0, 31, 4, 32, 1, 44, 6, 95, 8, 22, 5,  6, 7, 94, 2, 84, 
    3,  7, 2, 54, 1,  9, 8, 57, 6, 23, 0, 75, 4,  7, 5, 38, 7, 86, 
    6, 96, 4, 28, 5, 87, 3, 40, 0, 81, 2,  7, 8, 96, 7, 20, 1, 58, 
    7, 50, 0, 56, 2, 85, 4, 71, 6, 13, 1, 53, 3, 86, 5,  3, 8, 84, 
    6, 25, 7, 67, 5, 86, 3, 38, 2, 18, 1, 86, 8, 28, 4, 90, 0, 30, 
    4, 30, 3, 37, 8, 40, 1, 77, 5, 75, 7,  2, 0,  4, 2, 53, 6, 68, 
    0,  8, 1, 95, 3, 82, 4, 28, 6, 13, 2, 91, 7, 11, 5, 79, 8, 68, 
    2, 66, 6, 87, 5, 84, 1, 97, 0,  7, 7, 48, 8, 31, 3, 63, 4, 61, 
    4, 14, 0, 77, 7, 85, 2, 17, 6, 53, 1, 39, 5, 58, 8, 37, 3,  4
  };
  const int q9265[] = {
    9, 9, // Number of jobs and machines
    3, 52, 2, 11, 4, 74, 1, 21, 8, 61, 0, 54, 5,  7, 7, 69, 6, 77, 
    0, 64, 7, 92, 4, 95, 3, 58, 8, 39, 1, 51, 5, 69, 6, 58, 2, 59, 
    4, 60, 3, 81, 1, 34, 0, 13, 2, 89, 6, 33, 5, 96, 8, 18, 7, 87, 
    7, 90, 8, 47, 2, 43, 6, 16, 4, 13, 3, 40, 0, 53, 5, 34, 1, 49, 
    4, 44, 2, 33, 7, 69, 3, 68, 8, 40, 0, 22, 6, 46, 1, 63, 5, 43, 
    0,  4, 7, 64, 8, 17, 3, 98, 1, 74, 2, 56, 4,  7, 5, 67, 6, 41, 
    5, 27, 1, 96, 6,  6, 3, 98, 7, 69, 0, 96, 8, 65, 4, 80, 2, 14, 
    6, 30, 4, 23, 7,  1, 2, 70, 3, 35, 1, 40, 0, 14, 8, 42, 5, 72, 
    5, 25, 3, 28, 8, 69, 2,  9, 4, 22, 7, 50, 0, 71, 1, 39, 6, 74
  };
  const int q9266[] = {
    9, 9, // Number of jobs and machines
    4, 73, 3, 55, 8, 82, 6,  4, 7, 34, 2, 22, 5, 92, 0, 91, 1, 30, 
    2, 77, 8, 55, 5, 78, 6, 61, 0, 33, 1, 91, 3, 55, 7, 97, 4, 57, 
    2, 21, 3, 62, 8, 38, 1, 13, 0, 19, 7, 76, 4,  6, 5, 65, 6, 81, 
    7, 60, 0, 61, 8, 54, 5, 85, 4, 11, 2, 93, 6, 98, 3, 21, 1, 43, 
    3, 42, 0,  7, 8, 73, 1, 11, 2,  6, 4, 68, 7, 95, 6, 86, 5, 76, 
    3, 31, 6, 94, 7, 52, 5,  2, 2, 62, 0, 22, 4, 62, 8, 98, 1, 65, 
    8,  7, 5, 28, 7, 84, 0, 92, 4, 22, 3, 81, 2, 33, 1, 61, 6, 67, 
    2, 51, 1, 58, 0, 74, 6, 32, 4, 88, 7,  6, 3, 42, 5, 52, 8, 38, 
    7, 32, 2, 25, 1, 38, 3, 64, 0,  6, 4, 19, 6, 44, 5, 45, 8, 40
  };
  const int q9267[] = {
    9, 9, // Number of jobs and machines
    5, 55, 6, 94, 8, 46, 1, 69, 2, 89, 3, 99, 4, 76, 7,  8, 0,  9, 
    6,  9, 0, 69, 1, 40, 7, 31, 8, 43, 3, 90, 5, 17, 4, 58, 2, 67, 
    4, 72, 5, 23, 8, 47, 0, 13, 2, 95, 6, 83, 3, 27, 1, 13, 7, 30, 
    2, 63, 4, 27, 8,  2, 0, 18, 5, 71, 1, 26, 6, 37, 7, 76, 3, 61, 
    5, 14, 0, 99, 3, 81, 2,  3, 7, 60, 6, 67, 8, 48, 4, 33, 1, 92, 
    1, 84, 0, 51, 7, 79, 2, 69, 8, 70, 6, 23, 3, 45, 5,  6, 4, 92, 
    2, 61, 0, 81, 1, 22, 6, 58, 7, 74, 4, 48, 5, 20, 3, 76, 8, 85, 
    5,  1, 6, 74, 1,  6, 0, 29, 4, 78, 8, 55, 3, 89, 2,  2, 7, 20, 
    0, 64, 4, 28, 2, 11, 5, 96, 8,  5, 1, 27, 6, 81, 3, 74, 7, 83
  };
  const int q9268[] = {
    9, 9, // Number of jobs and machines
    4, 12, 0, 68, 7, 91, 2, 85, 3, 75, 5, 51, 1, 97, 6, 31, 8, 23, 
    1, 59, 5, 25, 4,  2, 7, 62, 6,  2, 2, 61, 0, 37, 3, 56, 8, 12, 
    2, 20, 8,  7, 0, 36, 5, 29, 1, 72, 6, 40, 7, 93, 4, 65, 3, 90, 
    7, 66, 3, 46, 1, 20, 6,  1, 4, 41, 8,  5, 0,  9, 5, 61, 2, 92, 
    3, 98, 4, 79, 1, 52, 0, 94, 2, 41, 6, 75, 7, 26, 8, 46, 5, 99, 
    4, 93, 1, 79, 7, 29, 5, 27, 8, 55, 2, 92, 6, 16, 0, 63, 3, 34, 
    5, 12, 3, 32, 4, 72, 7, 82, 1, 58, 0, 37, 8, 83, 2, 88, 6, 27, 
    8, 49, 7, 59, 1, 97, 4, 27, 6, 80, 2, 62, 3, 10, 5, 91, 0,  2, 
    3, 62, 6, 23, 0, 36, 8, 73, 5,  3, 1, 83, 7, 49, 2, 28, 4, 44
  };
  const int q9269[] = {
    9, 9, // Number of jobs and machines
    6, 33, 3, 43, 8, 54, 5, 35, 2, 44, 1, 24, 0, 91, 4, 47, 7, 60, 
    5, 15, 8, 81, 1, 34, 4,  1, 2,  9, 3, 79, 6, 23, 7, 77, 0, 72, 
    8, 28, 2, 33, 6, 26, 0, 12, 5, 84, 3, 84, 7, 46, 4, 29, 1, 85, 
    5, 43, 8,  6, 4, 10, 6,  8, 3, 66, 7,  7, 1,  9, 0, 13, 2, 71, 
    6, 84, 3, 66, 1, 82, 5, 72, 2, 98, 0, 36, 8, 20, 4, 36, 7, 28, 
    7, 45, 2, 23, 5, 99, 1, 13, 6, 72, 0, 14, 8, 11, 4, 68, 3,  8, 
    5, 69, 7, 37, 2, 55, 3, 99, 1, 28, 6,  8, 4, 44, 0, 21, 8, 28, 
    2, 96, 6, 39, 3, 74, 7, 60, 8, 66, 4, 20, 5, 52, 1, 95, 0, 63, 
    6, 82, 2, 50, 4, 62, 5, 91, 7, 58, 8, 77, 3, 25, 0, 39, 1, 35
  };
  const int q9270[] = {
    9, 9, // Number of jobs and machines
    0, 46, 3, 67, 5, 41, 6, 27, 8,  5, 1, 87, 4, 65, 7, 85, 2, 56, 
    2, 90, 5, 16, 1, 60, 4, 20, 8,  1, 6, 84, 3, 89, 7, 40, 0, 52, 
    7, 50, 4, 54, 6,  3, 2, 13, 3, 80, 0, 31, 8, 20, 1, 66, 5, 81, 
    7, 74, 5,  5, 2, 93, 0, 21, 1, 74, 8, 51, 6, 28, 3, 34, 4, 15, 
    6, 31, 4, 92, 3, 18, 7, 34, 8, 59, 5, 74, 0, 23, 1, 73, 2, 17, 
    3, 73, 6, 62, 4, 80, 5, 83, 0, 85, 2, 91, 7, 39, 8, 29, 1, 66, 
    4, 35, 8,  1, 2,  4, 3, 68, 1, 47, 7, 19, 0, 78, 5,  3, 6, 44, 
    2, 26, 0, 67, 1, 63, 5, 44, 6, 19, 3, 41, 8, 37, 7,  7, 4,  9, 
    1, 47, 7, 49, 4, 76, 8, 52, 0, 93, 6, 56, 5, 15, 2, 32, 3, 37
  };
  const int q9271[] = {
    9, 9, // Number of jobs and machines
    1, 87, 6, 56, 7, 34, 3, 32, 0, 18, 8, 62, 4, 10, 5, 27, 2, 63, 
    7, 36, 4, 91, 2, 80, 0, 73, 5, 24, 1, 28, 3, 76, 8, 50, 6, 28, 
    0, 34, 1, 80, 3, 25, 5, 62, 6, 38, 7, 69, 2, 89, 8, 14, 4, 78, 
    2, 52, 4, 11, 7, 35, 6, 13, 8, 70, 0, 92, 5, 45, 3, 28, 1, 10, 
    5,  8, 8, 43, 2, 55, 6, 94, 7, 53, 4, 21, 3, 61, 1, 81, 0, 77, 
    4, 37, 3, 88, 5, 47, 8,  2, 6, 82, 2, 77, 1, 86, 7, 99, 0, 64, 
    0, 82, 1, 26, 6,  2, 4, 56, 2, 43, 5, 51, 7, 52, 3, 28, 8, 26, 
    2, 73, 0, 67, 6, 71, 5, 42, 3, 12, 1,  4, 4, 79, 7, 90, 8, 84, 
    0, 86, 2, 13, 8, 45, 6,  1, 3, 66, 4, 41, 1, 75, 5, 75, 7, 47
  };
  const int q9272[] = {
    9, 9, // Number of jobs and machines
    8, 20, 4, 40, 3, 36, 2, 67, 6, 10, 1, 99, 7, 65, 0, 36, 5, 38, 
    3,  4, 2, 44, 0, 95, 1,  5, 5, 46, 7, 88, 8, 20, 4, 89, 6, 27, 
    1, 16, 4,  4, 5, 65, 6,  6, 3, 13, 7, 20, 0, 75, 8, 80, 2, 69, 
    4, 59, 7, 23, 3, 54, 1, 70, 0, 63, 5, 26, 2, 67, 6, 62, 8, 73, 
    6, 80, 7, 83, 4, 41, 3, 58, 5, 75, 2, 12, 1, 46, 8, 63, 0, 25, 
    7, 10, 5, 42, 4, 19, 1, 63, 6, 16, 2, 56, 3, 68, 0, 38, 8, 97, 
    1, 62, 2, 53, 3, 11, 7, 73, 4, 91, 0,  7, 5, 77, 6, 69, 8,  1, 
    7, 53, 0, 47, 5, 35, 2, 38, 6, 68, 1, 29, 4, 85, 8, 36, 3, 42, 
    2, 83, 3, 13, 1, 25, 4, 45, 5, 24, 7, 68, 8, 27, 0, 42, 6, 13
  };
  const int q9273[] = {
    9, 9, // Number of jobs and machines
    7,  7, 4, 76, 5, 25, 6, 31, 1, 25, 3,  6, 0, 93, 2, 69, 8, 93, 
    7, 93, 1, 80, 0, 14, 4, 67, 5, 74, 8, 92, 3,  8, 6, 10, 2, 51, 
    2, 66, 3, 36, 6, 56, 8, 22, 0, 43, 7, 78, 4, 80, 5, 49, 1, 86, 
    3, 79, 7, 71, 1, 61, 2, 54, 0, 94, 8, 88, 6, 51, 5, 59, 4, 92, 
    8, 85, 7, 18, 5, 91, 0, 62, 1, 77, 4, 25, 3, 76, 6, 30, 2, 42, 
    5,  8, 0, 88, 2, 28, 4, 27, 8, 38, 1, 60, 6, 24, 7, 12, 3, 30, 
    8, 39, 1, 61, 2,  4, 7, 87, 6, 60, 0, 27, 4,  6, 3, 88, 5, 63, 
    0, 13, 1, 97, 2, 48, 5, 48, 7, 18, 8, 16, 6, 44, 3, 92, 4,  6, 
    4, 46, 6, 85, 5, 92, 8, 49, 3, 93, 7, 38, 2, 18, 1, 72, 0, 60
  };
  const int q9274[] = {
    9, 9, // Number of jobs and machines
    8, 96, 3, 27, 1, 57, 6, 76, 2, 78, 5, 40, 7, 22, 0, 43, 4, 17, 
    2, 98, 1, 86, 4, 41, 5, 96, 7,  3, 8, 45, 6, 28, 3, 42, 0, 26, 
    6, 22, 5, 71, 8, 40, 7, 20, 3, 35, 0,  8, 4, 77, 2, 66, 1, 43, 
    5, 87, 0, 72, 1, 26, 7, 75, 8, 70, 4, 45, 3, 67, 2, 62, 6, 88, 
    2,  8, 8,  8, 6, 73, 7, 79, 5,  6, 1, 38, 4, 82, 3, 39, 0, 25, 
    6, 84, 8, 14, 2, 88, 5, 33, 0, 87, 3, 81, 7, 99, 4, 26, 1, 51, 
    4, 59, 1, 39, 2, 44, 0, 35, 5, 20, 3, 96, 6, 39, 8,  1, 7, 10, 
    2, 93, 3, 10, 5, 39, 8, 58, 6, 30, 1, 97, 7, 46, 0, 92, 4, 71, 
    1, 41, 4,  1, 0, 87, 6, 78, 3, 86, 7, 91, 8, 24, 2, 97, 5, 31
  };
  const int q9275[] = {
    9, 9, // Number of jobs and machines
    2, 47, 6, 51, 3, 86, 1, 56, 4, 20, 5, 17, 8, 88, 0, 33, 7, 36, 
    2, 50, 3, 68, 6, 13, 8, 47, 1, 25, 7, 21, 5, 90, 0, 18, 4, 66, 
    7, 31, 1, 29, 2, 67, 4, 60, 3, 15, 6, 48, 0, 91, 5, 67, 8, 29, 
    7, 57, 4, 31, 0, 10, 1, 43, 5, 43, 3, 44, 8, 46, 6, 70, 2, 52, 
    3, 22, 7, 11, 0, 54, 5, 38, 6, 37, 2, 35, 4, 49, 8, 30, 1, 72, 
    3, 84, 2, 21, 6, 42, 5, 65, 8, 51, 7, 96, 1, 60, 0, 57, 4, 70, 
    8, 97, 5, 39, 0, 35, 2, 33, 1, 38, 6, 70, 3, 87, 4, 71, 7, 16, 
    5, 92, 2, 68, 8, 85, 7, 59, 6, 75, 0, 34, 4, 50, 3, 96, 1,  5, 
    7, 10, 0, 21, 1, 61, 3, 22, 6, 95, 8,  2, 2, 21, 4, 40, 5, 41
  };
  const int q9276[] = {
    9, 9, // Number of jobs and machines
    5, 82, 6, 64, 8, 87, 7, 80, 0, 66, 4, 73, 2, 41, 3, 94, 1, 36, 
    8, 13, 2, 96, 4, 70, 5, 88, 3, 85, 6, 96, 1, 22, 0, 47, 7, 77, 
    7,  6, 6, 38, 8,  6, 4, 50, 0, 68, 3, 90, 5, 62, 2, 34, 1, 89, 
    1, 63, 7, 20, 5, 33, 2, 56, 6, 79, 3, 21, 8, 55, 4,  4, 0, 27, 
    4, 20, 8, 73, 2, 47, 7, 11, 3, 92, 1, 64, 6, 65, 5, 43, 0, 17, 
    0, 62, 5, 45, 7, 96, 4, 32, 8,  3, 6, 44, 2, 31, 3, 66, 1, 22, 
    4, 63, 6, 59, 2, 44, 5, 12, 7, 88, 3, 23, 1, 72, 8, 96, 0, 49, 
    8, 94, 4, 75, 0, 18, 3, 20, 2, 93, 6, 72, 5, 94, 1, 46, 7, 32, 
    8, 84, 3, 15, 6, 65, 5, 97, 2, 17, 4, 27, 1, 86, 7, 60, 0, 33
  };
  const int q9277[] = {
    9, 9, // Number of jobs and machines
    4, 50, 3, 28, 1, 77, 7, 13, 2, 24, 8, 28, 5, 20, 6, 98, 0, 79, 
    4, 13, 7, 73, 6, 37, 1, 47, 2,  1, 8, 73, 0, 32, 3, 24, 5, 55, 
    7, 92, 1, 13, 4, 39, 6, 93, 3, 58, 8, 63, 5, 25, 2, 30, 0, 89, 
    8,  9, 7, 87, 3, 21, 0, 63, 1, 90, 2, 71, 6, 64, 5, 50, 4, 89, 
    6, 32, 1, 55, 8, 78, 2, 82, 4, 94, 7, 31, 0, 47, 3, 88, 5, 96, 
    3, 90, 8, 28, 6, 36, 7, 41, 1,  3, 4, 27, 2, 46, 5, 44, 0,  3, 
    8, 94, 3, 82, 2, 85, 5, 95, 6, 36, 0, 27, 1, 12, 7, 28, 4, 68, 
    4, 31, 6, 63, 1, 46, 8, 65, 5, 76, 2, 82, 7, 66, 0,  1, 3, 63, 
    6, 64, 2, 31, 4, 19, 0, 38, 1, 95, 3, 45, 8, 68, 5, 50, 7, 18
  };
  const int q9278[] = {
    9, 9, // Number of jobs and machines
    4, 92, 6, 59, 3, 46, 1, 86, 5, 78, 7, 74, 2, 92, 8, 74, 0, 58, 
    3, 58, 8, 99, 1, 58, 4, 82, 0, 81, 6,  7, 5, 69, 2, 83, 7, 96, 
    3, 45, 6, 85, 2, 80, 8, 25, 0, 29, 4, 23, 7, 62, 1, 93, 5, 92, 
    5, 92, 7, 72, 2, 50, 6, 30, 8, 61, 4, 29, 0, 23, 1,  9, 3, 84, 
    0, 52, 8, 52, 5, 61, 7, 21, 1, 78, 6, 73, 3, 73, 2, 88, 4, 97, 
    3, 19, 2, 33, 0, 52, 6, 56, 8,  9, 4, 58, 5, 67, 7, 97, 1,  8, 
    6, 15, 8, 80, 0, 58, 1, 52, 2, 47, 5, 28, 7, 15, 3, 80, 4,  7, 
    6, 85, 3, 64, 1, 31, 0, 98, 2,  4, 4,  3, 8, 29, 7,  3, 5, 35, 
    5,  8, 3, 77, 2, 22, 0, 85, 7,  8, 1, 94, 6, 81, 8, 81, 4, 80
  };
  const int q9279[] = {
    9, 9, // Number of jobs and machines
    2, 13, 1, 47, 4,  5, 0, 99, 5, 78, 7, 51, 3, 56, 6, 48, 8, 65, 
    6, 81, 1, 45, 8, 47, 7,  8, 4, 87, 0, 56, 5, 55, 2, 33, 3, 33, 
    1, 23, 2, 31, 5, 79, 0, 57, 7,  1, 3,  7, 4, 42, 8, 13, 6, 47, 
    3, 60, 7, 78, 6, 75, 4, 94, 5, 88, 8,  2, 0,  1, 2, 93, 1, 48, 
    4, 73, 2, 43, 8, 61, 5, 92, 0, 56, 1, 27, 7, 45, 3, 98, 6, 99, 
    3, 30, 7, 80, 5,  5, 6, 49, 0, 79, 4, 49, 2, 46, 1, 46, 8, 13, 
    5, 98, 6, 64, 7, 61, 0, 78, 2, 19, 8, 97, 3, 79, 4, 14, 1, 12, 
    7, 66, 8, 27, 2,  6, 3, 15, 1, 30, 0, 37, 6, 30, 4, 86, 5, 29, 
    5, 33, 3, 26, 0, 18, 6, 88, 2, 80, 7, 75, 4, 70, 8, 57, 1, 52
  };
  const int q9280[] = {
    9, 9, // Number of jobs and machines
    7, 64, 3, 79, 0, 82, 8, 74, 5, 73, 6, 68, 2, 16, 4, 76, 1, 68, 
    8, 87, 2, 16, 0, 12, 1, 63, 4,  5, 6, 12, 7,  3, 3, 19, 5, 49, 
    4, 93, 3, 50, 2, 53, 8, 74, 1, 26, 7, 28, 5, 10, 6, 17, 0,  4, 
    7, 50, 2, 24, 6, 81, 4, 48, 0, 29, 5, 83, 8, 70, 3,  2, 1, 99, 
    7, 72, 6, 57, 1, 45, 2, 20, 8, 75, 4, 32, 0, 53, 3, 37, 5, 55, 
    5, 36, 0, 71, 8, 67, 6, 77, 4, 91, 7, 50, 3, 19, 2, 58, 1, 92, 
    3,  6, 2, 58, 1, 81, 8, 65, 6, 96, 5, 94, 7, 28, 4, 73, 0,  2, 
    8, 77, 0, 86, 5, 62, 3, 82, 1, 30, 2, 32, 7, 15, 6, 39, 4, 51, 
    4, 27, 7, 75, 8, 60, 3, 67, 5, 96, 0, 80, 2, 32, 1, 39, 6, 78
  };
  const int q9281[] = {
    9, 9, // Number of jobs and machines
    3, 80, 1,  4, 6, 45, 5, 75, 2, 51, 0, 77, 7, 99, 8, 36, 4, 61, 
    6, 64, 8, 40, 2, 45, 0, 51, 1, 70, 7, 69, 4, 83, 3, 96, 5, 24, 
    3, 57, 0, 82, 1, 72, 6, 98, 8, 77, 7, 13, 4, 29, 5, 48, 2, 87, 
    2, 87, 3, 59, 7,  3, 0, 97, 6, 11, 5, 13, 8, 59, 4, 89, 1, 90, 
    3, 36, 6,  7, 4, 98, 8, 20, 5, 15, 0, 14, 1,  2, 2, 20, 7, 30, 
    1, 61, 8, 44, 4,  6, 2, 13, 3, 91, 7, 81, 0, 60, 5, 53, 6, 37, 
    8,  9, 2, 24, 4, 46, 5, 12, 7, 90, 6, 62, 3, 20, 1, 54, 0, 49, 
    1, 28, 7, 47, 0, 75, 5, 30, 6,  3, 4, 21, 8, 43, 2, 95, 3, 35, 
    7, 50, 6, 98, 3, 89, 4, 13, 0,  5, 5, 80, 8, 27, 2, 87, 1, 60
  };
  const int q9282[] = {
    9, 9, // Number of jobs and machines
    6,  6, 2, 53, 7, 23, 5,  6, 8, 93, 3, 16, 0, 21, 4, 37, 1, 15, 
    4, 44, 8, 23, 2, 42, 6, 80, 0, 22, 5,  3, 7, 39, 1, 46, 3, 39, 
    8, 34, 4, 77, 3, 84, 2, 98, 6,  3, 0, 20, 7, 41, 1, 97, 5, 71, 
    4, 33, 2, 92, 6, 94, 8, 63, 0, 55, 3, 89, 7, 42, 5, 34, 1, 88, 
    2, 46, 8, 54, 7,  1, 0,  8, 1, 57, 3, 26, 5, 26, 4, 18, 6, 69, 
    8,  3, 7, 79, 1,  2, 3, 77, 4, 36, 6, 40, 0, 98, 5, 37, 2, 91, 
    6, 98, 5, 86, 3, 36, 2, 10, 7, 93, 8,  6, 1, 35, 0, 66, 4, 61, 
    6, 19, 8, 45, 2, 52, 5, 96, 3, 95, 1, 46, 0, 46, 7,  1, 4, 58, 
    3, 47, 4, 36, 6, 91, 5, 51, 7, 51, 2, 50, 0, 97, 8, 11, 1, 92
  };
  const int q9283[] = {
    9, 9, // Number of jobs and machines
    1,  3, 5, 37, 3, 94, 7, 46, 8,  5, 2, 88, 4, 42, 0, 31, 6, 44, 
    5, 65, 7, 60, 1,  2, 2, 11, 4, 53, 8, 47, 0, 42, 6, 40, 3,  3, 
    8, 79, 4, 42, 2, 53, 6,  9, 3,  1, 5, 64, 0, 80, 7, 25, 1, 42, 
    2, 19, 3, 37, 0,  4, 1, 95, 6, 62, 7, 23, 4, 91, 8, 97, 5,  7, 
    7, 27, 1, 48, 0, 43, 8, 84, 3, 52, 2, 43, 5, 30, 6, 67, 4, 40, 
    3, 65, 0, 75, 2, 51, 6, 86, 7, 84, 1, 78, 4, 14, 8, 30, 5, 39, 
    2,  1, 6, 82, 4, 71, 1, 89, 3, 32, 0, 23, 8,  4, 5, 24, 7, 38, 
    6, 63, 2, 71, 4, 33, 7, 29, 0, 98, 3, 44, 5,  9, 8,  3, 1,  5, 
    5, 89, 0, 80, 7, 22, 1, 62, 4, 74, 2,  9, 3, 61, 6, 16, 8, 51
  };
  const int q9284[] = {
    9, 9, // Number of jobs and machines
    0, 77, 3, 47, 7, 40, 5, 28, 4, 19, 6, 43, 2, 99, 8, 86, 1, 60, 
    8, 31, 1, 23, 4, 46, 5, 58, 0, 41, 3, 63, 7, 77, 6, 85, 2, 78, 
    5, 10, 1, 96, 7, 70, 8, 17, 4, 98, 6, 92, 0,  6, 2, 28, 3, 89, 
    5, 42, 3,  8, 1, 41, 0,  8, 8, 98, 4,  2, 2, 29, 6, 71, 7, 88, 
    1, 61, 0, 79, 6, 51, 2, 60, 5,  9, 7, 93, 4, 32, 3,  3, 8, 41, 
    0, 99, 5, 85, 4, 33, 2, 40, 6, 55, 1, 19, 8, 82, 7, 66, 3, 19, 
    1, 15, 2, 18, 8, 49, 7, 48, 0, 71, 6,  1, 5, 19, 4, 19, 3, 70, 
    3, 27, 4, 26, 2, 67, 7, 28, 1, 15, 6, 10, 5, 83, 8, 50, 0, 59, 
    0, 68, 3, 17, 4, 51, 2,  6, 8, 18, 7, 91, 5, 44, 1, 65, 6, 73
  };
  const int q9285[] = {
    9, 9, // Number of jobs and machines
    0, 70, 1, 13, 2, 66, 8, 96, 6, 45, 3, 98, 7, 21, 4, 61, 5, 40, 
    6, 19, 0, 90, 2, 15, 3,  6, 7, 94, 8, 90, 5, 44, 4, 93, 1, 87, 
    1, 37, 3,  7, 4, 59, 2,  4, 7, 95, 6, 26, 5,  9, 0, 39, 8, 41, 
    7, 48, 3, 76, 5, 85, 0, 63, 4, 77, 2, 32, 6,  6, 8, 54, 1, 48, 
    8, 31, 5, 73, 7, 43, 1, 70, 0, 44, 2, 32, 4, 62, 6, 74, 3, 54, 
    5, 58, 2, 29, 0, 76, 1, 56, 6, 69, 4, 41, 3, 47, 7, 53, 8, 16, 
    6, 98, 3, 87, 8, 50, 7, 24, 1, 69, 5, 12, 4, 93, 2, 57, 0, 76, 
    5, 28, 7, 63, 8, 84, 6, 51, 4, 60, 3, 58, 1, 94, 0, 63, 2, 15, 
    1, 78, 5, 50, 6, 33, 8, 49, 2, 10, 4, 10, 0, 40, 3, 96, 7, 87
  };
  const int q9286[] = {
    9, 9, // Number of jobs and machines
    6, 96, 5, 43, 7, 29, 8, 96, 3, 49, 4, 72, 0, 98, 2,  8, 1, 10, 
    7, 68, 8, 56, 4, 15, 1, 16, 6, 56, 0,  9, 2, 11, 3, 47, 5, 65, 
    7, 14, 6, 17, 5, 65, 0, 55, 3, 56, 8, 76, 4, 79, 2, 74, 1, 66, 
    4, 19, 3, 90, 8,  8, 7, 83, 0, 38, 6, 88, 1, 78, 2, 24, 5, 30, 
    0, 98, 5, 46, 4,  7, 8, 15, 3, 66, 2, 47, 7,  3, 6, 64, 1, 43, 
    8, 62, 1, 12, 6, 28, 3,  3, 4, 12, 2, 46, 5, 77, 0, 56, 7, 57, 
    1, 14, 4, 53, 8, 75, 0, 48, 6, 89, 7, 26, 2,  9, 5, 55, 3, 30, 
    2, 76, 4, 68, 5, 12, 7, 88, 3,  8, 0, 31, 6, 29, 8, 50, 1, 11, 
    6, 12, 7, 84, 4, 96, 5,  2, 0,  4, 1,  8, 8,  8, 2, 97, 3, 18
  };
  const int q9287[] = {
    9, 9, // Number of jobs and machines
    3, 93, 2, 11, 0, 98, 7, 16, 4, 31, 8, 94, 5, 19, 6, 76, 1, 60, 
    4,  9, 7, 61, 6,  3, 8, 51, 3, 40, 2, 43, 0, 37, 5,  6, 1, 54, 
    6, 41, 8, 86, 1, 18, 3, 68, 0, 70, 7, 70, 2, 72, 5, 26, 4, 37, 
    1, 58, 2, 75, 4, 32, 7, 51, 0, 59, 8, 74, 6, 80, 5,  9, 3, 49, 
    4, 39, 6, 11, 3, 26, 8, 39, 7, 43, 2, 94, 1, 29, 0, 55, 5, 61, 
    3, 64, 6, 67, 7,  1, 4,  7, 5, 83, 0, 11, 2, 42, 8, 51, 1, 65, 
    4, 65, 0, 98, 5, 58, 3, 54, 8,  3, 7, 19, 6, 34, 2, 40, 1, 77, 
    8, 94, 1,  7, 2, 80, 3, 27, 4, 24, 7, 31, 6, 16, 5, 18, 0, 54, 
    7, 76, 8, 68, 2, 55, 0, 23, 4, 79, 5, 73, 3, 49, 1, 87, 6, 90
  };
  const int q9288[] = {
    9, 9, // Number of jobs and machines
    5, 31, 8, 41, 4, 29, 1, 70, 3, 87, 2, 30, 6, 12, 0, 77, 7, 71, 
    3,  3, 2, 76, 1, 91, 0,  6, 7, 31, 8,  7, 4, 14, 5, 88, 6, 23, 
    0, 13, 7, 69, 2, 19, 8, 92, 4, 59, 3, 83, 5, 69, 6, 49, 1, 71, 
    7, 12, 1, 70, 5, 22, 4, 10, 6, 48, 0, 39, 8, 47, 3, 19, 2, 27, 
    2, 71, 3, 80, 4, 48, 7, 72, 8, 49, 1, 14, 5, 30, 6, 43, 0, 44, 
    2, 92, 4, 37, 6, 64, 1, 15, 0, 54, 5, 43, 7, 84, 8, 92, 3, 31, 
    0, 72, 7,  5, 2, 26, 5, 28, 4, 47, 1,  5, 3, 96, 8, 72, 6, 62, 
    1, 84, 4, 94, 7, 33, 6, 78, 8, 48, 0, 25, 3, 33, 5, 57, 2, 17, 
    0, 21, 6, 39, 4, 56, 3, 49, 5, 80, 8, 59, 7, 68, 1, 75, 2,  6
  };
  const int q9289[] = {
    9, 9, // Number of jobs and machines
    6, 73, 7, 14, 2, 10, 3, 28, 1, 83, 4, 76, 8, 87, 0, 97, 5, 22, 
    0,  8, 7,  8, 1, 18, 2, 20, 3, 41, 8, 94, 6, 42, 5, 58, 4, 12, 
    1,  2, 7, 34, 3, 12, 2, 67, 4, 90, 6, 90, 8, 49, 0, 94, 5, 37, 
    2, 30, 0, 42, 3, 83, 1, 19, 4,  4, 5, 72, 8, 56, 6, 87, 7, 23, 
    4, 12, 6, 67, 0, 84, 5, 58, 1, 77, 2, 54, 3, 83, 7, 97, 8, 92, 
    8, 71, 1, 31, 5, 22, 0, 57, 6, 22, 7, 23, 4, 19, 3, 25, 2, 80, 
    4, 24, 3, 67, 0, 68, 2, 40, 1, 42, 8, 57, 6, 85, 7, 86, 5, 31, 
    4, 80, 5, 45, 6, 60, 7, 90, 1, 37, 3, 52, 0, 40, 2, 98, 8, 13, 
    2,  2, 0, 39, 6, 30, 8, 30, 3, 72, 1, 34, 7, 68, 4, 58, 5, 89
  };
  const int q9290[] = {
    9, 9, // Number of jobs and machines
    2,  5, 4, 96, 1, 11, 8, 72, 0, 97, 3, 12, 7, 12, 6,  3, 5, 54, 
    3, 30, 5, 18, 4, 70, 6, 88, 7, 94, 1, 74, 8, 15, 2, 85, 0, 67, 
    8, 25, 2, 63, 0,  2, 6, 78, 3, 98, 7, 14, 1, 73, 4, 56, 5, 99, 
    1, 43, 5, 77, 3,  8, 2, 43, 7,  6, 6, 23, 4, 29, 0, 82, 8, 44, 
    0, 24, 8, 80, 1, 19, 6,  4, 7, 41, 4, 30, 5, 15, 3, 11, 2, 20, 
    8, 66, 7, 15, 1, 47, 5, 46, 0, 68, 3, 67, 2, 82, 6, 52, 4, 77, 
    3, 52, 8, 54, 2, 85, 0,  9, 6, 56, 1, 61, 4, 87, 5, 69, 7, 42, 
    8, 39, 3, 43, 7, 40, 5, 36, 2,  2, 0, 70, 4, 73, 6,  6, 1,  7, 
    6, 28, 1, 57, 4,  7, 8, 19, 5, 93, 7, 79, 2, 63, 0, 67, 3, 30
  };
  const int q9291[] = {
    9, 9, // Number of jobs and machines
    0,  3, 1, 77, 5, 76, 6, 12, 3, 43, 8, 69, 7, 15, 4, 82, 2, 10, 
    0, 41, 1,  1, 2, 13, 4, 77, 5, 19, 3, 44, 8, 80, 6, 66, 7,  3, 
    6,  4, 2, 57, 7,  9, 1, 10, 0, 68, 5, 14, 8, 73, 3, 12, 4, 33, 
    0, 82, 7, 81, 6, 46, 2, 55, 1, 49, 4, 53, 3, 91, 5, 22, 8,  5, 
    0, 32, 5, 16, 4, 13, 8, 35, 2, 93, 1, 75, 6, 66, 3, 83, 7, 79, 
    3, 54, 8, 89, 2, 83, 1, 80, 5, 91, 6, 65, 4, 72, 0, 52, 7, 94, 
    5, 37, 4, 83, 6, 48, 8, 74, 2, 47, 0, 88, 3, 47, 1, 38, 7, 10, 
    7, 38, 8, 62, 4, 84, 5, 92, 6, 56, 2, 89, 3, 61, 0, 31, 1, 33, 
    3, 50, 6, 97, 5, 51, 4, 74, 7, 46, 2, 74, 8, 33, 1, 72, 0, 66
  };
  const int q9292[] = {
    9, 9, // Number of jobs and machines
    1, 82, 3, 41, 0, 76, 5, 71, 8, 10, 6, 60, 7, 81, 2, 94, 4, 57, 
    3,  8, 7, 25, 1, 70, 2, 43, 0, 67, 4, 37, 6, 27, 8, 81, 5, 36, 
    4, 82, 7, 83, 6, 24, 3, 20, 2, 16, 8, 47, 0, 44, 1, 64, 5, 33, 
    8, 74, 5, 88, 2, 89, 3, 94, 4, 36, 0, 65, 6, 58, 1, 33, 7, 96, 
    0,  9, 7, 57, 5, 89, 2, 56, 3, 31, 8, 78, 1, 83, 4, 89, 6, 93, 
    7, 24, 1, 70, 8, 70, 2, 63, 3, 49, 4, 13, 0, 56, 6,  6, 5, 13, 
    3, 20, 2, 92, 5, 97, 1, 17, 4, 59, 6, 76, 8, 35, 0, 20, 7, 44, 
    6, 86, 5, 97, 4,  8, 3, 51, 1, 55, 7, 10, 8, 81, 0, 96, 2, 58, 
    3, 11, 7, 55, 4, 25, 5, 74, 6,  6, 1, 27, 8, 50, 0, 31, 2, 15
  };
  const int q9293[] = {
    9, 9, // Number of jobs and machines
    2, 35, 5, 89, 7, 83, 0, 22, 3, 93, 8, 88, 1, 56, 4, 93, 6, 81, 
    4, 80, 8, 58, 0, 38, 6, 33, 1, 64, 2, 14, 7, 58, 5, 79, 3,  3, 
    6, 46, 3, 68, 4, 40, 7, 75, 1, 34, 0, 75, 5, 13, 8, 39, 2, 11, 
    2, 15, 6, 12, 1, 78, 8, 86, 5, 74, 7, 38, 3, 29, 4, 59, 0, 83, 
    6, 81, 5, 11, 1, 61, 4,  3, 3, 34, 7,  7, 2, 34, 8,  8, 0, 60, 
    1, 52, 0, 73, 2, 63, 5, 73, 7, 30, 4, 55, 8, 16, 3,  7, 6, 20, 
    6, 93, 5, 14, 7, 71, 1, 11, 2,  7, 4, 27, 3, 23, 0, 63, 8, 96, 
    3, 49, 0, 60, 8, 76, 5, 75, 2, 52, 6, 82, 7, 14, 1,  8, 4, 28, 
    4, 71, 3, 83, 5, 82, 8, 19, 0, 51, 6, 57, 1, 23, 2, 12, 7,  8
  };
  const int q9294[] = {
    9, 9, // Number of jobs and machines
    1, 41, 6, 92, 8, 43, 3, 67, 4, 17, 7,  1, 2, 22, 5, 86, 0, 89, 
    6, 24, 3, 24, 1, 12, 0, 46, 7, 64, 4, 75, 5, 86, 8, 64, 2, 54, 
    5, 65, 0, 53, 7, 82, 8, 59, 2, 14, 6, 25, 4, 80, 1, 17, 3, 91, 
    2, 28, 4, 77, 8, 54, 5, 94, 0, 93, 1, 68, 3, 62, 6, 28, 7, 57, 
    5, 79, 4, 63, 0, 19, 7, 69, 1, 24, 3, 52, 2, 96, 6, 56, 8, 77, 
    1, 42, 7, 36, 2, 22, 4, 72, 0, 97, 8, 57, 3, 43, 5,  9, 6, 54, 
    5, 70, 8, 66, 1, 83, 4, 21, 6, 30, 2, 35, 7, 94, 3, 39, 0, 17, 
    4, 31, 3, 97, 5, 18, 8, 18, 1,  2, 0, 91, 2, 20, 7, 18, 6, 88, 
    3, 44, 5, 97, 0, 28, 7, 64, 4,  3, 2, 33, 6, 90, 8, 66, 1, 25
  };
  const int q9295[] = {
    9, 9, // Number of jobs and machines
    5, 12, 4,  8, 1, 94, 8, 79, 3, 37, 6, 23, 2, 81, 7, 86, 0, 48, 
    6, 88, 5, 28, 2, 73, 1, 33, 8, 79, 0, 98, 3, 41, 4, 71, 7,  2, 
    7, 87, 2, 31, 3, 16, 4, 28, 6, 19, 1, 94, 5, 28, 8, 78, 0, 56, 
    6, 86, 5, 57, 1, 86, 8, 95, 7, 23, 4,  5, 0, 46, 2, 36, 3, 97, 
    6, 20, 8, 92, 3, 61, 0, 23, 4, 91, 5, 50, 1, 66, 2, 81, 7, 48, 
    4, 49, 1, 68, 6, 46, 7, 53, 8,  1, 0, 97, 2, 91, 3, 62, 5,  7, 
    0, 79, 1, 48, 4, 99, 6,  8, 5, 31, 7, 69, 8, 77, 3, 90, 2, 82, 
    1, 38, 7, 36, 6, 63, 0, 76, 3, 77, 4, 92, 5, 20, 2, 23, 8, 51, 
    8, 64, 0, 40, 5, 89, 4, 43, 7, 47, 3, 95, 6, 42, 1, 87, 2, 67
  };
  const int q9296[] = {
    9, 9, // Number of jobs and machines
    2, 76, 1, 87, 5, 81, 8, 13, 6, 88, 0, 36, 7, 45, 3, 44, 4, 35, 
    8, 41, 7, 75, 4, 66, 3, 45, 5, 62, 2, 75, 0, 15, 6, 90, 1, 30, 
    7, 85, 3, 26, 8, 23, 4, 25, 2, 25, 0,  8, 1, 31, 5, 44, 6, 38, 
    7,  6, 4, 35, 6, 60, 5,  4, 8, 26, 3, 52, 1, 74, 2,  2, 0, 48, 
    6, 21, 8, 59, 3,  9, 2, 55, 4, 32, 7, 41, 5,  8, 0,  3, 1, 30, 
    1, 82, 7, 92, 0, 31, 2, 56, 6,  7, 5, 85, 4, 76, 3, 58, 8,  6, 
    5, 16, 8, 57, 6, 80, 0, 38, 1, 42, 4, 30, 3, 40, 2, 27, 7, 11, 
    6, 82, 7, 89, 8, 82, 3, 76, 1, 66, 2, 26, 0, 35, 5,  8, 4, 99, 
    1, 18, 2, 16, 0, 56, 5,  4, 6, 23, 7, 11, 8,  1, 3, 40, 4, 28
  };
  const int q9297[] = {
    9, 9, // Number of jobs and machines
    7, 79, 3, 33, 6, 48, 4, 68, 8, 20, 2, 21, 5, 94, 0, 94, 1, 32, 
    4, 73, 3, 51, 8, 25, 2, 44, 7, 83, 1, 28, 6, 89, 5, 99, 0, 95, 
    0,  2, 5, 69, 1,  9, 8, 38, 3, 32, 4, 97, 6,  7, 7, 63, 2, 51, 
    3, 32, 2, 71, 1, 30, 6, 30, 5,  5, 4, 53, 7, 55, 0, 69, 8, 33, 
    5, 51, 6, 51, 1, 14, 7, 41, 8, 94, 0,  9, 4, 52, 2, 40, 3, 11, 
    4, 63, 0, 56, 7, 48, 3, 67, 8,  6, 2,  1, 6, 54, 1, 59, 5, 17, 
    4, 96, 3, 32, 8, 94, 7,  3, 5, 27, 0, 62, 6,  8, 1, 98, 2, 80, 
    3, 56, 8, 17, 4, 67, 6, 80, 0, 19, 1, 53, 7, 75, 2, 67, 5,  9, 
    0, 49, 2, 11, 4, 93, 5, 41, 8, 26, 6, 67, 1, 28, 3, 30, 7, 91
  };
  const int q9298[] = {
    9, 9, // Number of jobs and machines
    2, 37, 7,  9, 0,  8, 5, 87, 6, 30, 1, 98, 4, 68, 8, 49, 3, 17, 
    0, 37, 3, 34, 6, 32, 1, 80, 7, 50, 8, 53, 5, 36, 4, 68, 2, 68, 
    2, 95, 0, 76, 8, 50, 3, 93, 1,  7, 4, 59, 6,  8, 7, 88, 5, 29, 
    7, 72, 3, 71, 5, 39, 8, 19, 6, 91, 2, 83, 1, 21, 4, 68, 0, 27, 
    0, 27, 6, 95, 1, 87, 8, 16, 2, 20, 5, 89, 4, 43, 3, 71, 7, 60, 
    0, 53, 8, 21, 4, 87, 2, 13, 3, 64, 1, 67, 5, 83, 7,  1, 6,  3, 
    5, 53, 1, 60, 8, 55, 0, 36, 6,  4, 3,  4, 2, 97, 4, 12, 7, 22, 
    0,  4, 4, 35, 8, 59, 7, 24, 1, 57, 5, 66, 2, 11, 3, 95, 6, 98, 
    2, 71, 4, 22, 8, 78, 3, 38, 0, 41, 5, 21, 6, 91, 7, 26, 1, 31
  };
  const int q9299[] = {
    9, 9, // Number of jobs and machines
    8, 23, 1, 73, 3, 92, 4, 29, 6, 20, 7, 79, 0, 84, 5, 92, 2, 86, 
    6, 58, 8, 83, 2, 84, 5, 20, 1, 70, 7, 39, 3, 44, 4, 93, 0, 77, 
    1, 16, 7, 93, 6, 10, 4, 81, 3, 73, 8, 63, 5, 78, 2, 41, 0,  8, 
    5, 30, 1, 43, 4, 50, 6, 62, 0, 37, 8, 65, 2, 54, 7, 39, 3, 81, 
    7, 57, 2, 95, 1, 88, 4, 90, 3, 30, 6, 14, 5, 93, 8,  2, 0, 38, 
    3,  2, 2, 77, 4, 48, 1, 36, 6,  9, 5, 20, 8, 51, 0, 51, 7, 13, 
    3, 91, 8, 20, 2, 28, 0, 78, 7, 33, 5, 66, 6, 60, 1, 10, 4, 43, 
    6, 42, 2, 32, 8, 10, 1, 90, 3, 10, 0, 97, 4, 35, 7, 24, 5, 86, 
    3, 52, 0,  9, 6, 61, 1, 49, 4, 21, 8, 25, 5, 93, 2, 86, 7, 73
  };
  const int q9300[] = {
    9, 9, // Number of jobs and machines
    1, 27, 0, 47, 5, 73, 4, 44, 8, 89, 7,  6, 2, 94, 3, 24, 6, 41, 
    6, 21, 7, 59, 4, 61, 3, 50, 1,  2, 2, 97, 8,  9, 5, 78, 0, 52, 
    6, 61, 2, 47, 1, 36, 8, 96, 3, 39, 0, 69, 7, 21, 4, 36, 5,  8, 
    3, 90, 6, 26, 5, 60, 2, 56, 7, 85, 0, 97, 8, 21, 4, 16, 1, 20, 
    8, 60, 2, 24, 1, 43, 5, 74, 0, 70, 6, 24, 3, 82, 7, 79, 4, 50, 
    0,  3, 1, 65, 2, 33, 5, 20, 7, 53, 6, 73, 3, 32, 4, 51, 8, 99, 
    3, 16, 0, 42, 6, 11, 4, 93, 7, 16, 8, 61, 2,  7, 1, 51, 5, 71, 
    3, 23, 0, 74, 8, 45, 7, 87, 4, 87, 1, 48, 5, 57, 2, 93, 6, 19, 
    0, 63, 7, 58, 5, 95, 4, 38, 6, 48, 8, 57, 1, 66, 2, 40, 3, 58
  };
  const int q9301[] = {
    9, 9, // Number of jobs and machines
    7, 51, 6, 46, 8, 13, 4, 47, 5,  5, 1, 96, 2, 10, 0,  5, 3,  4, 
    7,  9, 0, 20, 1, 35, 4, 80, 5, 43, 8, 50, 2, 14, 6, 39, 3, 84, 
    1, 10, 8, 10, 6, 83, 7, 68, 0, 78, 5,  6, 2, 30, 4, 25, 3, 54, 
    0, 41, 2, 25, 3, 12, 7, 61, 5, 91, 8, 88, 1, 83, 4, 98, 6,  9, 
    5, 67, 4, 80, 7, 90, 3, 67, 0, 97, 2, 63, 8, 62, 1, 21, 6, 48, 
    3, 60, 8, 61, 4, 46, 7, 50, 0, 76, 2, 91, 6, 81, 1, 99, 5,  6, 
    1, 77, 6, 48, 7, 56, 5, 58, 8, 91, 4, 33, 3, 40, 0, 58, 2, 98, 
    7, 58, 4, 85, 5, 16, 6,  3, 3, 85, 2,  1, 1, 46, 8, 22, 0, 45, 
    7, 37, 4,  5, 0, 57, 3,  2, 6,  7, 2, 36, 1, 72, 5, 10, 8, 44
  };
  const int q9302[] = {
    9, 9, // Number of jobs and machines
    3, 15, 2, 82, 0, 28, 7, 85, 5, 47, 4, 86, 6,  4, 8, 43, 1, 80, 
    1, 62, 4, 88, 8, 67, 2, 76, 6, 76, 5,  1, 7, 38, 3,  9, 0, 81, 
    4, 67, 0, 69, 3, 23, 1,  1, 7, 80, 6,  3, 5, 20, 2,  7, 8, 85, 
    0, 77, 2, 36, 8, 72, 1, 81, 4, 42, 3, 40, 7, 31, 6, 16, 5, 36, 
    2, 84, 3, 64, 1, 43, 6, 10, 4, 82, 8, 44, 5, 10, 0, 36, 7, 14, 
    3, 40, 4, 46, 5,  6, 6, 98, 2, 79, 7, 34, 0, 42, 1, 55, 8,  9, 
    7, 33, 6, 43, 2, 56, 4, 52, 8, 65, 0, 58, 5, 73, 3, 33, 1, 85, 
    6, 40, 2, 99, 4,  9, 0, 93, 8, 87, 1,  1, 5, 40, 7, 22, 3, 63, 
    8, 74, 2, 69, 4, 82, 5, 86, 0, 13, 7, 79, 3, 15, 6, 29, 1, 88
  };
  const int q9303[] = {
    9, 9, // Number of jobs and machines
    6, 15, 3, 59, 4, 90, 7, 83, 1,  2, 8, 58, 0, 97, 5, 79, 2, 99, 
    3, 53, 1, 98, 4, 84, 8,  4, 5,  7, 7, 55, 6, 32, 0, 34, 2, 21, 
    4, 37, 7, 50, 8, 92, 1, 68, 3, 21, 0, 31, 5, 29, 2, 71, 6, 49, 
    7, 90, 4, 22, 8, 13, 6, 99, 3, 12, 1,  7, 0, 38, 5, 10, 2, 90, 
    3, 88, 6, 16, 8, 96, 5,  8, 2, 49, 4,  3, 0, 56, 7, 96, 1, 85, 
    3, 51, 8,  5, 4, 99, 7, 64, 0, 57, 6, 24, 5, 24, 2, 32, 1, 96, 
    7, 50, 5, 90, 6, 35, 3, 93, 8, 60, 1, 89, 4, 31, 2, 17, 0, 25, 
    7,  9, 2, 64, 5, 52, 4, 68, 0, 13, 1, 74, 3, 45, 8, 67, 6, 26, 
    8, 95, 1, 65, 5, 25, 2, 57, 4, 12, 7, 65, 3, 43, 6,  9, 0, 97
  };
  const int q9304[] = {
    9, 9, // Number of jobs and machines
    6, 75, 7, 33, 4, 57, 8, 75, 5, 82, 1, 62, 2,  4, 3, 14, 0, 29, 
    2, 37, 1, 63, 7, 60, 3, 22, 5, 17, 8, 27, 4, 19, 6, 49, 0, 89, 
    8, 14, 2, 83, 7, 72, 0, 14, 3, 48, 1, 89, 4,  3, 6, 57, 5, 63, 
    1, 81, 5, 79, 2, 82, 3, 32, 0, 81, 6, 71, 4, 81, 8, 45, 7, 52, 
    8, 76, 0, 51, 2, 40, 4, 77, 7, 91, 6, 88, 5, 23, 1, 10, 3, 10, 
    4, 76, 7, 35, 5, 46, 0, 12, 2, 99, 6, 37, 3, 70, 1, 41, 8, 42, 
    2,  7, 7, 83, 8, 74, 3, 83, 0, 51, 1, 94, 5, 94, 6, 95, 4, 87, 
    3,  7, 4, 39, 6, 55, 1,  8, 2, 26, 7, 44, 0, 18, 5, 23, 8, 13, 
    7, 77, 4, 45, 6, 73, 2, 80, 1, 44, 5, 43, 3, 94, 8, 48, 0, 48
  };
  const int q9305[] = {
    9, 9, // Number of jobs and machines
    7, 90, 3, 14, 8, 43, 6, 13, 5, 74, 1, 95, 2,  2, 0, 47, 4, 93, 
    8, 92, 3,  1, 1, 86, 6, 14, 2, 30, 5,  1, 7, 85, 4, 14, 0, 60, 
    0, 20, 2, 33, 3, 22, 4, 51, 5, 33, 1, 61, 7, 23, 6, 45, 8, 21, 
    3, 59, 0, 95, 2, 67, 1, 32, 8, 39, 5, 13, 4, 34, 7, 14, 6, 28, 
    5, 36, 6, 89, 8, 52, 0, 78, 3, 91, 7, 77, 1, 77, 4, 71, 2, 81, 
    3, 56, 7, 32, 8, 62, 6, 56, 5, 16, 0, 45, 1, 34, 4, 93, 2, 58, 
    6, 35, 1, 73, 4, 52, 0, 87, 7, 50, 8, 51, 3, 39, 2, 69, 5, 60, 
    1, 99, 7, 42, 2, 80, 5, 53, 3, 35, 8, 68, 6,  5, 4, 55, 0, 32, 
    8, 48, 7, 98, 1, 35, 3, 45, 2, 69, 5, 49, 0, 28, 6, 94, 4,  3
  };
  const int q9306[] = {
    9, 9, // Number of jobs and machines
    0, 44, 7, 26, 6, 92, 8, 28, 4, 96, 1, 43, 3, 24, 2, 24, 5, 86, 
    3, 99, 2, 24, 6, 41, 7, 68, 4, 97, 1, 73, 8, 74, 5, 54, 0, 22, 
    4, 42, 2, 23, 7, 16, 0, 17, 8, 65, 5, 43, 6, 18, 1, 94, 3,  2, 
    8, 69, 4, 93, 5, 41, 3, 88, 7, 53, 1, 75, 0, 95, 2, 63, 6, 76, 
    8, 56, 6, 72, 2, 75, 5, 49, 3,  5, 4, 44, 1, 67, 7, 61, 0, 73, 
    6, 16, 2, 84, 1, 19, 5, 58, 7,  4, 8, 74, 3, 60, 4, 41, 0, 39, 
    7, 13, 6, 26, 4, 65, 8, 30, 2, 97, 5, 41, 1, 86, 0, 44, 3, 85, 
    8, 55, 5, 71, 4, 30, 3, 34, 6, 62, 2, 78, 1, 80, 7,  4, 0, 86, 
    4, 81, 7,  1, 5, 12, 8, 59, 1, 40, 6, 74, 0, 46, 2, 72, 3, 60
  };
  const int q9307[] = {
    9, 9, // Number of jobs and machines
    0,  7, 5, 67, 2, 93, 8, 90, 4, 35, 7, 75, 1, 60, 3, 76, 6, 74, 
    6, 14, 5, 14, 0, 84, 8, 63, 2, 26, 7, 91, 3, 14, 1,  5, 4, 39, 
    0, 39, 5, 41, 2, 58, 1, 38, 7, 93, 3, 58, 6, 31, 4, 83, 8, 13, 
    3, 89, 6, 28, 5, 28, 2, 16, 4,  9, 7, 50, 1, 76, 8, 20, 0, 38, 
    8, 55, 7, 29, 5, 73, 0, 78, 4, 99, 2, 22, 6, 79, 3,  5, 1, 67, 
    7, 90, 4, 29, 5, 89, 2, 13, 0, 42, 8, 74, 1, 35, 6, 68, 3, 27, 
    3, 43, 8, 99, 0,  9, 4, 50, 7, 95, 6,  4, 5, 74, 2, 72, 1, 80, 
    1, 30, 0, 15, 4, 22, 3, 26, 8, 62, 2, 65, 5, 22, 7, 58, 6, 45, 
    5, 57, 3, 30, 8, 83, 1, 80, 2, 85, 6, 42, 4, 77, 0, 12, 7, 58
  };
  const int q9308[] = {
    9, 9, // Number of jobs and machines
    1, 37, 3,  9, 8, 64, 5, 31, 7, 42, 0, 61, 2, 89, 4, 80, 6,  2, 
    2, 22, 1, 29, 4, 51, 5, 58, 6, 12, 7, 57, 8, 63, 0,  2, 3, 20, 
    7, 13, 6, 10, 1, 93, 2, 11, 4, 26, 8, 94, 0, 66, 3,  2, 5, 49, 
    7,  6, 6, 42, 3, 94, 4, 74, 1, 96, 8, 18, 2, 38, 5, 10, 0, 35, 
    5, 53, 3, 15, 0, 57, 4, 16, 1, 52, 6, 37, 7,  4, 8, 99, 2,  7, 
    1, 78, 5, 24, 4, 25, 0, 42, 7, 25, 6, 62, 8, 75, 2, 71, 3, 46, 
    3, 25, 2, 69, 7, 32, 4,  9, 6, 32, 8, 99, 5, 50, 1, 67, 0, 34, 
    5,  5, 6, 29, 7, 76, 3, 16, 1, 81, 0, 66, 8, 89, 2,  1, 4, 43, 
    4, 98, 5, 82, 7, 20, 1, 72, 2,  4, 3, 95, 8, 80, 6, 31, 0, 34
  };
  const int q9309[] = {
    9, 9, // Number of jobs and machines
    3, 76, 0, 23, 6, 45, 8, 75, 2, 91, 5, 42, 4, 93, 1,  3, 7, 29, 
    7, 79, 6, 77, 3, 40, 1, 22, 0, 80, 5, 55, 4, 64, 2, 87, 8, 75, 
    1, 62, 0, 81, 6, 94, 8, 81, 7, 23, 4, 42, 5, 49, 2, 34, 3, 65, 
    1, 35, 8,  2, 3, 67, 5, 59, 2, 41, 4, 29, 0, 94, 6, 97, 7, 15, 
    3, 66, 7, 62, 5,  4, 6, 42, 4, 60, 0, 28, 8, 46, 1, 41, 2, 47, 
    0, 81, 1, 23, 2, 50, 4, 79, 3, 45, 8, 85, 5, 46, 6, 66, 7, 60, 
    5,  1, 2, 18, 7, 59, 1, 35, 0, 38, 3, 36, 6, 38, 4,  5, 8, 88, 
    7, 27, 8, 49, 5, 10, 0, 68, 6, 79, 3, 81, 1, 91, 2, 57, 4, 86, 
    3, 82, 0, 89, 2, 41, 4, 25, 8,  5, 5, 99, 7, 26, 1, 42, 6, 36
  };
  const int q9310[] = {
    9, 9, // Number of jobs and machines
    4,  6, 0, 36, 1, 66, 7,  4, 2, 19, 5, 71, 3, 35, 8, 18, 6, 41, 
    0, 72, 2, 27, 4, 97, 5, 21, 1, 51, 6, 42, 7, 94, 3, 15, 8, 28, 
    0, 41, 5, 33, 4, 72, 1, 53, 8, 30, 2, 22, 7, 70, 6, 74, 3, 94, 
    0, 34, 8, 37, 2, 38, 6, 94, 1, 71, 3, 86, 4,  2, 7, 99, 5, 51, 
    0, 37, 7, 74, 3, 16, 2, 40, 8, 33, 6, 44, 5, 98, 1, 14, 4, 75, 
    7, 75, 6, 84, 8, 85, 3, 61, 4, 38, 2, 17, 1, 12, 0,  2, 5, 87, 
    5, 20, 7, 54, 3, 84, 6,  1, 1, 88, 4, 45, 2,  8, 0, 71, 8, 92, 
    5, 26, 6,  6, 8, 76, 1, 57, 7, 36, 0, 75, 4, 23, 3, 94, 2, 27, 
    2,  1, 8, 92, 0, 83, 5, 65, 7, 20, 6, 47, 1, 20, 3, 61, 4, 13
  };
  const int q9311[] = {
    9, 9, // Number of jobs and machines
    5, 49, 2, 11, 7, 23, 0, 66, 1, 10, 8, 38, 3, 25, 6, 42, 4, 87, 
    7, 49, 0, 45, 1,  6, 5, 81, 2, 23, 6, 26, 4,  8, 8, 57, 3, 19, 
    5, 10, 4, 74, 2, 25, 0, 57, 6, 57, 3, 96, 8, 31, 7, 13, 1, 87, 
    1, 89, 4, 69, 5, 23, 0, 95, 6, 27, 8, 84, 7, 38, 2, 16, 3, 60, 
    7, 82, 2, 58, 5, 42, 0, 95, 4, 27, 6, 11, 1, 45, 8, 75, 3, 16, 
    5, 11, 6, 33, 2, 85, 7, 92, 4, 30, 1, 95, 3, 12, 0, 71, 8, 80, 
    3, 43, 8,  3, 7,  8, 0, 85, 2, 26, 5, 26, 1, 39, 6, 42, 4, 28, 
    3, 49, 8, 42, 7, 87, 6, 71, 4, 96, 2,  7, 1,  1, 5, 77, 0, 42, 
    0, 83, 3, 77, 8, 83, 4, 69, 7, 83, 5,  6, 6, 48, 1, 23, 2, 47
  };
  const int q9312[] = {
    9, 9, // Number of jobs and machines
    4, 11, 8, 99, 5, 32, 2, 52, 1, 56, 7, 62, 0, 27, 6, 15, 3, 34, 
    0, 44, 6, 44, 3, 18, 8, 54, 1, 65, 4, 43, 5, 13, 2, 46, 7, 76, 
    1, 82, 6,  4, 5, 19, 8, 57, 0, 54, 7, 24, 4, 49, 2, 70, 3, 75, 
    1,  5, 0, 57, 4, 29, 7, 82, 5, 20, 2, 83, 8, 45, 3, 14, 6, 82, 
    8, 33, 7, 24, 0, 28, 4, 82, 5, 76, 3, 79, 6, 85, 2, 44, 1, 35, 
    2, 95, 4, 81, 6,  7, 8, 81, 7, 38, 3, 53, 0, 29, 1, 28, 5, 89, 
    1, 78, 0, 63, 4, 31, 7,  7, 5, 72, 2, 70, 6, 24, 8, 84, 3, 96, 
    2, 19, 1, 98, 8,  3, 6, 24, 5, 98, 3, 41, 4, 48, 7, 62, 0, 88, 
    7, 55, 5, 24, 8, 50, 3, 16, 1, 32, 0, 24, 2, 50, 4, 68, 6, 39
  };
  const int q9313[] = {
    9, 9, // Number of jobs and machines
    3, 32, 7, 47, 5, 63, 2, 77, 6, 49, 8, 24, 1, 70, 4, 42, 0, 19, 
    4, 96, 5, 75, 2, 10, 1, 62, 3, 98, 0, 67, 6, 36, 8, 81, 7, 93, 
    6, 25, 2,  9, 5, 54, 3, 86, 8, 57, 4,  6, 7, 30, 0, 88, 1, 40, 
    5, 60, 8, 57, 6, 69, 3, 62, 4, 80, 7, 85, 0, 66, 1, 86, 2, 65, 
    0, 38, 4, 29, 5,  2, 3,  4, 8, 59, 2, 50, 6, 38, 1,  2, 7, 65, 
    2, 98, 1, 72, 7,  2, 3, 34, 5, 82, 0, 35, 4, 41, 8, 63, 6, 24, 
    3, 98, 2, 60, 7, 69, 6, 65, 5, 14, 4, 64, 0, 64, 1, 65, 8, 24, 
    5, 61, 6, 41, 0, 83, 2,  3, 4,  6, 1, 11, 7,  5, 3, 40, 8, 24, 
    5, 67, 7, 79, 4, 16, 1, 22, 3, 33, 2, 25, 8,  9, 0, 86, 6, 23
  };
  const int q9314[] = {
    9, 9, // Number of jobs and machines
    0, 67, 8, 75, 7, 20, 1, 31, 5, 48, 6, 71, 4, 46, 2, 68, 3, 89, 
    6, 19, 7, 13, 2, 37, 8, 97, 0, 29, 4, 31, 1, 52, 5, 88, 3, 92, 
    4,  9, 2,  2, 5, 27, 8, 75, 7, 22, 6, 44, 3, 67, 0, 25, 1, 68, 
    4, 67, 7, 21, 5, 54, 2, 61, 0,  5, 1, 66, 8, 14, 3, 67, 6, 26, 
    8, 17, 1, 50, 5, 61, 0, 64, 3, 94, 6, 54, 7, 30, 4,  1, 2, 16, 
    4, 99, 5, 36, 7, 92, 1, 25, 0, 45, 2, 89, 3, 72, 8, 78, 6, 47, 
    8, 28, 2, 65, 0, 29, 4, 39, 7, 65, 3, 76, 1, 97, 5, 47, 6, 50, 
    8, 11, 3,  5, 5, 27, 4, 17, 6, 75, 1,  9, 2, 12, 0, 84, 7, 54, 
    6, 91, 2, 24, 0, 33, 5, 88, 7, 35, 1, 31, 8,  5, 4, 13, 3, 12
  };
  const int q9315[] = {
    9, 9, // Number of jobs and machines
    1, 70, 7, 13, 8, 52, 3, 65, 6, 49, 4, 52, 0, 69, 5, 93, 2, 28, 
    5, 70, 8, 16, 6, 41, 0,  3, 3, 58, 2, 31, 7, 99, 1, 49, 4, 52, 
    4, 42, 0, 42, 6, 43, 2, 36, 7, 60, 1,  7, 3, 66, 8, 47, 5, 66, 
    6, 72, 1, 16, 7, 49, 2, 15, 5, 90, 3,  8, 4, 76, 0, 11, 8, 83, 
    5, 90, 8, 96, 1, 30, 2,  7, 6, 17, 0,  2, 7, 87, 4, 26, 3, 31, 
    1, 68, 8, 29, 6, 43, 3, 56, 2,  2, 7, 80, 4, 59, 5, 28, 0, 95, 
    1, 63, 3, 57, 6, 65, 8, 89, 5, 27, 2, 46, 4, 61, 0, 77, 7, 45, 
    0, 77, 1, 26, 3, 11, 7, 44, 8,  7, 6, 44, 5, 43, 4, 39, 2, 69, 
    4, 54, 2, 54, 7, 41, 0, 40, 3, 43, 6, 33, 8, 23, 5, 66, 1, 30
  };
  const int q9316[] = {
    9, 9, // Number of jobs and machines
    1,  9, 3, 47, 8, 30, 0, 86, 4,  5, 6, 19, 5, 15, 2, 67, 7, 56, 
    7, 22, 1,  3, 6, 26, 3, 92, 2, 61, 4, 29, 0, 21, 8, 52, 5,  4, 
    1, 72, 3, 78, 8, 23, 4, 35, 5, 57, 7, 94, 2, 38, 0, 45, 6, 76, 
    4, 83, 3, 54, 2, 85, 7, 27, 6, 21, 1, 67, 5, 44, 8, 67, 0, 77, 
    0, 55, 1, 77, 5, 88, 7, 44, 6, 61, 8, 36, 2, 85, 3, 28, 4, 96, 
    6, 33, 3, 82, 2, 16, 1, 95, 7, 37, 5, 70, 0, 45, 8, 74, 4, 21, 
    4, 43, 5, 69, 1, 25, 0, 57, 7,  1, 2, 70, 3, 73, 6, 92, 8, 77, 
    3, 37, 4, 60, 2, 14, 7, 16, 5, 22, 6,  3, 1, 48, 0, 86, 8, 85, 
    7, 94, 5, 99, 1, 94, 8, 84, 3, 15, 4, 73, 2, 75, 6, 41, 0, 19
  };
  const int q9317[] = {
    9, 9, // Number of jobs and machines
    6, 85, 1, 52, 3, 24, 8, 52, 4,  8, 7, 54, 0, 83, 2, 87, 5, 52, 
    1, 49, 5, 50, 2, 95, 4, 86, 7, 45, 0, 15, 8, 80, 3, 43, 6,  3, 
    4, 69, 6, 46, 5, 69, 0, 76, 8, 91, 1, 27, 2, 19, 3,  8, 7, 43, 
    7,  7, 4, 79, 0, 59, 5,  5, 1, 22, 2, 99, 6, 65, 3, 72, 8, 77, 
    6,  9, 4, 49, 8, 84, 2, 29, 5, 86, 7, 50, 1, 67, 0, 12, 3, 17, 
    5, 65, 8, 46, 1, 67, 3, 78, 4, 65, 7, 88, 6, 10, 2, 75, 0, 80, 
    4, 97, 2, 48, 5, 64, 0, 95, 6, 65, 7, 19, 3, 69, 1, 76, 8, 28, 
    4, 31, 7, 44, 1, 96, 3, 60, 2, 66, 6, 31, 8, 99, 0, 58, 5, 21, 
    0, 81, 8, 35, 5, 52, 3, 42, 6, 90, 4, 85, 2, 45, 7, 46, 1, 83
  };
  const int q9318[] = {
    9, 9, // Number of jobs and machines
    6, 92, 1,  1, 7, 52, 3, 60, 0, 21, 2,  2, 5,  6, 4, 61, 8, 49, 
    2, 83, 7, 83, 0, 17, 5, 99, 3, 50, 6, 20, 4, 12, 1, 16, 8, 29, 
    7, 90, 1, 97, 8, 37, 4, 67, 3, 57, 6, 50, 0, 66, 2, 44, 5,  7, 
    0, 25, 6, 66, 8, 16, 3, 85, 2, 36, 1, 72, 4, 99, 5, 77, 7, 43, 
    8,  4, 0, 31, 3, 94, 6, 15, 4, 99, 1, 71, 5, 45, 7, 16, 2, 85, 
    2, 75, 1, 79, 4, 14, 3, 17, 8, 93, 5, 47, 7, 97, 6, 33, 0, 18, 
    4, 94, 0, 36, 3, 20, 2, 85, 1, 78, 5, 75, 8, 85, 7, 53, 6, 59, 
    3, 73, 2, 78, 5, 66, 6, 71, 8, 11, 0, 75, 4, 55, 1,  7, 7, 84, 
    4, 38, 3, 96, 2, 43, 7, 64, 5, 25, 6,  7, 0, 99, 1, 91, 8, 65
  };
  const int q9319[] = {
    9, 9, // Number of jobs and machines
    4, 84, 1, 40, 6, 97, 7, 53, 8, 34, 3, 75, 5, 49, 2,  2, 0, 74, 
    7, 33, 2, 11, 4, 99, 6,  6, 8, 30, 0, 52, 1, 47, 3, 69, 5, 35, 
    2, 17, 6, 48, 0, 95, 5,  3, 7, 73, 1, 27, 3, 12, 8, 72, 4, 38, 
    8, 72, 1, 46, 6, 90, 2, 56, 3, 16, 0, 12, 4, 47, 7, 82, 5, 92, 
    0, 68, 3, 59, 8, 35, 4, 79, 5, 84, 2, 25, 1, 85, 7,  4, 6, 10, 
    1, 23, 8, 85, 2, 80, 6, 43, 3, 47, 7,  7, 0, 22, 4, 86, 5, 41, 
    6, 12, 7, 14, 0, 96, 2, 28, 8, 43, 4, 76, 5, 31, 1, 52, 3, 91, 
    1, 11, 2, 10, 3, 22, 7, 30, 8, 57, 4,  4, 6, 69, 0, 24, 5, 15, 
    2, 87, 5, 62, 1, 50, 7, 90, 8, 88, 3,  5, 0, 15, 6, 37, 4, 42
  };
  const int q9320[] = {
    9, 9, // Number of jobs and machines
    6, 33, 8, 13, 1, 88, 3, 86, 2, 49, 0, 52, 7, 41, 4,  6, 5, 26, 
    0, 80, 7, 25, 5, 87, 4, 40, 6, 83, 2, 42, 1, 31, 8, 97, 3, 84, 
    0, 47, 5, 68, 4, 71, 8, 63, 1, 76, 3, 43, 2, 39, 6,  2, 7, 69, 
    3, 20, 8, 17, 7, 52, 5, 34, 1,  6, 4, 44, 2,  6, 0, 86, 6, 73, 
    4, 38, 8, 44, 0, 15, 2, 77, 1, 62, 6, 37, 5, 16, 7, 97, 3, 50, 
    7, 19, 0, 32, 6, 36, 3, 77, 5,  9, 1, 26, 8, 30, 4, 36, 2, 63, 
    5, 24, 4, 20, 8, 49, 7, 13, 1, 67, 3, 86, 2, 44, 6, 30, 0, 69, 
    6, 98, 0, 68, 7, 50, 2, 27, 1, 63, 4, 82, 3, 11, 5, 25, 8, 22, 
    1, 53, 3, 56, 4, 33, 0, 72, 2, 82, 7, 48, 8, 33, 6,  1, 5, 90
  };
  const int q9321[] = {
    9, 9, // Number of jobs and machines
    1, 88, 3, 81, 6,  5, 4,  5, 5, 63, 7, 46, 8, 91, 2, 53, 0, 72, 
    3, 36, 5, 28, 2, 77, 0, 69, 4, 13, 1, 34, 8, 82, 6, 21, 7,  8, 
    2, 90, 4, 73, 3, 91, 5, 30, 8, 87, 6,  8, 0, 69, 7, 89, 1, 86, 
    4, 13, 0, 93, 6, 21, 1, 38, 8, 76, 2, 37, 3, 34, 7, 75, 5, 54, 
    7, 54, 6, 64, 0, 37, 4, 13, 1,  9, 8,  2, 2, 27, 3, 13, 5, 89, 
    0, 45, 7, 88, 3, 44, 1, 27, 5, 47, 2, 43, 6, 55, 8, 52, 4,  6, 
    5, 96, 2, 36, 8, 79, 0, 52, 1, 14, 7, 25, 3, 74, 6, 32, 4, 34, 
    7, 89, 6, 26, 0, 75, 5, 24, 2, 43, 4, 66, 1, 28, 3, 77, 8, 46, 
    2, 91, 0, 79, 4, 53, 6, 36, 1, 17, 8, 52, 3, 36, 7, 54, 5, 88
  };
  const int q9322[] = {
    9, 9, // Number of jobs and machines
    8, 23, 2, 20, 3, 66, 0, 86, 7, 18, 4, 33, 5, 73, 1, 11, 6, 77, 
    5, 42, 7, 84, 0, 30, 4, 76, 3, 57, 6, 56, 2, 52, 8,  6, 1, 11, 
    6, 25, 0, 11, 2, 71, 5, 66, 3, 26, 8, 55, 7, 37, 4, 25, 1, 43, 
    7, 27, 2, 51, 4,  3, 1, 69, 3, 33, 6,  3, 5, 48, 0, 17, 8, 46, 
    3, 15, 2, 48, 0, 49, 7, 69, 1, 84, 4, 38, 8, 46, 5, 29, 6, 74, 
    6, 37, 3, 66, 1, 25, 4, 30, 2, 85, 0, 19, 7, 81, 5, 38, 8, 56, 
    5, 41, 8, 34, 0,  8, 3, 27, 7, 35, 1, 88, 6, 78, 2, 59, 4, 90, 
    8, 70, 5,  5, 0, 31, 3, 44, 7, 94, 4, 47, 6, 47, 1, 68, 2, 28, 
    8, 37, 5,  3, 2, 37, 7, 46, 4, 20, 6, 16, 1, 54, 3, 39, 0, 19
  };
  const int q9323[] = {
    9, 9, // Number of jobs and machines
    7,  1, 5, 85, 6, 23, 4, 93, 0,  9, 3, 29, 1, 59, 2, 23, 8, 27, 
    1, 39, 2, 43, 3, 45, 5, 17, 7, 51, 6, 33, 0, 34, 8, 52, 4, 52, 
    8,  7, 0, 44, 7, 23, 4, 98, 3, 56, 6, 50, 2, 76, 1, 41, 5, 70, 
    8, 53, 0,  2, 6,  7, 4,  6, 5, 35, 3, 63, 7, 91, 1, 81, 2, 30, 
    4, 53, 0, 37, 5,  9, 8, 98, 2, 29, 1, 77, 7, 42, 6, 86, 3, 56, 
    4, 62, 6, 50, 0, 59, 1, 96, 8, 66, 7, 77, 2, 61, 5, 43, 3, 89, 
    0, 83, 5, 86, 3, 23, 6, 98, 1, 69, 8, 44, 4,  7, 2, 44, 7, 14, 
    2, 13, 5, 41, 6, 69, 1, 84, 4, 39, 0, 22, 7, 44, 8, 90, 3, 91, 
    0, 88, 5, 40, 3, 23, 7, 79, 2, 78, 6, 24, 8, 26, 1, 65, 4, 92
  };
  const int q9324[] = {
    9, 9, // Number of jobs and machines
    5, 37, 3, 65, 1, 23, 6, 77, 0, 52, 4, 17, 7, 49, 8, 53, 2, 39, 
    0, 80, 1, 47, 2, 76, 4, 59, 8, 88, 7, 45, 5, 64, 6, 25, 3, 50, 
    8, 20, 3, 68, 4, 33, 0, 50, 7, 92, 5, 60, 1, 25, 2,  2, 6, 34, 
    1, 97, 3, 28, 7, 11, 6, 25, 5, 24, 4, 22, 8, 17, 0, 12, 2, 28, 
    6,  5, 3, 73, 8, 89, 0, 39, 1, 56, 4, 56, 5, 37, 7, 16, 2, 56, 
    0, 10, 1, 75, 2, 70, 6, 34, 8, 21, 5,  3, 7, 24, 3, 30, 4, 68, 
    7,  2, 1,  1, 4, 57, 3, 85, 5, 97, 2,  3, 8, 73, 6, 88, 0, 66, 
    5, 52, 6, 90, 1,  3, 4, 67, 0, 90, 8, 83, 2, 49, 3, 52, 7, 59, 
    5, 27, 0, 53, 2, 87, 3, 24, 6, 30, 7, 68, 8, 16, 4, 92, 1, 52
  };
  const int q9325[] = {
    9, 9, // Number of jobs and machines
    1, 97, 7, 96, 3, 86, 5, 43, 4, 18, 2, 77, 8, 33, 0, 45, 6, 39, 
    8, 18, 7, 42, 4, 12, 6, 82, 1,  5, 5, 78, 3, 68, 2, 32, 0, 60, 
    2, 34, 5, 99, 6, 26, 1, 10, 4, 24, 8, 26, 7, 75, 3, 19, 0, 66, 
    1, 16, 7, 93, 5, 98, 0, 18, 6, 69, 4, 32, 8, 36, 2, 31, 3, 49, 
    1, 97, 6, 33, 2, 74, 5, 78, 8,  8, 4, 12, 3, 82, 0, 10, 7, 90, 
    5, 47, 4, 20, 1, 42, 3, 90, 0, 37, 6, 81, 8,  2, 2, 47, 7, 72, 
    1, 79, 0, 82, 4, 61, 3, 40, 8, 47, 5, 70, 6, 40, 7,  5, 2, 91, 
    0, 44, 8, 27, 4, 96, 1, 15, 6, 95, 5, 76, 7, 33, 3, 47, 2, 55, 
    6,  1, 8, 45, 1, 51, 0, 26, 3, 79, 7, 44, 5, 73, 2, 49, 4, 90
  };
  const int q9326[] = {
    9, 9, // Number of jobs and machines
    2, 85, 5, 54, 0, 55, 6, 39, 4,  7, 3, 20, 8, 63, 7, 62, 1, 26, 
    8, 57, 1, 87, 5, 46, 6, 90, 7, 66, 3, 26, 2, 62, 0,  8, 4,  3, 
    5, 42, 6, 35, 2,  8, 3, 79, 0, 26, 7, 40, 1, 78, 4, 11, 8,  3, 
    1,  8, 7, 71, 6, 41, 5, 64, 4, 11, 2, 52, 8, 58, 0, 69, 3, 28, 
    4, 26, 8, 59, 3, 48, 1,  9, 7, 74, 5, 22, 6, 70, 0,  3, 2, 68, 
    3, 46, 7, 85, 6, 73, 5, 40, 1, 48, 0, 53, 2, 51, 8, 61, 4, 14, 
    7, 31, 4,  5, 6,  7, 5, 54, 2, 39, 3, 20, 0, 12, 1, 41, 8, 97, 
    5, 14, 3, 90, 0, 20, 4, 99, 6, 94, 7, 60, 2, 67, 1, 42, 8, 60, 
    5,  5, 8, 16, 2,  8, 4, 54, 7, 27, 0,  3, 3, 63, 6, 20, 1, 16
  };
  const int q9327[] = {
    9, 9, // Number of jobs and machines
    2, 15, 0, 64, 1, 38, 8, 31, 7, 73, 5, 78, 4, 18, 6, 14, 3,  3, 
    7, 81, 3, 98, 2, 92, 1, 87, 8, 85, 0, 95, 4, 82, 6, 71, 5, 61, 
    7, 78, 0, 90, 5, 38, 2, 69, 3, 41, 1,  9, 6, 97, 4, 40, 8, 36, 
    2, 87, 8, 52, 1, 29, 6, 68, 3, 66, 5, 43, 7, 10, 0, 36, 4, 63, 
    2, 76, 7, 81, 4,  2, 5, 36, 0, 16, 8, 27, 1, 94, 3, 34, 6, 65, 
    7, 14, 8, 46, 3, 81, 6, 30, 5, 21, 0,  5, 4, 48, 1,  9, 2, 71, 
    7, 68, 6, 24, 5, 59, 2, 53, 4, 76, 0, 84, 8, 15, 1, 79, 3, 61, 
    3, 71, 1, 47, 5, 73, 4, 69, 7, 76, 6, 10, 0,  4, 8, 97, 2, 69, 
    4, 74, 1, 11, 2, 63, 5, 52, 6, 75, 0, 46, 7, 30, 8, 46, 3, 61
  };
  const int q9328[] = {
    9, 9, // Number of jobs and machines
    0, 88, 1, 11, 6, 91, 5, 11, 3, 75, 7, 13, 2, 77, 8, 40, 4, 16, 
    5, 67, 4, 64, 8,  7, 3, 57, 7, 12, 1, 75, 2, 70, 0, 92, 6, 25, 
    4, 75, 3, 37, 0, 60, 6, 35, 1, 93, 5, 83, 2, 19, 8, 25, 7,  7, 
    0, 32, 2,  9, 8, 44, 1, 30, 5,  9, 7, 64, 3, 40, 6, 28, 4, 62, 
    1, 31, 5, 60, 8, 12, 4, 17, 0, 16, 3, 20, 7,  4, 6, 54, 2,  1, 
    1, 48, 7, 46, 4, 28, 3, 44, 2, 50, 6, 12, 5, 30, 8, 57, 0,  1, 
    1, 12, 0, 44, 6,  3, 8, 14, 7,  1, 5, 94, 3, 43, 4, 99, 2, 45, 
    5, 61, 0, 68, 3, 14, 7, 47, 8, 68, 6, 91, 1, 85, 2,  9, 4, 18, 
    2, 60, 6, 68, 8, 68, 4, 36, 3, 25, 1, 76, 5, 61, 7, 83, 0,  7
  };
  const int q9329[] = {
    9, 9, // Number of jobs and machines
    8, 41, 4, 33, 1, 12, 6, 97, 7, 58, 5, 65, 3, 73, 0, 44, 2, 30, 
    0, 81, 3, 57, 2, 49, 1, 75, 4, 85, 5,  8, 7, 29, 6, 44, 8, 25, 
    0, 30, 2, 34, 1, 68, 7, 65, 6,  6, 5, 25, 8, 60, 4, 57, 3, 70, 
    4, 78, 2, 38, 6, 70, 8, 24, 3,  7, 1, 53, 0, 88, 7, 48, 5,  4, 
    0, 88, 8, 62, 5, 17, 1, 87, 2, 44, 7, 10, 6, 17, 3, 72, 4, 47, 
    7, 23, 8,  5, 1, 22, 0, 63, 2, 85, 4, 92, 3, 56, 5, 77, 6, 60, 
    3, 64, 2,  5, 4, 38, 1, 44, 8, 61, 6, 16, 7,  9, 5, 30, 0, 44, 
    6, 47, 0, 12, 1, 29, 2, 87, 5, 74, 4, 64, 8, 99, 3, 82, 7, 34, 
    2, 33, 3, 70, 5, 44, 1,  4, 7, 48, 8, 47, 6, 80, 4, 32, 0, 51
  };
  const int q9330[] = {
    9, 9, // Number of jobs and machines
    0, 87, 8, 35, 7, 90, 5,  9, 1, 15, 3, 96, 2,  5, 6, 18, 4, 61, 
    8,  3, 1,  8, 2, 13, 0, 46, 7, 12, 4,  6, 3,  5, 5, 39, 6, 55, 
    4, 11, 7, 29, 2, 87, 5, 47, 1, 89, 3, 47, 6, 55, 0, 13, 8, 32, 
    4, 86, 2, 55, 3, 18, 8,  8, 7, 13, 1, 31, 5, 18, 6, 13, 0, 31, 
    0, 48, 6,  3, 3, 37, 7, 14, 2, 26, 4, 31, 8, 45, 5, 44, 1, 13, 
    4,  6, 7, 42, 1, 43, 6, 32, 3, 21, 2, 27, 0, 38, 8, 93, 5, 45, 
    5, 69, 8, 93, 7, 32, 2, 90, 6, 63, 0, 98, 4, 96, 3, 92, 1, 99, 
    5, 64, 0, 15, 7, 84, 2, 94, 4, 30, 1, 88, 6, 27, 8, 65, 3, 32, 
    1,  4, 3, 89, 8, 90, 2, 78, 7, 94, 0, 64, 4, 32, 5, 66, 6, 10
  };
  const int q9331[] = {
    9, 9, // Number of jobs and machines
    0, 50, 2, 85, 8, 93, 7, 82, 6, 13, 4, 23, 5, 69, 3, 38, 1, 61, 
    2, 61, 7, 57, 8, 94, 5, 57, 4, 93, 0, 31, 1, 79, 6, 69, 3, 38, 
    8, 63, 1,  8, 3, 87, 5, 28, 7, 10, 0, 83, 6, 90, 2, 91, 4, 81, 
    0, 90, 4,  9, 3, 69, 5, 79, 6, 78, 2, 18, 7, 48, 8, 94, 1, 44, 
    7, 39, 8, 54, 3, 62, 5,  9, 1, 60, 0, 21, 4, 28, 2, 38, 6,  2, 
    7, 63, 6, 25, 5, 84, 1,  3, 4, 28, 0, 45, 8, 57, 3, 60, 2, 28, 
    2, 53, 0, 19, 6, 91, 8, 23, 1, 45, 5, 98, 4, 83, 3, 65, 7, 95, 
    6, 29, 8, 70, 4, 13, 0,  7, 5, 64, 3, 71, 2, 85, 1, 11, 7, 60, 
    7, 90, 4, 69, 1, 82, 8,  6, 0, 46, 6, 23, 2, 15, 3, 13, 5, 42
  };
  const int q9332[] = {
    9, 9, // Number of jobs and machines
    2, 15, 8, 44, 5, 10, 1, 12, 7, 20, 4, 90, 3, 62, 6, 69, 0, 22, 
    7, 84, 6, 18, 8, 56, 1, 37, 3, 62, 4, 42, 0, 17, 5, 64, 2, 16, 
    8, 78, 4, 79, 1, 31, 6, 50, 2, 67, 3, 23, 5, 89, 0,  4, 7,  4, 
    4, 31, 6, 29, 1, 56, 7, 55, 3, 99, 5, 44, 2, 71, 8, 94, 0, 51, 
    5, 35, 6, 62, 4, 94, 0, 35, 8, 75, 2, 74, 3, 81, 7, 36, 1, 62, 
    3, 63, 6, 27, 7, 80, 8, 60, 0, 84, 2,  7, 5, 86, 1, 82, 4, 47, 
    6, 54, 8, 84, 5,  2, 2,  1, 0, 87, 4, 33, 3, 92, 1, 31, 7, 34, 
    3, 74, 2, 52, 4, 63, 7, 11, 0, 75, 5, 68, 8, 77, 1, 42, 6, 24, 
    0, 38, 5, 24, 2, 85, 1, 14, 6, 45, 3, 44, 7, 41, 4, 66, 8, 27
  };
  const int q9333[] = {
    9, 9, // Number of jobs and machines
    7, 69, 4, 68, 6, 29, 5, 14, 2, 63, 1, 24, 8, 34, 3, 17, 0,  2, 
    6, 69, 8, 55, 4, 79, 2, 54, 0, 78, 3, 82, 1,  3, 7, 92, 5, 78, 
    5, 63, 8, 35, 2,  5, 1, 46, 0, 35, 3, 63, 4, 85, 7, 10, 6, 55, 
    3, 23, 2, 23, 7, 75, 8, 52, 4, 31, 6, 91, 5, 30, 0, 46, 1, 86, 
    6, 10, 0, 74, 1, 53, 5, 75, 8, 14, 3, 68, 4, 18, 7, 27, 2, 42, 
    4, 12, 1, 54, 5, 89, 7, 45, 0, 43, 6, 83, 2, 22, 3,  4, 8, 98, 
    5, 95, 4, 81, 8, 41, 6, 68, 3, 24, 2, 29, 0, 46, 7, 28, 1, 16, 
    3, 49, 2, 66, 5,  2, 7, 42, 8, 76, 6, 46, 0, 75, 4, 91, 1, 62, 
    2, 27, 8, 97, 5, 15, 6, 66, 3, 18, 4, 56, 7, 58, 0, 44, 1, 80
  };
  const int q9334[] = {
    9, 9, // Number of jobs and machines
    3, 82, 0, 61, 6, 36, 4, 84, 1, 56, 2, 61, 7, 41, 5, 98, 8, 35, 
    7, 41, 8, 76, 4, 66, 6, 47, 0,  8, 5, 11, 2, 30, 3, 32, 1, 42, 
    1, 74, 6, 15, 3, 59, 4, 56, 7,  8, 2, 32, 0, 71, 8, 94, 5, 46, 
    3, 93, 4, 48, 7, 29, 5, 51, 8, 30, 0, 15, 6, 17, 2, 13, 1, 68, 
    5, 33, 1, 99, 8,  5, 2, 91, 7, 33, 3, 55, 6, 30, 4, 57, 0,  5, 
    0, 98, 4, 31, 8, 87, 2, 72, 5, 80, 3, 66, 6, 73, 7, 89, 1,  5, 
    6, 82, 0, 50, 5, 84, 7, 29, 3, 14, 1, 54, 8, 25, 2, 22, 4,  4, 
    2, 18, 0, 10, 5, 63, 4, 51, 3,  3, 1, 45, 8, 34, 7, 41, 6, 33, 
    3, 24, 8, 72, 0, 92, 2,  1, 7, 25, 1, 33, 5, 59, 6, 10, 4, 22
  };
  const int q9335[] = {
    9, 9, // Number of jobs and machines
    2, 52, 6, 95, 8,  2, 5, 32, 3, 35, 1, 93, 7, 10, 0, 84, 4, 17, 
    6, 78, 1, 42, 0, 55, 8, 44, 5, 55, 3, 69, 7,  5, 2, 41, 4,  6, 
    0, 75, 7, 55, 6, 41, 4, 44, 8, 70, 1, 59, 3, 17, 2, 28, 5, 95, 
    7, 12, 5, 18, 2, 79, 0, 96, 4, 95, 1, 19, 8, 15, 6, 39, 3, 14, 
    8, 33, 6, 20, 3, 89, 7, 77, 0, 15, 1, 16, 5, 96, 4, 99, 2, 39, 
    6, 91, 8, 81, 7, 30, 4, 36, 2, 11, 3,  6, 0, 23, 1, 45, 5, 35, 
    0, 27, 6, 52, 5, 43, 3, 26, 8,  3, 1, 72, 7, 73, 4, 61, 2, 35, 
    5, 42, 1, 36, 3, 46, 4, 72, 8, 19, 0, 41, 7, 59, 6, 59, 2, 97, 
    5, 64, 0, 17, 4, 35, 6, 65, 2, 43, 7, 62, 3, 26, 8, 42, 1, 11
  };
  const int q9336[] = {
    9, 9, // Number of jobs and machines
    6, 95, 4, 36, 7, 93, 2, 91, 8, 30, 3, 15, 1, 32, 0, 20, 5, 96, 
    6, 12, 0, 95, 5, 46, 7, 56, 3, 78, 8, 28, 2, 10, 1, 44, 4, 69, 
    8,  9, 2, 51, 1,  4, 3, 21, 7, 46, 6, 91, 5, 97, 4, 84, 0,  3, 
    7, 16, 8, 50, 0, 58, 1, 48, 4, 95, 3, 19, 6, 35, 2, 12, 5, 78, 
    3, 82, 0, 55, 7,  4, 8, 15, 6, 97, 2, 70, 5, 68, 4, 94, 1, 52, 
    8, 79, 7, 81, 0, 50, 2, 44, 5, 30, 1, 73, 4, 97, 3, 52, 6,  2, 
    1, 99, 7, 79, 3, 38, 0, 79, 5, 85, 2,  3, 6, 23, 8, 82, 4, 18, 
    8, 81, 2, 87, 6, 33, 4, 67, 1,  5, 0, 17, 3, 83, 7, 15, 5, 55, 
    3, 81, 1,  8, 0, 91, 8, 13, 2, 13, 4, 88, 7, 18, 6, 17, 5, 18
  };
  const int q9337[] = {
    9, 9, // Number of jobs and machines
    8, 64, 5, 46, 2, 47, 6, 18, 1, 76, 7, 82, 3,  3, 4, 58, 0, 69, 
    6, 63, 0, 79, 2, 67, 7, 70, 1, 77, 8, 97, 5, 14, 4, 67, 3, 80, 
    1, 52, 0, 75, 4, 19, 8, 98, 6, 78, 2, 71, 5, 34, 3, 52, 7,  5, 
    7, 22, 1, 50, 0, 12, 4, 18, 2, 88, 3, 44, 6, 11, 8, 55, 5, 75, 
    4,  5, 2, 66, 6, 79, 8, 58, 1, 69, 7, 42, 0, 87, 5, 39, 3, 65, 
    4, 49, 8, 13, 0, 34, 2, 92, 5, 21, 1, 85, 3, 69, 7, 12, 6, 81, 
    4, 42, 3, 12, 7, 32, 0, 66, 2, 19, 5, 85, 8, 29, 6, 51, 1, 46, 
    5, 75, 4, 98, 6, 15, 7, 63, 3, 29, 1, 68, 0, 38, 2, 37, 8, 28, 
    3, 69, 5, 47, 2, 52, 0, 10, 8, 87, 1,  2, 6, 15, 4, 21, 7, 84
  };
  const int q9338[] = {
    9, 9, // Number of jobs and machines
    8, 68, 1, 24, 7, 51, 4, 21, 2, 40, 5, 72, 0, 74, 6, 69, 3, 92, 
    2, 81, 0, 47, 5, 28, 1, 50, 4, 29, 7, 28, 3, 86, 6, 18, 8, 23, 
    3,  1, 1, 32, 2, 81, 5, 41, 7, 86, 6, 46, 8, 65, 4, 89, 0, 19, 
    6, 94, 8, 76, 7, 56, 0, 14, 2, 94, 1, 97, 4, 73, 3, 18, 5, 80, 
    5, 33, 6, 78, 8, 86, 2, 89, 1, 72, 0, 75, 3, 14, 7, 60, 4, 43, 
    5, 30, 4, 80, 1, 14, 6, 50, 2, 34, 0,  3, 7, 50, 8, 11, 3, 79, 
    1,  1, 4, 40, 6, 44, 8, 46, 3, 64, 5, 94, 0, 56, 7, 89, 2, 30, 
    2, 71, 8, 27, 6, 57, 3, 29, 0, 65, 4, 31, 5,  3, 1, 72, 7, 87, 
    5, 69, 7, 18, 2,  8, 3,  4, 0,  8, 1, 24, 8, 22, 6, 61, 4, 63
  };
  const int q9339[] = {
    9, 9, // Number of jobs and machines
    1, 29, 6, 36, 5, 25, 8, 42, 7, 55, 4, 47, 3, 25, 0, 74, 2, 61, 
    2, 79, 8, 13, 0, 77, 6, 68, 5, 34, 1, 11, 4, 97, 7, 71, 3, 56, 
    8, 87, 1, 73, 3, 96, 4, 64, 6, 78, 0, 45, 7, 34, 2, 59, 5, 65, 
    8, 83, 3,  2, 7,  8, 4,  9, 2, 43, 6, 74, 5, 24, 1, 44, 0, 26, 
    6, 71, 5, 64, 7, 49, 4, 32, 8, 61, 0, 23, 1, 95, 2, 24, 3, 17, 
    7, 99, 8, 68, 5,  1, 6, 27, 1, 77, 0, 21, 4, 67, 2, 90, 3, 11, 
    5, 76, 2, 61, 7, 72, 3, 55, 0, 25, 6,  3, 8, 78, 4, 67, 1, 52, 
    7, 27, 6, 91, 2, 80, 1, 20, 3, 83, 8,  6, 0, 23, 4, 89, 5, 93, 
    6, 43, 0, 86, 8, 75, 7, 97, 1, 72, 4, 86, 5, 46, 3, 85, 2, 49
  };
  const int q9340[] = {
    9, 9, // Number of jobs and machines
    2, 66, 5, 16, 7, 51, 6,  4, 0, 59, 8, 56, 1,  5, 4, 50, 3, 18, 
    6, 17, 3, 27, 4,  7, 1, 52, 0, 93, 7, 67, 8, 48, 5, 44, 2, 52, 
    7, 40, 2, 74, 0, 47, 8, 11, 3, 20, 4, 43, 1, 16, 5, 37, 6, 97, 
    3, 72, 4, 74, 2, 90, 8, 40, 0, 73, 5, 91, 1,  2, 7, 54, 6,  2, 
    5, 30, 2, 82, 8, 69, 7, 13, 0, 66, 6, 49, 4,  6, 3, 26, 1,  8, 
    5, 15, 2,  9, 7, 78, 8, 20, 6, 76, 1,  9, 4,  4, 3,  9, 0, 88, 
    8, 10, 3, 24, 4, 40, 0, 36, 7, 43, 5, 24, 6, 59, 2, 15, 1,  9, 
    1, 16, 5, 14, 7, 11, 4, 77, 6, 17, 8, 15, 0, 30, 2,  1, 3, 21, 
    3, 48, 8, 52, 4, 58, 2, 38, 1, 62, 6, 46, 5, 50, 0, 19, 7, 95
  };
  const int q9341[] = {
    9, 9, // Number of jobs and machines
    7, 76, 0, 25, 3, 64, 6, 92, 8, 45, 4,  9, 5, 59, 1,  6, 2, 17, 
    2, 71, 0, 80, 8, 26, 3, 33, 4, 36, 1, 93, 6, 28, 5, 70, 7, 37, 
    8, 53, 7, 13, 6, 33, 0, 63, 3, 78, 2, 95, 1, 53, 4, 73, 5,  4, 
    3, 92, 6, 46, 8, 87, 1, 38, 0, 50, 7, 37, 4, 40, 5, 66, 2, 41, 
    3, 88, 2, 64, 1, 64, 0, 22, 7, 78, 6, 84, 8,  2, 4, 38, 5, 70, 
    4, 79, 8, 89, 0, 92, 7, 67, 2, 44, 6, 99, 1, 75, 3, 83, 5, 68, 
    4, 21, 7, 50, 0, 96, 6, 53, 5, 69, 3, 82, 2, 57, 8, 92, 1,  1, 
    3, 55, 1, 83, 8, 58, 7, 82, 0, 88, 2, 64, 4,  4, 5, 77, 6, 10, 
    5, 48, 8, 86, 2, 85, 7,  5, 6, 98, 4, 75, 1, 96, 0, 74, 3, 32
  };
  const int q9342[] = {
    9, 9, // Number of jobs and machines
    1, 21, 7, 66, 0, 99, 8, 58, 5, 24, 2, 34, 6, 95, 4, 52, 3, 21, 
    1, 96, 6, 89, 2, 15, 5, 92, 7, 71, 8, 25, 0, 19, 4, 54, 3, 15, 
    5, 71, 3, 97, 6, 19, 0, 55, 1, 12, 7, 17, 2, 38, 8, 53, 4, 88, 
    5, 80, 8, 65, 4, 41, 0, 98, 3, 46, 2, 68, 7, 32, 6, 79, 1, 19, 
    8, 12, 3, 75, 2, 19, 1, 68, 0, 72, 4,  2, 5, 20, 7, 65, 6, 82, 
    5, 34, 0, 38, 2, 13, 4, 89, 7,  7, 6, 26, 1, 53, 8, 22, 3, 87, 
    7, 89, 3, 78, 8, 82, 2, 43, 1, 75, 6, 13, 0,  3, 5, 58, 4, 38, 
    5, 24, 2, 67, 8, 66, 4, 24, 1, 11, 3, 53, 6, 15, 0, 69, 7, 71, 
    6,  6, 7, 68, 2, 69, 5, 69, 8, 63, 4, 28, 3, 79, 0, 60, 1, 46
  };
  const int q9343[] = {
    9, 9, // Number of jobs and machines
    0, 98, 4, 34, 5, 55, 6, 47, 2,  1, 3, 22, 8, 58, 7, 69, 1, 72, 
    0, 22, 3, 36, 5, 14, 8, 94, 7, 69, 1,  7, 4, 15, 6, 15, 2, 72, 
    5, 37, 2, 18, 3, 24, 7, 95, 4, 39, 1, 45, 0, 92, 8, 18, 6, 76, 
    0, 59, 5, 84, 6, 20, 3, 46, 8, 44, 2, 78, 1, 86, 4, 22, 7, 36, 
    8, 19, 0, 90, 7, 94, 4, 90, 3, 47, 2, 67, 1, 48, 6, 37, 5, 99, 
    7, 59, 6, 77, 5, 75, 0, 13, 1, 24, 2,  6, 4, 51, 3, 22, 8, 16, 
    5, 70, 8, 34, 2, 62, 4,  9, 3, 63, 7, 88, 1,  2, 6, 74, 0,  8, 
    8, 87, 3,  5, 4, 98, 5, 81, 1, 49, 0, 16, 2, 41, 7, 85, 6, 54, 
    8, 80, 6, 74, 2, 22, 4, 75, 3,  6, 5, 79, 1, 48, 7, 33, 0,  7
  };
  const int q9344[] = {
    9, 9, // Number of jobs and machines
    1, 69, 6, 62, 4, 41, 2, 93, 8, 64, 3, 17, 7, 10, 0, 18, 5, 75, 
    8, 38, 2, 92, 7, 82, 1, 71, 5, 39, 4, 24, 0, 38, 6, 85, 3, 52, 
    2, 67, 5, 97, 0, 57, 4, 83, 3, 29, 8, 43, 6, 37, 7, 26, 1, 71, 
    1, 52, 0, 59, 2, 14, 4, 36, 7, 45, 6, 90, 5, 38, 3, 12, 8, 29, 
    0, 94, 3, 23, 5, 22, 1, 83, 7, 44, 4, 19, 6,  4, 8, 19, 2, 20, 
    8, 76, 5, 70, 0, 95, 3, 13, 1, 51, 6, 40, 2, 48, 4, 18, 7, 82, 
    7,  7, 8, 88, 0, 12, 6, 24, 3, 25, 4, 36, 1, 94, 5, 77, 2, 34, 
    5, 76, 4,  1, 7, 42, 8,  7, 2, 60, 0, 94, 1, 21, 6, 19, 3, 22, 
    5, 34, 1, 30, 7, 57, 0, 78, 4, 94, 6, 53, 3, 13, 8, 51, 2, 42
  };
  const int q9345[] = {
    9, 9, // Number of jobs and machines
    7,  9, 4, 23, 6, 71, 5, 15, 1, 11, 0, 15, 8, 84, 3, 35, 2, 69, 
    5, 18, 4, 17, 3, 30, 1, 29, 0, 40, 6, 12, 2, 77, 7, 52, 8, 63, 
    5, 95, 8, 15, 3, 55, 7,  6, 2, 66, 6, 40, 0, 85, 1, 93, 4, 40, 
    1, 71, 6, 21, 3, 88, 4, 61, 5, 99, 0, 77, 8, 77, 7, 36, 2, 24, 
    0, 36, 3, 77, 7,  6, 8, 20, 4, 13, 5, 75, 2, 91, 6, 83, 1, 71, 
    4, 18, 2, 53, 6, 91, 0, 90, 7, 95, 1, 20, 8, 87, 3, 80, 5, 54, 
    5, 56, 4, 30, 7, 30, 3, 77, 2,  7, 1, 96, 6,  7, 0, 21, 8, 38, 
    5, 78, 6, 90, 1, 76, 8,  8, 4, 69, 0, 41, 2, 93, 3, 89, 7, 62, 
    6,  9, 2, 74, 3, 70, 4,  8, 5,  8, 8, 34, 1, 32, 7, 20, 0, 80
  };
  const int q9346[] = {
    9, 9, // Number of jobs and machines
    1, 66, 8, 10, 2, 64, 4, 71, 5, 57, 0, 93, 7, 47, 6, 68, 3, 13, 
    0, 94, 2, 12, 5, 29, 8, 29, 7, 83, 4, 11, 6, 40, 3, 70, 1, 70, 
    1, 63, 5, 61, 0, 10, 8, 61, 4, 36, 6, 37, 3, 54, 7, 92, 2, 41, 
    0, 87, 5, 36, 6, 26, 3, 30, 2, 59, 7, 52, 8, 58, 4, 13, 1, 66, 
    0, 85, 5, 14, 3, 78, 7, 89, 8, 56, 4, 72, 2, 43, 6, 57, 1, 80, 
    5, 99, 3,  5, 4, 26, 2, 22, 0, 33, 1, 58, 7, 53, 6, 40, 8,  7, 
    1, 58, 3, 72, 8, 15, 2, 33, 0, 21, 6, 42, 7,  8, 4, 77, 5, 83, 
    7, 29, 3, 49, 8, 36, 6, 94, 5, 71, 0, 13, 2, 54, 1, 42, 4, 84, 
    3, 32, 4, 23, 1, 57, 5, 73, 7, 50, 0, 26, 8, 72, 6, 48, 2, 30
  };
  const int q9347[] = {
    9, 9, // Number of jobs and machines
    7, 15, 3, 99, 1, 25, 4, 12, 8, 83, 2, 89, 5, 26, 6, 23, 0,  9, 
    5, 45, 3, 41, 2, 47, 0, 14, 6,  8, 8, 74, 4, 10, 7, 45, 1, 27, 
    5, 88, 8, 70, 3, 30, 4, 74, 2, 43, 0, 73, 7, 11, 1, 26, 6, 20, 
    2, 51, 5,  6, 3, 29, 4, 40, 8, 37, 0, 42, 7, 48, 6, 68, 1, 64, 
    2,  6, 3, 51, 6, 79, 8, 72, 1, 84, 5, 18, 7, 19, 0, 55, 4,  5, 
    6, 23, 3, 31, 5, 69, 2, 43, 1,  3, 0, 21, 8, 75, 7,  8, 4, 80, 
    5, 40, 3, 20, 4, 42, 8, 16, 1, 63, 2, 56, 6, 83, 7, 13, 0, 41, 
    6, 74, 0, 96, 8, 73, 5, 53, 3, 26, 7, 60, 4, 52, 1, 45, 2, 98, 
    1, 95, 3, 80, 8, 15, 4,  2, 2, 83, 6, 66, 5, 69, 7, 73, 0, 16
  };
  const int q9348[] = {
    9, 9, // Number of jobs and machines
    3,  8, 8, 82, 5, 92, 1, 56, 4, 72, 7, 63, 2, 18, 0, 61, 6, 82, 
    1, 93, 6, 40, 4, 55, 3, 69, 5, 41, 7, 22, 2, 51, 8, 19, 0, 15, 
    4, 26, 7, 25, 3, 27, 5, 39, 6, 25, 1, 27, 2,  7, 0, 73, 8, 72, 
    5, 20, 4, 56, 0, 16, 8, 37, 1, 12, 6, 67, 7, 10, 2, 59, 3, 69, 
    8, 63, 1, 56, 2, 64, 0,  7, 5, 19, 3, 60, 4, 19, 6, 40, 7, 28, 
    4, 62, 7, 38, 3, 38, 8, 42, 5, 77, 2, 25, 1, 12, 0, 33, 6, 13, 
    0,  2, 4, 63, 7, 72, 8, 26, 5, 45, 2, 35, 3, 10, 1, 45, 6, 97, 
    3, 39, 0,  1, 7, 11, 2, 62, 6, 76, 5, 87, 8, 12, 1, 66, 4, 37, 
    2, 12, 6, 57, 8, 82, 4, 87, 3, 30, 7, 14, 5, 31, 0, 61, 1, 20
  };
  const int q9349[] = {
    9, 9, // Number of jobs and machines
    4, 50, 1, 56, 7,  3, 5, 12, 0, 90, 3, 23, 2, 24, 8, 10, 6, 59, 
    5,  5, 1, 76, 6, 29, 0, 98, 4, 12, 7, 33, 3, 65, 2, 30, 8, 91, 
    4, 32, 1, 43, 7, 71, 2, 16, 3, 64, 5, 51, 0, 80, 8, 76, 6,  2, 
    4, 34, 7,  7, 6,  3, 0, 91, 1, 59, 5, 51, 3, 96, 8, 82, 2, 34, 
    3, 72, 6, 70, 8, 71, 0, 58, 1, 46, 5, 37, 2, 22, 4, 12, 7, 50, 
    1, 43, 6, 28, 0, 41, 8, 28, 3, 76, 5, 19, 4,  7, 2, 20, 7, 73, 
    7, 64, 8,  6, 0, 51, 5, 45, 2, 79, 6, 90, 1, 20, 4, 56, 3, 91, 
    8, 93, 5,  5, 2, 45, 6, 77, 7, 74, 1, 43, 0, 56, 3,  9, 4, 40, 
    8, 70, 1, 92, 7, 72, 0, 52, 4, 69, 3, 41, 2, 75, 6, 33, 5, 80
  };
  const int q9350[] = {
    9, 9, // Number of jobs and machines
    4, 39, 8, 70, 3, 79, 5, 13, 6, 59, 1, 13, 7, 33, 2,  7, 0, 68, 
    0, 29, 3, 63, 5, 10, 2, 77, 1, 58, 7, 16, 4,  3, 6, 48, 8, 16, 
    2, 63, 5, 96, 8, 82, 6, 83, 3, 23, 0, 35, 7, 80, 4, 17, 1, 32, 
    8, 61, 2, 96, 5, 10, 0, 10, 1, 35, 7, 47, 4, 57, 3, 45, 6, 83, 
    6, 47, 0, 22, 8, 98, 4, 16, 7, 29, 2, 66, 5, 19, 3, 64, 1, 20, 
    6, 96, 8, 48, 7, 64, 4, 86, 5, 69, 2, 46, 1, 99, 0, 65, 3, 31, 
    2, 53, 0, 28, 6, 13, 1, 82, 7, 86, 8, 73, 5, 40, 3, 26, 4, 63, 
    2, 57, 5, 50, 4, 87, 6, 56, 3, 51, 7, 19, 0, 57, 8, 62, 1,  8, 
    1, 12, 3, 45, 8, 84, 2, 23, 5, 65, 6,  4, 4, 53, 0, 49, 7, 41
  };
  const int q9351[] = {
    9, 9, // Number of jobs and machines
    0, 32, 5, 62, 4, 54, 6, 39, 2, 18, 7, 94, 3, 91, 1, 55, 8, 60, 
    0, 54, 7, 59, 4, 90, 8, 79, 3, 43, 1, 35, 2, 39, 5, 92, 6, 25, 
    6, 17, 1, 15, 7, 11, 0, 86, 8, 94, 3, 52, 4, 12, 5, 24, 2, 66, 
    8, 60, 2,  2, 5, 62, 6, 84, 1, 86, 3, 46, 7, 74, 0, 20, 4, 36, 
    2, 23, 0, 49, 5, 50, 3, 34, 7, 71, 4, 13, 6, 86, 1, 31, 8, 85, 
    0, 80, 4, 58, 7, 10, 5, 43, 3, 28, 6, 85, 2, 66, 1, 11, 8, 36, 
    1,  2, 6, 50, 2, 96, 3, 10, 0, 39, 5, 45, 4, 70, 8, 95, 7, 76, 
    4, 77, 2, 61, 1, 55, 8, 43, 5, 23, 7, 29, 0, 29, 6, 11, 3, 98, 
    2, 76, 0, 95, 5, 13, 3, 67, 4, 24, 6,  7, 7, 27, 8, 24, 1, 56
  };
  const int q9352[] = {
    9, 9, // Number of jobs and machines
    4, 68, 5, 74, 0, 43, 1, 26, 6, 83, 2, 14, 3,  5, 8, 45, 7, 70, 
    7, 64, 3, 49, 8, 67, 2, 35, 0, 31, 6, 12, 1, 34, 5, 21, 4, 18, 
    6, 18, 7, 85, 8, 96, 4, 65, 5, 29, 1, 57, 0, 11, 2, 83, 3, 43, 
    7,  7, 3, 73, 0, 88, 8, 60, 5, 79, 2, 89, 4, 78, 6, 62, 1, 42, 
    2, 36, 8, 81, 3, 18, 5, 54, 6, 48, 7, 32, 4, 83, 0, 60, 1, 86, 
    0, 99, 7, 52, 8, 10, 1, 66, 6, 97, 5, 25, 4, 78, 2, 57, 3, 52, 
    7, 67, 6, 53, 0, 76, 5, 57, 3, 82, 8, 22, 4, 26, 1,  5, 2, 40, 
    2, 32, 7, 87, 4, 73, 1, 17, 5, 62, 3, 58, 8, 97, 6, 50, 0, 56, 
    1, 38, 6, 83, 3, 17, 4, 59, 7, 28, 5, 60, 2, 69, 8, 31, 0, 74
  };
  const int q9353[] = {
    9, 9, // Number of jobs and machines
    8, 31, 0, 49, 4, 45, 1,  9, 5, 68, 3, 16, 7, 17, 6,  1, 2, 67, 
    2, 78, 1, 71, 8, 29, 6, 96, 5, 16, 0, 20, 4, 52, 3,  8, 7, 21, 
    1, 80, 0, 93, 5, 33, 2, 67, 6, 83, 3,  5, 8, 68, 4, 18, 7, 57, 
    3,  9, 2, 82, 5, 60, 8, 13, 6, 71, 7, 58, 0, 90, 4, 50, 1, 23, 
    1, 34, 7, 65, 3, 28, 6, 33, 4, 82, 2, 76, 0, 99, 5, 90, 8, 32, 
    1, 95, 4,  6, 5, 57, 8, 80, 2, 69, 3, 49, 6, 86, 0, 17, 7,  1, 
    5, 90, 8, 83, 4, 27, 3, 98, 2, 73, 7,  9, 1, 99, 0, 93, 6, 69, 
    5, 41, 1, 41, 8, 82, 2, 35, 6, 58, 0, 19, 7, 91, 4, 40, 3, 10, 
    4,  9, 0, 86, 5,  4, 8, 68, 1, 95, 2, 58, 7, 44, 3, 71, 6, 26
  };
  const int q9354[] = {
    9, 9, // Number of jobs and machines
    3, 69, 4, 36, 7, 84, 2, 65, 0, 35, 1, 19, 5, 47, 6, 51, 8, 70, 
    0, 64, 7, 17, 2, 23, 1, 41, 6, 88, 5, 49, 8,  6, 4, 65, 3, 62, 
    7,  8, 1, 71, 6,  8, 0, 56, 8, 54, 5, 19, 3, 87, 2, 25, 4, 84, 
    5, 90, 4, 71, 6, 56, 0, 59, 8, 81, 7, 40, 1, 39, 3, 19, 2, 77, 
    1, 27, 2, 63, 5, 18, 3, 36, 0, 39, 7,  2, 8, 50, 4, 97, 6, 47, 
    2,  7, 7, 48, 1, 71, 4, 70, 5, 27, 3, 69, 6, 81, 0, 34, 8,  4, 
    3, 58, 6, 31, 1, 22, 4, 96, 5, 91, 0, 74, 7, 36, 2, 17, 8, 98, 
    2, 53, 8, 44, 4, 33, 5, 11, 6,  1, 3,  4, 0, 41, 1, 42, 7, 71, 
    2, 61, 6, 54, 1, 47, 5,  9, 0, 79, 3, 32, 4, 37, 8, 94, 7, 70
  };
  const int q9355[] = {
    9, 9, // Number of jobs and machines
    1, 22, 8, 52, 5, 30, 4, 76, 0, 18, 2, 71, 7, 32, 3, 62, 6, 96, 
    1, 24, 0, 11, 4, 24, 8, 48, 7, 98, 5, 46, 2, 15, 3, 87, 6, 97, 
    4, 40, 2,  9, 7,  6, 8, 72, 0,  6, 3, 19, 6,  9, 1, 95, 5, 45, 
    3, 73, 5, 87, 6, 47, 1, 51, 8,  6, 0, 16, 4, 14, 2, 93, 7, 97, 
    1, 75, 6, 73, 3, 93, 7,  2, 2, 41, 5, 51, 0, 33, 8, 10, 4, 44, 
    4, 43, 3, 65, 1, 71, 2, 70, 0, 82, 5, 57, 8, 43, 6, 56, 7, 53, 
    7, 51, 1, 14, 5, 67, 2, 68, 0,  2, 4, 77, 3,  1, 8, 70, 6, 63, 
    0,  1, 8, 11, 7, 71, 2, 84, 6, 55, 5, 48, 3, 24, 4, 19, 1, 29, 
    5, 44, 2, 30, 1,  4, 8, 66, 4, 95, 0, 17, 7, 56, 3, 16, 6, 10
  };
  const int q9356[] = {
    9, 9, // Number of jobs and machines
    2, 32, 8, 55, 7, 89, 5,  4, 1, 24, 0, 86, 3, 19, 4, 38, 6,  6, 
    2, 49, 4, 37, 6, 37, 3, 61, 8, 98, 7, 95, 0, 74, 5,  3, 1, 26, 
    4, 15, 2, 43, 0, 55, 3, 44, 5, 64, 8, 95, 6, 40, 1, 58, 7, 87, 
    0, 87, 8, 45, 6,  5, 3, 89, 7, 81, 5,  2, 2, 53, 4, 81, 1, 78, 
    7, 14, 3, 31, 1, 62, 0, 84, 6, 60, 5,  5, 8, 61, 2, 75, 4, 16, 
    7, 42, 8, 90, 1, 88, 4, 83, 0,  7, 2, 32, 6, 69, 3, 24, 5,  5, 
    5, 91, 7, 68, 4, 38, 2, 90, 8, 23, 0, 29, 6, 77, 3, 16, 1, 58, 
    0, 21, 6, 99, 2, 87, 8, 57, 7, 24, 1, 45, 4, 29, 5,  2, 3, 93, 
    8, 72, 7, 15, 6, 24, 2, 50, 3, 36, 4, 58, 5, 74, 1, 64, 0, 65
  };
  const int q9357[] = {
    9, 9, // Number of jobs and machines
    6, 57, 3, 60, 7, 82, 2, 56, 8, 29, 0, 14, 1, 20, 5, 55, 4, 32, 
    8, 80, 0, 19, 4, 57, 5, 33, 7, 72, 2, 36, 6,  8, 1, 50, 3, 22, 
    2, 47, 0, 69, 5, 61, 8, 49, 7,  3, 3, 67, 1, 19, 4, 60, 6, 91, 
    4, 46, 2, 70, 6, 69, 8, 42, 3, 65, 7, 36, 5,  2, 0, 86, 1, 59, 
    5,  6, 3, 92, 1, 94, 7, 76, 6, 87, 8, 46, 4, 10, 2, 99, 0, 43, 
    3, 58, 4, 61, 6,  9, 5, 82, 1,  3, 0, 72, 8,  5, 7, 10, 2, 74, 
    7, 73, 0, 48, 3, 26, 8, 12, 6, 51, 2, 35, 1, 93, 4, 18, 5, 14, 
    3, 28, 0, 72, 8, 72, 7, 20, 1, 34, 2, 39, 4, 63, 5, 48, 6, 45, 
    8, 87, 7, 58, 1, 27, 6, 19, 2, 30, 5,  3, 4, 98, 3, 81, 0, 66
  };
  const int q9358[] = {
    9, 9, // Number of jobs and machines
    1, 80, 3, 86, 0, 59, 6,  8, 2,  7, 5,  7, 4, 71, 8, 63, 7, 92, 
    8, 93, 0, 97, 5, 98, 1, 61, 6, 24, 7, 61, 2, 90, 3, 86, 4, 38, 
    7, 86, 4, 99, 3, 86, 8,  4, 6, 16, 1, 90, 5, 80, 0, 67, 2, 29, 
    6, 22, 4, 31, 5, 74, 2, 74, 3, 12, 7, 95, 8, 44, 1, 73, 0, 76, 
    1, 90, 2, 80, 0,  1, 6, 74, 5, 94, 3, 35, 7, 40, 8, 55, 4, 25, 
    0, 11, 7, 28, 8, 67, 6, 86, 2, 64, 5,  7, 3, 49, 4, 13, 1, 60, 
    8, 58, 4, 59, 1, 91, 7, 84, 5, 43, 3, 31, 0, 19, 2, 51, 6,  8, 
    6,  4, 2, 36, 4, 92, 7, 37, 8, 45, 0, 62, 3, 80, 1,  7, 5, 77, 
    1, 51, 5,  4, 7, 83, 2, 20, 8, 38, 0, 72, 6, 78, 3,  8, 4, 69
  };
  const int q9359[] = {
    9, 9, // Number of jobs and machines
    3, 80, 1, 28, 0, 54, 6,  2, 4,  7, 2, 33, 8, 92, 7, 41, 5, 62, 
    1, 71, 3, 78, 6, 60, 5, 36, 8, 91, 7, 29, 4, 32, 0, 37, 2, 67, 
    2, 22, 3,  4, 4, 95, 1, 94, 7, 78, 6, 46, 0, 68, 8, 59, 5, 98, 
    6, 35, 7, 69, 0, 55, 2, 39, 4, 49, 8,  4, 1, 28, 5, 69, 3,  2, 
    5, 23, 2, 58, 3, 34, 4, 60, 8, 56, 7, 87, 6, 60, 0, 47, 1,  8, 
    2, 32, 3, 11, 5, 98, 7, 13, 6, 87, 1, 70, 4,  2, 0, 20, 8, 94, 
    5, 54, 3, 76, 6, 74, 0, 31, 4, 93, 2, 68, 1, 58, 8, 36, 7, 85, 
    2,  7, 6,  5, 8, 37, 4, 88, 0, 23, 5, 65, 1, 10, 7, 59, 3, 32, 
    3, 30, 0, 95, 5, 79, 8, 79, 2, 26, 4, 56, 6, 64, 1, 42, 7,  8
  };
  const int q9360[] = {
    9, 9, // Number of jobs and machines
    2, 46, 5, 99, 7, 11, 6, 57, 8, 52, 0, 25, 4, 39, 1, 30, 3, 71, 
    4,  7, 2,  7, 7, 35, 8, 50, 1, 78, 3, 59, 6, 30, 0, 13, 5,  7, 
    3, 61, 4, 86, 0, 63, 1, 44, 8, 51, 7, 97, 6, 50, 2, 72, 5, 80, 
    5, 42, 8,  7, 3, 75, 6, 77, 4, 27, 1,  6, 7, 54, 2, 42, 0, 26, 
    1, 22, 3, 14, 2,  9, 4, 46, 7, 24, 6, 14, 0, 32, 5, 47, 8, 31, 
    1,  8, 5, 13, 6, 36, 0, 47, 7, 25, 4, 31, 3, 49, 2, 25, 8, 42, 
    7, 98, 1, 19, 0, 10, 2, 85, 3, 12, 6, 13, 4, 69, 8, 88, 5, 92, 
    4, 45, 1, 74, 0, 49, 2, 14, 7, 41, 5, 61, 3, 89, 6, 43, 8, 91, 
    4, 33, 1,  7, 0, 89, 2, 58, 8, 11, 7, 43, 5, 35, 6, 58, 3, 57
  };
  const int q9361[] = {
    9, 9, // Number of jobs and machines
    3, 23, 2, 70, 8, 88, 6,  6, 0, 71, 7, 35, 1, 50, 5, 81, 4, 26, 
    7,  2, 3, 77, 1, 86, 2,  6, 6, 15, 8, 78, 0, 76, 4, 11, 5, 64, 
    2, 68, 3, 52, 0, 56, 6, 43, 4, 77, 5, 96, 1, 86, 7, 58, 8, 34, 
    4, 64, 7, 84, 1, 51, 3, 97, 6, 51, 2, 99, 0, 32, 8, 63, 5, 80, 
    0,  6, 6, 28, 2, 28, 4,  9, 3, 95, 7, 42, 5, 58, 8, 13, 1, 76, 
    7, 97, 3, 77, 0, 26, 6, 65, 2, 82, 4, 13, 8, 87, 5, 18, 1, 22, 
    2, 50, 3, 50, 8, 93, 1, 49, 0, 47, 6, 70, 4, 56, 5, 79, 7, 67, 
    8, 36, 0, 37, 5,  5, 7, 50, 3, 48, 4, 79, 2, 10, 6, 91, 1, 14, 
    7, 69, 3, 89, 1, 17, 0, 82, 4, 47, 5, 57, 6, 35, 8, 35, 2, 22
  };
  const int q9362[] = {
    9, 9, // Number of jobs and machines
    2, 48, 8, 32, 3, 66, 0, 96, 6, 90, 5,  7, 4, 19, 7, 27, 1, 34, 
    6, 15, 8,  1, 5, 82, 4, 16, 3, 95, 2, 84, 7, 79, 0, 60, 1, 53, 
    0, 37, 5, 19, 7, 89, 2, 36, 6, 47, 8, 68, 4, 66, 1,  7, 3, 87, 
    3, 30, 8, 73, 2, 43, 1, 62, 0, 61, 7, 70, 5, 13, 4, 92, 6, 95, 
    4, 65, 0, 88, 3, 13, 7, 96, 8, 24, 1, 52, 5, 67, 6, 77, 2, 46, 
    5, 35, 8, 24, 4, 95, 0, 23, 1, 50, 3, 17, 7, 40, 6, 99, 2, 17, 
    0, 90, 6, 66, 5, 57, 1, 80, 3, 90, 7, 92, 2, 57, 4, 33, 8,  1, 
    7, 59, 5, 38, 1, 93, 0, 18, 4, 41, 3,  5, 6, 77, 8, 94, 2, 41, 
    1, 57, 4, 37, 7, 38, 8, 83, 6, 15, 3, 39, 2, 77, 5, 29, 0, 20
  };
  const int q9363[] = {
    9, 9, // Number of jobs and machines
    5, 31, 0, 77, 6,  2, 7, 84, 1, 73, 2, 81, 3, 15, 8, 88, 4, 42, 
    1,  7, 0, 97, 8, 99, 3, 29, 6, 64, 5, 25, 2, 16, 4, 41, 7, 53, 
    1, 97, 4, 86, 0, 91, 2,  7, 8, 68, 7, 25, 6, 98, 3, 56, 5, 33, 
    8, 20, 0, 88, 2, 86, 7, 31, 4, 61, 6, 94, 5,  4, 1, 16, 3, 48, 
    1,  2, 6, 55, 7, 67, 0, 99, 5, 69, 8, 72, 3, 31, 4, 56, 2, 28, 
    0, 69, 7, 18, 6, 19, 1, 38, 2, 11, 3, 49, 5, 46, 8, 64, 4, 99, 
    2, 25, 7, 22, 0,  3, 1, 32, 6, 27, 8, 36, 3, 85, 5,  1, 4, 25, 
    7, 86, 0, 21, 1, 51, 5, 48, 8, 73, 3, 67, 4, 44, 6, 15, 2, 42, 
    4,  7, 2, 60, 1, 80, 7, 28, 3,  4, 0, 11, 5, 32, 6, 56, 8, 54
  };
  const int q9364[] = {
    9, 9, // Number of jobs and machines
    0, 96, 1, 63, 7, 21, 5, 66, 3, 29, 4, 13, 8, 59, 2, 76, 6, 31, 
    5, 57, 6, 60, 7, 88, 2, 44, 0, 47, 3,  2, 4,  7, 1, 29, 8, 86, 
    7,  8, 1, 90, 4, 31, 3, 91, 8, 89, 0, 38, 5, 44, 6, 84, 2, 16, 
    2, 51, 4, 65, 0, 28, 5, 34, 6, 94, 8, 24, 7, 78, 3, 37, 1, 64, 
    5, 83, 2, 48, 7,  5, 8, 16, 3, 94, 4, 65, 6,  6, 1, 35, 0, 21, 
    3, 48, 2, 60, 8, 50, 5, 83, 7, 35, 0, 84, 4, 87, 1, 85, 6, 73, 
    8, 98, 4, 36, 2,  9, 7, 36, 1, 24, 3, 57, 5, 46, 6, 77, 0,  4, 
    7, 62, 3, 25, 0, 22, 8, 60, 5, 36, 4, 81, 6, 43, 1, 12, 2, 12, 
    4,  6, 2, 50, 8, 64, 5, 23, 3, 92, 0, 89, 1, 35, 7, 18, 6, 51
  };
  const int q9365[] = {
    9, 9, // Number of jobs and machines
    2, 86, 6, 69, 8, 66, 1, 20, 7, 69, 0, 92, 3, 99, 4, 30, 5, 24, 
    4, 22, 1, 89, 2, 50, 3, 93, 0, 97, 5, 63, 7, 19, 6,  6, 8, 17, 
    3, 34, 5, 20, 0, 13, 7, 99, 8, 48, 6, 93, 2, 50, 1, 78, 4, 62, 
    8, 80, 5, 89, 2, 77, 0, 40, 6, 97, 4, 22, 3, 28, 7,  7, 1, 13, 
    8,  8, 2, 71, 4, 68, 3, 40, 1, 88, 0, 98, 5, 20, 6, 34, 7, 77, 
    4, 47, 2, 14, 8, 44, 7, 21, 6, 43, 3, 46, 0,  1, 1, 25, 5, 10, 
    7, 23, 2, 71, 6, 37, 1, 54, 0, 49, 4, 89, 8, 12, 3, 68, 5, 64, 
    0, 44, 8, 41, 2, 96, 7, 39, 4, 19, 6, 92, 5,  3, 1, 20, 3,  5, 
    0, 18, 6, 16, 1, 75, 5,  4, 2, 52, 8, 29, 4, 94, 7, 75, 3, 95
  };
  const int q9366[] = {
    9, 9, // Number of jobs and machines
    1, 67, 3, 83, 0, 56, 5, 66, 8, 45, 4, 61, 6, 57, 2, 85, 7, 92, 
    1, 39, 2, 53, 3, 24, 0, 25, 8, 32, 7, 29, 5, 64, 6, 65, 4, 88, 
    2, 79, 8, 42, 0, 91, 6, 34, 1, 40, 5, 63, 4, 81, 7, 79, 3, 35, 
    0, 92, 2, 73, 5, 44, 4,  6, 1, 15, 6, 42, 7, 66, 3, 72, 8,  7, 
    2, 43, 0, 60, 8, 40, 7, 88, 3, 85, 4, 42, 6,  2, 1, 15, 5, 44, 
    0, 28, 2, 81, 4, 79, 3, 79, 1, 59, 6,  5, 5, 86, 8, 40, 7, 69, 
    5, 99, 0, 51, 3, 49, 2, 71, 7, 65, 1, 54, 6,  8, 8, 68, 4,  9, 
    2, 43, 3, 42, 0, 75, 1, 19, 7, 20, 8,  2, 5, 95, 6, 94, 4, 50, 
    0, 38, 8, 98, 6, 63, 4, 84, 5, 37, 3, 15, 2, 61, 7, 20, 1, 49
  };
  const int q9367[] = {
    9, 9, // Number of jobs and machines
    8, 54, 2, 21, 1, 82, 6, 10, 0, 75, 3, 80, 5, 58, 7, 98, 4, 45, 
    0, 65, 2,  7, 6, 27, 3, 62, 5, 20, 4, 37, 7, 52, 8, 13, 1, 21, 
    5, 41, 0, 83, 3, 97, 2,  8, 8, 55, 1, 37, 7, 71, 4, 95, 6, 36, 
    0,  4, 8, 39, 6, 40, 2, 52, 4, 16, 3, 14, 1, 66, 5, 18, 7, 42, 
    6, 64, 0, 76, 1, 51, 4, 19, 8, 98, 3, 34, 7, 10, 2, 49, 5, 45, 
    2, 86, 1, 59, 0, 11, 8, 75, 3, 17, 4, 56, 5, 63, 7, 86, 6, 43, 
    4, 89, 5, 82, 1, 64, 3, 78, 2, 41, 6, 21, 0, 49, 7, 11, 8, 92, 
    6, 11, 3, 81, 2, 80, 0, 33, 8, 46, 7,  8, 1, 79, 4, 76, 5, 16, 
    4, 52, 5, 12, 1, 77, 8, 11, 7, 96, 2, 66, 3, 25, 0, 12, 6, 43
  };
  const int q9368[] = {
    9, 9, // Number of jobs and machines
    2, 87, 6, 29, 0, 84, 5, 77, 1,  6, 3, 97, 4, 99, 8, 54, 7, 14, 
    5, 98, 1,  6, 7, 25, 8, 54, 4, 48, 3, 62, 0, 64, 2, 22, 6, 93, 
    3, 17, 8, 29, 6, 32, 1, 58, 0, 31, 7, 48, 5, 13, 4, 21, 2, 83, 
    8, 83, 0, 19, 1, 50, 6, 25, 4, 46, 2, 87, 5, 25, 3, 99, 7, 96, 
    7, 96, 8, 30, 2, 67, 3, 95, 4, 23, 5, 87, 6, 30, 0, 66, 1, 17, 
    8, 55, 4, 33, 1, 48, 2, 68, 0, 82, 5, 13, 7, 70, 3, 38, 6, 16, 
    8, 78, 0, 63, 2, 95, 3, 54, 7,  5, 5, 16, 4,  9, 6, 66, 1,  1, 
    1, 80, 0, 89, 7, 70, 3, 29, 5, 21, 6, 13, 4, 93, 8, 10, 2, 47, 
    5, 64, 6, 96, 0, 70, 7, 91, 3, 24, 1, 48, 8, 91, 4, 59, 2,  5
  };
  const int q9369[] = {
    9, 9, // Number of jobs and machines
    7, 93, 5, 19, 6, 84, 0, 68, 2, 91, 4, 61, 8, 17, 3, 73, 1, 49, 
    8, 62, 6, 96, 2,  6, 0, 56, 7, 10, 5, 53, 3, 65, 4, 21, 1, 79, 
    2, 17, 5,  4, 1, 37, 8, 43, 0, 26, 4, 32, 7, 68, 6, 14, 3, 31, 
    2, 22, 5, 82, 4, 87, 3, 43, 0, 46, 1, 22, 7,  1, 8, 78, 6,  2, 
    0, 68, 8, 32, 2,  8, 1, 72, 5, 65, 6,  9, 3, 62, 7, 41, 4, 23, 
    5,  7, 2, 21, 6, 69, 4, 68, 1, 90, 7, 32, 8,  1, 0, 12, 3, 33, 
    6, 64, 4, 74, 1, 12, 7, 17, 2, 35, 8, 28, 5, 84, 3, 43, 0, 23, 
    7, 85, 8, 47, 2, 44, 5, 74, 4, 51, 0,  2, 1, 42, 6, 52, 3, 99, 
    8, 73, 2, 45, 7, 83, 6, 39, 5, 71, 0, 96, 1, 35, 3, 47, 4, 34
  };
  const int q9370[] = {
    9, 9, // Number of jobs and machines
    3, 69, 4, 30, 6, 42, 8, 67, 2, 78, 0, 35, 1, 96, 5, 39, 7, 35, 
    2, 81, 0, 93, 3, 80, 1, 85, 8,  4, 4, 67, 7, 71, 6, 82, 5, 85, 
    6, 11, 8, 62, 3, 62, 4, 46, 5,  4, 7, 97, 0, 76, 1, 66, 2, 72, 
    2, 16, 1, 79, 6, 31, 8,  4, 0, 13, 3, 55, 5, 32, 4, 31, 7, 47, 
    6, 45, 0, 31, 1, 79, 2, 54, 7, 86, 5, 74, 3, 89, 4,  1, 8, 65, 
    2,  9, 5, 35, 7, 50, 6, 89, 4, 25, 3, 98, 0,  2, 8, 66, 1, 64, 
    6,  6, 7, 53, 4, 54, 0, 29, 1, 65, 3, 65, 8, 10, 5, 81, 2, 62, 
    7, 29, 2, 26, 6, 65, 4, 18, 0, 57, 8,  5, 5, 72, 3, 76, 1, 57, 
    3, 98, 2, 29, 0, 51, 7,  6, 8, 88, 6, 65, 4, 77, 1, 19, 5, 17
  };
  const int q9371[] = {
    9, 9, // Number of jobs and machines
    2, 75, 4, 71, 6, 80, 0, 65, 3,  4, 7, 81, 8, 90, 5, 20, 1, 55, 
    0, 25, 4,  4, 6, 48, 2, 98, 1, 78, 8, 59, 3, 41, 7, 68, 5, 81, 
    6, 13, 8, 14, 2, 44, 7, 58, 4, 29, 3, 81, 5, 91, 1, 55, 0, 29, 
    5,  5, 7, 21, 0, 73, 4, 57, 1, 72, 8, 88, 6, 87, 2,  3, 3, 11, 
    7, 35, 5, 77, 0, 42, 8, 33, 1, 96, 2, 63, 3,  6, 6, 41, 4, 94, 
    7, 94, 3, 15, 0,  5, 8, 17, 4, 38, 5, 79, 1, 28, 2, 45, 6, 64, 
    6, 72, 4, 49, 5, 98, 7, 75, 1, 50, 2, 45, 0, 53, 8,  1, 3, 55, 
    6, 16, 8, 21, 7, 98, 0, 44, 5, 31, 3, 29, 4, 51, 2, 53, 1, 46, 
    4, 17, 2, 33, 6, 83, 7, 59, 3, 81, 8, 63, 5, 31, 1, 49, 0, 43
  };
  const int q9372[] = {
    9, 9, // Number of jobs and machines
    7,  9, 0, 76, 6, 94, 2, 44, 1, 28, 8, 60, 3, 16, 4,  1, 5, 71, 
    4, 76, 2, 65, 8, 61, 0, 50, 6, 11, 7, 72, 1, 12, 5, 24, 3, 68, 
    5, 95, 1, 31, 7, 89, 2, 30, 4, 20, 6,  6, 8, 44, 3, 26, 0, 73, 
    0, 78, 7, 11, 1, 14, 6, 31, 5, 50, 8, 49, 4, 54, 3, 22, 2, 58, 
    5, 74, 7, 62, 4,  8, 2, 75, 0, 15, 6, 22, 8, 66, 3, 80, 1,  2, 
    8, 79, 3, 70, 1,  9, 5,  2, 6, 26, 0, 68, 4,  2, 7, 99, 2, 34, 
    8, 25, 1, 23, 7, 59, 4, 34, 0, 76, 5, 46, 6, 22, 2,  8, 3, 33, 
    5, 93, 0, 25, 8, 12, 7, 24, 4, 83, 2, 57, 3, 10, 1, 30, 6, 40, 
    7, 26, 8, 13, 1, 27, 5, 33, 4, 61, 0, 30, 6, 96, 3, 92, 2, 23
  };
  const int q9373[] = {
    9, 9, // Number of jobs and machines
    6, 48, 1, 69, 5, 89, 7, 27, 3, 84, 4, 14, 0, 83, 8, 21, 2, 82, 
    4, 72, 0,  9, 3, 16, 1, 99, 2, 71, 5, 72, 6, 46, 7, 62, 8, 39, 
    0, 55, 1,  3, 5, 21, 7, 15, 8, 67, 6, 64, 3, 31, 4, 76, 2, 67, 
    7, 37, 5, 21, 4, 78, 6, 14, 2, 38, 8, 91, 3, 63, 0, 92, 1, 12, 
    6, 38, 4, 83, 7, 89, 2, 51, 1, 43, 8, 46, 0, 88, 5, 14, 3, 49, 
    5,  1, 6, 23, 2, 37, 0, 25, 1, 37, 8, 44, 7, 27, 3, 90, 4, 68, 
    6, 67, 5, 99, 3, 36, 1, 41, 7,  6, 8, 84, 0, 86, 4, 59, 2, 53, 
    0, 69, 6, 29, 4, 87, 5, 18, 8, 70, 7, 76, 2, 64, 3, 69, 1,  1, 
    3,  8, 5, 71, 1, 25, 8, 10, 6, 51, 7, 58, 0, 39, 2, 27, 4, 92
  };
  const int q9374[] = {
    9, 9, // Number of jobs and machines
    4, 84, 8, 23, 1, 79, 0, 66, 2, 48, 6, 12, 7, 46, 5, 20, 3, 17, 
    0, 77, 5, 13, 3, 43, 6, 84, 4, 58, 7, 70, 8, 65, 2, 36, 1,  9, 
    6,  7, 3, 92, 1, 22, 5, 72, 8, 68, 4,  2, 7, 93, 2,  5, 0,  2, 
    1, 22, 7, 10, 3, 52, 5,  4, 4,  3, 0, 28, 6, 99, 8, 64, 2, 54, 
    7, 59, 0, 42, 1, 50, 3, 83, 6, 15, 2, 64, 4, 78, 5, 22, 8, 37, 
    3, 78, 2, 36, 4, 63, 0, 63, 1, 40, 6, 43, 7, 49, 5, 39, 8, 50, 
    7, 16, 2,  7, 3, 37, 8, 83, 1, 60, 0, 27, 5, 84, 6, 31, 4, 13, 
    3,  5, 8, 91, 5, 58, 7, 34, 4, 54, 2, 34, 1, 32, 6, 88, 0, 12, 
    5, 47, 7, 78, 8, 23, 4, 92, 6,  9, 2, 20, 3,  9, 1, 62, 0, 81
  };
  const int q9375[] = {
    9, 9, // Number of jobs and machines
    1, 62, 8, 71, 3, 13, 4, 19, 6, 28, 0, 69, 5, 11, 2, 24, 7, 38, 
    5, 56, 0, 91, 4, 55, 8, 99, 1, 90, 2, 89, 6, 40, 3, 11, 7, 19, 
    1, 72, 3, 92, 5, 41, 4,  3, 8, 98, 2, 72, 6, 48, 7, 18, 0, 46, 
    6, 26, 3,  3, 7, 83, 0, 89, 1, 46, 4, 65, 5, 35, 8, 44, 2, 63, 
    2, 78, 7, 97, 1, 76, 3, 79, 8,  5, 5, 55, 4, 85, 6, 82, 0, 63, 
    5, 98, 8, 25, 0, 11, 7, 87, 3,  4, 4,  6, 1, 46, 2, 33, 6, 70, 
    8, 60, 6, 86, 1, 16, 3, 81, 4, 44, 7, 73, 5, 60, 0, 86, 2, 73, 
    5, 18, 0, 87, 1, 76, 4, 21, 8, 10, 7, 33, 2, 60, 6, 40, 3, 52, 
    1, 93, 3, 28, 2, 96, 5, 32, 6, 40, 0,  4, 4, 87, 7, 16, 8, 82
  };
  const int q9376[] = {
    9, 9, // Number of jobs and machines
    3, 96, 6,  2, 7, 43, 4, 59, 2, 86, 5, 23, 1, 82, 0, 38, 8, 70, 
    5, 95, 2, 95, 1, 19, 4, 42, 7, 52, 6, 89, 0, 28, 8, 61, 3, 23, 
    4, 29, 0, 90, 8, 84, 5, 59, 2, 96, 6, 77, 3, 63, 1, 90, 7, 79, 
    5, 87, 0, 72, 8, 75, 6, 18, 1, 48, 4, 43, 3, 16, 7, 35, 2, 95, 
    3, 37, 7, 72, 8, 56, 0, 99, 5, 90, 2, 10, 4, 19, 1, 66, 6, 60, 
    4,  7, 0, 87, 5, 11, 7, 61, 3, 10, 1, 15, 2, 98, 6, 93, 8, 29, 
    2, 58, 4, 45, 0, 70, 1, 89, 6, 62, 8, 17, 7, 68, 5, 19, 3, 93, 
    5, 78, 8, 94, 7, 91, 3, 17, 1,  2, 2, 16, 6, 47, 4, 96, 0, 33, 
    0, 43, 1, 34, 3, 30, 8, 41, 5, 92, 7, 59, 2, 53, 4, 80, 6, 89
  };
  const int q9377[] = {
    9, 9, // Number of jobs and machines
    3, 85, 2, 36, 7, 22, 5, 38, 6, 65, 8,  1, 0, 99, 4, 88, 1, 28, 
    0, 92, 5, 35, 1,  6, 6,  5, 7, 95, 2, 66, 4, 29, 8, 89, 3, 20, 
    2,  6, 8, 95, 5, 75, 1, 99, 4, 84, 7, 72, 6, 66, 3, 26, 0, 52, 
    2, 64, 7, 72, 5, 95, 8, 19, 4, 68, 0, 35, 1,  4, 6, 21, 3, 85, 
    4, 14, 1, 24, 3, 29, 8, 68, 7, 77, 2,  2, 6, 52, 5, 52, 0, 41, 
    0, 59, 8, 40, 2,  6, 6, 44, 5, 55, 4, 73, 1, 84, 7, 95, 3, 76, 
    1, 30, 4, 85, 6, 80, 2, 87, 3, 45, 0, 21, 5, 55, 8, 30, 7, 78, 
    3, 61, 5, 12, 0, 48, 8, 99, 6, 15, 2, 23, 7, 55, 4, 67, 1, 84, 
    2, 55, 8, 81, 5, 91, 1, 45, 6, 67, 0, 40, 4, 52, 3, 71, 7, 17
  };
  const int q9378[] = {
    9, 9, // Number of jobs and machines
    4, 24, 1, 99, 6, 35, 5, 95, 0, 58, 3, 91, 8, 90, 2, 95, 7, 55, 
    8, 30, 3, 46, 1, 22, 0, 83, 7, 14, 6, 85, 4, 56, 5, 16, 2, 48, 
    5, 39, 6, 26, 0, 23, 8, 75, 4,  1, 1, 70, 3,  1, 7, 54, 2, 70, 
    0, 37, 7,  6, 3, 23, 8, 10, 1, 17, 2, 42, 4, 31, 6, 27, 5, 95, 
    4,  2, 5, 59, 7, 65, 6, 92, 0, 51, 2, 15, 8, 16, 3, 24, 1, 34, 
    8, 49, 7,  3, 3, 92, 2,  4, 6, 63, 4, 16, 5, 68, 0, 12, 1, 97, 
    7, 44, 4, 19, 0, 52, 8, 26, 6,  5, 1, 57, 5, 22, 3, 95, 2, 62, 
    2, 42, 7, 52, 3, 28, 8, 65, 1, 39, 6, 30, 5,  4, 4, 96, 0, 37, 
    2, 94, 6, 37, 8,  1, 3, 87, 5, 44, 0, 60, 7,  1, 1, 90, 4, 82
  };
  const int q9379[] = {
    9, 9, // Number of jobs and machines
    4, 45, 0, 70, 8, 90, 3, 77, 1, 18, 5, 23, 6, 28, 7, 24, 2, 48, 
    8, 68, 4, 78, 3, 53, 6, 31, 0, 93, 1, 83, 2, 13, 5,  7, 7, 15, 
    6, 38, 5, 76, 0, 67, 3, 75, 4, 77, 7, 62, 8, 71, 2, 66, 1, 81, 
    5, 39, 6, 36, 8, 20, 7, 35, 4, 33, 0, 84, 1, 40, 2, 65, 3,  7, 
    6, 86, 3, 71, 4, 48, 1, 76, 5, 65, 2, 55, 0,  5, 7, 90, 8, 62, 
    8, 52, 5, 19, 4, 46, 6, 60, 7,  5, 1, 47, 2, 77, 3, 93, 0, 34, 
    3,  3, 7, 29, 6, 41, 5,  1, 1, 76, 8, 77, 4, 25, 2, 59, 0, 32, 
    4,  5, 5, 33, 3, 65, 6, 23, 1, 81, 2, 73, 8, 73, 0, 43, 7, 62, 
    4, 34, 0, 75, 1, 80, 7, 41, 6, 55, 5, 81, 3, 57, 8, 91, 2, 65
  };
  const int q9380[] = {
    9, 9, // Number of jobs and machines
    0, 73, 2, 89, 7, 34, 3,  8, 8,  5, 6, 40, 1, 86, 4, 10, 5, 97, 
    6, 81, 2, 96, 5, 53, 7, 98, 4, 34, 8, 14, 1, 94, 3, 48, 0, 18, 
    3, 13, 1,  9, 7, 89, 4, 56, 6,  7, 0, 33, 8, 89, 5, 25, 2, 12, 
    0, 94, 5, 74, 4, 36, 3, 31, 2, 53, 6, 58, 7, 45, 1, 86, 8, 85, 
    1, 85, 7, 73, 6, 31, 0, 43, 2, 71, 4, 60, 5, 43, 3, 67, 8, 33, 
    8, 40, 1, 57, 3, 15, 2, 68, 6, 12, 0, 88, 5, 71, 4, 74, 7, 50, 
    5, 70, 1, 81, 2, 44, 7, 12, 3, 58, 6, 51, 4, 57, 8, 92, 0, 71, 
    3, 36, 5, 34, 4, 70, 7, 54, 6, 76, 8, 84, 2,  4, 0, 73, 1, 13, 
    0, 70, 6, 78, 7, 89, 5, 99, 8,  7, 2, 79, 1, 33, 3, 15, 4, 25
  };
  const int q9381[] = {
    9, 9, // Number of jobs and machines
    2, 99, 1, 35, 3,  2, 7, 11, 5, 99, 4, 18, 6, 44, 0, 22, 8, 73, 
    8, 41, 6,  4, 3, 23, 0, 56, 7, 25, 4, 62, 1, 62, 2, 43, 5, 24, 
    0, 16, 6, 33, 8, 82, 3, 85, 4, 87, 1, 40, 2,  7, 7, 88, 5, 61, 
    8, 66, 3, 71, 6, 56, 4,  5, 2, 15, 7, 32, 1, 13, 5, 66, 0, 60, 
    5, 73, 0, 47, 3, 19, 8, 32, 4, 70, 2, 92, 1, 48, 6, 65, 7, 51, 
    6, 21, 4, 77, 2, 95, 8, 96, 5, 19, 3, 87, 7, 27, 0, 11, 1, 84, 
    0, 28, 8, 47, 7, 31, 5, 26, 1,  5, 6, 42, 2, 44, 4, 58, 3, 97, 
    2, 40, 5, 93, 0, 84, 4, 25, 1, 29, 8, 58, 7, 19, 3,  5, 6, 51, 
    6, 85, 4, 26, 1, 59, 5, 78, 7, 69, 3, 64, 2, 53, 8,  8, 0,  4
  };
  const int q9382[] = {
    9, 9, // Number of jobs and machines
    1, 12, 6, 57, 5, 68, 7, 95, 3, 97, 8, 25, 0, 22, 4, 62, 2,  9, 
    7, 66, 1, 67, 2, 98, 3, 86, 6, 36, 0, 26, 8, 15, 5,  3, 4,  7, 
    4,  8, 7, 12, 0,  5, 5, 66, 2, 96, 1,  9, 3, 96, 6, 29, 8, 24, 
    3, 17, 5, 65, 8, 65, 0, 16, 1, 42, 2, 50, 4, 57, 7,  6, 6, 85, 
    0, 42, 8, 67, 3, 27, 1, 51, 7, 39, 2, 24, 4, 60, 6,  3, 5, 18, 
    2, 38, 1,  8, 4, 36, 0, 69, 5, 83, 8, 73, 3, 60, 6, 13, 7, 67, 
    7, 52, 0, 59, 3, 63, 5, 45, 2, 37, 4, 23, 8, 31, 6,  2, 1, 40, 
    8, 86, 6, 85, 5, 98, 3, 39, 0, 56, 1, 14, 7, 87, 2, 39, 4, 26, 
    1, 96, 6, 65, 4, 37, 8, 46, 0, 98, 7, 56, 5, 40, 2, 50, 3, 14
  };
  const int q9383[] = {
    9, 9, // Number of jobs and machines
    6, 18, 2, 80, 7, 62, 3, 55, 1, 18, 5, 91, 4, 19, 0, 30, 8, 78, 
    5, 91, 8, 67, 0, 37, 6, 33, 1, 18, 7, 42, 2, 94, 3, 76, 4, 32, 
    4, 41, 8, 52, 1,  6, 3, 22, 7, 64, 5, 73, 6, 39, 0, 63, 2,  1, 
    3, 70, 6, 83, 8, 45, 5,  7, 2, 79, 4, 63, 0, 87, 7, 41, 1, 26, 
    4, 55, 7, 15, 8, 73, 6, 81, 5, 99, 0, 17, 3,  6, 1, 21, 2, 87, 
    5, 36, 6, 45, 8,  2, 4, 47, 3, 65, 2, 34, 7, 83, 0, 10, 1, 46, 
    5, 95, 1, 56, 0, 22, 6, 69, 2, 63, 3, 61, 8, 67, 4, 91, 7,  6, 
    1, 63, 4, 94, 2, 55, 8, 75, 7, 49, 6, 45, 5, 12, 0, 40, 3, 25, 
    2, 21, 0, 47, 8, 25, 6, 66, 5, 55, 3, 20, 7, 78, 4,  3, 1, 76
  };
  const int q9384[] = {
    9, 9, // Number of jobs and machines
    6, 39, 2, 15, 5,  7, 1, 99, 4, 51, 7, 37, 3,  4, 0, 89, 8, 53, 
    3, 86, 6,  2, 4, 47, 2, 45, 0, 98, 5, 30, 8, 70, 1, 36, 7, 83, 
    2,  2, 5, 16, 1, 14, 3,  4, 8, 54, 6, 52, 4, 54, 0,  4, 7, 22, 
    5, 10, 6, 64, 8, 21, 1, 34, 3,  1, 0, 22, 7, 65, 2, 68, 4, 59, 
    5,  6, 8, 26, 2, 95, 3,  6, 7, 43, 6, 53, 1, 13, 0, 85, 4, 65, 
    1, 94, 7, 94, 5, 23, 2, 31, 8, 17, 3, 70, 0, 42, 6, 53, 4, 28, 
    8, 13, 2,  6, 1,  8, 4,  5, 6, 79, 3, 32, 0, 93, 5,  3, 7, 64, 
    1, 22, 7, 38, 5, 95, 3, 32, 6, 98, 2, 53, 4, 20, 0, 72, 8,  8, 
    1,  7, 2, 99, 0, 36, 8, 12, 3, 42, 6, 97, 5, 24, 7, 48, 4, 86
  };
  const int q9385[] = {
    9, 9, // Number of jobs and machines
    7, 62, 2, 97, 4, 63, 5, 95, 0, 80, 1, 68, 8, 81, 3, 94, 6, 40, 
    2, 31, 4, 80, 0,  7, 8, 56, 5, 63, 1, 99, 3,  1, 6, 68, 7, 10, 
    5, 60, 6, 19, 7, 86, 2, 70, 4, 61, 8, 96, 0, 80, 1,  5, 3, 32, 
    2, 88, 3, 85, 4,  9, 1, 21, 5, 84, 0, 47, 7, 81, 8, 94, 6, 47, 
    7, 23, 0, 75, 2, 10, 6, 44, 4, 43, 5,  7, 8, 48, 3, 38, 1, 39, 
    4, 33, 5,  7, 8, 79, 6, 90, 2, 51, 0, 35, 7, 64, 1, 92, 3, 28, 
    4, 67, 0, 21, 2, 96, 6, 14, 7,  6, 8, 44, 3, 68, 1, 71, 5, 39, 
    4, 30, 8, 75, 6, 89, 0, 38, 7, 82, 1, 55, 3, 45, 5, 57, 2, 43, 
    0, 45, 1, 84, 4, 70, 5, 41, 3, 75, 2, 38, 8, 98, 7, 37, 6, 81
  };
  const int q9386[] = {
    9, 9, // Number of jobs and machines
    7, 88, 0,  3, 2, 56, 5, 88, 4,  9, 8, 36, 6, 25, 1, 75, 3, 55, 
    2, 72, 0, 90, 5, 82, 8, 31, 7,  2, 6, 93, 1, 97, 3, 10, 4, 68, 
    5, 98, 2, 69, 1, 12, 6, 84, 3, 82, 8, 94, 7, 76, 0, 47, 4, 68, 
    4, 29, 3, 46, 8, 97, 5, 63, 7, 91, 1, 73, 6, 68, 2, 78, 0, 85, 
    5, 61, 4, 81, 6, 81, 3, 50, 7, 36, 1,  5, 0, 77, 2, 71, 8, 66, 
    7,  5, 3, 31, 8, 11, 5, 20, 4, 89, 2, 55, 1, 99, 0, 24, 6, 56, 
    3, 34, 1, 33, 5, 40, 0, 80, 8, 96, 6, 19, 4, 57, 2, 68, 7, 81, 
    7, 74, 3, 73, 5, 65, 1, 33, 8, 12, 6, 27, 2, 36, 0, 90, 4, 24, 
    5, 46, 6,  9, 8, 73, 1, 71, 0, 73, 2, 25, 4,  5, 7, 44, 3, 41
  };
  const int q9387[] = {
    9, 9, // Number of jobs and machines
    5, 28, 1, 16, 0, 91, 8, 39, 4, 61, 7, 12, 6, 26, 3, 83, 2, 25, 
    3, 99, 4,  4, 8, 31, 0, 25, 6, 40, 7,  4, 5,  4, 2, 65, 1, 77, 
    7, 51, 4, 86, 3, 53, 1, 17, 0, 80, 8, 25, 5, 66, 2, 73, 6, 84, 
    5,  1, 1, 78, 8,  3, 6, 70, 0, 59, 4, 13, 3, 33, 2, 66, 7, 74, 
    4,  9, 7, 79, 8, 20, 5, 29, 2, 23, 3, 71, 6, 97, 0, 84, 1, 92, 
    7, 64, 6, 87, 5, 99, 8,  3, 2,  6, 4, 21, 3, 71, 1, 71, 0, 51, 
    6, 53, 8, 95, 4, 50, 5, 17, 3, 58, 7, 33, 2, 40, 0, 55, 1,  4, 
    7, 33, 2, 54, 0, 74, 5, 25, 1, 36, 3, 57, 8, 76, 4, 98, 6, 55, 
    8, 48, 3, 69, 4, 22, 2, 68, 6, 27, 7, 61, 0, 90, 5, 18, 1, 82
  };
  const int q9388[] = {
    9, 9, // Number of jobs and machines
    7, 56, 3, 48, 0, 56, 2, 34, 4, 16, 6, 97, 5, 83, 8, 51, 1,  6, 
    2, 20, 0, 99, 6, 13, 4, 51, 3, 83, 5, 24, 8, 46, 1, 29, 7,  8, 
    5, 12, 6, 19, 7, 16, 4, 31, 8, 66, 1, 78, 3,  7, 2, 75, 0, 71, 
    4, 19, 1, 33, 3, 72, 8,  3, 6, 56, 0, 72, 2, 58, 5, 63, 7, 22, 
    8, 87, 7, 26, 2, 78, 3, 70, 5, 59, 0, 14, 1, 21, 6, 65, 4, 44, 
    6, 36, 1, 24, 3, 74, 5, 24, 4, 44, 0, 76, 7, 32, 8, 13, 2, 38, 
    1, 93, 2, 55, 6, 99, 4, 79, 7, 78, 3, 14, 5, 37, 8, 30, 0, 97, 
    5, 94, 2, 48, 1, 74, 8, 21, 6, 13, 4, 64, 0, 90, 3, 99, 7, 23, 
    8, 42, 5,  7, 6, 34, 4, 45, 1, 53, 0, 77, 7, 89, 3, 97, 2, 62
  };
  const int q9389[] = {
    9, 9, // Number of jobs and machines
    0, 94, 7, 27, 3, 76, 5, 87, 2, 67, 4, 63, 1, 19, 8, 71, 6, 89, 
    7, 42, 3, 97, 1, 84, 5, 45, 8,  2, 6, 76, 0, 93, 2,  1, 4, 53, 
    2, 80, 6, 37, 4, 86, 8, 95, 0, 27, 7, 57, 1, 43, 3, 86, 5, 41, 
    3, 79, 8, 77, 1, 59, 6, 21, 0, 51, 5, 99, 2,  4, 4, 28, 7, 46, 
    2, 17, 4,  2, 8, 41, 0, 46, 7, 78, 3, 66, 5,  2, 1, 82, 6, 89, 
    1, 74, 8, 22, 5, 89, 4, 82, 3, 77, 7, 84, 6, 37, 2, 44, 0, 67, 
    5, 19, 1, 53, 0, 14, 6, 89, 2,  5, 3, 96, 4, 23, 7, 84, 8, 42, 
    7, 37, 2, 47, 5, 64, 4, 88, 0,  9, 6, 64, 3, 20, 1, 45, 8,  8, 
    2, 19, 8, 70, 1, 49, 7, 17, 6, 60, 3, 23, 4, 62, 0, 38, 5, 20
  };
  const int q9390[] = {
    9, 9, // Number of jobs and machines
    0, 57, 8, 98, 4, 23, 2, 40, 6, 64, 7, 93, 5, 39, 3, 98, 1, 52, 
    7, 53, 0, 67, 6, 17, 1, 19, 4, 85, 2, 64, 8, 83, 5, 74, 3, 73, 
    0, 22, 5, 44, 2, 29, 8, 27, 6, 35, 7, 34, 4, 28, 3, 76, 1, 84, 
    8, 67, 5, 26, 1, 60, 2, 60, 0, 73, 3,  8, 4, 39, 6, 27, 7, 25, 
    6, 31, 3, 85, 1, 20, 4, 26, 0, 32, 7, 82, 8, 11, 2, 25, 5, 73, 
    0,  9, 7,  7, 8, 78, 1, 39, 6, 15, 3, 61, 2, 99, 5, 87, 4, 23, 
    5, 18, 7, 29, 4, 90, 2, 54, 3, 51, 0,  4, 8, 57, 1, 73, 6, 64, 
    1, 55, 6, 36, 0, 75, 4, 65, 7, 83, 8, 68, 3, 38, 2, 36, 5,  9, 
    7, 71, 6, 51, 1, 99, 0, 36, 4, 72, 3, 74, 5, 30, 2, 96, 8, 42
  };
  const int q9391[] = {
    9, 9, // Number of jobs and machines
    0, 78, 8, 53, 5, 15, 2, 60, 7, 54, 4, 13, 1, 14, 6, 27, 3, 80, 
    0, 79, 7, 99, 5, 30, 1, 14, 6, 35, 2, 67, 8, 28, 3, 80, 4, 42, 
    8, 93, 0, 42, 5, 61, 6, 23, 7, 54, 4, 25, 1, 76, 2,  5, 3, 20, 
    2, 94, 7,  3, 3, 95, 4, 43, 1, 51, 6, 72, 5, 33, 8, 44, 0, 39, 
    7, 24, 6, 21, 1, 47, 0, 50, 3, 11, 8, 71, 5, 12, 2, 17, 4, 24, 
    3, 37, 7, 27, 8, 33, 2, 68, 6, 92, 1, 27, 0, 14, 4, 56, 5, 38, 
    4, 56, 2, 15, 5, 68, 0, 85, 7, 50, 1, 83, 8, 92, 3, 37, 6, 37, 
    6,  3, 2, 83, 0, 77, 1, 46, 8, 32, 7, 39, 3, 72, 4, 53, 5, 77, 
    5, 79, 7, 10, 4, 65, 2, 34, 3, 65, 6, 41, 0, 40, 8, 45, 1, 12
  };
  const int q9392[] = {
    9, 9, // Number of jobs and machines
    3, 28, 1, 47, 2, 91, 0,  5, 5, 10, 8, 30, 7, 30, 4, 58, 6, 23, 
    5, 15, 2, 21, 0, 13, 7,  4, 4, 64, 6, 80, 3, 60, 8, 85, 1, 89, 
    6, 57, 5, 56, 1,  3, 3, 30, 8, 76, 0, 11, 7, 51, 2, 21, 4,  3, 
    0, 81, 7, 76, 5, 67, 6, 13, 3,  1, 2, 37, 1, 64, 4, 50, 8, 80, 
    1, 40, 2, 93, 5,  8, 7, 49, 0, 19, 4, 62, 6, 32, 3, 52, 8, 19, 
    1, 60, 5, 85, 8, 42, 2, 17, 3, 81, 0, 46, 7, 87, 4, 43, 6, 95, 
    2, 97, 5, 38, 7,  9, 3, 71, 1, 40, 0, 53, 8, 87, 6, 98, 4, 50, 
    7, 11, 0, 75, 2, 75, 8, 64, 6, 47, 4, 80, 1,  2, 5, 87, 3, 73, 
    0, 90, 4, 35, 7, 88, 3, 30, 2, 36, 8, 17, 5, 63, 1, 15, 6, 93
  };
  const int q9393[] = {
    9, 9, // Number of jobs and machines
    4, 17, 3, 13, 7, 60, 6, 16, 0, 42, 1, 87, 2, 37, 8, 36, 5, 89, 
    5, 10, 2, 65, 3, 29, 7, 84, 0, 34, 8, 85, 6, 18, 4, 72, 1, 62, 
    7, 19, 2, 99, 4,  4, 8, 64, 6, 36, 3, 65, 1,  4, 5,  3, 0, 67, 
    0, 66, 6, 83, 3, 84, 8,  2, 7, 18, 2, 81, 4, 42, 1, 97, 5, 50, 
    3, 57, 0, 99, 2, 94, 7, 19, 8, 22, 1, 46, 4, 63, 5, 98, 6, 62, 
    0, 52, 7, 80, 4, 91, 8, 20, 5, 87, 3, 62, 2, 35, 6, 19, 1, 86, 
    4,  4, 7, 77, 6, 86, 2, 19, 5, 69, 0, 92, 8,  6, 1, 64, 3, 31, 
    2, 64, 5, 93, 6, 44, 8, 31, 0, 91, 1, 78, 3, 97, 7, 48, 4, 62, 
    2, 86, 4, 54, 5, 24, 7, 99, 8, 56, 1,  8, 6, 60, 3, 30, 0,  9
  };
  const int q9394[] = {
    9, 9, // Number of jobs and machines
    6, 41, 4, 61, 8, 29, 5, 56, 7, 74, 0, 33, 1, 21, 2, 94, 3, 58, 
    8, 31, 7, 84, 6, 94, 1, 71, 4,  6, 5, 85, 2, 76, 3, 75, 0, 45, 
    1, 47, 8, 77, 3, 62, 7, 20, 0, 72, 4, 33, 2, 21, 5, 99, 6, 79, 
    2, 46, 6, 34, 5, 20, 3, 64, 4, 77, 8,  9, 7, 14, 1, 51, 0, 21, 
    8, 57, 6, 67, 0, 48, 3, 41, 1, 25, 2,  7, 5,  4, 7, 37, 4, 60, 
    1, 44, 3, 29, 0, 32, 7,  8, 4, 18, 6, 79, 8, 96, 2, 70, 5, 83, 
    6, 35, 4, 61, 5, 61, 2, 84, 8, 14, 7, 56, 3, 98, 0, 13, 1, 13, 
    4, 77, 0, 15, 2, 43, 7, 81, 1, 98, 6, 42, 8, 53, 5, 26, 3, 62, 
    8, 61, 2, 34, 6, 37, 4, 55, 5, 13, 0, 69, 3, 27, 7, 43, 1, 17
  };
  const int q9395[] = {
    9, 9, // Number of jobs and machines
    6,  6, 3, 10, 1, 34, 8, 55, 0, 55, 7, 18, 2, 93, 5, 15, 4, 36, 
    8, 23, 3, 32, 5, 41, 1, 93, 0,  5, 2, 36, 6, 95, 7, 93, 4, 93, 
    5,  2, 6,  9, 8, 84, 0, 57, 3, 27, 4, 68, 1, 85, 7, 73, 2, 53, 
    4, 18, 3, 29, 0, 93, 8, 32, 1, 20, 7, 13, 2, 40, 6, 36, 5, 89, 
    2, 52, 1, 37, 6, 36, 5, 65, 7, 61, 4,  9, 8, 16, 0,  3, 3, 96, 
    6,  3, 1,  6, 4, 62, 0, 25, 5, 65, 2, 85, 7, 77, 3, 25, 8, 93, 
    2, 30, 6,  9, 7, 14, 8, 21, 0, 52, 5, 18, 4, 67, 1, 49, 3, 96, 
    5, 86, 3, 56, 1, 78, 7, 25, 4, 35, 6, 61, 2, 21, 0, 33, 8, 38, 
    2, 31, 8, 69, 0, 21, 7, 32, 1, 36, 4, 32, 5, 36, 3, 30, 6, 46
  };
  const int q9396[] = {
    9, 9, // Number of jobs and machines
    3, 25, 8, 21, 4, 93, 7, 63, 2, 63, 0, 48, 5, 66, 6, 96, 1, 82, 
    8, 83, 4, 64, 6, 95, 5, 93, 1, 29, 3, 70, 7, 41, 0, 32, 2, 69, 
    4, 94, 5, 35, 3, 27, 8, 26, 0, 41, 1, 30, 2, 17, 6, 74, 7, 79, 
    1, 52, 3, 56, 2, 55, 5, 44, 6, 66, 8, 71, 0, 90, 7, 28, 4, 42, 
    4, 93, 0, 51, 1, 34, 8, 86, 2, 90, 5,  9, 6, 76, 3, 86, 7, 68, 
    8,  1, 2, 48, 6, 67, 1, 79, 0, 28, 7, 42, 4, 17, 3,  6, 5, 51, 
    8, 86, 7, 72, 0, 18, 2, 65, 4, 30, 5, 27, 3, 85, 1, 29, 6, 35, 
    0, 48, 2, 65, 8, 76, 1, 42, 4, 36, 5, 76, 6, 27, 7, 61, 3, 48, 
    2, 25, 5, 74, 7, 70, 4, 31, 1, 77, 0, 37, 6, 10, 3, 19, 8, 25
  };
  const int q9397[] = {
    9, 9, // Number of jobs and machines
    4, 16, 3, 42, 1, 74, 5, 48, 7, 79, 8, 99, 0, 77, 6, 12, 2, 35, 
    3, 43, 5, 31, 6, 85, 7, 73, 2,  4, 4, 67, 1, 33, 8,  4, 0, 89, 
    4, 90, 3, 81, 7, 36, 0, 55, 2, 35, 1, 61, 6, 16, 8, 75, 5, 32, 
    0, 48, 3, 91, 7, 91, 1, 79, 4, 11, 2,  1, 6, 22, 8, 90, 5, 40, 
    1, 41, 5, 78, 8, 77, 6, 55, 0, 64, 7, 38, 4,  6, 2,  4, 3, 11, 
    7, 66, 5, 79, 8, 62, 3, 24, 0, 53, 6, 25, 2, 17, 1, 36, 4, 64, 
    3, 10, 6, 88, 4, 53, 1, 19, 7, 47, 8, 47, 0, 38, 2, 11, 5, 52, 
    5, 13, 3, 55, 2, 43, 7, 40, 8, 44, 0, 85, 4, 40, 6, 49, 1, 85, 
    2, 63, 1, 77, 6, 49, 0, 95, 3, 28, 4, 77, 5, 42, 8, 61, 7, 85
  };
  const int q9398[] = {
    9, 9, // Number of jobs and machines
    0, 89, 2, 43, 6, 90, 4, 41, 8, 46, 5, 72, 7, 29, 1,  5, 3, 67, 
    6, 90, 2, 21, 5, 84, 1, 73, 4, 34, 8, 93, 3, 24, 7, 59, 0, 60, 
    7, 77, 5, 86, 6, 44, 8, 94, 4,  6, 1, 74, 0, 64, 2, 48, 3, 62, 
    5, 24, 4, 20, 8, 33, 3, 57, 1, 99, 7, 58, 0, 56, 6, 56, 2, 70, 
    7, 84, 1, 75, 3, 46, 0,  5, 6, 41, 4, 46, 2, 31, 8, 66, 5, 28, 
    4,  6, 7, 93, 6, 99, 8, 79, 1, 92, 5, 98, 2, 39, 0,  7, 3,  8, 
    3, 79, 0, 85, 7, 21, 2, 91, 8,  1, 6, 74, 4, 12, 1, 58, 5, 52, 
    0,  5, 7, 63, 8, 49, 2, 26, 3, 21, 5, 50, 6, 15, 1, 59, 4, 90, 
    6, 18, 1, 26, 2, 71, 0,  2, 5, 27, 4, 84, 7, 72, 3,  6, 8, 96
  };
  const int q9399[] = {
    9, 9, // Number of jobs and machines
    8, 99, 5, 71, 7, 59, 3, 23, 6, 76, 2, 25, 1, 37, 0, 63, 4,  9, 
    2, 23, 3, 13, 6, 52, 5, 29, 7, 90, 4, 57, 8, 70, 0, 57, 1, 93, 
    5, 94, 3, 83, 6, 78, 1, 29, 7, 73, 2, 17, 4, 94, 8, 94, 0, 47, 
    1, 82, 6, 56, 2, 33, 7, 88, 5, 81, 0,  6, 8, 63, 4,  8, 3, 20, 
    8, 11, 5, 64, 2, 69, 7, 73, 1, 45, 3,  7, 0,  1, 6, 83, 4, 79, 
    1,  4, 0, 27, 8, 27, 5, 59, 6, 86, 4, 75, 2, 78, 3, 33, 7,  6, 
    1, 39, 8, 69, 0, 21, 7, 91, 4, 18, 5, 37, 3, 99, 2, 38, 6, 19, 
    8, 73, 1, 70, 4, 78, 7, 17, 0, 68, 3, 52, 6, 40, 5, 90, 2, 90, 
    6, 34, 5,  6, 8, 87, 1, 92, 7, 23, 2,  5, 0,  1, 4, 92, 3, 36
  };
  const int q9400[] = {
    9, 9, // Number of jobs and machines
    7, 29, 4, 36, 2, 74, 5, 69, 1, 27, 8, 51, 6, 40, 0, 55, 3, 80, 
    7, 39, 1, 32, 5, 40, 8, 92, 6, 48, 3, 18, 0, 54, 2, 53, 4, 27, 
    7, 66, 5, 35, 2, 81, 0, 19, 6, 79, 8, 52, 1, 95, 3, 32, 4, 61, 
    3, 72, 4, 85, 7, 64, 8, 32, 5, 28, 0, 10, 1, 10, 6, 67, 2, 75, 
    8, 37, 2, 82, 1, 78, 0, 18, 3,  5, 4, 56, 6, 50, 5, 15, 7, 32, 
    5, 69, 1, 14, 0, 41, 7, 13, 2, 52, 8,  3, 3, 78, 4, 73, 6, 24, 
    7, 76, 6, 93, 1, 16, 3, 94, 8, 13, 2, 22, 5, 72, 4, 96, 0, 49, 
    1, 17, 7, 72, 3, 30, 6, 50, 5, 18, 8, 90, 2, 37, 4, 69, 0, 72, 
    3,  9, 4, 31, 6, 87, 1, 44, 0, 95, 5, 24, 8, 86, 7, 63, 2, 27
  };
  const int q9401[] = {
    9, 9, // Number of jobs and machines
    5, 71, 8, 30, 7, 79, 2, 66, 0, 30, 6, 75, 4, 69, 3, 71, 1, 20, 
    3, 30, 6, 78, 0, 59, 2, 86, 1, 60, 4, 93, 5, 86, 8, 88, 7, 27, 
    0, 30, 4, 68, 5, 77, 6, 71, 3, 90, 1, 13, 2, 92, 8, 96, 7, 48, 
    0, 69, 3, 69, 4, 94, 6, 62, 2, 53, 8, 42, 1,  1, 5, 77, 7, 96, 
    5, 26, 7, 56, 4,  2, 1, 19, 6, 49, 2, 67, 3, 58, 0, 52, 8, 15, 
    8, 50, 1, 98, 5, 41, 0, 19, 2, 68, 4, 84, 3, 59, 7, 32, 6, 99, 
    4, 97, 0, 12, 1, 75, 7, 26, 6, 62, 2, 41, 3, 90, 8, 43, 5, 56, 
    8, 88, 2, 91, 7, 51, 6, 89, 1, 88, 3, 40, 4, 78, 5, 39, 0, 61, 
    5, 39, 6,  7, 2, 92, 4, 43, 1, 94, 7, 12, 0,  7, 3, 24, 8, 26
  };
  const int q9402[] = {
    9, 9, // Number of jobs and machines
    6, 22, 2, 48, 7, 17, 5, 92, 4, 74, 1, 43, 3, 45, 0, 97, 8, 82, 
    1, 29, 0, 71, 2, 15, 5, 19, 7,  4, 4, 45, 8, 50, 6, 44, 3, 88, 
    5,  2, 3, 89, 4, 46, 0, 19, 8, 32, 7, 54, 2,  9, 1,  4, 6, 32, 
    8, 89, 3, 79, 4, 38, 7, 22, 1, 63, 6, 64, 5, 89, 2, 27, 0,  6, 
    6, 36, 5,  6, 1, 30, 7, 48, 2, 88, 8, 88, 4, 14, 0, 69, 3, 80, 
    3, 31, 0, 33, 4, 43, 1, 86, 7, 95, 8, 29, 5, 69, 2, 96, 6, 20, 
    2, 11, 0, 20, 3, 69, 6, 52, 7, 82, 4, 18, 1, 44, 5, 40, 8, 75, 
    4, 64, 5, 74, 8, 37, 1, 22, 0, 48, 3, 41, 6,  4, 2, 78, 7, 12, 
    5, 74, 8,  9, 3,  5, 6, 31, 2, 58, 4, 81, 1, 38, 0, 72, 7, 46
  };
  const int q9403[] = {
    9, 9, // Number of jobs and machines
    1, 46, 7, 20, 8, 86, 0, 34, 6, 92, 5, 73, 2, 63, 3, 44, 4, 95, 
    0,  1, 6, 56, 3, 24, 8, 24, 1, 97, 4, 72, 7, 72, 5, 80, 2, 50, 
    1, 54, 2, 97, 8, 73, 0, 23, 3, 76, 5, 97, 4, 14, 7, 18, 6, 43, 
    5, 92, 6,  3, 2, 45, 7, 69, 3, 40, 8, 95, 0, 23, 1,  1, 4, 21, 
    0, 52, 5, 82, 4, 64, 6, 85, 1, 39, 7, 83, 8, 27, 2, 70, 3, 67, 
    7, 50, 6, 12, 0, 74, 5, 56, 2, 73, 8, 15, 1, 98, 4, 19, 3, 31, 
    0, 65, 4, 40, 8, 79, 1, 31, 2, 10, 6, 35, 5, 78, 7, 63, 3, 74, 
    2, 50, 0, 24, 6, 73, 3, 95, 5, 75, 7, 78, 8, 31, 1, 82, 4,  7, 
    5, 16, 6, 75, 2,  1, 1, 84, 4, 22, 8, 50, 0, 40, 7, 16, 3, 28
  };
  const int q9404[] = {
    9, 9, // Number of jobs and machines
    4, 49, 0, 49, 2, 66, 7, 16, 6, 53, 8,  2, 3, 89, 1, 32, 5, 20, 
    5, 53, 6, 97, 0, 76, 7, 68, 1, 37, 3, 81, 4,  7, 8, 12, 2,  5, 
    2, 86, 8, 33, 1,  6, 6, 12, 4, 73, 0,  3, 3,  3, 5, 52, 7, 58, 
    7, 75, 4, 65, 6,  2, 0, 30, 5, 67, 3, 87, 2, 73, 1, 54, 8, 19, 
    3, 91, 2, 71, 7, 20, 0, 49, 4, 11, 6, 96, 5, 41, 8, 18, 1, 60, 
    6, 30, 0, 24, 5, 75, 2, 97, 8,  9, 1, 52, 7, 59, 4, 55, 3, 87, 
    6, 38, 5, 43, 8,  3, 2, 83, 3, 11, 7, 76, 4, 59, 1,  2, 0, 44, 
    2, 77, 7, 62, 0, 36, 6, 35, 5, 80, 1, 33, 3, 66, 4, 93, 8,  5, 
    2, 43, 8,  4, 6, 26, 5, 33, 7, 22, 1, 55, 0, 43, 4, 47, 3, 62
  };
  const int q9405[] = {
    9, 9, // Number of jobs and machines
    0, 73, 3,  5, 6, 40, 8, 65, 5, 30, 4, 69, 7, 84, 1, 13, 2, 14, 
    3,  8, 1, 28, 2, 14, 7, 33, 0, 91, 5, 54, 8, 45, 4, 76, 6, 34, 
    7, 94, 8, 32, 1, 83, 2, 19, 0,  3, 3, 58, 4,  8, 5, 78, 6,  9, 
    5, 64, 6, 59, 4, 85, 2, 75, 8,  4, 7, 90, 0, 31, 1, 69, 3, 60, 
    4, 26, 3, 71, 0,  6, 6, 64, 2, 16, 8, 29, 7, 67, 1, 52, 5, 45, 
    2, 20, 1, 80, 7,  3, 8, 80, 4, 15, 5, 66, 0, 69, 6,  5, 3, 10, 
    5,  2, 2, 75, 1, 10, 4, 95, 3, 42, 0, 53, 7, 26, 6, 37, 8, 39, 
    8, 48, 7, 57, 0, 95, 1, 22, 5, 42, 6,  3, 3, 12, 4, 67, 2, 58, 
    1, 31, 0, 84, 4, 98, 3,  8, 2, 98, 6, 69, 5, 72, 7, 72, 8, 12
  };
  const int q9406[] = {
    9, 9, // Number of jobs and machines
    1, 93, 5, 21, 6, 10, 0, 20, 8, 23, 7, 92, 4, 30, 2, 11, 3, 97, 
    3, 54, 6, 71, 2, 71, 5, 10, 8, 67, 4, 51, 7, 69, 0,  2, 1, 85, 
    1, 75, 0, 79, 3, 45, 6, 21, 5, 96, 4, 97, 7, 44, 2, 85, 8, 72, 
    4, 39, 1, 20, 2, 31, 5,  1, 6, 56, 7,  8, 8,  5, 0, 68, 3,  9, 
    8, 13, 7,  8, 0, 97, 1, 21, 2, 83, 3, 59, 4, 12, 6, 76, 5, 59, 
    3, 45, 0, 91, 7, 54, 5, 44, 4, 42, 6, 29, 1, 76, 8, 67, 2, 84, 
    1, 69, 8, 29, 3, 91, 4, 97, 7, 60, 0, 75, 6, 83, 2, 73, 5, 12, 
    6, 75, 1, 63, 3, 17, 8, 73, 4, 70, 7, 35, 0, 94, 5, 16, 2, 18, 
    3, 69, 7, 50, 2, 68, 0, 79, 6, 59, 5, 35, 4, 83, 8, 13, 1, 53
  };
  const int q9407[] = {
    9, 9, // Number of jobs and machines
    6, 84, 5, 16, 2, 41, 1, 56, 0, 68, 4, 55, 8, 60, 7, 63, 3, 15, 
    8, 20, 0, 68, 4, 63, 5, 26, 2, 31, 6, 33, 1, 63, 7, 11, 3, 57, 
    1, 21, 6, 96, 0, 96, 5, 86, 8, 43, 7, 94, 4, 35, 3, 62, 2, 84, 
    5, 76, 8, 76, 6, 16, 2, 39, 0, 35, 7, 79, 3, 79, 4, 72, 1, 78, 
    0, 90, 4, 49, 2, 99, 3, 93, 5,  4, 6, 21, 8, 52, 1, 40, 7,  9, 
    6,  8, 7, 99, 2, 20, 8, 11, 3, 44, 0, 97, 1, 18, 4, 56, 5, 88, 
    4, 96, 2, 67, 7, 73, 3, 40, 8, 80, 5, 51, 6, 76, 1, 62, 0, 86, 
    3, 56, 5, 76, 0,  1, 7,  6, 1, 40, 4, 27, 2, 39, 6, 61, 8, 96, 
    0, 50, 2, 18, 7, 75, 5, 27, 3, 70, 8, 60, 1, 37, 4, 84, 6, 77
  };
  const int q9408[] = {
    9, 9, // Number of jobs and machines
    5, 36, 7, 44, 4, 97, 8, 64, 0, 14, 1, 60, 3, 28, 2, 67, 6, 60, 
    6,  8, 3, 46, 7, 57, 8, 13, 0, 12, 1, 89, 5, 14, 4, 67, 2,  7, 
    7, 46, 6, 43, 1, 40, 3, 87, 4, 29, 8, 10, 5, 85, 2, 59, 0, 98, 
    5, 47, 4, 47, 7, 64, 3, 54, 2, 91, 1, 30, 8, 28, 6, 13, 0, 80, 
    1, 29, 3, 37, 7, 12, 4, 68, 0, 57, 2, 25, 8, 30, 6, 90, 5,  2, 
    5, 59, 6, 13, 7, 18, 3, 24, 1, 10, 2,  1, 0, 95, 4, 88, 8, 14, 
    4, 96, 7, 87, 0, 52, 6, 40, 5, 96, 2,  1, 8, 86, 3, 20, 1, 59, 
    4, 80, 0, 42, 6, 57, 1, 87, 8, 37, 7, 86, 2, 93, 3, 34, 5, 34, 
    7, 96, 5, 95, 0, 27, 6, 19, 8, 59, 2, 69, 4, 97, 3,  9, 1, 67
  };
  const int q9409[] = {
    9, 9, // Number of jobs and machines
    4, 92, 7, 13, 0, 91, 2,  7, 1, 76, 8, 35, 5, 49, 6, 38, 3, 17, 
    2, 46, 5, 83, 3, 17, 7, 98, 8, 10, 4, 53, 1, 77, 0, 57, 6, 80, 
    3, 24, 4, 40, 5, 93, 7, 54, 6, 31, 8, 70, 0, 56, 1,  4, 2, 37, 
    5, 22, 8, 72, 3, 14, 4, 97, 2, 42, 6, 42, 1, 49, 7, 15, 0, 20, 
    7, 66, 6, 73, 2,  4, 8, 40, 0, 48, 1, 24, 3, 97, 4, 50, 5, 80, 
    2,  6, 5, 37, 4, 69, 8,  7, 1, 49, 0, 51, 3, 67, 6, 69, 7, 21, 
    4,  2, 6, 48, 0, 94, 7, 27, 8,  5, 1, 54, 3,  6, 5, 60, 2, 12, 
    7, 20, 3, 38, 2, 43, 8, 60, 5, 94, 4, 43, 6, 23, 0, 25, 1, 12, 
    3, 21, 2, 31, 5,  1, 7, 89, 8,  2, 0, 36, 4, 95, 6, 97, 1, 21
  };
  const int q9410[] = {
    9, 9, // Number of jobs and machines
    7, 11, 3, 82, 0, 27, 1, 19, 6, 20, 4, 51, 5, 28, 2, 87, 8, 54, 
    5, 35, 2, 22, 0, 38, 3, 36, 1, 96, 6, 86, 8,  3, 7, 54, 4, 51, 
    2, 39, 1, 23, 4, 73, 7, 67, 0, 96, 6, 72, 8, 36, 3, 95, 5, 92, 
    0, 45, 4, 18, 1, 25, 6, 17, 7, 95, 2,  4, 8, 27, 3, 59, 5, 42, 
    6, 73, 2, 47, 7, 14, 8, 76, 4, 62, 0,  5, 5,  4, 1, 25, 3, 54, 
    7, 56, 5, 69, 8, 89, 1, 82, 3, 24, 6, 60, 2, 23, 0, 82, 4, 91, 
    1, 68, 6, 56, 7, 53, 8,  4, 2, 86, 4,  9, 3, 41, 0, 57, 5, 65, 
    5, 15, 6, 54, 1, 66, 2, 51, 0, 29, 4, 45, 8, 99, 3, 92, 7, 26, 
    2,  2, 6,  7, 1, 55, 8,  1, 0, 57, 4, 35, 5, 69, 3, 95, 7, 45
  };
  const int q9411[] = {
    9, 9, // Number of jobs and machines
    8, 43, 1,  5, 4, 60, 6, 37, 7, 38, 5, 64, 0, 70, 2, 55, 3,  8, 
    8, 52, 6, 83, 1, 66, 2, 20, 0, 15, 7, 19, 4, 59, 5,  4, 3, 77, 
    1, 77, 4, 54, 0, 46, 8, 51, 6, 98, 5, 58, 7, 17, 3, 60, 2, 79, 
    3,  2, 1, 28, 8, 28, 4, 66, 0, 73, 2, 75, 7, 52, 6, 14, 5, 62, 
    3, 75, 4, 37, 0, 97, 7, 12, 8, 70, 5,  2, 6, 25, 1, 85, 2, 25, 
    5, 25, 7, 51, 3, 96, 6, 22, 4, 23, 8, 53, 2, 57, 1, 76, 0, 74, 
    5, 58, 4, 41, 0, 46, 7, 59, 3, 22, 2, 66, 8, 36, 6, 26, 1, 64, 
    0, 96, 6, 24, 3, 70, 7,  7, 2, 16, 1, 41, 8, 47, 4, 54, 5, 81, 
    1, 45, 7, 60, 0,  3, 2, 26, 5, 11, 4, 75, 3, 31, 6, 51, 8, 17
  };
  const int q9412[] = {
    9, 9, // Number of jobs and machines
    0, 53, 1, 75, 3, 80, 5, 57, 6, 92, 8, 67, 2, 93, 7,  5, 4, 59, 
    6, 38, 4, 67, 0, 87, 8, 26, 3, 91, 7, 84, 1, 13, 5, 44, 2, 94, 
    4, 13, 8, 43, 3, 72, 6, 34, 5, 19, 7, 65, 2, 79, 0, 71, 1,  5, 
    4, 14, 2, 27, 6, 47, 3, 24, 1,  2, 7, 95, 8, 54, 5, 59, 0, 46, 
    8, 33, 5, 90, 3, 51, 2, 23, 7, 78, 4, 76, 6, 61, 1, 17, 0,  7, 
    8, 32, 6, 97, 2, 94, 3, 90, 4, 47, 0, 87, 1, 54, 7, 62, 5, 76, 
    0, 84, 2, 13, 7, 43, 6, 55, 4, 78, 1,  6, 5, 21, 8, 83, 3, 89, 
    8,  7, 2, 36, 4, 35, 5, 96, 1,  5, 0, 67, 7,  5, 6, 39, 3, 25, 
    6, 13, 0, 10, 5, 95, 4,  4, 1, 23, 3, 72, 2, 97, 8, 84, 7, 29
  };
  const int q9413[] = {
    9, 9, // Number of jobs and machines
    6, 30, 2, 21, 0,  3, 8, 58, 7,  9, 5, 48, 1,  6, 3, 56, 4, 44, 
    1, 77, 4, 34, 7, 63, 6, 77, 2, 67, 8, 11, 5, 64, 0, 55, 3, 42, 
    5, 91, 2, 46, 1, 97, 0, 44, 6, 90, 3, 80, 4, 53, 8, 43, 7, 92, 
    7, 37, 8, 13, 1, 95, 2, 35, 0, 53, 6, 92, 4,  1, 3, 40, 5, 38, 
    0, 61, 6,  5, 7, 95, 8, 25, 4, 86, 2, 21, 5, 99, 3, 67, 1, 67, 
    7, 59, 8, 68, 6, 64, 1, 99, 2, 36, 5, 74, 4, 61, 0, 57, 3, 78, 
    4, 33, 2, 42, 3, 71, 1, 29, 0, 95, 8, 40, 6, 76, 7, 74, 5, 33, 
    0,  2, 1, 48, 2, 10, 6, 22, 5, 65, 8, 70, 3, 44, 4, 40, 7, 88, 
    0, 58, 5, 62, 1, 68, 6, 70, 3, 43, 4, 45, 7, 73, 2, 93, 8,  6
  };
  const int q9414[] = {
    9, 9, // Number of jobs and machines
    3, 42, 0,  6, 1, 11, 7, 72, 5, 50, 6, 24, 4, 73, 8, 15, 2, 34, 
    1, 95, 4, 91, 6, 77, 2, 26, 3, 10, 0, 58, 5, 90, 8, 49, 7, 28, 
    8, 98, 1, 45, 5, 84, 4, 87, 0, 55, 2, 29, 7, 11, 6, 70, 3, 91, 
    1, 80, 6, 97, 8,  5, 4, 88, 7, 71, 0, 69, 2, 32, 5, 49, 3, 69, 
    7,  2, 8, 28, 6, 90, 1, 48, 5, 86, 4,  4, 3, 71, 2, 85, 0, 15, 
    6, 80, 7, 69, 8, 68, 4, 84, 5, 27, 2, 39, 0, 54, 1, 47, 3, 22, 
    2, 55, 1, 68, 3, 11, 7, 57, 4, 46, 6, 83, 5, 52, 8, 76, 0, 61, 
    5, 10, 0, 20, 4, 78, 2, 43, 3, 38, 7, 44, 1, 45, 8, 96, 6, 69, 
    7, 16, 2, 43, 5, 55, 3,  7, 0, 99, 8, 13, 1,  4, 6, 18, 4, 95
  };
  const int q9415[] = {
    9, 9, // Number of jobs and machines
    2, 74, 6, 15, 0, 45, 7, 47, 1, 49, 4, 90, 3,  5, 8, 48, 5, 89, 
    1, 39, 8, 98, 5, 52, 6,  4, 7, 90, 0, 80, 2, 32, 4, 38, 3, 92, 
    2,  9, 4, 55, 7, 56, 3,  5, 6, 69, 0, 99, 5, 80, 1, 29, 8, 17, 
    2, 85, 5, 76, 6, 90, 0, 36, 4, 18, 8, 27, 1, 44, 7, 19, 3, 76, 
    7, 76, 0, 54, 2, 48, 6, 89, 3, 67, 1,  7, 8, 80, 4, 85, 5, 81, 
    3, 67, 0, 67, 7, 85, 6,  2, 4, 57, 5, 11, 2, 66, 1, 69, 8, 67, 
    4, 53, 6, 67, 8, 40, 7, 56, 5, 64, 3, 98, 2, 65, 1, 84, 0,  6, 
    4,  4, 3, 12, 7, 65, 6, 72, 5, 80, 2, 88, 1, 85, 8, 56, 0, 73, 
    4, 64, 6, 42, 0, 33, 7, 21, 2, 47, 8, 20, 5, 66, 1, 20, 3, 72
  };
  const int q9416[] = {
    9, 9, // Number of jobs and machines
    2, 67, 1, 70, 0, 23, 4, 74, 7, 66, 6, 96, 5, 87, 8, 89, 3, 57, 
    5, 81, 2, 31, 0, 51, 7, 48, 3, 91, 4, 85, 8, 12, 1,  9, 6, 79, 
    0, 83, 5, 53, 3, 20, 6, 79, 8, 32, 4, 60, 7, 95, 1, 10, 2, 16, 
    8, 38, 0, 61, 5, 13, 1, 84, 6, 19, 2,  3, 4, 35, 7, 99, 3, 13, 
    8,  6, 7, 51, 3, 24, 2, 49, 4, 40, 0, 70, 1, 85, 5, 35, 6, 38, 
    8,  2, 7, 43, 1, 88, 6, 95, 2, 37, 0, 86, 4, 12, 3, 89, 5, 96, 
    3, 53, 4, 40, 2, 53, 5, 64, 8, 98, 7, 97, 1, 72, 6, 44, 0, 59, 
    6, 80, 7, 30, 1, 38, 5, 36, 8, 74, 3, 98, 2, 49, 0, 18, 4, 46, 
    8, 56, 7, 29, 5, 45, 2, 38, 0, 36, 4, 98, 6, 49, 1, 34, 3, 58
  };
  const int q9417[] = {
    9, 9, // Number of jobs and machines
    6, 64, 0, 69, 1, 83, 5, 23, 2, 20, 7, 62, 4, 35, 8, 27, 3, 25, 
    4, 15, 7, 85, 1, 68, 2, 95, 6, 47, 8, 26, 5, 10, 0, 48, 3, 63, 
    3, 10, 8, 10, 7, 83, 6, 35, 1, 57, 0, 66, 4,  1, 2, 14, 5, 94, 
    8, 70, 6, 17, 1, 79, 2, 78, 4, 12, 7, 34, 5, 31, 3, 83, 0, 71, 
    8, 21, 1, 65, 2, 45, 4, 94, 5, 66, 6, 48, 0, 49, 3, 53, 7,  6, 
    1,  7, 6, 16, 3, 27, 5, 27, 2, 59, 8, 52, 0, 63, 4, 70, 7, 68, 
    2, 36, 5, 19, 8, 41, 7, 81, 4, 70, 3, 32, 6,  1, 1, 67, 0,  4, 
    2, 16, 1, 93, 5, 59, 8, 47, 3, 60, 4, 25, 7, 69, 0, 14, 6, 40, 
    6, 30, 1, 91, 5, 91, 3, 75, 0, 62, 4, 72, 7, 52, 2, 67, 8, 70
  };
  const int q9418[] = {
    9, 9, // Number of jobs and machines
    0, 65, 4, 82, 1,  6, 6, 91, 5, 85, 2, 38, 8, 43, 7, 34, 3, 32, 
    4, 98, 5, 72, 0, 73, 6, 96, 1, 44, 3, 87, 2, 93, 7, 88, 8,  5, 
    8, 44, 5, 64, 7, 55, 3, 64, 0, 27, 2, 12, 4, 58, 1, 75, 6, 72, 
    1, 68, 3, 17, 4, 33, 5, 39, 2, 26, 8, 41, 7, 44, 6, 95, 0, 62, 
    5, 84, 7, 82, 1, 82, 2,  7, 8, 25, 4, 75, 6, 97, 3, 88, 0, 56, 
    7, 81, 3, 90, 0,  8, 1, 61, 6, 45, 8, 60, 2, 43, 5, 56, 4, 52, 
    0, 53, 7, 84, 1, 40, 8, 17, 6, 19, 3, 88, 2, 31, 4,  3, 5, 27, 
    3, 71, 6, 80, 8,  8, 0, 79, 7, 36, 1, 59, 2, 90, 5, 38, 4, 50, 
    8, 92, 5, 50, 6, 15, 7, 15, 1,  5, 0, 48, 3, 78, 2, 73, 4, 54
  };
  const int q9419[] = {
    9, 9, // Number of jobs and machines
    1, 39, 0, 88, 4, 74, 3,  2, 8, 82, 2, 97, 5, 76, 7, 63, 6, 81, 
    7, 43, 5, 14, 3, 45, 6, 55, 1, 23, 0, 56, 4, 27, 8, 79, 2, 16, 
    4,  5, 0, 94, 5, 36, 7, 61, 3, 37, 2, 26, 6, 20, 8, 76, 1,  9, 
    5,  8, 0, 99, 8, 94, 2,  8, 6, 63, 4, 34, 1, 52, 7, 33, 3, 87, 
    0, 47, 3, 31, 7,  5, 5, 50, 6, 62, 2, 21, 1,  4, 8, 70, 4, 29, 
    5, 27, 1, 43, 6, 23, 4, 46, 7, 96, 0, 62, 8,  1, 3, 37, 2, 55, 
    8, 37, 7,  8, 0,  4, 6, 49, 2, 80, 5, 53, 3,  8, 4, 66, 1, 93, 
    2, 60, 1, 12, 4, 36, 3, 96, 7, 12, 5, 68, 8,  3, 6, 76, 0, 72, 
    1, 60, 0, 79, 3, 91, 2, 41, 8, 16, 6, 75, 4, 86, 7, 39, 5, 27
  };
  const int q9420[] = {
    9, 9, // Number of jobs and machines
    5, 65, 2, 22, 4, 32, 6, 19, 3, 50, 7,  5, 1, 19, 0, 86, 8, 38, 
    8, 92, 4, 94, 2, 50, 0,  2, 3,  3, 7, 99, 1, 86, 5, 23, 6, 51, 
    3, 36, 4, 84, 1, 58, 0, 73, 2, 83, 8, 15, 6, 25, 7, 30, 5, 60, 
    5, 83, 0, 85, 3, 28, 7, 30, 1, 51, 4, 15, 2, 41, 8, 42, 6, 15, 
    2, 50, 1, 42, 5, 41, 6, 89, 8, 40, 3,  6, 0, 85, 4, 98, 7, 62, 
    1, 31, 7, 19, 3, 84, 0, 75, 5, 15, 6, 23, 4, 78, 2, 95, 8, 44, 
    8, 55, 6, 41, 2, 63, 0, 83, 4, 36, 3, 28, 1, 98, 7, 41, 5, 77, 
    6, 49, 8, 75, 0, 61, 7,  1, 3, 59, 1,  2, 5, 47, 4, 93, 2, 32, 
    5, 67, 6, 37, 0, 14, 4, 80, 8, 43, 7, 99, 1, 48, 2, 56, 3, 43
  };
  const int q9421[] = {
    9, 9, // Number of jobs and machines
    6, 68, 7, 23, 3, 19, 5, 31, 1, 39, 2, 19, 0, 60, 8, 46, 4, 95, 
    1, 81, 3, 54, 2, 18, 4, 20, 0, 69, 8, 93, 7, 95, 5, 12, 6, 77, 
    2, 13, 8, 69, 7, 38, 5, 38, 4, 76, 0, 71, 1, 95, 6, 63, 3,  4, 
    6, 95, 0, 82, 3, 48, 5, 85, 2, 93, 1, 85, 4, 98, 8,  9, 7, 90, 
    2, 78, 5, 83, 8, 15, 6, 80, 0, 54, 4, 51, 7, 54, 1, 17, 3, 82, 
    0, 59, 1, 45, 2, 16, 3, 17, 4, 15, 8, 19, 6, 24, 5,  1, 7,  8, 
    3, 21, 6,  4, 1,  2, 5, 47, 4,  3, 7, 82, 2, 62, 8, 64, 0, 39, 
    2, 13, 0, 42, 7, 52, 8, 63, 5, 28, 1, 95, 3, 93, 4, 14, 6, 60, 
    6, 94, 0, 38, 2,  1, 7, 94, 8,  9, 5, 39, 3, 24, 1, 62, 4,  2
  };
  const int q9422[] = {
    9, 9, // Number of jobs and machines
    0, 36, 3, 38, 7, 29, 4, 49, 8, 83, 1, 23, 6, 99, 2, 37, 5, 48, 
    3, 30, 0, 56, 1, 15, 2, 47, 4, 23, 5, 45, 6, 61, 7, 67, 8, 22, 
    3, 62, 0, 19, 2, 12, 4, 69, 8, 27, 6, 69, 7, 63, 1, 13, 5, 78, 
    7, 22, 3, 27, 8, 32, 5, 71, 0, 78, 6, 16, 4, 57, 1, 19, 2, 57, 
    4, 55, 8, 92, 3, 19, 5, 27, 2, 14, 7, 93, 1, 45, 6,  2, 0, 31, 
    4, 35, 6, 72, 3, 96, 5, 22, 1, 45, 2, 22, 8, 43, 7,  6, 0, 46, 
    4, 93, 7, 47, 2, 49, 5, 67, 8, 40, 1, 31, 6, 79, 3, 68, 0, 52, 
    7, 82, 3, 27, 4, 72, 1, 75, 8, 70, 0, 21, 5, 51, 6, 98, 2, 79, 
    6,  1, 0, 62, 1, 60, 4, 45, 3, 38, 7, 28, 5, 56, 8, 27, 2, 15
  };
  const int q9423[] = {
    9, 9, // Number of jobs and machines
    3, 66, 6, 85, 7, 16, 5, 20, 2, 44, 4, 66, 0, 23, 8, 98, 1, 47, 
    4, 67, 2, 36, 7, 37, 1, 12, 3, 62, 6,  6, 5, 41, 0, 85, 8, 77, 
    8, 31, 1, 27, 2, 84, 7, 91, 6, 82, 5, 51, 3, 56, 0, 45, 4, 28, 
    2, 79, 4, 14, 7,  1, 0, 36, 5, 44, 6, 12, 3, 61, 8, 52, 1, 51, 
    0, 80, 4, 30, 7, 60, 1, 47, 3, 83, 8, 85, 2, 66, 5, 82, 6, 88, 
    4, 12, 7, 40, 5, 14, 6,  8, 8, 77, 2, 70, 1, 97, 3, 62, 0, 97, 
    6, 47, 0, 91, 4, 79, 7, 16, 2, 48, 8,  3, 3, 45, 5,  3, 1, 59, 
    5, 59, 8, 85, 7, 63, 0, 28, 2, 91, 1, 30, 6, 98, 4, 99, 3, 97, 
    2, 12, 4, 59, 7, 72, 1, 10, 8, 98, 0, 97, 6, 79, 3, 18, 5, 79
  };
  const int q9424[] = {
    9, 9, // Number of jobs and machines
    2, 86, 4,  7, 5, 41, 7, 51, 6, 49, 3, 43, 0, 61, 8, 47, 1, 67, 
    8, 25, 5, 45, 2, 92, 4, 80, 3, 43, 1, 33, 7, 11, 0, 28, 6, 40, 
    2, 30, 7, 35, 1, 31, 8, 84, 5, 59, 4, 61, 3, 32, 0, 37, 6, 71, 
    8, 97, 6, 92, 2,  3, 4, 16, 7, 61, 1, 84, 3, 23, 5, 42, 0, 35, 
    1, 24, 7, 56, 5, 43, 6, 93, 2, 85, 8, 29, 4, 45, 0, 60, 3, 84, 
    8, 15, 7, 43, 0, 98, 6,  4, 4, 53, 2, 74, 1, 96, 5, 95, 3, 57, 
    7,  4, 6, 88, 5, 37, 2, 97, 4,  1, 1, 11, 3, 95, 0, 48, 8, 18, 
    2, 62, 4, 94, 8,  4, 7, 62, 1, 82, 6, 85, 5, 21, 0, 54, 3, 32, 
    1, 62, 5, 22, 8, 41, 6, 99, 4, 71, 0, 67, 2, 42, 7, 56, 3, 24
  };
  const int q9425[] = {
    9, 9, // Number of jobs and machines
    8, 52, 5, 32, 0, 85, 1, 25, 7, 14, 3, 72, 6, 82, 2, 39, 4, 90, 
    4, 92, 5, 95, 6, 87, 7, 42, 2, 40, 8, 22, 0, 83, 3, 20, 1, 36, 
    5, 55, 0, 16, 6, 90, 2, 76, 7, 89, 1, 23, 4, 15, 3,  8, 8, 54, 
    1, 16, 7, 71, 4, 53, 2,  1, 0, 81, 5,  7, 3, 59, 8, 31, 6, 62, 
    8, 71, 5,  5, 7, 39, 2, 75, 4, 79, 6, 39, 0, 54, 1, 71, 3, 63, 
    3, 97, 7, 17, 1, 62, 0, 99, 8, 88, 5, 42, 6, 60, 4,  8, 2, 16, 
    8, 53, 7, 18, 2,  4, 1, 48, 5, 57, 3, 73, 0, 18, 6, 21, 4,  6, 
    6, 47, 5, 27, 0, 98, 7, 55, 1,  5, 8, 56, 2, 27, 4, 36, 3, 60, 
    7, 39, 4, 25, 5, 77, 6, 98, 2, 79, 0,  9, 3, 93, 1, 58, 8, 84
  };
  const int q9426[] = {
    9, 9, // Number of jobs and machines
    0, 64, 1, 30, 8, 44, 3, 72, 6, 13, 4, 61, 5, 59, 7, 72, 2,  6, 
    6, 51, 0, 37, 5,  9, 1, 77, 8, 62, 4, 99, 7, 95, 3, 44, 2, 91, 
    4, 25, 3, 62, 7, 93, 6, 10, 5, 75, 0, 57, 1, 43, 2, 97, 8, 55, 
    3, 67, 7, 24, 6, 19, 5, 82, 0, 92, 1,  2, 2, 27, 4, 35, 8, 55, 
    7, 92, 4, 65, 6, 97, 1,  1, 0,  5, 3, 79, 5, 84, 2, 45, 8, 17, 
    0, 42, 4, 33, 8,  9, 2, 86, 5, 34, 1, 10, 3, 22, 6, 26, 7, 21, 
    6, 43, 8, 13, 4, 68, 7, 71, 5, 89, 3, 94, 1, 91, 2, 35, 0, 70, 
    5, 51, 8, 19, 2, 49, 3, 41, 0, 51, 4, 42, 7, 91, 6, 96, 1, 55, 
    0, 32, 5, 57, 1, 45, 2, 12, 8, 39, 3, 13, 4, 66, 6, 85, 7, 33
  };
  const int q9427[] = {
    9, 9, // Number of jobs and machines
    5, 21, 7, 63, 4, 47, 3, 34, 8, 10, 6, 67, 2, 15, 1, 31, 0, 39, 
    0, 65, 1, 83, 3, 69, 2, 65, 4, 80, 5, 78, 8, 45, 7, 89, 6, 92, 
    0,  3, 6, 13, 1, 94, 7, 45, 4, 55, 5,  3, 8, 87, 3,  1, 2, 39, 
    6,  2, 1, 91, 2, 85, 8, 16, 3, 50, 0,  6, 4,  8, 7, 74, 5, 67, 
    4, 33, 8, 41, 0,  4, 2,  7, 3, 66, 5, 74, 1, 55, 7, 20, 6, 44, 
    4, 19, 8, 65, 7, 40, 3,  6, 2,  1, 1, 15, 6, 54, 0, 48, 5, 41, 
    7, 51, 3, 89, 5, 68, 0, 99, 8, 13, 2,  2, 1, 35, 4, 75, 6, 49, 
    2, 39, 7, 17, 8,  1, 4, 34, 3, 38, 5,  2, 0, 19, 6, 79, 1, 89, 
    2, 98, 0, 75, 4, 80, 6, 73, 1, 49, 8, 13, 7, 17, 5,  4, 3, 63
  };
  const int q9428[] = {
    9, 9, // Number of jobs and machines
    1, 11, 0, 98, 8,  6, 6, 65, 7, 25, 4, 59, 3, 72, 2, 87, 5, 35, 
    4, 31, 5, 76, 3, 47, 1, 45, 7, 18, 2, 53, 8, 73, 0, 24, 6, 56, 
    0, 16, 1, 65, 6, 88, 5, 15, 4, 51, 2, 86, 3, 91, 8, 81, 7, 90, 
    7, 24, 5, 19, 1, 37, 4, 12, 8, 27, 2, 10, 3, 50, 0, 54, 6, 92, 
    6, 41, 0, 83, 8, 35, 5, 73, 4, 32, 7, 87, 1, 65, 2,  2, 3, 78, 
    6, 33, 1, 76, 0, 85, 2, 78, 5, 72, 4, 97, 8, 36, 7, 55, 3, 32, 
    7, 65, 1, 69, 3,  8, 5, 29, 4, 93, 0, 85, 2, 45, 8, 49, 6, 89, 
    8, 40, 1,  2, 5, 85, 4, 84, 2,  9, 3,  9, 6, 82, 0, 87, 7, 48, 
    8, 90, 1, 79, 7,  8, 2, 94, 6, 78, 4, 63, 0, 69, 3, 16, 5, 64
  };
  const int q9429[] = {
    9, 9, // Number of jobs and machines
    4, 90, 5, 41, 0, 42, 1, 33, 7, 33, 8, 27, 6, 70, 3,  6, 2, 50, 
    3, 38, 7, 53, 0, 87, 1, 66, 5, 25, 8, 27, 6, 35, 4, 35, 2, 73, 
    5, 22, 1, 97, 7, 28, 4, 62, 8, 61, 2, 16, 0, 76, 6, 29, 3, 21, 
    7, 23, 6,  2, 1, 44, 3, 35, 4, 19, 2, 92, 8, 84, 5, 55, 0, 25, 
    8, 45, 3, 76, 2,  1, 7, 25, 4,  2, 1, 94, 6, 70, 0, 57, 5,  6, 
    4, 93, 5, 49, 7, 85, 1, 79, 6,  9, 8, 27, 0, 32, 2, 31, 3, 10, 
    1, 71, 0, 81, 2, 64, 7, 38, 8, 21, 5, 53, 6, 78, 3, 63, 4, 95, 
    5, 62, 0, 28, 2, 53, 6, 45, 7, 66, 8, 74, 4, 69, 1, 65, 3, 52, 
    1, 59, 3, 49, 6, 60, 0, 23, 4, 24, 7, 45, 8, 41, 2, 40, 5, 96
  };
  const int q9430[] = {
    9, 9, // Number of jobs and machines
    4, 48, 2, 93, 8, 29, 7, 92, 3, 72, 5, 10, 6, 81, 1, 63, 0, 63, 
    2, 78, 4, 50, 0, 13, 7, 40, 3,  8, 5, 96, 8, 10, 6, 46, 1, 43, 
    6, 78, 5, 85, 4, 26, 1,  6, 8, 50, 2, 21, 3,  1, 0, 10, 7, 39, 
    5, 92, 6,  2, 3, 56, 4, 11, 0, 23, 2, 39, 7, 13, 1, 41, 8, 15, 
    4, 44, 7, 33, 1, 58, 3, 30, 5, 86, 8, 52, 6, 40, 0, 51, 2, 75, 
    5, 69, 2, 84, 0, 71, 6, 32, 7, 27, 8,  8, 1, 86, 3, 78, 4, 20, 
    8, 10, 3, 71, 4, 43, 6, 74, 2, 90, 7, 61, 5, 37, 0, 15, 1, 83, 
    4, 16, 6,  3, 1, 61, 2, 66, 5, 72, 0, 19, 8, 23, 3, 53, 7, 73, 
    1, 16, 7, 53, 3, 21, 6, 55, 2, 59, 5, 49, 4, 36, 8, 63, 0,  4
  };
  const int q9431[] = {
    9, 9, // Number of jobs and machines
    0, 45, 6, 96, 1, 55, 5, 23, 4,  5, 3, 37, 8, 37, 2, 29, 7, 99, 
    8, 58, 1, 36, 4, 81, 6, 80, 2, 84, 3, 45, 0, 59, 7, 46, 5, 30, 
    3, 96, 0, 27, 7, 51, 2, 92, 8, 75, 4, 89, 6, 12, 1, 68, 5, 72, 
    8, 35, 6, 62, 2, 79, 3, 10, 0, 29, 4, 87, 7, 16, 1, 22, 5, 89, 
    7, 66, 6, 94, 1, 89, 0, 19, 3,  2, 5, 30, 2, 39, 4, 54, 8, 70, 
    2, 82, 3, 60, 4, 19, 1, 44, 6, 84, 0, 56, 8, 22, 7, 29, 5, 29, 
    5,  6, 2, 77, 0, 90, 6, 35, 4, 64, 3, 87, 7, 99, 1, 26, 8, 20, 
    3, 36, 2, 34, 8, 16, 0,  1, 7, 51, 1, 24, 6, 42, 5, 92, 4, 98, 
    2, 17, 0, 98, 4, 14, 1, 42, 3, 86, 8, 31, 6, 28, 7, 45, 5, 27
  };
  const int q9432[] = {
    9, 9, // Number of jobs and machines
    3, 57, 6,  1, 8, 25, 0, 43, 5, 92, 2, 52, 1, 76, 4, 28, 7, 20, 
    3, 26, 6, 53, 2,  6, 4, 57, 7, 70, 1, 78, 5, 16, 8, 95, 0, 53, 
    1, 70, 3, 53, 5, 89, 0, 20, 6, 26, 4, 98, 8, 53, 2, 79, 7, 20, 
    6, 27, 5, 17, 7, 13, 0, 82, 3, 28, 8, 46, 4, 82, 2, 23, 1, 92, 
    4,  2, 6, 60, 2, 37, 7, 64, 5, 58, 1,  1, 0, 84, 3, 53, 8, 89, 
    1, 48, 3, 40, 5, 47, 2, 89, 4, 62, 8, 58, 7,  3, 6, 98, 0, 62, 
    6, 99, 0, 63, 1, 24, 7, 71, 3, 83, 8, 79, 5, 27, 4, 80, 2,  1, 
    3, 86, 8, 25, 0, 24, 4, 67, 7,  5, 5, 57, 1, 96, 6, 17, 2, 83, 
    2, 34, 3, 10, 0, 56, 6, 35, 5, 60, 7, 15, 1, 59, 8,  3, 4, 79
  };
  const int q9433[] = {
    9, 9, // Number of jobs and machines
    8, 44, 3, 18, 1, 92, 4, 28, 2, 83, 6, 41, 5, 71, 7, 84, 0, 83, 
    2, 90, 1, 35, 6, 91, 0, 72, 5, 59, 3, 57, 8, 91, 4, 93, 7, 54, 
    4, 70, 3, 20, 1, 57, 2, 52, 8, 27, 0, 56, 7, 16, 5, 62, 6, 79, 
    2, 78, 1, 36, 8, 41, 0, 46, 6, 77, 3, 51, 4, 34, 5, 26, 7, 20, 
    2, 53, 8, 18, 5, 34, 0, 68, 3, 27, 6, 31, 1, 94, 4, 35, 7, 50, 
    1,  2, 0, 96, 7, 98, 6, 12, 3,  7, 4, 29, 8, 55, 2, 15, 5, 87, 
    2, 16, 3, 66, 1, 14, 0, 52, 7, 86, 5, 91, 8, 47, 4, 46, 6, 87, 
    5, 15, 1,  1, 7, 80, 8, 62, 0, 48, 6, 54, 3, 75, 2, 20, 4, 47, 
    7, 92, 5, 56, 3, 14, 4, 54, 1, 64, 8, 88, 2, 59, 0, 62, 6, 63
  };
  const int q9434[] = {
    9, 9, // Number of jobs and machines
    7, 59, 0, 15, 4, 66, 8, 44, 1, 36, 5, 27, 3, 30, 2, 73, 6, 41, 
    3, 62, 0, 58, 6, 72, 8, 22, 2, 34, 4, 43, 5, 36, 7, 60, 1, 16, 
    4, 77, 1, 82, 8, 59, 5, 67, 6, 74, 3, 76, 7, 75, 0, 36, 2, 42, 
    7, 10, 6, 75, 8, 26, 4, 15, 0, 25, 1, 58, 3, 54, 5, 31, 2, 24, 
    8, 97, 0, 26, 5, 85, 3, 60, 2, 86, 1, 79, 6, 92, 4, 44, 7, 41, 
    8, 98, 0, 23, 1, 70, 5, 19, 2, 93, 3, 55, 4, 97, 6, 72, 7, 66, 
    5,  1, 2, 64, 3, 61, 8, 82, 1, 62, 6,  2, 0, 61, 7, 22, 4, 46, 
    0, 46, 1, 56, 4, 42, 6,  7, 7, 51, 5, 40, 2, 96, 8, 69, 3, 77, 
    0, 21, 6, 74, 3,  4, 8, 28, 1, 55, 2, 63, 7, 64, 4, 16, 5, 77
  };
  const int q9435[] = {
    9, 9, // Number of jobs and machines
    6, 92, 1,  2, 8, 69, 3,  5, 5, 38, 2, 50, 4, 91, 0, 74, 7,  7, 
    3, 14, 7, 60, 1, 49, 4, 14, 2, 10, 5, 89, 0, 95, 8, 74, 6, 51, 
    6, 19, 0, 18, 1, 98, 8, 86, 7, 33, 3, 59, 4, 26, 2, 53, 5, 43, 
    2, 53, 6, 47, 4, 71, 8, 56, 5, 41, 7, 53, 1, 18, 3,  5, 0, 39, 
    6, 33, 8, 16, 5, 23, 4, 13, 3, 36, 7,  3, 0, 91, 2, 97, 1, 16, 
    0, 25, 1, 97, 5, 18, 7, 61, 8, 67, 4, 41, 6, 24, 3, 67, 2, 88, 
    6, 86, 4, 94, 0, 74, 5, 16, 1, 56, 3, 81, 8, 18, 2,  6, 7, 32, 
    8, 98, 0, 40, 3, 94, 4, 75, 6, 52, 7,  4, 1, 58, 5, 10, 2,  7, 
    5, 38, 7, 61, 1, 52, 6, 38, 8, 98, 4, 27, 2,  2, 0,  7, 3, 82
  };
  const int q9436[] = {
    9, 9, // Number of jobs and machines
    0, 72, 5, 22, 7, 70, 8, 65, 3, 59, 6, 32, 2, 73, 4, 96, 1, 55, 
    3, 33, 1, 85, 8, 72, 7, 42, 6, 57, 5, 70, 2, 88, 0,  4, 4, 22, 
    2, 19, 4, 66, 1, 91, 3, 21, 0,  9, 8, 47, 6, 21, 5,  9, 7, 52, 
    7,  5, 2, 24, 4, 47, 5, 85, 6, 47, 3, 41, 0, 80, 8, 54, 1, 49, 
    8, 52, 1, 59, 7,  3, 5, 32, 2, 91, 0, 55, 3, 44, 4, 91, 6, 75, 
    7,  8, 5, 46, 3, 17, 8, 31, 0, 93, 2, 71, 1, 91, 6,  3, 4, 39, 
    7, 29, 5, 65, 6, 24, 1,  5, 0,  6, 2, 55, 3, 76, 4, 24, 8, 65, 
    5, 71, 7, 98, 0, 26, 2, 34, 6, 50, 8, 22, 4, 17, 3, 25, 1, 22, 
    7, 67, 0, 42, 5,  2, 4, 41, 3, 64, 8, 34, 6, 68, 2, 42, 1, 17
  };
  const int q9437[] = {
    9, 9, // Number of jobs and machines
    1,  6, 6, 79, 5, 21, 7, 94, 4, 86, 0, 30, 8, 59, 2, 26, 3, 68, 
    4, 81, 8, 11, 0, 88, 1, 18, 6, 43, 5,  4, 2, 27, 3, 49, 7,  8, 
    2, 78, 3, 42, 0, 53, 1, 51, 4, 20, 6, 23, 7, 71, 8, 71, 5, 81, 
    8, 69, 2, 39, 1, 81, 3, 55, 6, 67, 0, 58, 7, 21, 4, 75, 5, 19, 
    7, 73, 2, 71, 3, 54, 1, 60, 4, 39, 5, 71, 6, 35, 8, 77, 0, 45, 
    7, 14, 0, 68, 1, 61, 6, 96, 4,  4, 2, 70, 8,  9, 3, 82, 5, 90, 
    1, 86, 3, 53, 2,  6, 4, 34, 0, 17, 8, 26, 6, 58, 7, 96, 5, 49, 
    8, 67, 2, 10, 7, 12, 6, 43, 4, 45, 3, 59, 5, 22, 0, 50, 1,  1, 
    3, 93, 2,  1, 5, 92, 0, 94, 6,  5, 7, 86, 8, 85, 1, 60, 4, 10
  };
  const int q9438[] = {
    9, 9, // Number of jobs and machines
    4,  5, 7, 80, 5, 62, 8, 41, 0, 46, 6, 33, 3, 35, 1, 66, 2, 80, 
    2, 94, 7, 41, 3, 41, 8, 35, 4, 82, 5, 70, 6, 46, 1, 95, 0,  3, 
    7, 42, 4, 85, 6, 38, 0, 29, 2, 34, 5, 36, 3, 51, 1, 93, 8, 17, 
    2, 44, 5, 50, 6, 56, 1, 72, 0, 82, 4, 29, 7, 58, 3, 97, 8, 85, 
    7,  7, 1,  1, 3, 88, 2, 59, 5, 68, 6, 95, 0, 29, 4,  4, 8, 64, 
    8, 24, 2, 92, 1, 64, 3, 62, 7, 42, 0, 55, 6, 44, 4, 77, 5, 54, 
    7, 42, 8, 27, 6, 54, 2, 94, 4, 45, 0, 42, 3, 50, 1, 61, 5, 25, 
    4, 82, 7, 45, 8, 24, 3, 36, 1, 80, 6, 75, 5, 83, 0, 53, 2, 35, 
    4, 82, 6, 69, 0, 75, 3, 35, 2, 85, 1, 63, 5, 50, 8,  2, 7, 20
  };
  const int q9439[] = {
    9, 9, // Number of jobs and machines
    8, 47, 1, 16, 0, 78, 7, 60, 5, 80, 2, 91, 6, 71, 3, 94, 4,  8, 
    7, 95, 6,  7, 1, 15, 8, 82, 4, 57, 3,  3, 2, 57, 5, 54, 0, 92, 
    3, 98, 0, 93, 8, 58, 2, 99, 7, 40, 1, 60, 5, 96, 4, 12, 6, 37, 
    4, 53, 0, 21, 8, 77, 7, 36, 6, 50, 5, 57, 2, 80, 1, 48, 3, 15, 
    3, 49, 5,  8, 6, 68, 4, 40, 2, 80, 7, 44, 8, 94, 1, 83, 0, 57, 
    1, 53, 7, 78, 2, 43, 8, 17, 6, 26, 4,  3, 0, 22, 3, 70, 5, 91, 
    6, 54, 8, 35, 0, 70, 5, 11, 2, 20, 7, 77, 1, 37, 4, 65, 3, 39, 
    8, 68, 2, 75, 7, 20, 5, 56, 4, 70, 6, 86, 1, 30, 0, 94, 3, 84, 
    6,  3, 8, 83, 0, 69, 1, 42, 3, 19, 2, 82, 4, 28, 7, 47, 5, 56
  };
  const int q9440[] = {
    9, 9, // Number of jobs and machines
    8, 59, 4, 78, 0, 42, 6, 85, 1,  8, 3, 55, 5, 21, 2, 56, 7, 27, 
    5, 59, 4,  5, 7, 83, 1, 22, 0, 53, 2, 81, 8, 51, 3, 34, 6,  7, 
    0, 48, 7, 60, 3, 87, 5, 91, 1, 93, 2, 53, 6, 23, 4, 25, 8,  3, 
    6, 24, 0, 35, 7, 15, 8, 48, 3, 69, 5, 34, 1, 31, 4, 97, 2, 97, 
    0, 29, 6, 94, 4, 70, 5, 11, 2, 38, 8, 47, 3, 86, 7, 42, 1, 98, 
    4,  8, 2,  9, 5, 73, 8, 72, 3, 66, 7, 49, 1, 25, 6, 78, 0, 15, 
    2, 59, 0, 56, 4, 11, 3, 18, 5, 29, 7, 49, 1, 16, 8, 15, 6, 14, 
    6, 73, 1, 38, 3, 54, 2, 73, 8, 48, 5, 74, 7, 59, 0, 89, 4, 77, 
    7, 54, 2, 15, 1, 94, 3, 78, 6, 78, 0, 63, 8, 27, 5, 22, 4, 88
  };
  const int q9441[] = {
    9, 9, // Number of jobs and machines
    6, 19, 0, 97, 7, 64, 1, 61, 8, 62, 5,  8, 4, 90, 3, 80, 2, 88, 
    7, 28, 8, 84, 5, 88, 6,  6, 3, 87, 2, 75, 4, 32, 1, 56, 0, 94, 
    5, 55, 2, 65, 1, 35, 6,  5, 7, 90, 8, 65, 4, 14, 0, 42, 3, 32, 
    2, 25, 3, 26, 4, 12, 1, 72, 5, 49, 8, 84, 0, 40, 6, 22, 7, 18, 
    3, 96, 6, 36, 7, 89, 4, 39, 5, 79, 0, 67, 2, 49, 8, 85, 1, 54, 
    1, 91, 4, 60, 2, 31, 3, 58, 0, 40, 5, 11, 7,  8, 6, 50, 8, 44, 
    1,  7, 8, 25, 4, 92, 3,  4, 2, 66, 5, 99, 6, 17, 0, 69, 7, 26, 
    4, 94, 6, 61, 5, 11, 3, 67, 0, 96, 2,  1, 1, 12, 8, 36, 7, 70, 
    4, 82, 7, 54, 2,  1, 6, 31, 3, 37, 5, 19, 1, 15, 8, 69, 0, 60
  };
  const int q9442[] = {
    9, 9, // Number of jobs and machines
    7, 54, 6, 97, 4, 65, 8, 61, 3,  6, 1, 89, 5, 74, 2, 56, 0, 59, 
    7,  8, 2, 88, 3, 16, 5, 50, 8, 12, 0, 62, 6, 56, 4, 81, 1, 60, 
    5, 35, 0, 78, 4, 45, 3, 88, 6, 77, 1, 95, 2, 69, 8, 30, 7, 15, 
    5, 71, 0, 27, 8, 52, 2, 67, 4, 95, 6, 60, 3, 76, 1, 42, 7, 68, 
    1, 34, 0, 55, 5, 55, 4, 23, 3, 91, 8, 42, 2, 23, 6, 22, 7, 11, 
    0, 36, 5, 80, 6, 76, 3, 58, 2, 48, 4, 52, 7, 32, 8, 90, 1, 97, 
    0, 88, 3, 22, 5, 63, 7, 45, 4,  9, 8, 41, 1, 50, 2, 19, 6, 94, 
    6,  5, 3, 23, 5, 14, 7, 32, 8, 36, 4, 11, 1, 53, 2, 11, 0, 78, 
    0, 35, 1, 40, 2, 37, 3, 31, 6, 42, 4, 76, 8, 33, 7, 53, 5, 75
  };
  const int q9443[] = {
    9, 9, // Number of jobs and machines
    5, 46, 0, 47, 7, 53, 2, 62, 1, 61, 3, 47, 8, 23, 6, 96, 4, 69, 
    8, 90, 0, 96, 4, 69, 6, 38, 7, 54, 3, 82, 2, 95, 1,  3, 5, 69, 
    6, 83, 1,  8, 5, 17, 0,  2, 8, 33, 4, 10, 7, 52, 2, 90, 3, 64, 
    4, 41, 0, 12, 1, 18, 5, 86, 8, 79, 2, 44, 6, 96, 7, 51, 3, 63, 
    0, 82, 5, 13, 2, 58, 8, 62, 1, 92, 7,  5, 6, 33, 4, 59, 3, 85, 
    4, 21, 7, 44, 3,  8, 0, 82, 5, 64, 2, 23, 6, 12, 8, 90, 1, 25, 
    8, 36, 1, 19, 0, 18, 6, 91, 5, 59, 3, 15, 2, 29, 7, 32, 4, 29, 
    5, 49, 3, 74, 4, 79, 7, 25, 1, 51, 8, 19, 0, 89, 2, 32, 6, 41, 
    2, 15, 3, 20, 1, 85, 0, 44, 8, 36, 5, 72, 7, 81, 4, 42, 6, 79
  };
  const int q9444[] = {
    9, 9, // Number of jobs and machines
    6, 69, 1, 39, 3, 62, 7, 96, 4, 29, 8, 58, 5, 64, 0, 19, 2, 34, 
    8, 14, 7, 78, 6, 69, 3, 95, 0, 81, 2, 55, 4, 77, 1, 29, 5, 76, 
    4, 98, 7, 90, 2, 35, 0, 47, 5, 73, 8,  4, 3, 81, 1, 90, 6, 76, 
    6, 63, 8, 47, 3, 73, 1, 92, 4, 85, 2, 79, 0, 61, 7,  6, 5, 13, 
    1,  3, 3,  1, 7, 59, 6, 97, 0, 87, 2,  3, 5, 82, 8, 24, 4, 48, 
    5, 10, 4, 57, 1, 98, 0, 14, 3, 24, 8, 12, 2, 69, 7, 53, 6, 56, 
    3, 40, 0, 74, 2, 61, 5, 34, 6, 10, 8, 19, 7, 48, 1, 22, 4, 22, 
    5, 53, 0, 72, 3, 59, 1, 83, 7, 20, 6, 73, 8, 70, 2, 92, 4, 59, 
    2, 36, 0, 34, 5, 50, 3, 62, 1, 49, 4, 22, 7, 98, 6, 40, 8, 81
  };
  const int q9445[] = {
    9, 9, // Number of jobs and machines
    4, 81, 2, 58, 3, 70, 6, 52, 5, 78, 7, 42, 1, 32, 8, 90, 0, 62, 
    6, 57, 8, 71, 1, 72, 5, 10, 2, 59, 0, 23, 4, 58, 3, 73, 7, 73, 
    2,  5, 8, 78, 5, 86, 6, 99, 7, 79, 1, 29, 0, 42, 4, 27, 3, 21, 
    8,  7, 0, 94, 3, 83, 2,  4, 6, 94, 4, 81, 7, 72, 1, 37, 5, 11, 
    7, 54, 2, 54, 8,  2, 0, 77, 6, 92, 5, 37, 3,  6, 4, 84, 1, 22, 
    5, 58, 1, 59, 7,  3, 0, 72, 4, 20, 8, 80, 2, 79, 6, 96, 3, 86, 
    7,  1, 6, 71, 0,  5, 2, 47, 4, 52, 3, 14, 5, 45, 8, 59, 1, 81, 
    6, 60, 7, 16, 0, 71, 4, 83, 1, 86, 3, 70, 5, 77, 2, 75, 8, 68, 
    0, 90, 2, 89, 6, 43, 3, 51, 7, 41, 1, 26, 8, 28, 4, 77, 5, 95
  };
  const int q9446[] = {
    9, 9, // Number of jobs and machines
    3, 94, 5, 71, 1, 25, 4, 83, 2, 66, 8, 93, 0, 75, 7, 86, 6, 43, 
    6, 34, 1, 42, 8, 61, 4, 40, 3, 21, 7, 30, 2,  2, 0,  9, 5,  7, 
    8, 38, 3, 47, 6, 46, 2,  5, 5,  8, 4, 92, 7, 49, 0, 63, 1, 90, 
    2, 53, 3,  6, 5, 53, 8, 51, 1, 62, 4, 29, 6, 73, 7, 87, 0, 83, 
    2,  6, 4, 37, 7, 86, 5, 82, 0, 99, 1, 24, 3, 37, 8, 80, 6, 98, 
    7, 88, 0, 34, 3, 89, 1, 47, 8, 83, 5, 57, 4, 27, 2, 42, 6, 95, 
    7, 35, 5, 51, 6, 39, 0, 26, 3, 91, 4, 24, 2, 97, 1, 26, 8, 63, 
    6, 73, 8, 36, 1, 24, 0, 55, 7, 83, 3, 95, 2, 15, 4, 33, 5, 49, 
    0, 97, 7, 27, 8, 96, 6, 76, 2, 50, 3, 54, 4, 35, 5, 48, 1, 18
  };
  const int q9447[] = {
    9, 9, // Number of jobs and machines
    0, 51, 1, 43, 7, 67, 5, 66, 8, 18, 6,  9, 2, 65, 3, 66, 4, 69, 
    4, 67, 7, 91, 3, 20, 0, 51, 5, 87, 6, 54, 2,  7, 1, 91, 8, 79, 
    4, 71, 8, 70, 1, 49, 5, 97, 7, 59, 2, 69, 6, 99, 3, 53, 0, 72, 
    7, 50, 5, 75, 1, 27, 2, 92, 8, 58, 3, 29, 0, 29, 4, 96, 6, 78, 
    7, 69, 5, 39, 0, 65, 1, 40, 3, 61, 8, 81, 4, 98, 6, 61, 2, 35, 
    7, 94, 5, 15, 4, 90, 0,  2, 1, 92, 2, 59, 6,  3, 8, 61, 3, 43, 
    6, 99, 7, 87, 3,  6, 1, 20, 5, 51, 0,  3, 4, 18, 8, 29, 2, 41, 
    3, 91, 2, 49, 7, 13, 4, 64, 8, 99, 1, 25, 6, 22, 5,  9, 0, 77, 
    3, 76, 2, 73, 1, 16, 4, 46, 7, 45, 5,  9, 0,  7, 8, 73, 6, 58
  };
  const int q9448[] = {
    9, 9, // Number of jobs and machines
    3, 98, 8, 59, 2, 89, 6, 13, 7, 69, 1, 18, 0, 28, 5, 33, 4, 77, 
    2, 74, 8, 13, 1, 53, 3, 28, 0, 67, 5, 42, 4, 50, 7,  8, 6, 96, 
    4, 57, 5,  5, 0, 35, 8, 96, 3, 48, 1, 27, 2,  9, 7, 62, 6, 97, 
    3, 39, 1,  1, 7, 11, 2, 22, 5, 30, 0, 81, 6, 68, 8, 50, 4, 21, 
    0, 65, 1, 83, 7,  5, 3, 73, 8, 18, 4, 13, 2, 54, 6, 65, 5, 67, 
    2, 27, 0, 20, 6, 13, 8, 49, 7, 54, 3, 53, 4, 54, 5, 39, 1, 70, 
    1, 22, 4, 22, 5, 27, 0, 58, 7, 38, 6, 96, 8,  1, 3, 48, 2, 35, 
    4, 90, 0, 87, 5, 98, 1, 25, 3,  9, 8, 54, 2, 54, 6,  4, 7, 57, 
    4, 93, 0, 21, 5, 31, 2, 36, 1, 71, 6, 16, 8,  3, 3, 32, 7, 51
  };
  const int q9449[] = {
    9, 9, // Number of jobs and machines
    2, 14, 4, 12, 0, 93, 3, 30, 7, 40, 1, 65, 6,  9, 8, 50, 5, 96, 
    0, 92, 7, 53, 4, 50, 5, 88, 8, 53, 3, 81, 6, 97, 1, 51, 2, 52, 
    7, 68, 1, 21, 2, 98, 0,  5, 8, 58, 4, 67, 5, 25, 3, 48, 6, 44, 
    7, 67, 0, 98, 1, 20, 6, 50, 2,  2, 8, 14, 5, 66, 4, 76, 3, 16, 
    1, 77, 5, 28, 2, 21, 3, 84, 7, 18, 0, 20, 4, 16, 6,  4, 8, 84, 
    4, 32, 1, 60, 6, 93, 0, 47, 8, 60, 3, 16, 5, 17, 2, 39, 7, 22, 
    2, 87, 8,  7, 3, 22, 0, 10, 1, 12, 4, 45, 5, 82, 6, 46, 7, 41, 
    7, 22, 6, 11, 8, 61, 5, 24, 4, 29, 0, 22, 1, 58, 3, 48, 2, 22, 
    1, 51, 3,  3, 0, 62, 6, 23, 5,  1, 8, 10, 7, 59, 2, 56, 4, 57
  };
  const int q9450[] = {
    9, 9, // Number of jobs and machines
    6, 81, 3, 24, 2, 62, 7, 10, 4, 65, 0, 70, 8, 64, 1, 13, 5, 68, 
    8, 60, 6, 61, 4, 77, 2, 37, 7, 52, 1,  9, 3, 84, 0, 43, 5, 27, 
    5, 76, 7, 95, 2, 25, 4, 85, 0, 77, 6, 88, 3, 42, 1, 65, 8, 14, 
    7, 59, 0, 47, 6, 25, 4,  2, 3, 65, 8, 29, 1,  8, 5, 55, 2,  8, 
    3, 48, 8, 52, 4, 25, 2, 33, 7, 19, 5, 18, 0, 51, 6, 29, 1, 52, 
    2, 98, 0, 48, 6, 48, 7,  6, 4, 64, 8, 29, 1,  3, 3,  7, 5, 90, 
    6, 61, 3, 78, 1, 99, 0, 45, 4, 21, 2, 41, 8, 38, 7, 30, 5, 49, 
    8, 82, 7, 91, 2, 88, 5, 98, 4, 86, 6, 77, 3, 79, 1, 80, 0, 52, 
    8, 34, 6, 82, 5, 86, 3, 12, 4, 98, 2, 80, 0, 66, 7,  5, 1, 53
  };
  const int q9451[] = {
    9, 9, // Number of jobs and machines
    5, 88, 8, 43, 4, 50, 2, 38, 1, 60, 7, 65, 3, 81, 6, 57, 0, 14, 
    5, 18, 0, 92, 3, 35, 7,  6, 8, 57, 6, 32, 2, 27, 1, 66, 4, 52, 
    8, 32, 4, 41, 0, 87, 3, 76, 5, 91, 2,  7, 7, 38, 1, 12, 6, 43, 
    1, 15, 4, 80, 8, 40, 6, 78, 0,  4, 7, 85, 3, 45, 5,  8, 2, 80, 
    0,  3, 8, 63, 1, 44, 4,  9, 6, 22, 5, 70, 2, 56, 7, 72, 3, 46, 
    2, 81, 7, 42, 5, 22, 8, 11, 4, 31, 3, 96, 1, 14, 6,  1, 0, 94, 
    8, 45, 2, 23, 4, 60, 0, 81, 5, 66, 6, 70, 7, 56, 1, 75, 3, 80, 
    4, 97, 8, 70, 3,  6, 0, 25, 7, 34, 2, 37, 1, 74, 6, 83, 5, 55, 
    3, 67, 8, 96, 5,  7, 7, 98, 2, 27, 0, 15, 6, 42, 1, 87, 4, 69
  };
  const int q9452[] = {
    9, 9, // Number of jobs and machines
    6, 27, 3, 37, 5, 30, 4, 30, 8,  7, 2, 79, 1,  5, 7, 74, 0,  1, 
    3, 19, 8, 50, 4, 35, 7, 18, 6, 44, 5, 75, 0, 93, 1,  8, 2, 31, 
    3, 47, 5, 13, 2, 41, 1, 62, 7, 96, 8, 19, 0, 11, 6, 46, 4, 76, 
    3, 53, 8, 26, 2, 87, 0, 57, 1,  5, 6, 10, 7, 88, 4, 91, 5, 34, 
    0, 88, 6, 94, 5,  5, 8, 50, 2, 17, 7, 12, 3, 19, 4, 59, 1, 14, 
    1, 45, 0, 73, 6, 73, 5, 53, 2, 86, 3, 48, 4, 67, 7, 97, 8, 15, 
    5,  7, 2, 34, 7, 48, 6, 37, 3, 98, 0, 65, 4, 86, 1, 91, 8, 73, 
    8,  2, 7, 94, 6, 40, 4, 83, 2, 12, 0, 68, 3, 23, 1, 67, 5, 82, 
    6,  6, 5, 94, 2, 87, 8, 93, 3,  8, 1, 59, 7, 65, 0, 12, 4, 47
  };
  const int q9453[] = {
    9, 9, // Number of jobs and machines
    6, 79, 8, 17, 7, 69, 2, 81, 3, 68, 0, 37, 1, 89, 5, 84, 4,  3, 
    8, 50, 2, 84, 4, 25, 3, 32, 1, 40, 0, 91, 5, 68, 7, 47, 6, 29, 
    2, 61, 3, 40, 4, 94, 5, 32, 1, 59, 7, 94, 8, 34, 0, 85, 6, 39, 
    6, 58, 7, 59, 8, 82, 4, 81, 3, 43, 1, 18, 5, 37, 2, 92, 0, 82, 
    7, 89, 0, 50, 5, 76, 4, 33, 1, 47, 8, 78, 6, 96, 3, 85, 2, 10, 
    6, 32, 0, 75, 7, 61, 5, 56, 8, 61, 2, 88, 4, 24, 1, 51, 3, 93, 
    4, 20, 3, 61, 0, 45, 2,  5, 6,  2, 1, 13, 7, 27, 5, 15, 8, 99, 
    8, 14, 1, 12, 3, 61, 2, 73, 7, 11, 0, 48, 4, 56, 5, 26, 6, 27, 
    2, 62, 1,  5, 6, 75, 3, 71, 5, 58, 8, 20, 0, 91, 4, 17, 7, 90
  };
  const int q9454[] = {
    9, 9, // Number of jobs and machines
    2, 95, 5, 24, 6, 47, 3, 56, 0, 68, 7, 28, 4, 15, 8, 43, 1, 63, 
    2, 85, 4, 22, 5, 11, 0, 47, 1, 39, 3, 20, 6, 17, 8, 45, 7, 85, 
    2, 39, 0, 91, 4, 88, 1, 99, 7, 23, 6,  2, 8, 91, 3,  1, 5, 48, 
    0, 39, 6, 74, 8, 37, 3, 62, 5, 81, 7, 28, 2, 81, 4, 66, 1, 65, 
    7, 59, 5, 57, 1, 94, 2, 68, 4, 65, 0,  5, 6, 29, 8, 16, 3, 25, 
    2, 49, 5, 33, 1, 30, 8, 14, 6, 64, 3, 15, 0, 84, 7, 58, 4, 91, 
    6, 77, 1, 51, 2, 54, 7, 72, 8, 94, 5, 64, 4,  6, 0, 38, 3, 22, 
    1, 13, 5, 62, 4, 37, 2, 87, 3, 11, 0, 74, 6, 18, 8, 41, 7, 48, 
    6, 82, 0, 23, 4, 29, 2, 54, 7, 69, 8, 95, 3,  8, 5, 51, 1, 84
  };
  const int q9455[] = {
    9, 9, // Number of jobs and machines
    6, 95, 2, 24, 1, 70, 0, 53, 4, 42, 5, 59, 8, 68, 3, 50, 7, 42, 
    5, 94, 8, 34, 7, 73, 1,  6, 4, 61, 0, 82, 3, 35, 2, 88, 6, 44, 
    1, 85, 3, 71, 5, 54, 4, 31, 8, 40, 2, 66, 6, 71, 7, 25, 0, 24, 
    5, 34, 6,  3, 2, 37, 8, 89, 4, 44, 3, 57, 1, 18, 7, 92, 0, 17, 
    6, 49, 0, 31, 8, 17, 2, 35, 4,  6, 1, 71, 3, 64, 5, 86, 7, 59, 
    0,  1, 6, 19, 1, 94, 2, 10, 5, 71, 8, 91, 3, 17, 4, 52, 7, 82, 
    1, 45, 5, 35, 8, 67, 0, 40, 4, 72, 3, 77, 7, 62, 6, 39, 2, 55, 
    8, 40, 7, 35, 1, 67, 3, 90, 4, 84, 2, 17, 0, 74, 5, 76, 6, 68, 
    3, 96, 5,  2, 8, 53, 4, 94, 2, 17, 1, 88, 7, 29, 6, 71, 0, 20
  };
  const int q9456[] = {
    9, 9, // Number of jobs and machines
    3, 79, 5, 35, 6, 12, 0, 66, 1, 37, 7, 17, 2, 84, 4, 57, 8, 23, 
    0, 76, 5, 76, 1, 20, 4, 65, 7, 99, 3, 49, 2, 52, 6, 18, 8, 15, 
    5, 92, 4, 74, 6, 11, 8, 32, 7, 89, 1, 83, 2, 66, 3, 63, 0, 72, 
    1, 53, 0, 71, 8, 78, 5, 38, 4, 54, 3, 14, 6,  8, 7, 17, 2, 59, 
    4, 96, 1, 22, 2, 29, 8, 94, 0, 46, 7, 49, 6, 53, 3, 44, 5, 84, 
    2,  7, 6, 85, 5, 83, 8, 35, 1, 47, 7, 99, 0, 47, 3, 27, 4, 69, 
    3, 67, 2, 47, 7, 48, 6, 53, 8, 14, 5, 23, 0, 11, 1, 74, 4, 39, 
    4,  5, 6, 34, 0, 30, 8, 59, 1, 93, 7, 28, 3, 49, 2, 24, 5, 76, 
    3, 95, 1, 33, 7, 68, 8, 90, 6, 63, 4, 75, 0, 77, 2, 71, 5, 43
  };
  const int q9457[] = {
    9, 9, // Number of jobs and machines
    6, 94, 3,  9, 0, 71, 4, 26, 1, 29, 8, 99, 7, 62, 2, 90, 5, 63, 
    3, 16, 7, 77, 0, 70, 4, 65, 2, 66, 1, 86, 6, 76, 8, 59, 5, 30, 
    5, 83, 0, 79, 3, 90, 7, 93, 8, 30, 6, 11, 1, 89, 4, 86, 2, 67, 
    4, 42, 6, 68, 2, 76, 7, 40, 5, 97, 8, 48, 0, 52, 3, 86, 1, 82, 
    8, 90, 1, 20, 2,  6, 7,  4, 3, 63, 6, 28, 4, 12, 5, 46, 0, 53, 
    7, 59, 2, 34, 3,  5, 1, 95, 5,  5, 8, 65, 0, 53, 6, 71, 4, 78, 
    8, 21, 1, 21, 7, 44, 0, 87, 6, 71, 5, 97, 2, 90, 3, 61, 4, 85, 
    8, 61, 6,  6, 4, 85, 5, 97, 0, 52, 2, 57, 7, 91, 3, 17, 1, 32, 
    5, 98, 2,  1, 8, 97, 1, 19, 0, 47, 6, 16, 4, 59, 7,  7, 3, 21
  };
  const int q9458[] = {
    9, 9, // Number of jobs and machines
    7, 78, 8, 71, 3, 98, 2, 43, 5, 86, 0, 88, 6, 63, 1, 45, 4, 92, 
    5, 73, 0, 19, 1, 62, 2,  3, 7, 62, 8, 97, 4, 23, 3, 81, 6, 60, 
    5, 11, 1, 26, 3, 52, 8, 69, 7, 70, 0, 16, 2, 94, 6, 42, 4, 63, 
    4, 97, 5, 72, 3, 17, 7, 81, 6, 45, 0, 56, 1, 73, 8, 54, 2, 53, 
    3, 91, 0, 34, 5, 33, 7, 66, 8, 36, 1, 77, 4, 32, 6, 16, 2, 30, 
    7, 90, 5,  2, 3, 43, 2,  7, 4, 22, 6, 35, 1, 44, 0, 89, 8,  6, 
    0, 40, 5, 27, 1, 34, 7,  8, 8, 45, 4, 28, 2, 19, 6, 12, 3,  7, 
    3, 76, 2, 68, 0, 63, 6, 69, 1, 50, 8,  1, 4, 39, 5, 65, 7, 47, 
    8, 65, 7, 95, 4, 74, 1, 79, 6, 82, 2, 23, 0, 77, 5, 13, 3, 30
  };
  const int q9459[] = {
    9, 9, // Number of jobs and machines
    6, 46, 1, 81, 5, 57, 4, 78, 7, 44, 0, 56, 2, 23, 3, 57, 8, 92, 
    0, 37, 4, 95, 3, 11, 2, 86, 5, 26, 7,  2, 6, 98, 8, 21, 1, 62, 
    2, 71, 1, 98, 5,  3, 0, 72, 4,  3, 6, 12, 7,  3, 8, 57, 3,  4, 
    8, 57, 4, 78, 6,  6, 3, 14, 7, 83, 1, 66, 2, 46, 5, 96, 0, 81, 
    8, 12, 7,  4, 0, 60, 3, 20, 5, 10, 1, 10, 6, 33, 4, 96, 2, 86, 
    8, 66, 5, 39, 1, 23, 7, 52, 0, 95, 2, 78, 6, 26, 3, 45, 4, 51, 
    1, 12, 5, 54, 2, 20, 4, 77, 8, 43, 0, 32, 7, 14, 3, 63, 6, 49, 
    3, 63, 0, 45, 2, 50, 8, 98, 5, 10, 7, 35, 6,  7, 4, 50, 1,  8, 
    4,  1, 2, 75, 0, 47, 7, 19, 1, 93, 6, 89, 8, 21, 3, 21, 5, 75
  };
  const int q9460[] = {
    9, 9, // Number of jobs and machines
    0,  9, 7, 86, 2,  6, 3, 45, 1, 72, 8, 34, 4, 22, 5, 13, 6, 72, 
    6, 21, 5, 60, 4, 11, 7,  1, 0, 67, 2,  1, 1, 21, 8, 25, 3, 89, 
    7, 36, 5, 82, 0, 89, 8, 47, 6, 56, 3, 90, 2, 74, 1, 93, 4, 19, 
    1, 53, 2, 85, 0,  1, 4, 91, 7, 14, 5, 41, 8, 51, 3, 28, 6, 41, 
    8, 17, 6, 86, 3, 98, 0, 42, 4, 39, 5, 57, 7, 51, 1, 44, 2, 39, 
    7, 53, 0,  3, 8, 80, 1, 97, 3, 36, 2, 17, 4, 79, 6, 10, 5, 70, 
    6, 67, 3, 36, 0, 84, 8, 46, 5, 66, 1, 73, 7, 72, 4, 65, 2, 51, 
    7, 21, 2, 27, 8, 83, 4, 61, 1, 31, 6, 41, 0, 12, 5, 46, 3, 40, 
    0, 21, 4, 62, 6,  7, 3, 97, 1, 49, 5, 54, 2, 56, 8, 28, 7, 41
  };
  const int q9461[] = {
    9, 9, // Number of jobs and machines
    3, 25, 1, 33, 4, 21, 8, 96, 5, 86, 7, 84, 6, 14, 0, 16, 2, 27, 
    5, 17, 1, 68, 4, 44, 8,  5, 0, 84, 3, 31, 2,  6, 6, 76, 7, 64, 
    0, 42, 2, 22, 1, 46, 5, 15, 6, 74, 7, 67, 4, 65, 8, 44, 3, 88, 
    8,  4, 4, 80, 6, 64, 3, 58, 1, 24, 0, 79, 5, 59, 2, 30, 7, 19, 
    8, 15, 6, 46, 5, 78, 4, 28, 1,  2, 0, 42, 2, 81, 3, 84, 7, 81, 
    0, 52, 6,  3, 3, 91, 1, 28, 7, 29, 2,  5, 5, 44, 4, 21, 8, 48, 
    7, 15, 0, 23, 4,  9, 1, 85, 8, 38, 6, 62, 2, 76, 3, 44, 5, 16, 
    7, 54, 8, 78, 0, 34, 2, 60, 6, 94, 5, 73, 1, 11, 3, 31, 4, 34, 
    4, 42, 8, 61, 2, 92, 7, 67, 0, 53, 1,  1, 3, 43, 6, 99, 5, 33
  };
  const int q9462[] = {
    9, 9, // Number of jobs and machines
    5, 58, 3, 15, 0, 85, 4, 64, 8, 86, 7, 42, 2, 71, 1, 82, 6, 66, 
    4, 71, 3, 34, 8,  4, 1, 70, 2, 71, 7, 32, 0, 37, 5, 64, 6, 20, 
    2, 63, 6, 99, 0, 76, 8, 66, 4,  2, 1, 39, 3, 53, 5, 21, 7, 52, 
    5, 55, 6, 46, 1, 93, 2, 35, 8, 23, 4, 67, 7, 17, 3, 35, 0, 52, 
    8, 10, 2, 62, 3, 10, 5, 97, 1, 97, 0, 78, 7, 83, 4, 95, 6, 95, 
    0, 17, 3, 70, 1, 98, 4, 66, 2, 83, 8, 97, 5, 54, 6, 28, 7, 28, 
    1, 45, 6, 32, 3, 72, 7, 33, 4, 72, 0, 33, 8, 54, 5, 36, 2, 31, 
    5, 74, 6, 37, 2, 40, 8, 16, 4, 66, 0, 63, 7, 44, 1, 28, 3, 74, 
    2,  7, 7, 24, 4, 35, 0, 28, 1, 62, 6, 62, 8, 96, 5, 76, 3, 35
  };
  const int q9463[] = {
    9, 9, // Number of jobs and machines
    1, 28, 8, 97, 2, 69, 6, 76, 3, 61, 5, 76, 7, 98, 4,  8, 0, 70, 
    3, 54, 1, 22, 7,  5, 6, 31, 2,  5, 8, 59, 0, 39, 5, 18, 4, 30, 
    0, 35, 7, 59, 6, 12, 4, 85, 2,  5, 1, 36, 5, 78, 3, 74, 8, 96, 
    7, 30, 8, 29, 0, 41, 6, 23, 4, 69, 1, 12, 5, 85, 2,  9, 3, 36, 
    4, 46, 1, 54, 2, 54, 6, 12, 0,  5, 3, 70, 5, 54, 7, 30, 8,  9, 
    0, 17, 1, 91, 3, 51, 2, 20, 5, 49, 6, 34, 4, 14, 8, 31, 7, 75, 
    0, 10, 2, 63, 8, 52, 4, 31, 7, 38, 3, 62, 1, 69, 5, 17, 6, 98, 
    7, 20, 4, 43, 1, 65, 5, 56, 3, 18, 8, 22, 6,  8, 2, 23, 0, 37, 
    3, 83, 1, 17, 7, 55, 8, 82, 4, 77, 5, 49, 2, 37, 0, 34, 6, 14
  };
  const int q9464[] = {
    9, 9, // Number of jobs and machines
    5, 40, 7, 17, 6, 21, 0, 46, 4, 57, 3, 50, 1,  2, 2, 42, 8, 68, 
    4, 50, 5, 14, 2, 47, 0, 44, 1, 53, 3, 48, 8, 16, 7, 30, 6, 21, 
    0, 97, 8, 38, 1, 58, 7, 41, 2, 15, 6, 77, 5,  1, 4, 58, 3, 10, 
    0, 67, 7, 83, 2, 72, 3, 21, 5,  3, 1, 20, 6, 76, 8,  3, 4, 78, 
    4, 23, 6, 24, 0, 65, 5, 29, 3, 23, 1, 20, 8, 21, 7, 98, 2, 36, 
    0, 69, 4, 37, 5, 89, 7, 25, 8, 44, 3, 66, 2, 15, 1, 86, 6, 83, 
    1, 24, 7, 67, 8, 42, 4, 18, 2, 70, 3, 10, 6, 64, 0, 31, 5, 78, 
    3, 64, 2, 94, 5, 70, 8, 12, 0,  6, 6, 55, 1, 28, 7, 52, 4, 77, 
    2, 86, 4, 29, 8,  3, 3, 73, 7, 60, 0, 59, 6, 77, 5, 95, 1, 15
  };
  const int q9465[] = {
    9, 9, // Number of jobs and machines
    2, 46, 7, 66, 3, 17, 0, 29, 8, 24, 5, 92, 1, 97, 6, 19, 4, 25, 
    8, 14, 4, 77, 1, 73, 0, 34, 7, 45, 3, 82, 2, 43, 6, 65, 5,  5, 
    4, 36, 8, 22, 2, 25, 6, 49, 1, 47, 3, 32, 5,  5, 0, 21, 7, 19, 
    1, 32, 8, 33, 2, 89, 3, 43, 5, 20, 6, 20, 7, 32, 0, 52, 4, 31, 
    0, 92, 4, 24, 1, 40, 2, 31, 8, 94, 5, 15, 3, 87, 7, 81, 6, 65, 
    7, 59, 3, 48, 2, 90, 5, 25, 8, 43, 0, 95, 4, 73, 1,  6, 6, 44, 
    1, 67, 5, 27, 6, 97, 0, 26, 2, 12, 3, 30, 4, 38, 8, 51, 7, 96, 
    3, 32, 7, 42, 4,  5, 2, 81, 0, 41, 6, 34, 1, 88, 8, 37, 5, 14, 
    4, 59, 3, 36, 2, 87, 6, 43, 0, 34, 7, 51, 1, 64, 8, 67, 5, 56
  };
  const int q9466[] = {
    9, 9, // Number of jobs and machines
    5, 54, 7, 59, 2, 71, 1, 78, 6, 47, 8, 35, 4, 27, 3, 44, 0, 80, 
    3, 61, 8,  6, 5,  5, 6, 18, 4, 61, 0, 21, 7, 28, 1, 75, 2, 52, 
    4, 93, 7, 62, 3, 73, 5, 59, 1, 38, 8, 54, 0, 36, 6, 57, 2, 21, 
    7, 29, 3, 57, 2, 94, 5, 76, 6, 98, 4, 59, 0, 33, 8, 28, 1, 65, 
    2, 39, 1,  7, 6, 32, 7,  6, 5, 22, 0, 13, 3,  5, 8, 72, 4, 65, 
    7,  5, 6, 27, 1, 85, 8, 25, 5, 36, 2, 87, 3, 71, 0, 75, 4, 36, 
    7, 91, 6, 84, 8, 63, 1, 72, 0, 39, 3, 13, 2, 21, 5, 60, 4,  7, 
    8, 57, 1, 67, 3, 49, 6, 84, 2, 13, 4, 71, 5, 15, 0, 17, 7, 41, 
    1, 17, 2, 97, 5, 93, 3, 89, 7, 58, 6, 31, 8, 61, 4, 89, 0, 83
  };
  const int q9467[] = {
    9, 9, // Number of jobs and machines
    6, 64, 5, 42, 3, 19, 0, 29, 7, 32, 2, 29, 8, 41, 4, 25, 1, 22, 
    1, 89, 0, 67, 3, 92, 6, 58, 8, 39, 7, 15, 2, 73, 5, 57, 4, 92, 
    3, 14, 7, 69, 2, 53, 5, 63, 4, 43, 0, 20, 6, 89, 1, 10, 8, 27, 
    2, 82, 4, 21, 5, 55, 3, 44, 7, 66, 1, 82, 0, 96, 6,  5, 8, 30, 
    7, 74, 6, 68, 5, 61, 0, 39, 8, 94, 4, 14, 2, 15, 1, 12, 3, 25, 
    5, 42, 4, 31, 7, 60, 3, 63, 1,  7, 0, 30, 6, 23, 8, 34, 2, 24, 
    5, 46, 0, 78, 3, 50, 8, 77, 7, 89, 1, 84, 4,  1, 6, 28, 2, 21, 
    7,  1, 5, 52, 4, 62, 0, 43, 8, 82, 2, 30, 6, 92, 3, 72, 1, 46, 
    5, 94, 1, 88, 6, 92, 4, 88, 0, 14, 7, 75, 3, 80, 2, 10, 8, 13
  };
  const int q9468[] = {
    9, 9, // Number of jobs and machines
    5, 72, 6,  3, 8, 35, 0, 83, 2, 27, 1, 60, 4, 51, 3, 84, 7, 25, 
    5, 16, 4, 96, 8, 36, 1, 22, 6, 12, 3, 64, 0, 99, 7, 54, 2,  2, 
    5, 75, 7, 89, 4, 62, 3, 56, 6, 19, 0, 33, 8, 90, 2, 66, 1, 63, 
    6, 70, 0, 48, 4, 34, 8, 27, 7, 26, 1, 67, 2, 72, 3, 78, 5, 54, 
    3, 72, 1, 99, 0,  6, 2, 43, 5, 91, 7, 72, 4, 95, 8, 41, 6, 92, 
    7, 43, 1, 70, 0, 43, 5, 26, 8, 88, 4,  8, 6, 17, 2,  8, 3, 57, 
    2,  9, 3, 48, 6, 14, 8, 63, 1,  2, 0, 30, 5, 23, 7, 53, 4, 71, 
    8, 18, 7, 41, 5, 80, 1, 33, 2, 43, 4, 43, 0, 45, 3, 24, 6, 79, 
    6, 93, 4, 22, 7, 67, 0, 84, 5, 55, 8, 74, 3, 17, 1, 20, 2, 31
  };
  const int q9469[] = {
    9, 9, // Number of jobs and machines
    2, 50, 6, 80, 5, 26, 1, 66, 3, 61, 7,  2, 0,  4, 4, 34, 8, 67, 
    5, 11, 3, 90, 1, 13, 0, 91, 7, 62, 2, 96, 8, 62, 4, 33, 6, 50, 
    1, 58, 0, 13, 2, 20, 6, 61, 7, 68, 5, 79, 8, 88, 3,  3, 4, 94, 
    4, 28, 7, 99, 0, 51, 6, 72, 5,  6, 1,  1, 3, 64, 8, 27, 2, 75, 
    1, 75, 6, 21, 8, 33, 2, 25, 4, 46, 0,  2, 3, 49, 7, 83, 5, 92, 
    7, 97, 3, 32, 5, 93, 1, 35, 0, 46, 4, 53, 8, 63, 2,  9, 6,  4, 
    8, 66, 7,  1, 0, 25, 6, 80, 2,  9, 4, 49, 1, 36, 5, 32, 3, 22, 
    5, 93, 7, 62, 1, 13, 2, 11, 4, 21, 3, 23, 0, 49, 8, 33, 6, 95, 
    7, 36, 8, 69, 2, 48, 6, 76, 0, 89, 3, 22, 5, 24, 4, 10, 1, 17
  };
  const int q9470[] = {
    9, 9, // Number of jobs and machines
    0, 64, 4, 43, 5,  2, 3, 19, 2, 46, 7, 42, 1, 34, 8, 95, 6, 16, 
    5, 59, 3, 44, 4, 56, 1, 89, 0, 84, 6, 28, 8, 47, 2, 33, 7, 59, 
    7, 55, 0, 15, 5, 91, 4, 34, 8, 41, 2, 44, 3, 11, 6, 43, 1, 33, 
    2, 67, 4, 85, 0, 77, 7, 10, 5, 81, 3, 71, 1, 69, 6, 62, 8, 94, 
    7, 38, 5, 85, 1, 59, 8, 56, 2, 40, 4, 67, 6, 52, 0,  6, 3, 36, 
    4, 45, 8,  2, 0, 13, 7, 79, 6, 46, 5, 80, 3, 94, 2, 80, 1, 93, 
    3, 98, 4, 56, 0, 13, 1, 75, 6, 95, 8, 68, 5, 74, 7, 76, 2,  6, 
    0, 85, 5,  3, 8, 33, 3, 69, 1, 89, 2, 91, 6, 63, 4, 58, 7, 28, 
    2, 23, 6, 24, 0, 57, 3, 85, 8, 58, 7, 28, 5, 48, 1, 97, 4, 50
  };
  const int q9471[] = {
    9, 9, // Number of jobs and machines
    5, 60, 3, 99, 1, 45, 6,  4, 8, 53, 7, 50, 2, 69, 4, 32, 0, 97, 
    2, 56, 6, 87, 7, 51, 1, 24, 3, 94, 4, 33, 5, 50, 8, 74, 0, 19, 
    6, 35, 2, 25, 0, 89, 4, 23, 3, 77, 5, 14, 7, 97, 8, 86, 1, 61, 
    6, 12, 1, 88, 0, 75, 2, 36, 7, 99, 4, 81, 8, 29, 3,  5, 5, 91, 
    7, 67, 5, 27, 8, 77, 1, 73, 6, 29, 4, 49, 3, 18, 0, 79, 2, 44, 
    6, 11, 8, 15, 7, 24, 0, 33, 4, 15, 5, 51, 3, 29, 2, 90, 1, 38, 
    6, 24, 0, 49, 7,  2, 4, 65, 1, 19, 3, 44, 5, 18, 8, 67, 2, 98, 
    6,  1, 3, 89, 8, 73, 0, 35, 7, 92, 4, 12, 1, 45, 5, 46, 2, 68, 
    2, 12, 1, 63, 3, 67, 6, 25, 0, 33, 4, 30, 7, 10, 8, 41, 5, 31
  };
  const int q9472[] = {
    9, 9, // Number of jobs and machines
    7, 47, 4, 69, 5, 84, 0, 60, 3, 79, 1, 49, 8, 49, 2, 79, 6, 71, 
    5, 80, 0, 51, 8, 70, 4,  2, 7, 15, 2, 66, 6, 50, 3, 91, 1, 81, 
    3, 12, 7, 23, 5, 16, 8, 33, 2, 53, 0, 69, 1, 24, 4, 62, 6, 86, 
    1, 69, 6, 59, 4, 25, 2, 82, 7, 57, 5, 41, 8, 25, 0, 76, 3, 37, 
    1, 73, 0, 23, 8, 14, 3, 25, 7, 72, 2, 61, 4, 62, 6, 92, 5, 68, 
    3, 42, 5, 33, 1, 77, 0,  6, 6, 28, 2, 53, 4, 96, 7, 91, 8, 14, 
    1, 34, 3, 52, 5, 19, 2, 24, 7, 73, 0, 52, 8, 39, 6, 89, 4,  3, 
    4,  1, 6, 15, 0, 45, 5, 78, 3, 66, 1, 69, 2, 33, 7, 29, 8, 84, 
    2,  8, 0, 90, 3, 57, 8, 11, 5, 29, 7, 42, 1, 15, 6, 64, 4, 76
  };
  const int q9473[] = {
    9, 9, // Number of jobs and machines
    5, 20, 0, 42, 3,  9, 1, 50, 4, 87, 7, 80, 8, 83, 2, 72, 6, 11, 
    1, 66, 4,  2, 0, 60, 8, 15, 2, 73, 6, 73, 5, 55, 3, 29, 7, 62, 
    1, 92, 4, 52, 2, 66, 7,  5, 6, 64, 5, 11, 0, 78, 8, 51, 3, 82, 
    6, 59, 1,  8, 5, 25, 3, 55, 7, 85, 2, 60, 8,  2, 0, 80, 4, 90, 
    3, 43, 6,  9, 1, 23, 5, 37, 8, 39, 4, 22, 7, 81, 0, 95, 2,  9, 
    8, 45, 5, 61, 2, 61, 4,  9, 3, 94, 6, 62, 1, 25, 7,  6, 0, 72, 
    6, 43, 8, 37, 1, 97, 2, 51, 5, 18, 3,  2, 0, 84, 4, 16, 7, 51, 
    6, 26, 5, 35, 3, 50, 7, 39, 8, 85, 0, 10, 2, 93, 4, 85, 1, 62, 
    5, 12, 8, 20, 4, 46, 2, 74, 0,  2, 3, 70, 7, 58, 1, 85, 6, 62
  };
  const int q9474[] = {
    9, 9, // Number of jobs and machines
    3, 72, 1, 19, 8, 55, 5, 99, 7, 79, 6, 50, 4, 25, 0, 21, 2, 34, 
    4, 80, 2, 26, 8, 53, 5, 21, 3, 84, 0, 24, 1,  7, 6, 15, 7, 76, 
    2,  7, 1, 79, 3, 59, 8, 52, 0, 11, 5, 10, 6, 83, 4, 34, 7, 64, 
    1, 84, 5, 57, 2, 10, 8, 87, 4, 62, 0, 45, 6,  7, 7, 28, 3, 14, 
    3, 78, 7, 22, 4, 54, 2, 28, 6, 19, 1, 92, 0, 71, 5, 55, 8, 13, 
    1, 60, 8,  9, 5, 40, 6, 83, 7, 77, 0, 19, 3, 28, 2, 90, 4, 30, 
    2, 61, 4, 96, 5, 87, 1, 49, 7, 56, 3, 75, 0, 60, 6, 64, 8, 42, 
    1, 92, 5, 62, 6, 54, 4,  9, 0, 24, 2, 12, 7, 84, 3, 35, 8, 57, 
    2, 82, 0, 59, 5, 88, 1, 86, 8, 77, 7, 63, 6, 77, 4, 15, 3, 23
  };
  const int q9475[] = {
    9, 9, // Number of jobs and machines
    7,  9, 4, 17, 3,  6, 2, 16, 0, 47, 6, 23, 8, 58, 1, 68, 5, 61, 
    8, 97, 4, 93, 1, 81, 2, 81, 0, 16, 6, 33, 7, 91, 5,  7, 3, 51, 
    2, 56, 3, 22, 4, 88, 8, 80, 1, 26, 7, 65, 6, 66, 0, 45, 5, 42, 
    5, 55, 4, 89, 8, 44, 6, 94, 3, 57, 7, 93, 0, 14, 1, 35, 2, 33, 
    6, 24, 1, 85, 5, 37, 2, 91, 3, 79, 0, 42, 4, 57, 8, 11, 7, 49, 
    4, 21, 7, 61, 5, 64, 1, 94, 6, 91, 8, 49, 0, 40, 2, 24, 3, 56, 
    2, 56, 8, 60, 0, 49, 5, 72, 3, 84, 4, 61, 7, 21, 1,  7, 6, 91, 
    4, 73, 2, 84, 5, 16, 3,  3, 0,  3, 1, 40, 7,  1, 6, 54, 8, 66, 
    5, 19, 7, 72, 8, 25, 4, 13, 2, 56, 1, 84, 0, 63, 3, 69, 6, 35
  };
  const int q9476[] = {
    9, 9, // Number of jobs and machines
    2, 85, 7, 66, 1, 42, 5, 13, 3, 18, 8, 43, 4, 60, 6, 86, 0, 14, 
    5, 65, 2, 85, 0, 32, 8, 14, 6, 81, 3, 59, 4, 85, 1, 88, 7, 28, 
    3, 91, 4, 82, 7, 62, 5, 48, 6, 49, 0, 95, 2, 61, 8, 88, 1, 37, 
    3, 22, 2, 68, 4, 79, 6, 29, 8, 31, 1, 26, 0, 59, 7, 71, 5, 94, 
    7, 83, 2, 64, 1, 74, 0, 63, 8, 47, 3, 16, 6, 59, 5,  8, 4, 24, 
    6, 34, 8, 47, 2, 82, 4, 37, 7, 50, 1, 58, 3, 96, 0,  4, 5, 79, 
    6, 96, 3, 35, 2, 98, 7, 27, 5, 10, 1, 35, 4, 51, 0, 75, 8, 38, 
    7, 13, 1, 42, 8, 80, 5, 78, 2, 75, 4, 31, 0,  4, 6, 99, 3, 75, 
    4, 77, 6, 43, 5, 89, 7, 81, 2, 17, 8, 78, 0, 50, 3, 37, 1,  7
  };
  const int q9477[] = {
    9, 9, // Number of jobs and machines
    1, 18, 8, 57, 6, 33, 7,  6, 2, 89, 4, 35, 3, 49, 5, 87, 0, 17, 
    8, 59, 6, 73, 3, 24, 5, 37, 2, 42, 1, 67, 0,  9, 4, 65, 7, 54, 
    5, 12, 1, 37, 7, 13, 6, 63, 4, 66, 3, 62, 0, 95, 2, 70, 8, 98, 
    5, 82, 2, 78, 1, 63, 3, 31, 7, 79, 0, 15, 4, 50, 8, 60, 6, 96, 
    2, 69, 3, 73, 7, 22, 8, 94, 4, 78, 1,  9, 6, 80, 5,  5, 0, 38, 
    6, 29, 5, 79, 4, 45, 1, 19, 2, 73, 8, 75, 3, 88, 7,  9, 0, 16, 
    6, 65, 7, 35, 3, 96, 2, 32, 8, 83, 4, 50, 1, 84, 0, 31, 5, 42, 
    3, 21, 0, 53, 1, 73, 5, 74, 6,  5, 8, 40, 7, 67, 2,  6, 4, 93, 
    6,  9, 5, 86, 2,  5, 8, 42, 3, 27, 7,  8, 4, 45, 0,  5, 1, 18
  };
  const int q9478[] = {
    9, 9, // Number of jobs and machines
    8, 46, 5, 70, 7, 57, 1, 63, 0, 48, 2,  3, 3, 32, 6, 99, 4,  2, 
    2, 30, 1, 14, 7, 67, 4, 14, 8, 94, 6, 47, 0, 85, 5, 84, 3, 15, 
    8, 78, 4, 50, 5, 43, 7, 72, 1,  8, 6, 45, 3, 44, 2, 14, 0,  4, 
    6, 10, 8, 81, 7, 92, 1, 85, 0,  4, 5, 13, 2, 71, 3, 66, 4, 99, 
    3, 48, 7, 78, 4, 24, 6, 27, 0, 41, 8, 80, 2, 10, 5, 42, 1, 58, 
    6, 44, 7, 33, 1, 83, 2, 40, 0,  4, 4, 57, 5, 14, 3, 60, 8,  2, 
    8, 35, 6,  4, 4, 81, 2, 93, 1, 63, 7, 79, 0, 72, 5, 32, 3, 96, 
    2, 99, 6, 95, 0,  3, 5, 15, 4, 97, 7, 41, 1, 76, 8, 34, 3, 97, 
    2, 36, 3, 59, 7, 87, 5, 72, 0, 27, 4, 77, 1,  6, 6, 60, 8,  5
  };
  const int q9479[] = {
    9, 9, // Number of jobs and machines
    6, 85, 0, 65, 5, 31, 2, 19, 3, 10, 7, 38, 1, 46, 4,  3, 8, 89, 
    8, 76, 7, 42, 5, 32, 3,  3, 6, 85, 2, 71, 4, 38, 0, 30, 1, 44, 
    7, 61, 8, 19, 0, 73, 4, 88, 1, 53, 5, 89, 3, 27, 6, 83, 2,  9, 
    2, 30, 0, 51, 6, 20, 7, 48, 8, 87, 3, 93, 4, 45, 5, 24, 1, 88, 
    1, 39, 8, 86, 5, 91, 6, 86, 3,  6, 2, 91, 4, 37, 7, 93, 0, 21, 
    3,  1, 1, 90, 6, 77, 2, 23, 5, 12, 8, 98, 7, 31, 0, 67, 4, 23, 
    5, 84, 1, 67, 0,  5, 3, 95, 2, 15, 4, 39, 7, 14, 6, 25, 8, 22, 
    1, 56, 4, 51, 6, 99, 5, 81, 0,  2, 2, 97, 3, 15, 7, 15, 8, 82, 
    5, 43, 8, 17, 7, 31, 3, 53, 2, 58, 0, 51, 1, 13, 4, 56, 6, 38
  };
  const int q9480[] = {
    9, 9, // Number of jobs and machines
    8, 98, 2, 65, 0, 75, 3, 90, 1, 21, 4, 16, 5, 48, 6, 27, 7, 75, 
    1, 42, 7, 88, 2, 63, 4, 81, 6, 10, 8, 49, 0, 34, 3, 71, 5, 56, 
    1, 69, 7, 68, 4, 43, 6, 67, 0, 24, 5, 35, 3, 27, 8, 29, 2, 65, 
    7, 28, 1, 19, 3, 20, 2, 28, 8, 77, 0, 17, 5, 92, 4, 29, 6, 88, 
    8, 99, 0, 35, 2, 28, 3, 53, 6, 26, 5, 80, 7, 31, 1, 80, 4, 40, 
    0,  6, 3, 12, 7, 86, 6, 37, 4, 61, 1, 87, 5, 20, 8, 14, 2, 14, 
    2,  6, 7, 86, 4, 67, 3, 10, 5, 74, 1, 18, 8, 47, 6, 53, 0, 23, 
    5, 78, 0, 14, 6, 20, 8, 16, 4, 86, 1, 32, 7, 35, 3, 63, 2, 84, 
    0, 50, 7, 75, 4, 62, 3, 24, 2, 61, 5, 54, 6, 43, 8, 48, 1, 88
  };
  const int q9481[] = {
    9, 9, // Number of jobs and machines
    8, 26, 3, 38, 0, 47, 1, 30, 6, 24, 7, 26, 5, 83, 4, 61, 2, 57, 
    1, 90, 3, 99, 5, 99, 2, 72, 8, 30, 6, 45, 7, 56, 4,  9, 0, 41, 
    4, 91, 5, 26, 8, 40, 3, 17, 7, 89, 6,  3, 1, 61, 2, 34, 0, 14, 
    2,  4, 4, 67, 6, 52, 8, 45, 1,  8, 5, 22, 0,  4, 7, 89, 3, 58, 
    1, 61, 4, 77, 6, 29, 8, 76, 7, 58, 5, 44, 0, 14, 2,  6, 3, 41, 
    4, 41, 2, 44, 0, 23, 3,  9, 1, 22, 6, 56, 7, 63, 8, 80, 5, 10, 
    0, 92, 7,  4, 6, 93, 4, 45, 2, 34, 3, 77, 1, 92, 5, 65, 8, 47, 
    7, 83, 0, 43, 4,  5, 3, 67, 8, 98, 1, 68, 6,  3, 2, 29, 5, 62, 
    2, 10, 3, 68, 5, 27, 8, 14, 6, 15, 7, 21, 4, 95, 0,  2, 1, 12
  };
  const int q9482[] = {
    9, 9, // Number of jobs and machines
    8, 49, 0, 70, 4, 45, 7, 36, 2, 98, 3, 38, 5, 20, 1, 69, 6, 73, 
    0, 91, 1, 41, 7, 29, 6, 19, 3, 54, 2, 10, 5, 44, 4, 82, 8, 47, 
    0, 36, 1, 79, 3, 72, 5, 30, 4, 85, 2, 77, 8, 29, 6, 91, 7, 16, 
    5, 96, 7, 73, 0, 19, 3, 79, 6, 49, 2, 90, 8, 70, 1, 25, 4, 54, 
    5, 87, 2, 95, 1, 10, 8,  7, 4, 19, 6, 98, 3, 76, 7, 25, 0, 37, 
    5, 81, 6, 26, 0, 67, 3,  4, 1, 86, 8, 85, 4, 82, 2, 29, 7, 34, 
    0,  3, 5, 45, 8, 50, 4, 46, 1, 53, 7, 11, 6, 90, 3, 62, 2, 76, 
    7, 63, 6, 52, 2, 43, 3, 77, 1, 94, 5, 23, 4,  3, 8, 45, 0, 97, 
    2, 52, 6, 56, 8, 25, 5, 18, 1, 37, 3, 74, 7, 37, 4, 94, 0, 40
  };
  const int q9483[] = {
    9, 9, // Number of jobs and machines
    1, 36, 6, 75, 2, 70, 4, 56, 8, 73, 7, 30, 3, 78, 0, 98, 5, 81, 
    1, 49, 6, 13, 0, 88, 8, 68, 2, 72, 7, 52, 4, 82, 5, 96, 3,  1, 
    5, 13, 8,  9, 4, 77, 1, 82, 7, 72, 2, 78, 3, 98, 0, 76, 6, 66, 
    5, 54, 6, 20, 3, 50, 8, 54, 2, 13, 0, 15, 1, 68, 7, 38, 4, 25, 
    8, 92, 2, 91, 4, 97, 0, 92, 1, 45, 3, 41, 7, 99, 5, 84, 6, 28, 
    0, 68, 8, 78, 1, 68, 2, 11, 7, 80, 6, 57, 3,  5, 5, 46, 4, 30, 
    0,  3, 5, 94, 3, 20, 4, 28, 8, 22, 7, 43, 1, 24, 2, 71, 6, 33, 
    7, 64, 0, 41, 3, 55, 5,  2, 2, 23, 4, 52, 1, 82, 8, 68, 6, 11, 
    1, 58, 0, 15, 3, 92, 6, 40, 7, 20, 5, 47, 8, 77, 4, 96, 2, 56
  };
  const int q9484[] = {
    9, 9, // Number of jobs and machines
    7, 79, 3, 42, 2, 35, 5, 19, 6, 53, 1, 16, 8, 53, 4, 57, 0, 82, 
    1, 70, 5, 20, 4, 81, 3, 92, 2, 68, 8, 39, 7, 40, 0,  3, 6, 15, 
    6, 83, 1, 40, 4, 78, 8, 13, 5, 40, 3,  3, 0, 33, 2, 15, 7, 31, 
    2, 10, 8, 81, 0, 13, 6, 88, 4, 77, 3, 47, 1, 27, 5, 24, 7, 60, 
    5, 55, 6, 77, 4, 11, 7, 56, 2, 83, 3, 81, 1, 47, 0, 95, 8, 18, 
    2, 18, 4, 83, 7, 41, 8, 11, 6, 28, 5, 47, 0, 97, 1, 55, 3, 29, 
    5, 49, 8, 98, 1, 87, 6, 40, 4, 97, 0, 89, 7, 35, 2, 88, 3, 94, 
    3, 52, 7, 27, 6, 43, 5, 24, 0, 30, 8, 53, 4, 28, 2, 16, 1, 38, 
    5, 94, 0, 83, 8, 98, 6, 74, 4, 24, 3, 72, 1, 71, 2, 40, 7, 80
  };
  const int q9485[] = {
    9, 9, // Number of jobs and machines
    7, 44, 0, 14, 4, 30, 3, 78, 2, 73, 1, 36, 5, 55, 8, 80, 6, 12, 
    6, 58, 0, 16, 2, 44, 5,  5, 4, 84, 8, 57, 3, 43, 1, 64, 7, 92, 
    8, 50, 2, 60, 3, 96, 7, 49, 4, 97, 1, 61, 0, 87, 5, 50, 6, 52, 
    8, 75, 5, 85, 7, 40, 6, 26, 0, 39, 3, 54, 1, 17, 2, 74, 4, 20, 
    3,  2, 7, 94, 5, 62, 8, 11, 6, 47, 4, 70, 1, 23, 0, 89, 2, 34, 
    2, 94, 7, 27, 0, 65, 8, 88, 1, 66, 5, 98, 6, 16, 4, 13, 3, 58, 
    0, 54, 8, 51, 4, 94, 5,  9, 1, 52, 3, 82, 2, 43, 6, 49, 7, 76, 
    1, 60, 4, 42, 2, 82, 5, 78, 6, 72, 0, 24, 8, 67, 3, 25, 7, 18, 
    1, 65, 4, 20, 3, 49, 2,  1, 6,  5, 0, 63, 7, 87, 8, 70, 5, 42
  };
  const int q9486[] = {
    9, 9, // Number of jobs and machines
    8, 67, 0, 18, 4, 55, 2, 63, 6, 65, 1, 84, 5, 31, 7, 51, 3,  3, 
    2, 94, 0, 14, 6, 41, 5, 35, 7,  7, 1, 57, 8, 87, 4,  1, 3, 70, 
    0, 36, 4, 40, 2, 50, 1, 62, 5, 92, 6, 84, 3, 89, 8, 73, 7, 75, 
    5, 65, 2, 55, 7, 68, 4, 98, 1, 10, 3, 97, 8,  8, 0, 75, 6, 11, 
    3, 16, 7, 86, 8, 89, 2, 16, 1, 40, 5,  3, 0,  7, 6, 89, 4, 89, 
    4, 89, 7, 52, 6,  9, 3, 87, 1, 48, 5, 56, 0, 62, 2, 71, 8,  5, 
    0, 20, 5, 70, 6, 20, 8, 30, 1,  1, 7, 73, 4, 53, 2, 60, 3,  6, 
    4, 59, 6, 98, 1, 64, 0, 17, 2, 12, 5, 44, 7,  9, 3, 22, 8, 84, 
    7, 84, 5, 66, 4, 62, 1,  6, 6,  1, 2, 54, 3, 32, 0, 45, 8, 38
  };
  const int q9487[] = {
    9, 9, // Number of jobs and machines
    3, 24, 0, 67, 5, 52, 1, 39, 2, 71, 7, 33, 6, 69, 4, 62, 8, 90, 
    7, 89, 1, 22, 0, 10, 8, 51, 4, 35, 3, 57, 5, 38, 2, 40, 6, 62, 
    8, 74, 3, 12, 4, 37, 1, 72, 7, 94, 0, 20, 2, 44, 6, 53, 5, 34, 
    5, 91, 8,  8, 4, 25, 2, 44, 7, 41, 0, 40, 6, 75, 1, 70, 3, 16, 
    8, 76, 5, 52, 2, 22, 3, 50, 6, 38, 7, 50, 1, 32, 4,  6, 0, 15, 
    5,  5, 3, 78, 7, 48, 0, 14, 6, 23, 4, 38, 8,  5, 2, 68, 1, 87, 
    5, 54, 4, 80, 7, 32, 3, 19, 1, 63, 0, 89, 8, 65, 6, 65, 2, 47, 
    0, 46, 2, 35, 6, 51, 5,  8, 3, 92, 1, 78, 8, 54, 7, 61, 4, 71, 
    8, 27, 2,  8, 7, 72, 6, 35, 3, 93, 1, 70, 4, 58, 5, 12, 0, 40
  };
  const int q9488[] = {
    9, 9, // Number of jobs and machines
    3, 89, 0, 84, 5, 18, 7,  1, 2, 18, 4, 51, 6, 74, 1,  3, 8, 74, 
    4, 39, 5,  4, 6, 45, 7, 13, 1, 17, 0, 12, 8, 78, 2, 11, 3, 93, 
    4, 39, 5, 48, 8,  4, 3, 12, 6, 45, 7, 22, 2, 30, 0, 68, 1, 16, 
    3, 78, 7, 80, 4, 14, 0, 50, 1,  4, 8, 89, 2, 54, 6, 19, 5, 36, 
    6, 86, 7, 19, 0,  5, 5, 43, 8, 96, 1, 86, 2, 68, 3, 89, 4, 87, 
    1, 18, 7, 41, 0, 83, 4,  4, 5, 29, 2, 82, 6, 86, 3, 57, 8,  3, 
    6, 29, 8, 56, 5, 48, 4, 57, 0, 66, 3, 29, 1, 51, 7, 42, 2, 24, 
    1, 20, 3,  5, 6, 54, 7, 23, 0, 21, 8, 55, 2, 54, 4,  3, 5, 36, 
    4, 26, 5, 20, 7,  9, 2,  1, 6, 40, 0, 54, 8,  2, 3, 46, 1, 46
  };
  const int q9489[] = {
    9, 9, // Number of jobs and machines
    5, 92, 7, 61, 2, 35, 0, 35, 1,  8, 3, 38, 8, 86, 6, 62, 4, 66, 
    8, 17, 6, 28, 3, 85, 4, 51, 7, 79, 1, 70, 0, 88, 2,  4, 5, 34, 
    8,  8, 5, 70, 0, 98, 6, 46, 3, 13, 2, 47, 7, 21, 4, 65, 1,  6, 
    8, 78, 5, 72, 7, 64, 3, 18, 6, 36, 1, 15, 2, 46, 0, 69, 4,  8, 
    8, 66, 6, 61, 7, 91, 4, 30, 0, 75, 1, 81, 5, 79, 3, 79, 2, 13, 
    0, 49, 7, 21, 3, 62, 6, 14, 4,  5, 2, 55, 1, 60, 5, 13, 8, 31, 
    5, 12, 7, 84, 1,  3, 3, 71, 8,  1, 0, 62, 6, 91, 4, 63, 2, 47, 
    3, 25, 2, 34, 8, 92, 7, 21, 6, 10, 4, 43, 1, 52, 5, 83, 0, 97, 
    3,  2, 5, 54, 0,  1, 4, 64, 1, 97, 7, 45, 8, 58, 2, 33, 6, 71
  };
  const int q9490[] = {
    9, 9, // Number of jobs and machines
    8, 97, 1, 85, 4, 85, 5, 94, 3, 65, 6, 21, 2, 26, 0, 55, 7, 28, 
    5, 56, 2,  1, 0, 69, 1, 15, 3, 45, 4, 64, 7, 77, 6, 50, 8, 80, 
    5, 36, 0, 39, 7, 62, 3, 16, 8, 68, 6, 78, 4, 71, 2, 83, 1, 79, 
    1, 16, 8, 62, 0,  8, 6, 90, 2, 58, 3, 27, 5, 63, 7, 64, 4, 73, 
    5, 40, 3, 70, 0, 72, 1, 28, 7, 78, 6, 68, 2, 84, 8, 74, 4, 83, 
    4, 52, 7, 11, 8, 91, 6, 61, 1, 54, 5, 15, 3, 61, 2, 37, 0, 36, 
    1, 53, 0, 51, 4, 78, 3, 67, 6, 13, 7, 11, 2, 93, 8, 98, 5, 64, 
    1, 48, 5, 21, 7, 85, 4, 47, 0, 16, 2, 56, 3, 34, 6, 64, 8, 16, 
    3, 20, 4, 57, 8, 39, 7, 78, 0,  7, 2,  5, 1, 42, 5, 30, 6, 62
  };
  const int q9491[] = {
    9, 9, // Number of jobs and machines
    1, 32, 6, 76, 7, 72, 3, 82, 8, 60, 5,  4, 0, 56, 4, 87, 2, 86, 
    5, 54, 3, 66, 6, 79, 2, 38, 1,  6, 4,  9, 0, 31, 7, 56, 8, 35, 
    8, 63, 7, 20, 0, 62, 3, 37, 6, 64, 4, 78, 5, 48, 2, 71, 1, 12, 
    3, 64, 6, 35, 2, 20, 8, 87, 5, 56, 0, 62, 7, 38, 4, 54, 1,  2, 
    0, 82, 6, 49, 7, 66, 8, 57, 5, 37, 3, 43, 4, 30, 2, 71, 1, 90, 
    5, 26, 2, 95, 7, 19, 1, 44, 8, 49, 4, 15, 3, 75, 0,  7, 6, 89, 
    7, 49, 2, 65, 0,  4, 5, 36, 1, 36, 3, 13, 8, 11, 4, 62, 6, 86, 
    2, 53, 7, 16, 1,  1, 3, 42, 4, 86, 6, 24, 5,  5, 8, 53, 0, 67, 
    7, 91, 6, 46, 4, 32, 0, 25, 1, 70, 2, 17, 8, 26, 5, 54, 3, 73
  };
  const int q9492[] = {
    9, 9, // Number of jobs and machines
    5, 95, 3, 75, 0, 32, 7, 73, 6, 61, 2,  1, 1, 20, 8, 65, 4, 78, 
    6, 69, 7, 63, 8, 30, 0, 46, 2, 53, 3, 81, 4, 84, 5, 91, 1, 10, 
    2, 89, 5, 36, 0, 28, 4, 11, 3, 83, 6, 86, 8, 27, 1, 22, 7, 68, 
    8, 74, 0, 28, 1, 16, 4, 56, 5, 62, 6, 74, 7, 60, 3, 49, 2, 40, 
    5, 89, 1, 26, 8, 57, 4, 44, 0, 22, 7, 94, 3, 83, 2, 99, 6, 21, 
    7,  8, 1, 33, 8, 51, 4, 93, 2, 92, 0, 62, 5, 35, 3, 58, 6, 79, 
    3, 80, 7, 33, 0, 42, 8, 60, 2, 16, 4, 97, 6, 12, 5, 38, 1, 28, 
    1, 71, 5, 98, 0, 51, 8, 68, 4, 42, 7,  1, 2, 10, 3, 36, 6, 71, 
    0, 81, 6, 54, 1, 90, 4, 10, 3, 64, 5, 72, 2, 16, 7, 23, 8, 12
  };
  const int q9493[] = {
    9, 9, // Number of jobs and machines
    5, 66, 6, 19, 1, 72, 4, 96, 0, 68, 3, 55, 8, 27, 2, 98, 7, 76, 
    5, 40, 8, 10, 2, 20, 7, 72, 0, 16, 1, 86, 3, 90, 6, 71, 4, 77, 
    7, 51, 1, 90, 5, 24, 0, 18, 2, 21, 6, 17, 4, 57, 3, 78, 8, 16, 
    8,  3, 2, 13, 3, 29, 7, 10, 5, 20, 0, 29, 4, 78, 1, 37, 6, 88, 
    2, 47, 4, 43, 3, 72, 7, 22, 8, 25, 1, 84, 6, 41, 5, 61, 0, 70, 
    7, 55, 5, 37, 0, 26, 8, 69, 6, 21, 1, 99, 2, 47, 3,  5, 4,  1, 
    2, 43, 6, 65, 3,  6, 7, 51, 4,  6, 8,  8, 5, 67, 1, 44, 0, 70, 
    3, 57, 7,  4, 4, 24, 1, 78, 2, 36, 6, 39, 0, 98, 5, 73, 8, 83, 
    7, 50, 0, 41, 1, 49, 8,  1, 3, 59, 4, 96, 5, 60, 2, 80, 6, 19
  };
  const int q9494[] = {
    9, 9, // Number of jobs and machines
    6, 50, 3, 35, 7, 69, 5,  8, 2, 89, 4, 98, 1, 32, 0,  5, 8, 98, 
    8, 62, 3, 36, 7,  4, 6, 92, 5, 11, 2, 23, 1, 29, 0, 94, 4, 41, 
    6, 66, 5, 32, 8, 82, 4, 62, 7, 72, 0, 39, 3, 97, 2, 13, 1, 95, 
    2, 51, 7, 67, 1, 23, 6, 35, 0, 39, 8,  2, 3, 53, 5, 17, 4, 38, 
    1, 25, 4, 92, 6, 66, 0, 51, 3, 15, 2, 19, 7, 25, 5, 73, 8, 68, 
    4, 58, 7, 82, 6,  8, 1,  7, 2, 75, 3, 37, 0, 78, 5, 80, 8, 99, 
    3, 12, 2, 81, 5,  6, 6, 17, 0, 30, 7, 17, 4, 13, 1, 23, 8,  4, 
    1, 66, 7, 21, 8, 32, 5, 78, 6, 56, 2, 92, 0, 65, 4, 44, 3, 33, 
    0, 66, 1, 67, 4, 57, 7, 67, 2, 29, 5, 89, 3, 15, 6, 19, 8,  6
  };
  const int q9495[] = {
    9, 9, // Number of jobs and machines
    5, 64, 7, 26, 6,  6, 3, 21, 2, 21, 1,  1, 0, 43, 4, 50, 8, 58, 
    6, 38, 1, 22, 4,  2, 8, 71, 0, 52, 7, 95, 3, 78, 5, 47, 2, 76, 
    5, 90, 1, 31, 4, 26, 3, 47, 2,  5, 0, 34, 6,  3, 7, 54, 8, 23, 
    8, 18, 4, 80, 2, 80, 7, 79, 3, 19, 6, 94, 0, 64, 1, 76, 5, 27, 
    0, 23, 3, 66, 2, 85, 7, 19, 6, 84, 4, 50, 8, 58, 1, 18, 5, 26, 
    3, 17, 8, 46, 6, 19, 0, 63, 4, 78, 2, 75, 7, 44, 5, 27, 1, 86, 
    2, 30, 6, 60, 4, 19, 7, 59, 0, 83, 3, 29, 8, 38, 5, 45, 1, 79, 
    6, 20, 7, 43, 1, 18, 4, 32, 0, 70, 3, 50, 8, 45, 5, 70, 2, 34, 
    8, 31, 1, 99, 4, 10, 3, 50, 7, 14, 0, 78, 6, 47, 5, 47, 2, 25
  };
  const int q9496[] = {
    9, 9, // Number of jobs and machines
    3, 26, 7, 78, 1, 96, 6, 69, 8, 18, 0, 86, 2, 44, 4,  2, 5, 42, 
    5, 34, 6, 28, 7, 19, 3, 60, 0, 69, 4, 14, 2, 38, 1, 43, 8, 77, 
    4, 98, 3,  5, 5, 36, 2,  4, 0, 85, 1, 27, 6, 21, 7, 56, 8, 76, 
    4, 19, 7, 63, 3, 24, 8,  9, 2, 68, 1, 12, 5, 17, 0, 57, 6, 91, 
    5, 95, 4, 38, 7, 97, 6, 80, 8, 16, 1, 75, 0, 12, 2, 14, 3, 62, 
    4, 83, 7, 43, 5, 68, 3, 96, 1, 24, 6, 29, 0,  8, 8, 59, 2, 45, 
    4,  1, 1, 52, 2, 54, 6, 89, 7, 85, 3, 60, 8, 27, 0, 14, 5, 95, 
    3, 41, 0, 27, 5, 76, 6, 95, 4, 33, 1, 96, 2, 10, 7, 31, 8, 11, 
    5,  8, 2,  4, 1, 21, 8, 96, 7, 29, 6, 62, 0, 37, 4, 77, 3, 28
  };
  const int q9497[] = {
    9, 9, // Number of jobs and machines
    3, 83, 1, 80, 0, 55, 8,  8, 6, 93, 5, 80, 2, 52, 4, 33, 7, 50, 
    8, 19, 2, 10, 3, 88, 4, 90, 0, 39, 7, 13, 1, 13, 5, 62, 6, 89, 
    4, 90, 8, 83, 7, 71, 3, 26, 5, 74, 0, 52, 6, 32, 1, 91, 2, 59, 
    8, 17, 4, 58, 0, 36, 1, 14, 5, 67, 3, 91, 7, 22, 6, 51, 2, 93, 
    1, 15, 5, 73, 6, 67, 4, 57, 0, 18, 3,  6, 2, 34, 7, 56, 8, 41, 
    8, 14, 2, 50, 4, 12, 3, 31, 5, 40, 6, 70, 7, 70, 1, 27, 0, 66, 
    4, 90, 8, 44, 7, 20, 2, 22, 0, 26, 6, 64, 1, 97, 3, 24, 5, 91, 
    8, 20, 5, 76, 1, 69, 7, 91, 2, 15, 3, 72, 4, 18, 6, 80, 0, 90, 
    1, 31, 4, 11, 6, 22, 5, 18, 8, 62, 7, 47, 0, 14, 2, 82, 3, 58
  };
  const int q9498[] = {
    9, 9, // Number of jobs and machines
    1, 78, 0, 94, 8, 59, 3, 18, 2, 31, 5, 72, 4, 70, 6, 62, 7, 53, 
    4, 23, 0, 72, 8, 75, 7, 87, 5, 12, 1, 51, 6, 60, 3, 44, 2, 22, 
    6,  4, 1, 63, 3, 85, 0, 12, 8, 32, 7, 99, 5,  6, 2, 70, 4, 85, 
    2, 43, 7, 67, 5, 87, 1, 87, 4, 96, 3, 52, 8, 45, 6, 45, 0,  3, 
    6,  3, 4, 61, 8, 61, 7, 48, 5, 64, 1, 36, 3, 85, 0, 96, 2, 71, 
    0, 76, 4, 52, 2, 12, 7,  9, 6, 92, 5, 90, 8, 51, 1, 87, 3, 58, 
    3, 26, 0,  1, 4, 41, 8, 97, 6, 89, 5, 67, 2, 23, 7, 92, 1, 76, 
    5, 97, 7, 13, 1, 57, 0, 24, 4,  2, 8, 76, 3, 42, 2, 53, 6, 87, 
    3, 74, 5, 75, 0, 97, 4,  8, 6, 11, 1, 76, 2, 10, 8, 43, 7, 80
  };
  const int q9499[] = {
    9, 9, // Number of jobs and machines
    0, 12, 3, 11, 5, 63, 4, 28, 7, 59, 8, 61, 2, 64, 6, 12, 1, 18, 
    3, 38, 6, 68, 2, 67, 4, 88, 1, 39, 5, 12, 0, 45, 7, 15, 8, 78, 
    4, 39, 0, 58, 5, 25, 7, 50, 6, 98, 2, 10, 3, 63, 1, 52, 8, 81, 
    2, 11, 4, 63, 7, 73, 6,  4, 1, 12, 8,  7, 5, 69, 0,  5, 3, 65, 
    3, 43, 4, 31, 1, 38, 5, 67, 7, 37, 2, 38, 8, 34, 6, 40, 0, 74, 
    4, 89, 8, 70, 0, 93, 2, 65, 6, 70, 3, 66, 5, 15, 7, 61, 1, 69, 
    6, 99, 7, 74, 1,  4, 8, 63, 2, 10, 3, 67, 0, 63, 4, 72, 5, 25, 
    6,  1, 7, 13, 1, 72, 8, 80, 4, 58, 0, 35, 2, 63, 5, 96, 3,  6, 
    5, 92, 3, 27, 4, 47, 2, 11, 0, 80, 1, 56, 8, 32, 7, 19, 6, 41
  };
  const int q9500[] = {
    9, 9, // Number of jobs and machines
    2, 78, 0, 55, 8, 23, 4, 60, 7,  6, 5, 99, 1, 25, 6, 62, 3, 83, 
    1, 43, 8, 29, 3, 86, 7, 32, 4, 67, 2, 96, 6, 82, 0, 16, 5, 65, 
    7, 36, 1, 89, 0, 66, 8, 76, 4, 69, 6, 95, 5,  6, 2, 97, 3, 98, 
    4, 19, 2, 43, 5,  4, 6,  3, 8, 60, 0, 52, 3, 86, 7, 92, 1, 62, 
    6, 97, 7, 11, 2, 60, 3, 76, 0, 25, 8, 40, 5, 16, 1, 79, 4, 75, 
    4, 13, 0, 70, 5, 91, 7, 17, 6, 42, 3, 29, 2, 61, 8,  8, 1, 39, 
    4, 16, 1,  3, 8, 24, 7,  8, 3, 26, 0, 33, 6, 51, 5, 63, 2, 47, 
    7, 91, 1, 54, 5, 18, 0, 54, 8, 85, 4, 86, 3, 57, 6, 43, 2, 98, 
    3, 85, 7, 13, 5, 96, 8, 20, 6, 95, 4, 54, 1, 46, 0, 19, 2, 85
  };
  const int q9501[] = {
    9, 9, // Number of jobs and machines
    2, 98, 4, 29, 3, 31, 1, 11, 7, 90, 5, 13, 8, 68, 0, 67, 6, 77, 
    6, 66, 0, 69, 5, 75, 3, 19, 7, 41, 2, 19, 8, 59, 1, 68, 4, 43, 
    3, 69, 4, 82, 0, 68, 8, 91, 7, 95, 2, 75, 5, 20, 1, 47, 6, 39, 
    3, 88, 8, 47, 0, 58, 7, 37, 6, 50, 1,  5, 2, 38, 5, 85, 4, 18, 
    6, 69, 4, 63, 2, 14, 8, 22, 0, 79, 3, 16, 7, 98, 5, 15, 1, 17, 
    6, 10, 2, 38, 0, 50, 1, 37, 3, 46, 7, 32, 8,  3, 4, 49, 5, 47, 
    5, 76, 1, 26, 3, 78, 0,  2, 2,  4, 4, 30, 7, 43, 6, 72, 8,  4, 
    6, 20, 3, 98, 5, 51, 8, 66, 7, 57, 1, 91, 0, 54, 2,  3, 4, 54, 
    8, 49, 2, 12, 5, 50, 7, 15, 0,  8, 1,  9, 4, 26, 3, 48, 6, 17
  };
  const int q9502[] = {
    9, 9, // Number of jobs and machines
    5, 65, 0,  4, 3, 32, 7, 61, 1, 89, 8, 91, 4, 23, 2, 60, 6, 46, 
    0, 95, 8,  4, 4, 99, 1, 99, 3, 54, 2, 58, 6, 27, 5, 54, 7, 95, 
    3,  1, 8, 20, 4, 98, 6, 75, 5, 12, 1, 70, 2, 59, 0, 34, 7, 48, 
    0, 33, 6,  8, 7, 92, 8, 64, 3, 53, 1, 43, 4, 53, 5, 64, 2, 95, 
    0, 58, 6, 48, 5, 94, 2, 11, 4, 25, 3, 62, 1, 79, 8, 25, 7, 67, 
    8, 34, 0,  1, 4, 63, 5, 56, 7, 37, 6, 55, 1,  2, 2, 85, 3, 98, 
    7,  6, 0, 54, 8, 16, 6, 24, 1, 65, 4, 50, 2, 10, 5, 55, 3, 57, 
    1,  5, 0, 72, 7, 95, 4, 53, 6, 67, 2, 99, 5, 85, 3, 76, 8, 73, 
    1, 10, 5, 56, 0, 23, 8, 44, 6, 27, 3, 86, 7, 73, 4, 90, 2, 42
  };
  const int q9503[] = {
    9, 9, // Number of jobs and machines
    4, 84, 0, 16, 1, 12, 8, 49, 5, 39, 6, 66, 2, 27, 3, 54, 7, 63, 
    5, 15, 4, 81, 6,  1, 3, 36, 8, 74, 1, 47, 7, 73, 2, 96, 0, 60, 
    7,  7, 3, 16, 0, 13, 6,  2, 5, 20, 8, 60, 2, 42, 4, 24, 1, 69, 
    5,  1, 8,  8, 2, 83, 3, 72, 1, 72, 6, 71, 7, 41, 0, 99, 4,  5, 
    1, 26, 2, 77, 3, 28, 5, 66, 7, 22, 8, 89, 6, 50, 0, 27, 4, 60, 
    4,  8, 7, 71, 5, 23, 6, 81, 8, 73, 0, 56, 1, 84, 3, 28, 2, 41, 
    0, 72, 7, 93, 2, 90, 6, 24, 8, 25, 5, 12, 4, 86, 1,  4, 3, 26, 
    3, 10, 6, 10, 2, 36, 1, 78, 8, 61, 5, 79, 0, 32, 7, 43, 4, 76, 
    3, 44, 7, 30, 8, 63, 0, 32, 5, 59, 4, 23, 1, 92, 2, 51, 6,  6
  };
  const int q9504[] = {
    9, 9, // Number of jobs and machines
    1, 52, 5, 78, 7, 77, 6, 93, 3, 29, 0, 14, 8, 21, 2, 15, 4, 32, 
    7, 73, 8, 85, 1, 77, 0, 27, 6, 29, 4, 75, 3, 81, 5, 74, 2, 72, 
    7, 21, 4, 97, 5, 29, 8, 74, 0, 88, 6, 89, 3, 15, 2, 78, 1, 49, 
    0, 42, 5, 31, 7, 90, 8,  7, 3, 70, 2, 36, 1, 95, 6, 11, 4, 15, 
    8, 18, 4, 71, 5, 49, 0, 73, 7, 27, 6, 42, 3, 25, 1, 65, 2, 51, 
    0, 89, 2, 40, 3, 57, 4, 97, 6, 93, 1, 25, 8, 15, 7, 24, 5, 86, 
    3, 92, 4, 54, 8, 80, 7, 90, 1, 75, 6,  2, 2, 17, 5, 76, 0, 13, 
    2,  4, 3, 17, 8, 18, 5, 39, 1, 18, 0, 36, 4, 60, 7, 11, 6, 43, 
    3, 12, 2, 71, 0, 65, 8, 12, 4, 22, 6, 41, 7, 45, 5, 71, 1, 98
  };
  const int q9505[] = {
    9, 9, // Number of jobs and machines
    5, 66, 1, 41, 7, 27, 2, 68, 3, 49, 0, 25, 6, 38, 4, 82, 8, 89, 
    5, 63, 6, 72, 7, 20, 0, 49, 4, 39, 1,  4, 2, 26, 8, 94, 3, 35, 
    3, 13, 8, 89, 5,  4, 0, 45, 6, 85, 7, 80, 4, 33, 1, 59, 2, 67, 
    7, 82, 6, 51, 0, 50, 4, 90, 3, 71, 2, 48, 5, 95, 1, 53, 8, 89, 
    2, 24, 1, 92, 6, 32, 8, 41, 3, 69, 7, 22, 4, 74, 0, 41, 5, 71, 
    2, 80, 4, 98, 7, 28, 1, 37, 5, 98, 8, 38, 0, 57, 6, 17, 3, 42, 
    2, 94, 8,  1, 1, 92, 6, 58, 4, 46, 5, 30, 3, 54, 7, 27, 0, 85, 
    4, 59, 2, 83, 5, 16, 6, 55, 1, 68, 3, 34, 8, 12, 7, 72, 0, 37, 
    8, 58, 0, 20, 4, 40, 2, 24, 3, 19, 5, 82, 7, 90, 6, 58, 1, 56
  };
  const int q9506[] = {
    9, 9, // Number of jobs and machines
    5, 14, 3, 87, 4,  8, 2, 49, 7, 62, 6,  8, 8, 64, 0, 67, 1,  8, 
    0, 83, 8,  2, 7, 46, 2, 27, 3,  6, 5, 70, 1, 99, 6, 83, 4, 30, 
    8, 66, 4, 86, 3, 55, 2, 16, 5, 67, 0,  6, 6, 63, 1, 88, 7, 28, 
    3, 68, 6, 87, 8, 13, 7, 84, 5, 63, 2, 67, 1, 55, 0, 62, 4, 78, 
    5, 16, 7,  7, 2, 78, 3, 56, 1, 55, 4, 78, 6, 62, 8,  7, 0, 56, 
    8, 83, 3, 24, 6, 11, 1, 18, 0, 66, 7, 77, 4,  8, 5,  6, 2, 93, 
    4, 30, 3, 31, 5, 88, 8, 21, 6, 74, 0, 37, 7, 55, 2, 22, 1, 54, 
    2, 20, 1, 53, 4, 97, 7, 65, 8, 60, 3, 50, 5,  9, 0,  6, 6, 40, 
    7, 96, 8, 79, 5, 46, 2, 24, 1, 66, 0, 29, 3, 68, 4, 27, 6, 73
  };
  const int q9507[] = {
    9, 9, // Number of jobs and machines
    4, 91, 8, 40, 2, 13, 3, 55, 7, 66, 5, 97, 0, 67, 6, 86, 1, 83, 
    7, 97, 1, 13, 5, 90, 0,  7, 2, 72, 4, 41, 6, 81, 3, 32, 8, 70, 
    7, 55, 6, 48, 5, 19, 0, 61, 2, 27, 4, 36, 8, 93, 3, 26, 1, 41, 
    6, 80, 5, 20, 0,  9, 3, 68, 1, 40, 4, 80, 2, 20, 8, 75, 7,  7, 
    5, 53, 1, 30, 8, 52, 0, 35, 6, 84, 3, 74, 4, 40, 7, 98, 2,  4, 
    1, 70, 4, 10, 6, 10, 0, 12, 8, 76, 2, 93, 5, 25, 3, 22, 7, 45, 
    1, 50, 0, 92, 5,  3, 7, 45, 8, 82, 2, 41, 3, 63, 6, 18, 4, 91, 
    2, 75, 7, 25, 8, 56, 6, 19, 0, 25, 4, 70, 1, 15, 5, 27, 3,  8, 
    8, 86, 3, 84, 7, 84, 1, 52, 4, 29, 0, 66, 2, 51, 5, 46, 6, 89
  };
  const int q9508[] = {
    9, 9, // Number of jobs and machines
    4, 89, 1, 42, 2, 34, 8, 85, 5, 20, 3, 71, 7, 91, 6, 85, 0, 37, 
    2,  1, 0, 14, 7, 90, 1, 85, 8, 42, 4, 98, 6,  2, 5, 31, 3, 81, 
    8, 12, 6, 79, 0, 12, 4, 60, 1, 48, 3, 66, 2, 88, 7, 67, 5, 79, 
    1, 55, 3, 70, 5, 69, 2, 74, 4, 19, 7, 67, 8, 26, 0, 37, 6, 21, 
    1, 71, 3, 35, 0, 85, 7, 69, 6, 52, 5, 38, 4,  5, 2, 59, 8, 52, 
    4, 32, 6, 32, 0, 52, 3, 78, 1,  8, 8, 98, 2, 28, 5, 46, 7, 88, 
    2, 35, 3, 96, 4, 40, 7, 93, 0, 16, 8, 16, 5, 50, 6, 68, 1, 11, 
    1, 50, 7, 86, 0, 35, 5, 90, 4, 43, 2, 77, 6, 88, 3, 25, 8, 32, 
    8, 13, 7, 66, 3,  6, 0, 57, 5, 43, 6, 69, 1, 84, 2, 48, 4, 34
  };
  const int q9509[] = {
    9, 9, // Number of jobs and machines
    1, 11, 4, 86, 8, 62, 5, 68, 7, 39, 3, 21, 2, 42, 0, 56, 6,  6, 
    7,  6, 0, 10, 5, 12, 2, 39, 3,  6, 4, 87, 1, 33, 8, 98, 6, 40, 
    1, 41, 3, 88, 5, 96, 7, 54, 8,  9, 0, 70, 4, 67, 2,  1, 6, 83, 
    2,  7, 3, 12, 6, 77, 8, 83, 0, 15, 4, 66, 1, 22, 7, 32, 5, 79, 
    7, 80, 0, 43, 3,  1, 4, 94, 5,  7, 8, 13, 1, 22, 6, 19, 2, 45, 
    1, 67, 5, 96, 2, 32, 8, 89, 3, 93, 6, 67, 7, 51, 0, 54, 4, 31, 
    4, 27, 8, 85, 5, 30, 7,  5, 6, 99, 0, 58, 3, 56, 1, 84, 2, 35, 
    0, 58, 5, 74, 8, 58, 4, 51, 2, 50, 1, 91, 7, 89, 3, 94, 6, 68, 
    2, 60, 3, 73, 8, 13, 1, 95, 4, 68, 5, 63, 6, 99, 0, 28, 7,  8
  };
  const int q9510[] = {
    9, 9, // Number of jobs and machines
    0, 11, 4, 92, 6, 77, 8, 91, 1, 66, 3, 18, 2, 63, 5, 41, 7,  3, 
    0, 49, 8, 24, 6, 17, 3, 34, 5, 46, 7, 22, 2, 61, 4, 70, 1, 95, 
    5, 48, 2, 61, 1, 13, 8, 86, 3, 59, 6, 11, 7, 85, 0, 89, 4, 71, 
    5, 16, 4, 98, 7, 21, 6,  4, 0, 54, 3, 82, 1, 86, 8, 21, 2, 24, 
    2, 12, 4, 24, 6, 60, 3, 75, 8, 35, 1, 41, 7, 27, 5, 84, 0, 85, 
    8,  3, 4, 33, 2, 77, 5, 69, 1, 71, 6, 21, 3, 38, 0, 70, 7, 62, 
    3, 34, 2, 92, 5, 80, 8, 37, 6, 15, 0, 34, 1, 33, 7, 35, 4, 27, 
    2,  4, 4, 53, 0, 76, 1, 46, 5, 51, 8, 20, 3, 39, 7, 21, 6, 66, 
    2, 47, 0, 54, 8, 49, 3,  2, 5, 59, 6, 95, 4, 73, 1, 17, 7, 24
  };
  const int q9511[] = {
    9, 9, // Number of jobs and machines
    1, 19, 5, 55, 7, 56, 2, 39, 6, 82, 4, 84, 8, 31, 3, 35, 0, 66, 
    6,  9, 2, 25, 0, 72, 5, 99, 7, 48, 4, 37, 8, 96, 1, 25, 3, 46, 
    8,  7, 5, 41, 2, 97, 3, 95, 1, 67, 7, 19, 0, 96, 6, 63, 4, 22, 
    6, 53, 4, 54, 5, 57, 1,  7, 8,  2, 2, 61, 3, 34, 0, 12, 7, 78, 
    8, 88, 0, 81, 1, 49, 6, 34, 3, 45, 5,  1, 2, 79, 4, 19, 7, 59, 
    6, 75, 7,  2, 1, 24, 4, 33, 5, 14, 2, 52, 3, 62, 0, 13, 8, 36, 
    0, 58, 3, 26, 1, 77, 2, 36, 8, 53, 7, 34, 6, 24, 5, 43, 4, 86, 
    5, 60, 0, 48, 7, 35, 1, 58, 2, 52, 8, 52, 3, 64, 4, 50, 6, 52, 
    3, 82, 6, 31, 5, 40, 8, 86, 4, 63, 7,  5, 2, 20, 1, 45, 0, 94
  };
  const int q9512[] = {
    9, 9, // Number of jobs and machines
    5, 43, 3, 39, 2, 11, 1,  1, 6, 59, 0, 40, 8, 78, 4, 96, 7,  8, 
    0, 53, 7,  3, 5, 23, 4, 30, 8, 54, 2,  3, 3, 39, 1, 82, 6, 71, 
    6, 63, 3, 68, 0, 60, 2, 46, 1, 45, 4,  1, 7,  5, 5, 74, 8, 82, 
    6, 57, 2, 52, 7, 95, 8, 65, 0,  9, 4, 46, 3, 29, 1, 20, 5, 36, 
    0, 33, 1, 91, 8, 95, 4, 88, 7, 56, 5, 70, 2, 33, 6, 25, 3, 67, 
    5, 78, 6, 74, 4, 46, 8, 98, 1, 56, 7, 36, 2, 25, 0, 23, 3, 37, 
    8, 45, 7, 78, 3, 50, 4, 79, 6, 13, 2, 26, 1, 54, 0, 23, 5,  8, 
    1, 10, 8, 65, 7, 54, 3, 97, 0,  4, 5, 57, 2, 78, 4,  5, 6, 75, 
    2,  9, 3, 70, 7, 18, 0, 82, 1, 63, 4, 79, 5, 77, 8,  4, 6, 61
  };
  const int q9513[] = {
    9, 9, // Number of jobs and machines
    4, 84, 1, 96, 2, 38, 7, 25, 8, 24, 0, 75, 3, 21, 5, 88, 6, 49, 
    8, 72, 0, 92, 3, 25, 5, 73, 4,  8, 6, 29, 2, 46, 7, 83, 1, 32, 
    6, 65, 2, 41, 0, 38, 5, 20, 4, 12, 1, 44, 7, 18, 3, 27, 8, 96, 
    3, 54, 8, 10, 5,  4, 1, 69, 7, 57, 0, 73, 4, 78, 2, 92, 6, 98, 
    1, 67, 4, 16, 2, 10, 5, 28, 8, 89, 0, 58, 7, 96, 6,  9, 3, 74, 
    2, 78, 8, 57, 4, 35, 1, 42, 0, 63, 6, 73, 7, 89, 3, 62, 5, 92, 
    4, 18, 3, 51, 6, 23, 8, 55, 1, 13, 2,  5, 7, 99, 5, 29, 0, 59, 
    3, 21, 1, 22, 0, 21, 7, 80, 6, 47, 4, 48, 8, 19, 2, 99, 5, 81, 
    3, 83, 6, 76, 1, 67, 8, 71, 7, 34, 2, 31, 4, 98, 5, 84, 0, 79
  };
  const int q9514[] = {
    9, 9, // Number of jobs and machines
    7, 64, 3, 73, 5, 69, 4, 58, 8, 30, 0, 25, 6,  4, 2, 46, 1, 59, 
    8, 85, 7, 80, 3, 65, 2, 95, 6, 52, 4, 53, 0, 40, 5, 86, 1, 56, 
    7, 53, 5, 51, 6, 52, 1, 82, 3, 64, 0,  8, 4, 58, 2, 26, 8, 19, 
    8,  9, 2, 90, 5, 55, 6, 40, 3, 43, 4, 41, 1, 65, 7,  9, 0, 44, 
    2, 22, 0, 80, 1, 88, 6, 10, 4, 56, 7, 82, 8, 62, 5, 51, 3, 28, 
    8, 23, 2,  8, 5, 71, 4, 34, 3,  1, 1, 14, 0, 65, 7,  4, 6, 55, 
    2, 50, 0, 70, 5, 36, 7, 34, 1, 46, 6, 78, 8, 26, 4, 44, 3, 30, 
    5, 22, 0, 83, 4, 26, 2,  7, 1, 83, 7, 68, 8, 63, 6, 17, 3, 98, 
    6, 89, 3,  1, 1,  3, 5,  7, 2, 50, 8, 88, 0, 93, 7, 76, 4, 99
  };
  const int q9515[] = {
    9, 9, // Number of jobs and machines
    8, 87, 0, 40, 5, 33, 2, 55, 1, 62, 6, 99, 3, 33, 4, 55, 7, 57, 
    5, 47, 7, 88, 0, 38, 8, 41, 4, 93, 6, 67, 1, 69, 2, 96, 3, 82, 
    2, 36, 8, 78, 5, 43, 6, 71, 7, 99, 1, 73, 3, 13, 0, 46, 4, 64, 
    2, 55, 8, 27, 3, 52, 0, 46, 5, 52, 4, 72, 6, 85, 1, 86, 7, 61, 
    8, 28, 1, 12, 3, 83, 6, 37, 7, 14, 2, 47, 0, 25, 5, 12, 4, 15, 
    3, 24, 1, 76, 2, 23, 5, 27, 7, 65, 8, 10, 6, 34, 4, 61, 0, 49, 
    5, 30, 8, 92, 6, 40, 2, 90, 4, 65, 7,  9, 1, 74, 3, 33, 0, 10, 
    8, 47, 1, 50, 7, 95, 6, 49, 5, 83, 2, 57, 4, 80, 3, 53, 0, 54, 
    3,  2, 2, 70, 8, 67, 4, 92, 5, 87, 6, 21, 1, 71, 0, 28, 7, 36
  };
  const int q9516[] = {
    9, 9, // Number of jobs and machines
    6, 74, 1, 37, 7, 44, 0,  4, 3, 90, 4, 66, 2,  9, 5, 34, 8, 99, 
    7, 77, 2, 86, 8, 86, 5, 56, 3, 88, 1, 67, 0, 26, 4, 76, 6, 16, 
    1, 59, 8, 74, 0, 93, 3, 59, 7, 84, 5, 23, 2, 76, 4, 89, 6, 83, 
    4, 79, 3, 81, 2, 67, 7,  8, 1, 45, 8, 84, 6, 75, 5, 28, 0, 96, 
    4, 38, 2, 81, 7, 38, 0, 29, 8, 47, 1, 46, 6,  8, 5, 93, 3, 77, 
    2, 85, 6,  7, 7, 10, 5, 12, 4, 73, 3, 64, 1, 35, 0, 61, 8, 39, 
    4, 78, 2, 51, 5, 95, 3, 81, 7, 93, 1, 10, 6,  3, 8, 41, 0, 41, 
    2, 82, 6, 79, 4, 48, 8, 67, 7, 29, 5, 45, 3, 83, 1, 20, 0, 71, 
    5, 61, 1, 45, 3, 44, 8, 33, 7, 33, 0, 95, 6, 24, 4, 49, 2, 19
  };
  const int q9517[] = {
    9, 9, // Number of jobs and machines
    5, 89, 1,  5, 0, 37, 2, 64, 6, 86, 3, 32, 7,  7, 4, 82, 8, 59, 
    5, 80, 2, 98, 8, 67, 0, 36, 3, 53, 6, 11, 4, 74, 7, 59, 1, 37, 
    4, 31, 8, 97, 6, 59, 5, 26, 7, 73, 2, 77, 1, 49, 0, 30, 3, 52, 
    4, 14, 6, 43, 8, 43, 0, 57, 1, 29, 7, 70, 3, 94, 5, 54, 2, 29, 
    3,  8, 7, 48, 1,  5, 0, 97, 2, 93, 6, 61, 4, 41, 5,  1, 8, 85, 
    0, 51, 3, 41, 5, 72, 1, 46, 6,  5, 2, 18, 7, 80, 8, 32, 4, 67, 
    3, 27, 2, 99, 7, 30, 1, 84, 5, 43, 8, 28, 4, 47, 0,  4, 6,  8, 
    3, 47, 6, 93, 2, 28, 7, 50, 0, 49, 5, 33, 1, 64, 8,  3, 4, 43, 
    7, 45, 6, 76, 1, 35, 3, 23, 0, 54, 5, 68, 2, 64, 4, 49, 8, 34
  };
  const int q9518[] = {
    9, 9, // Number of jobs and machines
    3, 67, 8, 64, 1, 63, 6, 67, 2, 99, 5, 80, 0, 72, 4, 65, 7,  9, 
    0,  3, 1, 83, 3, 26, 4, 22, 6, 96, 7, 83, 8, 86, 5, 59, 2, 44, 
    5, 53, 1, 55, 3, 11, 2, 78, 7, 64, 0, 76, 6, 93, 4, 54, 8, 39, 
    6, 18, 3, 51, 0, 40, 2, 93, 8, 87, 1, 46, 4, 48, 7, 41, 5, 88, 
    1, 36, 7, 73, 0, 68, 2, 34, 5, 79, 3, 86, 8, 84, 6, 47, 4, 53, 
    0, 94, 7, 12, 5, 42, 6,  1, 4, 16, 1, 26, 2,  7, 8, 97, 3, 65, 
    6, 36, 7, 38, 1, 36, 2, 50, 8, 78, 4, 36, 0, 48, 5, 86, 3, 55, 
    2,  7, 6, 41, 8, 78, 3, 77, 4, 53, 5,  1, 1, 70, 0, 27, 7, 28, 
    6, 22, 7, 40, 1, 89, 5, 49, 3, 15, 0, 50, 8, 94, 4, 81, 2, 76
  };
  const int q9519[] = {
    9, 9, // Number of jobs and machines
    1, 86, 3, 19, 4, 45, 7, 56, 5, 53, 0, 30, 2, 40, 6, 59, 8, 70, 
    4, 52, 6, 84, 5, 89, 2, 20, 3, 40, 8, 46, 0, 63, 1, 57, 7, 27, 
    2, 60, 1, 43, 8, 23, 4, 17, 3,  6, 5, 89, 6, 93, 7, 32, 0, 11, 
    5, 28, 7,  3, 4, 89, 2, 25, 6, 56, 0, 85, 8, 40, 3, 12, 1, 43, 
    3, 28, 0, 56, 2, 70, 6, 55, 4, 26, 5, 88, 7, 17, 1, 51, 8, 65, 
    0, 22, 1, 34, 3, 81, 7,  6, 2, 35, 6, 58, 4,  6, 8, 38, 5, 59, 
    2, 71, 7, 48, 1,  2, 5, 49, 4, 22, 0, 22, 6, 72, 8, 65, 3, 22, 
    4, 64, 8,  4, 1,  4, 3, 66, 7, 61, 2, 55, 5, 88, 0,  3, 6, 48, 
    1, 89, 8, 93, 7, 34, 5, 72, 3, 47, 6, 46, 0, 55, 4, 34, 2, 21
  };
  const int q9520[] = {
    9, 9, // Number of jobs and machines
    6, 31, 7, 59, 8, 38, 5, 61, 2,  1, 1, 82, 4, 73, 3, 92, 0, 39, 
    0, 74, 2, 51, 7, 45, 1, 87, 6, 96, 4, 14, 5, 19, 3, 86, 8, 52, 
    1,  3, 8,  4, 3, 53, 7, 28, 5, 12, 0, 13, 4, 45, 6, 64, 2, 59, 
    3, 97, 0, 99, 4, 22, 1, 65, 8, 64, 6, 42, 7, 56, 2, 58, 5,  6, 
    5, 25, 7, 71, 8, 30, 0, 84, 1, 55, 2,  1, 6, 45, 4, 61, 3,  4, 
    7, 85, 4,  3, 3,  4, 1, 88, 0, 59, 6, 90, 5, 88, 2, 82, 8,  9, 
    2, 63, 1, 34, 4, 21, 3, 96, 6, 94, 7, 52, 5, 26, 0, 44, 8, 25, 
    1, 38, 4, 52, 6,  4, 5, 81, 3, 35, 0, 90, 8, 35, 2, 66, 7,  8, 
    4, 34, 8, 80, 5, 77, 1,  6, 7, 15, 0, 96, 3, 98, 6, 48, 2, 86
  };
  const int q9521[] = {
    9, 9, // Number of jobs and machines
    1,  3, 5, 57, 7,  3, 2, 37, 6, 97, 0, 13, 3,  2, 8, 30, 4, 52, 
    2, 52, 0, 87, 5, 86, 4, 23, 6, 62, 7, 61, 8, 56, 1, 50, 3, 78, 
    0,  1, 3, 52, 8,  6, 6, 92, 2, 22, 5, 20, 7, 13, 4, 26, 1, 38, 
    7, 36, 5, 73, 6, 37, 2, 57, 0, 19, 1, 51, 3, 49, 8, 29, 4, 54, 
    1, 57, 7, 83, 8,  8, 6, 64, 4, 73, 0, 40, 5, 55, 3, 83, 2, 25, 
    0, 80, 8, 82, 5, 22, 7, 35, 3,  4, 2,  1, 4, 94, 1, 42, 6, 34, 
    5, 46, 1, 86, 8, 18, 7, 72, 2, 39, 0, 82, 3, 39, 4,  8, 6, 58, 
    0, 93, 6, 53, 4, 51, 8, 94, 2, 20, 7, 96, 5, 34, 3, 42, 1, 66, 
    6, 77, 3, 77, 7, 58, 5, 18, 1, 65, 2, 64, 8, 59, 0, 59, 4, 97
  };
  const int q9522[] = {
    9, 9, // Number of jobs and machines
    7, 73, 4, 57, 3, 36, 1, 12, 6, 57, 0, 88, 8, 85, 2, 78, 5, 18, 
    7, 29, 4, 89, 0, 64, 8, 36, 6, 35, 1, 99, 3, 83, 5, 36, 2, 13, 
    0, 99, 2, 18, 4, 70, 3, 68, 8, 66, 6,  5, 5,  3, 1,  9, 7, 64, 
    7, 49, 6, 88, 8, 88, 2, 72, 5, 30, 1, 66, 0,  7, 4,  6, 3, 20, 
    8, 54, 4, 71, 5, 37, 1, 41, 3, 74, 2, 15, 7, 49, 0, 87, 6, 93, 
    2, 93, 1, 69, 0, 93, 5, 72, 8, 47, 6, 22, 7, 19, 4, 31, 3, 59, 
    6, 88, 2, 51, 0, 44, 7, 20, 4,  7, 5, 29, 8, 30, 1, 65, 3, 70, 
    0, 58, 2, 56, 7, 79, 3, 89, 6, 57, 5, 66, 4, 26, 8, 65, 1, 35, 
    8, 87, 1, 21, 2, 41, 5, 34, 4, 36, 3, 65, 0, 67, 6,  7, 7,  6
  };
  const int q9523[] = {
    9, 9, // Number of jobs and machines
    3, 20, 7, 74, 5, 92, 6, 19, 8, 57, 0, 86, 1, 62, 2, 53, 4, 99, 
    1, 55, 8, 19, 6, 50, 0, 54, 3, 83, 5, 86, 7, 49, 2, 36, 4, 51, 
    5, 86, 7, 59, 6, 55, 2,  6, 8, 64, 4, 71, 0, 21, 3, 42, 1, 63, 
    1, 57, 6, 30, 4, 97, 5, 10, 8, 86, 3, 57, 7, 72, 2, 16, 0, 92, 
    1, 90, 0, 42, 5, 77, 7, 30, 3, 67, 8, 71, 2, 62, 6, 78, 4, 23, 
    0,  1, 1, 79, 6, 37, 5,  8, 7, 80, 4, 60, 2, 87, 3, 49, 8,  2, 
    3, 88, 2,  9, 6, 36, 5,  8, 7, 41, 0, 11, 1,  6, 4, 85, 8, 18, 
    0, 62, 3, 37, 2, 74, 7, 44, 4, 85, 1, 63, 8, 62, 5, 85, 6, 98, 
    4, 22, 8, 49, 7, 10, 0, 44, 5, 26, 6, 49, 3, 29, 1, 81, 2, 18
  };
  const int q9524[] = {
    9, 9, // Number of jobs and machines
    2, 28, 0, 76, 8, 80, 5, 95, 7, 21, 1, 14, 4, 89, 3, 21, 6, 79, 
    3,  2, 6, 75, 5, 29, 7, 77, 1, 78, 8, 72, 2, 34, 4, 59, 0, 44, 
    1, 80, 4, 31, 5, 96, 6, 19, 3, 22, 0,  3, 8,  3, 7, 12, 2, 88, 
    5, 94, 2, 74, 0, 73, 1, 91, 3,  9, 6, 63, 8,  4, 7, 23, 4, 31, 
    0, 81, 7, 90, 1, 65, 5, 34, 3, 48, 4, 59, 8, 58, 2, 32, 6,  2, 
    7,  7, 1, 25, 6, 11, 0, 64, 2, 63, 4, 34, 5, 27, 8, 87, 3, 67, 
    8, 47, 2, 75, 3, 35, 0, 39, 4, 16, 6, 94, 7,  2, 1, 81, 5, 49, 
    7, 56, 1, 39, 2, 51, 4, 43, 8, 23, 6,  2, 0, 31, 3, 26, 5, 79, 
    7, 32, 1, 94, 3, 54, 0,  4, 6, 14, 4, 78, 2, 28, 5, 82, 8, 63
  };
  const int q9525[] = {
    9, 9, // Number of jobs and machines
    7, 91, 3, 24, 6, 12, 8, 50, 5, 84, 0, 37, 1, 19, 4, 97, 2, 73, 
    4, 57, 1, 37, 3, 87, 2, 96, 0, 94, 7, 59, 8, 84, 5, 48, 6, 20, 
    2, 43, 7, 22, 6, 89, 5, 72, 8, 47, 1, 24, 3, 71, 0, 19, 4,  7, 
    1, 16, 6, 13, 7, 24, 8, 93, 5, 50, 4, 99, 0, 96, 3, 90, 2, 34, 
    5, 22, 2, 77, 7, 23, 6, 34, 4, 44, 0, 59, 3, 23, 8,  6, 1, 93, 
    3, 26, 4, 99, 5, 58, 7, 51, 0, 47, 1, 10, 6, 56, 8, 25, 2, 52, 
    3, 78, 5, 20, 7, 36, 0, 69, 6, 17, 1,  8, 2, 21, 8, 26, 4,  1, 
    1, 40, 2, 35, 5, 31, 6, 38, 4, 53, 8, 26, 3, 69, 0, 55, 7,  4, 
    3, 41, 5, 53, 1, 35, 7, 48, 6, 27, 0, 48, 4, 87, 8, 81, 2, 13
  };
  const int q9526[] = {
    9, 9, // Number of jobs and machines
    2, 11, 6, 25, 3, 98, 4, 29, 8, 59, 1, 47, 5, 83, 0,  5, 7,  2, 
    6, 92, 3, 65, 4, 35, 8, 14, 5, 94, 2,  5, 1, 32, 7, 67, 0, 39, 
    8, 24, 2, 94, 4, 56, 3, 28, 0, 73, 1, 83, 6, 55, 7, 51, 5, 30, 
    6, 99, 4, 71, 0, 97, 5, 48, 7, 59, 2, 79, 1, 52, 3, 67, 8, 89, 
    1, 58, 8, 75, 3, 25, 0, 98, 5, 98, 4, 11, 6, 55, 2, 24, 7, 70, 
    7, 88, 6,  4, 5, 61, 0, 69, 8,  3, 1, 39, 2, 66, 3, 27, 4, 41, 
    3, 35, 8, 77, 5, 96, 1, 81, 7, 14, 4, 47, 2, 42, 6, 16, 0, 59, 
    8,  6, 6, 88, 1, 73, 0, 36, 3,  4, 5, 84, 4, 41, 2, 73, 7,  3, 
    0, 99, 7, 36, 5, 53, 3, 24, 2, 38, 1, 68, 4, 74, 8, 95, 6, 60
  };
  const int q9527[] = {
    9, 9, // Number of jobs and machines
    4,  9, 1, 56, 6, 77, 0, 13, 5, 44, 8, 88, 3, 36, 2, 12, 7,  6, 
    6, 90, 3, 32, 0, 19, 1,  9, 2,  3, 5, 84, 8, 15, 4, 59, 7, 35, 
    0,  3, 2, 22, 8,  3, 6, 96, 3, 14, 4, 80, 5,  7, 7,  6, 1, 30, 
    8, 80, 7, 26, 1, 91, 6, 21, 2, 41, 4, 95, 5, 94, 3, 20, 0, 11, 
    0, 19, 3, 12, 4, 78, 7, 99, 6, 41, 2,  4, 1, 73, 8, 64, 5, 27, 
    1, 81, 5, 25, 6, 61, 4, 28, 2, 77, 0, 75, 7, 49, 3, 66, 8, 62, 
    5, 46, 3, 17, 2,  4, 4, 88, 0, 28, 1, 82, 8, 15, 7, 84, 6, 40, 
    8, 69, 0, 59, 2, 20, 7, 67, 4, 37, 1, 61, 3, 73, 5, 88, 6, 43, 
    0, 57, 8, 93, 1, 99, 7,  3, 4,  9, 3, 10, 2, 19, 5, 59, 6, 69
  };
  const int q9528[] = {
    9, 9, // Number of jobs and machines
    4, 28, 2, 51, 3, 35, 6, 18, 5,  9, 8, 70, 1, 90, 7, 30, 0, 92, 
    2, 99, 4, 51, 3, 14, 6, 59, 0, 44, 8, 99, 5, 90, 7, 63, 1, 58, 
    4,  6, 7, 85, 5, 17, 1, 45, 2, 21, 8,  4, 3, 34, 6, 99, 0, 64, 
    1, 93, 6, 85, 7, 48, 3, 92, 8, 24, 0, 62, 2, 29, 5, 56, 4, 74, 
    1, 59, 0, 78, 5, 28, 6, 48, 2, 61, 3, 66, 4, 92, 8, 90, 7, 48, 
    3, 84, 8, 38, 2, 36, 4, 21, 6, 42, 0, 52, 7, 45, 1,  6, 5, 32, 
    8, 58, 1, 64, 0, 94, 5, 33, 2, 83, 4, 94, 3, 15, 7, 72, 6,  9, 
    7, 92, 6, 22, 3, 43, 1,  7, 5, 87, 8, 24, 0, 75, 4, 35, 2, 22, 
    7, 21, 5, 53, 2, 39, 6, 81, 3, 81, 8, 94, 1, 86, 0, 13, 4, 59
  };
  const int q9529[] = {
    9, 9, // Number of jobs and machines
    7, 89, 8, 76, 4, 64, 3, 61, 1, 73, 2, 32, 0, 71, 6, 29, 5, 32, 
    0, 71, 6, 42, 4,  1, 8, 88, 5, 85, 3, 39, 7, 24, 1, 29, 2, 60, 
    5, 76, 6,  5, 0, 21, 4,  6, 2, 69, 8,  4, 7, 54, 1, 49, 3, 61, 
    1, 52, 3, 19, 5, 77, 7, 12, 0, 15, 2, 44, 6,  6, 8, 36, 4, 57, 
    0, 22, 3, 33, 2, 64, 4, 75, 7, 32, 1,  9, 5, 29, 6, 19, 8, 98, 
    3, 74, 5, 83, 1, 15, 7, 34, 8, 84, 6, 49, 2,  8, 4, 74, 0, 18, 
    1, 44, 0, 81, 5, 82, 8, 53, 7,  6, 6, 53, 4, 69, 2, 63, 3, 46, 
    4, 30, 5, 56, 1, 99, 7, 51, 6, 97, 2, 78, 8, 93, 0, 88, 3, 86, 
    3, 38, 1, 23, 0, 65, 7, 95, 2, 33, 8, 75, 6, 67, 4, 89, 5, 13
  };
  const int q9530[] = {
    9, 9, // Number of jobs and machines
    6, 36, 7, 29, 5, 70, 0, 78, 1, 75, 4, 61, 2, 65, 8, 80, 3, 58, 
    1, 72, 2, 31, 5, 87, 8, 78, 3, 37, 4, 18, 0, 18, 7,  2, 6, 90, 
    4, 56, 6, 13, 0, 25, 5, 93, 7, 97, 2,  2, 8, 89, 3, 38, 1, 40, 
    5,  6, 6, 88, 8, 54, 2, 41, 1, 48, 0, 64, 7, 12, 3, 53, 4, 64, 
    6, 25, 2, 24, 0, 92, 3, 20, 8,  5, 1, 82, 7, 76, 5, 25, 4, 76, 
    7, 61, 5, 82, 1, 94, 4,  6, 8,  1, 3, 71, 6, 88, 2, 99, 0, 31, 
    0, 61, 5, 24, 8, 50, 4, 96, 3, 21, 7, 47, 1, 96, 2, 71, 6,  4, 
    2, 16, 8, 10, 0,  5, 4, 33, 1, 46, 3, 47, 6, 67, 7, 57, 5, 68, 
    6, 83, 8, 97, 3,  9, 7, 51, 2, 12, 5, 80, 0, 62, 4, 23, 1, 26
  };
  const int q9531[] = {
    9, 9, // Number of jobs and machines
    2, 43, 6, 37, 8, 54, 5, 22, 1, 41, 7, 99, 3, 10, 4, 98, 0, 70, 
    2, 43, 5,  1, 0, 70, 4, 42, 8, 55, 3,  5, 1, 44, 6, 12, 7, 98, 
    0, 13, 4, 47, 7, 72, 3, 83, 2, 77, 1, 26, 6, 36, 8, 63, 5, 19, 
    4, 56, 7, 18, 1, 53, 5, 71, 0, 81, 3, 11, 6, 76, 8, 51, 2,  1, 
    4, 16, 6, 54, 2, 60, 0, 99, 5, 89, 1, 37, 7, 28, 8,  1, 3, 31, 
    3, 68, 1, 75, 5, 20, 4,  4, 6, 14, 7,  8, 8, 71, 0,  2, 2, 82, 
    4, 55, 7, 17, 8, 28, 5, 32, 6, 43, 2, 99, 1, 38, 3, 97, 0, 68, 
    6, 20, 4, 61, 8, 34, 5, 36, 2,  9, 7, 90, 1, 44, 3,  9, 0, 11, 
    7, 99, 4, 92, 6, 45, 1, 93, 8, 78, 3, 19, 0, 98, 2, 82, 5, 79
  };
  const int q9532[] = {
    9, 9, // Number of jobs and machines
    5, 88, 1, 87, 3, 62, 8, 40, 4, 12, 0, 56, 6, 78, 2, 92, 7, 70, 
    0, 63, 1, 62, 4, 39, 3, 95, 8, 84, 5, 19, 7,  1, 2, 42, 6, 88, 
    6, 50, 0, 84, 8, 55, 3, 39, 7, 27, 2, 51, 5, 24, 4, 69, 1, 94, 
    8,  2, 6, 57, 0, 83, 5, 20, 2, 55, 1, 39, 7, 17, 3, 11, 4,  1, 
    7, 60, 3, 66, 4, 62, 0, 20, 1, 29, 8, 97, 5, 61, 6, 46, 2,  4, 
    1, 74, 5, 39, 2, 17, 3, 98, 4, 91, 6, 24, 7, 34, 0, 72, 8, 55, 
    2, 13, 1, 14, 7, 34, 5, 47, 0, 58, 3, 90, 4, 13, 6, 65, 8, 46, 
    0, 80, 3, 17, 2, 13, 1, 68, 6, 78, 4, 44, 7, 17, 5, 17, 8, 70, 
    0, 75, 2, 41, 4, 12, 6, 55, 8, 70, 1, 89, 7, 77, 3, 41, 5, 48
  };
  const int q9533[] = {
    9, 9, // Number of jobs and machines
    0,  6, 3, 20, 6, 70, 4, 69, 1, 50, 8, 79, 2, 57, 7, 68, 5, 14, 
    0, 53, 1, 80, 5, 97, 2, 39, 3, 53, 8, 80, 4, 40, 6, 18, 7, 51, 
    4, 30, 2, 33, 5, 46, 0, 29, 7, 91, 8, 87, 6, 58, 1, 29, 3, 48, 
    1, 36, 6, 18, 5, 24, 2, 42, 7, 82, 8, 32, 0, 27, 4, 81, 3, 92, 
    5, 46, 6, 40, 0, 96, 1, 75, 7, 75, 8, 66, 4, 14, 2, 28, 3, 67, 
    5,  8, 6, 12, 1,  3, 0, 44, 2, 78, 3, 27, 4, 96, 8, 75, 7, 52, 
    3, 60, 6, 38, 2, 32, 7, 42, 8, 66, 5, 33, 1, 32, 4, 60, 0, 65, 
    4,  2, 3, 19, 5, 27, 1, 34, 6, 41, 7, 75, 8, 59, 2, 19, 0, 62, 
    6,  3, 8, 40, 4, 92, 0,  7, 1, 62, 2, 75, 5, 16, 7, 89, 3, 10
  };
  const int q9534[] = {
    9, 9, // Number of jobs and machines
    6, 44, 1, 83, 8, 50, 0, 10, 2, 44, 7, 87, 5, 81, 3, 65, 4, 86, 
    6, 93, 8, 27, 0, 92, 2, 10, 1, 36, 5, 70, 3, 24, 7,  8, 4, 63, 
    7, 51, 3, 11, 8, 22, 0, 24, 5, 27, 6, 50, 1, 39, 4, 69, 2, 71, 
    6, 82, 8, 73, 5, 88, 0, 48, 4, 89, 3, 81, 7, 44, 2, 81, 1, 58, 
    7, 37, 2,  8, 0, 20, 4, 45, 8, 92, 6, 25, 3,  8, 5, 36, 1, 27, 
    0, 20, 3, 99, 5, 84, 7, 20, 2, 68, 4, 80, 8, 86, 6, 67, 1, 41, 
    4, 65, 8, 52, 5, 90, 7, 52, 0, 90, 2, 45, 1, 23, 6, 11, 3, 96, 
    2, 63, 7, 18, 4, 22, 3, 27, 5, 73, 0, 97, 6, 14, 8, 98, 1, 54, 
    5, 84, 7, 91, 4, 12, 2, 45, 6,  7, 8, 23, 0, 64, 1, 27, 3, 40
  };
  const int q9535[] = {
    9, 9, // Number of jobs and machines
    6, 55, 7, 62, 2, 22, 0,  3, 5, 62, 3, 21, 1, 78, 8, 60, 4, 33, 
    4, 39, 0, 49, 3, 80, 8, 57, 6, 30, 7, 17, 5, 22, 2, 10, 1, 82, 
    1, 36, 2, 96, 0, 88, 5, 60, 7, 32, 6, 14, 8, 17, 3, 62, 4, 46, 
    4, 32, 3, 12, 8,  2, 7, 59, 0, 13, 6, 35, 2, 44, 1, 42, 5, 41, 
    1, 59, 2, 96, 4, 95, 8, 43, 6, 46, 0, 80, 3, 64, 5, 89, 7, 35, 
    0, 94, 2,  4, 5, 82, 8, 81, 4, 76, 6, 98, 3, 24, 1, 54, 7, 58, 
    3, 50, 0,  4, 1, 95, 2, 23, 8, 91, 6, 86, 4, 51, 5, 81, 7, 15, 
    0, 12, 3,  9, 2, 39, 7, 66, 4, 28, 1, 95, 5, 32, 8, 16, 6, 42, 
    1, 83, 3, 28, 8, 99, 4, 95, 2, 90, 7, 13, 6, 67, 5, 15, 0, 82
  };
  const int q9536[] = {
    9, 9, // Number of jobs and machines
    2, 82, 8, 16, 1, 89, 3, 26, 7, 19, 6, 87, 4, 64, 0, 80, 5, 33, 
    8, 55, 2, 46, 1, 26, 0, 38, 7, 78, 6, 99, 4, 23, 3, 22, 5, 33, 
    5, 66, 8, 19, 1, 58, 2, 83, 3,  6, 6, 91, 7,  8, 4, 38, 0, 15, 
    3, 51, 5, 35, 8, 85, 2, 60, 4, 36, 6, 31, 0, 55, 1,  3, 7, 47, 
    7, 10, 0, 11, 4, 12, 1, 36, 2,  2, 3, 29, 5, 97, 6, 66, 8, 67, 
    0, 88, 5, 75, 3, 59, 8, 73, 1, 80, 6, 63, 2, 71, 7, 40, 4, 88, 
    6, 18, 1, 97, 7, 47, 2, 34, 5, 21, 3, 91, 8, 45, 0, 20, 4, 35, 
    3, 82, 0, 14, 6, 59, 8, 55, 7, 29, 4, 37, 5, 12, 2, 23, 1, 28, 
    7, 11, 8, 17, 2,  9, 5, 66, 6, 85, 0, 55, 3, 97, 4, 84, 1,  2
  };
  const int q9537[] = {
    9, 9, // Number of jobs and machines
    6, 50, 7, 25, 8, 31, 4, 83, 5, 11, 1, 94, 0, 90, 3, 41, 2,  5, 
    4,  1, 8, 22, 1,  3, 2, 24, 0, 39, 6, 59, 7, 93, 3, 44, 5, 76, 
    0, 47, 1, 74, 3, 74, 7, 80, 5, 74, 8,  8, 4, 31, 6, 93, 2, 55, 
    8, 21, 2, 31, 1, 94, 5, 55, 3, 83, 7, 23, 4, 84, 6, 80, 0, 25, 
    2, 32, 5, 73, 3, 60, 0, 80, 6, 10, 8,  5, 4, 10, 1, 57, 7, 28, 
    4, 71, 2, 28, 3, 31, 8, 22, 7, 62, 1, 97, 6, 47, 0, 75, 5, 73, 
    5, 30, 8, 75, 6, 38, 1, 92, 4, 49, 2, 89, 7, 50, 3, 64, 0, 44, 
    2, 91, 5, 50, 1, 89, 4,  9, 6, 89, 3, 47, 0, 18, 8, 56, 7, 10, 
    5,  4, 2, 73, 8, 28, 4, 58, 6, 47, 7, 62, 0,  2, 1, 90, 3,  8
  };
  const int q9538[] = {
    9, 9, // Number of jobs and machines
    1, 62, 8, 24, 4, 46, 7, 62, 3, 50, 5, 73, 6, 74, 2, 27, 0,  2, 
    7, 10, 4, 71, 6, 91, 3, 44, 8, 36, 0, 65, 5, 28, 1, 18, 2,  2, 
    5, 14, 2, 70, 7, 38, 1, 51, 0, 49, 8, 99, 4,  3, 6, 10, 3, 88, 
    7, 18, 1, 67, 0, 49, 8, 55, 4, 28, 3, 31, 5, 19, 6, 86, 2, 41, 
    3, 70, 8, 80, 6, 84, 4, 69, 7, 54, 5, 46, 0, 98, 2, 97, 1, 83, 
    4, 97, 3, 35, 7, 89, 1, 24, 6, 79, 5, 90, 2, 78, 0, 52, 8, 14, 
    0, 75, 8, 24, 5, 21, 6, 59, 7, 48, 1,  6, 2, 13, 3, 90, 4, 51, 
    7,  8, 8,  6, 1, 27, 4, 62, 5,  2, 6, 39, 2, 32, 0, 14, 3, 38, 
    0, 91, 7, 65, 4, 50, 8,  9, 6, 71, 1, 62, 5, 17, 3, 80, 2, 43
  };
  const int q9539[] = {
    9, 9, // Number of jobs and machines
    5,  3, 6, 11, 8, 23, 0, 27, 2, 90, 1, 39, 4, 65, 7, 20, 3, 57, 
    3, 72, 6, 72, 2, 79, 0, 87, 7, 92, 5, 88, 8, 43, 1, 52, 4, 95, 
    3, 47, 7, 37, 5, 61, 6, 49, 1, 24, 8, 33, 4, 51, 0, 51, 2, 26, 
    8, 42, 0, 90, 3,  7, 6, 89, 1, 28, 2, 65, 4, 32, 5, 48, 7, 52, 
    0, 43, 8, 99, 5, 54, 1, 11, 2, 88, 4, 41, 3, 30, 7, 98, 6, 37, 
    8, 92, 2, 46, 7, 53, 1, 19, 4, 81, 6, 84, 5, 59, 0, 87, 3, 43, 
    1, 36, 6, 87, 5, 87, 3, 18, 7,  3, 2, 23, 8, 31, 0, 98, 4, 33, 
    3, 38, 6, 31, 0, 25, 2, 10, 5, 72, 8, 72, 1, 89, 4, 31, 7, 29, 
    1, 58, 4, 55, 2, 54, 5, 77, 6, 60, 3, 70, 7, 50, 8, 79, 0, 38
  };
  const int q9540[] = {
    9, 9, // Number of jobs and machines
    5, 20, 6, 56, 2, 79, 3, 61, 8, 83, 1, 73, 4, 61, 7, 87, 0, 65, 
    8, 72, 6, 84, 7, 61, 2, 55, 4, 64, 5, 55, 1, 10, 0, 78, 3, 45, 
    4, 88, 7, 78, 1, 62, 8,  4, 3, 38, 5, 55, 0, 35, 6, 51, 2, 68, 
    8, 88, 7, 30, 6, 41, 4,  9, 3, 22, 5, 27, 2, 72, 0, 39, 1, 91, 
    5, 62, 1, 18, 3, 21, 4, 93, 6, 17, 2, 19, 7, 19, 8, 80, 0, 38, 
    5, 21, 8, 18, 6,  4, 2, 51, 0,  7, 4, 20, 7, 37, 3, 36, 1, 60, 
    1, 21, 7, 80, 8, 33, 2, 32, 5, 56, 0, 60, 6,  1, 3, 52, 4, 71, 
    1, 65, 8, 94, 7, 16, 6,  8, 0, 57, 4, 59, 2, 84, 5, 91, 3, 34, 
    2, 14, 7, 67, 5, 47, 3, 64, 6, 40, 4, 57, 0, 33, 1, 91, 8, 11
  };
  const int q9541[] = {
    9, 9, // Number of jobs and machines
    8, 64, 6, 34, 7, 25, 1, 25, 3, 68, 2, 97, 0, 89, 4, 19, 5,  4, 
    5, 76, 4, 61, 0, 80, 2, 78, 6, 97, 3, 33, 1, 49, 8, 37, 7, 83, 
    7, 77, 8, 80, 2, 53, 0,  6, 1, 62, 6, 66, 4, 13, 5, 54, 3, 88, 
    0, 89, 4, 85, 1, 54, 7, 47, 5,  5, 6, 45, 3, 73, 2, 49, 8, 72, 
    3, 44, 2, 14, 0, 31, 8, 86, 1, 29, 4, 40, 6, 36, 5, 48, 7, 44, 
    8, 14, 1, 98, 6, 72, 4, 77, 2, 84, 5, 26, 7, 64, 3, 62, 0, 91, 
    5, 64, 6, 91, 2, 26, 3, 87, 4, 40, 7, 69, 0,  3, 8, 70, 1,  2, 
    4, 19, 2, 79, 5, 95, 3, 84, 8, 91, 6, 83, 1, 24, 7, 29, 0, 67, 
    6,  4, 1, 75, 0, 77, 5, 10, 4, 49, 2, 11, 7, 62, 3, 53, 8, 11
  };
  const int q9542[] = {
    9, 9, // Number of jobs and machines
    7, 99, 8, 98, 0, 94, 4, 41, 6, 73, 3, 39, 5, 74, 2, 96, 1, 21, 
    7, 80, 5, 96, 1, 74, 6, 79, 2, 53, 0, 46, 3, 62, 8, 79, 4, 94, 
    8, 57, 5, 34, 0, 68, 6, 91, 4, 92, 1, 64, 7, 36, 2, 52, 3, 79, 
    3, 53, 4, 51, 5, 81, 7, 64, 1, 45, 0, 83, 2, 38, 8, 50, 6, 72, 
    7,  3, 3, 36, 8, 35, 5,  4, 6, 46, 1, 91, 4,  2, 0, 91, 2, 92, 
    1, 74, 7, 16, 4, 89, 8, 48, 2, 12, 6, 30, 0, 95, 5,  5, 3, 23, 
    2, 99, 7, 25, 8, 83, 6, 76, 5, 15, 3, 15, 0, 99, 1, 32, 4, 56, 
    0, 54, 3,  5, 7, 51, 4, 62, 8, 64, 6, 20, 5, 24, 2,  7, 1, 73, 
    2, 54, 5, 65, 4,  1, 1, 88, 6, 45, 8,  4, 7, 49, 3, 24, 0,  3
  };
  const int q9543[] = {
    9, 9, // Number of jobs and machines
    3, 22, 4, 45, 8,  1, 5, 20, 7,  4, 2, 82, 1, 24, 6, 45, 0, 10, 
    2, 94, 6, 64, 7, 26, 1,  1, 5, 39, 8, 65, 0, 48, 3, 54, 4, 68, 
    7, 50, 5,  8, 4,  7, 2, 48, 6, 17, 3, 98, 1, 58, 0, 57, 8, 41, 
    6, 60, 0, 94, 7, 29, 5, 74, 3, 83, 8, 55, 2, 82, 4, 76, 1, 52, 
    5, 51, 1, 40, 6, 27, 0, 82, 3, 43, 2, 58, 7, 25, 8, 10, 4, 29, 
    0, 57, 1, 85, 6, 65, 8, 19, 7, 61, 3, 94, 2, 64, 5, 35, 4, 27, 
    2, 35, 6, 41, 0,  9, 8, 60, 5, 66, 1, 77, 4,  8, 7, 44, 3, 78, 
    4, 77, 2, 20, 3, 97, 0, 32, 6, 44, 1, 91, 5, 88, 8, 45, 7, 83, 
    6, 69, 1, 65, 7, 80, 8, 60, 4, 59, 3, 80, 0, 53, 2, 47, 5, 41
  };
  const int q9544[] = {
    9, 9, // Number of jobs and machines
    4, 25, 8, 93, 7, 32, 2, 83, 0, 37, 3, 33, 1,  8, 6, 24, 5, 27, 
    0, 80, 5,  8, 1, 94, 7, 62, 4, 87, 8, 33, 2,  8, 3, 51, 6, 78, 
    6, 35, 1, 42, 8, 26, 7, 38, 5, 26, 2,  9, 3, 90, 0, 86, 4, 16, 
    0, 15, 6, 58, 8,  3, 2, 22, 3, 42, 7,  1, 4, 21, 1, 99, 5, 47, 
    6, 23, 1, 17, 0,  1, 3, 16, 4, 72, 5, 13, 8, 42, 7, 96, 2, 32, 
    3, 18, 4, 33, 1, 37, 7, 11, 8, 46, 0, 77, 6, 27, 5, 18, 2, 76, 
    8, 39, 5, 77, 3,  2, 7, 29, 0, 47, 4, 65, 6, 31, 1, 69, 2,  8, 
    5, 79, 4,  7, 3, 97, 7, 73, 6, 42, 0, 33, 2,  3, 8, 45, 1, 45, 
    6, 52, 5, 60, 4, 13, 0, 80, 8, 34, 7, 90, 2, 17, 1, 45, 3, 79
  };
  const int q9545[] = {
    9, 9, // Number of jobs and machines
    8, 74, 1, 35, 3, 25, 5, 85, 6,  6, 7, 44, 2, 50, 0, 26, 4, 27, 
    8, 36, 1, 77, 0, 67, 2, 98, 5,  5, 4, 95, 3, 82, 6, 21, 7, 65, 
    5, 86, 4, 39, 1, 28, 6, 37, 7, 40, 0, 85, 8, 84, 3, 91, 2,  6, 
    0, 85, 6, 52, 1, 95, 4, 62, 8, 35, 5, 69, 3, 76, 2,  2, 7, 75, 
    5, 86, 2, 75, 4, 52, 7,  4, 3, 66, 0, 15, 8, 31, 6, 12, 1, 29, 
    4, 21, 7, 61, 0, 38, 8, 30, 1, 53, 6, 27, 2,  8, 5, 37, 3,  7, 
    4, 36, 1, 65, 2, 38, 5, 94, 7, 16, 0, 12, 8, 14, 3, 16, 6, 13, 
    3, 91, 2, 37, 0, 15, 4,  9, 7, 46, 8, 61, 1, 36, 6, 91, 5, 35, 
    2, 66, 4, 46, 1, 21, 7, 14, 8, 99, 5, 53, 6, 12, 3, 11, 0, 82
  };
  const int q9546[] = {
    9, 9, // Number of jobs and machines
    4, 20, 1,  8, 7, 24, 3, 60, 5, 52, 2, 11, 6, 46, 0,  3, 8, 65, 
    4, 99, 7, 86, 2, 74, 5, 90, 1, 70, 6, 88, 8, 33, 0, 33, 3, 12, 
    7, 15, 8, 91, 2, 36, 1, 33, 3, 63, 0, 17, 6, 88, 4, 26, 5, 56, 
    7, 27, 2, 34, 4, 50, 0, 39, 3, 13, 8, 47, 1, 55, 6,  3, 5, 41, 
    1, 10, 3, 62, 4, 33, 5,  5, 7, 78, 0, 51, 8, 90, 6, 32, 2, 20, 
    4, 13, 0,  6, 5, 35, 1, 67, 8, 64, 7,  5, 3, 85, 6, 14, 2, 95, 
    0, 70, 4, 91, 3, 10, 7, 17, 1, 82, 2,  3, 6, 96, 5, 80, 8, 89, 
    1, 62, 3, 58, 5, 10, 8, 22, 2, 67, 7, 77, 0,  8, 6, 39, 4, 62, 
    1, 15, 7, 26, 6, 59, 8, 76, 4, 76, 2, 89, 0, 38, 5, 74, 3, 29
  };
  const int q9547[] = {
    9, 9, // Number of jobs and machines
    6, 73, 4, 55, 1, 15, 2, 97, 3, 22, 7, 92, 5, 56, 0, 91, 8, 30, 
    1, 40, 4, 55, 3, 39, 8, 99, 5, 89, 6, 60, 2, 18, 0, 22, 7, 96, 
    7, 47, 4, 41, 0, 94, 5, 81, 6, 50, 2,  5, 1, 89, 8, 74, 3, 49, 
    8, 69, 1, 80, 6, 89, 3, 57, 2, 28, 4, 28, 5, 97, 7, 28, 0, 82, 
    6, 41, 2, 38, 5,  6, 4, 84, 1, 16, 3, 68, 7, 16, 8, 43, 0, 63, 
    1, 82, 5, 69, 8, 61, 2, 93, 4, 34, 7, 78, 0, 61, 6, 27, 3, 87, 
    1, 71, 5, 71, 4, 95, 3, 69, 2, 30, 7, 63, 0, 72, 8, 46, 6, 58, 
    7,  3, 3, 73, 0, 49, 5,  6, 2, 11, 6, 76, 4, 38, 8, 68, 1, 59, 
    5, 37, 2, 40, 3, 96, 8, 89, 7, 83, 4, 99, 0, 66, 1, 47, 6, 23
  };
  const int q9548[] = {
    9, 9, // Number of jobs and machines
    6, 95, 5, 33, 7, 96, 8, 56, 2, 70, 3, 12, 1, 33, 0, 67, 4, 15, 
    4, 62, 1, 86, 0, 18, 3, 51, 6,  1, 7, 50, 8, 39, 5, 93, 2, 99, 
    0, 77, 1, 40, 7, 34, 2, 84, 5, 83, 6, 48, 3, 65, 8, 89, 4, 91, 
    4,  8, 1, 77, 3, 25, 2, 70, 7, 19, 5, 47, 6, 27, 8, 40, 0, 46, 
    3, 18, 6, 36, 1, 60, 5, 93, 7, 68, 2, 67, 0, 61, 4, 20, 8, 20, 
    4, 43, 3, 48, 7, 85, 2, 79, 8, 10, 1, 98, 6, 48, 0, 33, 5, 68, 
    5, 54, 3, 62, 7, 58, 6, 22, 8, 54, 0, 56, 1, 94, 2, 70, 4, 76, 
    5, 50, 4, 45, 0, 44, 6, 84, 2, 56, 1, 93, 7, 32, 3, 71, 8, 55, 
    2, 73, 1, 88, 5, 69, 6, 86, 8, 16, 0, 43, 4, 64, 7, 23, 3, 61
  };
  const int q9549[] = {
    9, 9, // Number of jobs and machines
    2, 80, 1, 44, 7, 69, 5, 42, 0, 38, 4, 40, 6, 95, 3, 47, 8, 10, 
    7, 76, 0, 94, 8, 10, 4, 87, 5, 21, 1, 75, 3, 91, 6, 21, 2, 26, 
    2, 93, 8,  6, 4, 52, 5,  5, 3, 54, 0, 61, 1, 29, 6, 18, 7, 35, 
    2, 99, 1,  6, 8, 92, 6, 94, 7, 19, 5, 95, 4, 30, 3, 47, 0, 61, 
    5, 13, 0, 18, 7,  2, 8, 92, 2, 33, 4, 50, 1,  2, 3, 15, 6, 74, 
    0, 85, 8, 30, 4, 75, 1, 83, 6, 84, 2, 70, 3, 48, 5, 71, 7, 40, 
    7, 46, 2, 91, 1, 87, 8, 47, 4, 92, 6, 59, 5, 40, 3, 52, 0,  5, 
    6, 37, 5, 87, 1, 87, 8, 26, 7, 10, 3,  5, 0, 75, 2, 80, 4, 92, 
    3, 99, 4, 92, 2, 72, 7, 51, 8, 38, 6, 70, 0, 57, 1, 30, 5, 72
  };
  const int q9550[] = {
    9, 9, // Number of jobs and machines
    0, 47, 1, 79, 6, 73, 4, 40, 2, 67, 8, 24, 5,  1, 3, 63, 7, 27, 
    8, 23, 1, 53, 5, 36, 4, 14, 6, 84, 2, 75, 7,  6, 0, 74, 3, 26, 
    2, 91, 1, 99, 0, 73, 5, 88, 7, 11, 4, 51, 8, 41, 6, 53, 3, 45, 
    2, 47, 8, 38, 1, 35, 0, 22, 3, 23, 5, 54, 4, 53, 6, 25, 7,  4, 
    6, 54, 1, 14, 0, 83, 4, 57, 3, 44, 7, 32, 5, 21, 2, 14, 8, 17, 
    5, 10, 7, 86, 8, 28, 4, 19, 0, 34, 2, 70, 6, 62, 3,  8, 1, 51, 
    5, 31, 7, 52, 4,  3, 8, 90, 6, 70, 1, 15, 2, 31, 0, 65, 3, 29, 
    1, 22, 3, 76, 6, 61, 2, 93, 0, 69, 5, 88, 8, 87, 7, 89, 4, 98, 
    6, 91, 5, 28, 3, 16, 2,  7, 1, 14, 7,  7, 0, 49, 4, 90, 8, 69
  };
  const int q9551[] = {
    9, 9, // Number of jobs and machines
    4, 52, 1, 60, 7, 26, 5,  4, 3, 32, 2, 35, 6, 83, 8, 73, 0, 76, 
    1,  2, 3, 40, 2, 80, 6, 56, 7, 72, 4, 26, 0, 86, 8, 72, 5,  1, 
    8, 97, 6, 78, 1, 67, 4, 31, 3, 14, 7, 68, 0, 57, 2, 72, 5,  3, 
    1, 36, 0, 23, 4, 51, 6, 95, 3, 53, 2, 89, 5,  7, 8, 55, 7,  8, 
    1, 38, 3, 10, 5, 67, 4, 21, 8, 51, 6, 14, 0, 92, 2,  9, 7, 65, 
    4, 63, 7, 75, 6, 57, 2, 16, 5, 88, 3, 57, 8, 19, 1, 29, 0, 21, 
    5, 66, 8, 13, 0,  6, 6, 82, 3, 44, 1, 62, 2, 78, 7, 26, 4, 97, 
    8, 79, 0, 87, 4, 36, 2, 67, 5,  3, 6, 96, 1, 36, 7, 78, 3, 31, 
    6, 30, 5,  8, 2, 36, 3, 95, 0, 65, 1, 94, 7,  3, 4, 60, 8, 82
  };
  const int q9552[] = {
    9, 9, // Number of jobs and machines
    0, 34, 7, 85, 5, 86, 8, 35, 1, 97, 2, 60, 4, 98, 6, 26, 3, 36, 
    4, 61, 0, 21, 6, 67, 7, 11, 3, 24, 5, 79, 1, 62, 2, 69, 8, 68, 
    2, 69, 1, 98, 0, 67, 6, 31, 5, 34, 8, 88, 7, 19, 4, 28, 3, 40, 
    1, 55, 8, 52, 5, 81, 3, 70, 4, 69, 0, 25, 6, 91, 2, 14, 7, 85, 
    2, 79, 7,  1, 4, 50, 1, 24, 0,  5, 3, 65, 6,  3, 5, 46, 8, 57, 
    3, 67, 8, 10, 4, 82, 6, 44, 5, 25, 7, 92, 1, 23, 0, 32, 2, 24, 
    0, 95, 3, 62, 5, 19, 7, 55, 8, 36, 6, 15, 2, 93, 1, 52, 4, 83, 
    6, 32, 8, 95, 3, 21, 0,  4, 2,  1, 1, 81, 4, 80, 7, 47, 5, 36, 
    0, 67, 6, 61, 8, 49, 1, 96, 4, 74, 3, 24, 7, 63, 5, 16, 2, 42
  };
  const int q9553[] = {
    9, 9, // Number of jobs and machines
    6, 64, 7, 79, 0, 41, 1, 13, 3, 38, 4, 57, 8, 98, 5, 36, 2, 75, 
    2, 72, 4, 75, 6, 43, 3, 56, 0,  3, 7, 28, 5, 75, 1, 25, 8,  5, 
    5, 73, 7, 76, 6, 80, 8, 85, 2, 35, 4, 31, 1, 60, 0, 41, 3, 85, 
    3, 38, 2, 23, 8,  1, 1, 90, 7, 19, 4, 62, 0, 94, 5, 37, 6, 58, 
    6, 99, 2, 34, 5, 23, 8,  5, 4, 46, 7, 82, 3, 65, 1, 17, 0, 59, 
    3, 48, 5, 33, 1, 34, 2, 94, 6, 32, 0, 20, 8, 28, 4, 59, 7, 54, 
    6, 23, 8,  9, 1, 21, 7, 93, 2,  7, 5, 24, 3,  9, 0, 97, 4, 25, 
    2, 36, 0, 97, 3, 73, 8, 18, 4,  6, 7, 32, 5, 26, 1,  9, 6, 97, 
    8, 40, 0, 49, 5, 77, 1, 77, 7, 21, 2, 86, 6, 98, 3, 98, 4, 75
  };
  const int q9554[] = {
    9, 9, // Number of jobs and machines
    2, 84, 0,  8, 8, 23, 4, 53, 1, 33, 3, 25, 7, 39, 6, 35, 5, 98, 
    3, 98, 4, 88, 1, 80, 2, 39, 6, 91, 0, 66, 7, 84, 8, 70, 5, 85, 
    8, 56, 1, 83, 7, 98, 5, 52, 4, 68, 3,  6, 0, 27, 2,  9, 6, 49, 
    7, 69, 3, 96, 4, 10, 8, 59, 1,  7, 5, 68, 2, 29, 0,  8, 6, 20, 
    7,  8, 6,  8, 5, 90, 2, 37, 1, 52, 0, 82, 8, 61, 4, 86, 3, 61, 
    8, 62, 5, 98, 7, 72, 6, 17, 3, 41, 1, 68, 4, 30, 2, 70, 0,  9, 
    1, 32, 4, 26, 7, 64, 6, 16, 2,  3, 3, 36, 0, 16, 8, 36, 5, 27, 
    5, 66, 0, 14, 2, 36, 1, 77, 4, 55, 7, 56, 3,  1, 6, 31, 8, 31, 
    8, 65, 4, 85, 5, 15, 2, 18, 1, 81, 7,  3, 6, 38, 0, 27, 3, 39
  };
  const int q9555[] = {
    9, 9, // Number of jobs and machines
    0, 99, 8, 33, 2, 57, 7, 73, 1, 86, 5,  3, 3, 82, 6, 50, 4, 38, 
    5,  2, 3, 81, 4, 30, 7, 59, 1, 21, 6, 93, 2, 12, 0,  3, 8, 42, 
    1, 80, 4, 12, 8, 24, 0, 15, 6, 97, 5, 45, 2, 47, 7, 68, 3,  9, 
    6, 23, 1,  7, 3, 15, 7, 10, 4, 82, 8, 24, 5,  8, 2, 26, 0, 45, 
    7,  1, 4, 24, 1, 13, 3, 93, 5, 67, 6,  1, 0, 60, 8, 64, 2, 33, 
    3, 65, 7, 78, 0, 83, 1, 22, 8, 39, 5, 65, 6, 72, 2, 31, 4, 64, 
    5, 27, 6, 60, 7, 66, 8, 29, 1, 27, 3,  1, 4,  9, 0, 77, 2, 26, 
    4, 94, 3, 54, 7, 49, 8, 11, 2,  2, 1, 14, 0,  3, 6, 85, 5, 81, 
    1, 45, 0, 22, 5, 20, 6, 88, 4, 37, 2,  8, 7, 70, 8, 30, 3, 65
  };
  const int q9556[] = {
    9, 9, // Number of jobs and machines
    5,  8, 4, 50, 8, 28, 2, 92, 3, 66, 7, 51, 6, 95, 0, 97, 1, 75, 
    5, 30, 4, 19, 0, 32, 6, 15, 8, 59, 1, 75, 2, 39, 7, 10, 3, 68, 
    7, 42, 1,  1, 6, 18, 8, 86, 5, 41, 2, 36, 0, 49, 4, 21, 3, 77, 
    8, 88, 2, 80, 3, 27, 4, 19, 1, 49, 0, 83, 5, 66, 7, 26, 6, 37, 
    8, 66, 1, 27, 5, 10, 0, 24, 6, 21, 4, 70, 3, 83, 2, 70, 7,  5, 
    0, 96, 7, 38, 6, 91, 4,  4, 8, 46, 5, 79, 1, 62, 2, 90, 3, 86, 
    1, 65, 6, 33, 7, 75, 5, 17, 3, 27, 4, 32, 2, 82, 0, 30, 8, 28, 
    0, 53, 5, 68, 4, 36, 6, 43, 2, 73, 3, 26, 1, 67, 8, 80, 7, 82, 
    1, 15, 3, 83, 5, 16, 8, 33, 6, 51, 4, 92, 0, 75, 7, 92, 2, 21
  };
  const int q9557[] = {
    9, 9, // Number of jobs and machines
    0, 81, 8, 11, 4, 17, 2, 11, 1, 86, 5, 80, 7, 35, 6, 10, 3, 22, 
    5, 48, 7, 62, 8, 72, 3,  9, 2, 80, 4, 87, 0,  8, 1, 46, 6, 72, 
    8, 46, 3, 73, 5,  5, 4, 92, 1,  6, 2, 51, 7, 12, 0,  9, 6, 73, 
    2, 31, 5, 11, 4, 63, 1, 39, 8, 56, 6, 10, 7, 14, 3, 68, 0, 65, 
    1, 89, 8, 86, 0, 67, 3, 46, 2, 94, 7,  5, 4, 97, 5, 33, 6, 45, 
    6, 24, 5, 55, 4, 64, 3, 73, 1, 20, 2, 88, 7, 73, 8, 97, 0, 43, 
    8, 89, 6, 59, 7, 10, 3, 88, 2, 28, 1, 24, 0, 81, 5, 12, 4, 58, 
    0, 50, 3, 80, 1, 11, 8, 41, 2, 18, 6,  4, 5, 46, 7, 98, 4, 98, 
    8, 89, 6, 12, 4, 57, 7, 16, 5, 50, 3, 11, 1, 54, 0, 58, 2, 82
  };
  const int q9558[] = {
    9, 9, // Number of jobs and machines
    3, 54, 8, 64, 1, 59, 2, 35, 7, 27, 6, 29, 4, 74, 5, 26, 0, 84, 
    5, 92, 0, 45, 1, 50, 2, 92, 4, 90, 6, 32, 7, 49, 8, 80, 3, 79, 
    1, 90, 7, 10, 3, 71, 0, 23, 4, 54, 8, 51, 6, 18, 5, 62, 2,  4, 
    5, 42, 3, 63, 6, 11, 2, 71, 4, 40, 7,  7, 8, 97, 0, 53, 1, 99, 
    6, 92, 3, 29, 8, 78, 7, 40, 4, 21, 5, 24, 1, 77, 2, 75, 0, 53, 
    4, 60, 5, 56, 1, 65, 6,  4, 2, 71, 0, 96, 8,  2, 3, 45, 7, 12, 
    8, 30, 6, 23, 5, 54, 0, 81, 3, 37, 1,  5, 7,  8, 2, 21, 4, 64, 
    6, 43, 1, 50, 4,  3, 3, 72, 7, 43, 8, 66, 0, 19, 2, 46, 5, 57, 
    0, 33, 5, 94, 2, 23, 7, 89, 4, 34, 3, 13, 1, 99, 6, 69, 8, 42
  };
  const int q9559[] = {
    9, 9, // Number of jobs and machines
    6,  1, 1, 87, 5, 99, 7, 43, 2,  3, 4,  3, 3, 72, 0,  5, 8, 22, 
    8, 34, 1, 74, 7, 98, 2, 24, 3, 96, 6, 13, 0, 21, 4, 76, 5, 17, 
    3, 22, 5, 92, 2, 83, 4, 78, 1, 80, 6, 97, 0, 35, 8, 61, 7, 69, 
    1, 66, 2, 10, 7, 14, 8, 58, 4, 22, 3, 44, 0, 72, 6, 32, 5, 36, 
    0, 15, 2, 64, 5, 96, 8, 79, 4, 39, 1,  1, 6, 10, 7, 55, 3, 51, 
    0, 45, 5, 35, 4, 61, 8, 48, 6, 41, 2, 12, 3, 56, 7, 90, 1,  2, 
    5,  5, 3, 85, 0, 11, 4, 54, 1, 88, 7, 75, 6, 84, 8, 46, 2, 18, 
    1, 96, 3, 29, 7, 67, 6, 80, 2, 68, 5, 79, 8, 33, 0, 96, 4, 21, 
    1, 28, 5, 69, 2,  5, 6, 59, 7, 26, 4, 62, 3, 93, 8, 70, 0, 46
  };
  const int q9560[] = {
    9, 9, // Number of jobs and machines
    0, 24, 5, 13, 2, 76, 6, 61, 3, 64, 8, 63, 7, 51, 1, 89, 4, 83, 
    8, 18, 5, 32, 7,  8, 1, 26, 2, 56, 4, 24, 3, 50, 0,  8, 6, 99, 
    5, 36, 2,  7, 1, 54, 7,  6, 0, 70, 3, 62, 6, 46, 4,  2, 8, 49, 
    4, 18, 6, 20, 0, 79, 8, 36, 3, 29, 1, 19, 2, 21, 5, 36, 7, 73, 
    3, 23, 7, 28, 6, 26, 0, 44, 5, 89, 4, 44, 2, 71, 8,  5, 1, 70, 
    8, 77, 5, 32, 4, 73, 2, 39, 0, 41, 3, 82, 7, 93, 1, 90, 6, 29, 
    4, 83, 6, 67, 5, 37, 1, 90, 0, 72, 2, 74, 3, 52, 7,  5, 8, 99, 
    6, 76, 2,  5, 0, 44, 7, 84, 1, 62, 8, 92, 5,  7, 3, 77, 4, 71, 
    1, 35, 5, 40, 2, 67, 7, 49, 8, 89, 3,  1, 6, 87, 0, 13, 4, 94
  };
  const int q9561[] = {
    9, 9, // Number of jobs and machines
    1, 91, 7, 58, 4, 69, 5, 48, 6, 67, 3, 69, 2, 52, 0, 35, 8, 70, 
    3, 40, 5, 78, 0, 44, 4, 66, 6, 24, 1, 57, 2,  2, 8, 70, 7, 48, 
    0, 39, 4, 47, 8, 66, 1, 16, 3, 47, 5, 54, 6, 62, 7, 44, 2, 32, 
    2, 28, 4, 36, 8, 91, 1, 96, 6, 17, 7, 43, 0, 46, 3, 11, 5, 16, 
    4, 27, 6, 52, 1, 62, 2, 18, 0, 15, 8, 84, 7, 56, 3, 44, 5,  8, 
    7, 93, 1, 93, 5, 80, 2, 77, 6, 22, 8, 17, 3, 66, 4, 71, 0, 19, 
    4, 91, 2,  2, 5, 16, 0, 25, 3,  7, 1,  9, 7, 53, 8, 19, 6, 61, 
    4, 39, 5, 98, 8, 65, 0, 10, 3, 26, 1, 43, 7, 97, 6, 89, 2, 74, 
    5, 71, 3, 79, 4, 37, 1,  2, 2, 61, 6, 30, 8, 87, 7, 30, 0, 10
  };
  const int q9562[] = {
    9, 9, // Number of jobs and machines
    1, 13, 3,  2, 4,  1, 5, 73, 0, 22, 8, 37, 7, 27, 6, 66, 2, 21, 
    8, 55, 6, 13, 4, 16, 1, 66, 5,  8, 2, 64, 0, 57, 3, 98, 7, 78, 
    3, 70, 2, 38, 1, 65, 5, 49, 0, 50, 7, 79, 6, 26, 4, 54, 8, 30, 
    0, 21, 5, 53, 7, 92, 1, 93, 3, 92, 4, 87, 6, 82, 8, 61, 2, 95, 
    7, 68, 3, 86, 1, 19, 5, 12, 0, 63, 4, 20, 6, 19, 8, 93, 2, 25, 
    3, 72, 8, 31, 1, 44, 2, 12, 6,  3, 5, 99, 7, 41, 4, 32, 0, 44, 
    0, 32, 1, 80, 6, 89, 2, 89, 3, 49, 4, 49, 5, 49, 7, 62, 8,  4, 
    2, 26, 4, 87, 0, 41, 8, 67, 6, 66, 7, 48, 1, 30, 5,  5, 3, 46, 
    6, 67, 1, 58, 8,  5, 5, 80, 3, 73, 7,  9, 2, 84, 4, 10, 0, 37
  };
  const int q9563[] = {
    9, 9, // Number of jobs and machines
    1, 47, 2, 99, 3, 52, 0, 47, 5, 41, 7, 26, 4, 55, 6, 34, 8, 84, 
    1, 69, 6, 60, 5, 68, 0, 17, 3, 40, 7, 84, 2, 93, 4, 64, 8, 16, 
    0, 11, 8, 98, 5, 54, 2, 28, 6, 23, 4, 77, 3, 81, 7,  1, 1, 65, 
    6, 88, 3, 33, 2, 87, 4, 29, 0, 70, 5, 27, 8, 68, 1, 18, 7, 28, 
    4, 80, 5, 81, 1, 35, 6, 48, 0, 38, 7, 41, 2, 16, 3, 24, 8, 63, 
    1, 92, 4, 20, 8, 81, 2, 78, 7,  6, 5, 46, 3, 29, 0, 45, 6, 68, 
    5, 82, 1, 33, 6, 43, 0, 71, 3, 92, 8, 50, 2, 71, 7, 27, 4, 36, 
    3, 42, 0, 96, 1,  7, 2,  3, 5, 41, 8, 53, 6, 20, 7,  4, 4, 92, 
    1, 43, 7,  6, 8, 66, 4, 91, 6, 40, 2, 38, 0, 59, 3, 68, 5, 27
  };
  const int q9564[] = {
    9, 9, // Number of jobs and machines
    0,  4, 5, 25, 2, 55, 3, 15, 7, 35, 1, 28, 6, 93, 4, 51, 8, 93, 
    2, 98, 5, 26, 4, 90, 0, 58, 3, 30, 1, 95, 7, 29, 8, 70, 6, 47, 
    8, 20, 5, 71, 7, 51, 6,  8, 2, 28, 0, 75, 3, 42, 1, 94, 4,  8, 
    1, 60, 5, 89, 6, 51, 0, 63, 4, 96, 2,  8, 8, 22, 3, 74, 7, 45, 
    3, 82, 1, 40, 7, 24, 8, 43, 4,  5, 0, 53, 6, 80, 5, 37, 2, 57, 
    2, 69, 4, 47, 1, 53, 6, 21, 8, 40, 0, 35, 5, 65, 3, 77, 7, 15, 
    4, 64, 7, 54, 8, 49, 1, 94, 0, 65, 5, 21, 6, 19, 2, 43, 3, 85, 
    2,  5, 5, 62, 7, 52, 8, 81, 6, 13, 1, 12, 4, 80, 3, 41, 0, 60, 
    0, 84, 8, 46, 5, 58, 1, 74, 6, 26, 7, 46, 2, 38, 3,  6, 4, 30
  };
  const int q9565[] = {
    9, 9, // Number of jobs and machines
    0, 82, 6, 87, 4, 35, 3, 79, 5, 40, 1, 92, 8,  5, 2, 47, 7, 60, 
    7, 30, 1, 51, 6, 94, 0, 63, 5, 91, 2, 18, 4, 48, 8, 42, 3, 13, 
    5, 65, 2, 55, 7, 25, 6, 41, 1, 30, 3, 82, 8, 63, 0, 35, 4, 32, 
    0, 63, 2, 14, 1, 24, 7, 69, 3, 34, 5, 64, 4, 21, 8, 42, 6, 46, 
    5, 13, 6, 15, 0, 57, 1, 68, 4, 19, 3, 91, 8, 98, 7, 40, 2, 84, 
    7, 87, 2, 79, 8, 26, 5, 78, 3, 61, 0, 49, 4, 45, 6, 48, 1, 80, 
    0, 25, 4, 65, 1,  5, 6, 61, 2, 70, 5, 34, 3, 53, 7, 38, 8, 20, 
    7, 32, 1, 45, 2,  4, 8, 47, 4, 42, 3, 85, 6,  3, 0, 16, 5, 70, 
    2, 69, 6, 64, 3, 38, 4, 70, 0, 77, 7, 85, 5, 37, 8, 54, 1, 28
  };
  const int q9566[] = {
    9, 9, // Number of jobs and machines
    0, 70, 8, 41, 5, 40, 2, 91, 3, 58, 1, 17, 6, 60, 4,  3, 7, 91, 
    2, 41, 7, 46, 8, 30, 1, 72, 5, 49, 6, 74, 3,  9, 0, 82, 4, 19, 
    7, 65, 3, 77, 0, 84, 4, 91, 2, 63, 8, 18, 6, 12, 5,  3, 1, 53, 
    0, 49, 2, 63, 3, 51, 5, 99, 1, 38, 6, 47, 4, 27, 8, 24, 7, 90, 
    4, 58, 8, 79, 3, 20, 5, 97, 2, 55, 1, 20, 7, 13, 6, 27, 0, 66, 
    4, 42, 7, 22, 3, 49, 8, 15, 1, 32, 0, 10, 6, 77, 5, 14, 2, 31, 
    7, 33, 8, 85, 5, 94, 4, 36, 3, 63, 0, 75, 6, 82, 1, 54, 2, 19, 
    8, 95, 3,  1, 1, 53, 4, 13, 6, 10, 2, 76, 5, 12, 0, 59, 7, 21, 
    5, 22, 7, 91, 8, 68, 6, 74, 1, 96, 3, 16, 2, 56, 4, 24, 0, 99
  };
  const int q9567[] = {
    9, 9, // Number of jobs and machines
    2, 93, 5, 34, 1, 74, 7, 72, 0, 38, 3, 86, 8, 27, 4, 86, 6, 50, 
    3, 68, 2, 43, 5, 87, 0, 74, 7, 34, 8, 42, 4, 73, 1,  2, 6, 72, 
    8, 35, 7, 22, 1, 37, 4,  3, 0,  3, 5, 53, 2,  6, 3, 55, 6, 34, 
    6, 79, 4,  9, 2, 91, 3, 61, 8,  6, 0, 51, 5, 32, 7, 35, 1, 13, 
    1, 60, 8, 29, 6, 22, 4, 78, 7, 20, 0, 56, 2, 36, 5, 25, 3, 95, 
    6, 91, 1, 38, 3, 65, 4, 71, 7, 66, 5, 79, 8, 55, 0, 49, 2,  1, 
    8, 95, 5, 43, 1, 58, 3, 78, 2, 56, 0, 89, 4, 49, 7, 23, 6, 92, 
    3, 93, 0, 11, 4, 91, 5, 45, 1, 77, 7, 20, 8, 46, 6, 78, 2, 30, 
    3, 87, 6, 10, 4, 52, 1, 58, 0, 59, 8, 59, 7, 97, 2, 64, 5, 72
  };
  const int q9568[] = {
    9, 9, // Number of jobs and machines
    4, 43, 0,  3, 3, 93, 5, 71, 8, 27, 2, 97, 6, 74, 7, 72, 1, 92, 
    3, 56, 1,  2, 0, 68, 7, 78, 8, 11, 5, 93, 2, 82, 4, 49, 6, 40, 
    3, 58, 5, 38, 4, 98, 7, 59, 0, 61, 1, 43, 2, 76, 8,  5, 6, 90, 
    1, 74, 4, 76, 3, 39, 6, 18, 0, 88, 7, 62, 2, 42, 8, 58, 5, 25, 
    4, 27, 3, 64, 6, 79, 0, 60, 8, 73, 5, 50, 7, 30, 2, 17, 1,  9, 
    8, 80, 1, 82, 6, 85, 2, 57, 7, 13, 0, 70, 4, 16, 3, 16, 5, 33, 
    0, 34, 5, 80, 8, 85, 2, 29, 7, 93, 3, 63, 4, 53, 1, 10, 6, 19, 
    8, 55, 1, 63, 6, 98, 5, 47, 4, 71, 0, 10, 7, 32, 2, 78, 3, 55, 
    8, 52, 3, 84, 4, 94, 1, 17, 5, 99, 0, 85, 6, 56, 7, 64, 2, 56
  };
  const int q9569[] = {
    9, 9, // Number of jobs and machines
    0, 21, 2, 96, 7, 53, 3, 34, 1, 60, 6, 87, 4, 62, 5, 76, 8, 68, 
    8, 70, 4, 56, 6, 68, 3, 79, 7, 84, 2,  4, 0, 34, 1,  1, 5, 26, 
    5, 78, 6, 32, 0, 34, 4, 64, 7, 52, 8, 81, 1,  4, 3, 80, 2, 55, 
    8, 85, 4, 42, 0, 76, 3, 51, 7, 79, 2, 38, 5, 50, 1, 77, 6, 72, 
    6, 92, 3, 17, 7, 52, 4, 18, 0, 26, 1, 65, 5, 58, 8, 43, 2, 21, 
    7, 74, 6, 41, 0, 62, 5, 45, 8, 35, 3, 57, 1, 55, 2, 52, 4, 42, 
    1, 59, 0, 49, 3, 16, 7, 88, 4, 88, 2, 50, 5, 78, 6, 13, 8, 99, 
    7, 29, 8,  7, 2, 24, 4, 76, 3, 63, 0, 53, 6, 31, 5, 20, 1, 61, 
    2, 24, 8, 88, 4, 31, 6, 42, 5, 74, 3, 60, 0,  1, 1, 54, 7, 11
  };
  const int q9570[] = {
    9, 9, // Number of jobs and machines
    6, 29, 0, 86, 7, 63, 2,  5, 5, 84, 3, 41, 1, 97, 8, 62, 4, 54, 
    8,  8, 7, 97, 3, 70, 0, 42, 6, 74, 5, 55, 1, 82, 4, 64, 2, 18, 
    6, 41, 3, 38, 4, 44, 0,  9, 1,  9, 7, 21, 5, 27, 2,  5, 8, 35, 
    0, 11, 8, 56, 6, 71, 4, 38, 7, 68, 2, 55, 5, 30, 1, 92, 3, 74, 
    1, 90, 6, 10, 2, 59, 4, 62, 5, 57, 7, 40, 8, 19, 3, 34, 0, 81, 
    0, 34, 8, 39, 3, 75, 2, 88, 6, 55, 5, 60, 1,  1, 4, 68, 7, 96, 
    0, 96, 5, 23, 2, 94, 1, 75, 8, 34, 7, 32, 3,  4, 4, 80, 6, 76, 
    0,  4, 5, 65, 7, 89, 4, 68, 6, 62, 3, 55, 2, 91, 1, 77, 8, 38, 
    4, 82, 1, 71, 3, 40, 2, 51, 8, 76, 7, 29, 5, 83, 0, 86, 6, 32
  };
  const int q9571[] = {
    9, 9, // Number of jobs and machines
    2, 17, 1, 62, 3,  5, 4, 96, 7, 86, 0, 55, 5, 86, 6, 20, 8,  9, 
    1, 36, 2, 70, 8, 99, 0, 94, 3, 43, 5, 73, 7, 39, 6, 98, 4, 23, 
    3,  6, 7, 81, 0, 27, 4,  6, 8, 99, 6, 69, 5, 12, 1, 10, 2, 60, 
    4, 41, 6, 25, 3, 21, 5, 73, 8, 77, 0, 43, 1, 34, 7, 80, 2, 24, 
    6, 83, 5, 56, 2, 71, 4, 16, 1, 10, 7, 88, 0,  8, 8, 70, 3, 70, 
    1, 71, 0, 84, 6,  1, 4, 91, 8, 47, 3, 24, 2, 20, 7, 38, 5, 24, 
    1, 30, 4,  5, 8, 78, 0, 82, 6, 99, 7, 37, 5, 71, 3, 90, 2, 18, 
    1, 70, 3, 95, 6, 94, 7, 19, 8, 40, 4, 64, 2, 80, 5, 37, 0,  3, 
    3, 73, 0,  8, 8, 90, 1, 61, 6, 27, 4, 21, 5, 96, 2, 26, 7,  7
  };
  const int q9572[] = {
    9, 9, // Number of jobs and machines
    5, 19, 2, 73, 3, 38, 8, 53, 6, 99, 7, 66, 4,  9, 1, 10, 0, 96, 
    4, 52, 3, 93, 5, 15, 0, 65, 8, 50, 1, 64, 7, 97, 2, 19, 6, 32, 
    0, 10, 6, 23, 8, 14, 3, 39, 2, 96, 1, 33, 5, 49, 7, 55, 4, 79, 
    7, 88, 2, 50, 0, 37, 6, 49, 5, 30, 4, 77, 8, 55, 1,  2, 3, 52, 
    1, 64, 5,  2, 4, 24, 2, 84, 8, 84, 0, 37, 7, 23, 3, 94, 6, 42, 
    2,  9, 8, 59, 4, 37, 7, 95, 6, 78, 3,  5, 5, 20, 1, 99, 0, 89, 
    4, 78, 5, 55, 7, 56, 1, 33, 3,  6, 6, 31, 8, 25, 2, 83, 0, 47, 
    4, 82, 2,  2, 7, 36, 8, 10, 3, 53, 6,  7, 5, 23, 1, 64, 0, 21, 
    7, 99, 1, 58, 6, 49, 8, 90, 3, 70, 4, 20, 5, 76, 2, 10, 0, 13
  };
  const int q9573[] = {
    9, 9, // Number of jobs and machines
    4, 22, 6, 59, 2, 14, 0, 61, 8, 58, 7, 24, 1, 79, 5, 42, 3, 64, 
    4, 15, 1, 31, 2, 81, 0, 49, 8, 26, 7, 84, 5, 25, 6,  1, 3, 77, 
    2, 13, 0, 16, 4, 98, 8, 41, 7,  5, 3, 36, 6, 70, 5, 83, 1, 79, 
    2, 94, 7, 37, 8, 52, 5, 87, 0, 34, 3, 66, 1, 71, 6, 53, 4, 29, 
    6, 33, 0, 55, 7, 77, 4, 75, 8, 75, 5, 89, 1, 97, 3, 59, 2, 17, 
    6, 69, 4, 80, 5, 24, 0, 31, 2,  8, 1, 40, 3, 67, 8, 17, 7, 39, 
    3, 69, 1, 33, 0, 12, 6, 72, 5, 80, 4, 38, 7, 14, 2, 79, 8, 55, 
    0,  2, 4, 66, 3,  3, 5,  9, 1, 46, 7, 72, 2, 47, 8, 58, 6, 24, 
    6, 92, 7, 62, 3,  5, 4, 71, 0, 62, 1, 90, 8,  7, 2, 16, 5, 31
  };
  const int q9574[] = {
    9, 9, // Number of jobs and machines
    7,  3, 2, 58, 1, 20, 0,  7, 4, 93, 5, 29, 3, 18, 8, 87, 6, 71, 
    3, 58, 6,  7, 8, 89, 0, 60, 2, 53, 4, 96, 7, 15, 5, 27, 1, 97, 
    8, 32, 4, 17, 7, 93, 1,  2, 0, 29, 2, 66, 3, 60, 6, 52, 5, 81, 
    0,  9, 6, 56, 3,  9, 2,  5, 4, 67, 5, 33, 7, 13, 8, 90, 1, 98, 
    6, 43, 7, 74, 1, 47, 4, 98, 0, 36, 8,  8, 5, 92, 3, 95, 2, 80, 
    8, 47, 1,  2, 4, 66, 7, 46, 0, 11, 5, 42, 6,  5, 2, 36, 3, 78, 
    5, 40, 4,  2, 3, 46, 0, 43, 7, 37, 8, 50, 6, 12, 1, 68, 2, 26, 
    8, 15, 7, 54, 4, 10, 2,  5, 0, 30, 5, 48, 3, 22, 1, 13, 6, 92, 
    7, 27, 2, 11, 6,  5, 0, 18, 5, 37, 1, 98, 3, 66, 4, 69, 8,  2
  };
  const int q9575[] = {
    9, 9, // Number of jobs and machines
    4, 11, 0, 57, 8, 39, 2, 49, 7,  9, 1, 23, 3, 47, 5, 56, 6, 47, 
    4, 29, 8, 84, 1, 23, 5, 82, 3, 22, 0,  2, 6, 27, 7, 29, 2, 25, 
    2, 57, 6, 16, 1, 69, 7, 88, 4, 90, 5, 29, 3, 90, 8, 36, 0, 91, 
    1, 50, 7, 92, 8, 24, 3,  6, 5, 37, 4, 34, 6,  2, 2, 77, 0, 95, 
    2, 79, 8, 75, 1, 99, 0,  4, 5, 25, 3, 66, 7, 28, 4, 29, 6, 22, 
    4, 31, 7, 47, 6, 37, 8, 77, 2, 18, 3, 15, 0, 97, 5, 18, 1, 36, 
    7, 29, 2, 21, 8, 81, 5, 33, 4,  8, 3, 24, 6, 79, 1, 30, 0, 36, 
    7, 30, 5, 84, 3, 61, 8, 10, 6, 78, 1, 42, 0, 33, 2, 34, 4, 13, 
    8, 31, 2, 86, 7, 13, 5, 10, 3, 29, 4, 19, 1, 73, 6,  4, 0, 63
  };
  const int q9576[] = {
    9, 9, // Number of jobs and machines
    6, 37, 8, 39, 5,  7, 1, 32, 4, 32, 2, 15, 3, 25, 7, 74, 0, 27, 
    8, 93, 3, 74, 7, 36, 2, 80, 1, 56, 0, 85, 4, 80, 5, 37, 6,  9, 
    4, 13, 7, 89, 8, 82, 0, 59, 2, 82, 5, 77, 1, 28, 6, 96, 3, 34, 
    2, 85, 8,  9, 4, 27, 5, 33, 0, 33, 6, 92, 7,  2, 3, 80, 1, 25, 
    2, 15, 1, 90, 6, 55, 5, 65, 8, 60, 4, 60, 0,  5, 7, 87, 3, 39, 
    0, 99, 3, 51, 8, 39, 1, 66, 2, 21, 7, 67, 6, 66, 5, 63, 4, 81, 
    7, 95, 2,  9, 0, 34, 4, 98, 8, 46, 3, 83, 1,  5, 6, 66, 5, 35, 
    6, 84, 8, 58, 7, 55, 0, 37, 3, 40, 5, 38, 2, 42, 4, 12, 1, 64, 
    3, 78, 7, 59, 6,  7, 8, 99, 1, 67, 5, 36, 4, 64, 2, 62, 0,  7
  };
  const int q9577[] = {
    9, 9, // Number of jobs and machines
    3,  9, 8, 74, 4, 38, 7, 80, 0, 74, 6, 66, 5, 52, 1, 11, 2, 11, 
    4, 91, 2, 19, 7, 35, 3, 95, 0, 40, 8, 31, 5, 70, 6, 67, 1, 29, 
    5, 34, 8, 59, 6, 45, 2, 77, 3,  2, 0, 59, 7,  4, 1, 95, 4, 29, 
    5, 15, 7, 70, 1, 38, 0, 19, 6, 35, 4, 61, 3, 21, 2, 17, 8, 96, 
    5, 47, 0, 97, 4, 74, 1,  9, 7, 82, 8, 73, 3, 37, 2, 57, 6, 91, 
    6, 11, 2, 65, 7, 82, 5, 86, 4, 62, 8, 21, 0, 88, 1, 10, 3, 84, 
    0, 22, 8, 18, 5, 18, 3, 11, 1,  6, 4, 54, 6, 96, 7, 62, 2, 72, 
    3, 29, 6,  3, 5, 70, 1, 68, 2, 50, 8, 47, 0, 50, 7, 32, 4, 16, 
    4, 14, 5, 13, 7, 37, 6, 27, 1, 20, 8, 44, 0, 28, 3, 93, 2, 42
  };
  const int q9578[] = {
    9, 9, // Number of jobs and machines
    0, 39, 3,  2, 6, 15, 5, 29, 7,  8, 8, 16, 2, 95, 1, 82, 4, 66, 
    3, 86, 4, 80, 6, 42, 0, 59, 2, 42, 8, 25, 7, 45, 5, 84, 1, 83, 
    2, 78, 6,  8, 1,  9, 4, 27, 8, 50, 7, 55, 5,  3, 0, 92, 3, 39, 
    4, 24, 1, 80, 5, 60, 7, 71, 3, 55, 8, 29, 0, 62, 2, 85, 6, 55, 
    5, 29, 8, 24, 0, 42, 6, 21, 4, 89, 2, 76, 7, 68, 1, 43, 3,  7, 
    2, 12, 6,  1, 1, 32, 0, 47, 5, 91, 8,  2, 3, 48, 7, 19, 4, 66, 
    7, 56, 0, 96, 5, 12, 6, 46, 4, 16, 1, 57, 3, 80, 2, 99, 8, 56, 
    6, 37, 8, 19, 3, 29, 2, 75, 4, 69, 7, 21, 5, 79, 0, 15, 1, 83, 
    8,  5, 7, 37, 1, 52, 4, 60, 6, 60, 2, 66, 5, 99, 3, 59, 0, 94
  };
  const int q9579[] = {
    9, 9, // Number of jobs and machines
    0, 21, 2,  2, 7, 16, 3, 89, 4, 54, 1, 29, 5, 65, 6, 88, 8, 46, 
    4, 93, 5, 77, 0, 29, 3, 36, 2, 37, 6, 38, 1, 32, 7, 62, 8,  8, 
    5, 33, 4, 79, 7, 45, 8, 89, 0, 73, 3, 61, 2, 44, 1, 29, 6, 19, 
    8, 51, 0, 28, 3, 57, 1, 77, 2, 75, 7,  8, 6, 69, 5, 96, 4, 32, 
    0, 42, 1, 40, 8, 79, 5, 46, 7, 41, 3, 35, 4, 84, 6, 73, 2, 50, 
    6, 19, 3, 15, 2, 99, 8, 65, 7, 80, 0, 26, 5, 48, 4, 12, 1, 32, 
    0, 48, 1, 90, 7, 50, 4, 24, 5, 91, 3, 10, 2, 35, 6,  2, 8, 56, 
    1, 89, 2, 35, 0, 17, 5, 39, 7, 98, 8, 13, 3, 65, 4, 32, 6, 43, 
    8, 67, 0, 41, 6, 70, 1, 26, 2, 43, 7, 67, 3, 10, 4, 11, 5, 93
  };
  const int q9580[] = {
    9, 9, // Number of jobs and machines
    8, 78, 5, 99, 7, 61, 0, 56, 6, 19, 4, 60, 2, 89, 1, 84, 3, 62, 
    1, 95, 4, 54, 6, 45, 5, 27, 2, 23, 3, 18, 7, 19, 0, 31, 8, 31, 
    3, 67, 8, 63, 4, 58, 7,  5, 5, 79, 6, 32, 2,  6, 0, 43, 1, 13, 
    2, 14, 6, 34, 7, 96, 3, 26, 1,  7, 8, 13, 5, 22, 4, 45, 0, 20, 
    2, 85, 8,  1, 4,  7, 3, 77, 0, 16, 1, 83, 6, 10, 5, 86, 7, 50, 
    0, 44, 6, 51, 3, 62, 2, 53, 7, 10, 4,  8, 5, 98, 8, 89, 1, 85, 
    6, 51, 7, 87, 1, 43, 0, 70, 2,  5, 8, 13, 5, 94, 4, 76, 3, 28, 
    7, 80, 4, 71, 1, 44, 3, 30, 8, 37, 0, 36, 2, 83, 6, 66, 5, 80, 
    0, 84, 4, 48, 7,  8, 5, 19, 8, 36, 3, 17, 6, 95, 2, 29, 1,  1
  };
  const int q9581[] = {
    9, 9, // Number of jobs and machines
    6, 19, 3, 48, 0, 62, 2, 32, 7, 45, 4, 47, 5,  6, 1, 62, 8, 43, 
    8, 27, 6, 54, 4, 36, 7, 46, 0, 98, 5, 42, 1, 69, 3, 13, 2, 47, 
    6,  9, 3, 60, 5, 29, 4, 45, 0, 51, 7, 50, 8, 10, 1, 45, 2, 44, 
    2, 57, 1, 51, 4, 61, 6, 71, 0, 56, 8, 41, 7, 33, 5, 52, 3,  1, 
    5, 92, 8, 44, 7, 73, 1, 89, 3, 89, 6, 61, 4,  4, 2, 99, 0, 75, 
    8, 87, 6, 74, 4, 31, 1, 94, 0, 66, 2, 17, 5, 39, 3, 70, 7, 36, 
    5, 37, 1, 33, 8, 76, 0, 61, 7, 48, 2, 40, 6, 42, 3, 70, 4,  5, 
    7, 16, 5, 20, 6, 45, 0, 65, 2, 38, 8, 12, 1, 42, 4, 91, 3, 98, 
    8, 23, 5, 85, 2, 49, 7, 76, 0, 95, 3, 35, 1, 64, 4, 31, 6, 62
  };
  const int q9582[] = {
    9, 9, // Number of jobs and machines
    5, 26, 4, 41, 0, 71, 3, 99, 7, 33, 8, 15, 6, 40, 2, 47, 1, 56, 
    2, 28, 6, 53, 5, 57, 0, 38, 8, 70, 3, 19, 4,  7, 1, 14, 7, 81, 
    3,  8, 5, 30, 4, 20, 7, 28, 1, 34, 8, 10, 0, 61, 2,  4, 6, 97, 
    7, 42, 0, 36, 2, 92, 6, 36, 1, 34, 5, 30, 8, 63, 4, 46, 3, 13, 
    8, 44, 4, 45, 6, 83, 5, 15, 2, 63, 1, 89, 7, 62, 3, 19, 0, 77, 
    4, 90, 5, 82, 6, 25, 8, 39, 7, 79, 3, 73, 0, 40, 1, 96, 2, 39, 
    4, 87, 3, 65, 7, 48, 5, 14, 2, 62, 8, 31, 0,  1, 1, 82, 6, 36, 
    6, 81, 2, 20, 7, 76, 5, 97, 0, 20, 1, 64, 3, 91, 4, 72, 8, 81, 
    2, 88, 0, 57, 4, 57, 7, 55, 5, 73, 6, 10, 3, 23, 1, 99, 8, 46
  };
  const int q9583[] = {
    9, 9, // Number of jobs and machines
    6, 73, 3, 46, 2, 71, 4, 45, 5,  5, 0,  5, 8, 65, 1, 59, 7, 97, 
    3,  1, 8, 81, 6, 39, 7, 93, 5,  2, 4, 21, 2, 79, 1, 79, 0, 73, 
    2, 31, 4, 36, 0, 34, 5, 19, 6, 39, 3, 30, 7, 95, 1,  1, 8,  3, 
    2, 67, 7, 10, 3, 16, 0, 15, 5, 62, 1, 93, 8, 26, 6, 88, 4, 91, 
    5, 92, 6, 13, 0, 56, 2, 48, 4, 60, 7, 56, 1, 68, 8,  8, 3,  1, 
    2,  4, 5, 92, 7, 55, 3, 97, 8, 64, 6, 46, 4, 98, 1, 54, 0, 36, 
    6, 20, 4, 94, 8, 28, 1,  9, 7, 20, 0, 91, 3, 93, 2, 67, 5, 34, 
    4, 81, 5, 43, 3, 11, 7, 23, 8,  7, 1, 84, 0, 77, 2, 63, 6, 60, 
    5,  2, 2, 79, 3,  4, 8, 52, 4, 60, 0, 56, 1, 42, 7, 25, 6, 67
  };
  const int q9584[] = {
    9, 9, // Number of jobs and machines
    1,  6, 6, 30, 4, 21, 0, 40, 3, 35, 5, 78, 8, 66, 2, 75, 7, 89, 
    5, 77, 4, 55, 6, 54, 1, 39, 0, 42, 3, 25, 7, 49, 8, 78, 2, 34, 
    6, 94, 0, 25, 4, 57, 3, 71, 1, 70, 5, 60, 2, 27, 7, 92, 8, 29, 
    2,  8, 0, 26, 6, 67, 3, 51, 4,  4, 7, 67, 8, 60, 5, 21, 1, 97, 
    4, 96, 7,  3, 0, 89, 6,  9, 1, 79, 3, 53, 5, 61, 8, 65, 2,  9, 
    2, 34, 5, 65, 1, 81, 7, 49, 3, 13, 6, 40, 0, 99, 8,  6, 4, 78, 
    8, 56, 1, 48, 6, 64, 2, 24, 3, 22, 4, 46, 7, 42, 5, 55, 0, 46, 
    0, 11, 1, 91, 4, 81, 3, 88, 7, 45, 8, 27, 6, 29, 2, 14, 5, 87, 
    3, 17, 1, 79, 5, 64, 6, 35, 2, 12, 0, 57, 7, 28, 8, 67, 4, 57
  };
  const int q9585[] = {
    9, 9, // Number of jobs and machines
    3, 90, 0,  2, 6, 91, 2, 83, 4, 61, 7, 49, 8, 36, 5,  2, 1, 68, 
    1, 83, 0, 60, 4,  7, 2, 80, 6, 55, 8, 63, 3, 10, 5, 69, 7, 75, 
    7, 74, 6, 36, 8, 59, 4, 16, 0, 53, 5, 98, 2, 60, 3, 25, 1,  1, 
    1, 71, 2, 63, 3,  8, 7, 79, 0, 27, 5, 49, 6, 60, 4, 94, 8, 61, 
    3, 64, 0,  4, 4, 42, 5, 64, 2, 54, 1, 22, 8, 41, 6, 37, 7, 40, 
    8, 91, 5,  3, 7, 49, 1, 41, 6, 71, 4, 12, 0, 21, 2,  4, 3, 73, 
    2, 49, 6, 43, 4, 60, 1, 32, 0, 82, 5, 64, 7, 98, 8,  5, 3, 47, 
    2, 43, 7, 52, 5, 63, 0,  4, 1, 32, 8, 11, 6, 55, 4, 10, 3,  7, 
    5, 73, 0, 95, 3, 78, 4, 41, 1, 28, 6, 74, 2, 84, 8, 51, 7, 38
  };
  const int q9586[] = {
    9, 9, // Number of jobs and machines
    6, 55, 3, 15, 7, 67, 0, 53, 8, 52, 4, 25, 5, 94, 1, 42, 2, 18, 
    4, 64, 2, 83, 1, 65, 6, 38, 3, 39, 0, 11, 5, 59, 8, 70, 7, 61, 
    1, 47, 6, 22, 0, 27, 8,  5, 2,  2, 7, 39, 3, 71, 5, 92, 4, 62, 
    4, 67, 1, 47, 6, 36, 3, 85, 0, 93, 5, 29, 8, 29, 7, 45, 2, 70, 
    0, 12, 2, 98, 5, 96, 7, 31, 1, 72, 4, 56, 3, 17, 6, 39, 8,  2, 
    5, 48, 2,  9, 1, 80, 0,  1, 7, 98, 8, 79, 3, 83, 6, 40, 4, 24, 
    1, 57, 3, 90, 8, 61, 6, 47, 4, 24, 7, 23, 5, 43, 0, 67, 2, 21, 
    3, 95, 4, 37, 0,  6, 5, 49, 7, 38, 2, 25, 6, 23, 8, 72, 1, 61, 
    6, 91, 8, 55, 0, 25, 1, 75, 3, 92, 5, 44, 2, 77, 4, 89, 7, 60
  };
  const int q9587[] = {
    9, 9, // Number of jobs and machines
    8, 89, 7, 60, 5, 66, 1, 71, 0, 67, 3, 81, 4, 62, 6, 18, 2, 18, 
    1, 48, 3, 14, 0, 21, 5, 88, 2, 44, 8, 60, 4, 55, 7, 20, 6, 81, 
    4, 47, 7,  9, 2, 37, 8, 80, 6, 25, 5, 15, 1, 93, 0, 20, 3, 49, 
    2, 33, 8, 56, 4, 66, 0, 73, 6, 24, 1,  3, 5, 24, 3, 91, 7, 63, 
    7, 59, 6, 61, 8, 73, 2, 86, 3, 63, 1, 61, 4, 87, 0, 39, 5, 59, 
    3, 67, 7, 68, 2, 40, 0,  1, 4, 85, 6, 30, 5, 17, 8, 71, 1,  3, 
    2, 21, 0, 91, 3, 10, 6, 86, 5, 36, 7, 85, 1, 72, 4, 17, 8, 42, 
    4, 78, 5, 73, 0, 34, 7, 36, 3, 66, 2,  8, 8, 36, 1, 90, 6, 69, 
    4, 36, 3, 95, 1, 24, 7, 22, 5, 37, 8, 91, 6, 20, 2, 77, 0, 65
  };
  const int q9588[] = {
    9, 9, // Number of jobs and machines
    1, 20, 8, 46, 3, 62, 5, 86, 2, 25, 7, 57, 0, 18, 6, 87, 4, 39, 
    3, 71, 4, 39, 2, 41, 5, 14, 8, 23, 6,  5, 7,  9, 1, 60, 0,  4, 
    3, 91, 0,  5, 7, 44, 1, 94, 4, 46, 8, 83, 5, 77, 6, 47, 2, 32, 
    3, 26, 4, 71, 2, 11, 5, 99, 0, 75, 7, 92, 6, 51, 1,  8, 8, 35, 
    5, 66, 7, 61, 8, 47, 2, 25, 1, 95, 6, 13, 3, 29, 0, 97, 4, 90, 
    0, 19, 8, 39, 7, 44, 4, 21, 1, 76, 2, 87, 6, 59, 3, 80, 5, 66, 
    2, 80, 6, 51, 8, 97, 5, 61, 1, 51, 3,  8, 0, 35, 7, 57, 4, 51, 
    7, 24, 8, 29, 5, 40, 1, 42, 4, 16, 3,  4, 6, 39, 0, 46, 2, 72, 
    0, 20, 5,  5, 3, 45, 8, 58, 7, 30, 4, 29, 1, 17, 6,  9, 2, 92
  };
  const int q9589[] = {
    9, 9, // Number of jobs and machines
    2, 57, 3, 15, 8, 93, 5, 58, 7, 55, 0, 34, 6, 24, 1, 23, 4, 39, 
    3, 78, 6, 87, 5, 46, 7, 67, 2, 25, 0, 58, 1, 85, 4, 92, 8, 43, 
    5, 62, 8, 44, 2, 27, 7, 92, 1, 85, 6, 84, 0, 65, 3, 90, 4, 92, 
    7, 72, 3,  1, 5,  4, 2,  5, 6, 40, 0, 37, 4, 12, 8, 63, 1,  6, 
    1,  3, 0, 25, 7, 82, 6, 89, 8, 73, 2, 62, 5, 84, 4, 13, 3, 12, 
    7, 11, 8, 50, 0, 34, 5,  7, 6, 43, 4, 75, 2,  9, 3, 68, 1, 66, 
    4, 58, 0, 13, 8, 47, 2, 88, 6, 30, 5, 87, 3, 85, 7, 27, 1, 34, 
    1, 69, 6,  1, 8, 79, 3, 58, 7, 28, 4, 40, 5, 58, 0, 85, 2, 61, 
    5, 51, 1, 66, 0, 68, 8, 39, 2, 37, 6, 18, 3,  9, 7, 49, 4, 81
  };
  const int q9590[] = {
    9, 9, // Number of jobs and machines
    0, 73, 8, 85, 2, 71, 5,  7, 3, 63, 1, 43, 6, 76, 4, 37, 7, 32, 
    0, 49, 2, 86, 1, 82, 8, 60, 5,  2, 3, 89, 6, 30, 7, 59, 4, 64, 
    5, 58, 1, 97, 7, 91, 0, 87, 8, 46, 4, 54, 6, 27, 2, 46, 3, 85, 
    4, 55, 1, 47, 3, 55, 5, 69, 0, 31, 7, 15, 8, 44, 6, 69, 2, 46, 
    5, 88, 6, 31, 4, 29, 0, 61, 2, 53, 3, 25, 8, 12, 7, 30, 1, 91, 
    8, 63, 5, 68, 2, 27, 7,  5, 3, 76, 6, 39, 1, 64, 0, 73, 4, 28, 
    2, 96, 8, 82, 5, 93, 1, 94, 6, 12, 3, 68, 7, 37, 4, 76, 0, 12, 
    4, 43, 3,  9, 5, 59, 0, 30, 2,  6, 1, 42, 8, 98, 6, 44, 7,  9, 
    8, 34, 7, 25, 6, 73, 0, 27, 1, 91, 5, 20, 4, 69, 3, 48, 2, 62
  };
  const int q9591[] = {
    9, 9, // Number of jobs and machines
    3, 25, 4, 28, 0, 38, 6, 39, 1, 52, 7, 74, 5, 47, 8, 34, 2, 86, 
    2, 58, 7,  6, 5, 80, 1, 50, 3,  9, 6, 21, 0, 30, 8, 98, 4, 72, 
    2, 62, 7, 61, 8, 95, 4, 22, 1, 98, 3, 93, 5, 37, 6, 67, 0, 69, 
    6, 47, 8, 85, 4,  7, 3, 11, 7, 36, 5, 23, 0, 36, 2, 77, 1, 41, 
    0, 12, 3, 65, 2, 43, 5, 73, 7, 38, 1, 14, 4, 23, 6, 47, 8,  9, 
    8, 21, 2, 21, 6, 73, 3, 45, 0, 44, 5, 83, 4, 85, 1, 43, 7, 58, 
    5, 18, 4,  4, 0, 29, 6,  5, 8,  1, 3, 81, 1, 14, 7, 37, 2, 44, 
    4, 95, 2, 82, 5, 16, 6, 25, 3, 99, 0, 32, 7, 11, 1, 85, 8, 76, 
    5, 43, 2, 88, 1, 24, 6, 39, 3, 15, 7, 75, 4, 63, 0, 45, 8, 43
  };
  const int q9592[] = {
    9, 9, // Number of jobs and machines
    8, 28, 0, 91, 2, 19, 1, 13, 7, 82, 3, 85, 5, 71, 4, 93, 6, 23, 
    0, 12, 7, 45, 8,  7, 3, 15, 2, 54, 5, 77, 6, 44, 1, 43, 4, 17, 
    2, 16, 8, 34, 0, 41, 4, 55, 5, 75, 7, 90, 6, 68, 3, 44, 1, 78, 
    3, 72, 0, 75, 6, 11, 2, 92, 8, 75, 5, 33, 4, 72, 1, 61, 7, 12, 
    2,  3, 6, 29, 3, 60, 5, 69, 7, 94, 0, 10, 8, 62, 1, 16, 4, 26, 
    8, 94, 7, 20, 5,  4, 4, 43, 1, 48, 3, 70, 6, 49, 0, 85, 2, 48, 
    5, 57, 3, 63, 7, 14, 6, 78, 2, 77, 0, 26, 8, 47, 1, 15, 4,  4, 
    5, 60, 1, 44, 6, 93, 3, 83, 7, 97, 8, 35, 4,  6, 2, 36, 0, 16, 
    3, 28, 0, 28, 6, 76, 2,  4, 8, 41, 4, 75, 7, 51, 1, 46, 5, 13
  };
  const int q9593[] = {
    9, 9, // Number of jobs and machines
    0, 80, 7, 66, 3, 45, 8,  9, 2, 28, 1, 50, 6, 71, 4, 68, 5,  8, 
    1, 84, 3, 18, 7, 33, 6, 63, 8, 44, 2, 84, 4, 76, 5, 91, 0, 40, 
    2, 34, 8, 56, 5, 74, 3, 52, 1, 94, 0, 39, 7, 61, 4, 73, 6, 78, 
    8, 74, 7, 71, 0, 72, 2, 48, 6, 72, 1, 20, 5,  3, 3, 68, 4, 93, 
    1, 97, 6, 81, 3, 74, 7, 39, 5, 87, 2, 34, 4, 76, 8,  2, 0, 63, 
    4, 67, 6, 34, 7, 69, 3, 90, 1, 59, 0, 36, 8, 14, 5, 92, 2, 59, 
    1, 72, 8, 37, 6, 68, 3, 57, 7, 87, 0, 93, 5, 93, 2, 62, 4, 29, 
    8, 66, 0, 43, 7, 72, 5, 53, 3, 99, 1, 72, 4, 62, 2, 22, 6, 63, 
    7, 72, 1, 67, 5, 44, 3, 47, 6, 17, 4, 11, 8, 25, 0, 56, 2, 46
  };
  const int q9594[] = {
    9, 9, // Number of jobs and machines
    3, 23, 8, 14, 7, 37, 6, 15, 0, 74, 5, 59, 4, 86, 2, 58, 1, 29, 
    7, 26, 6, 38, 5, 92, 4,  9, 2, 91, 0, 98, 8, 30, 1, 12, 3,  7, 
    3, 37, 6, 80, 5, 86, 0, 37, 4, 13, 8, 16, 2, 94, 7, 76, 1, 33, 
    4, 18, 7, 91, 1, 48, 6, 49, 3, 65, 2, 76, 8, 50, 5, 64, 0, 57, 
    6, 24, 1, 15, 2, 35, 3, 15, 4, 68, 7, 12, 5, 39, 0, 11, 8, 80, 
    0, 14, 6, 77, 3,  4, 5, 91, 1, 81, 4, 68, 8, 51, 2, 38, 7, 51, 
    8, 47, 3,  2, 6, 40, 2, 18, 4,  5, 5, 46, 1, 83, 0, 41, 7, 70, 
    7, 61, 1, 19, 2, 14, 5, 12, 8, 55, 4, 26, 3, 67, 6, 66, 0, 76, 
    2, 34, 3, 91, 8, 23, 0, 30, 5, 10, 6, 16, 1, 43, 4, 83, 7, 93
  };
  const int q9595[] = {
    9, 9, // Number of jobs and machines
    7, 93, 2, 46, 0, 58, 8, 41, 5, 90, 3, 13, 1, 88, 6, 22, 4, 26, 
    1, 39, 8, 55, 5, 77, 6,  6, 2, 90, 3, 29, 4, 71, 0, 81, 7, 54, 
    7, 72, 1, 18, 5, 45, 4, 56, 0, 82, 3, 70, 6, 15, 8, 49, 2, 74, 
    4, 14, 2, 37, 3, 66, 8, 54, 5, 13, 6, 36, 1, 71, 7, 66, 0, 83, 
    3, 28, 0, 80, 6, 17, 8, 65, 2,  5, 1, 26, 4, 66, 7, 52, 5, 11, 
    3, 77, 2, 31, 7, 25, 5, 42, 1, 53, 0, 32, 4, 69, 6, 67, 8, 44, 
    8, 74, 0,  1, 6, 24, 5,  6, 7, 59, 2, 56, 1,  8, 3, 17, 4, 95, 
    5, 32, 8, 66, 4, 78, 3, 12, 0, 67, 1, 86, 7, 71, 2, 43, 6, 15, 
    8,  2, 6, 98, 3, 14, 2, 57, 5,  1, 0, 41, 7,  2, 4, 61, 1, 48
  };
  const int q9596[] = {
    9, 9, // Number of jobs and machines
    1, 25, 8, 28, 2, 51, 3, 18, 6, 39, 5, 36, 0,  7, 7, 70, 4, 54, 
    1, 65, 2, 58, 7, 25, 6, 29, 8, 43, 0, 57, 3,  8, 4, 56, 5, 54, 
    1, 59, 5, 61, 7,  6, 2, 10, 3, 37, 6, 32, 8, 71, 4,  7, 0, 44, 
    0, 55, 6, 35, 3, 67, 5, 14, 4, 86, 7, 52, 8, 20, 2, 18, 1, 31, 
    5, 18, 2,  8, 1,  1, 6, 98, 7, 72, 8, 52, 3, 11, 0, 77, 4, 75, 
    8, 34, 7, 31, 6, 62, 1, 34, 2, 34, 0, 53, 4, 56, 3, 89, 5, 92, 
    0, 68, 1, 56, 3, 94, 8, 14, 7, 36, 5, 72, 4, 64, 2, 33, 6,  1, 
    6, 92, 4, 23, 7, 30, 5, 36, 1, 90, 8, 16, 3,  9, 2, 44, 0, 28, 
    5, 25, 1, 39, 7, 80, 4, 85, 8, 84, 6, 72, 3,  4, 0, 31, 2, 85
  };
  const int q9597[] = {
    9, 9, // Number of jobs and machines
    5, 12, 0, 19, 3, 10, 6, 74, 8, 43, 1, 34, 7, 50, 4, 35, 2, 75, 
    6, 23, 0, 54, 8, 69, 4, 64, 1, 52, 2, 53, 5, 14, 7, 87, 3, 15, 
    0, 45, 7, 69, 5, 17, 3, 54, 4, 12, 6, 67, 1, 95, 8, 16, 2, 20, 
    3, 76, 7, 33, 2, 79, 8, 66, 5, 28, 1, 50, 4, 68, 0, 65, 6, 25, 
    6,  6, 5, 58, 8, 73, 2, 76, 4, 59, 1, 55, 0, 58, 7, 36, 3, 64, 
    0, 19, 6, 63, 3, 84, 2, 87, 5,  8, 4, 87, 7, 71, 8, 30, 1, 27, 
    2, 61, 7, 39, 4, 36, 1, 28, 8, 28, 3, 94, 5, 15, 6, 43, 0, 90, 
    5, 15, 8, 30, 4, 17, 0, 66, 2, 31, 3, 15, 1, 44, 6,  9, 7, 97, 
    6, 69, 5, 30, 4, 50, 0, 99, 2, 43, 8, 11, 7, 80, 1, 35, 3, 67
  };
  const int q9598[] = {
    9, 9, // Number of jobs and machines
    1,  8, 4, 84, 8, 96, 2, 28, 3, 20, 5, 13, 6, 38, 7, 44, 0, 89, 
    0, 55, 5, 58, 1, 66, 7, 35, 3, 94, 6, 33, 2, 60, 8, 63, 4, 11, 
    5, 17, 4, 51, 3, 88, 7, 36, 1,  2, 0, 25, 8, 28, 2, 70, 6, 56, 
    6, 51, 8, 89, 1, 95, 3, 49, 2, 93, 4, 52, 5, 24, 7, 24, 0, 36, 
    4, 97, 7, 91, 5, 56, 2, 46, 8, 75, 1, 76, 3, 77, 0, 46, 6, 76, 
    2, 38, 7, 34, 6, 33, 3, 42, 8, 39, 1, 14, 0, 49, 5, 14, 4, 69, 
    2,  6, 1, 67, 3, 20, 7, 71, 6, 97, 8, 60, 0, 23, 4, 18, 5,  5, 
    1, 39, 5, 78, 7, 21, 3, 68, 4, 28, 2,  9, 0, 39, 8, 93, 6, 97, 
    0, 60, 7, 93, 2, 25, 4, 82, 1, 98, 8, 87, 5, 12, 3,  5, 6, 30
  };
  const int q9599[] = {
    9, 9, // Number of jobs and machines
    7, 78, 4, 66, 1, 88, 2, 22, 6,  9, 5, 59, 8, 70, 0,  8, 3, 91, 
    5, 81, 4,  8, 1, 85, 6, 31, 2,  2, 7, 71, 0, 33, 3, 53, 8, 60, 
    5, 66, 2, 86, 8, 38, 1, 75, 0, 16, 3, 17, 4, 66, 6,  4, 7, 99, 
    6, 41, 2, 22, 7, 84, 4, 50, 5, 71, 3, 20, 1,  4, 8, 91, 0, 57, 
    1, 28, 4, 32, 0, 27, 2, 80, 5, 66, 3, 23, 7, 37, 8, 44, 6, 70, 
    6, 29, 3, 33, 5, 77, 8, 71, 7, 46, 1, 17, 2, 57, 4, 48, 0, 11, 
    1, 90, 5,  5, 3, 76, 6, 46, 0, 45, 7, 86, 8, 71, 4, 65, 2, 31, 
    4, 91, 1,  9, 6, 51, 2, 86, 0, 36, 3, 61, 8, 42, 7,  2, 5, 35, 
    3, 68, 6, 99, 1, 21, 2,  1, 4, 44, 5, 30, 8, 23, 7, 50, 0,  5
  };
  const int q9600[] = {
    9, 9, // Number of jobs and machines
    4, 51, 0, 76, 8, 97, 1, 30, 6, 46, 3, 64, 5, 38, 7, 85, 2,  3, 
    5, 81, 2,  1, 7, 80, 8, 78, 6, 17, 4, 43, 3, 66, 1, 31, 0, 62, 
    5, 94, 7, 57, 2, 88, 8, 60, 6, 70, 0, 30, 1, 87, 4, 70, 3,  6, 
    4, 42, 7, 61, 0, 30, 2, 96, 8, 33, 5, 82, 3, 47, 1, 74, 6,  8, 
    1, 76, 2, 94, 8, 79, 0, 13, 5, 99, 7, 51, 4, 31, 3, 22, 6, 81, 
    2, 18, 8,  9, 5, 20, 7, 80, 3,  8, 6, 67, 1, 17, 4, 26, 0, 45, 
    7, 24, 1, 34, 0, 92, 3, 71, 5, 73, 4, 93, 6, 58, 8, 89, 2, 84, 
    4, 63, 7, 38, 8, 29, 1, 39, 5, 23, 0, 17, 6, 40, 3,  1, 2, 70, 
    1, 74, 2, 73, 7, 86, 5, 30, 8, 30, 6, 13, 0, 87, 3, 50, 4, 61
  };
  const int q9601[] = {
    9, 9, // Number of jobs and machines
    5, 25, 0, 44, 6, 11, 8, 82, 2, 53, 4, 86, 3, 49, 1, 70, 7, 76, 
    4, 79, 2, 60, 1, 45, 6, 77, 0, 58, 3, 86, 5, 68, 8, 92, 7, 87, 
    5,  8, 2, 44, 1, 25, 4, 68, 0,  1, 6, 37, 8, 36, 3, 47, 7, 70, 
    4,  6, 8, 78, 3, 96, 6, 78, 2, 11, 5, 44, 7, 69, 1, 73, 0, 61, 
    8, 53, 5, 37, 6, 34, 7, 33, 3, 81, 4,  2, 0, 53, 2, 38, 1, 70, 
    5, 44, 2, 98, 0,  7, 1, 12, 6, 18, 8, 89, 4, 23, 7,  8, 3, 25, 
    8, 10, 4, 22, 6, 49, 3, 88, 7, 19, 1, 79, 2, 27, 0, 92, 5, 54, 
    0, 28, 1, 82, 7, 59, 3, 59, 6, 13, 4, 16, 2, 81, 5, 80, 8, 11, 
    7, 40, 3, 75, 1, 38, 0, 13, 6, 81, 8, 65, 5, 51, 4,  6, 2, 30
  };
  const int q9602[] = {
    9, 9, // Number of jobs and machines
    4, 65, 1,  9, 8, 94, 5, 40, 3, 82, 0, 53, 2, 89, 7, 41, 6, 58, 
    8, 71, 1, 23, 4,  7, 0, 66, 7, 29, 6, 35, 3, 90, 5, 61, 2,  2, 
    3, 53, 8, 12, 1, 19, 7,  7, 2, 71, 0, 42, 6, 81, 4,  6, 5, 68, 
    4, 83, 5,  8, 1, 25, 8, 49, 7, 11, 2,  2, 3, 78, 6, 46, 0, 15, 
    5, 48, 0, 90, 2, 85, 4, 52, 1, 86, 3, 34, 7, 85, 8, 18, 6, 26, 
    2, 30, 3, 20, 0, 78, 6, 45, 8,  5, 7, 89, 5, 20, 1, 25, 4, 36, 
    6, 63, 3, 13, 0, 63, 2, 39, 7, 22, 5, 73, 8, 82, 1, 24, 4, 16, 
    2, 70, 8, 68, 4, 99, 1, 33, 3, 93, 7, 99, 5, 88, 0, 21, 6, 94, 
    3, 75, 5, 16, 0,  8, 2, 83, 4, 56, 1, 38, 6, 29, 8, 66, 7, 73
  };
  const int q9603[] = {
    9, 9, // Number of jobs and machines
    8, 99, 0, 75, 2, 99, 4, 96, 5, 99, 1,  8, 3, 60, 7, 87, 6, 13, 
    1, 10, 6, 34, 5, 30, 2, 39, 3, 17, 4, 66, 7,  2, 8, 48, 0, 82, 
    8,  4, 3, 68, 5, 98, 7, 27, 4, 57, 2, 75, 0, 95, 1, 23, 6, 14, 
    5, 28, 3, 76, 7, 33, 6, 32, 8, 62, 0, 69, 4, 65, 1, 45, 2, 79, 
    4, 47, 7, 97, 2, 11, 8, 53, 6, 36, 5, 58, 1,  8, 0, 35, 3, 29, 
    6, 18, 3, 14, 1, 60, 2, 61, 5, 71, 7,  1, 4,  4, 0, 16, 8, 56, 
    1, 22, 0, 51, 6, 23, 7, 73, 2, 53, 5, 45, 8, 57, 3, 62, 4, 54, 
    4, 17, 8,  1, 6, 40, 5, 22, 7, 55, 3, 97, 1, 74, 2, 93, 0, 55, 
    6, 39, 3, 19, 4, 77, 0, 30, 5, 72, 1, 18, 8, 98, 2, 57, 7, 74
  };
  const int q9604[] = {
    9, 9, // Number of jobs and machines
    4,  7, 0,  2, 5, 55, 8, 23, 1, 47, 7, 18, 2, 67, 3, 55, 6, 99, 
    8, 43, 1,  3, 7, 14, 0, 27, 3, 75, 4,  8, 5, 41, 2, 32, 6,  1, 
    3, 26, 1, 43, 6, 70, 8,  1, 2, 53, 0, 89, 4, 35, 7, 90, 5, 48, 
    8, 46, 7, 21, 1, 84, 6, 38, 0, 90, 5, 61, 3, 14, 2, 22, 4, 82, 
    4, 49, 5, 11, 1, 52, 2, 25, 0, 44, 7, 72, 3, 36, 6, 59, 8, 15, 
    4, 17, 0, 75, 7,  7, 2,  5, 6, 70, 3,  9, 5, 56, 8, 26, 1,  2, 
    3, 70, 7, 66, 8, 21, 6, 62, 1, 75, 4, 41, 0, 44, 2, 80, 5, 81, 
    0, 27, 3, 29, 6, 79, 2, 99, 4, 31, 8, 68, 5, 79, 1, 30, 7, 84, 
    6,  7, 3, 25, 0, 75, 2,  1, 5, 97, 8, 67, 1, 14, 7, 27, 4, 97
  };
  const int q9605[] = {
    9, 9, // Number of jobs and machines
    0, 83, 2, 63, 4, 31, 3, 77, 8, 76, 7, 28, 6, 61, 5, 29, 1, 94, 
    7, 98, 5, 93, 1, 25, 3, 30, 2, 16, 0, 40, 4, 64, 6, 21, 8, 83, 
    5, 24, 4, 89, 8, 81, 6, 47, 0,  7, 2, 77, 1, 14, 3, 83, 7, 95, 
    3,  5, 2,  3, 8, 91, 6,  2, 4,  7, 7, 14, 0, 39, 5,  3, 1, 15, 
    5, 47, 1, 21, 0, 88, 7, 85, 6, 52, 4, 56, 2, 37, 8, 74, 3, 77, 
    5, 57, 4, 70, 6, 31, 7, 48, 1, 17, 0, 65, 3, 38, 2, 86, 8,  8, 
    7, 85, 6, 95, 0, 81, 5, 88, 2, 60, 8, 94, 1, 89, 3, 81, 4, 67, 
    3,  4, 2, 30, 6, 44, 8, 41, 0, 37, 7, 86, 5, 38, 4,  3, 1, 81, 
    6, 17, 3, 56, 7, 14, 0,  6, 8, 85, 1, 69, 2, 65, 5, 78, 4, 91
  };
  const int q9606[] = {
    9, 9, // Number of jobs and machines
    4, 84, 7, 68, 6, 80, 5,  2, 2, 24, 1,  8, 8, 96, 3,  9, 0, 82, 
    3, 74, 7, 74, 0, 50, 6,  5, 8, 75, 2, 84, 5, 84, 1, 95, 4, 90, 
    6, 38, 7, 56, 2, 68, 3, 77, 8, 31, 4, 75, 0, 35, 1, 11, 5, 82, 
    6, 97, 1, 45, 5, 51, 3, 15, 2, 23, 7, 93, 8, 45, 0, 23, 4, 63, 
    2,  5, 4, 38, 6, 92, 1, 37, 7, 61, 5, 15, 3, 19, 0, 54, 8, 13, 
    7, 40, 8, 67, 0, 34, 4, 89, 3, 98, 5, 65, 6, 85, 2, 25, 1, 50, 
    1, 19, 6, 44, 0, 20, 4,  7, 5, 67, 7, 95, 8, 83, 3, 94, 2, 42, 
    5, 93, 7, 55, 3, 73, 1, 33, 4, 31, 2, 20, 8, 97, 0, 33, 6, 42, 
    0,  8, 7, 77, 5, 83, 8, 22, 2, 41, 3, 15, 4, 87, 1, 26, 6, 15
  };
  const int q9607[] = {
    9, 9, // Number of jobs and machines
    6, 82, 7, 26, 3, 20, 0,  8, 2, 36, 1, 46, 4, 17, 5, 57, 8, 42, 
    4, 55, 8, 51, 6, 86, 3, 12, 0, 76, 2, 32, 7, 57, 1, 49, 5, 75, 
    5, 59, 7, 22, 4, 70, 0, 23, 3, 76, 6, 32, 1, 82, 2, 39, 8, 80, 
    3, 15, 4, 61, 5, 71, 0,  3, 1, 17, 7, 63, 8, 20, 6, 10, 2, 36, 
    3, 36, 1,  3, 4, 15, 2, 35, 8, 95, 0, 69, 6, 97, 7, 80, 5, 61, 
    8, 65, 0, 71, 2, 95, 3, 10, 1, 16, 7, 91, 5, 54, 6, 88, 4, 38, 
    5, 21, 6, 21, 3, 10, 0, 74, 8, 66, 1, 56, 2, 62, 4, 49, 7, 55, 
    7, 72, 0, 44, 3, 15, 2, 93, 4, 23, 5, 11, 1, 35, 6, 84, 8, 69, 
    0, 50, 3, 92, 2, 92, 1, 53, 6, 91, 4, 27, 8, 40, 5, 65, 7, 74
  };
  const int q9608[] = {
    9, 9, // Number of jobs and machines
    0, 42, 2, 72, 1, 90, 4, 54, 7, 57, 3, 61, 5, 33, 8, 38, 6, 53, 
    5, 78, 8, 31, 0, 88, 2, 16, 6, 56, 3,  9, 7, 15, 4, 85, 1, 27, 
    0,  7, 2, 90, 7,  2, 6, 32, 5, 96, 4, 89, 8, 27, 1, 99, 3, 21, 
    3, 37, 4, 81, 7, 70, 6, 28, 1, 47, 8, 90, 2, 44, 0, 87, 5, 58, 
    2, 32, 5, 88, 1, 88, 3, 28, 7, 34, 4, 27, 8, 39, 6, 33, 0, 58, 
    1, 65, 2, 87, 5, 72, 0, 29, 7, 56, 3, 51, 4, 27, 6, 85, 8, 76, 
    5, 81, 2, 61, 6, 49, 3, 50, 4, 83, 8, 10, 1,  2, 7,  8, 0, 72, 
    2, 19, 4, 64, 0, 82, 6, 88, 8, 12, 3, 68, 1,  3, 5, 66, 7, 34, 
    3, 92, 5, 78, 6,  5, 7, 29, 2, 11, 8, 31, 1, 32, 4,  8, 0, 73
  };
  const int q9609[] = {
    9, 9, // Number of jobs and machines
    0, 46, 8,  7, 4, 87, 5, 76, 1, 85, 2, 29, 6, 85, 3, 13, 7, 63, 
    2, 63, 8, 24, 0, 14, 6, 26, 7, 38, 3, 18, 5, 10, 4, 24, 1, 15, 
    0,  6, 5, 38, 6, 23, 2, 26, 4, 85, 1, 84, 8, 34, 7, 21, 3, 59, 
    8, 35, 6, 37, 2, 10, 0, 14, 1, 43, 5, 50, 4,  9, 3,  9, 7, 26, 
    0, 62, 1,  2, 8, 85, 7, 43, 3, 60, 2, 28, 4, 46, 5, 66, 6, 81, 
    1, 34, 3, 17, 6, 29, 4, 47, 7, 39, 2, 47, 5, 29, 0, 20, 8,  6, 
    2, 80, 4, 98, 5, 56, 7, 25, 0,  3, 8, 10, 1, 70, 6, 39, 3, 89, 
    3, 29, 6, 52, 2, 40, 5, 29, 7, 48, 0, 91, 8, 37, 1, 67, 4, 72, 
    7, 86, 3, 84, 0, 77, 4, 76, 5, 16, 8, 77, 1, 44, 2, 17, 6, 14
  };
  const int q9610[] = {
    9, 9, // Number of jobs and machines
    3, 25, 2, 36, 6, 58, 4, 60, 7, 24, 5, 36, 8, 14, 1, 14, 0, 42, 
    8, 55, 2, 15, 7, 58, 5, 82, 0, 11, 6, 20, 1, 38, 3, 31, 4, 85, 
    7,  9, 2, 63, 0, 61, 6, 27, 8, 40, 4, 56, 5, 10, 3, 98, 1, 15, 
    8, 91, 5, 20, 7, 95, 2, 12, 0, 41, 3, 27, 1, 36, 6, 17, 4, 37, 
    8, 95, 7, 86, 0, 35, 1, 88, 5, 99, 4, 54, 6, 82, 3, 52, 2,  1, 
    2, 54, 7,  9, 5, 50, 0, 67, 6, 70, 1, 57, 3, 54, 8,  9, 4, 66, 
    3, 53, 4, 50, 5, 34, 1, 55, 0, 10, 2, 87, 6, 48, 7, 56, 8, 72, 
    2, 87, 7, 92, 6, 92, 4, 70, 1, 81, 8, 47, 3,  2, 0,  3, 5, 91, 
    5, 33, 8, 84, 3, 86, 6, 73, 7, 81, 4, 56, 2,  5, 1, 41, 0, 50
  };
  const int q9611[] = {
    9, 9, // Number of jobs and machines
    0, 28, 5, 27, 3, 73, 1, 85, 6, 88, 4, 32, 7,  1, 2, 24, 8, 36, 
    7, 13, 6, 44, 3, 27, 8,  4, 5, 70, 1, 77, 0, 50, 4, 13, 2, 42, 
    2, 72, 8, 26, 1, 34, 6, 25, 5, 20, 3, 35, 4, 90, 7, 86, 0, 48, 
    2, 36, 4, 77, 8,  7, 6, 76, 7,  3, 0, 68, 3, 53, 5, 70, 1,  5, 
    1, 89, 4, 80, 5,  5, 8, 56, 7, 62, 2, 36, 0, 98, 6, 24, 3, 41, 
    3, 20, 7, 36, 0,  8, 2,  4, 6, 65, 8, 84, 1,  2, 4,  2, 5, 24, 
    6, 98, 4, 47, 3, 41, 5, 73, 8, 49, 0, 30, 1,  7, 2, 17, 7, 53, 
    6, 51, 2, 89, 4, 92, 3, 15, 5, 16, 8, 12, 7,  8, 0, 37, 1, 40, 
    7, 64, 4,  6, 1, 34, 6, 60, 0, 21, 3, 65, 2, 62, 8, 16, 5, 28
  };
  const int q9612[] = {
    9, 9, // Number of jobs and machines
    4,  7, 3, 54, 6, 50, 0, 43, 5, 77, 1, 55, 8, 19, 2, 91, 7, 79, 
    3, 43, 6, 21, 7, 94, 0, 69, 1, 34, 2, 11, 4, 68, 5, 12, 8, 36, 
    1, 64, 0, 91, 6, 56, 2, 81, 8,  6, 7, 82, 4, 51, 5, 17, 3, 56, 
    5, 19, 4, 85, 3,  8, 2, 53, 0, 41, 6, 70, 7, 20, 1, 42, 8, 73, 
    8, 98, 5, 89, 2, 68, 6, 11, 3, 17, 4, 85, 7, 35, 1, 67, 0, 83, 
    5, 89, 0, 27, 1, 42, 7, 12, 2, 18, 8, 71, 3, 49, 4, 73, 6, 70, 
    8, 68, 6, 71, 7, 77, 0, 24, 4, 66, 5, 64, 3, 73, 1, 17, 2, 18, 
    0, 29, 1,  3, 8, 58, 6, 69, 4, 69, 5, 59, 2, 60, 3, 56, 7, 23, 
    1, 10, 3, 35, 0, 31, 2, 31, 5, 57, 6, 20, 8, 45, 4, 10, 7,  5
  };
  const int q9613[] = {
    9, 9, // Number of jobs and machines
    7, 93, 5, 40, 8, 10, 6,  5, 0, 30, 3, 20, 1, 88, 4, 33, 2,  5, 
    1, 76, 7, 58, 5, 80, 0, 36, 2, 53, 8, 51, 6, 60, 3, 94, 4, 47, 
    6, 99, 0, 48, 7, 37, 4, 82, 3, 70, 5, 74, 2, 98, 1, 53, 8, 65, 
    8, 10, 6, 91, 7, 52, 1, 80, 5, 92, 2, 20, 0, 13, 3,  3, 4,  9, 
    5, 83, 7, 49, 1, 96, 4, 15, 2, 49, 3, 98, 6, 45, 0, 44, 8, 60, 
    8, 17, 2, 96, 6, 51, 7, 33, 5, 38, 0, 23, 3, 64, 1, 12, 4, 35, 
    5, 92, 1, 76, 3, 66, 4,  1, 6, 17, 8, 85, 0, 38, 2, 42, 7, 96, 
    6, 19, 1, 30, 2, 18, 8, 95, 4, 52, 5, 51, 7, 11, 3, 13, 0,  7, 
    7, 56, 4, 93, 8, 57, 6,  1, 5, 23, 3, 17, 0,  3, 2, 41, 1, 35
  };
  const int q9614[] = {
    9, 9, // Number of jobs and machines
    7, 35, 1, 86, 5, 72, 2, 36, 8, 38, 4, 25, 6, 13, 0, 82, 3, 65, 
    5, 53, 7,  6, 1, 41, 2, 41, 3, 17, 4, 36, 0, 92, 6, 32, 8, 60, 
    6, 57, 8,  1, 3, 48, 4, 75, 0,  9, 5, 23, 7, 10, 2, 61, 1, 53, 
    4, 45, 1, 65, 8, 63, 0, 24, 5, 92, 3, 87, 2,  6, 7, 44, 6, 57, 
    3, 28, 2, 79, 4,  4, 8, 84, 5, 59, 7, 98, 0, 21, 1, 64, 6, 29, 
    7, 35, 1, 53, 8,  8, 6, 20, 2, 93, 3, 50, 0,  6, 5, 68, 4, 19, 
    0, 92, 6, 70, 2,  8, 7, 82, 4, 35, 5, 62, 3, 29, 1,  4, 8,  8, 
    8, 99, 7, 83, 5, 29, 6, 25, 1, 48, 2, 65, 4, 93, 0, 16, 3, 64, 
    7, 27, 5, 83, 1, 23, 8, 64, 3, 99, 2, 51, 0, 79, 4,  8, 6,  5
  };
  const int q9615[] = {
    9, 9, // Number of jobs and machines
    0, 17, 4, 57, 5, 90, 8, 47, 2, 39, 1, 42, 3, 44, 6, 99, 7, 23, 
    8,  2, 3, 22, 6,  2, 4, 53, 2, 38, 1, 86, 0, 43, 7, 95, 5, 78, 
    7, 66, 1, 50, 3, 60, 4, 65, 2, 14, 5, 71, 6,  4, 8,  8, 0, 16, 
    0, 33, 3, 63, 4, 94, 6, 19, 5, 93, 2, 52, 8, 74, 1, 84, 7, 64, 
    5, 50, 7, 49, 0, 57, 2, 83, 6, 78, 3, 21, 8, 66, 4, 73, 1, 16, 
    2, 49, 0, 91, 1, 37, 3, 92, 7, 13, 6, 19, 4,  6, 8, 71, 5, 58, 
    8, 74, 3, 79, 0, 98, 1, 46, 4, 40, 2, 92, 5, 13, 7, 33, 6, 81, 
    1, 71, 0, 75, 5, 73, 8, 76, 4, 93, 6, 38, 3, 83, 7,  5, 2, 76, 
    2, 55, 3, 20, 6,  8, 0, 51, 8,  5, 1, 40, 4, 57, 5, 55, 7, 68
  };
  const int q9616[] = {
    9, 9, // Number of jobs and machines
    6, 66, 3, 94, 7, 31, 4, 28, 2, 28, 1, 10, 8, 96, 5, 81, 0,  7, 
    0, 61, 4, 40, 2,  4, 6, 25, 5, 81, 1, 60, 7, 55, 8, 78, 3, 84, 
    7, 54, 4, 11, 3, 45, 0, 35, 5, 43, 6, 73, 8, 52, 2, 18, 1, 40, 
    1, 98, 0, 27, 5, 36, 4, 88, 6, 38, 2, 50, 7, 64, 8, 84, 3, 35, 
    4, 82, 8, 21, 6, 48, 7, 54, 1, 30, 3, 27, 5, 14, 2, 67, 0, 36, 
    8, 99, 4, 10, 5,  5, 1, 38, 0, 30, 7, 48, 6, 94, 2, 54, 3, 97, 
    6,  7, 8, 79, 0, 42, 1, 21, 3, 72, 4, 57, 5, 14, 2,  1, 7,  1, 
    6, 47, 4, 54, 3, 25, 2,  7, 7, 91, 0, 85, 1, 62, 5, 36, 8, 13, 
    7,  6, 0, 84, 3, 63, 2,  5, 8, 38, 4, 58, 5, 83, 1, 15, 6, 75
  };
  const int q9617[] = {
    9, 9, // Number of jobs and machines
    5, 43, 7, 59, 4, 67, 0, 92, 1, 73, 3, 26, 6, 36, 2, 83, 8, 31, 
    1, 27, 8, 77, 4, 76, 5, 78, 6, 80, 3,  6, 2, 27, 7, 72, 0, 18, 
    6, 93, 7,  4, 3, 57, 4, 29, 1, 33, 2, 23, 8, 73, 5, 51, 0, 81, 
    0, 44, 8,  6, 6, 65, 7, 24, 1, 13, 4, 17, 2, 93, 3, 63, 5, 13, 
    6, 72, 1, 67, 0,  9, 7, 93, 8, 25, 5, 17, 3, 17, 2, 71, 4,  3, 
    0, 34, 2, 90, 5, 38, 1, 18, 8, 20, 7, 73, 3,  3, 6, 50, 4, 93, 
    1, 44, 6, 63, 8, 30, 2, 38, 7, 23, 5, 31, 3, 54, 4, 73, 0, 19, 
    1, 59, 6, 17, 0, 19, 7, 26, 5, 31, 2, 76, 3, 57, 4, 99, 8, 77, 
    3, 25, 4, 57, 5, 68, 8, 18, 7, 28, 2, 86, 1, 23, 0, 88, 6, 27
  };
  const int q9618[] = {
    9, 9, // Number of jobs and machines
    8, 77, 1, 82, 2, 94, 7, 44, 0, 38, 4, 12, 3, 21, 6, 20, 5, 17, 
    1, 40, 8, 42, 5, 58, 4,  5, 6, 74, 2,  2, 0, 42, 7, 23, 3, 76, 
    6, 48, 5, 51, 1, 61, 3, 98, 0, 58, 8, 78, 7, 38, 2, 70, 4, 89, 
    5, 18, 6,  3, 0, 44, 8, 71, 3, 57, 1,  7, 2, 30, 4, 48, 7, 20, 
    6, 17, 2, 97, 4, 61, 8, 51, 3, 34, 0, 72, 5,  2, 7, 59, 1, 69, 
    5, 90, 3, 27, 0, 87, 8,  5, 2, 17, 7, 92, 6,  2, 4, 17, 1, 57, 
    1, 23, 7, 76, 3, 39, 0, 42, 2, 32, 8, 73, 6, 50, 4, 36, 5,  9, 
    5, 49, 7, 77, 0,  7, 6, 10, 8, 45, 3, 19, 4, 67, 1, 16, 2,  7, 
    7, 75, 5, 47, 2, 28, 6, 73, 1, 43, 0, 95, 8, 40, 3, 36, 4,  4
  };
  const int q9619[] = {
    9, 9, // Number of jobs and machines
    2, 36, 1, 63, 8, 33, 6, 54, 0, 57, 7,  2, 4, 94, 5, 77, 3,  7, 
    8,  6, 3, 27, 0, 44, 7, 70, 6, 56, 4, 46, 1, 69, 2, 25, 5, 94, 
    0, 63, 2, 21, 4,  6, 8,  3, 3,  4, 5, 84, 6, 21, 7, 65, 1, 39, 
    2, 45, 8, 78, 1, 64, 6, 85, 3, 54, 4,  6, 7, 36, 5, 27, 0, 33, 
    3, 47, 2,  7, 8, 41, 4, 18, 5, 89, 7, 83, 6, 88, 1, 19, 0, 28, 
    6, 82, 8, 75, 0, 47, 5, 63, 7, 33, 2, 46, 4, 22, 3, 43, 1, 31, 
    3, 80, 2, 46, 8, 14, 0, 93, 1, 46, 6, 94, 7, 60, 4, 73, 5, 64, 
    0, 86, 1, 37, 3, 97, 7, 86, 5, 85, 6, 34, 4, 56, 8, 88, 2, 35, 
    5, 74, 4, 81, 2, 87, 0, 45, 3, 76, 6, 64, 7, 43, 8, 77, 1, 23
  };
  const int q9620[] = {
    9, 9, // Number of jobs and machines
    4, 52, 3,  3, 7, 61, 0, 92, 5, 33, 6,  5, 2, 92, 1, 42, 8,  6, 
    7, 76, 5,  5, 2, 52, 6, 57, 4, 43, 0, 44, 8, 46, 1,  7, 3, 50, 
    0, 11, 8, 79, 6, 45, 3, 92, 1, 11, 7, 49, 5, 71, 2, 54, 4, 34, 
    0, 12, 5, 11, 3, 24, 6, 28, 8, 29, 4, 48, 1, 39, 7, 64, 2, 22, 
    5, 73, 7, 79, 4, 86, 3, 42, 8, 48, 2, 89, 0, 93, 1, 86, 6, 87, 
    4, 37, 6, 40, 8, 89, 0, 15, 3, 94, 1, 85, 5, 84, 2, 24, 7, 94, 
    6, 28, 1, 79, 5, 11, 7, 14, 2, 57, 4, 65, 8, 34, 3, 39, 0, 81, 
    2, 34, 6, 84, 5,  4, 7, 45, 8, 59, 0, 85, 4, 17, 3, 84, 1, 97, 
    8,  8, 2, 28, 7, 55, 1, 35, 4, 85, 6, 34, 0, 53, 3, 78, 5, 29
  };
  const int q9621[] = {
    9, 9, // Number of jobs and machines
    3,  5, 4, 37, 0, 28, 8, 75, 1, 36, 2, 16, 7, 78, 6, 79, 5, 90, 
    1, 71, 6, 55, 0, 30, 5, 87, 3, 16, 2, 97, 7, 51, 8, 91, 4, 75, 
    8, 41, 3, 20, 4, 86, 2, 98, 6, 18, 0, 49, 1, 76, 5, 51, 7, 83, 
    2, 79, 7, 98, 8, 23, 0, 54, 6, 13, 3, 50, 4, 31, 1, 42, 5, 67, 
    6, 49, 2, 89, 1, 94, 0,  7, 4, 23, 8, 78, 7, 28, 5, 98, 3, 60, 
    5, 44, 3, 19, 8, 31, 4, 81, 1, 10, 6, 97, 0, 92, 2, 98, 7, 74, 
    4, 77, 3, 54, 2, 20, 8, 57, 5, 54, 0, 83, 7, 73, 1, 74, 6, 80, 
    0, 26, 1, 66, 2, 43, 3, 43, 8, 97, 5, 24, 6, 20, 4, 16, 7, 11, 
    4, 68, 3, 54, 2, 67, 0, 73, 7, 61, 5,  2, 6, 13, 8, 78, 1, 24
  };
  const int q9622[] = {
    9, 9, // Number of jobs and machines
    0, 31, 2, 13, 1, 87, 3, 64, 4, 72, 7, 58, 8, 49, 6, 73, 5, 76, 
    7, 51, 4, 36, 1, 94, 0, 52, 3, 99, 6, 44, 5, 22, 2, 47, 8, 97, 
    5, 77, 7, 13, 4, 91, 8, 62, 3, 82, 0, 21, 1, 52, 6, 20, 2, 34, 
    0, 16, 3, 97, 7, 39, 4, 90, 1, 25, 8, 91, 6, 13, 5,  9, 2,  7, 
    5, 48, 4, 87, 7, 51, 1, 95, 3, 70, 2, 39, 6, 49, 8, 24, 0, 44, 
    7, 38, 1,  9, 3, 53, 8, 85, 0, 45, 4, 27, 5, 35, 6, 39, 2,  1, 
    0, 35, 6,  1, 3, 15, 8, 64, 7, 62, 5, 22, 1, 58, 2, 32, 4, 38, 
    0, 81, 6,  1, 4, 33, 8, 87, 1, 91, 3, 62, 7, 67, 5, 58, 2, 54, 
    6,  4, 3,  5, 2,  8, 5, 43, 4, 65, 7,  8, 8, 19, 1, 24, 0, 39
  };
  const int q9623[] = {
    9, 9, // Number of jobs and machines
    5, 88, 7, 91, 0, 48, 6,  8, 1, 14, 8, 98, 2,  6, 3, 52, 4,  9, 
    8, 53, 3, 71, 0, 26, 1, 52, 6, 14, 7, 41, 4, 64, 2, 95, 5, 24, 
    8, 93, 5, 55, 2, 18, 4, 84, 1, 54, 6,  8, 7, 72, 3, 71, 0,  7, 
    3, 54, 0, 97, 8, 18, 7, 98, 2, 45, 6, 95, 1, 29, 4, 78, 5, 69, 
    0, 18, 6, 70, 4, 96, 5, 89, 3, 19, 8, 83, 2, 41, 1, 51, 7,  5, 
    4, 98, 2, 48, 7, 42, 0,  5, 8, 45, 6,  8, 3, 74, 1,  4, 5, 53, 
    3, 55, 5, 96, 0, 23, 2, 85, 8, 92, 6,  9, 7, 19, 1, 64, 4, 92, 
    8, 67, 1, 70, 3, 43, 6, 65, 4, 23, 2, 49, 0, 54, 5, 13, 7, 76, 
    4, 37, 5,  2, 0, 27, 3, 71, 1, 97, 6, 20, 2, 97, 8, 18, 7, 24
  };
  const int q9624[] = {
    9, 9, // Number of jobs and machines
    5, 52, 8, 37, 1,  6, 3, 33, 7, 54, 2, 46, 4, 58, 6, 52, 0, 85, 
    6, 70, 2, 15, 8, 53, 5, 35, 1, 99, 7,  3, 4, 83, 3, 85, 0, 13, 
    2, 24, 4, 37, 1,  5, 0, 65, 8, 59, 6, 23, 5, 55, 7, 28, 3, 22, 
    3, 80, 5, 45, 7, 17, 6, 61, 2, 66, 4, 47, 8, 53, 0, 40, 1, 59, 
    6, 43, 3, 24, 8, 70, 2, 34, 4, 89, 0, 58, 5, 92, 1, 19, 7, 58, 
    1, 56, 3, 97, 6,  7, 8, 84, 0, 65, 2, 66, 7, 66, 4, 55, 5, 32, 
    5, 58, 4, 84, 7, 57, 8, 80, 3, 56, 2, 96, 6, 42, 0, 83, 1, 55, 
    4, 98, 1,  7, 2, 61, 3, 47, 0, 11, 7, 57, 5, 30, 6, 51, 8, 70, 
    4,  8, 0, 69, 1, 76, 5, 75, 7, 94, 2,  8, 6, 39, 8, 46, 3, 74
  };
  const int q9625[] = {
    9, 9, // Number of jobs and machines
    3, 14, 4,  4, 5,  7, 2, 43, 6, 13, 0,  2, 1, 79, 8, 60, 7, 98, 
    5, 77, 6, 68, 2, 47, 7, 47, 8, 34, 3, 15, 0, 66, 4, 98, 1, 11, 
    3, 99, 5, 68, 8, 82, 0,  6, 7, 71, 2, 25, 1, 57, 4, 65, 6, 15, 
    5, 38, 2, 43, 8, 49, 7, 24, 0, 98, 4, 73, 1, 89, 6, 94, 3, 42, 
    8,  3, 6, 71, 4, 35, 0, 43, 3, 92, 5, 39, 2, 44, 1, 95, 7, 56, 
    2, 55, 5, 85, 3, 99, 0, 37, 8, 30, 1, 19, 7, 42, 6, 78, 4, 62, 
    7, 84, 5, 96, 4, 53, 2, 54, 6, 68, 1, 66, 8, 11, 0, 32, 3, 18, 
    7, 23, 8, 25, 4, 74, 2, 92, 3, 49, 1,  6, 0, 77, 6, 84, 5, 98, 
    1, 28, 2, 38, 6, 50, 0, 26, 7, 93, 3, 86, 5, 28, 4, 55, 8, 69
  };
  const int q9626[] = {
    9, 9, // Number of jobs and machines
    0, 35, 5, 70, 8, 73, 3, 74, 4, 85, 2, 70, 1, 21, 7, 73, 6, 77, 
    1, 72, 6, 31, 4, 45, 0, 51, 7, 84, 3, 11, 2, 84, 5,  2, 8, 42, 
    0, 18, 5, 30, 4,  1, 1, 19, 2, 25, 3, 72, 6, 56, 8, 12, 7,  8, 
    2, 56, 0, 58, 7, 98, 3, 64, 8, 42, 4, 82, 6,  6, 5, 46, 1,  1, 
    4, 21, 8, 65, 7, 73, 3, 32, 1, 26, 0, 32, 2, 47, 5, 34, 6, 86, 
    8, 21, 1, 90, 6, 71, 4, 65, 7, 23, 5, 99, 0, 26, 2, 82, 3, 22, 
    8,  5, 0, 92, 7, 15, 6, 23, 5, 10, 2, 38, 3, 84, 1, 55, 4, 72, 
    6, 10, 0, 63, 1,  7, 5, 97, 7,  1, 8, 41, 4, 21, 2, 81, 3, 69, 
    6, 22, 3, 88, 8, 33, 2,  3, 1, 40, 4, 51, 5, 71, 0, 92, 7, 15
  };
  const int q9627[] = {
    9, 9, // Number of jobs and machines
    8, 82, 3, 51, 5, 15, 1, 86, 4, 97, 0, 32, 6, 74, 2, 93, 7, 30, 
    3, 12, 0, 71, 8, 56, 5, 71, 6, 52, 2, 30, 4, 98, 1, 97, 7, 15, 
    1, 31, 6, 84, 5, 78, 8, 39, 7, 75, 2, 95, 3, 53, 0, 60, 4, 62, 
    4, 33, 7, 85, 5, 82, 2, 95, 1, 38, 8, 49, 0, 58, 3, 50, 6, 66, 
    8, 93, 7, 53, 4, 56, 6, 38, 1, 70, 2, 16, 3, 43, 0, 72, 5, 80, 
    2, 57, 1, 57, 3, 71, 8,  3, 6, 78, 5, 14, 4,  4, 7, 71, 0, 59, 
    1,  4, 8, 78, 7, 53, 6, 70, 2,  1, 5, 48, 0, 36, 3, 52, 4,  5, 
    0, 98, 7, 20, 8, 31, 5, 59, 3, 75, 2, 31, 6, 88, 4, 96, 1, 72, 
    3, 32, 0, 60, 5, 33, 2, 89, 7, 68, 1,  8, 6, 68, 4, 44, 8, 16
  };
  const int q9628[] = {
    9, 9, // Number of jobs and machines
    0, 17, 2, 74, 3, 62, 7, 83, 5, 48, 6, 24, 8, 93, 1, 50, 4, 94, 
    8,  3, 7, 16, 3, 32, 4, 39, 6, 62, 2, 76, 1, 44, 0, 23, 5, 94, 
    4,  1, 1, 59, 0, 20, 3,  2, 8, 85, 5, 58, 6, 36, 2, 85, 7, 53, 
    0, 32, 6, 61, 2, 31, 7, 57, 3, 46, 5,  9, 1, 51, 4, 50, 8, 67, 
    4, 74, 7, 53, 0, 64, 3, 74, 5,  9, 8, 81, 6, 78, 2, 37, 1,  5, 
    4, 89, 2, 90, 3, 70, 7, 65, 8, 20, 0, 44, 1, 55, 5, 58, 6, 20, 
    6,  7, 1, 52, 0, 55, 8, 99, 4, 75, 7, 80, 2, 55, 5,  4, 3, 97, 
    4, 78, 5, 23, 3, 29, 2,  8, 8, 82, 0, 38, 1, 11, 7, 41, 6, 96, 
    7, 75, 5, 80, 3, 85, 4, 61, 0, 43, 6, 94, 8, 30, 1, 92, 2, 12
  };
  const int q9629[] = {
    9, 9, // Number of jobs and machines
    2, 95, 1, 44, 6,  4, 0, 20, 4, 38, 8, 27, 7, 23, 3, 40, 5, 83, 
    4, 69, 0, 27, 8, 88, 6, 43, 1, 23, 3, 51, 5,  3, 7, 78, 2, 98, 
    1, 12, 2, 68, 0, 75, 3, 36, 8, 29, 7, 62, 5, 97, 6, 27, 4, 82, 
    2, 88, 1, 85, 6, 99, 5, 61, 7, 20, 0, 98, 8, 93, 3, 77, 4, 48, 
    2, 76, 3, 78, 0, 33, 6, 16, 1, 83, 7, 50, 8, 99, 4, 14, 5, 58, 
    4, 61, 1, 77, 7, 63, 5, 24, 0, 30, 8, 86, 3, 61, 2, 15, 6, 47, 
    4, 54, 6, 52, 3, 66, 2, 39, 8, 91, 5, 18, 7, 89, 1, 46, 0, 12, 
    1, 62, 5, 50, 4, 67, 7,  2, 2, 46, 3, 70, 6, 38, 0, 66, 8, 86, 
    5, 65, 6, 32, 1, 11, 0, 43, 4, 35, 8, 82, 7, 93, 3, 32, 2, 85
  };
  const int q9630[] = {
    9, 9, // Number of jobs and machines
    2, 78, 8, 54, 3, 73, 0, 55, 5, 82, 7, 61, 6,  9, 4, 63, 1, 99, 
    3, 64, 7,  7, 0, 42, 5, 56, 2, 25, 6, 17, 1, 59, 4, 29, 8, 31, 
    1, 35, 3, 64, 4, 26, 6, 61, 8, 11, 5, 86, 2, 65, 0, 24, 7, 98, 
    8, 28, 3, 13, 2, 61, 0, 40, 4, 15, 7, 81, 6, 25, 5, 40, 1, 59, 
    1, 34, 8, 80, 6, 30, 5, 34, 2, 24, 4, 45, 3, 64, 7, 24, 0, 67, 
    4, 43, 5, 31, 6, 77, 0, 79, 1, 16, 2, 79, 8,  7, 3,  4, 7, 67, 
    2, 73, 3, 41, 5, 36, 4,  8, 8, 60, 0, 26, 7, 91, 6,  6, 1, 93, 
    2, 28, 0, 45, 4, 91, 3, 29, 8,  5, 5, 39, 6, 56, 7, 46, 1, 91, 
    4, 33, 5, 14, 6, 33, 7, 60, 0, 40, 3, 59, 8, 72, 2, 86, 1, 62
  };
  const int q9631[] = {
    9, 9, // Number of jobs and machines
    5, 14, 2, 65, 6, 96, 3, 77, 1, 69, 4, 17, 7, 36, 8, 62, 0, 80, 
    0, 73, 7, 50, 4, 63, 8, 61, 2, 36, 3, 12, 5,  1, 1, 92, 6, 60, 
    2, 86, 6, 76, 8, 68, 5, 73, 3, 48, 1, 53, 4, 68, 7, 33, 0, 48, 
    6, 96, 4, 22, 0,  5, 5, 52, 8, 52, 7, 31, 2, 66, 3, 62, 1, 45, 
    5, 84, 4, 58, 2, 94, 0, 87, 8, 20, 1, 51, 7, 76, 6, 79, 3, 23, 
    8, 18, 7,  5, 6, 42, 5, 88, 2, 48, 0, 53, 4, 81, 3, 21, 1, 56, 
    4, 29, 2, 61, 1, 83, 5, 36, 0, 11, 3, 70, 7, 63, 8, 66, 6, 67, 
    4, 93, 5, 47, 0, 99, 6, 56, 7, 78, 2, 39, 3, 50, 1, 50, 8, 97, 
    5,  1, 6, 77, 4, 80, 2, 40, 1, 96, 3, 49, 8, 99, 0, 70, 7, 66
  };
  const int q9632[] = {
    9, 9, // Number of jobs and machines
    0, 49, 2, 93, 6, 22, 4, 61, 1, 48, 3, 80, 7,  3, 5, 23, 8, 53, 
    1, 78, 6, 52, 2, 30, 7, 62, 3, 21, 4, 83, 5, 46, 0, 22, 8,  9, 
    6, 12, 7,  3, 8, 28, 2, 15, 5, 81, 3, 65, 1, 97, 4, 94, 0, 41, 
    5, 87, 7, 42, 0, 73, 6, 76, 8, 55, 3, 53, 1, 23, 2, 73, 4, 73, 
    8, 81, 1, 60, 4, 97, 0, 77, 7, 77, 6, 69, 3, 51, 5, 86, 2,  5, 
    1, 31, 7, 31, 2, 89, 5, 78, 6, 47, 3, 96, 8, 81, 4, 81, 0, 12, 
    0, 34, 1, 93, 7, 63, 8, 88, 2, 16, 6, 72, 4,  8, 3, 63, 5, 32, 
    2, 69, 5, 52, 4, 82, 7, 19, 1, 87, 6, 92, 0, 33, 3, 25, 8, 81, 
    4, 29, 6, 46, 3, 54, 8, 21, 1, 55, 5, 56, 7,  2, 2, 45, 0, 23
  };
  const int q9633[] = {
    9, 9, // Number of jobs and machines
    6, 34, 8, 34, 2, 20, 3, 16, 0, 25, 1, 72, 5, 31, 7, 33, 4, 41, 
    6, 44, 4, 42, 1, 19, 5, 40, 2, 30, 0, 64, 8, 19, 3, 74, 7, 94, 
    2, 76, 8, 48, 7, 51, 3, 54, 6, 10, 5, 57, 1, 28, 0, 22, 4, 74, 
    7, 18, 0, 46, 2, 28, 8, 83, 5, 28, 3, 56, 1,  7, 6, 76, 4, 66, 
    5, 28, 0, 17, 6, 48, 2, 86, 1, 66, 8, 29, 7, 54, 3, 23, 4, 17, 
    1, 53, 0, 25, 5, 45, 3, 80, 2, 71, 8, 63, 4, 93, 7, 56, 6, 83, 
    2, 48, 4, 53, 3, 67, 6, 46, 7, 64, 8, 51, 5, 61, 0,  6, 1, 24, 
    5, 31, 1, 39, 3, 18, 6, 21, 7, 49, 0, 55, 8, 85, 4, 51, 2, 62, 
    8, 99, 6, 79, 5, 18, 3, 20, 2,  7, 1, 75, 4, 92, 0,  2, 7, 75
  };
  const int q9634[] = {
    9, 9, // Number of jobs and machines
    2, 80, 1, 16, 4, 43, 3,  7, 8, 99, 7, 79, 6, 73, 0, 79, 5, 31, 
    0, 61, 4, 77, 7, 18, 8, 81, 3, 80, 5, 31, 2, 60, 1, 68, 6, 55, 
    8, 19, 2, 54, 5, 33, 1, 46, 3,  4, 6, 94, 0, 87, 7, 27, 4, 95, 
    6, 33, 5, 50, 0, 45, 1, 16, 3, 49, 2, 36, 8, 59, 7, 91, 4, 97, 
    5, 60, 1,  8, 2, 10, 8, 75, 0, 86, 6, 86, 4, 32, 3, 64, 7, 31, 
    8, 99, 1, 55, 3, 78, 7, 52, 4, 85, 2,  7, 6, 44, 5, 86, 0, 94, 
    5, 15, 1, 78, 8, 83, 3, 43, 7, 40, 6, 87, 0, 70, 4, 23, 2, 79, 
    1, 23, 8, 56, 2, 99, 0, 16, 5, 36, 3, 43, 6, 95, 7, 31, 4, 91, 
    1, 43, 2,  6, 6, 82, 3, 77, 5,  8, 4, 88, 8, 47, 7, 45, 0, 24
  };
  const int q9635[] = {
    9, 9, // Number of jobs and machines
    8, 59, 1, 45, 0, 21, 7, 96, 6, 88, 5, 86, 3, 82, 2, 67, 4, 65, 
    8, 46, 6, 13, 3, 30, 4, 97, 7, 30, 2, 49, 5, 15, 0, 33, 1, 61, 
    2, 90, 4, 67, 3, 63, 5, 44, 0, 46, 7, 64, 8,  9, 6, 66, 1,  9, 
    8, 40, 4, 43, 7, 24, 2, 80, 5, 45, 3, 41, 0, 58, 1, 81, 6, 64, 
    5,  9, 2, 47, 3, 28, 4, 21, 1, 80, 7, 78, 8, 25, 6, 70, 0, 65, 
    2, 16, 3, 51, 7, 28, 1,  2, 0, 19, 5, 83, 8, 24, 6,  3, 4, 61, 
    7, 89, 8, 44, 0, 85, 2, 52, 6, 41, 1,  1, 3, 18, 5, 95, 4, 68, 
    5, 22, 2, 65, 6, 22, 4, 47, 0, 35, 3,  8, 8, 77, 7, 38, 1, 45, 
    6, 14, 5, 79, 1, 55, 0,  7, 7, 83, 4, 86, 2, 61, 3, 86, 8, 84
  };
  const int q9636[] = {
    9, 9, // Number of jobs and machines
    6, 36, 3, 61, 7, 10, 4, 27, 8, 56, 5, 31, 0, 26, 1, 85, 2, 98, 
    8, 57, 3, 62, 5, 51, 6, 91, 7, 44, 4, 95, 1, 13, 0, 66, 2, 73, 
    1, 97, 6, 98, 7, 90, 4, 37, 0,  9, 5, 40, 8, 50, 3, 32, 2, 42, 
    3,  7, 2, 33, 5, 18, 6,  5, 1, 67, 0, 53, 4, 21, 7, 86, 8, 60, 
    3, 94, 6, 65, 8, 76, 5, 81, 2, 57, 4, 69, 7, 34, 1, 48, 0, 53, 
    2, 55, 8, 41, 3, 84, 7, 20, 4, 13, 5, 38, 1,  5, 6, 10, 0, 87, 
    6, 88, 7, 78, 5, 30, 8, 97, 3, 99, 4, 70, 1, 61, 0, 53, 2, 94, 
    6, 76, 0, 48, 1, 48, 7, 10, 5, 47, 8, 75, 4, 61, 2, 64, 3, 96, 
    7, 16, 3, 75, 8, 55, 1, 36, 4, 28, 5, 56, 2, 14, 0, 89, 6, 46
  };
  const int q9637[] = {
    9, 9, // Number of jobs and machines
    2, 81, 1, 34, 3, 16, 7, 36, 5, 62, 0, 69, 4, 37, 6, 84, 8, 30, 
    8, 91, 2, 57, 7, 75, 4, 27, 1, 75, 6, 75, 5, 22, 3, 34, 0, 21, 
    2, 38, 1, 29, 4, 27, 6, 98, 0, 67, 5, 31, 7, 31, 3, 24, 8, 16, 
    4, 17, 6, 51, 8, 35, 7, 55, 1, 85, 0, 59, 5, 43, 2, 38, 3,  1, 
    1,  4, 8,  3, 3, 94, 2, 13, 6, 82, 5, 89, 7, 22, 4, 65, 0, 85, 
    4, 90, 6, 55, 0, 96, 8, 36, 5, 24, 2, 39, 1, 96, 3, 98, 7, 64, 
    4, 15, 5, 25, 0, 49, 7, 54, 3, 15, 2, 80, 1, 54, 6, 91, 8, 19, 
    2, 45, 6, 20, 1, 75, 0, 35, 3, 59, 5, 84, 7, 78, 4, 28, 8, 84, 
    7, 42, 8, 20, 1, 34, 2, 48, 6, 97, 0, 22, 4, 71, 3, 26, 5, 67
  };
  const int q9638[] = {
    9, 9, // Number of jobs and machines
    5, 67, 2, 41, 3, 87, 1, 47, 6, 89, 7, 56, 8, 73, 4, 68, 0, 14, 
    1, 37, 0, 83, 7, 28, 6, 55, 5, 92, 2, 26, 3, 21, 4, 98, 8, 23, 
    4, 36, 7, 96, 8, 52, 2, 71, 3, 57, 6, 61, 5, 16, 1, 11, 0, 73, 
    0, 35, 4, 24, 7,  1, 6, 24, 8, 24, 3, 96, 5, 91, 2, 73, 1, 38, 
    8, 72, 3, 23, 1, 83, 5, 95, 0, 62, 4,  7, 6,  6, 7, 91, 2, 87, 
    2, 59, 0, 47, 5,  6, 3, 38, 4, 24, 1, 34, 6, 29, 7, 91, 8, 55, 
    8, 25, 7, 58, 2, 91, 5, 96, 3, 61, 4, 71, 0, 90, 6, 22, 1, 50, 
    3, 99, 0, 96, 5, 57, 8,  5, 7, 91, 2, 50, 6, 18, 4, 51, 1, 27, 
    3, 36, 4, 52, 6, 55, 8, 31, 5, 97, 0, 95, 2, 31, 1, 23, 7, 33
  };
  const int q9639[] = {
    9, 9, // Number of jobs and machines
    7, 94, 0, 12, 8, 70, 3,  9, 5, 60, 6, 89, 1, 28, 4, 35, 2, 13, 
    4, 12, 3, 14, 5, 92, 2, 71, 7, 80, 6, 52, 1, 73, 8, 29, 0, 85, 
    8, 89, 3, 96, 0,  3, 2, 46, 4, 46, 6,  5, 7, 10, 1, 37, 5, 21, 
    3, 26, 0, 45, 8, 18, 1, 81, 2, 24, 5, 61, 4, 33, 6, 63, 7, 72, 
    3, 31, 0,  2, 5, 61, 1, 73, 7, 15, 2, 82, 6, 35, 8, 87, 4, 39, 
    3, 33, 0, 41, 4, 15, 2, 95, 5, 55, 7, 74, 1, 75, 8, 74, 6, 51, 
    4, 95, 0, 59, 7, 62, 6, 58, 2, 91, 1, 38, 8, 20, 5, 75, 3, 23, 
    7, 31, 5, 68, 6,  1, 4, 50, 1, 74, 2, 91, 0, 33, 3,  3, 8, 22, 
    5, 58, 4, 73, 8, 45, 0, 92, 2, 10, 6, 33, 3, 36, 7, 64, 1, 20
  };
  const int q9640[] = {
    9, 9, // Number of jobs and machines
    2, 99, 4, 58, 0, 75, 6, 45, 1, 99, 8, 55, 7, 95, 3, 91, 5, 56, 
    2, 61, 7, 83, 6, 54, 8, 68, 5, 45, 1, 69, 0,  2, 3,  8, 4, 98, 
    2, 95, 4, 38, 0, 87, 1, 35, 7, 62, 5, 58, 8,  8, 3, 87, 6, 81, 
    0, 11, 7, 70, 8, 77, 5,  8, 1, 45, 4, 15, 2, 43, 6,  8, 3, 24, 
    0, 51, 6, 23, 1, 89, 4, 59, 5, 35, 3, 77, 2, 27, 7, 54, 8, 65, 
    8, 18, 1, 60, 7, 66, 0, 12, 6, 80, 5,  6, 3, 17, 4, 61, 2, 90, 
    1, 12, 0, 16, 2, 42, 4, 51, 6, 33, 8, 25, 5, 87, 3, 65, 7, 93, 
    4, 62, 8, 42, 6, 83, 1, 40, 2, 93, 0, 28, 5, 16, 7, 29, 3, 15, 
    3, 37, 1,  9, 0, 20, 5, 32, 2,  9, 4, 84, 6, 75, 7, 27, 8, 87
  };
  const int q9641[] = {
    9, 9, // Number of jobs and machines
    4, 56, 0, 36, 2,  8, 7, 68, 1, 66, 3, 87, 8, 13, 5, 80, 6,  3, 
    2, 16, 5, 93, 8, 87, 0, 38, 1, 95, 6, 39, 3, 69, 7, 35, 4, 21, 
    3, 19, 4, 36, 0, 77, 2, 61, 1, 30, 8, 36, 6, 23, 7,  1, 5, 56, 
    5, 14, 3, 61, 1, 45, 8, 39, 4, 98, 2, 17, 6, 26, 7, 88, 0,  5, 
    5,  4, 2,  5, 8, 14, 1, 41, 4, 36, 0, 69, 3, 83, 6, 68, 7, 41, 
    4, 44, 3, 42, 6, 76, 5, 55, 2, 64, 1,  1, 0, 36, 8, 61, 7, 57, 
    7, 28, 5, 98, 6,  2, 4, 38, 3, 83, 0, 74, 8, 13, 1, 71, 2, 97, 
    8, 49, 5, 65, 2, 54, 3, 38, 0, 99, 6, 10, 4, 80, 7, 65, 1, 97, 
    4, 34, 6, 58, 5,  4, 2, 16, 0, 40, 1, 12, 8, 94, 7, 87, 3, 18
  };
  const int q9642[] = {
    9, 9, // Number of jobs and machines
    2, 67, 6,  2, 7, 15, 4, 59, 0, 28, 5, 17, 8, 74, 1, 63, 3, 80, 
    2, 74, 3, 25, 8, 44, 5, 26, 4, 50, 1, 55, 7, 48, 6, 69, 0, 34, 
    4, 87, 2, 59, 5, 72, 3, 35, 1, 56, 6, 46, 7, 86, 0, 92, 8, 26, 
    2,  2, 6, 74, 5, 31, 0, 26, 3, 76, 7, 12, 1, 27, 4, 10, 8,  2, 
    0, 52, 8, 11, 3,  3, 2, 70, 7, 79, 5, 74, 4, 35, 1,  4, 6, 15, 
    4, 78, 0, 26, 5, 91, 2, 49, 7, 19, 1, 94, 3, 15, 8, 65, 6, 90, 
    6, 82, 3, 38, 5, 47, 7, 81, 8, 74, 4, 47, 2, 37, 1, 39, 0, 80, 
    0, 64, 8, 49, 2, 93, 4, 57, 5,  4, 7, 20, 6,  4, 1, 19, 3, 89, 
    5, 38, 6, 50, 1, 96, 7, 38, 4, 33, 0, 89, 8, 17, 3, 89, 2, 28
  };
  const int q9643[] = {
    9, 9, // Number of jobs and machines
    0, 18, 4, 19, 8, 89, 6, 96, 7, 34, 5, 58, 2, 11, 3, 94, 1, 52, 
    8, 32, 0, 52, 5, 57, 1,  2, 6, 35, 3, 68, 4, 26, 2, 40, 7, 43, 
    2, 28, 6, 71, 3, 80, 4, 21, 7,  5, 1, 55, 8, 77, 5, 37, 0, 97, 
    5, 34, 3, 35, 8, 94, 6, 60, 4, 14, 1, 92, 7, 52, 2, 45, 0, 14, 
    4, 59, 8, 58, 2, 32, 3, 34, 5, 33, 6, 51, 7, 19, 0, 30, 1, 73, 
    1, 50, 6, 97, 4, 60, 8, 83, 0, 42, 3, 91, 7, 48, 2, 30, 5, 64, 
    3, 70, 6, 14, 7, 62, 4, 36, 1, 29, 5, 89, 0, 92, 8, 34, 2, 39, 
    6, 86, 4, 39, 2, 12, 5, 55, 1,  8, 3, 73, 0,  1, 7, 26, 8, 24, 
    0, 15, 6, 28, 7, 61, 3, 83, 4,  7, 5, 79, 1, 18, 8, 33, 2, 84
  };
  const int q9644[] = {
    9, 9, // Number of jobs and machines
    0, 13, 7, 82, 4, 87, 2, 77, 1, 62, 8, 44, 5, 95, 3,  6, 6, 28, 
    7, 41, 4, 52, 5, 23, 1, 20, 2, 53, 3, 43, 8, 97, 6, 79, 0, 39, 
    6, 66, 7, 19, 4, 45, 2, 29, 1, 50, 5, 79, 0, 40, 8, 86, 3, 47, 
    3, 32, 7, 48, 6, 96, 8, 57, 4, 68, 1,  3, 2, 42, 0, 37, 5,  5, 
    8, 97, 5, 72, 3, 54, 2, 98, 4, 88, 0, 49, 6, 73, 1, 58, 7, 49, 
    3, 85, 4, 76, 0, 72, 5, 49, 8, 75, 1, 73, 6, 42, 2, 12, 7, 46, 
    1, 75, 5, 30, 4, 94, 8, 78, 7, 93, 3, 36, 0,  8, 2, 64, 6,  2, 
    0, 44, 4, 44, 8, 30, 2, 32, 1, 84, 7, 13, 3, 74, 6, 98, 5, 96, 
    5, 61, 6, 12, 8, 72, 4, 47, 0,  1, 3, 61, 1, 13, 2, 34, 7,  3
  };
  const int q9645[] = {
    9, 9, // Number of jobs and machines
    8, 53, 2, 23, 4, 11, 1, 48, 6, 19, 7, 12, 3, 16, 0, 63, 5, 71, 
    5, 44, 4, 83, 1, 80, 3, 12, 8, 49, 2, 52, 6, 60, 0, 70, 7, 75, 
    7, 75, 0, 39, 2,  1, 6, 12, 8, 54, 5, 74, 1, 69, 3, 99, 4, 27, 
    7, 64, 8, 13, 3,  8, 0, 94, 5, 23, 4, 27, 6, 28, 2, 59, 1, 85, 
    6, 22, 5,  8, 0, 21, 1, 23, 4, 35, 8, 79, 2, 89, 3, 12, 7, 62, 
    8, 45, 4, 15, 7, 32, 6, 18, 3, 78, 0, 19, 2, 73, 1, 58, 5, 69, 
    0, 72, 2, 75, 3, 83, 6, 10, 4, 44, 5, 42, 8, 44, 1, 90, 7, 68, 
    3, 26, 6, 88, 1, 23, 5, 48, 8, 82, 4, 85, 0, 52, 2, 40, 7, 58, 
    7,  5, 2, 31, 6, 82, 1, 94, 3, 30, 0, 82, 4,  3, 5, 24, 8, 78
  };
  const int q9646[] = {
    9, 9, // Number of jobs and machines
    5,  5, 1, 25, 4, 22, 0, 74, 2, 92, 3,  1, 7, 24, 6, 59, 8, 39, 
    4, 67, 6, 95, 3, 98, 8, 13, 0, 16, 2, 86, 1, 24, 7, 15, 5, 62, 
    4, 13, 3, 90, 0, 54, 8, 12, 1, 27, 5, 65, 6, 37, 7, 93, 2, 28, 
    2, 93, 1, 55, 3, 12, 5,  5, 6, 46, 0, 31, 4, 67, 8, 50, 7, 91, 
    5, 34, 4, 88, 7, 63, 6, 19, 2, 24, 3, 19, 0, 83, 8, 91, 1,  3, 
    4, 13, 3, 38, 5, 32, 0, 32, 7, 43, 2, 22, 1, 77, 6, 25, 8, 60, 
    6, 85, 8, 76, 0, 89, 7, 44, 3, 89, 4,  9, 2, 21, 5, 70, 1, 38, 
    7, 94, 1, 69, 5, 37, 6, 75, 8,  3, 0, 84, 2, 89, 3, 20, 4, 75, 
    7, 16, 6, 47, 0, 44, 4, 24, 3, 65, 5, 80, 1, 98, 2, 87, 8, 57
  };
  const int q9647[] = {
    9, 9, // Number of jobs and machines
    2, 53, 1, 42, 3, 27, 7, 75, 4, 17, 5, 30, 0, 21, 6, 60, 8, 38, 
    6, 75, 2, 87, 4, 35, 1, 75, 3, 44, 5, 93, 7, 51, 8, 97, 0, 42, 
    5, 47, 6, 38, 7,  4, 3, 47, 2, 53, 0,  6, 1,  3, 8, 44, 4,  8, 
    8, 55, 2, 71, 5, 55, 1, 39, 0, 35, 7, 10, 3, 81, 6, 73, 4, 62, 
    0, 85, 4, 38, 2, 80, 5, 98, 6, 46, 7, 36, 3, 64, 8, 30, 1, 67, 
    2, 81, 3, 56, 8, 45, 6, 22, 5, 80, 0, 49, 7, 22, 4, 63, 1, 56, 
    7, 21, 2, 21, 3, 13, 5, 58, 1, 87, 6, 32, 0, 56, 4, 29, 8, 31, 
    8, 83, 2, 42, 4, 66, 1, 12, 5, 55, 7, 57, 6, 43, 3, 56, 0, 53, 
    7, 56, 4, 47, 3, 41, 0, 35, 6, 57, 8, 36, 5, 23, 2, 53, 1, 23
  };
  const int q9648[] = {
    9, 9, // Number of jobs and machines
    7, 11, 5, 59, 8,  9, 2, 20, 0, 27, 4, 72, 3, 70, 6, 73, 1, 91, 
    7, 84, 1, 85, 4, 73, 6, 64, 2, 37, 3, 50, 0, 64, 8, 15, 5, 92, 
    8, 21, 1, 16, 0, 98, 6, 91, 5, 78, 7,  6, 3, 46, 2, 23, 4, 83, 
    1, 61, 5,  6, 0,  6, 7, 77, 8, 25, 4, 50, 6, 84, 2, 66, 3, 56, 
    5, 52, 7,  3, 8, 12, 1,  9, 0, 58, 3, 18, 2, 23, 4, 11, 6, 30, 
    8, 35, 4, 88, 2, 38, 3, 93, 7, 30, 5, 51, 0, 34, 6, 39, 1,  8, 
    0, 22, 6, 33, 1,  1, 4, 19, 2, 71, 3, 84, 8, 90, 5, 85, 7, 14, 
    2, 31, 5, 64, 4, 12, 0, 86, 6, 49, 1, 83, 3, 35, 8, 70, 7, 95, 
    7, 93, 4,  1, 2, 13, 8, 58, 0, 83, 1, 45, 3, 42, 5, 63, 6, 43
  };
  const int q9649[] = {
    9, 9, // Number of jobs and machines
    2, 32, 8, 30, 7, 87, 0, 50, 6, 43, 5, 37, 1, 95, 3, 64, 4, 51, 
    1, 37, 4, 87, 5, 85, 7, 65, 3, 44, 2, 67, 8, 56, 0, 78, 6, 30, 
    2, 87, 4,  4, 3, 80, 5, 21, 7, 86, 0, 33, 8, 83, 1, 48, 6, 22, 
    4, 65, 3, 31, 8, 18, 6, 85, 2,  2, 0, 73, 1,  6, 5, 29, 7, 11, 
    7, 71, 4, 61, 2, 66, 6, 15, 5, 82, 3, 50, 8, 63, 0, 96, 1, 19, 
    3, 89, 8, 25, 7, 79, 2, 28, 4, 24, 0, 59, 1, 79, 6,  4, 5, 32, 
    1, 38, 0, 38, 7, 92, 4,  9, 8, 44, 6, 72, 2,  1, 3, 43, 5, 60, 
    1, 78, 3, 29, 8, 74, 2, 13, 6, 38, 5, 37, 0,  9, 7, 37, 4, 87, 
    7, 26, 1, 71, 2, 16, 4, 30, 8, 17, 3, 92, 0, 82, 6, 29, 5, 78
  };
  const int q9650[] = {
    9, 9, // Number of jobs and machines
    5, 44, 7, 30, 2,  3, 6,  5, 8, 12, 3, 16, 1, 13, 4, 87, 0, 67, 
    3, 10, 5, 25, 0, 71, 8, 38, 6,  8, 4, 60, 2, 54, 7, 47, 1, 43, 
    6, 14, 1, 10, 8, 93, 0, 35, 5, 66, 7, 29, 3, 82, 4, 26, 2, 51, 
    5,  6, 6,  4, 8, 83, 7, 63, 1, 38, 0, 87, 2, 26, 4, 51, 3, 23, 
    3, 70, 7, 42, 8, 29, 1, 58, 4, 75, 6, 62, 2, 24, 5, 11, 0,  6, 
    8, 55, 2, 62, 7, 80, 6, 25, 5, 80, 0, 56, 1, 37, 3,  4, 4, 67, 
    0, 84, 4, 51, 7, 73, 3, 92, 1, 76, 8, 70, 6,  8, 5, 61, 2, 53, 
    4, 61, 7, 48, 3, 52, 0, 85, 1, 88, 2, 20, 6, 37, 8, 49, 5, 72, 
    6, 39, 8, 79, 0, 84, 5, 78, 7, 16, 2, 50, 1,  6, 4, 36, 3, 53
  };
  const int q9651[] = {
    9, 9, // Number of jobs and machines
    2, 49, 0, 40, 4, 99, 8, 43, 6, 74, 1, 37, 5, 30, 3, 24, 7, 89, 
    1, 22, 7, 69, 5, 98, 3, 42, 2, 17, 4, 12, 6, 60, 0, 96, 8, 63, 
    6, 88, 1, 43, 0,  1, 2, 57, 7, 30, 4, 65, 8, 96, 3, 93, 5, 28, 
    0, 66, 5, 13, 4, 32, 8, 54, 6, 35, 2, 94, 1, 12, 3, 45, 7, 11, 
    1, 46, 6, 21, 8, 45, 0, 76, 3,  4, 5, 66, 7, 47, 4, 89, 2, 10, 
    6, 65, 5,  2, 1, 13, 2, 28, 3, 68, 7, 69, 8, 69, 4, 28, 0, 11, 
    4, 70, 2, 83, 7, 79, 6, 72, 5, 61, 0, 37, 3, 10, 8, 64, 1, 70, 
    2, 61, 8, 80, 5, 29, 1, 26, 6, 49, 3, 26, 7,  5, 0, 61, 4,  4, 
    1, 49, 7, 74, 4, 76, 5,  9, 3, 34, 2, 43, 6, 63, 8, 72, 0, 88
  };
  const int q9652[] = {
    9, 9, // Number of jobs and machines
    2, 82, 3,  9, 7, 44, 5, 48, 8, 95, 4, 40, 6,  8, 0, 89, 1, 10, 
    2, 87, 3, 45, 8, 56, 4, 27, 6, 23, 1, 85, 7, 89, 0, 39, 5,  2, 
    1, 40, 7, 53, 4, 29, 8, 85, 2, 14, 0, 69, 6, 18, 3, 51, 5, 41, 
    7, 91, 6, 95, 2, 91, 4, 16, 5, 67, 3, 26, 8, 51, 1, 81, 0, 92, 
    1, 48, 0, 91, 8, 34, 4, 88, 5, 37, 3, 89, 6, 41, 7, 76, 2, 32, 
    5, 37, 0, 64, 1, 83, 8, 18, 2, 87, 6, 20, 4, 88, 7, 98, 3, 96, 
    8, 23, 0, 41, 3, 69, 6, 73, 2, 29, 4, 82, 5, 20, 1, 97, 7, 30, 
    3, 63, 5, 74, 7, 37, 0, 19, 8, 40, 1, 51, 6, 40, 2, 99, 4, 42, 
    3, 43, 0, 33, 6, 20, 7, 56, 1, 81, 4, 19, 2, 83, 8,  2, 5,  1
  };
  const int q9653[] = {
    9, 9, // Number of jobs and machines
    5, 44, 1, 36, 4, 32, 2, 57, 3, 42, 7, 89, 8, 80, 0, 38, 6, 79, 
    5, 48, 4, 55, 1, 13, 2, 67, 7, 96, 0, 40, 6, 49, 8, 36, 3, 86, 
    0, 40, 8, 73, 3,  5, 5, 34, 4, 15, 7, 73, 6, 33, 2, 84, 1, 86, 
    6, 42, 1, 76, 3, 31, 0,  3, 2, 84, 4, 84, 7, 75, 8, 31, 5, 55, 
    0, 59, 1, 86, 7, 66, 5, 76, 4, 67, 8, 18, 6, 17, 3, 70, 2, 10, 
    8, 36, 2, 11, 0, 57, 4, 29, 6, 41, 3, 95, 7, 74, 5, 42, 1, 97, 
    8, 43, 5, 80, 2, 12, 0, 95, 7, 56, 1, 44, 4,  4, 6, 93, 3, 24, 
    8, 29, 5, 18, 7, 89, 1, 19, 4, 65, 3, 64, 0,  7, 6, 86, 2, 62, 
    0, 71, 5, 85, 4,  1, 6, 37, 2, 50, 3, 73, 7, 37, 1, 68, 8, 99
  };
  const int q9654[] = {
    9, 9, // Number of jobs and machines
    7,  3, 1, 89, 5, 92, 4, 36, 6, 70, 0, 33, 2, 97, 3, 32, 8, 25, 
    2, 74, 4, 22, 7, 64, 0, 73, 6, 37, 1,  9, 8, 62, 3, 23, 5, 33, 
    8, 56, 3, 94, 6, 72, 5,  2, 4, 47, 7,  1, 1,  5, 2, 16, 0, 74, 
    7, 73, 2,  8, 1, 42, 5, 24, 0, 90, 3, 71, 4, 57, 6, 11, 8, 22, 
    2,  6, 4, 10, 6, 42, 3, 37, 8, 56, 0, 66, 7, 14, 5, 75, 1, 48, 
    8, 23, 5, 27, 2,  9, 6, 13, 0, 94, 1, 85, 3, 34, 4, 79, 7, 45, 
    0, 27, 7, 51, 1, 18, 2, 47, 8, 75, 3,  3, 6, 73, 5, 23, 4, 72, 
    3, 61, 1, 46, 0, 73, 6, 24, 2, 47, 8, 34, 5, 36, 4, 76, 7, 66, 
    6, 85, 8, 51, 0,  5, 1, 44, 7, 88, 4, 60, 2, 19, 3, 71, 5, 72
  };
  const int q9655[] = {
    9, 9, // Number of jobs and machines
    4,  5, 0, 63, 7, 30, 6, 49, 1, 26, 5, 15, 8, 36, 2, 71, 3, 98, 
    1, 81, 3, 74, 8, 30, 2, 44, 4, 62, 6, 43, 0, 45, 7, 92, 5, 14, 
    1, 93, 0, 23, 4, 68, 2, 82, 8, 34, 3,  5, 5, 50, 6, 86, 7,  9, 
    0,  8, 1, 21, 2, 20, 3,  9, 4, 32, 6, 97, 5, 23, 8, 38, 7, 94, 
    3, 43, 1,  4, 7, 76, 8, 77, 6, 52, 2,  1, 0, 75, 5, 95, 4, 47, 
    8, 27, 0, 44, 6, 35, 4, 32, 7,  6, 3,  8, 1, 85, 2, 73, 5, 13, 
    0, 55, 7,  5, 1, 50, 6, 69, 4, 40, 5, 78, 8, 51, 2, 34, 3, 76, 
    3, 55, 1, 56, 6, 54, 2, 73, 7, 49, 8, 40, 0, 32, 4, 67, 5, 82, 
    1, 94, 0, 54, 5, 50, 3, 41, 4, 72, 8, 47, 2, 14, 6, 33, 7, 79
  };
  const int q9656[] = {
    9, 9, // Number of jobs and machines
    3, 46, 8, 36, 7, 86, 2, 88, 1, 93, 0, 27, 6, 17, 4, 62, 5, 72, 
    3, 92, 6, 66, 5, 70, 4, 87, 2, 94, 7, 16, 0, 44, 1, 26, 8, 39, 
    4, 89, 5, 10, 8, 15, 3, 41, 0, 88, 2, 84, 6, 55, 7, 16, 1, 93, 
    6, 61, 7, 62, 2, 77, 1,  9, 4, 99, 0, 71, 8,  6, 3, 86, 5, 69, 
    4, 55, 6, 40, 7, 64, 3, 56, 5, 70, 0, 81, 1, 55, 8, 70, 2, 81, 
    4, 66, 5, 91, 1, 47, 8, 74, 2, 72, 0, 34, 7, 25, 6, 96, 3, 69, 
    4, 45, 2, 24, 8,  5, 6, 42, 7, 35, 3, 57, 1, 20, 5, 59, 0, 12, 
    4, 83, 8, 19, 3,  4, 6, 12, 2, 81, 5, 97, 1, 30, 0, 33, 7, 45, 
    5, 30, 4, 58, 3, 70, 2, 96, 8, 81, 7, 91, 1, 52, 0, 21, 6, 34
  };
  const int q9657[] = {
    9, 9, // Number of jobs and machines
    2, 39, 8, 96, 0, 54, 3, 21, 4, 51, 6, 65, 7, 81, 5, 34, 1, 76, 
    0, 58, 8, 40, 2, 92, 6, 32, 5, 59, 1, 29, 3, 10, 7,  5, 4, 47, 
    8, 29, 3, 93, 1, 25, 2, 80, 0, 67, 6, 23, 5, 90, 4, 32, 7, 98, 
    7, 13, 2, 35, 1, 24, 0, 77, 5, 70, 4, 70, 8, 35, 3, 35, 6, 91, 
    0, 80, 6, 69, 4, 78, 5, 60, 8, 34, 1, 85, 7, 58, 3, 85, 2, 44, 
    3, 27, 7, 37, 0, 47, 1, 95, 8, 41, 6, 19, 4, 72, 5, 11, 2, 78, 
    5, 29, 7, 93, 6, 20, 2, 95, 3, 19, 1, 79, 0, 76, 4, 46, 8, 62, 
    0, 85, 6, 49, 7, 67, 3,  5, 4, 85, 1, 56, 8, 53, 5, 63, 2, 47, 
    3, 70, 2, 75, 5, 59, 4, 36, 6, 59, 7, 46, 8,  7, 1, 62, 0, 93
  };
  const int q9658[] = {
    9, 9, // Number of jobs and machines
    4, 37, 7, 81, 0, 62, 8, 40, 5, 26, 1, 73, 2,  1, 3, 21, 6, 72, 
    5, 70, 2, 44, 1, 45, 0, 48, 8, 36, 3, 80, 4, 85, 7, 21, 6, 26, 
    0, 91, 5, 62, 1, 96, 3, 57, 2, 23, 6, 54, 7, 79, 4, 33, 8, 69, 
    0,  1, 5, 85, 2, 79, 4,  8, 8, 92, 6, 51, 1, 68, 3, 24, 7,  2, 
    8,  8, 4, 17, 6, 63, 5, 64, 1, 43, 0, 11, 2, 70, 3, 37, 7, 70, 
    5, 71, 4, 31, 6, 70, 0, 38, 1, 75, 7, 20, 3, 12, 2, 98, 8, 53, 
    3, 16, 8, 90, 6, 10, 5, 90, 1, 30, 4, 20, 7, 57, 0, 91, 2, 95, 
    4, 72, 1,  9, 7, 94, 3, 58, 8, 44, 5, 86, 0, 11, 6, 90, 2, 12, 
    7, 38, 2, 22, 6, 40, 3, 19, 8, 70, 1,  3, 4, 77, 0, 44, 5, 92
  };
  const int q9659[] = {
    9, 9, // Number of jobs and machines
    4, 55, 7, 98, 1, 10, 2, 82, 0, 31, 6,  7, 5, 62, 3, 16, 8, 22, 
    6, 89, 2,  8, 8, 71, 1, 87, 7, 10, 4,  4, 0, 86, 5, 52, 3, 34, 
    7, 92, 3, 54, 4,  5, 5, 18, 2, 63, 6, 32, 8, 43, 0, 20, 1, 54, 
    0, 93, 8, 58, 6, 36, 5, 59, 3, 31, 1,  7, 2, 58, 7, 68, 4, 65, 
    1, 89, 7,  8, 3,  2, 8, 52, 2, 54, 6, 92, 0, 60, 4, 94, 5, 81, 
    0, 72, 2, 50, 8, 17, 5, 51, 3, 67, 7, 49, 1, 15, 4, 91, 6, 14, 
    4, 90, 8,  1, 7, 21, 0, 49, 6, 95, 5, 87, 2, 73, 1,  2, 3, 30, 
    4, 47, 3,  3, 8, 14, 0, 88, 7, 45, 2, 88, 6, 67, 1, 25, 5, 65, 
    2, 55, 3, 57, 6, 21, 0, 16, 5, 70, 7, 21, 8, 20, 4, 46, 1, 24
  };
  const int q9660[] = {
    9, 9, // Number of jobs and machines
    2, 29, 0,  6, 1, 87, 6, 37, 4, 65, 3, 65, 5, 36, 8, 76, 7, 85, 
    2, 13, 4, 34, 5, 57, 7, 27, 0, 39, 1, 68, 8, 21, 3, 27, 6, 92, 
    8, 85, 0, 87, 6, 48, 1, 29, 3, 90, 7, 50, 4, 13, 5, 38, 2, 55, 
    3, 91, 1, 94, 7, 66, 8, 46, 0, 68, 5, 10, 2, 43, 4, 75, 6, 59, 
    6,  5, 8, 66, 3, 23, 0,  3, 2, 57, 1, 92, 4, 95, 7, 58, 5, 47, 
    1, 43, 3,  7, 6, 16, 5, 79, 7, 26, 0, 67, 8, 91, 4, 97, 2, 68, 
    3, 31, 7, 72, 4, 19, 2, 23, 6, 62, 1, 33, 0, 33, 5, 59, 8, 80, 
    2, 13, 7, 49, 8, 81, 3, 32, 0, 26, 4, 50, 1, 14, 6, 36, 5, 45, 
    1, 37, 3, 94, 8, 65, 0, 70, 2, 90, 6, 10, 5, 34, 7,  5, 4, 38
  };
  const int q9661[] = {
    9, 9, // Number of jobs and machines
    8,  9, 7, 46, 4, 73, 3,  5, 2, 29, 0, 42, 6, 29, 1, 62, 5, 26, 
    0, 96, 4, 43, 1, 51, 7, 90, 3, 71, 2, 95, 5, 61, 8, 30, 6, 64, 
    4, 14, 2, 70, 7, 64, 8, 99, 1,  8, 5, 83, 6, 44, 0, 76, 3, 41, 
    5, 75, 3, 97, 8, 69, 6, 80, 4, 34, 0, 59, 2, 33, 7, 35, 1,  7, 
    7, 69, 4, 84, 8, 30, 2, 24, 5, 81, 6,  4, 0, 43, 3, 84, 1, 31, 
    5, 90, 0, 66, 2, 51, 3, 96, 1,  7, 8, 39, 7, 86, 4, 58, 6, 64, 
    3, 48, 6, 33, 1,  9, 0, 25, 5, 14, 7, 47, 2, 50, 4, 39, 8, 43, 
    8, 39, 6, 64, 1, 62, 2, 87, 3, 45, 7, 90, 0, 17, 4, 92, 5, 94, 
    2, 35, 4, 38, 0, 22, 5, 59, 3, 45, 6, 48, 7, 47, 8, 15, 1, 13
  };
  const int q9662[] = {
    9, 9, // Number of jobs and machines
    7, 12, 4, 64, 3, 64, 5, 73, 8, 46, 6, 26, 1,  1, 2, 75, 0, 19, 
    3, 70, 8, 25, 2, 17, 6, 80, 1, 78, 7, 29, 5, 37, 0, 96, 4, 32, 
    2, 43, 0, 81, 4, 90, 5,  4, 3,  1, 7, 89, 8, 32, 1, 86, 6, 64, 
    8, 82, 5, 42, 2, 22, 0, 88, 1, 14, 6, 92, 7, 13, 3, 50, 4, 10, 
    6, 75, 2, 47, 3, 90, 8, 39, 5, 40, 1, 26, 4, 60, 7, 81, 0, 48, 
    3, 68, 6, 72, 0, 21, 8, 79, 4, 81, 7, 94, 1,  2, 5,  1, 2, 77, 
    6, 58, 1, 69, 7,  1, 3, 38, 8, 60, 4, 34, 5, 97, 2, 94, 0, 18, 
    1, 32, 3, 72, 8, 97, 2, 51, 6, 27, 7, 74, 0, 62, 5, 65, 4, 17, 
    3, 76, 5, 30, 4, 48, 1, 52, 7, 57, 8, 80, 6, 49, 0, 56, 2, 53
  };
  const int q9663[] = {
    9, 9, // Number of jobs and machines
    1, 35, 6, 83, 0, 79, 8, 73, 5, 44, 7, 66, 3, 68, 2, 78, 4, 61, 
    8, 24, 6, 79, 4, 27, 5, 19, 3, 98, 0,  2, 7, 26, 1, 41, 2, 67, 
    0, 97, 4, 29, 1, 72, 5, 42, 2, 32, 6, 60, 7, 43, 8, 88, 3, 65, 
    4, 24, 5, 20, 7, 34, 1, 44, 8, 94, 6, 88, 0, 30, 2, 30, 3, 68, 
    4, 57, 0, 79, 6, 80, 8, 82, 1, 57, 3, 94, 2, 36, 7, 76, 5, 61, 
    8, 65, 7, 20, 1, 57, 2, 91, 5, 36, 4, 80, 3,  3, 0, 99, 6, 32, 
    5, 61, 6, 76, 3, 47, 2, 32, 8, 61, 4, 39, 1, 96, 0,  1, 7, 33, 
    1,  5, 5, 97, 4, 10, 6, 63, 3, 55, 2, 41, 7, 90, 8, 99, 0, 59, 
    6, 94, 7, 47, 3, 38, 4, 97, 0, 63, 1, 52, 8, 92, 5, 75, 2, 70
  };
  const int q9664[] = {
    9, 9, // Number of jobs and machines
    5, 51, 1, 61, 8, 77, 4, 81, 3, 66, 6, 73, 2, 15, 0, 19, 7, 72, 
    8, 87, 7, 35, 4, 24, 5, 74, 2, 96, 6, 52, 1, 58, 3, 58, 0, 70, 
    5, 47, 3,  9, 2, 63, 6, 79, 4, 96, 1, 64, 7, 91, 0, 63, 8, 17, 
    7, 71, 6, 27, 0, 30, 1, 81, 5, 55, 2, 31, 8, 45, 4, 45, 3, 22, 
    8, 57, 3, 81, 1, 93, 2, 35, 5, 23, 0, 25, 6, 81, 4, 80, 7, 80, 
    4,  6, 1, 47, 3, 53, 0, 11, 8, 72, 5, 25, 7, 58, 6, 70, 2, 65, 
    5, 64, 8, 24, 2, 42, 6, 99, 1, 11, 0,  2, 7, 33, 3, 73, 4, 95, 
    1, 69, 7, 35, 6, 28, 8, 21, 5, 33, 2, 34, 4, 48, 3, 87, 0, 35, 
    1, 50, 5, 25, 2, 94, 6, 89, 7, 91, 4, 50, 8, 87, 0, 14, 3, 15
  };
  const int q9665[] = {
    9, 9, // Number of jobs and machines
    0, 39, 6, 24, 8,  7, 3, 92, 4, 71, 5, 20, 1, 18, 7, 57, 2, 10, 
    8, 79, 7, 30, 5, 36, 6, 68, 3, 92, 4, 77, 1, 91, 0, 10, 2, 63, 
    6, 12, 7, 50, 3,  1, 5, 95, 0, 32, 1, 70, 2, 30, 8, 36, 4, 33, 
    8, 23, 3, 75, 5, 82, 4, 69, 2,  4, 1, 63, 0, 50, 6, 12, 7, 13, 
    3, 26, 5, 29, 6, 74, 8, 27, 1, 25, 2,  7, 4, 97, 0, 95, 7, 55, 
    0, 55, 7, 35, 1, 95, 4, 52, 8, 47, 6, 72, 5, 14, 2, 79, 3, 66, 
    7, 64, 8, 19, 2, 64, 6, 58, 3, 19, 0, 70, 1, 78, 4, 28, 5,  3, 
    8, 75, 3, 77, 2, 42, 4, 51, 7, 60, 6, 40, 5, 99, 0, 44, 1, 44, 
    5,  5, 7, 13, 3,  7, 6, 95, 0, 87, 8, 26, 1, 30, 4, 79, 2, 33
  };
  const int q9666[] = {
    9, 9, // Number of jobs and machines
    5, 62, 2, 46, 6, 82, 1,  8, 3, 22, 8, 33, 4, 75, 0, 92, 7, 88, 
    5, 28, 0, 66, 6, 88, 4, 84, 7, 57, 2, 20, 1, 75, 8, 30, 3, 71, 
    5,  8, 1, 54, 0, 35, 8, 72, 6, 88, 4, 51, 7, 86, 2, 35, 3, 37, 
    4, 90, 2, 94, 8, 74, 3, 69, 6, 57, 5, 10, 1, 65, 7, 99, 0, 59, 
    5, 76, 7,  7, 2,  4, 6, 48, 8, 70, 0, 53, 4, 53, 3, 21, 1, 77, 
    0, 75, 8, 57, 6, 76, 5,  2, 1, 88, 2, 58, 3,  8, 7, 30, 4, 82, 
    4, 31, 6, 77, 1, 72, 7, 59, 2, 92, 5, 91, 3, 59, 8, 59, 0, 44, 
    0,  5, 8, 88, 4, 43, 6,  1, 2, 77, 1, 64, 5, 65, 7, 58, 3, 74, 
    0, 67, 2, 99, 4, 60, 5, 99, 8, 22, 6, 64, 1, 32, 7, 23, 3, 82
  };
  const int q9667[] = {
    9, 9, // Number of jobs and machines
    2, 47, 3, 28, 8, 23, 7, 13, 0, 79, 4, 68, 1, 52, 6, 60, 5, 24, 
    8,  3, 2, 61, 4, 95, 6, 43, 1, 63, 5, 96, 7, 45, 0, 38, 3, 63, 
    5, 10, 6, 93, 7, 36, 8, 44, 2, 78, 4, 96, 1, 66, 3,  1, 0, 66, 
    1, 83, 5, 15, 3, 93, 2, 11, 6, 30, 7, 90, 0, 19, 8, 24, 4, 21, 
    7, 28, 5, 29, 2,  7, 1, 58, 0, 61, 4, 27, 3, 70, 8, 79, 6, 25, 
    0, 64, 3, 88, 2, 55, 4, 73, 6, 34, 7, 88, 8, 16, 5, 75, 1, 59, 
    1, 16, 8, 47, 6, 71, 4, 44, 3, 24, 5, 25, 0, 68, 2, 91, 7, 65, 
    4, 26, 0, 62, 6, 71, 1, 74, 2, 45, 3, 25, 5, 87, 7, 71, 8, 21, 
    0, 36, 6,  5, 4, 64, 5, 93, 2,  8, 7, 14, 1, 30, 8, 49, 3,  6
  };
  const int q9668[] = {
    9, 9, // Number of jobs and machines
    8, 58, 2, 37, 7,  9, 6, 48, 3, 51, 4, 25, 0, 74, 1, 71, 5, 97, 
    8, 10, 6, 86, 5, 63, 2, 87, 3, 52, 0, 88, 7, 68, 1, 40, 4, 18, 
    2, 13, 0, 96, 4, 25, 7, 80, 1,  9, 5, 66, 3,  8, 8, 85, 6, 68, 
    2, 31, 6, 81, 5, 74, 3, 97, 0, 80, 1, 94, 8, 50, 4, 22, 7, 48, 
    4, 19, 0, 72, 5, 33, 2, 86, 8, 67, 6, 20, 7, 32, 1, 44, 3, 34, 
    0, 46, 2, 61, 5, 82, 4, 18, 3, 98, 7, 26, 8, 73, 6, 17, 1, 22, 
    2, 65, 3, 24, 8, 49, 0, 25, 7, 58, 5, 83, 1, 18, 4, 49, 6, 68, 
    4, 27, 6, 90, 0, 33, 8, 46, 2, 54, 5, 46, 1, 16, 3, 64, 7, 18, 
    0, 89, 2, 13, 4, 17, 5, 65, 1, 38, 3, 57, 8, 98, 7, 31, 6, 63
  };
  const int q9669[] = {
    9, 9, // Number of jobs and machines
    7, 90, 1, 15, 3, 58, 4, 45, 6, 13, 0, 13, 2,  6, 5, 81, 8, 92, 
    0, 18, 5, 84, 2, 97, 6, 23, 7, 70, 3, 25, 1, 66, 4, 22, 8, 58, 
    2, 68, 0, 50, 8, 24, 7, 31, 5, 29, 4, 63, 3, 24, 1, 20, 6, 78, 
    4,  8, 6,  9, 2, 10, 3, 39, 0, 24, 8,  2, 1, 84, 7, 13, 5, 53, 
    3, 23, 4, 69, 1, 23, 0, 44, 6, 37, 7, 31, 8, 73, 5, 94, 2, 10, 
    5, 46, 7, 34, 4, 35, 3, 73, 6, 92, 2, 67, 0, 92, 8, 61, 1, 11, 
    5, 74, 0, 95, 6, 47, 2, 66, 8, 25, 7, 42, 4, 92, 1, 54, 3, 34, 
    2, 53, 8, 63, 6, 82, 4, 56, 5, 82, 1,  6, 3, 36, 0, 75, 7, 39, 
    8, 48, 4, 88, 6, 94, 7, 43, 1, 72, 2, 34, 0, 42, 5, 30, 3,  3
  };
  const int q9670[] = {
    9, 9, // Number of jobs and machines
    5, 45, 3, 15, 6, 32, 0,  9, 4, 53, 7, 28, 8, 42, 1, 38, 2, 21, 
    6, 44, 1, 27, 5, 50, 0, 42, 3, 61, 7, 73, 2, 40, 8, 45, 4, 30, 
    8, 39, 3, 40, 0, 95, 2, 34, 7,  8, 4, 27, 1, 95, 6,  4, 5, 93, 
    5, 19, 3, 23, 4, 91, 7, 67, 0, 68, 6, 39, 2, 40, 1, 12, 8, 96, 
    4, 56, 7,  5, 0, 50, 2, 72, 5, 90, 8, 31, 3, 89, 6, 52, 1, 32, 
    2, 95, 5, 82, 1, 26, 3, 66, 8, 59, 7, 63, 6, 29, 0, 24, 4, 37, 
    6, 72, 7, 89, 2, 84, 0, 77, 4, 17, 3, 13, 1, 31, 8, 83, 5, 86, 
    4, 81, 7, 46, 3, 32, 5, 47, 6, 49, 2, 90, 1, 60, 8, 47, 0,  8, 
    4,  2, 0, 39, 3, 41, 2, 18, 1, 87, 5, 78, 7, 20, 6, 30, 8, 14
  };
  const int q9671[] = {
    9, 9, // Number of jobs and machines
    3, 34, 6, 46, 4, 14, 7, 26, 1,  9, 0, 29, 5,  3, 8, 55, 2, 38, 
    3,  8, 0, 11, 8, 61, 7, 62, 6, 19, 5, 35, 2,  3, 1,  5, 4, 89, 
    3,  1, 6, 71, 8, 36, 1, 46, 4, 66, 5, 82, 0, 41, 7, 16, 2, 61, 
    4, 67, 7, 85, 8, 38, 1, 45, 0, 42, 6, 96, 5, 56, 3, 32, 2, 42, 
    4, 23, 5,  1, 7, 94, 0, 90, 8, 99, 2, 72, 6, 51, 1, 26, 3, 54, 
    8, 18, 7, 24, 5, 85, 2, 16, 4, 94, 1, 85, 6, 95, 3, 61, 0, 56, 
    4,  7, 6, 94, 7,  3, 3, 18, 0, 80, 2, 41, 5, 20, 8, 88, 1, 29, 
    2, 25, 5, 39, 4, 58, 8, 89, 3, 86, 1, 99, 7, 69, 0, 83, 6,  4, 
    6, 45, 5, 66, 2, 22, 8, 29, 7, 74, 4, 16, 3, 92, 0, 48, 1, 72
  };
  const int q9672[] = {
    9, 9, // Number of jobs and machines
    0, 93, 6, 99, 1, 56, 7, 12, 3, 11, 8, 65, 4, 49, 2, 96, 5, 11, 
    7, 34, 2, 23, 1, 95, 6, 41, 8, 71, 4, 32, 0, 45, 5, 93, 3, 70, 
    6, 28, 7,  8, 0, 30, 1,  9, 4, 66, 2, 65, 5, 94, 8, 19, 3, 40, 
    5,  7, 3, 22, 4, 82, 0, 79, 6, 45, 2, 93, 1, 74, 7, 77, 8, 81, 
    2, 65, 5, 49, 6, 18, 8,  6, 0, 67, 4, 60, 1, 82, 7, 83, 3, 50, 
    0, 24, 1, 28, 4, 98, 2, 46, 5, 83, 7, 30, 6, 89, 3, 36, 8, 79, 
    2, 20, 3, 54, 8, 57, 7, 56, 4, 64, 0, 71, 1, 42, 5, 96, 6, 27, 
    0, 68, 1, 59, 8, 40, 4, 95, 7, 97, 2, 10, 5, 87, 6, 50, 3, 40, 
    5, 90, 8,  9, 4, 42, 3, 40, 6, 34, 1, 61, 7, 20, 0, 92, 2, 52
  };
  const int q9673[] = {
    9, 9, // Number of jobs and machines
    0, 65, 2, 86, 3, 13, 5, 82, 4, 86, 7, 53, 6, 93, 8, 24, 1, 41, 
    6, 35, 0, 37, 7, 17, 5, 83, 1, 45, 2, 88, 4, 98, 3, 77, 8, 76, 
    3, 65, 6, 65, 1, 54, 5, 13, 0, 83, 8,  1, 2, 45, 4, 87, 7, 94, 
    2, 68, 8, 55, 0, 39, 5, 69, 6, 92, 3, 90, 7, 20, 4, 46, 1, 46, 
    5, 67, 0, 18, 8, 80, 7, 80, 4, 51, 1, 79, 6, 33, 3, 28, 2,  4, 
    7, 13, 5,  6, 3, 15, 8, 95, 1, 31, 4, 76, 2, 11, 6, 36, 0, 24, 
    8, 36, 7, 33, 4, 12, 2, 64, 1, 75, 3, 89, 6, 85, 5, 80, 0, 65, 
    7, 28, 1, 33, 3, 96, 0, 36, 5, 81, 4, 75, 2, 76, 8, 86, 6, 76, 
    1,  3, 5, 37, 7, 62, 8, 71, 6, 76, 4,  3, 2, 86, 0, 66, 3,  1
  };
  const int q9674[] = {
    9, 9, // Number of jobs and machines
    4, 72, 8, 75, 3, 49, 0, 29, 1, 84, 5, 59, 7, 98, 6, 15, 2, 82, 
    8, 21, 0, 35, 5, 43, 2, 43, 3, 26, 1,  4, 6, 25, 7, 34, 4, 46, 
    2,  2, 5, 87, 7, 55, 0, 67, 3, 19, 6, 66, 4, 95, 8, 22, 1, 75, 
    7, 60, 6, 13, 1,  6, 5, 25, 4, 69, 2,  1, 8, 78, 3, 31, 0, 66, 
    2, 38, 0, 33, 5, 91, 8,  5, 3, 66, 6, 15, 7, 52, 4, 64, 1, 77, 
    8, 30, 1,  2, 6, 59, 7, 29, 2, 17, 5, 11, 4, 41, 0, 56, 3, 24, 
    4, 58, 3, 91, 1,  9, 0,  6, 2, 98, 7, 61, 5,  1, 6, 58, 8, 65, 
    4, 40, 3, 56, 2, 88, 1, 21, 0, 15, 6, 99, 8, 53, 7, 95, 5, 62, 
    4, 89, 7, 54, 0,  1, 2, 18, 3, 51, 1, 84, 8,  1, 6, 60, 5,  6
  };
  const int q9675[] = {
    9, 9, // Number of jobs and machines
    4, 54, 3, 54, 8, 97, 7,  7, 0, 37, 5, 98, 2, 49, 6, 23, 1, 30, 
    3, 63, 4,  6, 0, 67, 5, 72, 7, 91, 1,  1, 2, 24, 6, 55, 8, 98, 
    2, 26, 7, 38, 6, 93, 5, 26, 3,  3, 1, 97, 0, 34, 8, 37, 4,  5, 
    2,  3, 1, 53, 8, 45, 5, 89, 3, 82, 6, 19, 7, 72, 0, 97, 4, 31, 
    7, 60, 6, 45, 2, 66, 1, 85, 3, 78, 4, 11, 8, 79, 0, 31, 5,  2, 
    3, 49, 8, 37, 6, 53, 0, 34, 1, 68, 4, 60, 5, 14, 7, 85, 2, 93, 
    0, 19, 8, 18, 1, 56, 6, 72, 2, 28, 4, 22, 7, 31, 5, 24, 3, 64, 
    3, 58, 8, 13, 6, 85, 2,  3, 7, 72, 0, 97, 4, 97, 5, 12, 1,  7, 
    3, 76, 6, 81, 4,  9, 8, 45, 5, 52, 1, 25, 7, 17, 0, 78, 2, 31
  };
  const int q9676[] = {
    9, 9, // Number of jobs and machines
    3, 94, 1, 94, 5, 80, 8, 31, 2, 86, 6, 57, 0, 13, 7, 85, 4, 40, 
    2,  6, 1, 89, 0, 52, 4, 81, 8, 92, 6, 85, 7, 68, 3, 71, 5, 63, 
    8, 24, 2, 55, 5, 12, 0, 85, 3, 16, 4, 85, 7, 60, 6, 24, 1,  4, 
    5, 33, 7, 87, 8, 38, 4, 78, 2, 25, 0, 73, 1, 10, 6,  8, 3, 55, 
    3, 93, 7, 50, 1, 12, 4, 66, 5, 46, 0, 17, 8,  1, 6, 23, 2, 52, 
    2, 45, 3, 53, 0, 72, 7, 75, 5, 56, 8, 24, 6, 30, 4, 31, 1, 59, 
    4, 65, 0, 66, 6, 49, 2, 97, 5, 73, 3, 10, 1,  5, 7, 65, 8, 55, 
    3, 28, 1, 32, 6, 67, 5,  7, 0, 25, 2, 93, 7,  9, 8, 27, 4, 86, 
    8, 46, 4, 48, 7, 72, 2, 57, 1, 67, 3, 26, 6, 13, 5, 31, 0, 35
  };
  const int q9677[] = {
    9, 9, // Number of jobs and machines
    1, 36, 7, 99, 0, 30, 5, 55, 8,  6, 2, 15, 6, 27, 3, 28, 4, 28, 
    4, 17, 1, 83, 2, 68, 5, 13, 6, 42, 8, 81, 7, 26, 0, 38, 3, 88, 
    4, 43, 2, 35, 8, 10, 1, 97, 3, 46, 6, 92, 0, 98, 5, 42, 7, 56, 
    4, 71, 7, 34, 2, 61, 0, 42, 8, 82, 6, 60, 1, 59, 5, 56, 3, 41, 
    3,  6, 6, 71, 5, 58, 8, 90, 2, 56, 4, 51, 0, 74, 7, 86, 1, 21, 
    8, 60, 6, 56, 5, 89, 4, 61, 2, 22, 7, 65, 3, 75, 0, 65, 1, 37, 
    6,  4, 5, 60, 4, 36, 7, 53, 8, 48, 2, 58, 0, 45, 1, 47, 3, 81, 
    0, 83, 4, 25, 6,  7, 1, 67, 7, 10, 2, 36, 5, 52, 8, 43, 3, 61, 
    5, 12, 1, 60, 4, 91, 6,  7, 8, 84, 0, 97, 7, 74, 2, 70, 3, 44
  };
  const int q9678[] = {
    9, 9, // Number of jobs and machines
    8, 17, 2, 21, 6, 33, 0, 54, 3,  5, 5, 27, 7, 57, 1, 93, 4, 10, 
    1, 60, 6, 72, 3, 80, 2, 83, 8, 68, 7, 76, 5, 33, 4,  1, 0, 34, 
    4, 95, 8,  1, 0, 42, 7, 84, 2, 60, 3, 63, 1, 50, 6, 39, 5,  3, 
    0, 45, 1, 30, 6, 13, 7, 82, 8, 93, 3, 56, 2, 46, 4, 32, 5, 38, 
    3, 78, 8, 56, 4, 18, 1, 64, 2, 77, 5,  9, 6, 49, 7,  6, 0, 29, 
    5, 13, 3, 71, 1, 99, 2, 21, 6, 35, 8, 36, 7, 13, 0, 37, 4, 42, 
    1, 55, 3, 33, 6,  6, 8, 23, 0,  5, 5, 68, 7, 82, 2, 97, 4, 69, 
    7,  3, 4, 45, 8, 74, 1, 61, 2, 77, 6, 58, 0, 83, 3, 54, 5, 33, 
    4,  8, 7, 86, 2, 44, 5, 41, 8, 96, 0, 16, 3, 51, 1, 17, 6, 21
  };
  const int q9679[] = {
    9, 9, // Number of jobs and machines
    8, 35, 1, 37, 5, 63, 4, 52, 7, 37, 0, 84, 2,  7, 6, 34, 3, 38, 
    2, 24, 7, 98, 3, 40, 4, 29, 1, 79, 6, 28, 8, 45, 5, 92, 0, 25, 
    5,  3, 6, 66, 8, 65, 3, 75, 4, 21, 0, 83, 1, 44, 7, 27, 2, 13, 
    2, 28, 6, 23, 5, 48, 3, 55, 8, 19, 1, 80, 4, 54, 0, 49, 7, 23, 
    2, 46, 4, 96, 3, 32, 0, 45, 6, 15, 7,  5, 5, 62, 1, 46, 8, 27, 
    5, 74, 0, 88, 2, 35, 1, 77, 6, 22, 3,  3, 4, 11, 8, 43, 7,  6, 
    3, 53, 4, 72, 8, 26, 1, 87, 7, 78, 2, 10, 0, 48, 6, 73, 5, 59, 
    1, 60, 5, 43, 0, 23, 4, 57, 8, 67, 2, 70, 6, 27, 3, 95, 7, 76, 
    7, 99, 6, 81, 2, 28, 3,  2, 4, 40, 0, 15, 1, 69, 5,  9, 8,  9
  };
  const int q9680[] = {
    9, 9, // Number of jobs and machines
    2, 55, 6, 53, 1, 86, 4, 11, 8, 72, 7, 52, 5, 55, 3, 48, 0, 38, 
    0, 18, 7, 58, 2, 86, 6, 39, 1, 78, 5, 58, 4, 21, 8, 89, 3, 81, 
    2, 43, 8, 11, 5,  2, 1, 19, 4, 12, 0, 83, 7, 42, 6, 74, 3, 50, 
    7, 88, 4, 76, 5, 43, 6, 40, 3, 85, 2, 59, 8, 53, 1, 32, 0, 45, 
    1, 83, 0, 47, 8, 42, 3, 14, 2, 72, 6, 85, 7, 64, 4, 44, 5, 16, 
    5, 49, 6, 62, 7, 87, 1, 12, 8, 52, 0, 58, 3, 52, 2, 74, 4, 63, 
    5, 25, 2, 86, 0, 74, 1, 86, 8, 29, 3,  1, 7, 26, 6, 86, 4, 32, 
    8, 51, 6, 51, 4, 51, 0, 36, 5, 69, 2, 68, 3, 25, 7,  1, 1, 60, 
    8, 12, 6, 22, 4, 73, 7, 95, 3,  3, 1, 88, 2, 24, 0, 62, 5, 24
  };
  const int q9681[] = {
    9, 9, // Number of jobs and machines
    6, 31, 5, 12, 8,  3, 1, 99, 7, 99, 2, 20, 0, 41, 4, 10, 3, 36, 
    7,  7, 0,  7, 1, 27, 8, 58, 6, 33, 3, 43, 4, 84, 5, 24, 2, 16, 
    6, 93, 3, 30, 1, 60, 4,  8, 5, 83, 2, 50, 7, 30, 8, 37, 0, 11, 
    3, 23, 7, 75, 8, 86, 1, 22, 6, 33, 2, 47, 4, 97, 5, 47, 0, 47, 
    2, 68, 5, 91, 4, 25, 6, 64, 0, 71, 1, 66, 7, 24, 8, 17, 3, 53, 
    8, 50, 0,  2, 7, 37, 1, 97, 3, 98, 6, 54, 2, 29, 4, 88, 5, 36, 
    8, 20, 1,  8, 4, 46, 6, 52, 2, 16, 0, 63, 3, 19, 7,  7, 5, 46, 
    1, 50, 5, 34, 4, 31, 3, 73, 0, 14, 8, 92, 6, 98, 7, 40, 2, 90, 
    5, 64, 1, 75, 0, 64, 3, 84, 6,  2, 8, 21, 2,  1, 4, 72, 7, 77
  };
  const int q9682[] = {
    9, 9, // Number of jobs and machines
    4, 43, 3, 59, 1, 87, 2,  6, 8, 24, 5, 72, 6, 55, 7, 67, 0, 74, 
    3, 95, 7, 30, 5, 84, 2, 41, 1, 59, 8, 31, 0, 85, 6, 26, 4, 76, 
    3, 86, 4, 17, 7,  9, 8, 81, 0, 87, 2, 46, 5, 16, 1, 21, 6, 92, 
    4, 42, 5, 59, 6, 96, 7, 56, 2, 41, 8, 14, 1, 91, 3, 43, 0, 82, 
    8, 81, 0, 15, 6, 80, 3, 29, 4, 30, 7,  1, 5, 10, 2, 50, 1, 50, 
    5,  7, 0, 59, 2, 13, 8, 47, 1, 64, 4, 96, 6, 60, 3, 38, 7, 18, 
    6, 21, 4, 99, 1, 43, 7,  6, 2,  8, 0, 33, 3, 42, 8, 88, 5, 70, 
    1,  1, 6, 63, 0, 59, 5, 56, 7, 33, 3, 77, 8, 67, 4, 72, 2, 67, 
    8, 59, 3, 72, 7, 56, 6, 28, 5, 86, 0, 70, 4,  3, 2,  2, 1, 72
  };
  const int q9683[] = {
    9, 9, // Number of jobs and machines
    0, 84, 7, 37, 3, 13, 2, 90, 5, 71, 1, 22, 4, 58, 8, 45, 6, 80, 
    1, 69, 3, 43, 6, 10, 2, 61, 0, 83, 8, 81, 4, 96, 5, 88, 7,  2, 
    3, 43, 7, 86, 8, 41, 2, 61, 0, 85, 5, 97, 6, 45, 1, 81, 4, 84, 
    6, 69, 2, 62, 7, 20, 0, 39, 8, 64, 5, 44, 3, 37, 4, 41, 1, 64, 
    4, 26, 6, 56, 3, 41, 8,  6, 7, 33, 5, 72, 0,  7, 2, 75, 1,  5, 
    3, 46, 5, 37, 7,  7, 1, 44, 0, 55, 6,  2, 4,  5, 8, 49, 2, 77, 
    3, 19, 8, 25, 0, 61, 7, 36, 1, 14, 4, 67, 6, 46, 5, 67, 2, 55, 
    6, 24, 7, 25, 1, 94, 3, 31, 8, 25, 2,  4, 0,  8, 4, 33, 5, 89, 
    5, 87, 7, 14, 2, 90, 8, 18, 4, 81, 1, 86, 3, 34, 0, 98, 6, 53
  };
  const int q9684[] = {
    9, 9, // Number of jobs and machines
    8, 60, 4, 93, 5, 95, 6, 62, 1, 21, 0, 67, 2, 46, 3, 44, 7, 87, 
    2, 68, 5, 57, 4, 95, 1, 55, 8, 66, 0, 37, 3, 93, 7, 34, 6, 10, 
    5, 26, 7,  5, 2, 71, 1, 88, 0, 67, 6, 63, 4, 51, 8, 25, 3, 18, 
    4,  6, 5, 64, 3, 15, 8, 21, 7, 48, 6, 38, 1, 51, 0, 64, 2, 86, 
    5, 94, 7, 42, 8, 63, 1, 95, 2, 84, 4, 72, 0, 57, 6, 19, 3, 35, 
    0, 23, 7, 53, 8, 11, 3, 60, 6, 78, 1, 35, 4, 10, 2, 46, 5, 43, 
    6,  2, 8, 33, 4, 23, 5, 55, 7,  6, 3, 94, 0, 49, 2, 11, 1, 34, 
    4, 75, 6, 46, 5, 83, 7, 40, 8, 97, 2, 67, 1, 27, 3, 86, 0, 66, 
    6, 26, 8, 14, 2, 87, 4, 63, 7, 81, 3, 88, 5, 64, 1, 77, 0, 65
  };
  const int q9685[] = {
    9, 9, // Number of jobs and machines
    4, 17, 0, 30, 7, 81, 2,  8, 3, 16, 6, 90, 1, 69, 8, 51, 5, 16, 
    6, 19, 8, 83, 1,  4, 7, 83, 4, 87, 2, 31, 3, 91, 0, 49, 5, 67, 
    5, 38, 2, 39, 7,  5, 0, 41, 6, 26, 8,  5, 3, 31, 4, 98, 1, 66, 
    2, 29, 6, 24, 8, 72, 0, 97, 3, 96, 5, 63, 7, 13, 4, 16, 1, 38, 
    3, 77, 2, 35, 0, 59, 6, 58, 8, 86, 4, 52, 1, 79, 7, 17, 5, 48, 
    7, 18, 8, 59, 1, 63, 4, 91, 0, 83, 5, 89, 3, 75, 2, 16, 6, 27, 
    7, 38, 4, 45, 0, 11, 5, 83, 6, 51, 2, 95, 1, 25, 8, 72, 3, 30, 
    3, 69, 0, 12, 8,  7, 4, 88, 7, 44, 5, 84, 2, 62, 1, 47, 6,  4, 
    7, 98, 5, 34, 3, 68, 1, 28, 0, 15, 8,  3, 2, 35, 4, 98, 6, 45
  };
  const int q9686[] = {
    9, 9, // Number of jobs and machines
    8, 86, 5, 66, 4, 63, 7, 85, 3, 21, 1, 34, 6, 64, 0, 39, 2, 80, 
    7, 41, 0, 25, 6, 30, 5, 64, 8, 72, 1, 48, 2, 38, 3, 22, 4, 81, 
    5, 96, 2, 35, 4, 57, 0, 72, 1, 14, 3, 59, 6, 39, 7, 12, 8, 86, 
    2, 75, 5, 97, 3,  1, 6, 86, 8, 35, 0, 91, 4, 15, 7, 81, 1, 58, 
    6, 48, 1, 51, 0, 11, 8, 10, 4, 99, 7, 14, 3, 37, 5,  4, 2, 75, 
    1,  7, 4,  6, 8, 53, 0, 84, 6, 74, 7, 94, 3, 57, 2, 38, 5, 13, 
    5,  8, 4, 19, 3, 41, 7, 34, 8, 26, 1, 13, 0, 61, 6, 95, 2, 88, 
    2, 99, 7, 55, 8, 62, 4, 59, 3, 96, 6, 16, 5, 86, 1,  6, 0,  7, 
    8, 51, 3, 14, 6,  3, 0, 19, 4, 27, 1, 80, 7, 57, 5, 16, 2, 43
  };
  const int q9687[] = {
    9, 9, // Number of jobs and machines
    4, 47, 0, 91, 7, 47, 5, 87, 8, 73, 6, 63, 2,  9, 3, 93, 1, 21, 
    2, 77, 6, 38, 4, 16, 5, 40, 7, 49, 8,  2, 0, 46, 1, 72, 3, 69, 
    3, 50, 4, 87, 6, 43, 7, 88, 8, 22, 0, 48, 1, 44, 5, 17, 2, 26, 
    1, 33, 6, 42, 3, 72, 4, 10, 0,  2, 8, 10, 5, 19, 7, 45, 2, 13, 
    4, 43, 8, 77, 1, 87, 6, 50, 5, 57, 7, 82, 2, 74, 0, 80, 3, 41, 
    2, 49, 5, 92, 3, 13, 1, 42, 4, 18, 8, 80, 0, 79, 6, 49, 7,  3, 
    7, 68, 0,  3, 6, 29, 4, 80, 2,  5, 1, 50, 5, 15, 8, 47, 3, 60, 
    4, 13, 2, 10, 7, 97, 3, 41, 1, 70, 8,  3, 6, 36, 5, 73, 0, 28, 
    3, 19, 6, 52, 5, 77, 0, 49, 8, 56, 2, 24, 4, 73, 7, 41, 1, 41
  };
  const int q9688[] = {
    9, 9, // Number of jobs and machines
    6, 61, 7, 54, 5, 50, 2, 22, 1, 94, 4, 66, 0, 50, 3, 55, 8, 84, 
    5,  8, 0, 84, 4, 41, 3, 93, 6, 40, 1, 59, 8, 14, 2, 20, 7, 95, 
    1, 92, 3, 71, 5, 29, 8, 19, 7, 78, 0,  7, 2, 78, 4, 61, 6, 16, 
    6, 94, 7, 57, 5, 58, 4, 25, 3, 18, 2, 26, 1, 84, 8, 89, 0, 69, 
    7, 43, 3, 51, 2, 20, 0, 47, 1, 20, 5, 88, 6, 23, 8, 83, 4, 32, 
    0, 32, 4, 47, 5, 15, 7, 83, 8, 87, 2,  1, 3, 42, 1, 57, 6, 28, 
    2, 52, 0,  9, 5, 95, 4, 70, 7, 79, 6, 38, 1, 97, 8, 90, 3,  4, 
    4, 86, 8, 71, 2, 43, 6, 88, 7, 78, 1, 35, 3, 91, 5, 19, 0, 42, 
    3, 65, 2, 54, 0, 63, 7, 24, 8, 57, 1, 81, 5, 11, 4, 14, 6, 97
  };
  const int q9689[] = {
    9, 9, // Number of jobs and machines
    3, 36, 6, 61, 0, 36, 5, 53, 2, 94, 4, 90, 8, 44, 1,  2, 7, 10, 
    1, 41, 3, 86, 0,  3, 2, 19, 8, 44, 5, 45, 7, 48, 4, 37, 6, 75, 
    7, 10, 0, 34, 2,  9, 5, 17, 3, 78, 1,  4, 6, 15, 4, 59, 8, 11, 
    3,  9, 6, 91, 0, 23, 8,  7, 5, 11, 1, 88, 4, 73, 2, 85, 7, 89, 
    0, 38, 3, 61, 6, 38, 7, 58, 2,  6, 4, 82, 8, 74, 1, 49, 5, 16, 
    6,  1, 7, 96, 4, 41, 1, 58, 2, 61, 0, 33, 3, 67, 8, 28, 5, 14, 
    1, 20, 8, 73, 2, 88, 4, 32, 7, 31, 5, 41, 6, 79, 0, 47, 3, 55, 
    8, 49, 7, 25, 0, 86, 6, 77, 4, 99, 2, 86, 1, 85, 3, 90, 5, 84, 
    3, 16, 0, 69, 2, 29, 5, 94, 1, 64, 8, 60, 6, 55, 7, 82, 4, 75
  };
  const int q9690[] = {
    9, 9, // Number of jobs and machines
    0, 13, 3, 36, 4, 46, 1, 27, 5, 60, 6, 84, 8, 64, 2, 73, 7, 74, 
    0, 14, 6, 55, 1, 61, 7, 64, 2, 38, 5, 25, 8, 33, 4, 39, 3, 60, 
    2, 33, 5, 41, 8, 47, 7, 28, 1, 53, 3, 62, 4, 69, 6, 60, 0, 34, 
    3, 66, 0, 59, 1,  4, 5, 79, 4, 14, 8, 66, 6,  9, 7, 79, 2, 37, 
    8, 83, 1, 73, 2, 86, 4, 77, 3, 70, 6, 91, 7, 43, 5, 92, 0, 42, 
    3, 76, 1, 81, 2, 35, 5, 37, 7, 96, 8, 46, 4, 75, 6, 95, 0,  2, 
    7, 12, 8, 98, 0, 32, 2, 13, 4, 54, 6, 12, 5, 62, 3, 39, 1, 21, 
    6, 45, 2, 61, 4, 75, 0,  3, 7, 12, 8, 74, 1, 49, 5, 78, 3, 70, 
    7,  8, 2, 13, 0, 80, 8, 97, 6, 99, 5,  2, 1, 11, 3, 25, 4, 15
  };
  const int q9691[] = {
    9, 9, // Number of jobs and machines
    4, 31, 2, 48, 6, 69, 1, 52, 0, 36, 3, 67, 7, 96, 8, 73, 5, 89, 
    3, 78, 2, 88, 4, 76, 5, 72, 8, 47, 0, 72, 6, 38, 7, 25, 1, 22, 
    8, 90, 0, 48, 6, 70, 7, 60, 3,  1, 2, 47, 5, 49, 1,  5, 4, 23, 
    6, 20, 5, 79, 7, 49, 3, 91, 4, 51, 2, 62, 8, 10, 0, 91, 1, 38, 
    3, 67, 7, 63, 6, 41, 8, 85, 2, 69, 4, 42, 1, 54, 0, 18, 5, 40, 
    6, 63, 8, 36, 5, 59, 3, 21, 0, 67, 1, 78, 4, 18, 2, 75, 7,  6, 
    4, 81, 5, 28, 3, 38, 2, 10, 8, 89, 0,  5, 1, 29, 7, 15, 6, 28, 
    5, 93, 7, 77, 6, 33, 0, 58, 4, 31, 1, 60, 2, 75, 3, 59, 8, 69, 
    4, 26, 6, 15, 3, 13, 7, 70, 8, 65, 1, 66, 0, 34, 5, 92, 2, 63
  };
  const int q9692[] = {
    9, 9, // Number of jobs and machines
    6, 36, 0, 76, 8, 81, 5, 52, 2, 15, 1, 56, 7, 90, 3, 23, 4, 95, 
    1, 32, 3, 77, 8, 51, 2, 31, 7, 82, 4, 63, 6, 12, 0, 20, 5, 69, 
    5, 86, 8, 44, 0, 99, 2, 98, 4, 69, 1, 59, 3, 26, 7, 91, 6, 88, 
    3, 70, 2, 92, 1, 94, 7, 55, 6, 62, 8, 52, 5, 71, 4, 84, 0, 99, 
    8, 83, 4, 18, 7, 76, 3, 43, 6, 83, 1, 18, 5, 76, 2, 56, 0, 33, 
    4, 40, 0, 12, 2, 57, 5, 66, 6, 88, 7,  9, 1,  6, 8, 46, 3, 39, 
    7, 45, 5, 41, 6, 28, 3, 88, 8, 39, 4, 94, 1, 63, 0, 78, 2, 42, 
    4, 81, 2, 55, 0, 98, 8, 47, 3, 26, 7, 35, 6, 92, 5, 96, 1, 10, 
    8, 70, 7, 73, 2, 10, 1,  4, 4, 60, 0, 92, 5, 19, 3, 98, 6, 67
  };
  const int q9693[] = {
    9, 9, // Number of jobs and machines
    7, 83, 1, 82, 8, 86, 5, 17, 6,  5, 0, 57, 3, 79, 4, 38, 2, 41, 
    8, 56, 4, 94, 7, 27, 0, 28, 6, 91, 3, 50, 1, 84, 2, 20, 5, 31, 
    3, 28, 0,  5, 8, 96, 2, 46, 4, 44, 5, 26, 7, 11, 6, 18, 1, 25, 
    8, 54, 2, 83, 7, 82, 5, 53, 4, 71, 6, 54, 3, 72, 0, 82, 1, 50, 
    7, 95, 6, 16, 4,  1, 0, 17, 8, 98, 5, 89, 1, 43, 3, 98, 2, 74, 
    1, 62, 6, 75, 4, 28, 2, 53, 0, 63, 8, 20, 7, 60, 3, 44, 5, 46, 
    4, 99, 0, 92, 1, 15, 2, 41, 7, 77, 6, 98, 3, 15, 8, 29, 5, 89, 
    4, 36, 7, 20, 3, 81, 5, 90, 6, 93, 0, 28, 8, 79, 1, 97, 2,  7, 
    6, 57, 5, 51, 4, 27, 8, 38, 3, 19, 1, 62, 2, 14, 7, 33, 0,  5
  };
  const int q9694[] = {
    9, 9, // Number of jobs and machines
    1, 92, 8, 52, 5, 97, 4, 47, 7, 17, 3, 79, 0,  9, 2, 56, 6, 52, 
    0, 67, 4,  1, 5, 39, 6, 93, 8, 92, 7, 29, 3, 46, 2, 74, 1, 78, 
    0, 64, 5, 40, 2, 51, 4, 12, 7, 98, 1, 70, 8, 70, 3,  8, 6, 74, 
    1, 64, 2,  9, 7, 47, 5,  4, 6, 18, 0, 84, 3, 23, 8, 59, 4, 63, 
    3, 88, 0, 62, 6,  9, 4, 57, 5,  9, 2, 70, 8, 21, 7, 61, 1, 56, 
    2, 53, 5, 33, 0, 39, 4, 33, 1, 43, 8, 26, 7, 58, 6, 69, 3, 98, 
    1, 28, 7, 87, 8, 52, 3,  7, 4, 85, 6, 81, 5, 81, 2, 56, 0, 61, 
    8, 19, 3, 30, 4, 48, 0, 69, 7, 62, 5, 48, 2, 77, 1, 75, 6, 68, 
    4, 20, 6, 67, 0, 64, 7, 38, 1, 87, 5, 19, 8,  4, 2, 79, 3, 61
  };
  const int q9695[] = {
    9, 9, // Number of jobs and machines
    8, 43, 1, 36, 4, 25, 2, 36, 5, 87, 7, 58, 6, 55, 0, 90, 3, 56, 
    5, 27, 0, 83, 7, 42, 6, 42, 8, 78, 3, 31, 2, 70, 4, 91, 1, 23, 
    8, 22, 1, 90, 5, 24, 3, 85, 6, 16, 4, 92, 7, 63, 0, 60, 2, 42, 
    6, 12, 1, 83, 8, 13, 7, 62, 3, 96, 5, 27, 2, 15, 4, 72, 0, 48, 
    7, 68, 6, 89, 8, 82, 5, 24, 1, 48, 2, 15, 4, 24, 0, 93, 3, 80, 
    8, 35, 3, 17, 2, 91, 0, 54, 4, 81, 1, 17, 5, 64, 6, 70, 7, 64, 
    7, 22, 0, 46, 3, 64, 5, 39, 2, 21, 8, 24, 6, 53, 4, 94, 1, 73, 
    4, 29, 0, 85, 7, 23, 5, 84, 6, 42, 8, 12, 1, 86, 3, 21, 2, 16, 
    3, 37, 8, 84, 1, 41, 0, 75, 5, 67, 6, 42, 7, 50, 4, 92, 2, 38
  };
  const int q9696[] = {
    9, 9, // Number of jobs and machines
    5,  4, 2, 49, 6,  4, 7, 29, 1, 90, 3, 48, 0, 33, 4, 31, 8, 20, 
    2, 35, 5, 49, 3, 58, 6, 26, 1, 11, 8, 41, 7, 54, 0, 90, 4, 67, 
    2, 59, 8, 53, 0, 87, 3, 26, 6,  2, 4, 71, 7, 66, 5, 20, 1, 37, 
    1, 91, 6, 92, 7, 41, 3, 70, 4, 85, 0, 78, 5, 57, 2, 51, 8, 46, 
    6, 55, 4, 72, 7, 23, 3, 44, 5, 19, 2, 40, 1, 45, 0, 26, 8, 68, 
    7, 19, 8, 48, 5, 77, 0, 86, 2, 78, 3, 64, 6, 19, 1, 41, 4,  5, 
    4, 41, 8, 30, 5, 72, 7, 30, 2, 65, 0,  2, 6, 11, 1, 15, 3, 80, 
    8, 12, 0, 44, 6, 88, 2, 41, 3, 25, 4, 26, 5,  1, 7, 18, 1, 31, 
    3, 37, 0, 72, 1, 57, 8, 91, 7, 20, 5, 95, 4, 18, 2, 32, 6, 26
  };
  const int q9697[] = {
    9, 9, // Number of jobs and machines
    5,  3, 3, 63, 1, 19, 7, 20, 6, 33, 8, 34, 0, 96, 4, 64, 2, 63, 
    3, 98, 7, 13, 8, 17, 0, 56, 6, 10, 2, 36, 5, 10, 1, 33, 4, 30, 
    1, 65, 5, 33, 7, 32, 6, 15, 2, 80, 8, 53, 3, 18, 4, 71, 0, 71, 
    3, 76, 0, 61, 6, 60, 4, 81, 8, 70, 2, 78, 5, 86, 7, 81, 1, 19, 
    6,  5, 8, 89, 1,  1, 5, 18, 3, 67, 2, 50, 0, 85, 4, 41, 7, 18, 
    3,  1, 7, 16, 6, 51, 0, 33, 2, 32, 5, 83, 8, 76, 1, 35, 4, 63, 
    7, 69, 5, 16, 2, 45, 6, 36, 1, 20, 4, 66, 3, 13, 8, 40, 0, 60, 
    1, 82, 0, 50, 5, 11, 3, 86, 7, 65, 6, 27, 8,  6, 4, 53, 2, 61, 
    6, 89, 4, 99, 2, 76, 8, 72, 5,  3, 3, 27, 0, 22, 7,  8, 1, 58
  };
  const int q9698[] = {
    9, 9, // Number of jobs and machines
    6,  6, 7, 96, 0, 81, 5, 69, 1, 60, 8,  3, 2, 58, 3, 76, 4, 82, 
    4, 58, 0, 58, 7, 49, 3,  4, 5, 27, 8, 65, 2, 99, 6,  5, 1,  3, 
    4, 50, 5, 46, 3, 20, 0, 30, 1, 15, 8, 89, 7, 44, 6, 56, 2, 11, 
    5,  7, 0, 25, 3, 23, 6,  5, 4, 16, 7, 20, 8, 60, 2, 92, 1, 43, 
    1, 36, 2,  4, 7, 87, 0, 71, 6, 61, 4, 17, 8, 56, 5, 60, 3, 27, 
    8, 33, 2, 40, 4, 50, 7, 64, 5, 95, 0, 66, 3, 10, 1, 54, 6,  8, 
    5, 72, 8, 44, 6,  6, 7, 37, 1, 86, 2, 56, 3, 35, 4, 82, 0, 92, 
    8,  2, 6, 56, 7, 32, 5,  5, 0,  5, 2, 64, 1, 16, 4, 55, 3, 55, 
    0, 98, 2, 77, 5, 22, 3, 85, 7, 12, 6, 56, 1, 52, 8, 44, 4, 28
  };
  const int q9699[] = {
    9, 9, // Number of jobs and machines
    0, 31, 8, 82, 3, 12, 2, 69, 4, 59, 1, 35, 6, 84, 5, 45, 7,  5, 
    5, 69, 0, 68, 4, 88, 7, 37, 8, 90, 1, 72, 2, 22, 3, 14, 6, 41, 
    1, 56, 0,  8, 3, 10, 2, 82, 4, 70, 7, 64, 8, 74, 5, 39, 6, 27, 
    0, 37, 5, 23, 3, 73, 6, 24, 7, 66, 2, 21, 8, 88, 1, 32, 4, 57, 
    5,  4, 8, 38, 6, 92, 2, 38, 4, 54, 3, 67, 1, 77, 7, 70, 0, 73, 
    3, 75, 5, 92, 7, 55, 6, 24, 4, 68, 2, 49, 1, 31, 0, 97, 8, 96, 
    5, 90, 0, 60, 1, 43, 6, 23, 2, 53, 8,  9, 7, 65, 4, 93, 3, 87, 
    4, 82, 1, 77, 7, 74, 2, 74, 0, 14, 3, 59, 8,  9, 5, 89, 6,  9, 
    8, 71, 2, 64, 7, 92, 3, 86, 5,  3, 1, 72, 6, 97, 0, 65, 4, 46
  };
  const int q9700[] = {
    9, 9, // Number of jobs and machines
    1, 35, 7, 87, 6, 74, 3, 36, 0, 43, 2, 86, 4, 82, 5, 44, 8,  7, 
    5, 54, 7, 22, 3, 26, 8, 56, 2, 86, 6, 46, 1, 26, 4, 37, 0, 38, 
    1, 31, 0, 45, 6, 24, 4, 87, 5, 54, 3, 62, 8, 29, 7, 77, 2, 76, 
    3, 41, 2, 65, 8, 39, 4, 71, 7, 76, 5,  6, 0, 54, 6, 57, 1, 90, 
    3, 57, 5, 49, 4, 99, 2, 22, 6, 98, 0,  9, 1, 85, 8, 23, 7, 75, 
    4, 20, 8, 31, 5, 49, 0, 22, 1, 99, 6, 17, 2, 42, 7, 53, 3, 56, 
    2, 54, 5, 77, 1,  9, 0,  3, 8, 99, 6, 89, 3, 66, 4, 13, 7, 89, 
    6, 31, 4, 96, 7, 38, 8, 95, 2, 61, 0, 77, 3, 85, 1, 28, 5, 76, 
    7, 27, 8,  7, 6,  6, 4, 62, 5,  9, 0, 26, 1,  6, 3, 49, 2, 98
  };
  const int q9701[] = {
    9, 9, // Number of jobs and machines
    4, 20, 2, 84, 7, 21, 8, 99, 1, 44, 3, 57, 5, 40, 6, 38, 0, 79, 
    4,  3, 5, 73, 7, 15, 6, 24, 8, 30, 0, 72, 3, 67, 1, 83, 2, 42, 
    2, 60, 6, 97, 0, 68, 3, 88, 5, 28, 4,  7, 1, 80, 8, 92, 7, 22, 
    6, 39, 4, 72, 2,  1, 7, 35, 0, 87, 5, 68, 1, 14, 3, 21, 8, 56, 
    2, 44, 0, 19, 3, 38, 7, 18, 6, 67, 8, 25, 5, 16, 1, 37, 4, 20, 
    4, 67, 6,  3, 7, 28, 0, 23, 2, 14, 1, 52, 3, 59, 5,  1, 8, 27, 
    2, 92, 0, 33, 7, 79, 6, 74, 1, 34, 5,  2, 4, 59, 3,  5, 8, 79, 
    2, 45, 8, 28, 5, 28, 7, 30, 6, 84, 3, 37, 1, 64, 4, 94, 0, 46, 
    3, 95, 6, 62, 0, 92, 2, 29, 1, 69, 4,  1, 8, 95, 5, 19, 7,  6
  };
  const int q9702[] = {
    9, 9, // Number of jobs and machines
    2,  6, 4, 72, 6, 75, 1, 29, 3, 23, 0, 91, 5,  8, 7, 66, 8,  8, 
    0, 32, 7, 68, 4, 23, 8, 96, 1, 92, 3, 99, 2, 54, 6, 28, 5, 51, 
    1, 46, 8, 30, 2, 78, 5, 94, 6, 23, 4, 82, 0, 38, 7, 98, 3, 20, 
    5, 64, 8,  1, 1, 59, 6, 35, 3, 80, 2, 11, 4, 92, 7, 38, 0, 24, 
    5,  1, 1, 47, 3, 76, 0, 24, 2, 21, 8, 30, 4, 26, 7, 15, 6, 67, 
    4, 46, 7, 20, 3, 73, 6, 88, 2, 56, 0, 30, 8, 12, 5, 92, 1, 26, 
    3, 32, 0, 55, 4, 81, 5, 64, 8, 52, 7, 39, 1, 57, 2, 41, 6, 26, 
    7, 75, 5, 83, 3, 72, 1, 72, 4,  3, 0, 78, 8, 14, 2, 85, 6, 86, 
    2, 45, 5, 51, 0, 14, 7, 40, 4,  4, 3, 71, 6, 40, 1, 61, 8, 63
  };
  const int q9703[] = {
    9, 9, // Number of jobs and machines
    8,  6, 1, 25, 2, 47, 6, 71, 3, 10, 7, 39, 0, 61, 4, 78, 5, 40, 
    3, 81, 7, 51, 1, 11, 5, 24, 0, 29, 6, 30, 8, 21, 2, 75, 4, 18, 
    2, 17, 7, 27, 4, 43, 5, 33, 1, 60, 8, 12, 3, 25, 6, 44, 0, 11, 
    4, 21, 0, 51, 5, 15, 6, 83, 2, 49, 1, 56, 3, 10, 8, 52, 7, 45, 
    6, 69, 3, 74, 4, 66, 1, 35, 8, 90, 5, 19, 0,  1, 7, 29, 2, 59, 
    3, 16, 6, 62, 2, 65, 0,  8, 4, 30, 7, 79, 1, 55, 8, 20, 5, 92, 
    5, 82, 6, 51, 3, 76, 4, 64, 0, 38, 7, 72, 2, 93, 8, 71, 1, 70, 
    4, 56, 1, 22, 6, 74, 3, 57, 0, 74, 2, 82, 8, 40, 7, 75, 5, 45, 
    1, 64, 4, 14, 7, 80, 5, 65, 3, 24, 2, 71, 0, 81, 6, 80, 8, 88
  };
  const int q9704[] = {
    9, 9, // Number of jobs and machines
    2,  8, 5, 14, 3, 89, 1, 39, 7, 27, 0,  7, 4, 85, 6, 10, 8, 90, 
    5, 77, 0, 50, 3, 73, 7, 43, 2, 77, 1, 37, 4, 65, 6, 86, 8, 36, 
    6, 63, 1, 94, 4, 29, 0, 65, 7, 18, 8, 63, 2, 79, 3, 31, 5,  6, 
    3, 18, 8, 47, 2, 95, 1, 98, 7,  4, 6, 61, 0, 73, 4, 81, 5, 30, 
    4, 56, 2, 92, 8, 85, 6, 31, 5, 98, 1, 89, 7, 82, 0, 40, 3, 83, 
    8, 89, 7, 97, 3, 16, 1, 73, 2, 10, 6, 95, 5, 12, 0, 16, 4, 16, 
    4, 29, 3, 23, 1, 22, 2, 93, 7, 53, 5, 87, 8, 77, 0, 86, 6, 20, 
    1, 21, 2, 24, 0,  5, 3, 99, 6, 99, 4, 37, 7,  4, 5, 23, 8, 97, 
    6,  8, 1, 59, 0, 47, 5, 94, 8, 46, 4, 94, 2, 90, 7, 25, 3,  4
  };
  const int q9705[] = {
    9, 9, // Number of jobs and machines
    2, 55, 3, 12, 7, 90, 1,  1, 6, 93, 8, 24, 4, 98, 0, 40, 5, 92, 
    5, 20, 2, 62, 8, 77, 7, 64, 0, 72, 4, 50, 1, 75, 6, 63, 3, 25, 
    7, 21, 4, 90, 5, 24, 0, 65, 1, 71, 6,  7, 2, 74, 8, 63, 3, 64, 
    3, 85, 4, 59, 8, 50, 5, 20, 7, 25, 2, 27, 1, 72, 6, 30, 0,  7, 
    8,  7, 0,  6, 7, 70, 4, 37, 6, 71, 3, 96, 2, 84, 5, 41, 1, 16, 
    6, 56, 1,  6, 8, 73, 7, 86, 0, 68, 2, 45, 5,  7, 4, 34, 3,  8, 
    4,  6, 2, 50, 1, 91, 3, 74, 7, 53, 0, 51, 6, 29, 5, 40, 8, 34, 
    5, 59, 6,  8, 1, 31, 7, 98, 2, 39, 0, 21, 4, 64, 3, 55, 8, 43, 
    7, 32, 4, 12, 5, 76, 3, 64, 1, 46, 8, 42, 0, 22, 6, 96, 2, 27
  };
  const int q9706[] = {
    9, 9, // Number of jobs and machines
    7, 17, 3, 87, 5, 86, 0,  3, 2, 89, 8, 51, 4, 75, 6, 46, 1, 36, 
    6, 77, 2, 67, 8,  7, 7, 44, 0, 30, 5, 32, 4, 62, 3, 57, 1, 23, 
    2, 77, 1, 49, 5, 52, 7, 58, 6, 90, 8, 51, 0, 11, 4, 57, 3, 70, 
    3, 37, 8, 24, 6, 36, 0, 78, 5, 88, 7, 37, 1, 84, 2, 31, 4, 44, 
    4, 34, 0, 27, 8,  5, 3, 41, 1, 97, 5, 90, 7, 70, 6, 37, 2, 34, 
    1,  9, 7, 10, 3, 83, 0, 33, 2, 33, 4, 96, 6,  7, 8, 35, 5, 76, 
    3, 80, 5, 83, 8, 96, 7, 93, 4, 86, 2, 49, 6, 83, 1, 64, 0, 81, 
    6, 71, 8, 61, 7, 11, 2, 51, 0, 43, 4, 71, 1, 62, 5,  5, 3, 89, 
    7, 32, 4, 72, 0, 54, 2,  2, 5, 60, 3, 12, 1, 73, 6, 25, 8, 55
  };
  const int q9707[] = {
    9, 9, // Number of jobs and machines
    3, 86, 6, 90, 7, 44, 5, 83, 0, 88, 2, 95, 8,  2, 1, 41, 4, 22, 
    4, 76, 1, 56, 7, 27, 6, 31, 2, 60, 3, 79, 5, 74, 8, 78, 0, 61, 
    7, 62, 6, 82, 0, 33, 3, 53, 5, 45, 2, 96, 4, 39, 1, 60, 8, 31, 
    4, 11, 0, 30, 8, 34, 5, 26, 3, 57, 1, 59, 7, 23, 2, 61, 6, 96, 
    1, 73, 7, 53, 4, 50, 8, 98, 2, 53, 3, 96, 5, 33, 6, 73, 0,  6, 
    1, 79, 3, 46, 2, 36, 7, 19, 5, 42, 4, 18, 8, 59, 0, 18, 6, 84, 
    6, 39, 0,  9, 3, 56, 2, 18, 5, 43, 8, 46, 1, 46, 7, 93, 4, 20, 
    8, 58, 4, 90, 5, 91, 0, 98, 1, 57, 6, 68, 3, 89, 7, 76, 2, 91, 
    5, 65, 7, 10, 6, 46, 3, 24, 1,  5, 8, 83, 2, 74, 4, 47, 0,  9
  };
  const int q9708[] = {
    9, 9, // Number of jobs and machines
    5, 42, 2,  7, 1, 84, 8, 47, 0, 11, 4, 86, 6, 19, 3, 80, 7, 82, 
    2, 51, 6, 59, 5, 73, 8, 79, 7, 50, 3, 54, 1, 68, 4, 67, 0, 27, 
    4, 11, 3,  5, 7, 14, 5, 23, 8, 71, 6, 85, 1, 29, 0, 31, 2, 86, 
    0, 31, 7, 35, 1, 33, 3, 88, 4, 56, 6, 73, 5, 45, 8, 24, 2, 99, 
    3, 25, 1, 86, 4, 24, 2, 59, 0, 20, 6, 87, 5, 93, 7, 87, 8, 16, 
    7, 66, 4, 31, 3, 67, 0, 48, 2, 31, 6, 13, 1, 20, 5,  1, 8, 46, 
    2,  2, 1, 36, 6, 94, 8,  7, 3, 86, 4, 71, 0,  6, 5, 71, 7, 47, 
    2,  9, 1, 11, 6, 94, 5, 76, 7, 88, 3, 20, 4, 96, 0, 44, 8, 85, 
    6, 73, 2, 86, 7, 53, 8, 27, 0,  6, 4, 72, 1, 83, 5, 71, 3, 38
  };
  const int q9709[] = {
    9, 9, // Number of jobs and machines
    2, 90, 7, 26, 4, 79, 3, 34, 1, 22, 0,  5, 8, 56, 6,  5, 5, 82, 
    0, 84, 3, 97, 5, 79, 6, 25, 8, 99, 4, 86, 1, 38, 2, 98, 7, 70, 
    6, 66, 4, 45, 8, 40, 2, 72, 3, 29, 1,  7, 7, 19, 0, 65, 5, 65, 
    3, 38, 7, 20, 2, 88, 6, 96, 1, 23, 4, 65, 5, 40, 8, 41, 0, 66, 
    4, 31, 5, 48, 3, 16, 0, 21, 2, 73, 6, 62, 7, 71, 8, 33, 1, 30, 
    1, 15, 2, 27, 5, 35, 4, 35, 3, 97, 6,  3, 0, 38, 7, 89, 8, 61, 
    2, 17, 7, 73, 6, 23, 3, 48, 1, 49, 4, 59, 5, 45, 8, 31, 0, 41, 
    2, 32, 6, 67, 5, 94, 4, 43, 7, 93, 3, 82, 1, 95, 8, 24, 0, 82, 
    3, 69, 6, 21, 7, 41, 5, 53, 0, 53, 1, 56, 2, 34, 8, 76, 4, 78
  };
  const int q9710[] = {
    9, 9, // Number of jobs and machines
    5, 50, 0, 38, 7, 86, 4, 83, 8,  4, 3, 35, 2, 55, 1, 91, 6, 30, 
    2, 99, 6, 81, 0, 24, 5, 24, 7, 44, 1, 63, 4, 39, 8, 83, 3, 88, 
    5, 54, 0, 19, 4, 89, 3,  2, 2, 11, 7, 64, 8, 69, 1, 57, 6, 73, 
    2, 21, 5, 78, 6,  1, 0, 12, 4, 24, 7, 61, 1, 44, 8, 64, 3, 82, 
    5, 42, 4, 63, 2, 99, 6, 10, 0, 57, 8, 26, 1,  7, 3,  2, 7, 32, 
    4,  8, 0, 69, 7,  9, 1, 61, 6, 30, 3,  6, 5, 63, 8, 95, 2, 44, 
    2, 55, 6,  6, 0, 74, 8, 16, 1, 96, 7, 61, 3, 57, 4, 13, 5, 48, 
    7, 65, 1, 79, 8, 14, 2, 25, 6, 24, 0, 35, 5, 77, 3, 77, 4, 71, 
    6, 37, 4, 86, 5, 65, 7, 59, 1, 51, 0, 94, 8, 72, 3, 10, 2, 23
  };
  const int q9711[] = {
    9, 9, // Number of jobs and machines
    2, 69, 6, 79, 8, 30, 4, 73, 7, 79, 0, 57, 3, 11, 1, 30, 5, 98, 
    6, 30, 4, 47, 8,  6, 0, 49, 3, 89, 7, 66, 2, 70, 5, 16, 1, 50, 
    8, 57, 4, 11, 5, 37, 3, 78, 6, 50, 7, 40, 1,  6, 0, 50, 2, 82, 
    0, 55, 5, 35, 2, 45, 8, 70, 7, 49, 1, 80, 3, 98, 6, 22, 4, 22, 
    3, 56, 0, 10, 4, 16, 7, 65, 2, 94, 5, 19, 8, 83, 6, 76, 1, 15, 
    7, 80, 1, 17, 2, 88, 6, 98, 8, 89, 3, 97, 5, 13, 4, 37, 0, 50, 
    3, 36, 1, 52, 0, 80, 6, 79, 5,  8, 7, 34, 2,  9, 8,  6, 4, 24, 
    8, 54, 3, 52, 1, 29, 0, 88, 4, 13, 5, 27, 6, 50, 2,  2, 7, 28, 
    8, 89, 3, 43, 6, 10, 0, 74, 7,  5, 5, 64, 2, 12, 4, 84, 1, 36
  };
  const int q9712[] = {
    9, 9, // Number of jobs and machines
    6, 64, 7, 12, 5, 10, 4, 44, 2,  5, 1, 53, 0, 26, 8, 66, 3, 11, 
    3, 84, 5,  5, 2,  7, 7, 33, 0,  3, 1, 55, 8, 15, 6, 25, 4, 26, 
    7,  8, 5, 23, 6, 89, 0, 77, 4, 10, 2,  8, 1, 19, 3, 15, 8,  9, 
    0, 70, 3,  7, 6, 74, 4, 43, 5, 35, 1, 72, 8, 34, 2, 63, 7,  5, 
    0, 51, 4, 45, 8, 67, 3, 49, 7, 36, 1, 39, 5,  8, 6, 98, 2, 75, 
    6, 83, 5, 45, 4, 64, 7, 25, 1, 31, 0, 30, 3, 72, 2, 21, 8, 33, 
    5, 54, 2, 54, 4, 60, 0,  7, 3, 28, 7,  4, 1, 71, 8, 10, 6, 36, 
    4, 87, 0, 84, 3, 70, 1, 45, 2, 30, 7, 20, 6, 72, 5, 94, 8, 22, 
    2,  4, 1, 34, 8, 40, 5, 87, 3, 30, 0, 85, 7, 78, 6,  3, 4, 54
  };
  const int q9713[] = {
    9, 9, // Number of jobs and machines
    2, 62, 6, 38, 5, 48, 7, 71, 1, 31, 8, 10, 4, 81, 0, 89, 3, 97, 
    5, 91, 7, 46, 4, 70, 1, 67, 3,  3, 2, 28, 8, 53, 0, 22, 6, 47, 
    1,  5, 4, 43, 5, 56, 8, 99, 2,  5, 7, 17, 3, 96, 6, 94, 0, 91, 
    8, 37, 6, 65, 7, 55, 0, 61, 1, 72, 3, 80, 2, 26, 5, 51, 4, 26, 
    8, 86, 1, 59, 6, 58, 4, 53, 3, 78, 5, 67, 7, 54, 2, 15, 0, 92, 
    5, 44, 1, 72, 8, 64, 0, 92, 7, 99, 3, 22, 4, 73, 6, 50, 2, 71, 
    4,  1, 0, 75, 7, 25, 1, 76, 5, 77, 2, 14, 3, 23, 6, 37, 8, 59, 
    5, 23, 2, 61, 6, 18, 8, 33, 7, 73, 1,  7, 4, 23, 0, 98, 3, 60, 
    2, 29, 1, 63, 5, 24, 6, 30, 0, 81, 8, 51, 3, 20, 7, 15, 4, 27
  };
  const int q9714[] = {
    9, 9, // Number of jobs and machines
    0, 38, 8,  6, 5, 56, 3, 91, 2, 43, 6, 30, 4, 15, 1, 36, 7, 51, 
    7, 22, 1,  7, 5, 72, 2, 72, 3, 34, 6, 11, 4, 35, 0, 36, 8, 48, 
    1, 52, 3, 35, 7, 64, 0, 31, 6, 48, 8,  6, 2, 73, 5, 72, 4, 73, 
    3, 46, 5, 42, 4, 99, 6, 71, 1, 73, 0, 44, 8, 35, 7, 43, 2, 67, 
    0, 48, 6,  2, 3, 14, 1, 39, 5, 59, 8, 73, 7, 38, 2, 62, 4, 20, 
    6,  6, 3, 68, 4,  3, 0, 41, 2, 29, 8, 16, 1, 83, 5, 18, 7, 61, 
    8, 19, 6,  8, 2, 84, 1, 88, 3, 37, 7, 61, 4, 84, 5,  9, 0, 24, 
    2, 36, 6, 65, 3, 43, 5, 49, 7,  7, 1, 36, 4, 71, 8, 17, 0, 30, 
    2,  1, 4,  6, 1, 47, 3, 32, 7, 95, 5, 95, 8, 58, 0, 71, 6,  1
  };
  const int q9715[] = {
    9, 9, // Number of jobs and machines
    0, 57, 5, 50, 1,  8, 4, 22, 3,  7, 2, 48, 8, 86, 7, 85, 6, 31, 
    0,  1, 1, 19, 5, 63, 8, 79, 7, 15, 2, 55, 3, 99, 6, 48, 4, 52, 
    1, 20, 8, 32, 3, 21, 7, 53, 0, 12, 6, 53, 5, 71, 4, 42, 2, 29, 
    6, 42, 2, 56, 1, 93, 0, 87, 5, 73, 8, 83, 4, 96, 3, 91, 7, 93, 
    1, 17, 0, 62, 5, 21, 6, 61, 7, 85, 4,  4, 3, 99, 8, 36, 2, 60, 
    8, 34, 7, 26, 3, 93, 0, 68, 5, 36, 2,  2, 6, 65, 4, 51, 1, 78, 
    8, 75, 4,  4, 7, 64, 0, 21, 5, 24, 6, 41, 3, 29, 2, 35, 1,  9, 
    2, 53, 3, 21, 1, 68, 8, 87, 6, 19, 7, 27, 5, 29, 0, 99, 4, 65, 
    6, 95, 1, 59, 7, 91, 4, 43, 3, 40, 8, 13, 5, 70, 2, 55, 0, 85
  };
  const int q9716[] = {
    9, 9, // Number of jobs and machines
    5, 18, 4, 50, 1, 46, 8, 98, 3, 57, 2, 99, 7, 46, 0,  9, 6,  8, 
    7, 52, 8, 19, 4, 14, 3, 60, 5, 82, 0, 52, 6, 72, 1, 90, 2, 78, 
    7, 47, 0, 94, 6, 13, 4, 17, 3, 25, 8, 53, 1, 92, 5,  6, 2, 66, 
    7, 87, 6, 17, 4, 89, 1, 48, 3, 61, 2, 79, 0, 96, 8,  2, 5, 54, 
    7, 95, 1, 83, 2, 34, 5, 26, 8, 42, 0, 80, 3, 57, 6, 35, 4, 40, 
    5, 30, 7, 86, 4, 58, 1, 54, 0, 16, 2, 52, 8, 54, 6, 59, 3, 46, 
    4, 94, 7, 28, 2, 52, 6, 95, 5, 12, 8, 37, 1, 81, 0, 80, 3, 98, 
    5, 46, 4, 66, 0, 18, 7, 22, 1,  8, 2, 75, 3, 23, 6, 67, 8, 14, 
    4, 80, 2,  1, 8, 27, 5, 82, 1, 33, 3, 36, 7, 94, 6, 34, 0, 54
  };
  const int q9717[] = {
    9, 9, // Number of jobs and machines
    3, 17, 5, 78, 4, 59, 1, 93, 8, 22, 6, 40, 7, 16, 0, 50, 2, 60, 
    3, 62, 7, 86, 2, 90, 4, 75, 1, 83, 5, 50, 0, 53, 8, 91, 6, 70, 
    0, 27, 4, 57, 2,  8, 3, 24, 6, 75, 8, 95, 1, 82, 5, 84, 7, 68, 
    3, 11, 2, 31, 8, 61, 1, 19, 7, 34, 4, 58, 0,  8, 6, 60, 5, 41, 
    2, 35, 3, 70, 4, 54, 5, 81, 0, 55, 8, 27, 1, 55, 7, 11, 6,  8, 
    7, 57, 2, 24, 3, 43, 6, 88, 5, 43, 1, 33, 4, 59, 0, 88, 8, 33, 
    6, 92, 3, 65, 5, 90, 2,  8, 8, 30, 4, 70, 1, 89, 0, 96, 7, 56, 
    4, 96, 3, 25, 5,  5, 2, 37, 7, 50, 6, 30, 8, 22, 1, 90, 0, 26, 
    2, 63, 8, 59, 3, 54, 0, 77, 6, 88, 5, 29, 4, 80, 1, 60, 7, 25
  };
  const int q9718[] = {
    9, 9, // Number of jobs and machines
    6, 26, 7, 14, 0, 61, 5, 77, 3, 41, 4, 35, 1, 20, 8, 10, 2, 79, 
    6, 91, 2, 77, 7,  2, 5, 90, 1, 88, 3, 46, 0, 29, 8,  9, 4, 91, 
    3,  7, 2, 42, 5, 57, 7, 10, 8, 65, 4, 76, 0, 63, 1, 45, 6, 97, 
    6, 17, 3, 59, 0, 39, 4, 62, 2, 52, 7, 15, 5, 55, 8, 66, 1, 28, 
    4, 50, 1, 66, 6, 85, 7, 84, 3,  6, 0, 67, 2, 72, 8, 13, 5, 92, 
    6, 73, 0, 73, 2, 79, 7, 60, 3, 13, 4, 30, 8, 40, 5, 16, 1, 71, 
    7, 67, 4, 48, 5,  8, 2, 87, 8, 78, 6, 63, 3, 44, 1, 68, 0, 44, 
    0, 81, 1, 67, 6, 54, 4, 24, 5, 58, 3,  4, 2, 25, 7, 92, 8, 92, 
    6, 90, 4, 41, 7,  3, 0, 35, 3,  8, 8,  8, 2, 66, 5, 13, 1, 46
  };
  const int q9719[] = {
    9, 9, // Number of jobs and machines
    4, 95, 6, 31, 0, 33, 8, 65, 5, 16, 3, 25, 1, 39, 7, 55, 2, 49, 
    4, 25, 2, 76, 3, 29, 1, 75, 6, 51, 8, 84, 7, 48, 0, 71, 5, 16, 
    7, 27, 2, 99, 1, 20, 5, 98, 3, 55, 6,  6, 8, 96, 0, 50, 4, 61, 
    4,  9, 7, 41, 0, 26, 3, 72, 2, 59, 6, 69, 1, 25, 5, 34, 8, 63, 
    7, 37, 1, 17, 2,  4, 8,  7, 5, 88, 3, 36, 6, 65, 4, 45, 0, 98, 
    1, 82, 2, 46, 0, 23, 6, 23, 5, 83, 3, 13, 4, 20, 8, 99, 7, 26, 
    8, 12, 6, 56, 1, 30, 5, 91, 7, 32, 0, 93, 3, 29, 2, 89, 4, 77, 
    4, 61, 6, 52, 2, 94, 3, 74, 0, 42, 8, 23, 7, 11, 5, 63, 1, 96, 
    2, 61, 1, 24, 0, 96, 4, 87, 8,  5, 7,  9, 6, 95, 3, 11, 5, 12
  };
  const int q9720[] = {
    9, 9, // Number of jobs and machines
    8,  1, 7, 40, 0, 59, 6, 43, 1, 40, 2, 33, 5,  4, 4,  7, 3, 62, 
    5, 19, 0, 84, 2, 94, 8,  6, 3, 74, 1, 85, 4, 59, 6, 97, 7, 29, 
    0, 75, 2, 29, 1, 60, 8,  5, 3, 50, 7, 48, 5, 10, 6, 77, 4, 96, 
    1, 28, 8, 99, 7,  5, 4, 44, 3, 69, 0, 30, 6, 73, 5, 83, 2, 62, 
    7, 60, 8, 67, 4, 76, 6, 62, 2, 77, 1, 14, 0, 24, 3, 87, 5, 11, 
    8, 42, 1, 91, 0, 11, 6, 43, 5, 19, 3, 32, 2, 41, 7,  9, 4, 64, 
    3, 77, 2, 27, 1,  4, 6, 31, 4, 28, 7, 90, 5, 34, 8, 67, 0, 57, 
    8, 57, 7,  7, 1, 69, 0,  4, 2, 70, 4,  3, 5, 81, 6, 66, 3, 34, 
    6, 62, 3, 44, 7, 55, 2,  5, 1, 75, 8, 18, 5, 84, 4, 83, 0, 90
  };
  const int q9721[] = {
    9, 9, // Number of jobs and machines
    2, 61, 0, 66, 7, 36, 1, 91, 5, 62, 6, 83, 8, 34, 4, 89, 3, 39, 
    4, 20, 3, 56, 7, 98, 2, 36, 5, 72, 0, 71, 8, 80, 6, 14, 1, 89, 
    4, 71, 7,  7, 1, 21, 0, 23, 5, 79, 2, 19, 8, 93, 6, 64, 3, 55, 
    7, 35, 0, 62, 4, 66, 6, 43, 2, 19, 3, 61, 8, 56, 1, 67, 5, 79, 
    7, 84, 6, 54, 1,  6, 5, 81, 2, 52, 4, 88, 3, 90, 8, 36, 0, 73, 
    3,  1, 7, 97, 4, 33, 6,  4, 1, 51, 5, 53, 8, 47, 2, 91, 0, 23, 
    8,  4, 7, 14, 6,  9, 3, 25, 5,  7, 2, 75, 4, 32, 1, 57, 0, 77, 
    2, 41, 5,  1, 0, 94, 6, 48, 1, 98, 7, 34, 8, 54, 3, 90, 4, 24, 
    6, 14, 7, 62, 8, 22, 3, 70, 0,  6, 2,  6, 5, 67, 4,  9, 1, 51
  };
  const int q9722[] = {
    9, 9, // Number of jobs and machines
    2, 96, 7, 80, 8, 33, 5, 17, 6, 94, 0, 66, 4, 74, 1, 25, 3, 48, 
    2, 24, 7, 57, 1, 97, 8, 97, 6, 36, 0, 52, 5, 86, 3, 74, 4, 32, 
    4, 27, 3, 50, 1, 80, 8, 38, 7, 33, 0, 91, 5, 28, 6, 40, 2, 78, 
    2, 17, 6, 64, 4, 25, 3, 92, 1, 41, 5, 96, 7, 26, 8, 75, 0, 83, 
    5, 39, 0, 28, 1, 94, 4, 39, 3, 16, 8, 45, 7, 18, 2, 68, 6, 93, 
    3, 59, 0,  7, 5, 12, 6, 60, 8, 37, 7, 46, 1, 80, 2, 47, 4, 45, 
    3, 45, 1, 79, 4, 73, 2, 21, 6, 53, 7, 83, 8, 35, 0, 39, 5, 12, 
    3, 48, 4, 41, 2, 12, 0,  1, 7, 54, 6, 27, 8, 95, 5, 59, 1, 46, 
    0,  5, 5, 56, 7, 61, 6, 62, 4, 45, 8, 58, 1, 19, 2,  6, 3,  9
  };
  const int q9723[] = {
    9, 9, // Number of jobs and machines
    7, 46, 6, 96, 0, 23, 1, 79, 5, 54, 2, 93, 3, 34, 8, 79, 4, 71, 
    0, 85, 5, 28, 3, 88, 4, 33, 8,  8, 7, 71, 6, 30, 2, 20, 1, 56, 
    1, 40, 0, 33, 4, 97, 3, 58, 8, 82, 6, 17, 7, 52, 2, 15, 5, 98, 
    8,  8, 4, 21, 1,  3, 3, 12, 0,  8, 7,  6, 2, 27, 6, 38, 5, 90, 
    1, 44, 3, 84, 7,  8, 8, 73, 4, 12, 6, 71, 0, 45, 5, 70, 2, 10, 
    5, 17, 7, 85, 6, 38, 8, 44, 4, 39, 3, 38, 1,  5, 2, 68, 0, 62, 
    0, 72, 6, 83, 8, 18, 5, 63, 3, 13, 1, 43, 7, 94, 2, 12, 4, 48, 
    6,  6, 3, 69, 1,  8, 2, 41, 4, 78, 5, 98, 0, 35, 7, 75, 8, 13, 
    5, 97, 3, 10, 2, 77, 0, 42, 8, 14, 6, 63, 1, 97, 7, 50, 4, 22
  };
  const int q9724[] = {
    9, 9, // Number of jobs and machines
    3, 69, 8, 22, 0, 76, 2, 26, 1, 50, 7, 47, 5, 27, 4, 21, 6, 66, 
    1, 46, 3, 22, 6, 84, 0, 77, 5, 86, 7,  5, 8, 67, 4,  7, 2, 98, 
    1, 65, 2,  1, 5, 52, 4, 13, 3, 54, 6,  2, 7, 74, 8, 49, 0, 38, 
    8, 18, 0, 80, 6, 20, 2, 90, 5, 64, 4, 37, 1, 20, 7, 25, 3, 19, 
    5, 50, 4,  4, 2, 22, 3, 91, 0, 45, 1, 55, 7, 72, 6, 55, 8, 15, 
    1, 18, 7, 76, 3, 57, 6, 20, 4, 71, 2, 73, 0, 73, 8, 75, 5, 22, 
    5, 39, 6, 15, 1, 68, 8, 53, 7, 19, 4, 85, 0, 65, 2, 23, 3,  5, 
    3, 14, 8, 42, 0, 78, 5, 93, 6, 11, 4,  1, 2, 54, 7, 25, 1, 57, 
    8, 47, 3, 75, 2, 19, 6, 11, 5, 29, 4,  8, 1, 77, 7, 60, 0, 95
  };
  const int q9725[] = {
    9, 9, // Number of jobs and machines
    4, 22, 7, 70, 5, 38, 0, 19, 8, 27, 1, 61, 3, 77, 6,  2, 2, 76, 
    0, 69, 3,  7, 5,  8, 2, 61, 7, 22, 8, 21, 1, 68, 6, 65, 4, 64, 
    7, 96, 3, 87, 2, 89, 5, 91, 6, 10, 1, 58, 4, 97, 8, 33, 0, 55, 
    2, 10, 8, 26, 6, 58, 0, 26, 1, 46, 4, 76, 7, 89, 3, 61, 5, 49, 
    8, 74, 7, 48, 3, 19, 6, 59, 4, 40, 0,  8, 2, 19, 5, 17, 1, 67, 
    1, 25, 6, 81, 3, 87, 2, 12, 5,  3, 8, 16, 4, 15, 0, 17, 7, 59, 
    3, 79, 8, 99, 0, 92, 7, 29, 6, 36, 2, 78, 1, 54, 5, 74, 4, 26, 
    0, 38, 3, 74, 1, 44, 4, 46, 6, 64, 2, 96, 7, 84, 8,  5, 5, 17, 
    6,  9, 7, 28, 4, 48, 1,  6, 3, 57, 0, 57, 2, 65, 5,  8, 8, 56
  };
  const int q9726[] = {
    9, 9, // Number of jobs and machines
    1, 57, 8, 90, 4, 68, 7, 48, 6, 42, 2, 62, 5, 13, 3, 11, 0,  3, 
    3, 61, 1, 11, 2, 69, 6, 77, 5, 94, 8, 41, 0, 82, 4,  7, 7, 17, 
    8, 87, 5,  7, 6,  1, 4, 43, 3, 46, 7, 50, 2, 65, 1, 32, 0, 40, 
    7, 30, 6, 76, 8,  4, 1, 63, 5,  2, 4, 14, 0, 33, 3, 52, 2, 22, 
    2, 92, 8, 31, 4, 43, 1,  9, 7, 10, 3, 49, 5, 21, 6, 19, 0, 21, 
    2, 30, 3, 99, 8, 98, 5, 32, 7, 67, 1, 31, 6, 89, 4, 32, 0, 48, 
    8,  3, 0, 38, 5, 29, 2, 96, 4, 17, 7, 19, 1, 44, 6, 44, 3, 21, 
    2, 51, 4, 33, 3, 37, 5, 75, 8, 92, 6, 69, 7, 40, 1, 14, 0, 75, 
    6, 16, 5, 98, 8, 95, 1, 48, 3,  4, 0, 69, 2, 36, 7, 90, 4, 97
  };
  const int q9727[] = {
    9, 9, // Number of jobs and machines
    1, 64, 7, 46, 6, 46, 4, 10, 3, 78, 0, 84, 5, 36, 2, 51, 8, 60, 
    8, 15, 5, 35, 0, 13, 4, 90, 1, 56, 2, 21, 3, 56, 6, 48, 7, 96, 
    2, 86, 8,  5, 5, 11, 3, 23, 6,  5, 1, 26, 4, 77, 7, 65, 0, 67, 
    8, 81, 2, 85, 5, 48, 3, 13, 7, 86, 6, 32, 0, 91, 1, 63, 4, 93, 
    8,  1, 0, 77, 6, 70, 5, 69, 1, 74, 2, 92, 7, 23, 4, 41, 3, 73, 
    4, 49, 1, 76, 7, 50, 2, 83, 0, 76, 8, 96, 6,  3, 3, 74, 5,  1, 
    2, 68, 7, 81, 6, 27, 3, 35, 5, 12, 0, 40, 8, 62, 1, 80, 4, 79, 
    2, 73, 3, 32, 0, 35, 8, 60, 6,  4, 7,  3, 5, 97, 1, 27, 4, 79, 
    1, 97, 3, 18, 2, 17, 7, 15, 5, 20, 0, 11, 4, 45, 8, 74, 6, 65
  };
  const int q9728[] = {
    9, 9, // Number of jobs and machines
    6, 87, 4, 57, 3, 27, 7, 27, 5, 73, 2, 95, 8, 93, 0, 54, 1, 67, 
    6, 96, 0, 54, 8, 38, 4, 95, 7, 23, 2, 90, 5, 23, 3, 57, 1, 89, 
    8, 82, 4, 35, 5, 29, 2, 76, 1, 27, 3, 45, 0, 27, 6, 85, 7, 97, 
    6, 31, 7, 40, 0, 39, 3, 95, 5, 24, 1, 17, 4, 73, 2, 52, 8,  8, 
    7, 49, 3, 83, 6, 39, 0, 45, 1, 16, 2, 84, 8, 43, 5, 61, 4, 80, 
    7, 44, 3, 52, 2, 55, 6, 89, 5, 40, 4, 75, 1, 13, 8, 24, 0, 74, 
    0,  2, 5, 43, 1, 28, 7, 23, 3,  7, 4, 22, 2, 15, 8, 98, 6, 47, 
    6, 18, 8,  6, 0, 38, 1, 49, 7, 63, 4, 69, 5, 26, 2, 82, 3, 28, 
    8, 43, 3, 39, 1, 99, 7,  7, 5, 40, 6, 48, 0, 92, 2,  9, 4, 26
  };
  const int q9729[] = {
    9, 9, // Number of jobs and machines
    4,  2, 0,  6, 5, 81, 8, 10, 3, 76, 2, 96, 7, 82, 6, 81, 1, 76, 
    2, 44, 6, 73, 8, 72, 0, 58, 3, 53, 5, 10, 4, 75, 7, 39, 1,  8, 
    0,  2, 1, 79, 8,  5, 3, 78, 4, 87, 7, 56, 2, 81, 6, 14, 5, 17, 
    8, 98, 0, 77, 4, 74, 1, 24, 3, 36, 5, 24, 2, 96, 7, 32, 6, 11, 
    6, 61, 7, 62, 8, 82, 2, 31, 0, 65, 5, 35, 4, 21, 1, 42, 3, 81, 
    7, 32, 8, 14, 4, 97, 3, 99, 0, 52, 1, 88, 2, 93, 6, 17, 5, 90, 
    5, 93, 6, 77, 0, 61, 4, 12, 8, 27, 2, 89, 3, 10, 7,  1, 1, 23, 
    7, 50, 6, 55, 5, 88, 8, 24, 0,  7, 3, 82, 2, 80, 1, 18, 4,  7, 
    1, 79, 8, 59, 3, 30, 6, 90, 0, 61, 2, 94, 7, 93, 5,  4, 4, 73
  };
  const int q9730[] = {
    9, 9, // Number of jobs and machines
    7,  8, 2, 41, 8, 10, 5, 68, 0,  9, 6, 97, 3, 53, 4, 90, 1, 24, 
    6, 28, 3, 86, 2, 66, 7, 44, 5, 30, 0, 15, 8, 38, 4, 48, 1, 30, 
    7, 23, 8, 86, 4, 57, 1, 18, 0, 63, 3, 73, 5, 10, 6, 21, 2, 66, 
    8, 91, 3, 45, 4, 50, 5, 96, 0, 70, 7, 27, 1, 72, 6, 12, 2, 70, 
    2, 96, 6, 55, 4, 78, 3, 90, 5, 85, 0, 21, 8, 43, 1, 18, 7, 98, 
    2, 30, 0, 57, 1, 97, 7, 37, 4, 15, 3, 24, 8, 43, 6, 50, 5, 78, 
    0,  8, 5, 31, 8, 12, 1, 93, 2, 87, 3, 70, 6, 10, 7, 19, 4, 40, 
    1, 16, 5, 79, 3, 46, 0, 16, 2, 78, 8, 35, 4, 45, 6, 86, 7, 47, 
    4, 82, 3, 43, 0, 13, 6,  1, 5,  9, 1, 99, 8, 99, 7, 94, 2, 65
  };
  const int q9731[] = {
    9, 9, // Number of jobs and machines
    7, 32, 6, 44, 1,  9, 5,  8, 2, 62, 4, 56, 0, 92, 8, 61, 3, 36, 
    6, 26, 1, 78, 8, 52, 2, 33, 7, 47, 5, 47, 4, 82, 3, 65, 0, 88, 
    2, 96, 3, 71, 0, 93, 4, 80, 8, 53, 7, 63, 5, 16, 1, 61, 6, 52, 
    8, 45, 6, 12, 1, 87, 4, 95, 7,  8, 0, 68, 2, 76, 5, 20, 3,  6, 
    8,  7, 5, 99, 1, 41, 6, 58, 4, 44, 0, 51, 7, 97, 2,  3, 3, 65, 
    2, 33, 7, 35, 1, 86, 6, 67, 8, 84, 0, 13, 5,  9, 4, 44, 3, 70, 
    5, 74, 4, 37, 8, 33, 0, 73, 7, 60, 3, 39, 2, 61, 1, 84, 6, 98, 
    7, 94, 5, 98, 2, 43, 0, 82, 4,  8, 8, 47, 3, 31, 6, 59, 1,  9, 
    4, 47, 6, 97, 0, 38, 2, 69, 1, 85, 5, 85, 7,  8, 8, 98, 3, 28
  };
  const int q9732[] = {
    9, 9, // Number of jobs and machines
    1, 13, 8, 26, 0, 31, 5, 49, 6, 81, 4, 35, 3, 82, 7, 71, 2, 35, 
    1,  8, 5, 36, 2, 39, 3, 91, 7, 58, 6, 81, 4, 47, 0,  8, 8, 53, 
    4,  5, 5, 41, 1, 97, 3, 45, 6, 85, 8, 97, 2, 90, 7, 34, 0, 13, 
    3, 18, 2, 32, 0, 70, 8, 58, 7,  3, 1,  2, 5, 92, 6, 23, 4, 31, 
    2, 99, 3, 49, 6, 31, 4, 12, 5, 69, 1, 52, 0, 48, 7, 54, 8, 94, 
    7, 56, 6, 35, 2, 25, 5, 44, 4, 58, 8, 84, 0, 67, 3, 79, 1, 21, 
    0, 86, 4, 28, 6, 87, 1,  2, 2, 50, 7, 74, 3, 41, 5, 45, 8, 22, 
    5, 48, 1, 70, 0,  1, 2, 75, 3, 74, 7, 26, 8, 74, 4, 82, 6, 77, 
    6, 19, 0, 64, 1, 72, 2, 35, 7, 99, 5, 56, 4, 89, 8, 60, 3, 46
  };
  const int q9733[] = {
    9, 9, // Number of jobs and machines
    8, 84, 7, 72, 4, 19, 1, 16, 5, 24, 0, 27, 3, 10, 2, 64, 6, 48, 
    2, 10, 3, 73, 0, 95, 6,  8, 5, 69, 1, 37, 7, 73, 8, 98, 4, 97, 
    4, 91, 3, 33, 6, 13, 1, 93, 0, 62, 7, 18, 5, 47, 8, 92, 2, 34, 
    7, 58, 1, 88, 5, 26, 3, 81, 6, 55, 0, 53, 2, 82, 8, 90, 4, 93, 
    3, 45, 2, 52, 7, 36, 8, 71, 5, 91, 0, 90, 4, 48, 1, 62, 6, 85, 
    6,  7, 8,  7, 3, 31, 4, 93, 0, 60, 7, 24, 2, 36, 5, 24, 1, 23, 
    4, 96, 8, 21, 2, 90, 3, 78, 1, 85, 7, 51, 0, 14, 5, 81, 6, 33, 
    7, 31, 5, 29, 3, 59, 4, 52, 8, 34, 0,  1, 6, 18, 2, 15, 1, 34, 
    5, 92, 4, 70, 6, 55, 1, 94, 7, 71, 0, 22, 2, 18, 3, 28, 8,  3
  };
  const int q9734[] = {
    9, 9, // Number of jobs and machines
    7,  4, 6, 29, 5, 14, 8, 76, 0, 80, 3, 87, 1, 23, 4,  8, 2, 18, 
    0, 80, 7, 44, 6, 11, 3, 50, 2, 99, 8, 13, 4, 90, 5, 95, 1, 30, 
    6, 65, 2, 64, 7, 35, 1, 46, 5,  9, 0, 78, 3, 72, 4, 50, 8, 46, 
    5, 20, 3, 41, 0, 43, 8, 91, 1, 69, 6, 31, 7, 58, 2, 41, 4, 22, 
    1, 91, 3,  3, 5,  2, 7, 63, 4,  5, 2, 35, 6, 65, 0, 61, 8, 67, 
    2, 77, 8, 68, 1, 42, 4, 16, 6, 62, 5, 25, 0, 31, 7,  3, 3, 52, 
    4, 82, 8, 18, 7, 45, 6, 62, 3, 41, 1, 72, 2, 48, 5, 49, 0, 91, 
    1, 42, 6, 71, 2, 53, 0, 22, 7, 54, 4, 74, 3, 22, 5, 98, 8, 18, 
    4, 42, 6, 22, 7, 31, 3, 45, 0, 82, 2, 37, 8, 69, 5, 70, 1, 38
  };
  const int q9735[] = {
    9, 9, // Number of jobs and machines
    1, 59, 6, 44, 0, 67, 5,  1, 4, 18, 2, 30, 7, 27, 3, 85, 8, 70, 
    1, 66, 2, 60, 0, 27, 5, 31, 7,  4, 8, 40, 6, 69, 4, 18, 3, 51, 
    2, 36, 8, 16, 7,  6, 0, 17, 4, 67, 3, 87, 1, 63, 6, 39, 5, 22, 
    3, 84, 0, 40, 4, 95, 2, 30, 6, 10, 5, 57, 8, 37, 7, 19, 1, 43, 
    7, 93, 2, 25, 1, 40, 3, 54, 0, 67, 5, 75, 4, 62, 6, 98, 8, 42, 
    3, 34, 7, 35, 4, 10, 0, 10, 5, 40, 2, 38, 1, 92, 8,  2, 6, 55, 
    8, 32, 5,  6, 1, 90, 2, 19, 3, 66, 4, 78, 7, 97, 0, 24, 6, 88, 
    4, 90, 0, 32, 7, 23, 2, 99, 6, 61, 5, 54, 1, 33, 8, 20, 3, 82, 
    1, 60, 3,  2, 4, 36, 6,  9, 5, 86, 7, 15, 0, 50, 2, 65, 8,  3
  };
  const int q9736[] = {
    9, 9, // Number of jobs and machines
    0, 37, 2, 91, 8,  7, 4, 50, 3, 41, 1, 45, 5, 52, 6, 88, 7, 55, 
    0, 55, 5, 68, 3, 15, 4, 35, 1, 32, 7, 67, 6, 91, 2, 28, 8, 75, 
    3, 48, 6, 58, 8, 50, 4, 93, 0, 93, 2, 24, 7, 25, 5, 98, 1,  5, 
    2, 29, 6, 56, 7, 30, 8,  2, 5, 88, 0, 78, 4, 63, 1, 56, 3, 72, 
    8, 98, 4, 72, 6, 45, 5, 78, 0, 97, 2, 30, 7, 42, 3, 77, 1,  9, 
    8, 40, 0, 70, 7, 39, 4, 59, 2, 37, 3, 33, 6, 81, 1, 98, 5, 44, 
    2, 27, 8, 90, 3, 71, 4, 86, 6, 56, 7, 44, 5, 64, 0, 58, 1, 53, 
    3, 38, 7, 88, 6, 43, 8, 27, 4, 68, 5, 80, 0, 44, 2, 15, 1,  7, 
    5, 16, 7, 61, 3, 98, 6, 60, 1,  3, 0, 69, 8, 12, 2,  9, 4, 48
  };
  const int q9737[] = {
    9, 9, // Number of jobs and machines
    6, 61, 2, 68, 5, 96, 0, 25, 7, 81, 4, 71, 8, 33, 3, 69, 1, 73, 
    0, 66, 4, 44, 8, 52, 6, 35, 2, 79, 5, 37, 1, 50, 7, 56, 3, 90, 
    1, 27, 4, 17, 8, 36, 5, 31, 0, 48, 7, 25, 3, 56, 6, 75, 2, 78, 
    4,  4, 8, 81, 6, 88, 2, 91, 1, 99, 3, 86, 7, 37, 5, 57, 0, 31, 
    1, 48, 7, 42, 6, 35, 0, 54, 3, 59, 2, 71, 4, 75, 8, 30, 5, 90, 
    8, 76, 0, 13, 6, 10, 5, 21, 1, 49, 3, 61, 2, 17, 4, 61, 7, 75, 
    1, 16, 8, 33, 2, 88, 5, 55, 0, 51, 4, 90, 7, 74, 6, 64, 3, 30, 
    5, 79, 4, 14, 6, 48, 8, 10, 7, 93, 2, 24, 0, 64, 3, 59, 1, 10, 
    5, 20, 4, 18, 2, 90, 7, 78, 3, 77, 8, 29, 0,  5, 6, 45, 1, 91
  };
  const int q9738[] = {
    9, 9, // Number of jobs and machines
    2, 91, 6, 56, 8, 99, 4, 37, 1, 26, 3, 59, 0, 69, 7, 41, 5, 25, 
    0, 15, 2, 48, 3, 85, 5, 40, 8, 47, 7, 95, 1, 78, 4, 78, 6, 73, 
    6, 40, 1,  3, 7, 75, 8, 25, 0, 36, 5, 99, 3, 24, 2, 32, 4, 77, 
    2, 31, 5, 66, 8, 79, 1, 17, 3, 66, 6, 37, 7, 10, 4, 43, 0, 38, 
    4, 46, 1, 63, 6, 81, 7, 35, 5, 97, 8,  7, 2, 75, 3, 27, 0, 63, 
    1, 14, 2,  7, 8, 59, 3,  2, 6,  4, 0,  2, 5, 86, 4, 77, 7, 35, 
    3, 20, 0, 82, 8, 97, 2, 89, 6, 62, 5, 90, 4, 17, 7, 62, 1, 67, 
    3, 63, 4, 89, 8, 92, 0, 61, 6, 26, 2, 87, 5,  4, 1, 10, 7, 92, 
    8, 12, 7, 93, 2, 95, 6, 91, 1, 39, 0, 70, 4,  5, 5, 79, 3,  9
  };
  const int q9739[] = {
    9, 9, // Number of jobs and machines
    7, 68, 0, 73, 2, 28, 3, 31, 4,  1, 6, 80, 5, 92, 8, 57, 1, 54, 
    3, 47, 4, 22, 5, 52, 7, 65, 1, 84, 0, 66, 8, 77, 6, 23, 2, 86, 
    2, 23, 0, 78, 7, 26, 6, 96, 4, 67, 3, 90, 1, 30, 8, 80, 5, 40, 
    5, 10, 7, 11, 8,  2, 1, 19, 2, 47, 6, 36, 0, 78, 3, 25, 4, 54, 
    8, 70, 6,  8, 7, 81, 0, 11, 2, 38, 5, 23, 3, 44, 4, 42, 1, 35, 
    3, 78, 5, 28, 8, 32, 7, 25, 6, 54, 2, 32, 1, 56, 0, 99, 4, 62, 
    0, 68, 1, 22, 4, 89, 2, 72, 7, 42, 8, 55, 3, 66, 6, 38, 5, 14, 
    0, 58, 6, 11, 7, 43, 1, 20, 2, 47, 5, 62, 4, 70, 3,  6, 8, 60, 
    8, 24, 7,  5, 6, 65, 2, 14, 1, 44, 3,  7, 0, 52, 4, 28, 5,  2
  };
  const int q9740[] = {
    9, 9, // Number of jobs and machines
    5, 36, 0, 52, 6,  9, 8, 32, 4, 11, 2, 87, 3, 37, 7, 12, 1,  6, 
    8, 15, 3, 82, 4, 50, 5, 66, 7, 39, 0, 71, 6, 34, 1, 73, 2, 52, 
    8, 68, 2, 94, 5, 93, 6, 72, 7,  4, 3, 69, 4, 64, 0, 27, 1, 84, 
    8,  8, 0, 32, 3, 48, 7, 85, 5, 52, 1, 86, 4, 70, 6, 76, 2, 42, 
    2, 11, 7,  8, 6, 40, 3, 43, 0, 82, 8, 17, 1, 96, 5, 77, 4, 78, 
    8, 64, 4, 79, 0, 14, 7, 53, 3, 16, 2, 22, 5, 12, 1, 15, 6, 50, 
    3, 14, 1, 98, 6, 12, 2, 87, 0, 21, 8, 95, 4, 62, 7, 84, 5, 87, 
    4, 32, 3, 27, 7, 75, 6, 88, 5, 24, 1,  5, 0, 57, 8, 59, 2, 45, 
    5, 70, 4, 44, 0, 83, 8, 28, 3, 38, 6, 86, 2, 62, 1, 59, 7, 79
  };
  const int q9741[] = {
    9, 9, // Number of jobs and machines
    0, 63, 7, 53, 8, 66, 4, 48, 2, 84, 6, 72, 1, 47, 5, 73, 3, 57, 
    8, 54, 7, 23, 2, 14, 0, 20, 4, 15, 5, 11, 1, 81, 6, 44, 3, 49, 
    4, 84, 3, 74, 2, 22, 5,  2, 8, 74, 7, 61, 0, 35, 6, 90, 1, 67, 
    4,  6, 7, 24, 0, 77, 1, 60, 8, 99, 2,  6, 6, 18, 3, 84, 5, 71, 
    6, 68, 0, 48, 7,  9, 5, 70, 2, 97, 4, 58, 3, 33, 1, 30, 8, 39, 
    5, 13, 6, 29, 4, 47, 1, 60, 8, 76, 7, 94, 0, 70, 2, 78, 3, 81, 
    7, 33, 1, 53, 2, 83, 3, 60, 4, 41, 0,  6, 5, 55, 6, 28, 8, 89, 
    6, 63, 2, 33, 8, 92, 3, 58, 0, 31, 1, 24, 5, 17, 4, 49, 7, 32, 
    4, 78, 3, 21, 8,  2, 6, 56, 1, 51, 2, 97, 5, 44, 0, 56, 7, 57
  };
  const int q9742[] = {
    9, 9, // Number of jobs and machines
    2, 92, 1, 99, 4,  3, 0, 84, 7, 88, 5, 77, 6, 32, 8, 13, 3, 30, 
    5, 26, 2, 51, 1, 39, 8, 17, 0, 93, 6, 26, 4, 72, 7, 11, 3, 15, 
    7, 64, 5, 23, 3, 75, 8, 62, 2, 51, 4, 63, 1, 75, 6, 67, 0, 31, 
    3,  5, 7, 83, 2, 54, 6, 86, 1, 49, 4, 72, 8, 59, 5, 88, 0, 31, 
    7, 81, 4,  7, 1, 88, 0, 83, 2, 10, 5, 13, 8, 36, 6, 46, 3, 77, 
    6, 64, 3, 45, 0, 29, 8, 83, 1, 87, 2, 49, 4, 95, 7,  8, 5,  6, 
    0, 63, 6, 12, 8, 68, 2, 77, 3, 73, 5, 34, 7, 40, 1, 27, 4, 48, 
    3, 83, 4,  2, 2, 66, 5, 26, 7, 18, 6, 64, 1, 90, 8,  8, 0, 26, 
    7, 31, 1, 29, 2, 61, 4, 44, 3, 55, 8, 79, 0, 89, 5, 24, 6, 85
  };
  const int q9743[] = {
    9, 9, // Number of jobs and machines
    3, 41, 4, 73, 2, 36, 7, 99, 8, 15, 5, 36, 1, 16, 6, 11, 0, 36, 
    8, 34, 5, 41, 4, 31, 0, 71, 2, 40, 3, 62, 6, 93, 1, 30, 7, 13, 
    5, 57, 1, 19, 6, 81, 8, 92, 4, 60, 7, 77, 3, 22, 2, 64, 0, 96, 
    0, 21, 4, 15, 5, 77, 3, 66, 2, 83, 6, 95, 7, 51, 8, 17, 1, 25, 
    1, 81, 5, 73, 2, 41, 4, 19, 0, 71, 3, 32, 6,  6, 7, 55, 8, 61, 
    8,  1, 7, 47, 5, 88, 2, 14, 0,  1, 3, 87, 6, 82, 1, 56, 4,  6, 
    7, 52, 3, 89, 8, 86, 1, 34, 6, 95, 2,  5, 5, 49, 0, 96, 4, 61, 
    3, 15, 7, 12, 1,  4, 6, 35, 8, 47, 0, 57, 2, 18, 5, 62, 4, 19, 
    2, 85, 7, 63, 3, 11, 1, 69, 6, 37, 5, 34, 4, 27, 8, 48, 0, 73
  };
  const int q9744[] = {
    9, 9, // Number of jobs and machines
    2, 94, 5, 81, 4,  6, 7, 23, 6, 31, 1, 41, 0, 73, 3, 39, 8, 72, 
    7, 76, 2, 47, 3, 32, 8, 38, 1,  8, 5, 95, 6, 50, 4, 10, 0, 91, 
    8, 50, 7, 82, 1, 15, 3, 23, 0, 41, 5, 30, 2, 28, 4, 52, 6, 81, 
    6, 19, 2, 64, 5, 43, 0, 29, 4, 59, 7,  5, 3, 57, 1, 46, 8, 29, 
    1, 55, 7, 91, 2, 78, 8, 16, 4, 84, 0, 15, 6, 25, 5,  7, 3, 17, 
    8, 15, 3, 64, 1, 20, 6,  3, 4, 20, 2, 74, 0, 89, 7, 94, 5, 94, 
    1, 48, 2, 65, 0,  4, 5, 66, 3, 27, 6, 36, 4,  1, 7, 89, 8, 25, 
    2, 43, 7, 91, 3, 11, 0, 60, 5,  4, 6, 36, 1,  6, 8, 66, 4, 79, 
    1,  9, 8, 38, 5, 44, 0, 79, 3, 48, 4, 84, 2, 78, 6, 89, 7, 43
  };
  const int q9745[] = {
    9, 9, // Number of jobs and machines
    4, 66, 5, 52, 8, 48, 7, 14, 0,  8, 1, 53, 3,  7, 6, 49, 2, 53, 
    3, 23, 0, 29, 7, 32, 5, 66, 8, 53, 4, 95, 1, 96, 2, 68, 6, 21, 
    6, 27, 2, 86, 5, 48, 0, 50, 8, 18, 1, 86, 7, 46, 3, 47, 4, 11, 
    2, 44, 0, 96, 5, 25, 8, 82, 1, 29, 7, 68, 6, 42, 4, 79, 3, 51, 
    7, 96, 1, 20, 3, 67, 0, 44, 8, 29, 5, 97, 4, 61, 6, 77, 2, 53, 
    1, 83, 8, 62, 7, 22, 0, 21, 5, 99, 6, 20, 3, 49, 4, 10, 2, 48, 
    8, 53, 0, 82, 3, 92, 1, 49, 5, 22, 7, 20, 2,  4, 6, 58, 4, 98, 
    1, 12, 4, 65, 8, 43, 2, 30, 0, 55, 6, 92, 5, 10, 7, 39, 3, 26, 
    3,  5, 5, 20, 2, 58, 8, 32, 6,  7, 1, 75, 7, 37, 0, 21, 4, 55
  };
  const int q9746[] = {
    9, 9, // Number of jobs and machines
    8, 20, 0, 53, 5, 75, 1, 80, 4, 99, 2, 51, 3, 25, 7, 49, 6, 51, 
    8, 77, 1, 96, 6, 82, 5,  7, 3, 78, 4, 48, 2, 94, 7, 95, 0, 76, 
    4,  9, 8, 58, 3, 57, 6, 66, 5, 97, 2, 59, 1, 48, 0, 86, 7, 53, 
    4, 89, 5, 19, 6, 43, 1, 91, 7, 10, 8, 17, 3,  4, 0, 28, 2, 53, 
    4, 44, 0, 64, 3, 56, 5, 38, 6,  2, 7, 41, 1,  4, 8, 66, 2, 45, 
    6, 57, 8, 39, 4, 60, 5, 80, 1, 66, 2, 74, 7, 84, 3, 47, 0, 92, 
    7, 32, 3, 75, 8, 87, 1, 70, 6, 95, 5, 92, 0, 52, 4, 71, 2, 69, 
    8, 20, 4, 42, 1, 45, 3, 60, 6, 44, 0, 29, 2, 89, 7, 65, 5, 65, 
    0, 29, 8, 55, 1, 67, 5, 54, 2, 56, 4, 82, 7, 81, 3, 17, 6, 44
  };
  const int q9747[] = {
    9, 9, // Number of jobs and machines
    4, 71, 0, 77, 8, 16, 7, 20, 1, 39, 3, 23, 6, 17, 2, 15, 5, 82, 
    1, 66, 3, 58, 0, 16, 8,  4, 5, 46, 7, 16, 2, 15, 6, 32, 4, 57, 
    2, 87, 0, 91, 5, 47, 1, 77, 8, 24, 6, 35, 3, 75, 7, 10, 4, 11, 
    1, 21, 0, 47, 8, 66, 4, 90, 3, 15, 6, 21, 2, 50, 7, 15, 5, 93, 
    6, 95, 5, 33, 7, 31, 4, 10, 0, 51, 2, 33, 8, 11, 3, 84, 1, 66, 
    5, 47, 3, 97, 4, 25, 1, 97, 2, 60, 8, 74, 6, 29, 7, 21, 0, 58, 
    3, 48, 5, 16, 2, 89, 8, 22, 6, 56, 7, 44, 4, 38, 0, 84, 1, 26, 
    3, 91, 1, 12, 6,  2, 7, 58, 2, 76, 0, 34, 5, 72, 4, 97, 8, 76, 
    6, 67, 5, 30, 2, 35, 8, 50, 3, 41, 1, 47, 7, 26, 4, 99, 0,  7
  };
  const int q9748[] = {
    9, 9, // Number of jobs and machines
    7, 35, 0, 38, 5,  5, 4, 57, 6, 45, 2, 43, 8, 77, 1, 45, 3, 68, 
    5, 29, 1, 24, 0, 46, 2, 84, 4, 71, 7, 29, 6, 71, 8,  4, 3, 57, 
    6, 41, 0, 68, 7, 90, 2, 12, 8, 26, 1, 83, 4,  5, 5, 63, 3, 62, 
    0,  7, 1, 81, 7, 64, 4, 82, 6, 33, 8,  6, 3, 61, 2, 72, 5,  2, 
    2, 82, 6, 19, 7,  8, 4, 49, 3, 97, 0, 23, 5, 77, 1, 80, 8, 45, 
    1, 80, 0, 50, 7, 88, 5, 22, 4, 43, 6, 80, 2, 52, 3, 81, 8, 21, 
    6, 51, 5, 91, 1, 92, 2, 27, 3, 97, 4, 51, 0, 82, 7, 71, 8, 69, 
    0, 60, 6, 30, 4,  6, 3,  3, 1, 10, 7, 45, 5, 76, 8, 26, 2, 33, 
    2,  7, 8, 55, 7, 78, 6,  1, 3, 97, 1, 59, 5, 39, 0, 54, 4, 57
  };
  const int q9749[] = {
    9, 9, // Number of jobs and machines
    8, 71, 7, 68, 6, 53, 2, 67, 3, 26, 0, 35, 1, 14, 5, 35, 4,  6, 
    4, 52, 3, 17, 5, 87, 6,  5, 7, 45, 1, 30, 0, 73, 8, 89, 2, 87, 
    5, 25, 8, 64, 6, 75, 1, 38, 0, 27, 3, 50, 7, 90, 4, 40, 2, 52, 
    7, 31, 6, 75, 0, 60, 4, 81, 8, 24, 2, 16, 5, 17, 3, 15, 1, 18, 
    4, 62, 2, 96, 8, 74, 6, 72, 0, 47, 3, 57, 7, 24, 1, 36, 5, 59, 
    8, 63, 1, 73, 4, 78, 2, 78, 5, 25, 3, 96, 0,  8, 7,  1, 6, 58, 
    6, 53, 1, 33, 5, 81, 4, 53, 0,  4, 2, 56, 7, 92, 8, 44, 3, 14, 
    7, 69, 3, 12, 0, 78, 6, 78, 2, 79, 4, 13, 8, 66, 5, 59, 1, 15, 
    7, 15, 4, 79, 6, 13, 1, 91, 3, 31, 2, 89, 5, 97, 0, 91, 8, 91
  };
  const int q9750[] = {
    9, 9, // Number of jobs and machines
    3, 65, 0,  5, 1, 24, 5, 20, 7, 83, 2, 28, 6, 26, 8, 21, 4, 38, 
    6, 63, 8, 80, 7, 29, 2, 52, 1, 33, 4, 64, 0,  2, 5, 71, 3, 31, 
    8,  1, 7, 91, 0, 50, 1, 91, 4, 35, 5, 27, 3, 34, 6, 29, 2, 48, 
    1,  1, 0, 80, 3, 96, 7, 63, 4, 81, 5, 88, 6, 88, 8, 90, 2,  8, 
    0, 74, 3, 16, 6, 44, 7, 99, 4, 99, 1, 25, 2, 96, 8, 35, 5, 12, 
    7, 38, 1, 69, 6, 38, 4, 23, 3, 29, 2, 77, 0, 69, 8, 20, 5,  9, 
    2, 55, 0, 22, 4, 57, 1, 52, 6, 47, 3, 88, 8, 69, 7, 31, 5, 37, 
    1, 56, 0, 82, 7, 84, 2, 10, 4, 22, 8, 69, 5, 65, 3, 57, 6, 29, 
    5, 32, 0, 43, 3, 58, 1, 54, 6, 24, 4, 40, 8, 32, 7, 61, 2, 71
  };
  const int q9751[] = {
    9, 9, // Number of jobs and machines
    8, 45, 3, 11, 0,  9, 1, 86, 6, 39, 2, 19, 7,  6, 5, 70, 4, 84, 
    5, 22, 0, 52, 2, 44, 4, 31, 7, 79, 6, 94, 1, 22, 8, 86, 3, 80, 
    1,  6, 5, 88, 2, 87, 3, 42, 4, 31, 7, 56, 8,  6, 6, 38, 0, 41, 
    6, 18, 2, 70, 0, 34, 7, 55, 1, 47, 8, 36, 4, 73, 3, 14, 5, 37, 
    2,  9, 7, 94, 3, 74, 5, 71, 0, 80, 6, 62, 1, 33, 8, 13, 4, 81, 
    2, 85, 5, 21, 0, 46, 3, 39, 8, 66, 4, 47, 7, 75, 1, 41, 6, 68, 
    1, 26, 6, 35, 2, 79, 0, 97, 4, 99, 3, 58, 5, 98, 7, 73, 8, 35, 
    3, 15, 7,  9, 4, 21, 2, 13, 5, 67, 0, 83, 1, 56, 8, 88, 6, 65, 
    7, 33, 4, 41, 6, 90, 0, 38, 3, 84, 5, 23, 1, 22, 2, 26, 8, 51
  };
  const int q9752[] = {
    9, 9, // Number of jobs and machines
    2, 77, 0, 99, 6, 64, 5, 42, 7,  2, 4,  4, 3,  5, 8, 66, 1, 51, 
    2, 68, 0, 37, 8,  6, 5, 85, 1, 93, 4, 44, 7, 33, 6, 30, 3, 93, 
    6, 56, 1, 42, 4, 19, 3, 44, 5, 36, 7, 73, 2, 52, 0, 66, 8, 28, 
    2,  7, 1, 19, 0, 51, 4, 84, 6, 26, 7, 74, 3, 75, 8, 38, 5, 29, 
    7, 49, 2, 31, 1, 76, 0,  9, 5, 12, 4, 73, 3, 56, 6, 13, 8, 26, 
    2, 46, 0, 75, 8, 52, 3, 93, 7, 60, 5, 40, 6, 43, 4, 35, 1, 33, 
    3, 98, 6, 11, 8, 40, 7, 47, 1, 29, 0, 94, 5, 36, 4,  9, 2,  8, 
    1, 73, 8, 78, 0, 52, 2,  8, 7, 19, 3,  1, 6, 87, 5, 86, 4, 66, 
    5, 12, 6, 99, 0, 65, 3, 63, 1,  9, 8, 63, 7,  3, 2, 24, 4, 58
  };
  const int q9753[] = {
    9, 9, // Number of jobs and machines
    7, 59, 6, 53, 1, 11, 2, 40, 3, 50, 8, 10, 5, 57, 4, 72, 0, 51, 
    8, 74, 2, 44, 4, 70, 5, 82, 3, 31, 1, 91, 6, 45, 7, 66, 0, 80, 
    1, 47, 4, 75, 7,  1, 6, 33, 8,  1, 2, 48, 0, 18, 3, 77, 5, 97, 
    4, 38, 5, 62, 3, 54, 8, 69, 6, 92, 0, 90, 7, 31, 2, 46, 1, 14, 
    2, 55, 4, 91, 1, 41, 8, 47, 6, 85, 5, 13, 3, 83, 0, 41, 7, 15, 
    7, 67, 0, 36, 2, 50, 6, 10, 1, 83, 3,  9, 8, 85, 4, 51, 5, 64, 
    7, 55, 0, 42, 5, 62, 3, 74, 8, 71, 2, 20, 1, 82, 6, 66, 4, 21, 
    3, 73, 6, 61, 7, 22, 1, 30, 4,  1, 0, 26, 2, 38, 5, 57, 8, 74, 
    7, 67, 1, 40, 8,  6, 5, 87, 2, 65, 6, 42, 4, 74, 3, 25, 0, 95
  };
  const int q9754[] = {
    9, 9, // Number of jobs and machines
    3, 39, 2, 98, 4, 85, 6, 72, 0, 39, 8, 67, 5, 98, 7, 39, 1, 29, 
    7, 52, 1, 67, 3, 30, 0, 24, 8, 79, 5, 89, 6, 75, 2,  5, 4, 83, 
    7, 22, 4, 33, 2, 21, 3, 79, 0,  3, 6, 88, 8, 33, 1, 63, 5, 80, 
    5, 32, 2, 83, 6, 60, 8, 29, 1,  4, 3, 76, 7, 81, 4, 97, 0, 13, 
    2, 15, 7, 28, 8, 51, 6, 26, 1, 61, 3, 51, 4, 80, 5, 54, 0, 57, 
    7,  3, 1, 90, 2, 71, 0, 90, 6, 47, 4, 99, 5, 30, 8, 26, 3, 68, 
    8, 49, 1, 91, 0, 31, 5, 54, 4, 49, 3, 37, 2, 60, 6,  7, 7, 68, 
    7, 18, 8, 92, 4, 16, 2, 70, 0, 98, 6, 19, 1, 25, 5, 63, 3, 21, 
    4, 74, 7, 17, 8, 70, 0, 70, 5, 41, 3, 16, 1, 75, 2, 81, 6, 23
  };
  const int q9755[] = {
    9, 9, // Number of jobs and machines
    7, 69, 6,  3, 2, 62, 5, 71, 0, 42, 4,  7, 8, 66, 3, 56, 1, 22, 
    1, 53, 0, 42, 4, 12, 2,  6, 3,  4, 8, 65, 5, 87, 6, 16, 7, 88, 
    0, 73, 1, 82, 3, 43, 8, 96, 2, 38, 5,  7, 6, 64, 4, 46, 7, 77, 
    0, 94, 7,  3, 8, 28, 4, 55, 6, 67, 5, 70, 3, 88, 2, 20, 1, 37, 
    5, 33, 1, 24, 7, 92, 6, 13, 8, 84, 3, 71, 4, 37, 0, 25, 2, 20, 
    2, 82, 1,  2, 5, 76, 3, 79, 6, 87, 8, 73, 7, 34, 4, 97, 0, 42, 
    0, 41, 2,  1, 1, 39, 7, 48, 6, 32, 3, 88, 4, 49, 8, 66, 5, 27, 
    6,  8, 0, 41, 7, 15, 3, 57, 8, 19, 2, 11, 1,  1, 4, 25, 5,  5, 
    0, 56, 6, 94, 7, 72, 1, 62, 5, 59, 4, 95, 8, 81, 3, 42, 2, 52
  };
  const int q9756[] = {
    9, 9, // Number of jobs and machines
    7, 57, 2, 51, 5, 31, 0, 76, 3, 27, 8,  2, 6, 75, 4, 66, 1, 97, 
    8, 23, 4, 43, 6, 30, 0, 44, 3, 30, 5, 45, 7, 75, 1, 85, 2, 34, 
    6,  2, 0, 23, 3,  2, 2, 74, 7, 67, 5, 32, 4,  7, 1, 73, 8, 22, 
    1, 91, 2, 35, 8, 55, 4, 96, 6, 84, 5, 68, 3, 20, 7, 85, 0, 63, 
    2, 59, 1,  1, 7, 10, 5, 89, 0, 84, 6, 45, 8, 23, 3, 31, 4, 57, 
    4, 42, 6, 83, 1, 79, 7,  2, 0, 33, 8, 98, 5, 92, 2, 12, 3, 23, 
    3, 49, 2, 88, 0, 63, 1, 59, 6, 15, 8, 60, 7, 26, 4, 32, 5, 22, 
    2, 35, 5, 63, 8, 91, 1, 32, 0, 94, 6, 86, 3, 31, 4, 94, 7, 78, 
    1, 80, 4, 19, 3, 91, 6, 92, 7, 78, 5, 85, 0, 28, 2, 41, 8, 55
  };
  const int q9757[] = {
    9, 9, // Number of jobs and machines
    1, 78, 7, 53, 5, 73, 0, 31, 3, 28, 2, 34, 6, 97, 4, 18, 8, 72, 
    1,  3, 2, 94, 0, 97, 3, 69, 8, 95, 5, 36, 6,  4, 4, 43, 7, 35, 
    1, 64, 5, 93, 7, 65, 3,  2, 8, 39, 2, 34, 6,  6, 4, 11, 0, 44, 
    2, 50, 1,  9, 7,  1, 8, 42, 3, 79, 5, 43, 6, 15, 4, 92, 0, 10, 
    2, 80, 4, 78, 8,  4, 0,  4, 7, 45, 5, 76, 6, 91, 1, 54, 3, 91, 
    1, 24, 2, 49, 5, 56, 0,  5, 4, 39, 7, 78, 3,  9, 8, 48, 6, 65, 
    8, 19, 5, 72, 1, 35, 2, 21, 0, 77, 3,  7, 7,  6, 6, 12, 4, 85, 
    3, 41, 4, 80, 5, 31, 1, 76, 2,  5, 7,  5, 0,  2, 8, 35, 6, 44, 
    7, 44, 8, 71, 2, 45, 3, 79, 5, 22, 6,  7, 0, 54, 1, 28, 4,  6
  };
  const int q9758[] = {
    9, 9, // Number of jobs and machines
    0, 91, 6, 87, 8, 58, 7, 33, 1, 35, 2, 65, 3, 13, 4, 92, 5, 85, 
    2, 13, 7, 14, 6, 87, 1, 51, 0, 99, 5,  4, 3, 11, 8, 10, 4, 89, 
    5, 37, 1, 98, 3,  8, 4, 66, 7, 50, 2, 29, 0, 22, 8, 81, 6, 72, 
    4, 48, 6, 76, 7, 84, 0, 37, 1,  5, 8, 98, 3, 48, 2, 23, 5, 47, 
    7, 99, 2, 17, 1, 92, 3, 39, 0, 10, 5,  1, 6, 72, 8, 43, 4,  7, 
    4, 22, 8, 99, 5, 72, 1, 74, 0, 30, 2, 52, 3, 73, 6, 69, 7, 61, 
    3, 48, 0, 29, 8, 37, 6, 76, 2, 19, 1,  9, 4, 18, 7,  8, 5, 99, 
    8, 21, 3, 81, 1, 96, 7, 19, 5, 80, 0, 30, 4, 31, 2, 20, 6, 34, 
    4, 41, 7, 68, 0, 56, 1, 78, 6, 74, 8, 91, 2,  5, 5, 31, 3, 13
  };
  const int q9759[] = {
    9, 9, // Number of jobs and machines
    2, 74, 5, 22, 6, 52, 3, 33, 8, 10, 4, 64, 1, 69, 7, 28, 0, 88, 
    2,  2, 8, 83, 0, 90, 3, 94, 6, 36, 5, 89, 7, 30, 4, 62, 1,  4, 
    6, 32, 5, 80, 0, 90, 7, 27, 8, 57, 1, 85, 3, 31, 2,  4, 4, 37, 
    5, 52, 7, 48, 0, 35, 1, 75, 2, 46, 8, 48, 3, 19, 6, 61, 4, 42, 
    7, 25, 4, 13, 1, 63, 3, 34, 6, 25, 2, 92, 0, 10, 8, 92, 5, 84, 
    7, 73, 5, 38, 6, 10, 1, 30, 3, 27, 0, 97, 4, 28, 8, 67, 2, 35, 
    4, 68, 5, 98, 8, 81, 2, 86, 3,  3, 1, 58, 7, 80, 6, 29, 0, 94, 
    0, 13, 6, 90, 1, 92, 5, 41, 4, 68, 2, 37, 7, 45, 3, 67, 8, 45, 
    1, 13, 5, 58, 6, 47, 4, 62, 7, 45, 8, 39, 0, 24, 3, 48, 2,  6
  };
  const int q9760[] = {
    9, 9, // Number of jobs and machines
    5, 31, 4, 61, 3, 50, 2, 41, 0, 40, 8, 64, 1, 44, 6,  8, 7, 52, 
    5, 95, 4, 48, 0, 98, 8, 71, 3, 26, 7, 49, 2, 94, 1, 72, 6, 95, 
    0, 95, 3,  4, 6, 11, 8, 14, 5, 53, 7,  5, 1, 98, 2, 43, 4, 84, 
    2, 41, 8, 86, 0,  5, 1, 36, 5, 54, 6, 71, 3, 69, 7, 48, 4, 52, 
    4, 48, 0, 85, 8, 17, 3, 80, 5, 40, 1, 58, 6, 60, 7, 97, 2, 56, 
    5, 44, 8, 72, 1, 99, 4, 51, 3, 25, 6, 69, 7, 46, 0, 59, 2, 50, 
    8, 32, 4, 53, 2, 88, 3,  7, 7, 42, 1,  6, 0, 82, 5, 88, 6, 30, 
    0, 95, 3, 18, 6, 30, 1, 18, 5, 73, 2, 54, 8, 47, 7, 58, 4, 34, 
    8, 48, 7, 72, 5, 54, 3, 45, 6,  1, 1, 18, 4, 19, 0, 44, 2, 42
  };
  const int q9761[] = {
    9, 9, // Number of jobs and machines
    7, 15, 3, 26, 0, 26, 4, 48, 1, 99, 6, 85, 8, 14, 5, 86, 2, 86, 
    4, 16, 2, 10, 0, 93, 1, 81, 5, 36, 7, 71, 6, 57, 3, 52, 8, 64, 
    0, 69, 3, 97, 4, 15, 6,  8, 1, 99, 5, 65, 8, 57, 2, 67, 7, 12, 
    5, 78, 1, 61, 7, 38, 3, 43, 2,  4, 6,  8, 4, 18, 0, 45, 8, 45, 
    4, 66, 7, 31, 2, 50, 5, 24, 0,  7, 8, 29, 6,  5, 1, 13, 3, 96, 
    0, 31, 1, 65, 6, 28, 8, 61, 5, 12, 2, 58, 7, 61, 3, 65, 4, 17, 
    4, 81, 7, 81, 5, 16, 2, 27, 0, 70, 3, 63, 1, 79, 6, 25, 8, 85, 
    7,  7, 5, 11, 8, 55, 2, 53, 6,  2, 3, 55, 1, 69, 4, 21, 0,  2, 
    0, 49, 5, 36, 7, 48, 4, 66, 3,  9, 8, 13, 2, 81, 6, 12, 1, 59
  };
  const int q9762[] = {
    9, 9, // Number of jobs and machines
    6, 49, 4, 10, 3, 71, 7, 40, 1,  3, 0, 43, 5, 80, 8, 73, 2, 90, 
    5, 45, 2, 66, 0,  4, 8,  5, 4, 94, 7,  6, 3, 77, 6, 26, 1, 60, 
    3, 34, 6,  1, 8, 24, 5, 62, 4, 77, 1, 16, 7, 85, 0, 48, 2, 53, 
    4, 55, 8, 74, 1, 16, 0, 73, 3, 40, 2, 15, 6, 36, 7, 45, 5, 13, 
    6, 17, 1,  6, 4, 76, 8, 19, 7, 94, 2, 14, 3,  5, 5, 86, 0, 34, 
    0, 18, 6, 39, 1, 41, 3, 16, 8, 29, 7, 59, 2, 21, 5,  1, 4, 75, 
    6, 51, 1, 66, 3, 93, 5, 23, 2, 97, 7, 71, 4, 54, 8, 73, 0, 11, 
    3, 44, 0, 25, 7, 12, 4, 16, 2, 86, 1, 87, 6, 45, 8, 57, 5,  4, 
    2, 70, 6, 32, 8, 83, 0, 12, 1, 89, 4, 43, 7,  2, 3, 99, 5, 64
  };
  const int q9763[] = {
    9, 9, // Number of jobs and machines
    4, 14, 2, 22, 8, 54, 6, 10, 0, 91, 7, 78, 3,  1, 1, 64, 5, 14, 
    4, 88, 2, 27, 8,  6, 5,  3, 1, 32, 6, 78, 3, 34, 0, 37, 7, 35, 
    8, 45, 0, 38, 3, 39, 6, 81, 2, 76, 5, 40, 7, 70, 1, 86, 4, 62, 
    3, 56, 4, 55, 2, 42, 7,  4, 0, 96, 8, 20, 5, 55, 1,  9, 6, 28, 
    2, 74, 0, 36, 8, 54, 4, 24, 1, 52, 3, 53, 6, 82, 5, 53, 7, 82, 
    2, 55, 0, 69, 1, 31, 6, 56, 3,  3, 5, 94, 4, 42, 7,  1, 8, 93, 
    4, 19, 5,  1, 0, 18, 7, 50, 8,  9, 1, 31, 6, 92, 2,  2, 3, 66, 
    5, 92, 7, 29, 1, 40, 8, 63, 3, 50, 0, 68, 6, 31, 4, 97, 2,  1, 
    7, 11, 4, 98, 0, 35, 8, 32, 1, 12, 2, 34, 5,  9, 3, 11, 6, 18
  };
  const int q9764[] = {
    9, 9, // Number of jobs and machines
    2, 97, 3, 33, 4, 16, 0,  7, 1, 74, 7, 13, 6,  1, 8, 96, 5, 14, 
    1,  9, 0, 76, 3, 67, 2, 95, 6, 17, 4, 72, 5, 68, 7, 93, 8, 76, 
    0, 41, 1, 88, 6, 78, 2, 14, 3, 10, 8, 84, 7,  9, 5, 90, 4, 89, 
    5, 92, 2, 42, 0, 12, 6, 80, 1, 62, 8, 56, 7, 27, 4, 40, 3,  9, 
    0, 43, 5, 67, 8, 36, 4, 46, 6, 79, 3, 64, 1, 25, 7, 47, 2, 36, 
    7, 39, 5, 95, 3, 99, 0, 62, 8,  9, 4,  6, 2, 66, 1, 77, 6, 38, 
    5, 24, 7, 60, 2, 79, 0, 58, 1, 35, 6, 65, 4,  4, 3, 49, 8, 98, 
    7, 96, 1, 46, 3, 64, 8, 78, 2, 77, 5, 51, 0, 39, 6, 67, 4, 97, 
    0, 77, 6, 96, 3, 33, 8, 77, 4, 57, 2, 32, 7, 92, 1, 87, 5, 92
  };
  const int q9765[] = {
    9, 9, // Number of jobs and machines
    3, 83, 1, 18, 0, 52, 7, 51, 6, 41, 8, 79, 2, 98, 4, 79, 5, 31, 
    4, 56, 6, 18, 5, 11, 8, 30, 1, 63, 7, 13, 3, 17, 2, 88, 0,  5, 
    8, 86, 1, 94, 3, 54, 7, 13, 4, 44, 6, 58, 0, 61, 2, 36, 5, 18, 
    4, 93, 7, 52, 6,  4, 5, 99, 2, 14, 0, 29, 8, 80, 3, 50, 1, 10, 
    4, 18, 1, 87, 6, 18, 7, 61, 0, 24, 8, 61, 5, 52, 2, 36, 3, 50, 
    4, 71, 0, 49, 3, 33, 1, 21, 8, 90, 6, 10, 5, 24, 7, 58, 2, 72, 
    4, 29, 8, 24, 6, 60, 0, 45, 5, 11, 7, 57, 1, 11, 2, 95, 3, 76, 
    0, 24, 1, 62, 6, 95, 8, 65, 4, 41, 3, 79, 5, 16, 2, 17, 7, 79, 
    2, 22, 8, 81, 3, 40, 1, 25, 7, 75, 0, 41, 4,  5, 5, 18, 6, 63
  };
  const int q9766[] = {
    9, 9, // Number of jobs and machines
    7, 66, 3, 98, 1, 91, 5, 72, 2, 17, 4, 11, 0, 17, 6, 17, 8, 16, 
    3, 87, 0, 55, 2, 98, 1, 42, 8, 56, 7, 35, 4,  1, 6, 22, 5, 95, 
    0, 18, 4, 18, 6, 96, 5, 72, 7, 81, 2, 72, 8, 74, 1, 29, 3, 29, 
    5, 29, 4, 32, 8, 60, 7, 90, 0, 51, 1, 71, 6, 94, 3, 32, 2, 55, 
    7, 34, 1, 17, 5, 84, 0, 50, 6, 45, 4, 38, 3, 39, 8, 81, 2, 24, 
    8, 40, 7, 46, 1, 19, 6, 66, 4, 76, 3, 61, 2,  4, 5, 22, 0,  9, 
    7, 38, 2, 38, 1, 77, 0, 58, 5, 35, 8,  7, 3,  4, 4, 33, 6, 34, 
    7, 78, 2, 68, 0, 91, 1, 86, 5, 41, 8, 71, 3, 95, 4, 56, 6, 68, 
    1, 77, 3, 97, 4, 53, 7, 92, 6, 28, 2, 96, 5, 39, 8, 40, 0, 67
  };
  const int q9767[] = {
    9, 9, // Number of jobs and machines
    0,  2, 1, 15, 5,  2, 7, 58, 8, 26, 4, 76, 2, 19, 3, 84, 6, 41, 
    2, 90, 4, 69, 6, 24, 3, 52, 8, 69, 7, 78, 5, 43, 0, 12, 1, 30, 
    5,  4, 8, 11, 0,  4, 1, 30, 7, 38, 6, 65, 4, 27, 2,  3, 3, 89, 
    3, 80, 6, 25, 2, 97, 5,  7, 8, 42, 1, 13, 7, 91, 0, 46, 4, 95, 
    0, 88, 6,  5, 3, 29, 4, 86, 2, 32, 8, 35, 1, 14, 7, 53, 5, 26, 
    0, 35, 7,  6, 4, 97, 8, 26, 5, 30, 6, 71, 1, 34, 2, 39, 3, 82, 
    7, 95, 0, 38, 1,  9, 5, 86, 4, 80, 8, 30, 6, 34, 2, 26, 3, 64, 
    2, 87, 8, 11, 0,  6, 3, 66, 4, 97, 6, 80, 5, 66, 1,  6, 7, 51, 
    2, 20, 7, 32, 6, 93, 4, 89, 8, 47, 1, 35, 0, 92, 5, 32, 3, 84
  };
  const int q9768[] = {
    9, 9, // Number of jobs and machines
    7, 48, 6, 64, 1, 83, 4, 61, 2, 70, 0,  8, 5, 98, 8, 53, 3, 86, 
    4, 50, 8, 31, 7, 22, 3, 89, 0, 25, 1, 76, 5, 38, 6, 73, 2, 56, 
    6, 98, 5, 97, 0, 96, 8, 22, 2, 59, 3, 93, 4, 98, 7, 41, 1, 59, 
    8, 51, 0, 11, 5,  5, 3, 86, 6, 24, 4, 53, 2, 86, 7, 80, 1,  5, 
    7, 96, 2, 30, 1, 32, 4, 33, 8, 31, 6, 95, 5, 60, 0, 56, 3, 25, 
    7, 82, 3,  6, 5, 30, 8, 72, 4,  4, 0, 61, 1, 77, 2, 33, 6, 63, 
    3, 10, 6, 44, 0, 66, 8, 38, 7, 23, 4, 72, 5, 15, 1, 43, 2, 30, 
    2,  9, 7, 47, 6, 65, 4, 29, 3, 81, 8, 34, 5, 57, 1, 82, 0, 31, 
    7, 61, 2, 14, 1, 56, 5, 15, 0, 35, 8, 85, 6,  6, 3, 20, 4, 89
  };
  const int q9769[] = {
    9, 9, // Number of jobs and machines
    8,  1, 2, 48, 4, 22, 0, 94, 1, 52, 7, 55, 6, 98, 3,  4, 5, 32, 
    2, 65, 6, 16, 1, 28, 4, 38, 8, 37, 7, 97, 5, 98, 3, 50, 0, 36, 
    1, 82, 8, 44, 7, 36, 5, 67, 6, 27, 2, 79, 0, 20, 3, 52, 4, 76, 
    1, 68, 4, 71, 5, 15, 7, 25, 3, 46, 2, 17, 6, 48, 8, 66, 0, 82, 
    3, 44, 0, 25, 5, 93, 4, 43, 1, 54, 8, 52, 2, 18, 7,  7, 6, 45, 
    2, 62, 4, 63, 6, 25, 5, 36, 0, 56, 8, 82, 3, 11, 7, 89, 1, 11, 
    2, 22, 7, 38, 8,  7, 1, 24, 3,  9, 5, 28, 4, 92, 6, 43, 0, 16, 
    3, 81, 4, 59, 7, 91, 1, 48, 8, 97, 5, 69, 0, 63, 6, 53, 2, 90, 
    4, 68, 5, 25, 3, 51, 6, 95, 0, 88, 8, 73, 2, 68, 7, 17, 1, 50
  };
  const int q9770[] = {
    9, 9, // Number of jobs and machines
    5, 92, 2, 13, 0,  5, 6, 70, 4, 90, 3, 18, 1, 46, 7,  9, 8, 34, 
    3,  7, 1, 36, 6, 81, 4, 83, 7, 60, 2, 90, 0, 41, 8, 30, 5, 27, 
    4,  8, 1, 63, 2, 89, 8, 58, 0, 31, 7, 43, 5, 80, 3, 39, 6, 17, 
    3, 80, 5,  5, 1, 53, 6, 58, 2, 31, 7,  5, 0, 15, 4, 61, 8, 45, 
    4, 51, 3, 92, 7, 80, 8, 34, 2, 59, 5, 12, 6, 65, 0, 77, 1, 64, 
    3, 49, 7, 21, 1, 25, 4, 22, 6, 94, 0, 35, 2, 33, 8, 33, 5, 20, 
    8, 21, 6, 91, 5, 56, 3, 64, 1, 62, 4, 73, 0,  9, 7, 15, 2, 16, 
    3, 65, 8, 85, 4, 45, 7,  8, 1, 58, 6, 12, 2, 26, 0, 25, 5, 76, 
    2, 71, 7, 30, 6, 57, 5, 57, 1, 44, 3, 43, 0, 59, 4, 54, 8, 77
  };
  const int q9771[] = {
    9, 9, // Number of jobs and machines
    7,  7, 0, 64, 8, 66, 2, 65, 3, 60, 1, 88, 5, 17, 6,  7, 4, 52, 
    0, 85, 2, 65, 5, 75, 6, 31, 8, 94, 1, 27, 4, 69, 3, 23, 7, 22, 
    1, 35, 8, 56, 3, 81, 4, 17, 2, 43, 5, 61, 7, 25, 6, 61, 0, 58, 
    7, 74, 4, 11, 0, 82, 5, 68, 1, 25, 6, 81, 3, 35, 8, 59, 2, 80, 
    8, 35, 2, 38, 1, 91, 7, 20, 5, 60, 4, 18, 6, 12, 0, 20, 3, 22, 
    1, 43, 7, 11, 2, 30, 5, 45, 0, 94, 6, 12, 8, 45, 3, 35, 4, 18, 
    7, 99, 5, 82, 4, 28, 1, 68, 2, 95, 3, 37, 8, 47, 6, 49, 0, 79, 
    7,  7, 6, 67, 8, 43, 2, 25, 5, 27, 1, 38, 3, 14, 0, 23, 4, 69, 
    6, 88, 2, 53, 5, 77, 0,  5, 7,  2, 1, 14, 8, 26, 4, 24, 3, 71
  };
  const int q9772[] = {
    9, 9, // Number of jobs and machines
    7, 18, 0, 12, 6, 54, 2, 78, 5, 84, 3, 24, 8, 32, 1, 22, 4, 34, 
    7, 36, 5,  8, 1, 30, 6,  1, 3,  7, 4, 59, 0, 11, 8, 83, 2, 40, 
    0, 91, 8, 53, 3, 89, 4, 83, 6, 69, 1, 24, 2, 12, 5, 71, 7, 93, 
    1, 29, 7,  8, 8,  8, 0, 69, 5,  7, 4, 46, 2,  8, 6,  2, 3, 28, 
    1, 98, 7,  1, 6, 37, 3, 52, 0, 87, 8, 16, 2, 92, 5, 35, 4, 29, 
    8, 32, 3,  4, 7, 82, 6, 75, 1, 73, 0, 29, 5, 35, 2,  3, 4, 86, 
    3, 28, 8, 80, 5, 64, 0, 87, 2, 88, 7, 10, 1, 52, 6,  1, 4, 31, 
    8, 20, 0, 74, 1, 45, 5, 41, 6, 86, 7,  6, 3, 97, 4, 90, 2, 33, 
    2, 63, 3, 72, 0, 50, 4, 37, 7, 66, 1, 40, 8, 19, 5, 85, 6, 58
  };
  const int q9773[] = {
    9, 9, // Number of jobs and machines
    1, 48, 6, 25, 7, 71, 4, 81, 2, 54, 5,  7, 3, 17, 0, 23, 8, 61, 
    2, 45, 1, 78, 8, 22, 4, 75, 6, 64, 7, 29, 3, 39, 5, 37, 0, 53, 
    4, 29, 8, 39, 7, 74, 1, 42, 2, 37, 3, 46, 6, 39, 0, 76, 5,  8, 
    7, 50, 4, 45, 3, 74, 8, 45, 5, 61, 2, 80, 1, 56, 0, 70, 6, 66, 
    1, 36, 3, 31, 2, 67, 4, 20, 0, 33, 8, 31, 7, 82, 5, 35, 6, 15, 
    7, 62, 2, 36, 4, 94, 8, 68, 6, 52, 5,  4, 1, 26, 0, 18, 3, 65, 
    0, 14, 4, 17, 7, 21, 5, 62, 2, 48, 3, 44, 1, 60, 6, 42, 8, 40, 
    2, 73, 7, 90, 0, 21, 3,  3, 5, 11, 8, 96, 1, 56, 6, 34, 4, 22, 
    3, 41, 2, 86, 6, 49, 8, 18, 1, 22, 7, 59, 5, 48, 4, 71, 0, 99
  };
  const int q9774[] = {
    9, 9, // Number of jobs and machines
    2, 59, 7, 33, 5, 13, 6, 82, 8, 44, 4, 49, 3, 74, 0, 60, 1, 32, 
    3,  9, 4, 88, 8,  4, 2, 89, 0, 65, 5, 26, 6, 12, 7, 79, 1, 42, 
    8, 66, 3,  7, 2, 61, 5, 25, 0, 83, 1, 53, 4, 39, 6, 95, 7, 81, 
    3, 50, 8, 22, 0, 95, 4,  8, 7,  7, 2, 83, 6, 59, 1, 48, 5, 64, 
    4, 87, 7, 20, 8, 29, 3, 78, 5, 82, 2, 36, 1, 77, 6, 40, 0, 10, 
    7, 84, 3, 28, 6, 42, 5, 80, 2, 48, 1, 62, 4, 78, 8, 68, 0, 99, 
    3,  2, 6, 11, 0, 33, 8,  2, 4, 57, 2, 18, 5, 54, 1, 81, 7, 98, 
    4, 74, 5, 28, 1, 35, 2, 98, 7, 39, 3, 73, 8, 85, 0, 81, 6,  7, 
    5, 33, 8, 88, 4,  1, 6, 92, 0, 21, 7, 27, 3, 37, 1, 74, 2, 69
  };
  const int q9775[] = {
    9, 9, // Number of jobs and machines
    7,  5, 6, 36, 5, 55, 3, 11, 0, 38, 4, 49, 8, 57, 1, 67, 2, 69, 
    7, 90, 2,  9, 1,  1, 8, 56, 5, 70, 0, 88, 4, 31, 3, 51, 6, 53, 
    4, 85, 6, 67, 2, 31, 1, 45, 7, 65, 3, 61, 5, 70, 0, 10, 8, 30, 
    5, 13, 8, 94, 1, 34, 4, 95, 0, 25, 2, 23, 7, 70, 6, 65, 3, 68, 
    5, 14, 7, 13, 6, 48, 8, 38, 4, 70, 2, 15, 3, 13, 0, 24, 1, 28, 
    2, 32, 5, 54, 8, 13, 7, 74, 1, 68, 4, 10, 6, 14, 3, 45, 0, 62, 
    2, 36, 4,  2, 0, 16, 8, 11, 5, 17, 3, 32, 7, 25, 1, 24, 6, 23, 
    6,  5, 0, 80, 5, 22, 7, 58, 2, 27, 1, 54, 3, 79, 8,  1, 4, 65, 
    4, 41, 7,  4, 1, 65, 6, 22, 0, 60, 5, 15, 2, 62, 8,  9, 3, 86
  };
  const int q9776[] = {
    9, 9, // Number of jobs and machines
    0, 41, 4, 91, 7, 81, 6, 91, 1, 73, 8, 36, 3, 83, 5, 78, 2, 53, 
    4, 91, 6, 70, 0, 58, 5, 81, 2, 76, 1,  1, 3, 69, 8, 79, 7, 89, 
    7, 35, 6, 79, 4, 64, 1, 10, 3, 29, 2, 81, 0,  4, 5, 74, 8, 50, 
    6, 16, 1, 77, 5, 17, 2, 82, 3, 49, 4,  5, 0, 50, 7, 83, 8, 65, 
    1, 66, 6, 47, 5, 94, 3, 24, 2, 91, 8, 45, 4, 90, 0, 82, 7, 96, 
    8, 46, 0, 63, 1, 27, 2, 27, 6,  6, 5, 40, 4, 97, 3, 37, 7, 71, 
    7, 12, 3, 11, 6, 31, 5, 18, 4, 70, 1, 26, 0, 91, 8, 21, 2, 95, 
    1, 98, 0, 34, 6, 81, 4, 88, 5, 14, 2, 60, 3, 75, 8, 45, 7, 90, 
    7, 52, 1, 53, 6, 32, 2, 19, 0, 54, 5, 95, 8, 53, 3, 36, 4, 85
  };
  const int q9777[] = {
    9, 9, // Number of jobs and machines
    0, 83, 6, 92, 7, 54, 1, 79, 3,  4, 8, 42, 4,  4, 2, 38, 5, 16, 
    3, 88, 4, 19, 5, 66, 6, 38, 8, 17, 2, 43, 0, 99, 7, 76, 1, 64, 
    1,  8, 0, 43, 4, 68, 7, 26, 2, 68, 6, 22, 5, 25, 3, 40, 8, 71, 
    4,  4, 7, 82, 3, 25, 1, 91, 2, 17, 5, 51, 6, 88, 0,  8, 8, 43, 
    7, 97, 0, 71, 8, 33, 2, 56, 3,  4, 4,  5, 5,  9, 1, 91, 6, 91, 
    6, 83, 1, 22, 8, 40, 4, 77, 0, 38, 5, 36, 7, 93, 2,  1, 3, 58, 
    0, 17, 4,  8, 6, 57, 2, 23, 8, 24, 3, 46, 1, 95, 5, 93, 7, 13, 
    6, 77, 0,  5, 5,  2, 1, 59, 2,  9, 7, 80, 8, 88, 4,  7, 3, 29, 
    5, 71, 4, 67, 6, 95, 7, 40, 1, 65, 0, 80, 8, 43, 2, 72, 3, 21
  };
  const int q9778[] = {
    9, 9, // Number of jobs and machines
    2, 99, 3, 75, 1, 52, 6, 59, 0, 95, 7, 53, 8, 18, 5, 45, 4,  8, 
    8, 31, 3, 34, 7, 23, 6, 59, 5, 89, 1, 47, 2, 63, 4, 88, 0, 60, 
    1, 71, 4, 39, 5, 80, 7, 91, 8, 78, 6, 64, 0, 25, 2, 90, 3, 58, 
    7, 11, 2, 20, 0, 96, 6, 77, 3, 39, 4, 76, 1, 73, 8, 30, 5, 10, 
    7, 77, 8, 75, 5, 45, 6,  1, 2, 37, 3, 71, 0, 65, 4, 43, 1, 15, 
    6, 10, 0, 18, 2, 68, 8, 44, 4, 76, 5, 68, 3, 53, 7, 70, 1, 39, 
    0, 19, 5, 52, 7, 80, 3, 98, 2, 63, 4, 72, 8, 28, 1,  2, 6, 29, 
    8, 60, 2, 52, 4, 47, 3, 92, 0, 99, 6, 39, 7, 91, 5, 67, 1, 58, 
    4, 19, 5, 46, 1,  3, 3, 49, 2, 14, 7, 47, 0, 39, 8, 93, 6, 99
  };
  const int q9779[] = {
    9, 9, // Number of jobs and machines
    2, 87, 6, 84, 5, 98, 0, 30, 8, 23, 1, 96, 7, 21, 3, 63, 4, 75, 
    8, 19, 4, 72, 6, 25, 3, 78, 2,  9, 5, 12, 0, 35, 1, 99, 7, 19, 
    5, 76, 1, 72, 0, 89, 4, 81, 2, 70, 7, 78, 3, 59, 6, 15, 8, 50, 
    3, 11, 2, 56, 7, 36, 6, 31, 0, 21, 5, 34, 4, 83, 1, 88, 8, 93, 
    4, 63, 8, 58, 6,  5, 5, 37, 2, 64, 3, 15, 0, 62, 7, 63, 1, 99, 
    5, 82, 0, 89, 6,  7, 2, 96, 3, 14, 4, 67, 1, 93, 8, 17, 7, 87, 
    1, 34, 7, 72, 2, 25, 0, 62, 8, 92, 6, 53, 5, 24, 4, 66, 3, 91, 
    8,  3, 6, 93, 0, 34, 5, 18, 2, 60, 3, 20, 7,  9, 1, 19, 4, 51, 
    0, 95, 6, 51, 4, 92, 7, 48, 3, 84, 1, 81, 8, 52, 5, 96, 2, 24
  };
  const int q9780[] = {
    9, 9, // Number of jobs and machines
    1, 33, 0, 85, 4, 88, 5, 34, 3, 86, 8, 94, 6, 33, 7, 84, 2, 75, 
    2, 49, 4, 57, 7, 98, 6, 59, 1, 42, 3, 31, 0, 87, 5, 31, 8, 64, 
    8, 40, 1, 12, 4, 61, 5, 95, 6, 56, 2,  5, 3, 48, 0, 98, 7, 61, 
    0,  5, 4, 16, 6, 39, 2,  6, 1, 88, 7, 32, 3,  7, 5, 47, 8, 81, 
    8, 29, 6, 27, 2, 27, 0, 80, 1, 66, 5, 33, 4, 57, 3, 39, 7, 36, 
    8, 51, 4, 98, 2, 36, 1, 56, 3, 31, 6,  2, 5,  3, 7, 42, 0, 33, 
    0, 49, 1, 48, 8, 88, 3, 54, 7, 58, 2, 23, 4, 32, 6, 93, 5, 14, 
    8,  8, 3, 28, 0, 54, 7, 58, 6, 26, 5,  9, 2, 79, 1, 98, 4, 33, 
    5, 99, 2, 61, 4, 21, 1,  8, 6, 78, 7, 78, 8, 19, 0, 24, 3, 26
  };
  const int q9781[] = {
    9, 9, // Number of jobs and machines
    2, 38, 5, 72, 8, 53, 0, 73, 4,  9, 3, 45, 1, 73, 6, 64, 7, 92, 
    2,  4, 6, 66, 0, 19, 8, 88, 5, 79, 3, 26, 4, 43, 7, 75, 1, 22, 
    1, 16, 8, 60, 4, 36, 2, 65, 6, 50, 0, 48, 7,  1, 5, 35, 3, 52, 
    7, 25, 5, 64, 6, 96, 8, 56, 1, 68, 4, 41, 2, 16, 0, 85, 3, 35, 
    0, 48, 5, 97, 4, 18, 3,  1, 7,  2, 1, 14, 2, 16, 8, 82, 6, 49, 
    8, 54, 4, 43, 2, 40, 1, 86, 7, 97, 5, 90, 3, 30, 0, 21, 6, 89, 
    5, 73, 6, 21, 3,  7, 8, 21, 0, 34, 4,  5, 7, 47, 2,  5, 1,  9, 
    4, 71, 8, 24, 5, 93, 0, 36, 3, 71, 1,  4, 6, 19, 7, 77, 2,  6, 
    2, 78, 5, 47, 8, 32, 0, 10, 3, 90, 6, 39, 7, 72, 4,  3, 1, 82
  };
  const int q9782[] = {
    9, 9, // Number of jobs and machines
    3, 98, 8, 94, 4, 81, 0, 50, 5,  8, 2, 96, 6, 41, 1, 25, 7, 58, 
    3, 71, 2, 20, 5, 29, 4,  8, 7, 25, 8, 56, 1, 77, 6, 99, 0, 39, 
    7, 40, 1, 96, 6,  6, 2, 71, 0, 55, 3, 81, 4, 82, 8, 74, 5,  8, 
    7, 22, 3,  9, 2, 98, 5,  5, 0, 54, 6, 55, 1, 93, 8, 24, 4, 81, 
    8, 16, 2, 11, 4, 55, 3, 74, 6, 26, 7, 91, 0,  7, 1, 58, 5, 65, 
    5, 91, 3, 93, 1, 95, 7, 30, 4, 82, 2, 45, 8, 35, 6, 40, 0, 71, 
    0,  2, 2, 79, 6, 74, 1, 47, 5, 59, 8, 14, 4, 12, 3, 78, 7, 68, 
    6, 96, 7, 78, 1, 96, 5,  9, 4, 61, 3, 49, 0, 98, 8, 51, 2, 67, 
    5,  5, 1, 43, 4, 43, 2, 73, 7, 23, 0, 91, 6, 11, 3, 86, 8, 87
  };
  const int q9783[] = {
    9, 9, // Number of jobs and machines
    4, 75, 0, 88, 7, 15, 2, 37, 6, 62, 3, 46, 8, 17, 1, 87, 5, 34, 
    8, 15, 6, 51, 4, 72, 2,  3, 1, 80, 5,  3, 0, 62, 7, 64, 3, 34, 
    1, 31, 0, 23, 4, 86, 7, 42, 2, 16, 5, 82, 3,  9, 6, 90, 8, 51, 
    5, 32, 7, 10, 2, 89, 1, 20, 6, 20, 0, 88, 3, 73, 8, 96, 4, 81, 
    0, 65, 8, 78, 4, 33, 5,  6, 7, 96, 3, 40, 6, 24, 2, 90, 1, 43, 
    5, 41, 0, 42, 7, 60, 6, 68, 4,  4, 1, 50, 2, 27, 8, 71, 3, 37, 
    6,  9, 7, 14, 8, 23, 3, 73, 1, 77, 2, 22, 5, 25, 0, 61, 4,  5, 
    3, 74, 4, 47, 6, 33, 1, 18, 7, 85, 0,  5, 2, 79, 8, 19, 5, 90, 
    7, 16, 0, 11, 5, 70, 4, 87, 3, 58, 6, 75, 2, 14, 1, 50, 8, 96
  };
  const int q9784[] = {
    9, 9, // Number of jobs and machines
    2, 50, 0, 92, 8, 83, 7, 12, 6, 77, 5, 47, 1,  8, 4, 70, 3, 28, 
    1, 30, 6, 32, 7, 76, 5, 34, 4, 64, 8, 98, 0, 13, 2, 59, 3, 99, 
    3,  2, 2, 14, 7, 44, 5, 29, 8, 59, 1, 61, 0, 34, 6,  5, 4, 73, 
    4, 21, 0, 92, 1, 89, 3, 87, 5, 80, 7, 80, 6, 90, 2, 83, 8, 91, 
    6, 25, 1, 92, 8, 74, 3, 25, 7, 77, 0, 74, 2, 44, 5, 39, 4, 58, 
    5, 86, 4, 62, 2, 78, 1, 96, 6, 49, 8, 43, 7, 26, 3, 18, 0, 19, 
    6, 79, 1,  9, 3, 94, 0, 11, 8, 28, 7, 71, 4, 87, 2, 89, 5,  4, 
    4, 39, 6, 14, 8, 32, 1, 31, 2, 99, 3,  6, 5, 19, 0, 87, 7, 79, 
    4, 14, 0, 42, 5, 33, 6, 84, 7, 27, 2, 84, 8, 86, 1,  2, 3, 39
  };
  const int q9785[] = {
    9, 9, // Number of jobs and machines
    2,  7, 4, 39, 1, 81, 7, 29, 3, 95, 8, 96, 6, 85, 5, 89, 0, 97, 
    7, 23, 5, 32, 2, 48, 0, 74, 6, 50, 3, 42, 4, 34, 1,  2, 8, 85, 
    6, 43, 3, 66, 2,  4, 5, 11, 8, 49, 0, 20, 4, 58, 7, 74, 1, 60, 
    8, 95, 6, 54, 3, 24, 4, 53, 0, 88, 7, 98, 5, 40, 2, 19, 1, 21, 
    8, 95, 2, 24, 4, 24, 7, 61, 0, 62, 6, 62, 3,  7, 1, 32, 5, 62, 
    1, 37, 0, 98, 3, 76, 7, 68, 2, 10, 5, 37, 4, 94, 6, 61, 8, 32, 
    5, 56, 4, 28, 6, 45, 2, 45, 0, 63, 7, 63, 3, 81, 1,  1, 8, 55, 
    8, 63, 4, 34, 6, 41, 0, 16, 2, 47, 5, 12, 3, 73, 1, 10, 7, 76, 
    0, 59, 2, 58, 3, 68, 5, 60, 4, 23, 1, 67, 7, 39, 8, 29, 6, 56
  };
  const int q9786[] = {
    9, 9, // Number of jobs and machines
    8, 25, 1, 61, 5, 51, 7, 66, 3, 91, 6,  5, 2, 63, 4,  6, 0, 40, 
    8, 87, 4, 37, 5, 55, 3, 60, 7, 32, 6, 98, 0, 36, 1, 66, 2, 34, 
    7,  4, 4, 86, 0, 62, 8, 82, 5, 75, 3, 11, 1, 30, 6, 96, 2, 17, 
    1,  4, 3, 82, 4, 66, 8, 97, 5,  8, 7, 35, 6, 28, 0, 32, 2, 59, 
    5, 32, 4, 45, 2, 14, 7, 14, 3, 70, 1, 51, 6, 52, 0, 59, 8, 66, 
    4, 22, 3, 28, 6, 10, 5, 79, 0, 42, 1, 51, 8,  8, 2, 79, 7, 40, 
    0, 73, 2, 53, 7, 76, 3, 78, 4, 32, 1, 37, 5, 81, 8, 30, 6, 42, 
    4, 42, 6, 95, 0, 89, 2, 39, 5, 53, 3, 29, 7, 79, 8, 75, 1, 72, 
    2, 19, 6, 32, 7, 29, 1, 27, 5, 35, 3, 66, 8, 99, 4, 17, 0, 31
  };
  const int q9787[] = {
    9, 9, // Number of jobs and machines
    2,  4, 5,  4, 0, 21, 7, 73, 3, 92, 8, 79, 6, 51, 1, 31, 4, 88, 
    5, 26, 1, 85, 3, 36, 7, 63, 4, 26, 8,  2, 0, 28, 6, 54, 2, 23, 
    3, 72, 1, 63, 2, 13, 6, 64, 8, 83, 0, 94, 5, 82, 4,  6, 7,  6, 
    3, 48, 2, 18, 1, 74, 4, 10, 6, 89, 8, 76, 0, 38, 5, 75, 7, 11, 
    7, 58, 8, 45, 5, 59, 0, 35, 2, 70, 6, 89, 3, 24, 1, 71, 4, 64, 
    8, 52, 7, 29, 3, 19, 4, 74, 2,  5, 5, 10, 0, 90, 1, 58, 6, 91, 
    6, 27, 2, 52, 8, 74, 3, 83, 7, 56, 1, 45, 0, 32, 4, 46, 5, 94, 
    0, 82, 3, 84, 1, 62, 4, 79, 5, 63, 6, 13, 7, 43, 8, 73, 2, 21, 
    7, 37, 5, 63, 0, 42, 4, 67, 1, 43, 3, 36, 8,  7, 2, 88, 6, 23
  };
  const int q9788[] = {
    9, 9, // Number of jobs and machines
    8, 28, 3, 13, 7, 34, 5,  1, 2, 99, 0, 95, 6, 49, 4, 96, 1, 95, 
    7, 33, 6,  7, 1, 15, 4, 30, 5,  9, 3,  9, 2, 95, 8, 83, 0, 23, 
    8, 31, 0, 82, 6, 90, 1, 29, 2, 16, 7, 21, 5, 25, 3, 10, 4, 67, 
    5, 38, 8, 60, 7, 11, 1, 43, 0, 22, 4,  4, 2, 79, 6, 48, 3, 40, 
    4, 81, 3, 19, 1, 71, 6,  2, 7,  3, 2, 17, 0, 93, 5, 33, 8, 78, 
    8,  9, 3, 12, 4, 68, 2, 89, 0, 34, 7, 42, 6, 25, 1, 65, 5, 44, 
    7,  2, 0, 51, 6, 68, 2, 69, 3,  5, 8, 11, 4,  1, 5, 11, 1, 43, 
    2, 62, 8, 12, 5, 96, 0, 25, 4, 54, 1, 21, 3, 61, 7, 49, 6, 66, 
    1, 11, 3, 91, 0,  4, 7, 16, 4,  4, 6, 54, 2, 14, 8,  6, 5, 30
  };
  const int q9789[] = {
    9, 9, // Number of jobs and machines
    6, 83, 1, 63, 4, 68, 3, 29, 8, 33, 5, 47, 0, 55, 7, 55, 2, 89, 
    1, 49, 3,  3, 8, 85, 7,  5, 0, 63, 5, 53, 4, 48, 6, 60, 2, 29, 
    4, 71, 3,  7, 0, 35, 5, 54, 1, 99, 7, 48, 2, 92, 8, 57, 6, 88, 
    7, 61, 0, 24, 2, 68, 4, 48, 5, 60, 8, 80, 6, 98, 1, 64, 3, 17, 
    1, 12, 8, 59, 7, 82, 6, 55, 3, 23, 0, 69, 4, 73, 2, 90, 5, 27, 
    4,  6, 0, 89, 6,  1, 7, 58, 1, 28, 3,  9, 8, 66, 5, 86, 2, 39, 
    5, 95, 7, 87, 6, 70, 3, 18, 4, 53, 0, 30, 2, 71, 8, 44, 1, 15, 
    8, 55, 6, 45, 7,  6, 0, 53, 4, 47, 3, 84, 2, 32, 1, 63, 5, 49, 
    1, 36, 0, 55, 6, 99, 7, 81, 4, 27, 5, 64, 2, 67, 3, 90, 8, 92
  };
  const int q9790[] = {
    9, 9, // Number of jobs and machines
    5,  7, 8, 48, 1, 29, 3, 59, 6,  1, 2, 63, 7, 17, 0, 42, 4, 57, 
    3,  6, 7, 29, 1, 73, 5, 75, 8, 85, 2,  3, 4, 16, 6, 34, 0,  6, 
    0, 87, 1, 36, 3, 12, 6, 89, 2, 52, 7, 18, 8, 93, 5, 95, 4, 62, 
    6, 16, 0, 14, 3, 11, 4, 78, 5,  5, 1, 96, 2, 40, 8, 11, 7, 56, 
    0, 87, 3, 98, 5, 91, 7, 37, 6, 47, 4, 32, 2, 15, 1, 88, 8, 77, 
    2, 23, 4, 44, 3, 24, 0, 81, 1, 45, 7, 43, 8, 48, 5,  8, 6, 52, 
    7, 10, 6, 92, 5, 94, 4, 86, 2, 41, 0, 13, 1, 80, 3, 58, 8, 75, 
    7,  6, 3, 95, 0, 42, 1, 73, 8, 37, 6, 42, 4, 19, 5, 57, 2, 13, 
    0, 17, 6,  6, 1, 56, 7, 94, 4,  6, 5, 59, 8, 28, 3, 90, 2, 37
  };
  const int q9791[] = {
    9, 9, // Number of jobs and machines
    1, 86, 5, 82, 3, 49, 8, 38, 0, 55, 4, 44, 7, 98, 2,  8, 6, 31, 
    7, 71, 0,  6, 8, 88, 6, 58, 1, 68, 2, 61, 5, 51, 3, 24, 4, 19, 
    0, 83, 8, 10, 6, 39, 7, 45, 5, 52, 4, 11, 2, 78, 1, 16, 3, 85, 
    6, 69, 8, 54, 0, 61, 2, 18, 7, 72, 4,  1, 1,  6, 3, 24, 5, 33, 
    8, 46, 2, 38, 3,  4, 5, 18, 4, 75, 0, 74, 1,  5, 6, 94, 7, 90, 
    0, 92, 8, 11, 5, 30, 1, 12, 2, 63, 3, 91, 4, 74, 6, 40, 7, 45, 
    0, 73, 5, 99, 1, 30, 6, 29, 2, 26, 3, 17, 8, 93, 7, 29, 4, 90, 
    2, 86, 3, 74, 4, 63, 0,  3, 7, 52, 1, 28, 5, 50, 8,  9, 6,  9, 
    1, 72, 3,  3, 8, 83, 0, 89, 5, 11, 4, 41, 6, 96, 2, 44, 7, 89
  };
  const int q9792[] = {
    9, 9, // Number of jobs and machines
    2, 85, 7, 71, 8, 28, 5, 12, 6, 29, 1, 57, 0, 57, 4, 47, 3, 40, 
    6, 33, 8, 89, 4, 87, 1, 35, 7, 98, 0,  3, 3, 34, 2, 60, 5, 81, 
    4, 12, 6, 98, 3, 87, 7, 98, 0, 69, 1,  7, 5, 44, 8,  9, 2,  3, 
    7,  3, 6, 88, 3, 27, 1, 68, 8, 61, 0, 70, 2, 40, 4, 98, 5, 80, 
    5, 32, 7, 37, 4, 65, 2, 12, 1, 16, 6, 12, 8, 71, 3,  3, 0, 85, 
    8, 32, 4, 98, 7, 39, 1, 68, 2,  7, 5, 59, 6, 55, 3, 18, 0, 13, 
    4, 91, 8, 46, 0, 64, 1, 96, 5, 43, 6, 11, 7, 40, 2, 69, 3,  3, 
    3, 26, 7, 16, 1, 89, 4, 84, 8, 54, 6, 80, 5,  4, 0, 86, 2, 75, 
    8, 37, 0, 26, 3, 49, 4, 66, 1, 88, 5, 11, 7, 90, 6, 55, 2, 70
  };
  const int q9793[] = {
    9, 9, // Number of jobs and machines
    3, 97, 5, 65, 2,  8, 8, 42, 7, 59, 4, 50, 6, 34, 0, 32, 1, 10, 
    5, 56, 8, 44, 4, 56, 1, 28, 6, 78, 3, 78, 7, 47, 0, 14, 2, 75, 
    8, 80, 1, 71, 7, 83, 4, 53, 0, 29, 5, 11, 6, 26, 2, 80, 3, 63, 
    4, 34, 5, 38, 7, 17, 2, 71, 8, 50, 1, 13, 6, 15, 3, 59, 0, 97, 
    5, 78, 8, 22, 4, 70, 2,  4, 1, 68, 6, 52, 3, 17, 7, 91, 0, 18, 
    6, 18, 3, 59, 5, 21, 1, 64, 0, 96, 8,  1, 4, 55, 7, 75, 2, 43, 
    4, 39, 6, 44, 7, 19, 2, 66, 0, 47, 1, 29, 3, 70, 5, 54, 8, 90, 
    7, 45, 8, 72, 4, 96, 2,  2, 6, 44, 1, 38, 5, 37, 0, 10, 3, 34, 
    1, 36, 6, 81, 4, 61, 0, 88, 2,  2, 3, 79, 8, 31, 7, 46, 5, 85
  };
  const int q9794[] = {
    9, 9, // Number of jobs and machines
    1, 99, 4, 46, 0,  3, 3, 61, 2, 97, 6, 29, 8, 19, 7, 71, 5, 71, 
    8, 83, 7, 86, 6, 58, 1, 39, 3,  9, 5, 86, 0, 96, 2, 49, 4, 31, 
    2, 66, 7, 30, 8,  2, 0, 53, 4, 34, 1, 11, 3, 74, 6, 81, 5, 73, 
    5, 26, 0, 68, 4, 51, 7,  7, 1, 64, 3, 31, 8, 82, 2, 35, 6, 91, 
    1, 66, 6, 20, 5, 71, 3, 43, 8,  7, 4, 14, 2,  8, 0, 69, 7, 70, 
    6, 30, 3,  8, 0, 59, 5,  5, 1, 63, 7, 34, 2, 51, 4, 48, 8, 88, 
    7, 73, 6, 56, 0, 85, 4, 77, 3, 85, 8,  5, 1, 50, 5, 20, 2, 82, 
    0, 75, 2, 96, 4, 38, 6, 88, 3, 23, 8, 21, 1, 36, 5, 66, 7,  5, 
    0, 75, 1, 37, 7, 27, 3,  3, 6, 91, 2,  7, 8, 12, 4, 91, 5, 68
  };
  const int q9795[] = {
    9, 9, // Number of jobs and machines
    7, 22, 5, 10, 4, 33, 0, 60, 8, 10, 2, 33, 6, 93, 1, 79, 3,  4, 
    2, 90, 6,  5, 5, 96, 1,  8, 7, 58, 3, 35, 4, 95, 0,  3, 8, 14, 
    5, 93, 1, 11, 8, 66, 7, 46, 3,  4, 6, 33, 2, 43, 0, 26, 4,  8, 
    3, 23, 8, 91, 5, 80, 6, 27, 0, 37, 1, 81, 4, 57, 2, 33, 7,  7, 
    2, 38, 3, 41, 7,  4, 8, 49, 5,  6, 1, 55, 0, 55, 4, 63, 6, 88, 
    5, 71, 8, 45, 1,  4, 6, 70, 3, 14, 0, 74, 2, 61, 7, 46, 4,  6, 
    6, 58, 5, 29, 4, 63, 2, 31, 3,  6, 0,  5, 7, 82, 8, 90, 1, 34, 
    3, 58, 6,  3, 5, 32, 1, 86, 2, 91, 7, 87, 4, 22, 0, 97, 8, 62, 
    5, 10, 7, 28, 2, 10, 4, 81, 3, 20, 8, 14, 0, 91, 1, 63, 6, 18
  };
  const int q9796[] = {
    9, 9, // Number of jobs and machines
    4, 35, 8, 75, 0, 31, 2, 77, 5, 19, 6, 42, 7, 30, 3, 99, 1, 21, 
    6, 53, 5, 40, 7, 86, 2, 66, 4, 94, 8, 25, 1, 60, 3, 39, 0, 40, 
    1, 39, 0,  4, 8, 56, 7, 70, 5, 21, 6, 79, 2,  6, 4, 98, 3, 92, 
    2, 33, 5, 61, 4, 89, 8,  1, 6, 12, 0, 96, 1, 73, 3, 74, 7, 56, 
    6, 34, 3, 16, 0, 50, 8, 52, 1, 69, 4, 25, 5, 70, 7, 63, 2, 76, 
    3, 72, 6, 37, 2, 97, 0, 65, 1, 41, 5, 64, 4, 60, 8, 86, 7, 44, 
    4, 99, 0, 11, 7, 61, 1, 21, 3, 32, 5,  2, 6, 59, 8,  1, 2, 73, 
    1, 88, 6, 11, 7,  7, 4, 98, 5, 49, 3, 23, 2, 84, 8, 79, 0, 56, 
    8, 23, 6,  3, 5, 61, 4,  2, 0, 26, 1, 44, 3, 21, 2, 25, 7, 85
  };
  const int q9797[] = {
    9, 9, // Number of jobs and machines
    8,  2, 0, 64, 7, 95, 6, 62, 5, 97, 2, 23, 4, 88, 3,  2, 1, 93, 
    7, 18, 2,  7, 0, 67, 4, 53, 1,  7, 8, 40, 6, 13, 3, 14, 5, 58, 
    7, 73, 5, 90, 0, 72, 3, 11, 2, 34, 6, 44, 4, 43, 8, 90, 1, 74, 
    4, 75, 2, 72, 7, 97, 6, 14, 0, 37, 1, 17, 5,  5, 8, 55, 3,  4, 
    2, 28, 0, 62, 4, 12, 1, 84, 3, 75, 6, 93, 7,  8, 8, 72, 5,  2, 
    3, 22, 1, 43, 4, 90, 8, 53, 5, 82, 0,  1, 6,  9, 2,  7, 7, 66, 
    1, 28, 7, 76, 0, 59, 6, 99, 3, 98, 5, 82, 2, 72, 4, 69, 8, 58, 
    4, 85, 8, 11, 7, 52, 5, 12, 6, 47, 1, 46, 2, 44, 3, 15, 0,  7, 
    6, 16, 2, 26, 5, 94, 0,  6, 4,  8, 1,  9, 3, 64, 8, 54, 7,  7
  };
  const int q9798[] = {
    9, 9, // Number of jobs and machines
    0, 16, 1, 54, 6, 35, 3, 87, 2, 75, 7,  8, 8, 25, 5, 44, 4, 56, 
    7, 36, 8, 88, 1, 92, 0, 90, 6, 58, 4, 74, 3, 96, 2, 76, 5, 49, 
    7, 56, 8, 89, 4, 40, 2, 86, 0, 44, 6, 21, 3, 40, 1, 47, 5, 86, 
    0, 82, 8, 59, 5, 72, 4, 94, 3, 30, 7, 61, 2, 73, 6, 72, 1, 81, 
    5, 38, 0, 17, 3, 31, 8, 96, 6, 71, 2, 80, 7,  2, 4, 57, 1, 46, 
    1, 80, 8, 50, 0,  1, 7, 21, 5, 55, 2, 19, 4, 17, 3, 43, 6,  1, 
    8, 87, 7, 43, 5,  7, 3, 68, 4,  7, 1, 62, 2, 99, 6,  2, 0, 92, 
    4,  3, 3,  5, 6, 54, 5, 90, 1, 57, 0, 36, 8,  4, 2, 85, 7, 30, 
    4, 65, 6, 26, 2, 20, 7, 47, 1, 19, 0, 93, 5, 29, 8, 73, 3, 28
  };
  const int q9799[] = {
    9, 9, // Number of jobs and machines
    7, 82, 4, 75, 2, 11, 8, 18, 5, 11, 6, 15, 1, 56, 3, 90, 0, 15, 
    1, 33, 7, 23, 5, 92, 8, 50, 0, 16, 2, 47, 4, 11, 6, 34, 3,  1, 
    5, 99, 3,  2, 4, 33, 6, 73, 2, 27, 0, 15, 8, 19, 7, 20, 1, 83, 
    2, 51, 0, 65, 4, 31, 3, 41, 6, 23, 8, 73, 1, 26, 7, 89, 5, 62, 
    1, 75, 7, 94, 3, 38, 2,  3, 5, 66, 6, 19, 0,  3, 8, 64, 4, 61, 
    8, 11, 0, 88, 6, 17, 3, 37, 4, 39, 5, 85, 2, 98, 7, 41, 1, 37, 
    4, 68, 3, 15, 6,  7, 8, 94, 2, 11, 0,  6, 1,  4, 7, 63, 5, 29, 
    3, 23, 1, 89, 0, 80, 7, 50, 6, 32, 8,  9, 5, 89, 2, 72, 4, 10, 
    6, 17, 3, 33, 7, 14, 4, 38, 2, 28, 1, 55, 0, 88, 5,  1, 8,  9
  };
  const int q9800[] = {
    9, 9, // Number of jobs and machines
    4, 83, 3, 16, 6, 34, 2,  6, 7, 78, 0, 32, 5,  4, 8, 16, 1, 12, 
    1, 40, 4, 97, 2, 76, 0, 82, 3, 85, 5, 82, 7, 26, 6, 31, 8, 41, 
    1, 30, 3, 35, 8, 22, 7, 48, 5, 66, 2,  9, 0, 95, 4, 87, 6, 56, 
    5, 26, 2, 84, 6, 85, 1, 92, 8, 83, 7, 64, 3, 89, 4, 55, 0, 79, 
    0, 68, 4, 69, 2,  7, 8, 80, 7, 70, 3,  9, 1, 41, 5, 28, 6, 92, 
    8, 67, 2, 73, 3, 46, 7, 82, 1, 87, 6, 61, 5, 31, 4, 91, 0, 74, 
    0, 48, 7, 10, 4, 57, 8,  1, 3, 57, 1, 90, 6, 21, 5, 48, 2, 13, 
    5, 96, 4, 17, 6, 77, 1, 86, 7, 84, 0, 25, 3, 13, 2, 99, 8, 46, 
    5, 82, 7, 71, 6, 86, 0, 52, 8, 45, 3, 31, 1, 34, 2, 35, 4, 12
  };
  const int q9801[] = {
    9, 9, // Number of jobs and machines
    8, 44, 0, 68, 6, 44, 7, 62, 1, 53, 4, 67, 3, 60, 2, 17, 5, 88, 
    2, 78, 3,  7, 1, 32, 6, 42, 5, 37, 0, 12, 7, 93, 4, 34, 8, 78, 
    4, 67, 7, 76, 5, 90, 6, 95, 3, 16, 2, 25, 1, 43, 0, 93, 8, 84, 
    7, 37, 6, 67, 5, 77, 4, 83, 3, 47, 1,  6, 8, 20, 0, 26, 2, 67, 
    8, 49, 1, 61, 5, 51, 6, 24, 0, 95, 4, 28, 2, 66, 3, 21, 7, 46, 
    0, 34, 4,  6, 3, 74, 5, 97, 6, 31, 7, 38, 2, 34, 8, 74, 1, 89, 
    1, 31, 5, 75, 6, 34, 7, 56, 8, 58, 0, 80, 4, 91, 2, 85, 3, 70, 
    5, 28, 1, 19, 7, 56, 2, 21, 6, 30, 3, 29, 4, 81, 0, 83, 8, 46, 
    3, 94, 5, 91, 1, 31, 2, 10, 0, 91, 8, 59, 4, 45, 6, 16, 7, 46
  };
  const int q9802[] = {
    9, 9, // Number of jobs and machines
    6, 78, 7, 70, 5, 42, 8, 72, 1, 57, 4, 53, 0, 76, 3, 20, 2, 93, 
    5,  1, 4, 84, 3, 78, 2, 20, 1, 50, 8,  9, 0, 98, 7, 20, 6, 78, 
    1, 87, 4, 35, 2, 34, 5, 66, 6,  9, 3, 66, 8, 88, 7, 18, 0, 61, 
    4, 91, 0, 63, 6, 55, 7, 30, 5, 15, 1, 26, 2, 19, 3, 49, 8, 51, 
    0, 17, 6, 61, 2, 61, 3, 89, 8, 95, 4, 46, 7, 62, 1, 61, 5, 19, 
    7, 11, 6, 40, 3, 92, 2, 58, 0, 87, 8, 12, 5, 33, 4, 22, 1, 38, 
    7, 36, 6, 61, 5, 56, 3, 27, 8, 11, 2, 68, 1,  9, 0, 13, 4, 56, 
    5, 14, 0, 83, 2, 24, 3, 66, 4, 85, 6, 45, 7, 50, 8, 56, 1, 91, 
    8, 29, 3, 93, 6, 30, 2, 57, 7, 60, 0,  6, 5, 82, 1, 86, 4, 79
  };
  const int q9803[] = {
    9, 9, // Number of jobs and machines
    4, 52, 2, 64, 7, 35, 0, 79, 1, 83, 3, 93, 6, 26, 8, 50, 5, 24, 
    4, 21, 7, 96, 6, 56, 3, 31, 0, 56, 2, 72, 8, 83, 1, 38, 5, 42, 
    8, 17, 7, 77, 2, 28, 6,  7, 1, 95, 0, 22, 3, 54, 5, 55, 4, 58, 
    3,  3, 6, 56, 8, 64, 0, 56, 1,  2, 2, 55, 5,  5, 4, 57, 7, 61, 
    2, 81, 3, 15, 0, 90, 5, 87, 4, 20, 7, 41, 1, 37, 6, 99, 8, 79, 
    8, 95, 1, 73, 4, 24, 0, 35, 3, 78, 2, 31, 7, 23, 6, 70, 5, 86, 
    2, 30, 6, 24, 3, 64, 7, 26, 1, 41, 4, 68, 8, 27, 0, 55, 5,  7, 
    2, 22, 7, 32, 3, 47, 8, 49, 1, 51, 4, 83, 6, 61, 5, 15, 0, 94, 
    1, 23, 8, 69, 0, 46, 7, 52, 3, 85, 6, 66, 5, 61, 4, 28, 2, 76
  };
  const int q9804[] = {
    9, 9, // Number of jobs and machines
    4, 26, 6,  5, 8, 60, 7, 79, 3, 54, 0, 33, 5, 75, 1, 35, 2, 63, 
    2, 12, 0, 41, 8, 71, 1, 28, 3, 81, 4, 96, 7, 61, 6, 90, 5, 20, 
    0, 17, 6, 91, 7, 20, 4,  5, 2, 18, 1, 19, 3, 17, 8, 54, 5, 38, 
    0,  4, 6, 22, 4, 76, 1, 75, 2, 28, 8, 36, 3, 21, 7, 77, 5, 67, 
    3, 88, 0,  9, 4, 52, 7, 91, 1, 40, 8, 41, 2, 57, 5, 10, 6, 67, 
    3, 34, 6, 27, 8, 47, 1, 43, 4, 56, 2, 49, 0, 50, 7, 41, 5, 76, 
    0,  3, 7, 17, 1, 71, 6, 80, 2, 41, 5, 88, 3, 38, 4, 47, 8, 75, 
    4, 22, 6, 41, 0, 78, 3, 85, 8, 20, 5, 45, 7, 99, 2, 38, 1, 18, 
    6,  4, 5, 56, 2, 30, 1, 20, 7, 37, 3, 87, 0, 18, 4, 30, 8, 60
  };
  const int q9805[] = {
    9, 9, // Number of jobs and machines
    7, 38, 3, 79, 8, 35, 1, 14, 4, 65, 2, 59, 6, 40, 5,  4, 0, 27, 
    0, 42, 5, 38, 8, 94, 7, 82, 3, 22, 2, 53, 6, 55, 1, 52, 4, 46, 
    1, 44, 6, 42, 2, 33, 4, 95, 8, 58, 7, 77, 0, 23, 5, 56, 3, 92, 
    7, 60, 1, 26, 3,  1, 0, 22, 8, 17, 2, 42, 4, 22, 5, 44, 6, 44, 
    4, 95, 3, 33, 1, 24, 8, 62, 0, 67, 7, 33, 6,  8, 5, 59, 2, 19, 
    7, 12, 6, 39, 5, 32, 4, 97, 2, 91, 3, 25, 1, 13, 8, 53, 0, 23, 
    0, 30, 4, 29, 8,  5, 2, 18, 1, 53, 7, 69, 3, 73, 5, 56, 6, 47, 
    7, 80, 4, 79, 0, 81, 5,  6, 3, 39, 1, 52, 2, 31, 8, 18, 6, 45, 
    3, 27, 1, 19, 7, 33, 2, 51, 4, 98, 5, 86, 8, 82, 0, 25, 6, 26
  };
  const int q9806[] = {
    9, 9, // Number of jobs and machines
    0, 75, 4, 23, 3, 15, 7,  2, 2, 70, 5, 77, 6, 82, 8, 80, 1, 40, 
    4, 97, 0, 73, 1,  5, 6, 94, 7, 38, 3, 39, 2,  4, 5, 59, 8, 67, 
    1, 61, 3, 72, 4, 58, 7, 30, 6, 93, 0,  5, 5, 26, 8,  8, 2, 33, 
    1, 92, 0, 99, 5, 92, 6, 50, 7, 70, 3, 23, 8, 54, 4, 59, 2, 16, 
    3, 96, 0, 51, 6, 44, 7, 19, 2, 99, 8, 13, 4, 57, 1, 38, 5, 96, 
    3, 23, 0, 78, 4, 65, 2, 58, 5, 99, 6, 36, 7, 48, 8, 20, 1, 18, 
    5, 70, 3, 71, 6, 38, 8, 67, 1, 49, 4, 75, 0,  4, 7, 90, 2, 69, 
    0, 71, 2,  5, 7, 20, 4, 87, 6,  4, 3, 66, 8, 34, 5, 31, 1, 50, 
    5, 12, 6, 47, 2,  6, 3, 19, 8, 44, 7, 82, 1,  8, 0, 48, 4, 86
  };
  const int q9807[] = {
    9, 9, // Number of jobs and machines
    4,  4, 7, 24, 8, 59, 5,  7, 2, 13, 6, 86, 0, 38, 1, 58, 3, 64, 
    4, 50, 2, 85, 3, 87, 8, 90, 7, 34, 5, 61, 0, 82, 1,  2, 6, 97, 
    2, 95, 5,  7, 6, 10, 7, 25, 3, 84, 1, 48, 0, 78, 4, 91, 8,  3, 
    4, 68, 0, 23, 1, 64, 5, 75, 2, 13, 6, 30, 8, 99, 7, 30, 3, 68, 
    0, 57, 1, 15, 7, 51, 6,  8, 8, 33, 5, 11, 4,  1, 2, 38, 3, 93, 
    4, 97, 1, 50, 0,  3, 8, 53, 5, 61, 6, 67, 3, 71, 2, 46, 7, 36, 
    7, 84, 0, 84, 5, 42, 8, 85, 4, 73, 1, 77, 3, 49, 2, 39, 6, 90, 
    7, 39, 1, 86, 6, 11, 4, 34, 8,  3, 0, 22, 2, 41, 5, 98, 3, 55, 
    8, 25, 4, 53, 2, 31, 1, 16, 6, 50, 3, 18, 7, 77, 0, 23, 5, 40
  };
  const int q9808[] = {
    9, 9, // Number of jobs and machines
    0, 86, 3, 25, 6, 72, 8, 52, 4, 49, 5, 48, 1,  4, 2, 62, 7, 35, 
    4, 87, 3,  6, 1, 90, 7, 98, 6, 98, 2, 76, 5,  1, 0, 56, 8,  1, 
    3, 35, 6, 36, 5, 91, 0, 41, 8, 93, 4, 40, 1, 87, 2, 42, 7, 13, 
    6, 12, 3, 99, 1, 24, 2, 14, 4, 88, 5, 54, 0,  6, 7, 77, 8, 15, 
    3,  1, 4, 11, 7, 83, 6, 77, 2, 36, 0, 49, 8, 17, 1,  3, 5, 46, 
    8, 16, 3, 40, 1, 54, 7, 76, 0, 27, 6, 34, 5, 27, 4, 56, 2, 33, 
    8, 67, 6, 93, 3, 10, 7, 98, 4, 17, 0, 34, 5, 25, 2, 99, 1, 31, 
    3, 89, 1, 58, 4, 78, 0, 34, 8, 60, 5, 95, 2, 84, 7, 79, 6, 75, 
    2, 10, 6, 14, 7,  4, 4, 78, 5, 62, 3, 37, 0, 70, 8, 68, 1, 54
  };
  const int q9809[] = {
    9, 9, // Number of jobs and machines
    5, 53, 3, 32, 8, 54, 6, 23, 1,  6, 4, 40, 0, 59, 2, 60, 7, 50, 
    2, 74, 0, 16, 7, 26, 5, 96, 6, 37, 3, 18, 8, 21, 1, 21, 4, 83, 
    1, 66, 7, 36, 4, 21, 2, 83, 0, 17, 3, 71, 6, 33, 5, 46, 8,  6, 
    1, 59, 7, 13, 5, 64, 4, 77, 3, 58, 0, 79, 6, 88, 8, 83, 2, 52, 
    4, 40, 1, 58, 0, 55, 7, 91, 6, 89, 2, 56, 3, 68, 5, 85, 8, 81, 
    4, 95, 0, 38, 3, 98, 1, 22, 2,  4, 5, 26, 8, 85, 7,  9, 6, 61, 
    7, 31, 6, 32, 1, 64, 4, 91, 8, 72, 5, 82, 3, 39, 0, 16, 2, 83, 
    3, 57, 1, 91, 6, 47, 7, 70, 0, 52, 5, 27, 4, 67, 8, 79, 2, 37, 
    8, 42, 1, 90, 5, 99, 0, 41, 6, 53, 4, 72, 7, 66, 3, 11, 2,  1
  };
  const int q9810[] = {
    9, 9, // Number of jobs and machines
    8, 40, 5,  9, 1, 27, 4, 23, 6, 92, 3,  9, 7, 60, 0, 55, 2, 42, 
    7, 44, 1, 82, 4, 35, 6, 93, 3, 46, 5,  2, 0, 89, 2, 92, 8, 11, 
    0,  2, 4, 85, 7, 95, 1, 36, 8, 86, 5, 82, 2, 14, 6, 84, 3, 75, 
    0, 61, 8, 30, 3, 60, 1, 88, 4, 61, 7, 30, 5, 42, 2, 30, 6, 87, 
    0, 69, 7, 73, 6, 14, 2, 68, 8, 79, 5, 31, 1, 77, 3, 33, 4,  5, 
    3, 28, 4, 41, 0, 23, 1, 67, 7, 84, 5, 85, 6, 88, 8, 94, 2, 94, 
    1, 80, 6, 73, 2, 94, 8, 51, 7, 64, 0, 20, 5, 81, 3, 99, 4, 84, 
    8, 31, 7, 83, 5, 35, 3,  9, 0, 57, 6, 25, 2, 24, 4, 84, 1,  4, 
    0, 45, 7, 30, 6, 67, 8,  9, 3,  3, 2, 29, 5, 47, 4, 67, 1, 90
  };
  const int q9811[] = {
    9, 9, // Number of jobs and machines
    2, 74, 6, 63, 5, 58, 8, 29, 3, 19, 7, 11, 1, 41, 0, 58, 4, 51, 
    7, 41, 2, 88, 4, 62, 1, 12, 8, 28, 6, 62, 3, 85, 0, 82, 5, 99, 
    6, 82, 4, 41, 2, 48, 3,  5, 8, 16, 0, 59, 7, 17, 5, 17, 1, 13, 
    6, 42, 2, 30, 3, 37, 0, 24, 4, 71, 8, 92, 5, 47, 7, 36, 1, 49, 
    1, 15, 4, 83, 6, 53, 8, 17, 7, 64, 0, 48, 2, 68, 5, 35, 3, 54, 
    7, 64, 8, 42, 5, 44, 6, 10, 2, 26, 4, 72, 0, 90, 1, 69, 3, 77, 
    8, 44, 2, 52, 4, 31, 5,  2, 7, 79, 3, 63, 1, 36, 6, 79, 0, 78, 
    5, 43, 3, 20, 6, 85, 2, 11, 0, 26, 7, 61, 1, 10, 4, 52, 8, 97, 
    6, 52, 4, 27, 5, 95, 7, 90, 2, 44, 3, 73, 1,  5, 8, 77, 0, 99
  };
  const int q9812[] = {
    9, 9, // Number of jobs and machines
    0, 87, 4, 60, 6, 82, 7,  1, 1,  6, 5, 58, 8, 80, 3, 87, 2, 88, 
    6, 85, 0, 12, 2, 14, 3, 26, 5, 84, 4, 55, 7, 58, 8, 93, 1, 46, 
    7, 73, 3, 25, 6, 12, 0, 82, 1, 10, 5, 99, 2, 54, 8, 61, 4, 28, 
    7, 98, 4, 76, 8, 59, 2,  3, 0, 87, 3, 70, 1, 68, 5, 56, 6, 34, 
    5, 83, 1, 13, 0, 19, 8, 15, 6, 63, 3, 52, 7, 46, 4, 81, 2, 89, 
    7, 52, 6, 86, 8, 48, 2, 26, 0, 21, 5, 87, 1, 91, 4, 91, 3, 60, 
    0, 37, 5,  9, 3, 96, 8, 28, 6, 26, 7, 17, 4, 15, 2, 96, 1, 77, 
    4, 40, 8, 58, 7, 63, 2, 95, 3,  3, 6, 29, 5,  4, 1, 89, 0, 42, 
    4, 97, 2, 69, 7, 84, 5, 66, 3, 55, 1, 70, 8, 85, 0, 64, 6, 80
  };
  const int q9813[] = {
    9, 9, // Number of jobs and machines
    2, 71, 6, 30, 5, 74, 3, 21, 1, 44, 7, 19, 8, 58, 4, 91, 0, 24, 
    3, 59, 4, 42, 6, 27, 0, 85, 8, 58, 2, 28, 1, 79, 7, 31, 5, 63, 
    8, 65, 5, 17, 6, 23, 1,  9, 3, 62, 2,  8, 0, 91, 4,  7, 7, 43, 
    6,  6, 2, 14, 1, 87, 4, 86, 7, 94, 0, 46, 5, 12, 3, 63, 8,  9, 
    1, 58, 6, 89, 3,  6, 0, 35, 7, 93, 5, 72, 4, 10, 2,  3, 8, 90, 
    4, 29, 0, 86, 3, 43, 5,  9, 1, 18, 2,  2, 7,  4, 8, 18, 6, 88, 
    2, 18, 8, 66, 7, 43, 1, 85, 5, 26, 0, 24, 6, 21, 4, 72, 3, 35, 
    5, 86, 8, 33, 2, 35, 3, 49, 0, 81, 4,  4, 7, 46, 6, 61, 1, 82, 
    0, 87, 7, 17, 6, 90, 1, 39, 4, 23, 3, 32, 8, 50, 2, 75, 5, 29
  };
  const int q9814[] = {
    9, 9, // Number of jobs and machines
    3, 48, 6, 47, 1, 78, 7, 25, 5, 70, 0, 24, 4,  7, 2, 73, 8, 12, 
    5, 92, 8, 13, 7, 74, 1, 81, 2, 55, 4, 74, 6,  5, 3, 13, 0,  1, 
    3, 35, 2, 64, 6,  7, 0, 42, 5, 11, 4, 71, 7,  5, 8, 70, 1, 42, 
    5, 95, 8,  3, 1, 59, 3, 48, 6,  8, 4, 88, 7, 22, 0, 71, 2, 24, 
    2, 49, 0, 44, 8, 16, 6, 53, 1, 21, 4, 58, 7, 49, 3, 13, 5, 28, 
    6,  1, 8, 97, 3, 51, 4, 19, 0, 63, 5, 90, 1, 72, 7, 63, 2,  9, 
    3, 40, 1,  3, 0, 25, 5, 24, 8, 91, 6, 98, 2,  6, 7, 40, 4, 97, 
    3, 16, 4, 91, 8, 29, 5, 49, 1, 14, 6, 55, 7, 90, 2, 96, 0, 29, 
    5,  5, 1, 48, 3,  2, 0, 70, 8, 20, 7,  4, 6, 58, 4, 62, 2, 98
  };
  const int q9815[] = {
    9, 9, // Number of jobs and machines
    4, 52, 5, 48, 1, 46, 7, 96, 6, 29, 3, 83, 0,  7, 2, 87, 8, 31, 
    3, 55, 0, 96, 8, 37, 2, 82, 7, 86, 1, 74, 6, 59, 5, 24, 4, 37, 
    3, 58, 6, 53, 7, 44, 5, 28, 2, 85, 0, 88, 8, 87, 1, 71, 4, 86, 
    4, 22, 7, 18, 6, 41, 8, 48, 5, 27, 2, 22, 3, 49, 1, 39, 0, 98, 
    1, 92, 5, 47, 7, 54, 2, 13, 8, 23, 0, 72, 6, 86, 3, 17, 4, 60, 
    7, 11, 4, 49, 1,  6, 5, 59, 3, 91, 8,  9, 0, 38, 2, 26, 6, 52, 
    8, 82, 4, 96, 2,  3, 1, 60, 3,  5, 7, 50, 5, 11, 6, 58, 0, 42, 
    2, 34, 4, 54, 3, 20, 6, 46, 5, 80, 1, 48, 8, 40, 7, 83, 0, 95, 
    7, 97, 4, 46, 6, 71, 1, 76, 8, 12, 0, 21, 2, 47, 5, 66, 3, 50
  };
  const int q9816[] = {
    9, 9, // Number of jobs and machines
    4, 82, 5, 31, 3, 72, 8, 71, 2, 96, 1, 17, 6, 55, 0, 11, 7, 40, 
    2, 77, 1, 82, 7, 50, 6,  2, 5, 37, 4, 43, 8, 65, 0, 29, 3, 75, 
    4, 87, 8, 97, 2, 62, 5, 34, 7, 62, 1, 46, 3, 95, 6, 42, 0, 75, 
    6, 43, 7, 85, 0, 69, 3, 43, 8, 29, 2, 43, 4, 30, 5,  6, 1, 61, 
    2, 59, 6, 49, 4, 24, 1, 35, 0, 26, 7, 89, 8, 99, 5, 18, 3,  9, 
    5, 70, 0,  7, 1, 79, 7, 89, 6, 85, 4, 43, 8, 47, 3,  7, 2, 85, 
    0, 22, 5, 79, 8, 52, 7, 68, 2, 57, 1, 39, 4, 95, 6, 63, 3, 67, 
    3, 13, 6, 11, 7, 49, 0, 91, 1, 13, 4,  1, 8, 72, 2, 53, 5, 84, 
    0, 75, 5, 18, 1, 32, 6, 99, 4, 24, 2, 44, 8, 96, 7, 46, 3, 65
  };
  const int q9817[] = {
    9, 9, // Number of jobs and machines
    7, 18, 2, 55, 4, 35, 5, 53, 8, 74, 3, 85, 0,  1, 6, 19, 1, 43, 
    4, 32, 3, 18, 5, 58, 1, 14, 0,  6, 7, 74, 8, 98, 2, 70, 6, 32, 
    1, 63, 0, 55, 7, 77, 6, 27, 4, 37, 8, 87, 5, 36, 3, 70, 2, 72, 
    8, 52, 6,  5, 4, 90, 5, 11, 3, 97, 1, 63, 0, 57, 2, 47, 7,  7, 
    4, 79, 0,  8, 5, 49, 3, 96, 7, 36, 2, 62, 1, 44, 6, 55, 8, 95, 
    0, 80, 3, 64, 8, 65, 4, 25, 1,  1, 2, 52, 7,  6, 5, 85, 6, 32, 
    2, 91, 0, 14, 8, 48, 3, 41, 5, 34, 4, 68, 7, 86, 1, 95, 6, 55, 
    8, 59, 7, 61, 5, 33, 4, 22, 1, 22, 2, 55, 0, 20, 3, 42, 6, 34, 
    6,  4, 0, 14, 7,  4, 2, 97, 1,  2, 8, 30, 4, 70, 5, 13, 3, 14
  };
  const int q9818[] = {
    9, 9, // Number of jobs and machines
    7, 84, 3, 45, 5, 97, 1, 96, 4, 72, 6, 34, 0, 12, 8,  3, 2, 77, 
    3, 66, 5, 70, 7, 73, 2, 55, 4,  8, 1, 64, 8, 16, 0, 26, 6, 43, 
    1, 92, 4, 19, 8, 72, 2, 75, 5,  6, 7, 58, 6, 14, 3, 65, 0, 32, 
    0, 10, 7, 79, 4, 66, 3, 77, 5, 11, 8, 29, 1, 35, 6, 98, 2, 90, 
    5, 10, 8, 36, 1,  6, 3, 54, 2, 18, 6, 47, 0, 89, 7, 77, 4, 61, 
    7, 75, 0, 81, 2,  5, 1,  2, 4,  4, 8, 14, 6, 68, 3, 53, 5, 83, 
    7,  6, 2, 80, 4, 11, 3, 10, 5, 45, 0, 41, 8, 61, 6, 27, 1, 19, 
    8, 18, 1, 40, 0,  7, 7, 60, 6, 71, 3, 75, 5, 98, 2,  9, 4, 48, 
    1, 19, 8, 85, 5, 46, 0, 96, 2, 98, 6, 19, 3, 20, 4, 57, 7, 46
  };
  const int q9819[] = {
    9, 9, // Number of jobs and machines
    6, 19, 1, 82, 8, 65, 3, 20, 5,  5, 7,  9, 0, 16, 4,  8, 2,  6, 
    0, 13, 4, 73, 7, 20, 6, 96, 1, 47, 5, 91, 8,  3, 2, 82, 3, 82, 
    6, 55, 7, 26, 2, 38, 4, 67, 8, 50, 5, 16, 1, 15, 0, 63, 3, 31, 
    5, 89, 4, 61, 8, 57, 2,  5, 0,  8, 3, 64, 1, 88, 7, 36, 6, 30, 
    6, 21, 8, 46, 3, 81, 0, 64, 4, 61, 2, 80, 5, 67, 1, 71, 7, 44, 
    7, 56, 2, 98, 0, 57, 6,  2, 5, 34, 1, 31, 3, 55, 8, 34, 4,  1, 
    4, 85, 6, 64, 2, 43, 7, 59, 8, 65, 3, 68, 1, 80, 5, 11, 0, 57, 
    6, 73, 5, 45, 7,  2, 3, 91, 8, 81, 0, 40, 4, 76, 1, 68, 2, 16, 
    8, 93, 1, 93, 5, 57, 6, 56, 0, 57, 3, 90, 7, 30, 2, 11, 4, 33
  };
  const int q9820[] = {
    9, 9, // Number of jobs and machines
    5, 54, 0, 20, 7, 52, 4, 69, 1, 26, 8, 86, 3, 57, 6, 80, 2, 35, 
    4, 28, 3, 50, 8, 39, 1, 41, 7, 33, 6, 13, 5, 58, 0, 26, 2, 13, 
    2, 90, 1, 34, 0, 70, 8, 33, 6, 21, 4, 55, 3, 50, 5, 76, 7, 65, 
    5, 26, 1, 75, 8, 20, 0,  6, 6, 76, 4, 64, 7, 66, 3, 19, 2, 27, 
    1, 73, 6, 54, 7, 63, 8, 20, 3,  2, 0, 30, 2, 40, 4, 67, 5, 61, 
    0, 96, 6, 41, 8, 89, 4, 88, 2, 22, 7, 60, 3, 71, 1, 66, 5, 25, 
    7, 30, 1, 99, 4,  9, 5, 93, 3, 94, 2,  4, 6, 24, 8, 90, 0, 11, 
    0,  9, 3, 36, 5, 83, 7, 83, 8, 56, 1, 85, 2, 93, 4, 14, 6, 85, 
    5, 25, 6, 55, 8, 29, 3,  6, 1, 35, 2, 51, 7, 73, 0, 46, 4, 81
  };
  const int q9821[] = {
    9, 9, // Number of jobs and machines
    2, 72, 7,  4, 3, 84, 5, 12, 1,  7, 8, 80, 0, 63, 6,  8, 4, 34, 
    0, 41, 3, 41, 8, 19, 4, 55, 2, 67, 1,  4, 6, 84, 7, 78, 5, 21, 
    1, 18, 8, 75, 3, 74, 5, 24, 7, 91, 6, 61, 4, 38, 0, 87, 2,  8, 
    1, 64, 6, 89, 0, 73, 2, 94, 8, 91, 4, 26, 7, 43, 5, 52, 3, 49, 
    1, 13, 0, 96, 8, 47, 6,  6, 2, 25, 4, 94, 3,  4, 5, 83, 7, 35, 
    0, 36, 6, 32, 2, 78, 5, 86, 1, 74, 3, 67, 7, 57, 4, 31, 8, 61, 
    3, 35, 7, 89, 8,  2, 6, 91, 2, 75, 1, 90, 0, 90, 4, 91, 5, 78, 
    0, 43, 2, 76, 4, 10, 6, 43, 1, 93, 3, 12, 7, 78, 8, 63, 5,  5, 
    5, 16, 0, 43, 4, 14, 8,  9, 7, 19, 1, 53, 3, 60, 2, 66, 6, 22
  };
  const int q9822[] = {
    9, 9, // Number of jobs and machines
    6, 16, 3, 11, 7,  7, 1, 80, 5, 32, 2, 73, 0, 22, 4, 90, 8, 95, 
    7, 19, 2, 94, 3, 16, 1, 33, 6, 89, 5, 89, 0, 36, 8, 56, 4, 91, 
    7, 21, 0, 16, 1, 66, 8, 92, 5, 30, 2, 11, 4, 80, 6, 29, 3,  7, 
    5, 50, 2, 99, 0, 16, 1, 78, 6, 97, 7, 22, 3, 57, 4, 93, 8, 65, 
    4, 64, 6, 84, 2, 58, 5, 74, 0, 60, 7,  2, 3, 74, 1, 50, 8, 29, 
    0, 32, 5, 69, 6, 42, 8, 67, 3,  3, 2, 43, 4, 20, 7, 22, 1, 14, 
    2,  6, 5,  1, 4, 61, 3, 32, 7, 99, 6, 74, 0, 13, 8, 95, 1, 30, 
    6, 36, 1, 77, 0, 95, 4, 36, 2, 67, 3, 81, 8, 96, 5, 49, 7, 26, 
    8, 18, 1,  8, 7,  5, 0,  3, 6, 72, 4, 22, 5, 95, 2, 70, 3, 32
  };
  const int q9823[] = {
    9, 9, // Number of jobs and machines
    5, 74, 7, 66, 1, 31, 0, 86, 4, 36, 6, 23, 2, 41, 3, 81, 8, 62, 
    2, 12, 7, 13, 6, 40, 8, 19, 1,  3, 0, 28, 4, 15, 5, 71, 3, 78, 
    8,  9, 5, 76, 6, 96, 4,  1, 2, 61, 7, 98, 0, 81, 1, 10, 3,  5, 
    0, 13, 1, 82, 6, 39, 7, 10, 5, 24, 8, 34, 4, 17, 3, 19, 2, 99, 
    3,  1, 4, 75, 6,  5, 0, 71, 2, 55, 1, 26, 5, 82, 8, 11, 7, 66, 
    2, 93, 8, 60, 5, 27, 0, 90, 7, 17, 4, 41, 1, 14, 6, 73, 3, 75, 
    5, 28, 4,  9, 1,  3, 0, 16, 2, 85, 8, 79, 6, 63, 3, 94, 7, 52, 
    0, 10, 7, 83, 6, 21, 4, 14, 5,  9, 2, 37, 8, 51, 3, 25, 1, 45, 
    1, 26, 0, 79, 3, 43, 2, 43, 6, 92, 5, 38, 8, 93, 4, 98, 7, 59
  };
  const int q9824[] = {
    9, 9, // Number of jobs and machines
    1, 15, 0, 29, 4, 26, 7, 37, 2, 66, 6, 69, 5, 28, 8, 42, 3, 25, 
    1, 62, 7, 98, 2, 92, 3, 19, 4, 45, 6, 50, 8, 71, 0, 46, 5, 86, 
    1, 49, 3, 32, 8, 47, 7, 74, 5, 56, 0, 48, 2, 63, 6, 28, 4, 57, 
    5, 46, 4, 38, 0, 58, 2, 11, 1, 54, 8, 23, 3, 30, 7, 46, 6, 51, 
    4, 68, 0, 23, 2, 55, 8, 77, 1, 57, 5, 90, 3, 26, 6, 67, 7, 43, 
    3, 29, 0, 90, 5, 55, 6, 99, 4, 44, 1, 74, 8, 59, 2, 76, 7, 68, 
    8, 96, 4, 62, 6, 52, 1, 96, 7, 71, 5, 97, 2, 91, 0, 56, 3, 37, 
    4, 22, 6, 26, 3, 59, 5, 53, 1, 37, 2, 18, 0, 72, 7, 35, 8,  8, 
    8, 14, 6, 62, 2, 87, 0, 43, 3, 75, 1, 48, 5, 47, 4, 18, 7, 65
  };
  const int q9825[] = {
    9, 9, // Number of jobs and machines
    6, 56, 3, 24, 1, 79, 2, 98, 0, 44, 4, 58, 5, 40, 7, 35, 8, 73, 
    4, 94, 8, 34, 3, 23, 2, 60, 0, 53, 5, 56, 1, 81, 7, 43, 6,  4, 
    5, 47, 8, 93, 2, 65, 7, 50, 4, 94, 3, 57, 6, 21, 1, 14, 0, 45, 
    0,  8, 2, 13, 1,  4, 7, 28, 3, 22, 4, 91, 6, 44, 8, 83, 5, 19, 
    8, 62, 3, 92, 4, 76, 5, 64, 2, 34, 6, 56, 7, 36, 0, 89, 1, 60, 
    6, 68, 3,  1, 5, 84, 4, 82, 0, 38, 7, 63, 2, 94, 1, 25, 8, 72, 
    4, 46, 2, 97, 7, 50, 0, 54, 6, 52, 5, 77, 8, 53, 3,  3, 1, 94, 
    7, 30, 0, 81, 5, 17, 6, 52, 8, 62, 4, 58, 3, 47, 1, 95, 2, 64, 
    8, 52, 5, 75, 2, 60, 0, 74, 3, 21, 7, 86, 4, 42, 6, 47, 1, 17
  };
  const int q9826[] = {
    9, 9, // Number of jobs and machines
    4, 28, 1, 58, 5, 25, 2, 65, 6, 95, 0, 34, 7, 73, 8, 19, 3, 77, 
    0, 15, 2,  4, 5, 78, 6, 91, 8, 19, 1, 82, 4, 47, 3, 21, 7, 40, 
    2, 27, 6, 59, 3, 92, 4, 84, 5, 84, 0, 97, 1, 93, 7, 75, 8, 72, 
    0, 84, 6, 69, 3, 75, 5, 60, 8, 65, 1, 61, 4, 82, 7, 97, 2, 79, 
    3, 41, 1, 62, 0, 38, 2, 56, 6, 21, 4, 13, 5, 21, 7, 75, 8, 54, 
    1, 36, 5, 23, 4, 94, 8, 71, 2, 40, 7, 29, 6,  4, 0, 81, 3, 34, 
    5, 24, 2, 92, 7, 71, 3, 96, 8, 42, 4, 54, 6, 84, 0, 45, 1, 22, 
    7, 43, 0, 37, 8,  9, 2, 74, 3, 24, 1, 51, 5, 88, 6, 82, 4, 89, 
    3,  3, 2, 41, 5, 26, 8, 87, 6, 56, 7, 85, 0, 14, 4, 85, 1, 28
  };
  const int q9827[] = {
    9, 9, // Number of jobs and machines
    1, 54, 6, 18, 4, 14, 3,  1, 5, 34, 2, 51, 8, 39, 7, 86, 0, 85, 
    8,  4, 4, 90, 5, 75, 7, 32, 6, 37, 2, 29, 3, 13, 0, 77, 1, 51, 
    3, 48, 5, 79, 2, 48, 4, 12, 7, 79, 6, 57, 1, 19, 0, 63, 8,  7, 
    0,  3, 8, 32, 6, 51, 1, 62, 7, 73, 3, 52, 2, 49, 5, 12, 4, 54, 
    4, 34, 1, 14, 3, 78, 2, 92, 8, 10, 5,  2, 7, 81, 0,  3, 6, 35, 
    1,  4, 6,  8, 4, 47, 8, 39, 3, 43, 0, 72, 2,  3, 5, 23, 7, 73, 
    8, 12, 5, 73, 4, 50, 7, 81, 1, 61, 2, 86, 3, 98, 6, 91, 0, 88, 
    3, 66, 6, 68, 0, 87, 5, 14, 2, 87, 8, 69, 4, 44, 7, 53, 1, 22, 
    2, 33, 5, 80, 6, 62, 7, 71, 8, 99, 0, 46, 3, 49, 4, 99, 1, 93
  };
  const int q9828[] = {
    9, 9, // Number of jobs and machines
    3, 98, 4, 57, 0, 97, 2, 48, 6,  5, 1, 81, 5, 55, 8, 73, 7, 23, 
    3, 42, 7, 23, 5, 13, 6,  7, 1, 17, 0, 10, 4, 28, 8, 21, 2, 57, 
    8, 97, 5, 41, 7, 21, 4, 50, 6, 56, 2, 95, 3, 65, 1, 46, 0, 17, 
    0, 44, 6, 32, 3, 55, 5, 82, 7, 93, 2, 10, 8, 36, 1, 62, 4, 55, 
    7, 33, 4, 57, 3, 30, 6, 89, 0, 87, 8, 37, 5, 67, 1, 46, 2, 29, 
    3, 91, 5, 91, 1, 54, 8, 28, 6, 93, 2, 47, 7, 84, 4, 61, 0, 42, 
    4, 89, 3, 10, 8, 98, 7, 42, 2, 17, 0, 87, 5, 56, 1, 33, 6, 56, 
    6, 20, 0, 42, 4, 15, 3, 53, 7, 51, 5, 99, 1, 50, 8, 48, 2, 28, 
    1, 40, 6, 60, 4, 43, 7,  1, 5, 55, 2, 17, 3,  2, 0, 58, 8, 11
  };
  const int q9829[] = {
    9, 9, // Number of jobs and machines
    6, 67, 2, 35, 0, 87, 5, 99, 7, 84, 1, 41, 4, 59, 3, 52, 8, 71, 
    6, 35, 0, 32, 7, 46, 3, 13, 2, 78, 4, 24, 5, 98, 8, 12, 1, 64, 
    0, 14, 1, 41, 2, 92, 8, 78, 4, 83, 3, 18, 6, 51, 5, 44, 7, 45, 
    6, 25, 8, 63, 5, 45, 2, 41, 4, 38, 0,  3, 3, 35, 1, 60, 7, 60, 
    7, 65, 6, 50, 1, 40, 3, 76, 5, 83, 0, 48, 4, 72, 8,  2, 2, 69, 
    5,  5, 3, 35, 4, 28, 8, 41, 2, 25, 1, 59, 6, 34, 7, 97, 0, 49, 
    2, 95, 5, 60, 0, 66, 1,  4, 6, 22, 3, 85, 4, 24, 7, 97, 8, 95, 
    7, 17, 2, 20, 8, 53, 3, 25, 4, 56, 1, 63, 5, 22, 6, 88, 0,  5, 
    7, 84, 8, 76, 2, 85, 4, 99, 5, 17, 0, 97, 1, 93, 6, 74, 3, 76
  };
  const int q9830[] = {
    9, 9, // Number of jobs and machines
    7, 74, 3, 40, 5, 73, 8,  4, 0, 40, 1, 80, 2, 32, 6, 84, 4, 48, 
    6, 99, 2, 72, 8,  4, 5, 30, 0, 54, 1, 99, 7, 41, 3, 53, 4, 16, 
    3, 26, 7, 44, 8, 45, 5, 14, 0, 88, 4, 24, 1, 68, 6, 69, 2, 11, 
    7, 15, 2, 52, 4, 44, 5, 88, 6, 93, 8, 42, 3,  7, 1, 93, 0, 85, 
    8, 62, 0, 88, 7, 17, 4, 93, 1, 69, 6, 24, 3, 35, 2, 22, 5, 76, 
    6, 68, 2, 70, 7, 11, 5, 32, 4, 19, 8, 56, 0, 25, 1, 44, 3, 59, 
    4, 17, 6, 76, 7, 25, 5, 15, 8, 32, 2, 50, 3, 10, 0, 36, 1, 23, 
    0, 97, 4, 94, 1, 70, 6, 24, 2, 16, 5, 69, 7, 77, 3, 52, 8, 96, 
    4, 43, 8, 94, 2, 45, 3, 30, 7, 26, 0, 57, 1, 96, 5,  2, 6, 66
  };
  const int q9831[] = {
    9, 9, // Number of jobs and machines
    3, 65, 5, 20, 4, 23, 8, 47, 2, 97, 6, 70, 7, 37, 1, 26, 0,  1, 
    8, 11, 6, 64, 1, 51, 5,  4, 0, 92, 2, 89, 4,  9, 7, 25, 3, 21, 
    0, 90, 1, 77, 7, 27, 4, 10, 8,  9, 2,  2, 5, 42, 3, 60, 6, 48, 
    0, 59, 1, 83, 7, 43, 5, 21, 4, 59, 3, 76, 6, 71, 8, 15, 2,  3, 
    7, 59, 3, 12, 4, 73, 0, 76, 5, 58, 1, 61, 8, 28, 6, 18, 2, 41, 
    5, 94, 6, 12, 3, 66, 7, 31, 4,  3, 0, 88, 8,  4, 1, 64, 2, 76, 
    0, 22, 5, 95, 7, 30, 8, 49, 1, 31, 4, 99, 6, 75, 3, 70, 2, 70, 
    6, 11, 0, 19, 3, 15, 8, 54, 2, 32, 5, 33, 7, 13, 4, 50, 1, 38, 
    5, 92, 4, 27, 0, 27, 3, 26, 2, 97, 7, 71, 1, 62, 6, 29, 8, 47
  };
  const int q9832[] = {
    9, 9, // Number of jobs and machines
    4, 20, 3, 39, 2, 25, 7, 47, 5,  3, 1, 56, 0, 53, 6, 70, 8, 78, 
    2, 88, 5, 63, 8, 45, 1, 65, 0, 98, 4, 53, 6, 56, 7, 74, 3, 32, 
    0, 52, 5, 35, 3, 71, 7, 97, 8,  2, 2, 26, 1, 64, 4, 20, 6, 85, 
    3, 35, 7, 24, 8, 83, 2, 81, 6, 37, 5, 63, 4, 46, 1, 26, 0, 29, 
    4, 68, 0,  1, 7, 65, 3, 36, 1, 93, 5, 15, 8, 32, 2, 43, 6, 29, 
    6,  4, 5, 74, 3, 24, 7, 49, 0, 39, 2, 59, 4, 30, 1, 77, 8,  3, 
    0, 59, 6, 71, 8, 36, 3, 97, 4, 32, 2, 11, 1, 57, 5, 73, 7, 99, 
    5, 28, 2, 41, 1, 73, 7, 67, 6, 83, 8, 87, 3, 80, 4, 33, 0,  2, 
    1, 43, 7, 29, 0, 35, 6, 46, 4, 85, 3, 47, 8, 98, 5, 62, 2, 63
  };
  const int q9833[] = {
    9, 9, // Number of jobs and machines
    2, 79, 5,  4, 7, 36, 3, 68, 8, 49, 0, 66, 1, 64, 6,  5, 4, 32, 
    8, 54, 7, 95, 4, 35, 6, 78, 0, 24, 3, 54, 2, 33, 1, 15, 5, 20, 
    2, 90, 5, 33, 7, 87, 8, 41, 3, 34, 6, 67, 0, 93, 1, 98, 4, 77, 
    4, 98, 5, 64, 7, 81, 6, 82, 0,  9, 3, 65, 1, 25, 8, 64, 2, 35, 
    1, 18, 2, 89, 4, 31, 0, 47, 3, 47, 7, 17, 6, 28, 5, 20, 8, 47, 
    3, 14, 0, 82, 1, 55, 5, 65, 2, 80, 8, 41, 6, 26, 4, 21, 7, 96, 
    3, 45, 4, 13, 6, 39, 1, 25, 7, 19, 8, 97, 0, 20, 2, 46, 5, 14, 
    8, 10, 1, 60, 7, 77, 2, 48, 4, 28, 5, 15, 3, 73, 6, 17, 0, 49, 
    4, 95, 5, 76, 2, 42, 1, 99, 7, 40, 3, 62, 6, 17, 0, 99, 8, 80
  };
  const int q9834[] = {
    9, 9, // Number of jobs and machines
    1, 24, 5, 75, 4, 45, 7, 44, 6, 32, 8, 68, 2, 94, 0, 72, 3, 85, 
    4, 89, 1, 35, 7,  7, 0, 48, 8, 74, 2, 10, 6, 92, 3, 48, 5, 43, 
    4, 34, 2, 96, 0, 32, 8,  4, 3, 61, 1, 28, 6,  4, 7,  3, 5, 44, 
    0, 46, 8, 57, 2, 57, 1, 61, 5,  1, 4, 92, 3, 41, 7, 76, 6, 64, 
    3, 68, 1, 64, 5, 62, 0, 52, 8, 49, 4, 72, 2, 26, 7, 82, 6, 42, 
    8, 69, 7, 42, 3, 30, 4, 96, 0, 51, 1, 90, 2, 53, 6, 86, 5, 88, 
    8,  2, 1, 29, 3, 72, 7, 24, 4, 34, 6, 54, 0, 30, 2, 51, 5, 28, 
    3, 30, 1, 61, 0, 25, 7, 82, 8, 37, 5, 26, 6, 24, 2,  8, 4, 79, 
    1, 56, 6, 73, 4, 26, 0, 42, 5, 34, 3, 95, 2, 91, 7, 65, 8, 60
  };
  const int q9835[] = {
    9, 9, // Number of jobs and machines
    2, 33, 6,  5, 1, 59, 3,  8, 8, 40, 0, 99, 5, 47, 4, 66, 7, 11, 
    8, 39, 2, 66, 6, 46, 0, 14, 1, 17, 5, 23, 3, 92, 7, 57, 4, 19, 
    0, 53, 6, 36, 1, 98, 3, 32, 2, 83, 7, 36, 4, 31, 8,  9, 5, 48, 
    7, 11, 3,  5, 0, 70, 4, 38, 6, 65, 2, 89, 8, 57, 5, 35, 1, 25, 
    4, 41, 5, 52, 8, 45, 1, 48, 3, 69, 7, 48, 0, 46, 2, 75, 6, 69, 
    7, 91, 8, 42, 6, 89, 5, 44, 0,  3, 4, 25, 3, 36, 1,  7, 2, 30, 
    0, 78, 1, 16, 2, 10, 5, 97, 3, 33, 6, 81, 8, 22, 7, 66, 4, 40, 
    3,  1, 8, 34, 5, 97, 0,  3, 1, 60, 6, 40, 4, 53, 2,  8, 7, 53, 
    4, 90, 7, 69, 1, 17, 0, 72, 2, 64, 8,  5, 3, 93, 6, 24, 5, 90
  };
  const int q9836[] = {
    9, 9, // Number of jobs and machines
    6, 77, 1, 17, 7, 39, 5, 51, 8, 51, 2, 75, 0, 80, 4, 49, 3, 10, 
    2, 57, 3, 68, 6, 26, 1, 59, 7, 70, 4, 10, 0, 45, 5, 19, 8, 22, 
    3, 75, 2, 19, 8, 66, 0, 59, 5, 80, 6, 53, 4, 39, 7, 25, 1, 24, 
    8, 53, 3, 88, 0, 94, 6, 35, 2, 97, 1, 78, 7, 15, 4, 85, 5, 41, 
    6, 75, 1, 43, 7,  1, 2, 46, 5, 41, 8, 89, 3, 48, 4,  6, 0, 75, 
    6,  1, 5, 19, 1, 28, 0, 81, 2, 59, 3, 20, 7, 38, 4, 63, 8, 93, 
    3, 84, 8, 75, 0, 61, 2, 90, 7,  8, 5, 26, 1, 30, 4, 56, 6, 89, 
    6, 97, 8, 72, 5, 63, 3, 53, 2, 72, 0, 15, 1, 46, 7, 41, 4, 75, 
    6, 66, 2,  7, 7, 80, 0, 80, 1, 77, 5,  7, 8, 38, 3, 89, 4, 17
  };
  const int q9837[] = {
    9, 9, // Number of jobs and machines
    7, 96, 4,  2, 6, 30, 3, 63, 2, 88, 1, 76, 0, 53, 8, 86, 5, 85, 
    8, 78, 0, 73, 3, 62, 1, 49, 5, 97, 6, 92, 2, 51, 7, 42, 4, 21, 
    1, 50, 6, 59, 0,  4, 4, 47, 3, 43, 2, 82, 8,  6, 5,  5, 7, 94, 
    8, 52, 1, 95, 5, 52, 2, 26, 4, 18, 7, 61, 0,  5, 6, 76, 3, 67, 
    7, 34, 5, 77, 1, 10, 6, 44, 4, 80, 2, 59, 3, 84, 8, 52, 0,  8, 
    2, 56, 5, 45, 8, 62, 3, 71, 4,  1, 6, 54, 1, 71, 0, 36, 7, 53, 
    6, 26, 5, 19, 3, 92, 1,  6, 2, 94, 0, 27, 4, 24, 7, 77, 8, 29, 
    3, 98, 8, 74, 1, 95, 0, 25, 2, 50, 6, 70, 7, 51, 4, 23, 5, 35, 
    1, 59, 5, 30, 0, 96, 4, 19, 8, 85, 3, 66, 7,  3, 6, 31, 2, 33
  };
  const int q9838[] = {
    9, 9, // Number of jobs and machines
    5, 16, 7, 37, 2, 95, 6, 72, 1, 12, 3, 93, 4, 46, 8, 91, 0, 36, 
    3, 68, 8, 75, 7, 72, 1, 35, 2, 95, 0, 47, 4, 35, 6, 18, 5, 18, 
    7, 67, 4, 98, 5, 38, 8, 29, 3, 47, 2, 47, 6, 99, 0, 87, 1, 93, 
    8, 28, 6, 13, 2, 73, 3, 17, 4,  5, 1, 24, 7, 91, 5, 36, 0, 44, 
    0, 18, 4, 46, 7, 82, 1, 59, 5,  7, 6, 35, 8, 23, 3, 27, 2, 71, 
    2, 80, 3, 90, 0, 46, 5, 97, 6, 59, 1, 94, 4, 11, 8,  7, 7, 37, 
    5, 59, 0, 36, 2, 58, 3, 58, 7, 42, 1, 58, 6,  3, 4, 26, 8, 25, 
    6, 82, 5, 95, 8, 88, 4, 93, 1, 56, 0, 71, 3, 19, 7, 53, 2, 73, 
    5, 87, 1, 30, 4, 56, 0, 60, 8, 79, 7, 72, 2, 83, 3, 39, 6, 48
  };
  const int q9839[] = {
    9, 9, // Number of jobs and machines
    4, 76, 8,  4, 2, 24, 6, 83, 5, 43, 3, 55, 1, 77, 7, 66, 0,  6, 
    2, 17, 8,  5, 7, 90, 0, 13, 6, 17, 5, 62, 1,  9, 4, 76, 3, 46, 
    2,  5, 8, 66, 7, 36, 3, 28, 4, 62, 5, 39, 0,  4, 6, 96, 1, 89, 
    8, 35, 0, 40, 1,  1, 5,  2, 4, 68, 2, 77, 7, 67, 3, 61, 6, 63, 
    1,  8, 7, 57, 0, 33, 5, 55, 8, 82, 2,  6, 6, 86, 3, 22, 4, 28, 
    6, 87, 4, 96, 8, 47, 3, 12, 5, 39, 2, 16, 1, 47, 0, 39, 7,  2, 
    8, 20, 2, 98, 0, 28, 3, 95, 1, 52, 6, 93, 4, 85, 7, 67, 5, 40, 
    2, 76, 3, 78, 7, 64, 4, 41, 8, 84, 6, 96, 0, 57, 1, 29, 5, 10, 
    8, 21, 7, 47, 5, 38, 6, 80, 4, 47, 0, 46, 3, 20, 1, 68, 2, 36
  };
  const int q9840[] = {
    9, 9, // Number of jobs and machines
    3, 57, 5, 67, 8, 70, 1, 63, 6, 32, 7, 70, 2, 81, 0,  6, 4, 83, 
    2, 43, 0, 84, 5, 96, 3, 48, 7, 24, 8, 90, 6, 55, 4, 57, 1, 15, 
    5, 34, 4,  5, 8, 61, 7, 30, 1, 90, 0, 62, 6, 44, 3, 47, 2, 45, 
    2, 81, 6, 62, 1, 73, 7, 62, 3, 19, 4, 57, 8, 79, 5, 97, 0, 97, 
    8, 91, 6, 21, 1, 99, 0, 70, 3, 58, 5, 20, 2,  5, 4, 54, 7, 30, 
    2, 24, 7, 41, 8, 87, 1, 62, 6, 28, 3, 85, 5, 90, 4, 95, 0, 33, 
    3, 69, 2, 70, 6, 86, 7, 67, 5, 23, 8, 26, 0, 30, 4, 19, 1,  8, 
    4, 45, 3, 95, 2, 66, 8, 55, 0, 50, 6, 12, 5, 21, 1, 16, 7, 43, 
    5, 11, 6, 77, 8, 25, 3, 79, 0, 51, 4,  6, 7, 39, 1, 88, 2, 64
  };
  const int q9841[] = {
    9, 9, // Number of jobs and machines
    7, 85, 4, 99, 0, 36, 8, 25, 5, 71, 3, 97, 2, 15, 1, 23, 6, 13, 
    1, 91, 5, 28, 7, 71, 2,  1, 8, 84, 3, 69, 0, 66, 6, 42, 4, 87, 
    7, 11, 1, 40, 2, 75, 6, 70, 3, 20, 4,  7, 8, 56, 0, 70, 5, 52, 
    4, 21, 3, 50, 2, 29, 5, 31, 6,  3, 8, 48, 1, 82, 7, 99, 0, 40, 
    1, 10, 5, 53, 7, 52, 3, 70, 6, 15, 0, 57, 4, 70, 2, 93, 8,  1, 
    5, 85, 6, 43, 7, 68, 2,  5, 4, 71, 1, 42, 8, 13, 0, 18, 3,  7, 
    7, 90, 1, 15, 2, 87, 3, 66, 5, 20, 0, 72, 8, 37, 4, 68, 6, 19, 
    0, 96, 2, 96, 4, 59, 8, 36, 1, 58, 6, 75, 5, 47, 7, 61, 3,  1, 
    7, 31, 6, 64, 8, 42, 2, 28, 4, 80, 3, 55, 5, 25, 1, 47, 0, 83
  };
  const int q9842[] = {
    9, 9, // Number of jobs and machines
    2, 21, 5, 87, 4, 23, 0, 24, 1, 45, 3, 43, 8, 22, 7, 16, 6, 29, 
    1, 64, 7,  1, 3, 30, 6, 56, 0, 88, 5, 80, 4, 19, 2, 22, 8, 31, 
    5, 42, 2, 65, 1, 92, 0,  9, 6, 38, 8, 76, 4, 80, 3, 95, 7, 66, 
    6, 64, 1, 98, 3, 67, 2, 28, 5, 87, 0, 12, 8, 71, 7, 31, 4, 60, 
    4,  1, 3, 15, 8, 84, 5, 18, 0, 64, 7, 51, 2, 53, 6, 88, 1, 66, 
    7, 32, 4, 33, 5, 66, 2, 37, 0, 88, 6, 27, 8, 84, 1, 58, 3, 36, 
    7, 55, 3, 95, 4, 91, 0, 47, 8, 92, 6, 33, 5, 54, 2, 96, 1, 23, 
    0, 94, 6, 92, 2, 54, 1, 96, 5, 42, 8, 16, 7, 52, 4, 46, 3, 70, 
    4,  3, 6, 12, 2, 75, 7,  3, 1, 33, 5, 63, 0, 77, 8, 53, 3,  6
  };
  const int q9843[] = {
    9, 9, // Number of jobs and machines
    5, 95, 0, 38, 1, 81, 3, 88, 8, 16, 6, 90, 4,  3, 7, 66, 2, 63, 
    2, 27, 3,  9, 0, 17, 6, 90, 8, 12, 5, 26, 1, 72, 7, 31, 4, 12, 
    4, 54, 8, 33, 0, 14, 7, 84, 1, 85, 5, 65, 2, 42, 6, 81, 3, 73, 
    3,  3, 7, 40, 5, 43, 0, 89, 8, 67, 2, 69, 6, 56, 1, 26, 4, 64, 
    3, 93, 1, 31, 7, 47, 6, 65, 2, 19, 8, 40, 5, 48, 4, 62, 0, 83, 
    6, 82, 4, 53, 7, 22, 0, 62, 1, 58, 2, 25, 5,  2, 3, 80, 8, 39, 
    7, 54, 0, 54, 6, 98, 8, 11, 5, 73, 4, 60, 2, 54, 1, 70, 3,  4, 
    8, 15, 5, 42, 1, 21, 2, 22, 7, 81, 4, 55, 3,  6, 0, 70, 6, 43, 
    2, 44, 8, 96, 6, 56, 5,  6, 1, 89, 4,  9, 0, 88, 3, 71, 7, 99
  };
  const int q9844[] = {
    9, 9, // Number of jobs and machines
    3, 95, 7, 66, 0, 35, 2, 20, 5, 47, 4,  8, 8, 15, 6, 48, 1, 18, 
    6, 83, 1, 69, 7, 46, 2, 91, 4,  3, 8,  9, 0, 92, 3, 36, 5, 89, 
    2, 68, 5,  3, 6, 93, 8, 39, 3, 64, 4, 71, 1, 33, 7,  7, 0, 21, 
    7, 41, 3, 72, 6,  8, 2, 54, 8, 86, 5, 39, 4, 24, 1, 13, 0, 65, 
    7, 56, 3, 80, 8, 57, 6, 20, 4, 19, 2, 26, 5, 66, 0, 88, 1, 55, 
    5, 93, 1, 49, 4, 97, 3, 49, 0, 21, 6, 72, 2, 46, 7, 92, 8, 37, 
    5, 50, 0, 64, 2, 62, 6, 30, 7, 85, 8, 55, 3, 79, 4, 88, 1, 68, 
    8, 87, 6, 36, 1, 21, 4, 72, 3, 24, 2, 63, 5, 33, 7, 80, 0, 10, 
    4, 49, 0, 58, 3, 52, 7,  7, 5, 52, 2, 57, 8, 78, 1, 31, 6, 34
  };
  const int q9845[] = {
    9, 9, // Number of jobs and machines
    4, 50, 0, 43, 2, 78, 6, 89, 8, 93, 7, 18, 3, 68, 1, 26, 5, 75, 
    2, 49, 6, 24, 0, 23, 8, 19, 4,  1, 1, 22, 7, 34, 5,  8, 3,  9, 
    0, 55, 1, 39, 3, 13, 5,  9, 8, 46, 7, 76, 2, 59, 6, 16, 4, 81, 
    2, 55, 7, 13, 6, 49, 5, 78, 0, 24, 3, 75, 4, 30, 8, 35, 1, 67, 
    1, 69, 3, 89, 4, 73, 0, 68, 5, 27, 7, 89, 8, 33, 6, 35, 2, 86, 
    1, 29, 2, 97, 5, 20, 3, 52, 4, 79, 7, 57, 6, 33, 8,  5, 0, 96, 
    2, 83, 4, 94, 5, 86, 1, 60, 7, 79, 0, 41, 3, 65, 6, 47, 8, 11, 
    0, 97, 4, 78, 8, 99, 6, 54, 2, 26, 5, 50, 3, 35, 1, 99, 7, 37, 
    1, 59, 8, 84, 0, 52, 7, 65, 3, 35, 5, 86, 2, 94, 4, 55, 6, 16
  };
  const int q9846[] = {
    9, 9, // Number of jobs and machines
    7, 47, 8, 29, 0, 26, 5, 53, 6, 29, 2, 52, 1, 11, 4, 56, 3,  7, 
    6, 71, 3, 88, 8, 59, 7, 82, 2, 30, 0, 86, 1, 91, 4, 81, 5, 37, 
    2, 73, 8, 36, 3, 56, 4, 39, 1, 69, 5, 57, 6, 16, 0, 91, 7, 26, 
    8, 10, 7, 10, 2, 54, 3,  5, 4, 87, 0,  3, 5, 36, 6,  5, 1, 34, 
    3, 24, 0,  5, 6, 12, 7, 40, 1, 53, 4, 40, 8, 78, 2, 39, 5, 46, 
    0, 70, 7, 77, 8, 23, 2, 57, 1, 89, 4, 18, 5, 48, 3, 91, 6, 25, 
    6, 77, 4, 16, 5, 50, 7, 91, 8, 88, 1, 91, 0, 18, 2, 66, 3, 13, 
    4, 22, 1, 70, 0, 83, 8,  9, 7, 26, 3, 15, 5, 75, 6, 98, 2, 92, 
    1, 44, 0, 16, 5, 92, 8, 29, 7, 12, 2, 80, 6, 58, 4, 29, 3, 10
  };
  const int q9847[] = {
    9, 9, // Number of jobs and machines
    6, 89, 7, 14, 4, 78, 8, 78, 1, 38, 2, 18, 0, 63, 5, 56, 3, 10, 
    7, 74, 5, 81, 8, 34, 2, 88, 6, 66, 4,  3, 3, 57, 0, 39, 1, 16, 
    2, 36, 4,  7, 8, 60, 0, 36, 5, 89, 1, 86, 3, 79, 7, 47, 6, 33, 
    1, 50, 5,  9, 2,  7, 7, 61, 0, 36, 8, 92, 4, 62, 3, 14, 6, 89, 
    4, 35, 0, 18, 2, 57, 7,  8, 3, 37, 5, 24, 6, 18, 1, 98, 8, 21, 
    0,  7, 8,  4, 5, 97, 4, 58, 1, 98, 7, 28, 3, 86, 2, 38, 6, 78, 
    7, 30, 5, 50, 2, 75, 3, 55, 1, 62, 8, 86, 6, 70, 0,  3, 4,  5, 
    3, 33, 2, 88, 6, 98, 0, 46, 8, 58, 5, 87, 4, 43, 1, 55, 7, 66, 
    7, 21, 6, 73, 3,  5, 0, 12, 4,  7, 1, 60, 8,  1, 5, 62, 2, 42
  };
  const int q9848[] = {
    9, 9, // Number of jobs and machines
    0,  4, 3, 18, 1, 19, 8, 27, 7, 98, 5, 89, 4,  7, 2, 21, 6, 17, 
    3, 24, 4, 21, 6, 62, 7, 74, 5, 99, 1, 65, 8, 78, 2, 77, 0, 64, 
    7, 96, 1, 38, 8, 38, 5, 73, 2,  3, 0, 61, 6, 59, 4, 26, 3, 75, 
    6,  3, 7, 36, 5, 50, 8, 20, 2, 98, 1, 38, 4, 98, 0, 41, 3, 57, 
    1, 78, 4, 48, 5, 31, 8, 34, 0, 35, 3, 74, 7, 34, 2,  8, 6, 67, 
    1, 64, 2, 38, 5, 34, 3, 75, 4, 91, 8, 32, 0, 73, 7, 74, 6, 94, 
    0, 52, 8, 43, 6, 22, 5, 69, 4, 10, 2, 23, 1, 61, 3,  9, 7, 45, 
    8, 12, 3, 11, 1, 54, 0, 34, 7, 47, 5, 95, 4, 91, 2, 95, 6, 58, 
    7, 48, 6, 72, 3, 19, 1, 16, 2,  1, 0,  8, 8, 70, 4, 75, 5, 98
  };
  const int q9849[] = {
    9, 9, // Number of jobs and machines
    1, 81, 7, 31, 5, 87, 2, 98, 4, 48, 6, 37, 3, 52, 8, 68, 0, 97, 
    0, 44, 3, 73, 8, 40, 5, 17, 1, 37, 6, 47, 4, 79, 7, 70, 2, 83, 
    6, 97, 1, 36, 8, 24, 4, 45, 3, 89, 7, 56, 0, 49, 5,  4, 2, 24, 
    8, 50, 0, 45, 6, 94, 4,  7, 3, 63, 2, 74, 7, 23, 5, 33, 1,  9, 
    7, 36, 4, 80, 0, 34, 3, 59, 1, 19, 8, 88, 5, 72, 2, 46, 6, 73, 
    2,  3, 5, 68, 6, 70, 8, 31, 7,  3, 1, 58, 3, 21, 4, 42, 0, 69, 
    5, 69, 4, 84, 7, 63, 2,  4, 1, 74, 3, 90, 0, 42, 6, 65, 8, 84, 
    3,  4, 4, 63, 7, 88, 1, 12, 6, 48, 0, 38, 5, 84, 2, 61, 8, 80, 
    4, 37, 6, 89, 2, 35, 7, 27, 5, 85, 8, 56, 3, 71, 1, 34, 0, 71
  };
  const int q9850[] = {
    9, 9, // Number of jobs and machines
    8, 68, 0, 98, 5, 84, 7, 76, 6,  2, 1, 83, 4, 44, 2,  1, 3, 46, 
    5, 86, 3, 58, 4, 19, 1, 96, 2, 51, 0, 51, 6, 72, 8, 80, 7, 70, 
    2, 43, 3, 46, 0, 45, 4, 31, 7, 22, 5, 14, 8, 78, 1, 13, 6, 24, 
    6, 49, 4, 51, 3, 60, 7, 30, 2,  7, 8, 61, 5, 57, 1, 23, 0, 36, 
    7, 19, 5, 60, 0, 34, 2,  9, 1, 94, 8, 32, 6, 68, 4, 94, 3, 53, 
    5, 90, 2, 66, 0,  4, 7, 74, 6, 84, 3, 50, 4, 70, 1, 94, 8,  9, 
    5, 40, 6, 19, 1, 34, 8, 24, 0,  1, 7, 38, 3, 52, 2,  4, 4, 70, 
    6,  6, 5, 69, 7, 73, 2, 29, 4, 43, 1, 10, 3, 26, 0,  1, 8, 28, 
    7, 49, 3, 71, 1, 68, 6, 71, 8, 85, 0, 48, 4, 73, 2, 55, 5, 64
  };
  const int q9851[] = {
    9, 9, // Number of jobs and machines
    3, 53, 8, 36, 1,  7, 6, 80, 4, 43, 7, 91, 0, 95, 2,  7, 5, 50, 
    8, 53, 6, 36, 4,  7, 2, 37, 7, 49, 0, 19, 3, 73, 1, 35, 5, 73, 
    2, 97, 1, 74, 6, 40, 4, 19, 0, 67, 8,  4, 7, 51, 3, 80, 5, 42, 
    4, 66, 2, 70, 7,  2, 5, 11, 0, 52, 1, 17, 3, 37, 8, 89, 6,  7, 
    0, 12, 2, 90, 8, 75, 7, 14, 4, 38, 6, 55, 1, 81, 3,  6, 5, 13, 
    6, 68, 5, 28, 1, 16, 7,  2, 8,  9, 2, 69, 4, 14, 0, 94, 3, 82, 
    3, 25, 4, 92, 0, 14, 8, 12, 5, 42, 2, 66, 1, 28, 7, 55, 6, 77, 
    5, 41, 4, 86, 3, 54, 2, 28, 7,  3, 8, 98, 0, 73, 6, 56, 1, 30, 
    8, 86, 5, 31, 1, 28, 3, 36, 0, 21, 4, 43, 2, 58, 7, 86, 6, 17
  };
  const int q9852[] = {
    9, 9, // Number of jobs and machines
    4, 60, 1, 72, 8, 34, 0, 27, 5, 63, 7, 27, 6, 38, 2, 76, 3, 90, 
    2, 68, 6, 88, 5, 73, 8, 57, 4, 84, 1, 61, 3, 52, 7, 60, 0, 13, 
    7, 77, 4, 41, 6, 26, 0, 92, 2, 88, 1, 31, 5, 52, 8, 99, 3,  3, 
    5, 14, 0, 81, 2, 67, 4, 63, 7, 98, 3, 28, 6, 22, 8, 58, 1, 18, 
    3, 43, 1, 16, 5,  9, 2, 42, 7, 29, 8, 88, 6, 85, 0, 12, 4,  2, 
    0, 22, 1, 61, 6, 53, 7, 59, 8, 55, 4, 58, 5, 76, 3, 87, 2, 73, 
    8, 61, 2, 19, 1, 62, 6, 66, 7, 39, 4, 72, 5, 31, 0, 61, 3, 71, 
    8, 96, 6, 42, 5, 33, 4, 67, 3, 44, 2, 19, 7, 70, 1, 70, 0, 56, 
    1, 77, 4, 82, 8, 57, 2, 79, 0, 60, 5, 77, 6, 40, 3,  9, 7, 23
  };
  const int q9853[] = {
    9, 9, // Number of jobs and machines
    4, 20, 1, 27, 6, 62, 5, 47, 8, 56, 0, 92, 2, 25, 7, 69, 3, 98, 
    7, 72, 5, 82, 2, 73, 8, 43, 6,  9, 1, 71, 3, 48, 4, 78, 0, 79, 
    6, 64, 2,  6, 8, 27, 0, 33, 7, 24, 5, 72, 4, 88, 3, 22, 1, 18, 
    3, 58, 0, 39, 7, 13, 5, 12, 2, 93, 6, 64, 1, 54, 4, 92, 8, 45, 
    2, 77, 7, 36, 8, 12, 4, 37, 1, 72, 0, 44, 5, 84, 3, 35, 6, 60, 
    6, 86, 5, 99, 4,  3, 8, 18, 2,  8, 7, 93, 3, 44, 0,  9, 1, 69, 
    8, 56, 7, 27, 1, 29, 6, 93, 3, 41, 2, 81, 5, 98, 4, 11, 0, 44, 
    1, 30, 4, 91, 3, 52, 7, 51, 5, 75, 2, 91, 6,  4, 0, 46, 8, 66, 
    2, 35, 3, 70, 0, 34, 5, 32, 4, 26, 8, 57, 7, 36, 1, 62, 6, 55
  };
  const int q9854[] = {
    9, 9, // Number of jobs and machines
    2, 26, 8, 86, 7, 83, 6, 64, 0, 66, 5,  2, 1, 47, 4, 59, 3, 34, 
    8, 96, 1, 16, 0, 69, 3, 72, 2, 92, 4, 61, 6, 91, 5, 38, 7, 33, 
    1, 47, 0, 60, 8, 14, 7, 20, 6, 64, 4, 94, 5, 72, 2, 57, 3,  4, 
    1, 72, 3, 32, 8, 14, 0, 20, 6, 83, 5, 60, 7, 37, 4, 32, 2, 94, 
    6, 25, 1, 12, 2,  5, 7, 31, 8, 66, 4, 71, 5, 81, 3, 48, 0, 71, 
    2, 95, 1,  4, 0, 69, 5, 39, 4, 47, 8, 52, 6, 34, 7, 64, 3, 92, 
    7, 35, 1, 34, 6, 47, 2, 37, 0, 70, 5, 60, 8, 27, 4, 74, 3, 88, 
    8, 99, 4, 91, 6, 90, 0, 44, 7, 91, 1, 69, 5, 84, 3, 68, 2, 51, 
    6, 53, 1, 83, 0, 42, 2, 42, 8, 94, 5, 27, 7, 71, 4, 68, 3, 11
  };
  const int q9855[] = {
    9, 9, // Number of jobs and machines
    0, 57, 3, 26, 4, 28, 8, 33, 7, 85, 1, 62, 5, 81, 6, 45, 2, 61, 
    0, 65, 3, 72, 1, 18, 4, 81, 5, 50, 6, 31, 2, 42, 7, 50, 8, 87, 
    1, 67, 5, 46, 0, 98, 3, 65, 6, 47, 2, 86, 7, 27, 8, 47, 4, 23, 
    1, 86, 0, 22, 6, 37, 4, 78, 8, 55, 5, 34, 2, 21, 3, 76, 7, 11, 
    4, 61, 3, 79, 2, 91, 8, 12, 5, 48, 6,  3, 1, 46, 7, 83, 0, 47, 
    5, 46, 7, 29, 4, 78, 6, 34, 3, 37, 0, 64, 8, 53, 1, 25, 2, 53, 
    6, 37, 3, 61, 4, 24, 1, 70, 8, 98, 7, 66, 5, 27, 2, 73, 0,  8, 
    3, 81, 2, 99, 5, 40, 7, 77, 0,  2, 1, 44, 4, 57, 6, 45, 8, 39, 
    5, 98, 7, 98, 6, 44, 0, 90, 2, 81, 8, 53, 4, 16, 3, 88, 1, 81
  };
  const int q9856[] = {
    9, 9, // Number of jobs and machines
    7, 69, 4, 63, 1, 84, 5, 11, 6, 78, 2, 17, 3, 88, 8, 75, 0, 60, 
    1, 51, 2, 37, 0, 77, 6, 46, 3, 90, 8, 71, 5, 61, 4, 79, 7, 78, 
    2, 90, 8, 10, 3, 37, 1, 71, 7, 48, 0, 28, 5, 84, 6, 49, 4, 76, 
    4, 21, 1, 16, 2, 95, 7, 50, 6, 78, 3, 92, 0, 17, 5, 57, 8, 67, 
    3, 77, 4, 92, 6, 23, 2, 73, 5, 41, 0, 61, 8, 90, 1, 14, 7, 34, 
    1, 89, 5, 95, 0, 57, 6, 80, 7, 55, 3, 60, 8, 11, 2,  6, 4, 99, 
    6, 45, 8, 34, 4, 99, 5, 62, 2, 22, 0, 28, 1, 70, 3,  8, 7, 72, 
    3,  3, 6, 92, 5, 67, 2,  2, 4, 70, 1, 52, 0, 49, 8,  2, 7, 55, 
    6, 72, 8, 98, 2, 43, 7, 62, 1,  5, 3,  3, 0, 33, 5, 75, 4, 68
  };
  const int q9857[] = {
    9, 9, // Number of jobs and machines
    8, 81, 2, 55, 4, 23, 7, 64, 5, 99, 3, 14, 1, 41, 0, 78, 6,  7, 
    7, 25, 3, 47, 5, 67, 0, 88, 1, 36, 2, 26, 4, 29, 8, 67, 6, 99, 
    3, 24, 2,  8, 5, 29, 4, 17, 8, 32, 6, 10, 7, 74, 0, 58, 1, 14, 
    4,  6, 1, 82, 6, 50, 7, 30, 0, 63, 8, 17, 5, 27, 2, 40, 3, 62, 
    7, 79, 1, 94, 2,  9, 8, 35, 4, 27, 3, 78, 0,  9, 6, 65, 5, 99, 
    0, 34, 8, 21, 4, 14, 1, 22, 2, 26, 3, 43, 7, 47, 6, 14, 5, 12, 
    1, 92, 7,  3, 2, 79, 0, 84, 4, 31, 5, 69, 8, 49, 6, 82, 3, 32, 
    5, 67, 4,  6, 1, 13, 0, 13, 2,  8, 7, 76, 3, 42, 8, 34, 6, 19, 
    1, 52, 3, 50, 7, 43, 8, 60, 5, 66, 4, 63, 2,  5, 6, 64, 0, 62
  };
  const int q9858[] = {
    9, 9, // Number of jobs and machines
    7, 75, 6,  6, 2, 72, 0, 66, 4,  1, 1, 37, 8, 98, 5, 68, 3,  2, 
    1, 22, 7, 56, 5, 86, 2, 60, 8, 54, 3, 35, 4, 90, 0,  2, 6, 42, 
    7, 40, 3, 16, 2, 17, 5, 72, 4, 48, 0, 77, 8, 28, 6, 16, 1, 60, 
    3, 16, 8, 98, 2, 87, 0, 56, 7, 38, 5, 72, 4, 20, 1, 81, 6, 34, 
    3, 72, 6, 20, 8, 14, 2, 14, 5, 17, 7,  2, 1, 91, 4, 16, 0, 40, 
    7, 97, 1, 71, 3, 52, 5, 78, 4, 53, 0, 12, 8, 96, 6, 17, 2, 35, 
    4, 85, 1, 30, 0, 43, 6, 48, 8, 40, 5, 23, 3, 31, 7, 80, 2, 77, 
    4, 10, 3, 51, 6, 42, 2, 82, 8, 19, 0,  7, 1, 93, 5, 69, 7, 56, 
    7, 82, 3, 98, 1, 91, 2, 48, 0, 97, 8, 79, 5, 10, 6, 75, 4, 84
  };
  const int q9859[] = {
    9, 9, // Number of jobs and machines
    6,  7, 2, 63, 1,  6, 0, 13, 3, 83, 8, 97, 7, 90, 4, 37, 5, 43, 
    6, 31, 4, 19, 7,  5, 5,  1, 3,  9, 8, 80, 0, 10, 1,  7, 2, 66, 
    1, 50, 4, 81, 7, 13, 8, 20, 6, 84, 3, 71, 0, 35, 5, 11, 2, 95, 
    5, 80, 2, 30, 1, 93, 6, 37, 7, 58, 4, 18, 0, 28, 8, 70, 3, 22, 
    7, 67, 6, 54, 0, 89, 3, 32, 1, 52, 5, 41, 4, 63, 8, 44, 2, 25, 
    7, 61, 3, 51, 1, 44, 2, 10, 8, 45, 0, 67, 4, 88, 5, 15, 6,  5, 
    4, 28, 2, 71, 5, 14, 0, 72, 1, 46, 6, 12, 3, 12, 8, 87, 7, 81, 
    0, 17, 6,  8, 5, 41, 4,  3, 7,  9, 1, 21, 8, 31, 3, 68, 2, 30, 
    4, 54, 7, 37, 1, 15, 3, 29, 2, 22, 8, 85, 6, 70, 5, 19, 0, 66
  };
  const int q9860[] = {
    9, 9, // Number of jobs and machines
    8, 59, 5, 77, 2, 96, 7, 14, 0, 94, 3, 63, 4, 13, 6,  2, 1, 86, 
    1, 41, 3, 89, 7, 91, 4, 51, 8, 22, 6, 12, 5, 53, 2, 18, 0, 25, 
    2, 69, 8, 25, 7, 90, 6, 33, 5,  4, 0, 19, 4, 28, 1, 98, 3, 66, 
    8, 30, 6, 75, 4,  2, 3, 52, 0, 32, 2, 66, 1, 84, 7, 34, 5, 80, 
    4,  9, 3, 41, 0,  4, 7,  7, 5, 48, 1, 14, 8, 90, 6, 30, 2, 13, 
    5, 87, 8, 72, 2, 89, 1, 87, 4, 50, 7, 23, 6, 64, 0, 55, 3, 63, 
    0, 33, 5, 87, 8, 47, 7, 23, 6,  8, 1, 54, 4, 13, 2, 47, 3, 96, 
    8, 32, 4, 64, 2, 67, 5,  8, 6,  6, 0, 68, 3, 61, 1, 47, 7, 15, 
    5, 46, 3, 18, 1,  9, 4, 54, 6, 69, 2, 66, 8, 89, 0, 93, 7, 57
  };
  const int q9861[] = {
    9, 9, // Number of jobs and machines
    4, 60, 1,  5, 3, 72, 6,  9, 8,  6, 7, 30, 5, 51, 0, 81, 2, 37, 
    4, 79, 3, 96, 5, 28, 0, 94, 7,  6, 2, 76, 8, 42, 1, 58, 6, 37, 
    1,  1, 4, 45, 8, 76, 3, 51, 6, 89, 7, 59, 0, 75, 2, 28, 5,  9, 
    6, 21, 2, 14, 7, 63, 4, 37, 8,  4, 0, 58, 5, 32, 1, 33, 3, 45, 
    0,  6, 5, 80, 2, 40, 6, 60, 7, 62, 4, 39, 3,  6, 1, 48, 8, 75, 
    3, 37, 1, 61, 7, 42, 6, 64, 8, 88, 2, 56, 4, 23, 5, 66, 0, 94, 
    5, 74, 8, 55, 7, 18, 0, 31, 6, 57, 1, 97, 2, 28, 3, 99, 4, 53, 
    0, 14, 2, 95, 1,  9, 6, 65, 8, 24, 3, 99, 5,  6, 7, 95, 4, 58, 
    4, 25, 0, 44, 7,  5, 2, 30, 8, 90, 6, 22, 5, 54, 3, 94, 1, 55
  };
  const int q9862[] = {
    9, 9, // Number of jobs and machines
    1, 55, 2, 19, 6, 42, 4, 95, 5, 95, 3, 36, 8,  9, 7, 81, 0, 34, 
    0, 52, 7,  5, 4, 23, 1, 14, 6,  1, 2, 42, 8, 73, 5,  6, 3, 85, 
    0, 12, 1, 29, 2, 23, 4, 73, 7, 96, 5, 94, 8, 64, 6, 41, 3, 53, 
    8, 48, 7, 21, 0, 94, 1, 56, 4, 79, 2, 85, 3, 47, 6, 39, 5, 28, 
    6, 42, 0, 41, 5, 54, 4, 53, 2, 39, 8, 30, 1,  6, 7, 17, 3, 36, 
    3, 12, 6,  4, 7, 11, 0, 70, 5, 72, 1, 41, 8, 90, 2, 90, 4, 35, 
    1, 30, 7, 70, 6, 74, 0, 82, 2, 13, 5, 47, 3, 96, 4,  5, 8, 56, 
    1, 96, 7, 72, 8, 48, 2, 86, 6, 99, 5, 96, 0, 33, 4, 14, 3, 22, 
    6, 92, 0, 99, 8, 66, 4,  9, 5, 89, 3, 59, 2, 16, 1, 15, 7, 93
  };
  const int q9863[] = {
    9, 9, // Number of jobs and machines
    1, 63, 5, 50, 3, 53, 4, 30, 0, 26, 2, 61, 7,  4, 8, 98, 6, 97, 
    6, 14, 2, 11, 8, 89, 5, 72, 3, 36, 4, 83, 0, 28, 1, 38, 7, 13, 
    1, 63, 7, 30, 2,  9, 0,  4, 4, 61, 6, 58, 8,  5, 3, 81, 5, 24, 
    7, 88, 6, 12, 1,  6, 3, 41, 8, 46, 5, 46, 2, 70, 0, 69, 4, 39, 
    6,  4, 7, 58, 0, 68, 5, 20, 8, 61, 2, 79, 1, 53, 4, 77, 3,  2, 
    5, 95, 8, 53, 3, 19, 6,  3, 4, 58, 0, 38, 2, 38, 1, 71, 7, 39, 
    2, 42, 3, 22, 7, 12, 8, 11, 1, 96, 4, 30, 5, 99, 0, 53, 6, 83, 
    1,  3, 8, 11, 6, 30, 2,  2, 5, 86, 4, 19, 3, 54, 7, 47, 0, 87, 
    3, 95, 4, 58, 7,  9, 8, 59, 1, 88, 0, 70, 2, 57, 5, 87, 6,  3
  };
  const int q9864[] = {
    9, 9, // Number of jobs and machines
    3, 11, 0, 88, 1,  3, 2,  6, 4, 17, 7, 62, 8, 79, 6, 60, 5, 18, 
    5, 75, 3, 26, 6, 72, 4, 47, 0, 26, 2, 28, 7, 40, 8, 46, 1, 16, 
    4, 14, 0, 33, 7, 20, 6,  1, 3, 51, 5, 66, 2, 80, 1, 70, 8, 40, 
    2, 70, 4,  6, 8, 37, 0, 35, 6, 83, 5, 46, 1, 33, 7, 74, 3, 34, 
    5, 84, 7, 16, 6, 79, 4, 47, 2, 48, 0, 95, 3, 51, 8,  4, 1, 15, 
    8, 66, 5, 54, 1, 52, 2, 47, 3, 72, 6, 54, 4, 23, 0,  6, 7, 23, 
    2, 88, 6, 29, 7, 86, 8, 63, 3, 70, 4, 81, 5, 28, 0, 68, 1, 89, 
    3, 62, 1, 84, 4, 42, 2, 89, 6,  4, 0, 81, 5, 99, 8, 39, 7, 96, 
    8, 90, 3, 34, 6, 20, 2, 14, 7, 51, 0, 91, 5, 62, 4, 42, 1, 27
  };
  const int q9865[] = {
    9, 9, // Number of jobs and machines
    1, 47, 0,  9, 4, 17, 7, 96, 6, 10, 2, 82, 8, 34, 3,  9, 5, 40, 
    5, 51, 0, 48, 6, 97, 7, 33, 8, 52, 4, 43, 3, 40, 1, 21, 2, 90, 
    1, 19, 6, 42, 8, 37, 5, 19, 0, 34, 2, 80, 3, 99, 7, 74, 4, 76, 
    7,  2, 4, 64, 6, 13, 2, 29, 3, 21, 5, 39, 1, 93, 0, 89, 8, 74, 
    8, 19, 7, 90, 3, 17, 5, 97, 2, 21, 4, 52, 6, 73, 0, 19, 1, 80, 
    8, 78, 2, 20, 0, 22, 3, 40, 4, 95, 7, 55, 5,  7, 6, 91, 1, 93, 
    1, 30, 2, 46, 5, 39, 6, 56, 4, 29, 0,  6, 3, 92, 7, 28, 8, 54, 
    1, 50, 7, 73, 2, 67, 8, 14, 3, 35, 5, 80, 4, 41, 6, 14, 0, 21, 
    1, 36, 2,  9, 0, 39, 7, 67, 3, 76, 4, 40, 5, 10, 8, 82, 6, 35
  };
  const int q9866[] = {
    9, 9, // Number of jobs and machines
    1, 65, 0, 70, 3,  1, 2, 59, 8, 43, 7,  5, 4, 80, 5, 72, 6,  8, 
    3, 55, 6, 98, 2, 84, 1, 35, 0, 62, 5, 78, 8, 85, 4, 50, 7, 67, 
    2, 43, 5, 70, 7, 89, 6, 20, 8, 43, 1, 75, 3, 53, 4, 78, 0, 99, 
    1, 89, 5, 86, 6, 46, 2, 68, 0, 12, 4,  2, 7, 25, 8, 46, 3, 47, 
    7, 56, 8, 16, 6, 50, 1, 37, 4,  6, 3, 80, 0, 84, 5, 31, 2, 41, 
    5, 61, 4, 97, 8, 86, 7, 51, 0, 50, 6, 76, 1, 79, 3, 23, 2, 51, 
    5, 44, 2, 67, 1,  9, 6, 13, 4,  9, 8, 23, 0, 24, 7, 23, 3, 68, 
    1, 12, 3,  2, 6, 10, 4, 73, 0, 95, 7, 17, 5, 94, 2, 17, 8, 81, 
    4, 49, 7, 18, 5, 89, 0, 84, 8, 96, 2, 68, 3,  9, 6, 67, 1, 78
  };
  const int q9867[] = {
    9, 9, // Number of jobs and machines
    8, 99, 2, 35, 6, 95, 7, 89, 0, 26, 1,  8, 4, 54, 3, 61, 5, 51, 
    5, 44, 1, 42, 3, 46, 0, 82, 4, 51, 8, 84, 7, 66, 2, 78, 6, 41, 
    2, 73, 4, 71, 5, 62, 7, 96, 3, 52, 0, 25, 8, 72, 1, 68, 6, 17, 
    7, 87, 0, 28, 6, 79, 8, 51, 3, 28, 5, 58, 4,  3, 1, 57, 2, 33, 
    7, 11, 0, 71, 1, 21, 2, 43, 8, 14, 4, 50, 5,  4, 3, 52, 6, 64, 
    7, 54, 0, 22, 4, 67, 3,  5, 6, 14, 5, 15, 1, 28, 2, 46, 8, 41, 
    4, 74, 8, 13, 0, 89, 7, 72, 1, 35, 5, 64, 6, 43, 2, 77, 3, 35, 
    4, 78, 3, 61, 0, 95, 5, 41, 2, 96, 6, 93, 8, 86, 1, 16, 7,  3, 
    3, 29, 5, 77, 6, 48, 0, 42, 2, 81, 1, 44, 8, 76, 4, 57, 7, 37
  };
  const int q9868[] = {
    9, 9, // Number of jobs and machines
    5, 67, 4, 55, 2, 53, 3, 77, 6, 90, 0, 95, 1, 18, 7, 19, 8, 51, 
    8, 87, 4, 34, 6, 98, 5, 95, 2, 81, 0, 25, 7,  7, 1, 81, 3, 21, 
    3, 29, 0, 67, 6, 78, 7,  4, 2, 66, 4, 92, 1, 55, 8,  5, 5, 78, 
    4, 16, 3, 12, 6, 67, 7, 55, 5, 93, 2, 18, 8, 95, 0, 70, 1, 82, 
    8, 27, 2, 70, 4, 36, 3, 55, 6,  2, 7,  2, 1, 38, 0, 34, 5, 38, 
    6, 97, 5,  6, 4, 95, 7, 89, 8, 18, 3, 30, 0, 34, 2,  9, 1,  2, 
    3, 81, 1, 77, 2, 56, 8, 54, 5, 25, 6, 14, 0, 21, 7, 71, 4, 40, 
    7, 23, 8, 95, 1, 72, 6, 29, 0, 64, 3, 61, 4, 18, 2, 57, 5, 89, 
    4,  6, 6, 28, 3, 22, 0, 79, 7, 87, 2, 65, 8, 25, 1, 27, 5, 66
  };
  const int q9869[] = {
    9, 9, // Number of jobs and machines
    5, 99, 2, 31, 3, 17, 1, 85, 0, 46, 7, 92, 8, 92, 6, 89, 4, 55, 
    8, 92, 5, 17, 4, 58, 2, 62, 7, 11, 0, 82, 1, 99, 3,  8, 6, 39, 
    6, 62, 0,  6, 5, 58, 7, 22, 2, 46, 1, 27, 8, 33, 4, 70, 3, 31, 
    1, 13, 2, 94, 8, 31, 6, 68, 0, 44, 5, 43, 3, 12, 4, 69, 7, 57, 
    1, 51, 6,  6, 0, 82, 2, 78, 3, 69, 8, 72, 4, 46, 5, 46, 7, 46, 
    3, 21, 6,  1, 4, 33, 5, 77, 0, 97, 1, 94, 2, 95, 8, 69, 7,  7, 
    0, 90, 8,  1, 2, 63, 4, 64, 1, 27, 5, 83, 6, 30, 7, 88, 3, 47, 
    3, 44, 0, 84, 2, 13, 7, 13, 4, 35, 8, 25, 1, 28, 5, 37, 6,  2, 
    2, 48, 7, 25, 6,  9, 3, 50, 5, 21, 1, 95, 0, 52, 4, 37, 8, 40
  };
  const int q9870[] = {
    9, 9, // Number of jobs and machines
    3, 97, 7, 94, 5, 50, 2, 47, 6,  6, 0, 92, 8, 83, 4, 13, 1, 33, 
    4, 61, 3, 63, 8, 98, 1, 25, 0, 78, 7, 66, 2, 88, 5, 82, 6,  4, 
    4, 38, 2, 11, 5, 31, 7, 77, 1, 49, 8, 10, 3, 40, 6, 42, 0, 30, 
    3, 70, 0, 65, 4, 32, 5, 19, 8, 73, 2, 93, 7, 85, 1, 80, 6, 67, 
    0, 39, 7, 74, 1, 90, 6, 26, 8,  8, 2, 84, 5, 61, 4,  2, 3, 82, 
    0, 32, 1,  7, 6, 86, 5, 60, 4, 18, 8, 65, 2, 70, 3, 66, 7,  6, 
    7, 84, 0,  3, 8, 36, 4, 97, 2, 93, 6,  2, 1, 10, 3, 40, 5, 75, 
    4, 57, 8, 53, 3,  8, 1, 62, 6, 90, 7, 43, 5, 22, 0,  9, 2, 17, 
    8,  3, 0, 94, 4, 87, 6, 94, 7, 31, 2, 41, 1, 95, 5,  5, 3, 32
  };
  const int q9871[] = {
    9, 9, // Number of jobs and machines
    4, 50, 7, 34, 5, 65, 8, 74, 6, 51, 0, 46, 1, 32, 3, 91, 2,  4, 
    4, 49, 6, 94, 3, 12, 1, 29, 7, 97, 8, 58, 0, 26, 5, 69, 2, 80, 
    8, 83, 5, 15, 7, 70, 3, 83, 2, 13, 0, 55, 1, 60, 6,  6, 4, 64, 
    7, 29, 6, 62, 3, 62, 5, 31, 2, 33, 1, 55, 0, 10, 4, 24, 8, 97, 
    8, 40, 5, 46, 4, 85, 2, 48, 1, 78, 7, 72, 6, 42, 0,  7, 3, 23, 
    7, 20, 1, 63, 3, 14, 0, 29, 5, 72, 4, 82, 8, 37, 2, 50, 6, 11, 
    1, 99, 4,  2, 8, 89, 0, 82, 5, 75, 7, 24, 2, 98, 6, 80, 3, 99, 
    0, 13, 8, 23, 5, 14, 4, 12, 2, 94, 1, 11, 7, 50, 3, 38, 6,  1, 
    5, 15, 7, 91, 6, 88, 2, 50, 3, 99, 0, 96, 4, 33, 8, 59, 1, 19
  };
  const int q9872[] = {
    9, 9, // Number of jobs and machines
    1, 27, 4, 88, 0, 60, 7, 18, 3, 43, 5, 99, 6, 13, 2, 49, 8, 41, 
    7, 74, 4, 17, 6, 55, 1, 88, 8, 27, 2, 16, 3, 32, 5, 76, 0, 15, 
    7, 73, 6, 73, 8, 69, 0,  8, 4, 31, 3, 67, 2, 82, 5, 68, 1, 90, 
    6, 71, 8, 49, 4, 43, 3, 84, 0, 10, 1, 96, 2, 55, 7, 40, 5, 26, 
    4, 59, 5, 19, 1,  8, 8, 75, 3,  6, 0, 60, 7, 36, 6, 99, 2, 47, 
    0,  2, 4, 38, 8, 64, 7, 63, 5, 34, 2, 89, 6, 95, 3, 81, 1, 33, 
    4, 49, 5, 87, 2, 76, 0, 47, 7, 71, 3, 33, 6,  1, 1, 42, 8, 24, 
    7, 44, 1, 96, 6, 24, 8, 81, 0, 82, 3, 55, 5, 21, 2, 64, 4, 14, 
    7, 51, 6, 28, 4, 52, 3, 19, 0,  6, 1, 27, 2, 11, 8, 83, 5, 45
  };
  const int q9873[] = {
    9, 9, // Number of jobs and machines
    4, 44, 7, 81, 8, 53, 0, 62, 6, 53, 1, 84, 2, 16, 5, 60, 3, 93, 
    3, 51, 2, 28, 7, 46, 4, 21, 5, 11, 8, 89, 1, 26, 0, 71, 6, 21, 
    3, 68, 1, 63, 4,  2, 2,  1, 8, 16, 6, 16, 7, 19, 5, 59, 0, 24, 
    2, 44, 3, 49, 5, 77, 1, 73, 7, 18, 6, 36, 4,  7, 8,  1, 0, 52, 
    2, 25, 3, 75, 4, 88, 5, 71, 0, 13, 6, 15, 8, 75, 7, 57, 1, 49, 
    5, 83, 8, 18, 2, 93, 0, 76, 4, 36, 3, 42, 7, 76, 1, 33, 6, 82, 
    7,  9, 4, 28, 1, 37, 5, 80, 8, 85, 2, 77, 6, 95, 3, 23, 0, 29, 
    4, 81, 6,  2, 8, 61, 3, 61, 5, 44, 1,  3, 7, 78, 0, 25, 2, 10, 
    7, 63, 8, 96, 6, 99, 0, 68, 3, 35, 4, 22, 1, 95, 2, 74, 5,  5
  };
  const int q9874[] = {
    9, 9, // Number of jobs and machines
    7, 34, 4, 22, 5, 36, 3, 27, 0, 56, 1, 98, 8, 85, 2, 95, 6, 35, 
    0, 61, 4, 71, 1, 23, 3,  9, 6, 31, 8, 40, 2, 50, 5, 11, 7, 76, 
    3, 68, 8, 86, 7, 81, 6, 98, 4,  5, 2, 97, 5, 76, 1, 25, 0,  7, 
    2, 48, 5, 14, 6, 93, 8, 91, 0,  6, 3, 35, 1, 95, 4, 77, 7,  7, 
    4, 18, 2, 63, 7, 16, 5, 50, 6, 49, 1, 20, 3, 69, 0, 42, 8, 73, 
    8, 77, 6, 89, 5,  3, 0, 99, 3, 89, 4, 89, 2, 64, 1,  7, 7, 94, 
    4,  9, 6, 29, 5, 50, 7,  9, 3, 29, 8, 27, 2, 72, 1, 39, 0, 78, 
    3, 94, 0, 16, 6, 60, 7, 35, 5, 94, 4, 43, 8, 22, 2, 99, 1, 55, 
    5, 65, 2, 30, 8, 48, 6, 31, 3, 42, 4,  2, 0, 78, 1, 17, 7,  6
  };
  const int q9875[] = {
    9, 9, // Number of jobs and machines
    3,  5, 2, 64, 5, 36, 8, 69, 4,  6, 7, 92, 0, 17, 1, 77, 6, 73, 
    3,  6, 0, 51, 8, 72, 4, 76, 2, 29, 5, 83, 1, 85, 6, 67, 7, 32, 
    3, 84, 2, 79, 1, 77, 4,  1, 7, 53, 0, 65, 8, 44, 5, 99, 6, 50, 
    8, 19, 1, 81, 0, 66, 2, 74, 3, 38, 6, 20, 4, 41, 5, 37, 7, 57, 
    0, 56, 5, 87, 3, 23, 6, 78, 2, 41, 7, 91, 4, 43, 8, 49, 1, 85, 
    7, 22, 8, 32, 3, 95, 5, 73, 6, 81, 1, 18, 2, 77, 4, 96, 0, 70, 
    8,  4, 7, 32, 5,  2, 2, 52, 0, 88, 3, 77, 6, 53, 1, 13, 4, 51, 
    0, 92, 1, 81, 6, 97, 4,  5, 7, 48, 8, 17, 2, 76, 5, 42, 3, 21, 
    2, 55, 1, 30, 8, 30, 3,  8, 5, 32, 4, 90, 6, 25, 0, 93, 7, 92
  };
  const int q9876[] = {
    9, 9, // Number of jobs and machines
    4, 36, 3, 19, 2, 44, 1, 11, 6, 23, 7, 25, 0, 59, 8, 49, 5, 66, 
    0, 54, 5, 10, 8, 30, 7, 36, 4, 10, 3, 39, 6, 91, 1, 78, 2, 64, 
    2, 47, 5, 55, 4,  2, 8, 12, 0, 89, 7, 48, 1, 67, 3, 86, 6, 59, 
    1, 83, 2, 61, 8, 13, 4,  7, 7, 77, 6, 78, 5, 19, 0, 63, 3, 79, 
    3,  3, 5, 57, 7, 98, 0, 49, 6, 42, 1, 87, 2, 28, 4, 52, 8, 28, 
    1, 98, 5, 24, 3,  5, 0, 36, 2, 66, 7, 30, 4, 63, 6, 26, 8, 77, 
    5, 79, 6, 82, 0, 37, 8, 48, 2, 81, 4, 58, 3, 47, 1, 12, 7, 39, 
    3, 75, 8, 11, 7, 79, 5, 61, 1, 73, 6, 77, 2, 68, 4, 84, 0, 93, 
    6, 48, 8,  3, 2,  7, 4, 53, 7,  6, 0,  7, 5, 80, 3, 10, 1, 99
  };
  const int q9877[] = {
    9, 9, // Number of jobs and machines
    2, 47, 3, 70, 8, 45, 0, 50, 5, 65, 6, 42, 1, 67, 4, 46, 7, 33, 
    6, 21, 8, 45, 4, 60, 5, 86, 1, 87, 7, 83, 0, 25, 3, 13, 2, 30, 
    8, 61, 1, 38, 7, 10, 0, 12, 4, 80, 6,  2, 3, 35, 2, 71, 5, 24, 
    1, 27, 5, 80, 7, 29, 3, 83, 4, 47, 8, 61, 2, 31, 0, 24, 6, 89, 
    2, 19, 7, 97, 6, 73, 3, 46, 5, 86, 1, 84, 0, 81, 4, 15, 8, 52, 
    1, 48, 0, 92, 2, 30, 5, 13, 8, 89, 3, 13, 7, 92, 6, 11, 4, 69, 
    5, 71, 8, 39, 6, 61, 3, 51, 7,  3, 2,  2, 0, 14, 4, 35, 1, 46, 
    1, 20, 2, 24, 6, 93, 0, 15, 8, 48, 3,  7, 7, 92, 4, 20, 5, 61, 
    7, 60, 2, 45, 6, 38, 4, 98, 3, 10, 1, 37, 0, 57, 5, 82, 8, 35
  };
  const int q9878[] = {
    9, 9, // Number of jobs and machines
    3, 46, 1, 62, 0, 39, 6, 95, 2, 95, 7,  7, 4, 26, 8,  6, 5, 59, 
    3, 60, 7, 70, 4, 19, 6, 39, 2, 57, 1, 70, 5, 74, 0, 87, 8, 70, 
    1, 19, 6, 46, 5, 29, 2,  5, 7, 83, 4, 56, 8, 78, 3, 63, 0, 54, 
    2, 33, 1, 23, 5, 71, 6, 79, 3, 82, 4, 25, 8, 34, 7, 63, 0, 18, 
    1, 72, 6, 98, 0, 32, 8, 43, 3, 78, 5, 43, 7, 75, 4, 96, 2, 85, 
    8, 64, 1, 42, 0, 47, 5, 12, 4, 62, 6, 80, 3, 83, 2, 56, 7, 69, 
    1, 57, 5, 55, 4, 26, 7, 22, 2, 71, 0, 27, 6,  4, 3, 24, 8, 13, 
    4, 60, 3, 31, 8, 88, 5, 70, 6, 47, 7, 40, 0, 84, 1, 90, 2, 21, 
    3, 15, 6, 21, 5, 55, 4, 82, 7, 83, 1, 48, 8, 68, 2, 50, 0, 43
  };
  const int q9879[] = {
    9, 9, // Number of jobs and machines
    3, 58, 8, 99, 1, 12, 7, 99, 4, 25, 5, 95, 0, 92, 6, 84, 2, 55, 
    5, 36, 3, 73, 1, 66, 2, 76, 8, 68, 4, 30, 6, 27, 7,  8, 0, 34, 
    4, 23, 5, 79, 7, 77, 6, 18, 3, 77, 8, 70, 0, 40, 2, 70, 1, 56, 
    6, 30, 2, 22, 7, 15, 4,  7, 3, 15, 1,  1, 8, 77, 5, 38, 0, 70, 
    2, 13, 5, 71, 8, 72, 1, 30, 7, 76, 0, 21, 3, 29, 6, 67, 4, 33, 
    0, 32, 6, 88, 8, 88, 3,  4, 1, 69, 2, 41, 7, 39, 4, 18, 5, 84, 
    0, 66, 7, 25, 1, 85, 3, 46, 2, 58, 5, 40, 4, 87, 8, 15, 6, 40, 
    3, 86, 0, 54, 6, 75, 2, 58, 8, 44, 1, 75, 7, 10, 5, 40, 4, 31, 
    7, 65, 4,  6, 0, 14, 2, 41, 5, 37, 3, 77, 8, 84, 1, 69, 6, 63
  };
  const int q9880[] = {
    9, 9, // Number of jobs and machines
    4, 94, 7, 99, 1, 67, 2, 77, 8, 39, 5, 88, 6, 95, 3, 57, 0, 11, 
    2, 91, 7, 58, 6, 40, 8, 67, 4,  9, 3, 62, 5, 45, 1, 41, 0, 99, 
    7, 17, 6, 93, 8, 63, 2, 35, 0,  3, 3, 88, 4, 42, 5, 84, 1,  6, 
    5, 68, 8, 65, 1, 85, 2, 11, 0, 73, 3, 55, 4, 99, 7, 95, 6, 35, 
    3, 20, 0, 58, 2, 57, 7, 34, 8, 52, 6, 39, 5, 92, 4, 47, 1, 91, 
    6, 93, 2, 98, 1, 33, 4, 32, 5,  6, 7, 22, 0,  6, 8, 37, 3, 75, 
    2, 28, 4, 84, 5, 75, 7, 71, 1, 85, 0, 67, 8, 99, 3, 49, 6, 68, 
    3, 71, 7, 70, 2, 87, 6, 57, 1, 62, 5, 17, 4, 68, 8, 62, 0, 98, 
    2, 62, 3, 32, 8, 97, 4, 60, 5, 90, 7, 78, 6, 79, 0, 10, 1, 70
  };
  const int q9881[] = {
    9, 9, // Number of jobs and machines
    5, 67, 7, 72, 1, 70, 2, 60, 4, 33, 3, 13, 0, 10, 8, 40, 6, 19, 
    2, 85, 0, 44, 4, 10, 7, 26, 8, 39, 5, 56, 3, 51, 1, 65, 6, 11, 
    5, 57, 7, 20, 1, 80, 0, 23, 2, 74, 3, 36, 4, 94, 8, 45, 6, 84, 
    6, 79, 3, 35, 1, 74, 4, 14, 8, 58, 5, 95, 2, 34, 0, 98, 7, 14, 
    2, 89, 8, 57, 1, 53, 7, 35, 6,  8, 3,  4, 0, 31, 4, 58, 5, 64, 
    8, 93, 3, 25, 7, 43, 1, 86, 5, 56, 0, 51, 2, 99, 4, 59, 6, 57, 
    3, 54, 5, 32, 6, 22, 0, 73, 7, 89, 1, 73, 4, 68, 8, 69, 2, 87, 
    5, 82, 2, 94, 4, 42, 6, 60, 0, 36, 3, 65, 7, 41, 1,  3, 8, 29, 
    7, 80, 4, 74, 6, 10, 0, 82, 2, 49, 5, 97, 3, 45, 1, 10, 8, 56
  };
  const int q9882[] = {
    9, 9, // Number of jobs and machines
    0,  9, 1,  7, 7, 91, 5, 37, 3,  1, 6, 20, 2, 36, 8, 26, 4, 98, 
    0, 94, 6, 30, 2,  2, 4, 81, 7, 65, 1, 46, 8, 73, 5, 75, 3, 28, 
    2, 69, 0, 34, 1, 56, 6, 82, 8, 13, 3, 34, 7, 45, 4, 94, 5,  9, 
    5, 89, 4, 18, 6, 35, 3, 40, 7, 41, 2, 51, 1, 33, 8, 63, 0, 83, 
    1, 31, 2, 73, 4, 88, 7, 54, 3, 35, 0, 36, 5, 98, 6,  9, 8, 71, 
    8, 60, 4,  1, 6, 20, 5, 62, 2, 47, 0, 39, 1, 34, 3, 74, 7,  7, 
    1, 28, 4, 39, 8, 12, 6, 28, 2, 38, 3, 91, 5, 38, 7, 44, 0, 67, 
    5, 21, 6, 69, 2,  3, 3,  7, 4, 80, 0, 65, 1, 32, 8, 47, 7, 56, 
    6, 45, 8, 77, 1, 75, 5, 64, 7, 52, 3, 77, 4, 10, 0, 85, 2, 36
  };
  const int q9883[] = {
    9, 9, // Number of jobs and machines
    7, 33, 0, 65, 1, 25, 8,  7, 6, 65, 2, 88, 5, 22, 3, 71, 4,  8, 
    5, 65, 0, 15, 2, 31, 6, 67, 7, 35, 4, 44, 1, 92, 8, 48, 3, 19, 
    8, 94, 4, 86, 2, 78, 6, 87, 5, 82, 3, 49, 7, 84, 1, 58, 0, 41, 
    7, 75, 8, 97, 6,  6, 1, 15, 3, 54, 2, 39, 4, 98, 0, 42, 5, 38, 
    5, 96, 2, 19, 0, 69, 4, 16, 6, 98, 3, 25, 7, 88, 8, 79, 1, 99, 
    3, 62, 5, 55, 6, 67, 8, 44, 4, 13, 7, 28, 1, 78, 0, 44, 2, 52, 
    3, 85, 1, 93, 7, 43, 2, 95, 4, 36, 5, 53, 8,  3, 6, 63, 0, 88, 
    3, 59, 8, 22, 7, 49, 1, 36, 6, 89, 4, 32, 0, 28, 5, 20, 2, 23, 
    6, 91, 5, 89, 7, 42, 4, 90, 2, 84, 3, 13, 1,  9, 8, 11, 0, 74
  };
  const int q9884[] = {
    9, 9, // Number of jobs and machines
    6, 83, 8, 27, 4, 40, 1, 35, 7, 27, 0, 75, 2, 91, 5, 71, 3, 27, 
    7, 98, 2, 32, 5, 62, 0, 50, 4, 57, 6, 80, 1, 20, 8, 39, 3, 18, 
    3,  2, 1, 82, 2, 66, 5, 18, 8, 76, 7, 48, 4, 37, 6, 45, 0, 28, 
    4,  3, 7, 25, 0, 30, 3, 14, 5, 41, 1, 51, 2, 46, 6, 74, 8, 77, 
    5,  4, 7, 66, 1, 91, 6,  9, 2, 85, 3, 92, 8,  4, 4,  4, 0, 53, 
    7, 98, 2, 11, 0,  6, 5, 37, 6, 78, 4, 52, 1, 24, 8, 40, 3, 19, 
    8, 10, 3, 83, 5, 95, 0, 89, 4, 84, 6, 29, 2, 50, 7, 57, 1, 46, 
    5, 40, 7, 25, 4,  8, 6, 71, 1, 86, 2,  1, 8, 66, 3, 63, 0, 76, 
    7, 52, 6, 35, 3, 71, 8, 36, 2, 89, 1, 84, 0, 46, 5, 20, 4, 47
  };
  const int q9885[] = {
    9, 9, // Number of jobs and machines
    0, 71, 2, 94, 6, 18, 7, 80, 5, 61, 4, 94, 1, 99, 3, 61, 8, 39, 
    3, 97, 4,  8, 0, 33, 1, 27, 8, 39, 6, 67, 2, 49, 5, 65, 7, 90, 
    1, 95, 3, 68, 6, 94, 4, 51, 0, 10, 5, 96, 7,  8, 2, 89, 8, 33, 
    2, 77, 4, 70, 1, 32, 5, 89, 3, 80, 8, 13, 6, 14, 0,  7, 7, 72, 
    1, 15, 8, 92, 4, 54, 5, 52, 6, 80, 3,  7, 7,  5, 0, 67, 2, 64, 
    2,  8, 0, 32, 7, 23, 8, 48, 6, 69, 5, 46, 4, 75, 1, 92, 3, 20, 
    1,  9, 0, 69, 3, 78, 2, 68, 8, 26, 7, 72, 5, 85, 4, 46, 6, 21, 
    4, 16, 3, 62, 1, 76, 2, 40, 5, 53, 6, 82, 0, 60, 7,  2, 8, 70, 
    4, 59, 0, 83, 3, 34, 8, 57, 5, 75, 7, 78, 2, 90, 6, 34, 1, 88
  };
  const int q9886[] = {
    9, 9, // Number of jobs and machines
    5, 76, 1, 61, 4, 70, 6, 19, 8, 63, 3, 65, 7, 94, 2, 41, 0, 52, 
    7, 98, 3, 93, 0, 61, 4,  2, 2, 87, 8, 92, 1, 15, 5, 53, 6, 88, 
    5,  4, 7, 77, 6, 15, 8,  8, 2, 84, 3,  8, 0, 84, 1, 43, 4, 59, 
    2, 31, 1,  4, 5,  7, 8, 14, 7, 37, 4, 93, 3, 49, 6, 46, 0, 51, 
    7, 23, 5,  7, 4, 87, 1, 49, 2, 50, 8, 17, 3, 30, 6,  9, 0, 26, 
    8, 34, 4, 91, 0, 41, 3, 37, 2, 64, 5,  5, 7, 85, 6, 84, 1, 19, 
    1, 17, 4, 12, 3, 71, 2, 46, 7, 32, 0, 76, 8, 44, 5, 58, 6, 12, 
    7, 12, 1, 71, 8, 90, 4, 15, 2, 85, 0, 11, 3, 39, 6,  1, 5, 36, 
    8, 29, 1,  6, 6, 36, 3, 92, 2, 43, 7, 82, 0, 13, 4, 73, 5, 12
  };
  const int q9887[] = {
    9, 9, // Number of jobs and machines
    1, 77, 8, 13, 4, 61, 2, 35, 5, 31, 3, 76, 0, 41, 6, 43, 7, 32, 
    8, 28, 3, 25, 6, 75, 7, 29, 2, 73, 1, 74, 5, 65, 4, 37, 0, 93, 
    6, 71, 1, 73, 0, 54, 7, 97, 8, 97, 2,  8, 4, 36, 3, 28, 5, 81, 
    5, 25, 2, 48, 8, 86, 7, 12, 1, 90, 6, 23, 4, 63, 0, 77, 3, 96, 
    6, 49, 5, 93, 2, 99, 8,  2, 7, 17, 1, 30, 0, 28, 4, 51, 3,  5, 
    5, 73, 2, 59, 3, 56, 0, 98, 6, 14, 1, 75, 4, 47, 7, 92, 8, 76, 
    4, 84, 5, 89, 2, 69, 6, 68, 7, 38, 1, 42, 8, 23, 3, 15, 0, 41, 
    0, 27, 7, 33, 5, 38, 8, 67, 6, 93, 2, 62, 4, 12, 1, 77, 3, 90, 
    1, 49, 5, 84, 3, 11, 0, 76, 7, 54, 4, 15, 8,  5, 6, 25, 2,  7
  };
  const int q9888[] = {
    9, 9, // Number of jobs and machines
    3, 43, 1, 31, 5, 63, 2, 14, 0, 99, 4, 22, 6, 90, 7, 91, 8, 63, 
    1, 77, 2, 53, 7, 15, 0, 17, 4, 13, 8, 87, 6, 41, 3, 12, 5, 96, 
    6, 22, 1, 30, 0,  8, 2, 75, 8, 75, 3, 71, 5, 75, 7, 54, 4, 55, 
    7, 41, 6, 96, 2,  3, 0, 62, 4,  3, 1, 97, 5, 15, 8, 27, 3, 73, 
    4, 30, 2, 65, 1, 19, 3,  1, 6, 41, 8, 48, 7, 39, 5, 44, 0, 60, 
    8, 25, 6, 44, 3, 50, 5, 67, 4, 75, 0,  8, 7, 63, 1, 96, 2, 10, 
    6, 54, 3, 28, 7, 27, 4, 70, 2, 83, 5, 59, 8, 51, 0, 23, 1, 71, 
    1,  3, 7, 62, 3,  4, 6,  2, 4, 83, 0, 92, 8, 43, 2, 23, 5, 31, 
    6, 92, 0, 31, 2, 80, 1, 53, 8, 32, 3, 67, 4, 19, 5, 47, 7, 27
  };
  const int q9889[] = {
    9, 9, // Number of jobs and machines
    0,  1, 4, 45, 8, 96, 2, 48, 1, 59, 3, 72, 7, 72, 5, 19, 6, 19, 
    3, 22, 7, 83, 1, 26, 0, 94, 5, 25, 6, 29, 8, 68, 4, 96, 2, 14, 
    2, 72, 8,  6, 7,  3, 6, 33, 0, 15, 4, 76, 3, 88, 1, 52, 5, 56, 
    0, 41, 6, 55, 4, 99, 2, 42, 5, 79, 1, 19, 3, 71, 8, 59, 7, 23, 
    3, 93, 5, 18, 4, 14, 1, 85, 7, 44, 0, 28, 8, 13, 6, 84, 2, 27, 
    1, 96, 6, 84, 4,  3, 8, 21, 7, 24, 5, 17, 3, 58, 2, 11, 0, 14, 
    0,  6, 4, 79, 6, 83, 7, 33, 8, 57, 2, 26, 5, 17, 3, 38, 1, 12, 
    0, 10, 5, 43, 7, 42, 4, 16, 8, 37, 6, 30, 2, 56, 3, 47, 1, 18, 
    7, 79, 8, 70, 0, 20, 6, 90, 2, 21, 4, 14, 1, 48, 3, 15, 5, 67
  };
  const int q9890[] = {
    9, 9, // Number of jobs and machines
    5, 36, 0, 59, 7, 80, 3, 70, 6, 93, 2, 95, 4, 92, 1, 51, 8, 17, 
    5, 56, 1, 50, 0, 24, 8, 99, 7, 56, 6, 86, 4, 82, 3, 47, 2, 29, 
    5, 96, 7, 21, 8, 89, 4, 75, 6, 62, 1, 41, 2, 58, 0,  8, 3, 74, 
    8,  8, 0, 47, 6, 89, 3, 86, 4, 74, 2, 45, 1, 28, 5, 22, 7, 33, 
    5, 20, 2,  6, 4, 61, 6, 18, 8, 82, 7, 60, 1, 12, 0, 26, 3, 73, 
    3, 60, 6, 38, 5, 38, 1, 58, 7,  6, 0, 84, 2, 66, 4, 18, 8, 51, 
    5,  3, 2,  5, 8, 70, 3, 26, 7,  5, 0, 35, 6, 36, 4,  4, 1, 31, 
    2, 36, 8, 52, 3, 63, 0, 63, 1, 61, 5, 92, 4,  2, 6, 67, 7, 84, 
    7, 15, 4, 86, 0,  5, 8, 14, 1, 92, 2, 92, 5, 49, 3,  6, 6,  5
  };
  const int q9891[] = {
    9, 9, // Number of jobs and machines
    4, 65, 2, 56, 3, 71, 1, 82, 7, 99, 6,  1, 0, 97, 5, 20, 8, 20, 
    8, 25, 0, 38, 1, 69, 4, 52, 3, 97, 2, 96, 6, 35, 7, 45, 5, 14, 
    6, 82, 3, 93, 8, 69, 7, 63, 1, 83, 5, 80, 2, 74, 0, 66, 4, 93, 
    7, 88, 3, 47, 6, 89, 0, 30, 1,  3, 5, 12, 2, 32, 8, 17, 4, 98, 
    1, 10, 2, 48, 0, 78, 4, 29, 6, 68, 8, 96, 5, 50, 3,  4, 7, 80, 
    4, 58, 7, 90, 1, 12, 2, 73, 8, 42, 5, 61, 3, 59, 0, 51, 6,  3, 
    2, 99, 8, 65, 0, 97, 7, 65, 1,  2, 6,  4, 4, 85, 5, 64, 3, 84, 
    6, 80, 3, 35, 5, 79, 0,  9, 2, 62, 1, 11, 7, 98, 4, 21, 8, 79, 
    7, 98, 8, 91, 3, 43, 2,  6, 0, 44, 4, 23, 6, 24, 5,  5, 1, 71
  };
  const int q9892[] = {
    9, 9, // Number of jobs and machines
    1, 66, 7, 10, 8, 68, 3, 13, 5, 42, 0, 24, 2, 81, 4, 82, 6, 77, 
    8, 16, 6, 34, 0, 41, 7, 43, 4, 67, 5, 46, 3, 20, 1, 40, 2, 80, 
    3, 69, 6, 96, 7, 49, 4, 52, 0, 37, 1, 54, 8, 69, 2, 77, 5,  9, 
    7, 61, 1, 60, 6, 37, 5, 95, 2, 77, 0, 75, 3, 48, 4, 46, 8, 79, 
    3, 26, 7, 65, 4, 71, 2, 24, 0, 13, 5,  3, 8, 56, 6, 71, 1, 66, 
    8, 70, 0, 35, 5, 21, 3, 11, 4, 14, 2, 36, 1, 48, 6,  4, 7, 48, 
    4, 67, 7, 94, 3, 16, 1, 18, 5, 98, 6, 64, 0, 90, 2, 84, 8, 42, 
    0, 50, 7, 10, 6, 72, 2, 45, 5, 84, 3, 34, 1,  2, 8, 90, 4, 18, 
    1, 74, 3, 72, 5,  6, 0, 84, 6, 65, 4, 96, 8,  4, 2, 74, 7,  4
  };
  const int q9893[] = {
    9, 9, // Number of jobs and machines
    6,  3, 8, 97, 5, 68, 0, 47, 4, 47, 3, 29, 2, 46, 7, 65, 1, 99, 
    3, 40, 6, 69, 8, 43, 7, 67, 4, 20, 1, 78, 5, 68, 0, 95, 2, 64, 
    2, 74, 3, 75, 5, 35, 7, 71, 8,  1, 1, 65, 6, 80, 4, 57, 0, 13, 
    3, 70, 8, 46, 6, 66, 4,  4, 1, 60, 5, 35, 2, 22, 7,  6, 0, 85, 
    5, 80, 8, 36, 7, 84, 0, 55, 3, 81, 4, 77, 2, 15, 6, 81, 1, 39, 
    5, 94, 6, 58, 0, 59, 4, 17, 3, 19, 8,  8, 2, 88, 7, 45, 1, 31, 
    0,  6, 2, 85, 7, 53, 3, 54, 4, 72, 1, 47, 5, 99, 8, 63, 6, 49, 
    7, 41, 4, 35, 8, 67, 3, 33, 6, 93, 0,  3, 1, 88, 2, 47, 5, 76, 
    2, 41, 5, 23, 6, 31, 8, 43, 4, 41, 7, 66, 0, 30, 3, 59, 1,  4
  };
  const int q9894[] = {
    9, 9, // Number of jobs and machines
    5, 80, 1, 92, 0, 67, 2, 69, 8, 43, 4, 77, 7, 10, 6, 66, 3, 46, 
    3, 36, 4, 85, 2, 20, 7, 24, 8, 49, 5, 29, 0, 47, 6, 15, 1, 83, 
    6, 44, 5, 11, 2,  6, 4, 34, 3, 63, 1, 84, 7, 96, 0, 68, 8, 42, 
    4, 44, 6, 10, 1, 14, 3, 25, 7, 49, 8, 76, 5,  4, 0, 89, 2, 61, 
    8, 67, 6,  9, 7, 80, 2, 61, 0, 83, 5, 18, 1, 24, 4, 90, 3,  6, 
    2, 58, 6, 10, 0, 55, 3, 73, 7, 71, 4, 78, 8, 11, 5, 81, 1,  1, 
    3, 11, 8, 37, 6, 74, 2, 80, 7, 43, 0, 94, 1, 55, 4, 60, 5, 71, 
    0, 81, 3, 83, 2, 27, 1,  4, 6,  7, 8, 84, 5, 59, 4, 32, 7, 42, 
    4, 13, 7, 59, 5, 46, 2, 68, 0, 33, 1, 94, 6, 34, 3, 68, 8, 78
  };
  const int q9895[] = {
    9, 9, // Number of jobs and machines
    5,  1, 4, 46, 6, 52, 0, 73, 7,  8, 3, 16, 2, 90, 1, 50, 8, 34, 
    0, 30, 6, 93, 4, 15, 3, 49, 5,  1, 7, 13, 1, 90, 2,  9, 8, 25, 
    6, 99, 3, 24, 5, 27, 2, 73, 4, 17, 7, 43, 0, 42, 8, 23, 1,  6, 
    1, 17, 2, 37, 8, 70, 0, 93, 3, 83, 5, 45, 7, 76, 4, 29, 6, 83, 
    7,  7, 4, 68, 0, 13, 2,  6, 1, 92, 6, 50, 5, 65, 8,  9, 3, 19, 
    5, 57, 7, 79, 4, 43, 3, 91, 6, 72, 8, 36, 2, 71, 0, 60, 1, 29, 
    1, 36, 5, 19, 6, 41, 7, 84, 8, 39, 4, 60, 0, 61, 2, 25, 3, 85, 
    2, 24, 5, 61, 8, 27, 7, 45, 0, 87, 4, 89, 6, 27, 3, 17, 1, 31, 
    1, 67, 3, 88, 0, 10, 2, 16, 8, 66, 4,  8, 7, 48, 6, 91, 5, 26
  };
  const int q9896[] = {
    9, 9, // Number of jobs and machines
    8, 53, 3,  6, 7,  8, 6, 99, 5, 54, 1, 88, 0, 15, 4, 93, 2, 99, 
    7, 80, 3, 97, 4, 35, 5, 32, 1, 16, 2, 84, 8,  3, 6, 25, 0, 80, 
    1, 94, 0, 80, 3, 80, 6, 26, 2, 93, 4, 99, 8, 39, 7, 86, 5, 11, 
    0,  3, 3, 51, 7,  1, 6, 98, 1, 41, 2, 35, 4, 58, 8, 28, 5, 23, 
    6,  7, 7, 71, 8, 24, 4, 11, 2, 84, 5, 98, 1, 10, 0, 29, 3, 77, 
    4, 54, 1, 39, 7,  2, 5,  6, 8, 29, 2, 60, 6, 75, 0, 85, 3, 82, 
    5, 68, 6, 57, 3,  5, 0, 94, 7, 39, 2, 23, 8, 64, 4, 49, 1,  8, 
    0, 40, 3,  1, 4, 56, 1, 32, 6, 73, 5, 65, 2, 29, 7, 77, 8, 23, 
    4, 95, 8, 99, 2, 97, 7, 14, 6, 71, 0, 53, 5, 91, 1, 82, 3, 53
  };
  const int q9897[] = {
    9, 9, // Number of jobs and machines
    0, 48, 8, 97, 5, 99, 1, 39, 2, 84, 4, 16, 6, 14, 3, 79, 7, 90, 
    6,  3, 7, 64, 5, 53, 2, 23, 8, 19, 1, 43, 0, 97, 4,  8, 3, 48, 
    5, 64, 2, 90, 3, 50, 6, 42, 8, 80, 0, 80, 4, 19, 1, 17, 7, 20, 
    0, 10, 8,  6, 6, 71, 2, 14, 4, 89, 3, 59, 1, 86, 7,  6, 5, 66, 
    6, 73, 3, 16, 2, 59, 5,  4, 0, 37, 8, 49, 7, 27, 4, 26, 1, 76, 
    6, 24, 5, 85, 4, 80, 8, 87, 3, 39, 7, 23, 2,  5, 1, 42, 0, 56, 
    7, 13, 2, 24, 6, 42, 0, 94, 3, 15, 8, 95, 4, 98, 1, 72, 5, 45, 
    8, 99, 2, 50, 7, 34, 5,  1, 4, 21, 6, 20, 1, 87, 0,  4, 3, 41, 
    7, 87, 1, 80, 2, 51, 3, 69, 4, 95, 5, 55, 8, 86, 6, 85, 0, 71
  };
  const int q9898[] = {
    9, 9, // Number of jobs and machines
    0, 60, 3, 19, 4, 10, 8, 21, 5, 83, 2, 48, 7, 34, 1, 13, 6, 52, 
    4, 73, 6, 45, 8, 84, 0, 23, 2, 76, 3, 50, 5, 18, 7, 27, 1, 49, 
    6, 54, 4, 14, 0, 95, 2, 13, 3, 11, 1, 73, 5, 78, 7, 12, 8, 50, 
    3, 99, 5, 54, 1, 84, 6, 15, 4, 15, 8, 79, 7, 32, 2, 50, 0, 85, 
    8,  6, 6, 78, 1, 60, 0, 70, 4, 21, 5, 99, 7,  4, 2, 60, 3, 89, 
    3, 74, 6, 25, 0, 25, 7, 85, 1, 75, 4,  7, 2, 55, 8, 93, 5,  5, 
    1, 70, 2, 96, 0, 13, 7, 57, 4, 12, 8, 17, 3, 35, 6, 25, 5,  4, 
    0, 27, 4, 61, 8, 96, 6, 56, 3,  5, 5, 24, 7, 80, 1, 63, 2, 65, 
    3, 66, 0, 60, 5, 84, 6, 67, 8, 87, 2, 51, 4, 16, 1, 22, 7, 65
  };
  const int q9899[] = {
    9, 9, // Number of jobs and machines
    1,  5, 2, 36, 5, 11, 4, 74, 7, 76, 6, 95, 8, 98, 0, 39, 3, 50, 
    5, 26, 8, 97, 6, 43, 3, 27, 7, 55, 4, 49, 2, 70, 0, 87, 1, 60, 
    7,  1, 8, 52, 5, 76, 2, 91, 1, 86, 3, 46, 4, 86, 6, 57, 0, 12, 
    1, 59, 3, 52, 7, 52, 2, 81, 8, 28, 0, 92, 5, 70, 6, 62, 4, 57, 
    8, 56, 6, 21, 7, 33, 3, 22, 4, 52, 1, 19, 2, 89, 0,  9, 5, 90, 
    1, 62, 5, 16, 8, 64, 0, 21, 6, 21, 2, 62, 4, 46, 3, 55, 7,  7, 
    2, 97, 6, 73, 4, 57, 8, 30, 1, 92, 3, 27, 7, 94, 5, 19, 0, 98, 
    0, 38, 3, 50, 5,  4, 2, 95, 1, 57, 7, 53, 4, 97, 8, 90, 6, 67, 
    4, 41, 7, 33, 0, 81, 8, 70, 5, 80, 6, 42, 2,  2, 3, 58, 1, 91
  };
  const int q9900[] = {
    9, 9, // Number of jobs and machines
    1, 48, 6, 78, 4, 15, 2, 93, 7, 71, 3, 64, 0, 84, 5, 86, 8, 59, 
    5, 39, 1, 85, 0, 66, 3, 53, 4,  3, 7,  4, 8, 19, 6, 27, 2, 23, 
    6, 88, 7, 24, 4, 31, 8, 68, 3, 23, 1, 94, 5, 80, 2, 75, 0, 84, 
    4, 97, 0, 41, 5, 63, 7,  2, 1, 95, 6, 20, 3, 33, 8, 40, 2, 85, 
    0, 73, 1, 26, 7, 77, 6, 96, 4, 15, 3,  6, 2, 43, 8, 10, 5, 30, 
    3,  4, 8, 80, 4, 19, 2, 69, 5, 35, 7, 74, 6, 37, 1, 39, 0, 29, 
    6, 17, 3, 54, 2, 20, 1, 83, 4, 99, 5, 24, 0, 82, 8, 26, 7, 66, 
    3, 82, 1, 83, 8, 98, 5, 73, 0, 98, 6,  2, 4, 34, 2, 75, 7, 35, 
    7, 53, 1, 87, 3, 49, 5, 13, 8, 53, 4,  2, 6, 75, 2, 93, 0, 51
  };
  const int q9901[] = {
    9, 9, // Number of jobs and machines
    8, 37, 4,  7, 3, 26, 7, 74, 1, 73, 2, 93, 5, 50, 6, 74, 0, 94, 
    2, 51, 1, 82, 6, 38, 4, 84, 8, 99, 7, 52, 3, 43, 0, 42, 5, 48, 
    4, 46, 1, 31, 6, 10, 0, 54, 2, 98, 3, 87, 8, 29, 7, 76, 5, 69, 
    2, 93, 4, 50, 7, 97, 3, 77, 5, 10, 0, 73, 1, 36, 6, 63, 8, 13, 
    2, 46, 6, 34, 4, 91, 7, 88, 8, 88, 5, 37, 1, 50, 0, 55, 3, 43, 
    3,  2, 7, 64, 4, 86, 5, 91, 8, 87, 6,  3, 0, 33, 1, 77, 2,  8, 
    8, 69, 6, 84, 1, 19, 2, 66, 3, 55, 0, 17, 4, 91, 7, 84, 5, 50, 
    1, 23, 4, 11, 2, 51, 7, 69, 3, 23, 5, 34, 0, 40, 8, 93, 6, 75, 
    8, 46, 3, 34, 0, 99, 4, 74, 2, 97, 6,  1, 5, 47, 7, 46, 1, 38
  };
  const int q9902[] = {
    9, 9, // Number of jobs and machines
    6, 35, 8, 22, 4, 75, 1, 15, 5, 59, 0, 62, 3, 64, 7, 27, 2, 78, 
    8, 33, 4, 25, 6, 15, 3,  1, 2, 60, 0,  7, 7, 24, 5, 25, 1, 95, 
    6, 31, 7,  1, 4, 94, 0, 36, 1,  9, 5, 10, 3, 89, 8, 24, 2, 16, 
    5, 74, 6, 34, 7, 49, 0, 34, 1,  6, 8, 91, 4, 70, 3, 31, 2, 67, 
    6, 65, 2, 39, 8, 80, 5, 61, 1, 87, 0, 61, 7, 42, 3, 61, 4, 32, 
    2, 94, 5, 76, 0, 45, 8, 95, 6, 31, 3, 23, 1,  7, 7, 12, 4, 66, 
    0, 48, 5, 17, 2, 93, 8, 86, 3, 92, 7,  1, 6, 30, 1, 20, 4,  5, 
    2, 23, 6, 11, 5, 14, 7, 76, 3, 12, 8, 53, 1, 23, 4, 96, 0, 80, 
    8, 15, 4, 64, 7, 80, 5, 12, 0, 38, 3, 42, 2, 20, 6, 21, 1, 17
  };
  const int q9903[] = {
    9, 9, // Number of jobs and machines
    1, 28, 3, 28, 0, 25, 7, 97, 5, 26, 8, 45, 4, 22, 2, 79, 6, 16, 
    0,  9, 3, 88, 6, 72, 5, 13, 8, 84, 2, 40, 4, 57, 1, 82, 7, 70, 
    8,  2, 3, 24, 2, 37, 6, 91, 7, 25, 4, 33, 5, 59, 1, 40, 0, 47, 
    7, 75, 0, 41, 4, 55, 3, 92, 5, 88, 2, 43, 1, 37, 8, 33, 6, 91, 
    1, 50, 6, 94, 0, 56, 3, 30, 4, 88, 8, 14, 2, 84, 5, 84, 7, 28, 
    3, 12, 4, 37, 7, 97, 0, 75, 6,  3, 2, 99, 8, 64, 5, 68, 1, 97, 
    1, 83, 5, 24, 0, 88, 4, 78, 8, 18, 6, 69, 2, 84, 3, 42, 7, 17, 
    2, 43, 8,  6, 5, 54, 0, 62, 1, 61, 3, 83, 4,  5, 6, 72, 7, 61, 
    3,  3, 7, 70, 2, 54, 5, 70, 6, 31, 1, 86, 8, 19, 0, 39, 4, 67
  };
  const int q9904[] = {
    9, 9, // Number of jobs and machines
    8,  4, 4, 10, 1, 81, 6, 22, 2, 21, 5,  5, 7, 74, 3, 79, 0,  6, 
    6, 56, 1, 54, 3, 54, 0, 16, 5, 10, 4, 22, 8, 25, 2, 49, 7, 80, 
    3, 68, 2, 66, 7, 85, 1, 91, 0, 81, 6, 13, 5, 11, 4, 76, 8, 36, 
    2, 33, 0,  9, 3, 67, 5, 87, 6, 41, 8, 14, 1, 72, 4, 50, 7, 85, 
    6, 96, 2, 47, 4, 13, 1, 52, 5, 23, 0, 40, 3, 38, 7, 34, 8, 38, 
    4, 96, 7,  8, 5, 49, 1, 98, 0, 97, 6, 51, 8,  8, 3, 33, 2, 32, 
    0, 72, 2, 62, 6, 17, 1, 50, 8, 54, 5, 61, 4, 14, 3, 58, 7, 17, 
    2, 66, 7, 74, 0, 61, 5, 24, 8, 97, 6, 38, 4, 53, 1, 43, 3, 41, 
    0, 29, 6,  7, 1, 50, 8, 50, 2, 40, 4, 87, 3,  9, 7, 34, 5, 84
  };
  const int q9905[] = {
    9, 9, // Number of jobs and machines
    0, 46, 3, 86, 7, 66, 5, 73, 2, 59, 6, 60, 8, 46, 4,  6, 1, 72, 
    0, 14, 6, 14, 1, 33, 2, 26, 3, 85, 7, 78, 4, 32, 8, 92, 5, 34, 
    4, 79, 3, 72, 5, 34, 6, 35, 8,  9, 0,  1, 7, 90, 1, 20, 2, 92, 
    7, 20, 8,  9, 0, 66, 1, 17, 5, 28, 2, 43, 3, 31, 6, 83, 4, 95, 
    6, 90, 5, 83, 4, 56, 1, 61, 0, 56, 8, 90, 7, 69, 2, 78, 3, 97, 
    1, 61, 7, 44, 3, 77, 0, 38, 4, 23, 6, 41, 5, 43, 2, 16, 8, 21, 
    4, 33, 2, 57, 8, 68, 5, 95, 3, 78, 6, 64, 0, 78, 7, 70, 1,  6, 
    3, 64, 2, 16, 7, 59, 4, 75, 0, 57, 8, 55, 6, 77, 5, 83, 1, 75, 
    3, 17, 1, 72, 6, 93, 5,  2, 7, 73, 4,  5, 0, 54, 2, 58, 8, 98
  };
  const int q9906[] = {
    9, 9, // Number of jobs and machines
    2, 57, 8,  8, 7, 97, 0, 60, 1,  2, 3, 35, 5, 50, 6, 91, 4, 23, 
    3, 18, 6, 97, 7, 52, 5, 91, 0, 78, 1, 52, 4,  2, 2, 87, 8, 70, 
    3,  7, 2, 92, 7, 36, 8, 99, 4, 78, 6, 27, 0, 13, 5,  3, 1, 31, 
    0,  4, 1, 81, 6, 48, 3, 36, 7, 73, 5,  7, 4, 42, 8, 61, 2, 53, 
    8, 35, 1,  1, 3, 26, 6, 18, 2, 54, 4, 64, 0, 86, 5, 24, 7, 18, 
    3, 49, 5, 57, 8, 15, 1, 71, 4, 23, 7, 71, 2, 66, 0, 18, 6,  5, 
    3,  2, 2, 88, 1, 24, 8, 21, 7, 38, 0, 90, 5, 20, 4, 98, 6, 91, 
    0, 11, 4, 30, 7, 73, 6, 69, 2,  1, 5, 58, 3, 99, 1, 25, 8, 36, 
    8, 98, 0, 40, 7, 63, 1, 82, 6, 43, 3, 60, 5, 29, 2, 28, 4, 75
  };
  const int q9907[] = {
    9, 9, // Number of jobs and machines
    1, 80, 5, 47, 7, 59, 0, 46, 8,  2, 4, 83, 2, 41, 3, 37, 6, 66, 
    0, 81, 6, 95, 2,  4, 7, 34, 5, 53, 1, 37, 8, 98, 3,  8, 4, 22, 
    5, 41, 8, 69, 6, 79, 7, 39, 2, 37, 0, 64, 3, 35, 1, 93, 4, 83, 
    5, 32, 7,  3, 6, 13, 2, 27, 8, 66, 4, 25, 1, 96, 0, 74, 3, 15, 
    5, 26, 0, 84, 7, 12, 2, 46, 6, 53, 8, 59, 1, 57, 4, 85, 3, 85, 
    2, 95, 6, 19, 3, 48, 5, 39, 7, 90, 1, 41, 8, 79, 4, 66, 0, 33, 
    8, 94, 2, 64, 7, 58, 5, 89, 0, 14, 1, 54, 3, 50, 6,  9, 4, 18, 
    5, 67, 3, 55, 1, 96, 2, 71, 4, 46, 6, 22, 8, 36, 0, 78, 7, 57, 
    4, 16, 1, 59, 5, 24, 2, 63, 3, 82, 8, 95, 7, 51, 0, 52, 6, 98
  };
  const int q9908[] = {
    9, 9, // Number of jobs and machines
    8, 72, 2,  4, 4, 50, 1, 78, 7, 25, 6, 37, 0,  9, 5, 49, 3, 63, 
    5, 79, 4, 82, 8, 53, 2, 66, 3, 90, 7, 50, 0, 18, 6, 53, 1, 94, 
    4, 17, 5, 35, 6, 33, 2, 60, 7,  4, 0, 71, 1, 43, 8, 62, 3, 33, 
    3, 23, 8, 20, 4, 72, 0, 74, 1, 82, 2, 16, 5, 52, 7, 10, 6, 73, 
    0, 87, 4, 88, 7, 49, 2, 10, 5, 42, 8, 13, 3, 58, 1,  9, 6, 59, 
    7,  8, 2, 84, 8, 98, 6, 85, 5, 59, 0, 26, 1,  9, 4,  3, 3, 69, 
    8, 81, 2, 61, 4, 82, 6,  5, 3, 78, 7, 75, 5, 58, 0, 47, 1, 76, 
    3,  4, 4, 47, 7, 99, 1, 83, 0, 14, 8, 43, 2, 73, 6, 20, 5, 81, 
    4,  6, 7, 74, 5, 72, 0, 85, 2, 77, 6, 84, 8, 13, 3, 12, 1, 89
  };
  const int q9909[] = {
    9, 9, // Number of jobs and machines
    4, 43, 0, 51, 2, 87, 6, 30, 3, 95, 5, 78, 1, 84, 8, 21, 7, 99, 
    0, 80, 8, 54, 7, 37, 6, 22, 1, 11, 2, 14, 3, 34, 4, 61, 5, 96, 
    2, 34, 5, 96, 8,  1, 1, 94, 0, 42, 6, 99, 4, 86, 7, 33, 3,  1, 
    0, 94, 5, 32, 3, 29, 6, 71, 7, 55, 4, 89, 2, 98, 8, 58, 1, 19, 
    3, 41, 5, 10, 6, 44, 1, 41, 4, 27, 7, 24, 0,  6, 2, 25, 8, 34, 
    8, 36, 6, 98, 2, 58, 3, 35, 1, 88, 0, 95, 4, 42, 5, 77, 7, 89, 
    1, 73, 2, 24, 7, 22, 6, 55, 3, 55, 0, 83, 8, 79, 4, 53, 5, 34, 
    6, 42, 5, 13, 0, 29, 2, 54, 7, 65, 8, 86, 1, 61, 4, 94, 3, 43, 
    5, 88, 2, 15, 6, 35, 4, 27, 0, 15, 7, 39, 3, 49, 8,  5, 1, 71
  };
  const int q9910[] = {
    9, 9, // Number of jobs and machines
    6, 19, 1,  2, 4,  6, 3, 50, 7, 79, 0, 65, 8, 36, 5, 77, 2, 74, 
    5, 24, 7, 47, 3, 28, 6, 87, 0, 60, 4, 66, 8, 37, 1, 26, 2, 44, 
    0, 84, 7, 84, 2, 84, 8, 55, 5, 60, 4, 10, 3, 91, 6, 22, 1, 51, 
    4, 88, 2, 50, 6, 50, 1, 79, 8, 44, 5, 92, 7, 66, 0, 53, 3, 23, 
    1, 21, 7, 46, 0, 54, 3,  7, 6, 66, 8, 38, 5, 54, 2, 12, 4, 81, 
    0, 19, 2, 16, 1, 39, 6, 42, 8, 23, 5, 82, 4, 53, 7, 15, 3, 69, 
    6, 76, 5, 74, 3, 25, 7, 93, 0, 78, 2, 84, 1,  7, 8, 36, 4, 58, 
    6,  7, 4, 72, 1,  9, 8, 14, 3, 34, 5, 27, 2, 54, 7, 44, 0, 81, 
    4, 58, 2, 75, 5, 26, 3, 67, 6, 49, 0, 43, 1, 89, 7, 38, 8, 34
  };
  const int q9911[] = {
    9, 9, // Number of jobs and machines
    0, 99, 1, 52, 8, 80, 3,  5, 2, 95, 6, 93, 4, 62, 7, 88, 5, 95, 
    6, 38, 8, 14, 3, 93, 5, 26, 1, 24, 2, 50, 0, 62, 7, 42, 4, 84, 
    4, 27, 1, 95, 8, 60, 0, 26, 2, 85, 3, 94, 6, 36, 7, 99, 5, 18, 
    2, 55, 4, 83, 3,  3, 1, 45, 5, 54, 7, 35, 6,  5, 8, 21, 0, 57, 
    7, 38, 0, 69, 2, 81, 3, 14, 5, 23, 6, 41, 4, 46, 8, 60, 1, 63, 
    8, 81, 3, 85, 0, 74, 1, 24, 5, 50, 2, 81, 4, 11, 6, 68, 7, 34, 
    4, 44, 6, 36, 0, 13, 7, 33, 3, 42, 8, 42, 5, 78, 2, 61, 1, 86, 
    8, 83, 5, 14, 3, 19, 2,  4, 7, 50, 6, 28, 0, 35, 1, 56, 4, 58, 
    2, 12, 0, 95, 7, 60, 4, 61, 6, 67, 8, 48, 1, 70, 3, 38, 5, 76
  };
  const int q9912[] = {
    9, 9, // Number of jobs and machines
    4,  8, 8, 80, 1, 87, 7, 76, 6, 37, 0, 83, 2, 23, 5, 45, 3, 15, 
    2, 60, 4, 90, 5, 32, 1, 22, 0, 91, 6,  4, 8,  9, 7, 53, 3, 23, 
    5, 84, 1, 59, 2, 87, 8, 84, 3,  6, 0, 84, 4, 86, 7, 78, 6, 33, 
    7, 25, 4, 66, 8, 58, 0, 62, 1,  7, 2, 14, 5, 32, 3, 21, 6, 74, 
    5, 20, 2,  6, 1, 93, 8, 89, 0, 21, 7, 93, 4, 36, 6, 51, 3, 42, 
    5,  1, 7, 18, 0, 63, 8, 94, 1, 27, 6,  7, 2, 92, 4, 50, 3, 61, 
    1, 91, 2, 30, 7, 69, 5, 44, 0, 95, 4, 78, 6, 41, 8, 64, 3, 21, 
    8,  8, 0, 82, 1, 89, 6, 37, 7, 45, 4, 86, 2, 75, 3, 48, 5, 29, 
    6, 74, 0, 75, 5, 25, 2, 31, 3, 99, 8, 79, 4, 53, 1, 35, 7, 48
  };
  const int q9913[] = {
    9, 9, // Number of jobs and machines
    5, 90, 4, 99, 1, 58, 0, 93, 2, 30, 7, 49, 6, 75, 3, 63, 8, 21, 
    3, 52, 0, 73, 6, 66, 7, 42, 4, 92, 2, 72, 5, 98, 8, 10, 1, 24, 
    1, 76, 5, 26, 0, 38, 8, 81, 3, 40, 7, 78, 4,  7, 2,  6, 6, 28, 
    6, 46, 7, 48, 1, 79, 3,  7, 5, 36, 2, 83, 0, 93, 4, 52, 8, 21, 
    7, 67, 2, 79, 5, 50, 1, 75, 4, 57, 6, 84, 8, 89, 0, 21, 3,  3, 
    2, 41, 3, 39, 6, 75, 4, 62, 8, 68, 1, 77, 0, 95, 5, 74, 7, 11, 
    1, 63, 0, 23, 6, 60, 7, 56, 4, 54, 5, 70, 8, 78, 3, 20, 2, 84, 
    5, 49, 2, 25, 6, 71, 8, 33, 7,  8, 1, 64, 0, 91, 3, 62, 4, 19, 
    7, 85, 5, 58, 8, 64, 2, 89, 6, 40, 0, 22, 1, 21, 3, 78, 4, 50
  };
  const int q9914[] = {
    9, 9, // Number of jobs and machines
    4, 75, 7, 71, 2, 33, 5,  5, 0, 51, 6, 57, 8, 85, 3, 53, 1, 81, 
    6, 89, 2, 34, 7, 88, 0, 93, 8, 22, 1, 55, 4, 22, 3,  9, 5, 85, 
    4, 43, 5, 72, 0, 89, 7, 19, 3, 54, 1, 31, 8, 46, 2, 98, 6, 80, 
    6, 14, 4, 69, 7, 18, 8, 43, 2, 80, 3, 38, 1, 55, 5,  3, 0, 19, 
    4, 38, 3, 38, 0, 27, 1, 16, 6, 33, 8, 37, 7, 43, 2, 31, 5, 53, 
    0, 96, 7,  8, 5, 11, 1, 44, 3, 67, 2, 47, 8, 62, 4, 57, 6, 52, 
    4, 14, 0, 65, 8,  3, 2, 90, 5, 15, 1, 82, 3, 43, 7, 55, 6, 34, 
    0, 28, 6, 42, 5, 27, 2, 82, 4, 67, 7, 29, 8, 59, 1, 52, 3, 25, 
    4, 61, 7, 77, 8, 61, 0, 45, 1, 20, 5, 58, 2, 31, 3, 89, 6, 35
  };
  const int q9915[] = {
    9, 9, // Number of jobs and machines
    5, 95, 7, 90, 1, 21, 0, 54, 4, 38, 6, 42, 3, 96, 8,  6, 2, 89, 
    7, 78, 4, 72, 5, 24, 1, 84, 6, 89, 2, 42, 3, 61, 0, 76, 8, 23, 
    5, 92, 6,  4, 1, 75, 0, 29, 8, 27, 7, 23, 2, 71, 4, 65, 3,  8, 
    2, 33, 5, 62, 6, 82, 4, 41, 3, 23, 1, 99, 0, 36, 7, 82, 8, 95, 
    3, 21, 2, 48, 1, 88, 4, 74, 8, 81, 6, 16, 5, 32, 7, 99, 0, 40, 
    1, 23, 5, 33, 6, 63, 7, 30, 0,  7, 2, 16, 8, 67, 4, 12, 3, 15, 
    3, 62, 6, 78, 7, 23, 1, 52, 4,  8, 0, 23, 8, 66, 5, 88, 2,  2, 
    7,  1, 6, 67, 4, 57, 3,  6, 8, 31, 1, 22, 0, 83, 5, 59, 2, 86, 
    4,  1, 8, 14, 3, 92, 1, 58, 2,  7, 5, 39, 6, 67, 7, 67, 0, 41
  };
  const int q9916[] = {
    9, 9, // Number of jobs and machines
    6, 33, 8, 43, 0, 73, 7, 45, 2, 21, 1, 42, 3,  7, 5,  4, 4, 60, 
    5, 26, 8, 43, 6, 51, 1, 52, 4, 11, 3, 30, 7, 96, 0, 76, 2, 34, 
    1, 17, 4, 80, 5, 42, 0, 28, 2, 43, 8, 96, 7, 32, 3, 85, 6,  1, 
    3, 76, 7, 51, 4, 19, 2, 56, 8, 70, 1, 18, 6,  6, 5,  5, 0, 33, 
    7, 13, 3, 83, 5, 79, 4, 52, 2, 80, 8, 87, 0, 80, 6, 17, 1,  1, 
    3, 21, 8, 54, 6, 28, 4, 47, 2, 89, 5, 65, 0,  1, 7, 37, 1, 46, 
    4, 33, 3,  2, 2, 66, 1, 92, 8, 46, 0, 19, 5, 19, 6, 24, 7, 70, 
    7, 24, 4, 81, 0, 76, 2, 14, 3, 86, 1, 65, 6, 93, 5, 24, 8, 20, 
    2, 67, 3, 98, 5, 93, 4,  1, 0, 40, 7, 79, 1, 45, 6,  9, 8, 41
  };
  const int q9917[] = {
    9, 9, // Number of jobs and machines
    6, 98, 2, 69, 4, 40, 5, 68, 1, 32, 3, 64, 0, 57, 7,  9, 8, 62, 
    2, 19, 4, 69, 0, 53, 3, 14, 8,  3, 7, 16, 1, 54, 6,  4, 5, 47, 
    1, 71, 4, 14, 2,  6, 7, 49, 0, 64, 8, 94, 6,  2, 3, 96, 5, 20, 
    1, 48, 0, 59, 8, 94, 3, 70, 7, 30, 2, 41, 6, 20, 5, 98, 4,  2, 
    2, 35, 8, 26, 1, 89, 5, 46, 3, 92, 4, 72, 6, 94, 7, 22, 0, 15, 
    1, 41, 8, 81, 2, 18, 3, 47, 4,  4, 5, 10, 7, 24, 0, 35, 6, 71, 
    7, 45, 3, 92, 6, 68, 2,  4, 8, 10, 0, 84, 1,  4, 5, 55, 4, 18, 
    5, 13, 6, 39, 3, 64, 7, 50, 2, 50, 0,  7, 8, 80, 1, 35, 4,  5, 
    3, 87, 1, 91, 0, 38, 2,  1, 5, 96, 4, 60, 7,  2, 6, 93, 8, 95
  };
  const int q9918[] = {
    9, 9, // Number of jobs and machines
    6, 18, 4, 85, 8, 90, 0, 88, 3, 31, 7, 93, 2, 39, 1, 80, 5,  9, 
    3, 99, 8, 79, 2,  7, 6, 87, 7, 54, 5, 30, 4, 65, 0, 22, 1, 97, 
    1, 96, 5, 94, 8, 97, 6, 37, 7, 70, 0, 68, 4, 62, 2, 51, 3, 47, 
    5, 27, 0, 61, 2, 22, 3, 79, 4, 53, 1, 91, 8, 72, 6, 57, 7, 40, 
    7, 27, 2, 24, 3, 92, 5, 72, 8, 74, 4, 35, 6, 82, 1, 40, 0, 92, 
    5, 14, 8,  6, 7, 68, 2, 33, 4, 51, 3, 74, 6, 74, 0, 39, 1, 58, 
    2, 72, 3, 13, 4,  7, 0, 12, 7, 47, 8,  4, 1, 71, 5, 87, 6, 60, 
    8, 66, 5,  2, 0, 42, 3, 45, 2, 24, 7, 71, 6, 28, 4, 94, 1, 71, 
    2,  4, 5, 53, 6, 14, 8, 80, 0, 44, 7, 41, 4, 43, 3, 70, 1, 59
  };
  const int q9919[] = {
    9, 9, // Number of jobs and machines
    8, 67, 7, 91, 3, 64, 0, 15, 5, 19, 1, 55, 4, 78, 2, 89, 6,  6, 
    2, 77, 6, 40, 1, 79, 7, 66, 3, 60, 8, 24, 4, 17, 0, 75, 5, 11, 
    2,  1, 6, 66, 0, 26, 4, 14, 8, 99, 1, 69, 3,  5, 7, 38, 5, 81, 
    2, 25, 8, 49, 6, 98, 0, 66, 1, 25, 5,  4, 4, 48, 7, 58, 3, 16, 
    7, 87, 8, 63, 2, 28, 3, 99, 6, 58, 1, 16, 4, 47, 5, 31, 0, 84, 
    3, 53, 0, 72, 2, 31, 7, 57, 6, 95, 1, 96, 5, 78, 8, 10, 4, 10, 
    0, 45, 5, 63, 3, 14, 1, 34, 7, 49, 6, 76, 4,  8, 2,  4, 8, 23, 
    3, 69, 1, 75, 7, 18, 2, 78, 8, 61, 6, 81, 0, 90, 4, 26, 5, 98, 
    7, 22, 1, 97, 0,  5, 3, 48, 6, 36, 4, 53, 2,  9, 8, 75, 5, 46
  };
  const int q9920[] = {
    9, 9, // Number of jobs and machines
    5, 57, 0,  8, 6, 28, 7, 57, 3, 19, 1, 84, 2,  8, 4, 57, 8, 59, 
    2, 67, 5, 62, 0, 59, 6, 16, 7, 42, 1, 55, 4,  2, 8, 67, 3, 88, 
    4, 54, 8, 37, 5, 50, 2, 95, 0, 47, 6, 62, 1, 96, 7, 81, 3, 12, 
    0, 51, 5, 75, 1, 70, 2, 80, 6, 54, 4, 77, 8, 39, 7, 51, 3,  9, 
    0, 12, 7, 45, 1, 85, 6, 65, 3, 10, 8, 94, 2, 31, 5, 51, 4, 33, 
    2, 35, 1, 49, 3, 96, 5, 35, 0, 16, 7,  4, 4, 95, 8, 76, 6, 53, 
    8,  6, 1, 39, 4, 73, 3, 17, 0, 33, 2, 16, 7, 98, 6, 48, 5,  7, 
    5, 64, 1, 53, 7, 64, 0, 11, 2, 15, 6,  2, 4, 87, 3, 81, 8, 51, 
    7, 78, 6, 69, 0, 80, 4,  1, 5, 43, 2, 18, 3, 36, 1, 80, 8, 91
  };
  const int q9921[] = {
    9, 9, // Number of jobs and machines
    3, 67, 0, 47, 7, 97, 6, 59, 4, 48, 8, 85, 5, 98, 2, 61, 1, 18, 
    0,  6, 4, 73, 1, 74, 3, 31, 8, 37, 2, 24, 7, 34, 5, 64, 6, 52, 
    3, 50, 6, 35, 4, 37, 8, 71, 7, 24, 5, 29, 0, 27, 1, 80, 2, 19, 
    4, 38, 3, 15, 1, 95, 0,  5, 8, 95, 5, 18, 2, 47, 7, 50, 6, 54, 
    7, 25, 4,  4, 6, 76, 3, 39, 5, 53, 2, 94, 8, 40, 1, 53, 0, 44, 
    2, 52, 8, 67, 5, 71, 4, 70, 7, 68, 0, 48, 6, 68, 1, 40, 3, 86, 
    3,  4, 1, 56, 0, 19, 6, 52, 5, 37, 7, 48, 4, 58, 2, 82, 8,  5, 
    6, 28, 7, 49, 1, 24, 5, 39, 8, 70, 4, 27, 2, 39, 3, 52, 0, 83, 
    1, 53, 5, 55, 7, 63, 2, 88, 3, 55, 0, 72, 8, 40, 6, 95, 4, 64
  };
  const int q9922[] = {
    9, 9, // Number of jobs and machines
    8, 58, 3, 72, 7, 65, 6, 77, 1, 15, 5, 16, 2, 31, 0, 96, 4, 47, 
    5, 53, 0, 66, 2, 62, 7, 25, 8, 83, 4, 84, 1, 60, 3, 55, 6, 62, 
    7, 97, 6, 14, 2, 45, 8, 98, 5, 13, 0,  4, 3, 77, 4, 35, 1, 42, 
    5, 82, 6, 75, 2, 69, 0, 74, 8,  5, 1, 51, 3,  6, 4, 46, 7, 46, 
    1, 29, 7, 48, 2, 66, 0, 27, 5, 44, 3, 97, 4, 13, 6, 92, 8, 96, 
    5, 56, 2,  6, 1, 56, 0, 40, 8, 18, 3, 35, 6, 82, 4, 84, 7, 67, 
    2, 43, 6, 16, 3, 91, 8, 71, 5, 86, 0, 82, 7,  8, 1, 86, 4, 72, 
    2, 68, 7, 21, 3, 57, 4, 66, 0, 70, 6, 42, 1, 31, 5, 84, 8, 12, 
    3, 54, 6, 51, 4, 29, 0, 17, 5, 50, 7, 68, 2,  2, 1,  5, 8, 97
  };
  const int q9923[] = {
    9, 9, // Number of jobs and machines
    5, 66, 3, 26, 8, 78, 6, 61, 7, 63, 4, 83, 1, 25, 2, 93, 0, 13, 
    5, 76, 7, 92, 3, 46, 8, 59, 4, 26, 6, 31, 1, 46, 0, 40, 2,  4, 
    6, 96, 0, 13, 2, 22, 3, 41, 1, 71, 7, 46, 8, 15, 4, 76, 5, 70, 
    1, 15, 4, 85, 8, 51, 6, 99, 0, 26, 5, 14, 2, 22, 3, 92, 7, 50, 
    3, 25, 5, 21, 0,  3, 4, 93, 1, 73, 2, 38, 6, 52, 8, 40, 7, 16, 
    4, 69, 5, 50, 6, 54, 1, 43, 8, 25, 0, 56, 2, 49, 7, 21, 3, 66, 
    7, 46, 4, 94, 2, 10, 8,  5, 0, 10, 5, 72, 1, 97, 3, 52, 6,  5, 
    5, 67, 4, 95, 3, 77, 1, 50, 7, 19, 8, 37, 2, 58, 0, 30, 6,  5, 
    0,  9, 6, 97, 4, 60, 8, 53, 2, 32, 3, 88, 5, 81, 1, 52, 7,  6
  };
  const int q9924[] = {
    9, 9, // Number of jobs and machines
    0, 67, 8, 54, 5, 75, 3,  3, 6, 89, 2, 96, 1, 31, 7, 26, 4, 37, 
    7, 87, 4, 22, 0, 50, 5,  5, 3, 30, 8, 74, 2, 43, 1, 58, 6, 80, 
    8, 52, 5, 15, 1, 96, 3, 50, 6, 82, 2, 69, 7, 51, 4, 99, 0, 79, 
    5, 40, 0, 52, 6, 91, 2, 27, 8, 18, 4, 23, 3, 94, 7, 37, 1, 29, 
    5, 46, 1, 90, 3, 57, 8, 26, 7, 32, 0, 14, 6, 40, 2, 39, 4, 90, 
    3, 36, 0, 46, 1, 19, 5, 93, 8, 89, 6,  6, 7, 91, 4, 67, 2, 39, 
    5,  4, 1, 92, 6, 55, 3, 42, 7, 71, 0, 68, 2, 13, 8, 91, 4, 90, 
    3, 18, 6, 77, 1, 74, 7,  6, 5, 33, 0, 42, 8, 74, 2, 87, 4, 48, 
    7,  3, 1, 22, 6, 71, 5, 36, 0, 29, 4, 91, 3, 10, 8, 60, 2, 98
  };
  const int q9925[] = {
    9, 9, // Number of jobs and machines
    0, 10, 4, 27, 3, 46, 1, 98, 7, 82, 5, 41, 6,  3, 8, 13, 2,  3, 
    3, 16, 6, 82, 7, 52, 5, 90, 0, 33, 8, 42, 1, 93, 2, 94, 4, 98, 
    4,  1, 3, 90, 0, 51, 1, 24, 7, 89, 2, 12, 6, 40, 5, 40, 8, 13, 
    3, 52, 5, 10, 2, 58, 4, 54, 0, 61, 7, 47, 1, 29, 6, 37, 8, 34, 
    5, 24, 2, 59, 7, 93, 1, 49, 6, 46, 8, 45, 3, 75, 0, 52, 4, 40, 
    2, 23, 5, 52, 6, 64, 8, 98, 0, 58, 4, 56, 7, 28, 1, 74, 3, 38, 
    8, 89, 5, 32, 2, 64, 1, 42, 6, 40, 0, 45, 4, 96, 7, 66, 3,  6, 
    1, 84, 0, 26, 8, 44, 5, 70, 7, 90, 6, 30, 4,  7, 2, 67, 3, 48, 
    8, 37, 4, 38, 3, 50, 6, 65, 2, 34, 1, 65, 0, 41, 5, 50, 7, 93
  };
  const int q9926[] = {
    9, 9, // Number of jobs and machines
    7, 41, 6, 91, 8, 55, 3, 70, 1, 96, 0, 69, 4, 55, 5,  2, 2,  3, 
    1, 26, 7, 31, 8, 26, 3, 90, 2, 62, 0, 77, 6, 74, 4, 13, 5, 15, 
    4, 66, 5, 28, 1, 82, 2, 37, 8, 80, 7, 56, 6, 16, 3, 58, 0, 96, 
    4, 91, 2, 22, 7,  7, 3, 58, 8, 20, 5, 82, 1, 10, 6, 91, 0, 23, 
    5, 99, 0, 58, 4, 65, 6, 70, 1, 48, 3, 12, 7, 52, 2, 55, 8, 11, 
    7, 71, 6, 83, 2, 46, 3, 89, 5, 14, 1, 29, 8, 58, 4,  8, 0, 51, 
    1, 61, 6, 93, 7, 57, 3, 64, 4, 46, 2, 31, 8, 30, 5, 12, 0, 36, 
    7, 51, 5, 12, 1, 62, 2, 75, 8, 26, 4, 90, 6, 24, 3, 74, 0, 66, 
    0, 14, 8, 15, 7, 37, 6, 65, 5, 77, 2, 21, 1, 16, 3, 55, 4, 22
  };
  const int q9927[] = {
    9, 9, // Number of jobs and machines
    7, 58, 2, 29, 4,  4, 0, 76, 3, 69, 8, 94, 1, 53, 5, 23, 6, 62, 
    2, 69, 3, 14, 7, 84, 8, 16, 6, 77, 1, 45, 0, 25, 5,  1, 4,  9, 
    8, 24, 2, 46, 4, 87, 6, 35, 0, 52, 7, 40, 1, 38, 3, 33, 5, 90, 
    3, 95, 0, 49, 6, 91, 2, 78, 5, 52, 8, 61, 7, 62, 1,  7, 4, 59, 
    5, 45, 3, 62, 8,  4, 7, 45, 1, 98, 6, 67, 4, 13, 0, 52, 2,  1, 
    4, 69, 6, 26, 0, 31, 3, 37, 2, 10, 1,  5, 8, 87, 7, 36, 5, 71, 
    1, 42, 0, 48, 7, 46, 5, 46, 8, 36, 4,  4, 6, 47, 2, 30, 3, 93, 
    8, 70, 6, 13, 0,  8, 1,  1, 7, 33, 2,  6, 4, 34, 3, 98, 5, 93, 
    6, 16, 7, 45, 1, 69, 8, 16, 4, 67, 3, 52, 5, 46, 2, 52, 0, 89
  };
  const int q9928[] = {
    9, 9, // Number of jobs and machines
    8, 88, 0, 90, 7, 29, 6, 19, 1, 12, 2, 73, 3, 85, 5, 12, 4, 33, 
    3, 14, 4, 54, 0, 90, 5, 78, 6, 49, 1, 64, 2, 18, 8, 26, 7, 56, 
    6, 71, 5, 15, 4,  2, 1, 22, 8, 37, 7, 38, 3, 92, 0, 23, 2, 91, 
    2, 69, 0, 42, 5, 71, 8, 57, 7, 56, 6, 98, 3, 90, 1, 58, 4, 90, 
    0, 73, 6, 29, 1, 87, 8, 43, 2, 91, 3, 54, 5, 94, 7, 44, 4, 94, 
    1, 28, 0, 97, 7, 11, 8, 29, 6, 62, 5, 60, 4,  5, 3, 23, 2, 91, 
    3, 46, 2, 46, 0, 34, 7, 88, 6, 53, 8, 91, 4, 83, 1, 68, 5, 62, 
    6, 19, 8, 74, 0, 53, 4, 60, 7, 30, 3, 60, 5, 28, 2, 39, 1, 62, 
    0, 85, 5, 52, 7, 47, 2, 61, 4, 35, 3, 44, 8, 86, 6, 41, 1, 60
  };
  const int q9929[] = {
    9, 9, // Number of jobs and machines
    2, 30, 0, 19, 7, 29, 4, 61, 1, 68, 5, 65, 6, 47, 3,  2, 8, 88, 
    0, 80, 4, 61, 7, 96, 2, 71, 1, 35, 3, 46, 8, 96, 5, 40, 6, 34, 
    3, 26, 8, 87, 4, 29, 0,  7, 7, 46, 5, 95, 1, 49, 2,  3, 6, 83, 
    0, 92, 4, 71, 7, 93, 8, 41, 1, 20, 6,  9, 5, 34, 2, 34, 3, 22, 
    0, 63, 7, 59, 4, 29, 8, 17, 2, 33, 1, 25, 3,  8, 5, 91, 6,  3, 
    3, 20, 6, 32, 2,  3, 5, 26, 0, 51, 1, 33, 8, 83, 7, 42, 4, 26, 
    2, 32, 1, 20, 6, 23, 5, 91, 7, 66, 3, 52, 0, 47, 8, 63, 4, 83, 
    7,  9, 6, 20, 8, 44, 0,  5, 1, 61, 5, 32, 4, 70, 3, 22, 2, 78, 
    6,  6, 1, 46, 5, 64, 8, 52, 4, 11, 2, 41, 7, 32, 0, 50, 3, 90
  };
  const int q9930[] = {
    9, 9, // Number of jobs and machines
    2, 61, 1, 37, 6, 65, 5, 28, 7, 12, 3, 46, 0, 31, 8, 46, 4, 86, 
    3, 44, 0, 80, 2,  9, 4, 14, 7, 65, 1, 78, 8, 62, 5, 82, 6, 13, 
    5, 55, 1, 65, 2, 96, 6,  7, 0, 35, 3, 41, 8, 17, 7, 71, 4, 88, 
    8, 68, 3, 15, 6, 38, 5, 67, 4,  1, 7, 36, 1, 34, 2, 99, 0, 39, 
    3, 41, 6,  9, 0, 64, 8, 33, 2, 84, 5, 47, 1, 32, 4, 28, 7,  4, 
    4, 71, 8,  9, 1, 79, 5,  7, 7, 23, 3, 12, 6, 72, 2,  8, 0, 48, 
    1, 82, 5, 43, 7, 80, 4, 93, 6, 91, 3, 16, 2, 14, 0, 86, 8, 64, 
    4,  1, 0, 77, 7, 96, 3, 44, 8,  1, 5,  5, 6, 17, 1, 43, 2, 39, 
    1, 97, 3, 45, 7, 95, 8, 41, 5, 56, 6, 25, 0, 29, 4, 52, 2, 36
  };
  const int q9931[] = {
    9, 9, // Number of jobs and machines
    6, 91, 2, 10, 4, 69, 5, 96, 0, 10, 7, 98, 8, 77, 1, 72, 3, 89, 
    2, 40, 7, 32, 3, 83, 5, 19, 0,  3, 8, 22, 1, 86, 4, 38, 6, 68, 
    3, 93, 6,  7, 2, 46, 1, 58, 5, 61, 4, 20, 0,  2, 7, 35, 8, 52, 
    2, 83, 6, 84, 1, 79, 7, 19, 4, 58, 3, 14, 0, 65, 5, 60, 8, 24, 
    3, 72, 1, 41, 8, 94, 2, 99, 6, 85, 7, 68, 4,  7, 5, 11, 0, 66, 
    1, 28, 8, 92, 7, 87, 4, 50, 3, 47, 5, 81, 6, 64, 2, 94, 0, 45, 
    8, 27, 6, 29, 2, 26, 7, 95, 3, 37, 4, 81, 1, 24, 5, 66, 0, 44, 
    6,  3, 0, 37, 2, 26, 7, 55, 4, 45, 3, 69, 8, 28, 1, 54, 5,  2, 
    7, 19, 0, 83, 5, 60, 6, 20, 8, 95, 1, 70, 2, 71, 4, 60, 3, 63
  };
  const int q9932[] = {
    9, 9, // Number of jobs and machines
    1, 44, 3, 63, 5, 46, 0, 30, 8, 25, 2, 19, 7, 77, 6, 18, 4, 38, 
    2, 29, 5, 48, 6, 71, 8, 73, 4, 16, 1, 18, 7, 71, 3, 23, 0, 32, 
    8, 19, 7,  3, 3, 83, 1, 83, 2, 58, 4, 97, 6, 47, 5, 11, 0, 43, 
    0, 66, 5, 17, 4, 43, 2, 61, 1, 96, 6, 67, 7, 23, 3, 12, 8, 69, 
    1, 52, 8, 49, 4, 10, 3, 68, 6, 54, 7, 23, 0, 28, 2, 40, 5, 65, 
    4, 55, 3, 87, 2, 56, 0, 23, 8, 60, 7, 42, 5, 23, 1, 10, 6, 22, 
    8, 24, 6, 29, 3, 31, 7, 69, 2, 59, 4, 70, 0, 62, 1,  7, 5, 49, 
    2, 26, 6, 90, 8, 80, 1, 41, 0, 41, 3, 81, 4, 33, 7, 32, 5, 21, 
    8, 32, 3, 70, 4, 48, 6, 36, 2, 97, 7, 14, 5,  7, 0, 31, 1, 70
  };
  const int q9933[] = {
    9, 9, // Number of jobs and machines
    4, 92, 0, 62, 3, 14, 1, 21, 2,  8, 8, 12, 5, 75, 7, 88, 6, 37, 
    6, 89, 2, 90, 7, 64, 1, 34, 8, 64, 4, 66, 3, 95, 5, 96, 0, 91, 
    8, 97, 6, 78, 7, 45, 1, 46, 5, 39, 0, 22, 3, 13, 4, 80, 2, 23, 
    2, 69, 6, 75, 1, 60, 0, 19, 3,  5, 7,  7, 8, 67, 4, 69, 5, 98, 
    5, 95, 8, 93, 2, 25, 7, 77, 4, 91, 1, 74, 6,  1, 0, 39, 3, 59, 
    5,  6, 1, 63, 0, 56, 7, 53, 3,  3, 4, 89, 2, 84, 8, 15, 6, 14, 
    6, 14, 5, 69, 0, 22, 4, 72, 3, 93, 2, 20, 7, 20, 1, 25, 8, 30, 
    2, 69, 1, 97, 6, 32, 4, 67, 7, 26, 0, 52, 8, 30, 5,  9, 3, 46, 
    7, 43, 4, 85, 6, 37, 5, 32, 1, 96, 3, 46, 2, 40, 0, 98, 8, 38
  };
  const int q9934[] = {
    9, 9, // Number of jobs and machines
    0, 61, 4, 75, 2, 64, 1, 65, 6, 37, 3, 42, 5, 69, 8, 60, 7, 11, 
    4, 36, 2, 94, 6, 62, 1, 83, 7, 74, 5, 87, 0, 34, 8, 56, 3,  9, 
    3, 91, 6, 11, 2, 45, 0, 60, 4, 62, 5, 48, 8, 31, 1, 16, 7, 67, 
    2, 54, 7, 99, 8, 95, 5, 19, 1, 81, 4, 20, 3, 99, 6, 21, 0, 78, 
    8, 49, 5,  8, 7, 17, 4, 87, 2, 97, 6, 13, 3, 36, 0, 87, 1, 10, 
    4, 26, 1, 95, 7, 24, 5, 30, 8, 73, 0, 30, 6, 53, 2,  8, 3, 67, 
    3, 71, 7, 41, 2, 34, 1, 26, 5, 41, 6, 31, 4,  3, 0, 13, 8, 84, 
    0, 99, 4, 76, 5, 56, 1,  3, 8, 72, 6, 14, 3, 77, 7, 44, 2, 33, 
    8, 87, 2, 36, 5, 22, 4, 46, 6, 54, 3, 29, 7, 48, 1, 90, 0,  6
  };
  const int q9935[] = {
    9, 9, // Number of jobs and machines
    1, 11, 2, 61, 5, 94, 0, 36, 3, 19, 6, 57, 4, 69, 7, 18, 8, 83, 
    4, 18, 1, 67, 5, 98, 0,  5, 3, 31, 2, 35, 7, 86, 8, 78, 6, 11, 
    0, 46, 8, 98, 4, 89, 3, 15, 7, 89, 2, 25, 5, 32, 1, 23, 6, 60, 
    1, 95, 2, 36, 0, 24, 3, 51, 5, 50, 7, 71, 6, 76, 4, 66, 8, 25, 
    5, 56, 2, 53, 0, 82, 7, 45, 4, 69, 8, 82, 6, 91, 3, 63, 1, 70, 
    6,  4, 2, 37, 1, 38, 4, 49, 3, 64, 5, 36, 0, 19, 7, 70, 8,  5, 
    5, 24, 2, 53, 6, 31, 7, 63, 4,  6, 3, 72, 8, 57, 1, 82, 0, 12, 
    3, 29, 2, 45, 6, 98, 4, 14, 5, 55, 0, 80, 8, 57, 7, 62, 1, 45, 
    6, 15, 4, 94, 8, 13, 5, 16, 1, 77, 2, 69, 3, 20, 7, 76, 0, 48
  };
  const int q9936[] = {
    9, 9, // Number of jobs and machines
    0, 20, 8, 29, 6, 67, 7, 36, 4, 92, 3, 72, 5, 97, 2, 56, 1, 46, 
    3, 30, 1, 39, 8, 18, 6, 71, 4, 98, 7, 93, 5, 10, 2, 49, 0, 18, 
    3, 80, 0,  5, 4, 52, 6, 68, 8, 52, 7, 99, 1, 80, 5, 84, 2, 67, 
    4, 37, 7, 78, 3, 41, 0, 49, 2, 62, 6, 67, 1, 58, 5, 70, 8, 19, 
    8,  8, 3, 79, 7, 73, 0, 81, 6,  5, 1, 64, 2, 68, 5, 17, 4, 89, 
    6, 26, 3, 78, 0, 65, 1, 37, 5, 65, 4, 93, 2, 50, 7, 12, 8,  5, 
    4, 48, 7, 96, 1, 32, 0, 76, 5, 45, 8, 49, 3, 32, 6, 18, 2, 35, 
    2, 93, 6, 21, 8, 40, 3, 21, 4, 89, 1,  9, 0, 59, 7, 61, 5, 30, 
    5, 63, 6, 27, 7,  5, 0, 22, 8, 89, 3,  5, 4, 30, 2, 53, 1, 62
  };
  const int q9937[] = {
    9, 9, // Number of jobs and machines
    7, 29, 0, 26, 3, 44, 2, 16, 4, 15, 8, 11, 6, 11, 1,  4, 5, 95, 
    7, 89, 5, 68, 1, 82, 6, 92, 2, 50, 0, 19, 8,  3, 4, 77, 3, 14, 
    7, 87, 1, 68, 3, 67, 5, 73, 0, 82, 6, 91, 8, 62, 4, 88, 2, 96, 
    4, 18, 1, 31, 6, 52, 5, 36, 8, 69, 3, 36, 2, 85, 0, 64, 7, 77, 
    5, 74, 0, 89, 3, 17, 6, 29, 1, 68, 8, 52, 2, 27, 7, 31, 4, 42, 
    6, 96, 3, 46, 7, 93, 2, 50, 4, 63, 0, 72, 5, 47, 1, 11, 8, 57, 
    5, 68, 2, 54, 4, 78, 7, 53, 3, 16, 1, 97, 6, 28, 0, 62, 8, 26, 
    5, 77, 2, 38, 7, 52, 4, 39, 1, 75, 0, 33, 6, 52, 8, 69, 3, 17, 
    7, 37, 1, 25, 6, 36, 0, 57, 2, 72, 5, 76, 3,  6, 4, 44, 8, 28
  };
  const int q9938[] = {
    9, 9, // Number of jobs and machines
    8, 68, 4, 99, 2, 62, 6, 40, 3, 95, 1,  3, 5, 77, 0,  5, 7, 46, 
    4, 62, 8, 41, 7, 60, 1, 88, 6, 67, 3, 45, 5, 35, 0, 67, 2, 25, 
    1, 65, 0, 13, 5, 59, 2, 49, 8,  4, 7, 61, 4, 40, 3, 84, 6, 23, 
    2,  1, 5, 29, 8, 69, 4, 14, 1, 26, 6, 37, 0, 71, 3, 76, 7, 61, 
    7, 83, 8, 64, 0, 35, 5,  3, 1, 79, 3, 78, 2, 33, 4,  3, 6, 82, 
    1, 60, 4, 39, 8, 72, 0,  3, 5, 14, 2, 87, 6, 78, 7, 99, 3,  1, 
    4, 23, 7, 17, 3, 12, 0, 76, 1, 46, 6, 46, 2, 40, 8, 33, 5, 85, 
    1, 37, 7, 71, 5, 21, 4, 70, 3, 40, 8, 89, 0, 74, 6, 22, 2,  3, 
    3, 35, 4, 18, 0, 72, 2, 63, 5, 40, 1, 40, 6, 38, 7, 78, 8, 30
  };
  const int q9939[] = {
    9, 9, // Number of jobs and machines
    7, 88, 5, 24, 1, 28, 8, 40, 4, 50, 3, 62, 6,  1, 0, 89, 2, 14, 
    1, 65, 8, 51, 3, 28, 2, 28, 6, 97, 7, 55, 0, 97, 5, 74, 4, 90, 
    8, 61, 4, 55, 1, 41, 6, 87, 3, 29, 2, 73, 5, 55, 7, 69, 0, 81, 
    8, 99, 3, 52, 7, 81, 0, 62, 4, 88, 2, 16, 5, 55, 6, 23, 1, 95, 
    8, 72, 3, 29, 7, 33, 2, 94, 6, 61, 1, 65, 4, 21, 5, 33, 0, 75, 
    2, 67, 6, 83, 5, 46, 0, 19, 8, 38, 7, 66, 3, 96, 4, 67, 1, 80, 
    8, 10, 6, 37, 4, 89, 7, 60, 0, 54, 1, 77, 3, 72, 2, 79, 5, 58, 
    0, 17, 3, 32, 8, 61, 4, 13, 1, 21, 2, 80, 5, 59, 6, 99, 7, 91, 
    3,  3, 2, 43, 4, 66, 5, 73, 8, 46, 6, 49, 7, 45, 0, 96, 1, 67
  };
  const int q9940[] = {
    9, 9, // Number of jobs and machines
    8, 95, 0, 93, 3, 90, 4,  9, 5, 67, 1, 52, 2, 85, 6, 87, 7, 32, 
    8,  5, 7, 46, 6, 52, 5, 62, 3,  1, 0,  7, 4, 97, 2, 43, 1, 26, 
    5, 59, 6, 18, 4, 60, 8, 37, 0, 21, 1,  7, 3, 94, 7, 85, 2, 77, 
    1, 45, 5, 94, 8, 43, 0, 71, 3, 89, 4, 17, 6, 73, 7, 85, 2, 95, 
    5, 10, 6, 54, 7, 42, 4, 71, 0, 78, 1, 26, 8, 98, 3, 45, 2, 81, 
    5, 60, 0, 46, 4, 94, 7, 56, 6, 43, 3, 13, 2, 31, 8,  5, 1, 60, 
    2, 47, 1, 82, 7, 73, 0, 66, 3, 75, 8, 91, 5, 70, 6,  9, 4, 91, 
    3,  1, 7, 91, 8, 50, 6, 13, 4, 54, 0, 71, 2,  8, 1, 12, 5, 62, 
    8, 72, 0,  6, 3, 35, 5, 38, 7, 19, 6, 77, 1, 35, 2, 35, 4, 19
  };
  const int q9941[] = {
    9, 9, // Number of jobs and machines
    4, 93, 3,  7, 1, 95, 6, 37, 5, 47, 7, 11, 0,  3, 2, 39, 8, 23, 
    6, 39, 4, 21, 0, 15, 3, 26, 2, 70, 7, 17, 5, 21, 8, 30, 1, 85, 
    7, 78, 5, 66, 0, 99, 1, 49, 4, 22, 2, 67, 6, 43, 3, 59, 8, 69, 
    6, 40, 0, 79, 2, 74, 4, 78, 3, 52, 5, 69, 1, 89, 7, 36, 8, 95, 
    6, 78, 0, 88, 1, 51, 2, 73, 7, 21, 3, 65, 8,  2, 5, 66, 4, 65, 
    2, 96, 3, 43, 7, 41, 1, 36, 0, 97, 8, 39, 5, 97, 4, 38, 6, 82, 
    7, 90, 5, 35, 3, 62, 2, 85, 8, 66, 6, 83, 4,  2, 0, 21, 1, 81, 
    6, 45, 2, 42, 3, 12, 7, 32, 8, 98, 1, 38, 0, 61, 5, 70, 4, 66, 
    2, 86, 3, 30, 5, 48, 4,  9, 7, 85, 8, 83, 6, 95, 1, 98, 0, 90
  };
  const int q9942[] = {
    9, 9, // Number of jobs and machines
    0, 35, 3, 56, 6, 84, 2, 86, 4, 11, 5, 69, 1, 84, 8, 20, 7, 32, 
    2, 43, 8, 61, 4, 66, 3,  5, 6, 77, 0, 83, 1,  7, 5, 61, 7, 33, 
    0, 67, 7, 77, 6, 46, 1,  6, 3, 29, 4,  4, 8, 60, 5, 30, 2, 57, 
    3, 95, 5,  7, 6, 86, 7, 52, 1,  4, 2, 94, 4, 66, 0, 39, 8, 41, 
    3, 67, 2, 63, 5, 92, 4, 50, 7, 10, 8, 75, 0, 98, 6, 17, 1, 53, 
    8, 42, 1, 88, 5, 35, 7, 77, 3, 66, 4, 27, 2, 86, 0, 93, 6, 23, 
    8, 61, 4, 58, 1, 52, 3, 58, 6, 97, 2, 45, 7, 88, 5, 16, 0, 99, 
    7, 74, 0, 75, 5, 21, 6, 28, 8, 23, 2,  2, 1, 13, 3, 57, 4, 61, 
    5, 69, 8, 48, 7, 66, 1, 67, 4, 22, 0, 79, 3, 37, 6, 38, 2, 96
  };
  const int q9943[] = {
    9, 9, // Number of jobs and machines
    7, 70, 2, 25, 5, 61, 1, 87, 4, 93, 8, 53, 0, 73, 3,  2, 6, 36, 
    1, 98, 4, 88, 6, 36, 8, 17, 7, 67, 0, 45, 3, 79, 5, 82, 2, 99, 
    0, 94, 1, 77, 8, 53, 7, 99, 2, 17, 4, 50, 6, 34, 3, 71, 5, 68, 
    6, 59, 4, 77, 3, 99, 0, 84, 7, 34, 8,  8, 5, 73, 2, 48, 1, 99, 
    4, 45, 8, 60, 6, 46, 0, 67, 3, 88, 2, 32, 7, 49, 5, 99, 1,  6, 
    1, 51, 6, 67, 5, 42, 7, 33, 2, 98, 0, 57, 8, 18, 4, 84, 3, 62, 
    3, 18, 7, 26, 6, 55, 8, 21, 0, 76, 5, 94, 1, 67, 2,  5, 4, 29, 
    4,  7, 6, 84, 3, 28, 5, 41, 1, 17, 8, 87, 7, 85, 2, 31, 0, 87, 
    1, 62, 8, 84, 6,  1, 0, 44, 4, 38, 3, 89, 5, 44, 7,  1, 2, 63
  };
  const int q9944[] = {
    9, 9, // Number of jobs and machines
    3, 98, 6, 38, 4, 36, 0, 89, 8, 80, 7, 66, 2, 19, 5,  1, 1, 68, 
    3, 67, 6, 28, 4, 71, 5, 81, 2, 88, 0,  6, 8,  6, 7, 70, 1, 92, 
    8,  5, 6, 95, 3, 35, 0, 11, 7, 73, 1, 85, 2,  8, 5, 12, 4, 54, 
    3,  5, 4, 40, 7,  7, 5,  1, 0, 91, 6, 10, 8,  7, 1, 35, 2, 77, 
    0, 75, 7, 83, 2, 23, 6, 15, 5, 84, 3, 91, 4, 39, 1, 94, 8, 30, 
    0, 80, 8, 13, 5, 68, 1, 67, 6,  7, 3, 56, 4, 37, 7, 24, 2, 39, 
    0,  8, 5, 46, 3, 76, 7, 14, 1, 33, 6, 28, 2, 18, 8, 82, 4, 98, 
    3, 47, 6, 16, 4,  2, 8, 49, 7,  5, 2, 81, 0, 73, 5, 60, 1, 47, 
    6, 90, 8, 30, 0, 66, 7, 89, 2, 60, 4,  2, 1, 90, 3, 44, 5, 72
  };
  const int q9945[] = {
    9, 9, // Number of jobs and machines
    7, 21, 2,  4, 3, 95, 0, 30, 8, 82, 4, 44, 6, 82, 1, 27, 5, 18, 
    3, 75, 4, 42, 8, 63, 6, 12, 7, 51, 0, 28, 2, 43, 1, 22, 5, 86, 
    0, 33, 6, 35, 8, 27, 2, 64, 4, 56, 5, 46, 3, 51, 1, 40, 7, 46, 
    3, 71, 7, 22, 2,  3, 6, 73, 8, 29, 4, 92, 1, 49, 0, 23, 5, 89, 
    3, 75, 2, 27, 7, 88, 4,  8, 0, 48, 6, 86, 5, 81, 8, 57, 1, 23, 
    1, 12, 0, 18, 4, 68, 7, 79, 8, 71, 6, 55, 2, 54, 5, 68, 3,  8, 
    7, 45, 3, 81, 8, 32, 6, 43, 5, 66, 0, 74, 1, 88, 2, 67, 4, 42, 
    1,  6, 2,  8, 4, 77, 8,  5, 5, 15, 7, 43, 0, 87, 6, 84, 3, 54, 
    1, 51, 6, 17, 0, 54, 8, 37, 2,  5, 5, 35, 3, 91, 4, 37, 7, 62
  };
  const int q9946[] = {
    9, 9, // Number of jobs and machines
    4, 72, 5, 31, 6, 76, 0, 64, 3, 68, 8, 94, 2, 63, 1, 98, 7, 63, 
    6, 91, 1, 61, 2,  3, 3, 56, 7, 71, 5, 94, 0, 84, 4, 56, 8, 59, 
    8, 34, 5,  9, 2, 72, 1, 32, 7, 21, 4, 11, 6, 14, 3,  7, 0, 89, 
    7, 66, 4, 26, 8, 69, 6, 13, 1, 42, 5, 22, 2, 47, 0, 52, 3, 34, 
    4, 34, 8, 42, 1, 88, 7,  8, 3,  4, 2, 18, 0, 21, 5, 31, 6, 86, 
    4, 28, 6,  7, 2, 44, 3, 58, 1, 80, 8, 42, 0, 89, 5, 78, 7, 27, 
    2, 85, 1, 72, 7, 37, 0, 45, 3, 29, 5, 39, 6, 69, 4, 21, 8, 84, 
    6, 77, 5, 74, 0, 45, 7, 55, 4, 82, 3, 62, 2, 14, 8, 45, 1, 73, 
    6, 64, 0, 44, 7, 94, 8, 34, 4, 77, 2, 91, 5, 11, 1, 19, 3, 65
  };
  const int q9947[] = {
    9, 9, // Number of jobs and machines
    2, 42, 5, 77, 7, 43, 1, 69, 0, 54, 4, 86, 8, 14, 6, 99, 3, 47, 
    3, 66, 5, 57, 2, 33, 0, 87, 1, 15, 7, 93, 8, 50, 4, 52, 6, 62, 
    2, 91, 8, 44, 1, 33, 6, 87, 4, 49, 0,  8, 3, 10, 7, 33, 5, 50, 
    5, 34, 6, 82, 7, 24, 3, 54, 2,  5, 4, 23, 0, 44, 8, 15, 1, 58, 
    1, 99, 5, 92, 2, 57, 0, 56, 4, 49, 6, 84, 3, 85, 7, 28, 8, 60, 
    8, 12, 3, 37, 4,  3, 1, 50, 0, 33, 7, 22, 6, 99, 5, 74, 2, 45, 
    8, 54, 3, 97, 2, 77, 0, 91, 7, 87, 5, 43, 1,  1, 4, 16, 6, 63, 
    2, 65, 8, 83, 6, 20, 0, 11, 7, 44, 1, 11, 5, 46, 3, 11, 4, 88, 
    2, 47, 7, 25, 6, 69, 4,  6, 1, 10, 5, 16, 0, 57, 3, 27, 8, 28
  };
  const int q9948[] = {
    9, 9, // Number of jobs and machines
    2, 55, 3, 94, 6, 62, 0,  6, 4, 20, 5, 19, 1, 34, 7, 94, 8, 45, 
    6, 62, 2, 66, 8, 86, 4, 69, 7, 73, 0, 66, 3, 27, 1, 66, 5, 80, 
    2, 49, 4, 11, 7,  5, 8, 46, 1, 47, 3, 52, 6, 80, 0, 36, 5, 18, 
    5, 67, 3, 48, 7, 93, 6, 46, 0, 69, 1, 89, 8, 32, 2, 93, 4, 95, 
    8,  7, 4, 59, 1, 40, 2, 36, 0,  3, 3,  1, 7, 97, 6, 88, 5, 32, 
    7, 40, 1, 59, 4, 31, 3, 58, 5, 96, 6, 27, 2, 10, 8, 83, 0, 38, 
    8, 33, 2, 89, 7, 92, 3, 34, 6, 55, 5, 46, 4, 40, 1, 89, 0, 57, 
    7, 87, 8, 56, 4, 77, 2, 94, 0,  6, 5, 88, 3, 46, 1, 68, 6, 62, 
    6, 79, 1, 34, 2, 53, 7, 83, 8, 71, 3, 73, 4, 55, 0,  5, 5, 49
  };
  const int q9949[] = {
    9, 9, // Number of jobs and machines
    0, 93, 8, 54, 1, 43, 3, 47, 4, 35, 7,  5, 2, 60, 5, 86, 6, 24, 
    6, 41, 3, 96, 2, 51, 8, 31, 0, 13, 1,  7, 5, 40, 7, 76, 4, 62, 
    0, 32, 2, 12, 3, 28, 7, 99, 1, 11, 6, 79, 8, 65, 5,  3, 4, 75, 
    8, 26, 1, 85, 0, 98, 3, 22, 7, 90, 6, 44, 5, 54, 2, 24, 4, 78, 
    4,  6, 6, 66, 1, 70, 3, 66, 7, 80, 2, 39, 8, 31, 5, 69, 0, 92, 
    3, 94, 6, 71, 7, 19, 8, 88, 4, 62, 5, 98, 0, 15, 2, 33, 1, 31, 
    2, 39, 6, 74, 3, 75, 4, 39, 1,  7, 0, 11, 5,  8, 7,  3, 8, 69, 
    0, 38, 7, 21, 2, 72, 8, 23, 5, 95, 1, 39, 4, 27, 3, 96, 6, 45, 
    5, 52, 8, 83, 3, 70, 7, 84, 1, 30, 0, 63, 6, 36, 2, 70, 4, 12
  };
  const int q9950[] = {
    9, 9, // Number of jobs and machines
    5, 57, 2, 11, 3, 64, 6, 61, 0, 17, 8, 67, 1, 40, 7, 67, 4, 96, 
    4,  3, 3, 95, 5, 28, 1, 61, 6, 56, 0, 51, 2, 62, 7, 90, 8, 25, 
    8, 16, 3,  3, 5, 35, 6,  3, 1, 72, 2, 88, 4, 73, 0,  8, 7,  6, 
    7, 37, 1, 39, 8,  6, 4, 61, 0, 13, 6,  9, 2, 11, 3, 86, 5, 79, 
    7, 62, 0, 57, 8, 77, 6, 40, 1, 59, 5, 78, 2, 16, 4, 55, 3,  7, 
    3, 13, 4, 32, 6, 10, 2, 26, 0, 54, 8, 95, 7, 93, 5, 27, 1,  7, 
    8, 88, 3, 14, 6, 45, 5,  2, 2, 74, 0, 66, 1, 61, 4, 47, 7, 11, 
    4, 68, 0, 71, 3, 29, 1, 54, 7,  1, 6,  4, 8, 90, 5, 25, 2, 25, 
    1, 44, 8, 38, 6, 43, 0, 25, 7, 88, 2, 29, 3, 64, 4, 52, 5, 86
  };
  const int q9951[] = {
    9, 9, // Number of jobs and machines
    1, 89, 5, 70, 2, 93, 0, 55, 8,  4, 6, 58, 3, 27, 4, 24, 7, 10, 
    7, 69, 1, 96, 0, 29, 2, 19, 5, 75, 8,  4, 3, 10, 6, 55, 4, 29, 
    8, 20, 1, 87, 6, 92, 3, 16, 0, 31, 4, 67, 7,  3, 5, 43, 2, 64, 
    7, 97, 2, 99, 8, 45, 1, 94, 6, 23, 5, 87, 3, 68, 4, 43, 0, 28, 
    5, 65, 8, 99, 6, 56, 1, 18, 7, 51, 0, 87, 3, 19, 4, 14, 2, 26, 
    2, 90, 0, 75, 8, 89, 1, 39, 3, 48, 4, 75, 5, 73, 7, 76, 6, 53, 
    5, 95, 1, 39, 6, 89, 7, 69, 3, 75, 4, 29, 0, 39, 8, 24, 2, 29, 
    0,  2, 3, 44, 1, 54, 4, 95, 5,  8, 6, 47, 2, 38, 8, 56, 7,  2, 
    3, 17, 0, 76, 1, 68, 5, 89, 2, 11, 8, 41, 4, 55, 6, 56, 7, 50
  };
  const int q9952[] = {
    9, 9, // Number of jobs and machines
    0, 64, 1, 39, 6, 51, 7, 90, 8, 93, 4, 74, 2, 30, 5, 81, 3,  2, 
    8, 63, 5, 91, 1,  5, 4, 21, 3, 58, 6, 76, 0, 59, 7, 51, 2, 19, 
    4, 46, 3, 54, 1, 94, 2, 32, 8, 18, 5, 99, 6, 19, 0, 70, 7, 62, 
    0, 47, 4, 92, 2, 75, 6, 95, 8,  1, 7, 52, 5, 27, 3, 64, 1, 29, 
    1, 72, 3, 68, 2, 96, 7, 81, 0, 21, 4, 41, 6, 93, 5, 97, 8, 49, 
    7, 52, 6, 12, 5, 83, 4, 55, 1, 89, 0, 94, 3, 62, 8, 16, 2,  4, 
    3, 28, 0, 83, 6, 75, 1, 99, 2, 14, 5, 65, 7, 88, 4, 30, 8, 82, 
    5, 21, 4,  7, 0, 22, 7, 58, 2, 65, 1, 16, 8, 12, 6, 84, 3, 71, 
    2, 14, 8, 82, 3, 98, 5,  7, 0, 31, 7, 16, 4, 18, 1, 73, 6, 61
  };
  const int q9953[] = {
    9, 9, // Number of jobs and machines
    7,  5, 8, 55, 1, 16, 2,  7, 5, 69, 3, 55, 6, 77, 4, 18, 0, 28, 
    4, 22, 0, 14, 8, 74, 7, 99, 1, 84, 5, 28, 3, 58, 2, 94, 6, 44, 
    6, 97, 1,  6, 8, 89, 2,  4, 4, 95, 7, 77, 3, 68, 0, 36, 5, 27, 
    6, 91, 3, 39, 7, 39, 8, 62, 1, 35, 0, 92, 4,  5, 5, 16, 2, 86, 
    5, 80, 6, 76, 3, 28, 2, 43, 7, 60, 4, 44, 8, 26, 1, 56, 0, 88, 
    5,  3, 4, 61, 7, 77, 2, 57, 0, 54, 3, 43, 8, 12, 6, 74, 1, 56, 
    3, 24, 0, 11, 6, 98, 8, 94, 2, 83, 4, 12, 1, 83, 7, 72, 5, 52, 
    1, 96, 2, 18, 8, 48, 5, 77, 7, 31, 3, 31, 4, 61, 6, 27, 0, 49, 
    1, 86, 3, 99, 8, 34, 7, 16, 2,  2, 6, 19, 5, 75, 4, 20, 0, 47
  };
  const int q9954[] = {
    9, 9, // Number of jobs and machines
    2, 99, 1, 88, 7, 11, 0, 58, 3, 75, 6, 26, 5, 57, 8, 79, 4, 96, 
    7, 83, 2, 20, 8, 32, 5,  2, 0, 28, 1, 46, 6, 42, 4, 98, 3, 46, 
    6, 94, 7, 81, 2, 61, 5, 11, 8, 52, 1, 30, 0, 35, 4, 25, 3, 81, 
    4, 88, 7, 53, 1, 23, 3, 93, 0, 58, 2, 32, 6, 45, 5, 28, 8, 63, 
    2, 39, 0, 41, 8, 78, 5,  4, 6, 58, 3, 30, 4, 84, 7, 95, 1, 39, 
    7, 32, 8, 30, 3, 82, 4, 40, 0, 63, 5, 98, 1, 67, 6, 37, 2, 16, 
    3, 44, 1, 64, 4,  3, 6, 82, 8, 66, 0, 96, 7, 76, 2, 77, 5, 94, 
    1, 82, 3, 52, 7, 11, 8, 11, 2, 98, 4, 98, 6, 82, 5, 98, 0, 37, 
    2, 97, 6, 53, 1, 81, 8, 91, 3, 62, 4, 14, 0, 23, 5,  9, 7, 48
  };
  const int q9955[] = {
    9, 9, // Number of jobs and machines
    0, 46, 2, 82, 4, 93, 1, 83, 7, 29, 8,  1, 3, 37, 5, 89, 6, 73, 
    4, 22, 1,  3, 6,  1, 8,  7, 7, 87, 2, 29, 0, 46, 5, 43, 3, 34, 
    1, 91, 3, 75, 4, 51, 6, 40, 7, 39, 0, 33, 5, 85, 8, 65, 2, 11, 
    5, 49, 6, 97, 7, 44, 3, 63, 8, 63, 4, 59, 2,  7, 0, 92, 1, 26, 
    7, 52, 2,  8, 8,  4, 1, 33, 5, 91, 4,  3, 0, 17, 6, 38, 3, 89, 
    0, 52, 4, 39, 3, 88, 5, 78, 2, 31, 6,  5, 1, 28, 8, 17, 7, 91, 
    5, 33, 0, 87, 7, 36, 6, 32, 4, 91, 3, 78, 8, 20, 2, 46, 1, 85, 
    8, 33, 4, 46, 5, 18, 7, 18, 3, 11, 0, 90, 6, 90, 2, 80, 1, 57, 
    8, 86, 5, 59, 6,  5, 0, 28, 7, 33, 2, 82, 3, 29, 4, 75, 1, 66
  };
  const int q9956[] = {
    9, 9, // Number of jobs and machines
    3, 21, 7, 24, 5, 45, 0, 87, 4, 76, 6, 26, 2, 56, 8, 22, 1, 89, 
    6, 77, 4, 88, 5, 79, 1, 58, 3, 25, 2, 92, 0, 28, 7, 19, 8, 69, 
    8, 20, 2, 51, 0, 14, 3, 68, 1, 55, 6, 81, 5, 88, 4,  1, 7, 41, 
    2, 30, 1, 22, 0, 17, 5, 86, 4, 37, 3, 65, 6, 92, 8, 33, 7, 90, 
    2, 79, 5, 89, 4, 40, 1,  5, 7, 88, 6, 91, 3, 14, 0, 47, 8, 97, 
    0, 93, 4, 87, 7, 22, 2, 36, 6, 16, 5, 30, 3, 86, 1, 57, 8, 25, 
    5, 19, 3, 36, 1, 78, 7, 59, 8, 18, 4, 69, 0, 59, 6, 64, 2, 74, 
    5, 44, 4, 66, 6, 10, 3, 69, 7,  2, 1, 81, 8, 81, 0, 13, 2, 82, 
    7, 53, 5, 30, 8, 65, 2, 94, 4, 20, 1, 18, 3, 57, 0, 46, 6, 12
  };
  const int q9957[] = {
    9, 9, // Number of jobs and machines
    7, 62, 8, 90, 2, 53, 5, 99, 0, 50, 4, 24, 3, 64, 1,  5, 6, 93, 
    0, 13, 4, 36, 1, 60, 5, 62, 8, 40, 2, 30, 6, 93, 7, 93, 3,  7, 
    7, 98, 8, 55, 3, 29, 1,  2, 2, 67, 6, 67, 5, 86, 4, 21, 0, 41, 
    1, 73, 2, 32, 0, 75, 3, 83, 6, 93, 5, 45, 7, 10, 8, 52, 4, 75, 
    0,  6, 5, 27, 3,  5, 4, 61, 6, 38, 2,  4, 7, 50, 1,  3, 8, 13, 
    8, 98, 4, 85, 2, 20, 6, 76, 0, 80, 7, 11, 3, 67, 5, 32, 1, 55, 
    3,  1, 5, 68, 1, 18, 7, 56, 8, 50, 0, 70, 6, 97, 4, 68, 2, 92, 
    0, 37, 3, 27, 5, 36, 7, 91, 4,  9, 8, 48, 2, 38, 6, 29, 1, 91, 
    8, 19, 0,  9, 5, 65, 1, 19, 3, 74, 6, 90, 2, 17, 4, 89, 7, 18
  };
  const int q9958[] = {
    9, 9, // Number of jobs and machines
    2, 58, 5, 53, 3, 73, 0, 38, 4, 54, 7, 22, 6, 47, 8,  2, 1, 94, 
    6, 58, 1, 37, 8, 54, 3, 23, 4, 93, 2, 64, 5, 14, 7, 33, 0, 40, 
    7, 94, 6, 24, 8, 44, 2, 92, 3, 74, 5, 86, 1, 68, 0, 57, 4, 42, 
    2, 93, 4, 50, 1,  6, 6, 23, 7, 29, 8, 63, 3, 63, 5, 60, 0, 13, 
    6, 76, 4, 42, 2, 29, 0, 18, 1,  6, 7, 30, 5, 96, 3, 84, 8, 31, 
    3, 46, 8, 25, 4, 78, 7, 91, 1,  8, 2, 32, 6,  6, 5, 26, 0,  2, 
    2, 75, 0, 65, 1,  3, 5, 41, 6, 19, 4, 20, 8, 29, 7, 42, 3, 90, 
    4, 24, 6, 41, 1, 43, 0,  3, 8, 82, 2, 20, 5, 92, 3, 50, 7, 14, 
    4, 28, 6, 57, 1, 36, 8, 49, 5, 45, 7, 73, 3, 30, 2, 52, 0, 86
  };
  const int q9959[] = {
    9, 9, // Number of jobs and machines
    5, 24, 1, 94, 3, 99, 7, 75, 2, 38, 8, 40, 6,  2, 0, 13, 4, 88, 
    3, 59, 8, 13, 4, 75, 0, 38, 2, 28, 5, 51, 7, 23, 1, 41, 6, 59, 
    1, 31, 0,  5, 8, 29, 2, 34, 7, 61, 3, 70, 4, 81, 6, 85, 5, 67, 
    8, 14, 4, 39, 7, 51, 2, 37, 6, 81, 5, 22, 3, 85, 0, 25, 1, 75, 
    5, 57, 2, 95, 4, 93, 3, 96, 0, 31, 7,  2, 8, 88, 6, 84, 1, 59, 
    1, 13, 5, 45, 6, 56, 4, 69, 8, 24, 3, 69, 2, 68, 7, 84, 0, 73, 
    7, 41, 0,  5, 1, 83, 6, 17, 8, 72, 3, 68, 2, 16, 5, 80, 4, 49, 
    1, 76, 3, 99, 0, 22, 6, 43, 5, 43, 7,  7, 4, 59, 2, 23, 8, 74, 
    4, 44, 5, 44, 3, 99, 8, 80, 7, 34, 1, 72, 6, 55, 0, 34, 2, 93
  };
  const int q9960[] = {
    9, 9, // Number of jobs and machines
    7, 91, 0, 43, 3, 50, 5, 44, 2, 40, 8, 87, 4, 30, 1, 63, 6, 29, 
    6, 61, 5, 20, 4, 75, 1, 50, 7, 36, 3, 51, 0, 52, 8, 61, 2, 46, 
    0, 56, 4,  1, 3, 87, 2, 39, 6, 12, 1, 27, 7, 63, 8,  3, 5, 65, 
    7, 68, 4, 50, 6, 64, 8, 65, 5, 84, 0, 93, 3, 54, 2, 91, 1, 36, 
    1, 83, 7, 55, 5, 90, 2, 19, 0, 56, 6, 84, 3, 12, 8, 61, 4, 25, 
    8, 37, 3, 94, 1, 99, 4, 27, 0, 53, 2, 51, 7, 70, 5, 37, 6, 56, 
    1, 57, 3, 70, 8, 25, 2, 94, 0, 56, 7, 53, 4, 21, 5, 40, 6, 43, 
    6, 57, 5, 29, 2, 45, 8, 52, 3, 85, 1, 79, 0, 81, 4, 35, 7, 16, 
    1, 43, 3, 25, 7, 62, 0,  3, 2, 16, 4, 15, 8, 14, 5, 44, 6, 99
  };
  const int q9961[] = {
    9, 9, // Number of jobs and machines
    3, 27, 5, 46, 7, 85, 8, 52, 0, 67, 4, 93, 1, 45, 2, 38, 6, 37, 
    3, 94, 1, 84, 2, 23, 0, 48, 5, 93, 8, 56, 6, 13, 4, 99, 7, 69, 
    8, 85, 7, 56, 4, 43, 3,  5, 6, 76, 1, 57, 0, 92, 2, 83, 5, 16, 
    6,  3, 5, 42, 4, 19, 1, 49, 2, 61, 3, 20, 0,  9, 8, 50, 7, 48, 
    4,  1, 2, 95, 5, 73, 8, 79, 0, 80, 6, 63, 7, 50, 3, 98, 1, 73, 
    4, 64, 5, 49, 6, 76, 8, 30, 3, 36, 0, 48, 1, 44, 7, 94, 2, 15, 
    1,  1, 2,  7, 8, 76, 0, 68, 4, 63, 6,  9, 3, 85, 7, 14, 5, 74, 
    1, 58, 3, 57, 0, 48, 7, 46, 5, 11, 8, 30, 2, 59, 4, 67, 6, 49, 
    0, 83, 2, 41, 5, 44, 8, 28, 6, 61, 3, 57, 1, 47, 4, 68, 7, 87
  };
  const int q9962[] = {
    9, 9, // Number of jobs and machines
    8, 85, 0, 88, 2, 96, 6, 66, 5, 77, 3, 82, 1, 75, 4,  5, 7, 28, 
    3, 91, 1, 53, 7, 32, 8, 94, 6, 33, 0, 65, 4,  8, 5, 92, 2, 98, 
    3, 43, 6,  9, 8, 87, 5, 11, 2, 60, 7, 38, 4, 72, 1, 79, 0, 48, 
    4, 85, 8,  1, 1, 78, 7, 90, 0, 88, 2, 81, 5, 84, 3, 85, 6, 89, 
    7, 93, 8, 57, 6, 59, 0, 97, 1, 44, 3, 75, 4, 99, 5, 94, 2, 68, 
    7, 74, 2, 52, 5, 73, 1, 77, 0, 67, 4, 62, 6, 19, 3, 90, 8, 92, 
    6, 35, 0, 53, 5, 64, 4, 29, 1, 67, 2, 97, 8, 21, 7, 67, 3, 41, 
    2, 43, 4, 70, 3, 70, 1, 51, 6, 97, 8, 99, 5, 66, 7, 96, 0,  1, 
    6, 33, 7, 73, 5, 23, 1, 81, 4, 96, 0, 23, 8, 71, 3,  8, 2, 17
  };
  const int q9963[] = {
    9, 9, // Number of jobs and machines
    0, 42, 5, 93, 6, 58, 2, 63, 1, 65, 7, 32, 3, 48, 8, 41, 4,  4, 
    6, 62, 3, 23, 4, 39, 7,  7, 1, 92, 5, 76, 8, 96, 2, 17, 0, 52, 
    7, 98, 8, 45, 3, 62, 1, 15, 5, 95, 0, 50, 2, 30, 6, 43, 4, 95, 
    6, 59, 1, 49, 0, 11, 3, 74, 8, 65, 7, 63, 2, 45, 5,  7, 4, 55, 
    7, 36, 8, 18, 0, 97, 5, 86, 2, 48, 1, 32, 4, 61, 3, 41, 6, 93, 
    7, 31, 1, 83, 0,  3, 4, 15, 3, 84, 5, 26, 2, 60, 8, 95, 6, 47, 
    0, 26, 4, 60, 7, 33, 2, 50, 3, 52, 6, 64, 1,  4, 8, 67, 5, 91, 
    6, 77, 5, 74, 8, 70, 2, 44, 7, 89, 3, 79, 4, 39, 1, 77, 0, 56, 
    5, 27, 8, 82, 1, 33, 2, 88, 7, 14, 0, 56, 6, 79, 4,  7, 3, 68
  };
  const int q9964[] = {
    9, 9, // Number of jobs and machines
    2, 15, 7, 37, 5, 82, 1, 83, 4,  4, 8, 32, 6, 32, 0,  9, 3, 97, 
    5, 59, 0, 73, 3, 67, 1, 22, 4, 40, 7, 69, 2, 45, 6, 56, 8, 51, 
    2, 95, 7, 99, 8, 34, 3, 92, 5, 94, 6, 60, 0, 54, 1, 74, 4, 14, 
    6, 69, 0, 88, 2, 71, 7, 10, 1, 51, 4, 86, 8, 60, 3, 26, 5, 95, 
    1, 14, 5, 66, 8,  2, 6, 99, 0, 44, 3, 88, 4, 81, 7, 18, 2, 12, 
    2, 25, 8, 47, 0, 99, 4, 45, 6, 65, 3,  7, 5, 34, 1, 39, 7, 47, 
    1, 62, 2, 69, 8, 60, 7, 28, 6, 55, 5, 95, 4, 91, 0, 16, 3, 76, 
    8, 97, 5, 40, 1, 53, 2, 91, 7, 69, 6, 74, 0, 67, 3, 83, 4, 24, 
    2, 22, 5, 26, 4, 99, 8, 45, 0, 65, 6, 29, 7, 99, 1, 38, 3, 97
  };
  const int q9965[] = {
    9, 9, // Number of jobs and machines
    3, 40, 4, 87, 6, 55, 5, 74, 2, 45, 0, 63, 1, 96, 7, 89, 8, 18, 
    4, 98, 8, 43, 7, 56, 5, 44, 3, 19, 2, 34, 0,  3, 1, 36, 6, 95, 
    0, 36, 7, 23, 6, 88, 1, 26, 3, 15, 4, 76, 5, 48, 8, 55, 2, 64, 
    2, 70, 6, 38, 0, 86, 8, 64, 1, 91, 7, 89, 3, 43, 4, 47, 5, 60, 
    2,  5, 7, 83, 0, 31, 8, 31, 5, 64, 1, 92, 4, 61, 3, 68, 6, 16, 
    2, 89, 7, 86, 6, 90, 4,  6, 3, 62, 1, 42, 0, 64, 8, 49, 5, 18, 
    2,  8, 0, 31, 4, 93, 3, 83, 7, 81, 1, 18, 6, 17, 5, 60, 8, 66, 
    8, 90, 4, 13, 1, 20, 5, 51, 0, 57, 3, 20, 6, 76, 2, 27, 7,  7, 
    2,  6, 8, 70, 7, 77, 5, 41, 0, 35, 1, 75, 6,  4, 3, 68, 4, 14
  };
  const int q9966[] = {
    9, 9, // Number of jobs and machines
    7, 44, 1,  2, 4, 17, 5, 26, 6, 96, 2, 84, 0, 78, 3, 68, 8, 77, 
    1, 11, 6, 51, 3, 41, 8, 66, 0, 56, 2, 11, 5, 86, 4, 23, 7, 54, 
    8, 32, 6, 59, 1,  8, 7, 69, 5,  7, 0, 96, 3, 33, 4, 61, 2, 66, 
    8, 96, 5, 61, 2, 82, 0,  9, 3, 46, 7, 93, 4, 12, 6, 23, 1, 85, 
    6, 22, 0, 49, 4,  6, 7, 22, 8, 68, 1, 37, 3, 49, 2, 97, 5, 44, 
    3,  8, 7, 23, 6, 26, 2, 44, 5, 53, 1, 90, 8, 72, 0, 18, 4, 19, 
    8, 40, 5, 39, 6, 33, 1, 35, 2, 72, 3, 39, 4, 98, 0, 28, 7, 64, 
    6, 61, 4, 84, 0,  8, 5, 14, 3,  1, 1, 37, 7, 94, 8, 24, 2, 50, 
    2, 96, 8, 30, 6,  5, 3, 23, 4, 75, 7, 10, 1, 73, 0, 46, 5, 25
  };
  const int q9967[] = {
    9, 9, // Number of jobs and machines
    4, 91, 3, 49, 0, 75, 7, 21, 5, 47, 1, 91, 6, 97, 2, 89, 8,  7, 
    8, 35, 5, 11, 2, 57, 4, 67, 3, 68, 1,  1, 6, 35, 0, 75, 7, 10, 
    3, 29, 8, 53, 4, 87, 7, 81, 0, 84, 5, 30, 1, 66, 2, 84, 6, 77, 
    7, 12, 2, 46, 3, 51, 4, 60, 8, 50, 5, 55, 1, 34, 0, 81, 6, 53, 
    7, 53, 2, 64, 0, 23, 6,  8, 8,  2, 5, 94, 1, 68, 3, 64, 4, 45, 
    4, 70, 7, 70, 8,  2, 1, 73, 6, 35, 5, 80, 0,  4, 2, 81, 3, 13, 
    1, 46, 3, 33, 8, 34, 0, 28, 5, 31, 7,  2, 6, 40, 2, 94, 4, 75, 
    1, 95, 4, 58, 3, 84, 0, 59, 5, 37, 2,  4, 7, 60, 8, 71, 6, 45, 
    8, 17, 6, 13, 7, 27, 5, 53, 3, 40, 0, 40, 2, 48, 4, 34, 1, 70
  };
  const int q9968[] = {
    9, 9, // Number of jobs and machines
    5, 39, 7, 44, 4, 65, 0, 75, 6, 97, 2, 59, 8, 68, 3, 18, 1, 70, 
    4, 37, 3, 45, 8, 93, 1, 40, 0, 31, 5, 39, 2, 99, 6, 35, 7, 65, 
    4, 22, 2, 18, 6,  9, 5, 14, 1, 87, 3, 61, 7,  8, 8, 73, 0, 68, 
    0, 23, 1, 32, 2, 63, 5, 85, 3, 39, 8, 41, 7, 62, 4, 41, 6, 91, 
    5, 39, 8, 79, 4, 56, 6, 15, 2, 50, 0, 25, 1, 17, 7, 77, 3, 74, 
    1, 17, 5, 60, 8, 91, 7, 49, 4, 92, 3, 89, 0, 76, 6,  3, 2, 19, 
    4, 90, 2, 96, 0, 26, 8, 44, 1, 16, 7, 31, 6, 34, 3, 31, 5, 52, 
    8, 71, 5, 76, 6,  6, 4, 73, 7, 70, 1, 66, 3, 89, 2, 63, 0, 71, 
    4, 22, 2, 96, 3, 61, 1, 63, 6, 24, 7, 48, 0, 17, 8, 43, 5, 14
  };
  const int q9969[] = {
    9, 9, // Number of jobs and machines
    3, 36, 1, 11, 2,  4, 5, 17, 6, 32, 8, 80, 0, 71, 4, 61, 7, 54, 
    8, 95, 3, 32, 2, 26, 4, 18, 1, 46, 6, 90, 7, 85, 0,  6, 5, 15, 
    3, 64, 7, 30, 6,  6, 2, 64, 4,  7, 1, 27, 5, 21, 8, 35, 0,  7, 
    3, 75, 0, 96, 2, 36, 8, 76, 4, 69, 7, 31, 6, 24, 1, 32, 5, 11, 
    5, 90, 3, 56, 4, 97, 0,  4, 8, 52, 6, 59, 2, 39, 7, 48, 1, 71, 
    2, 55, 4, 28, 0, 36, 8, 48, 6, 65, 5, 36, 7, 84, 1, 92, 3, 91, 
    0, 27, 6, 26, 5, 64, 7,  3, 8,  9, 4,  6, 2, 63, 3, 22, 1, 71, 
    7, 44, 4, 95, 3, 83, 8, 91, 2, 19, 6, 89, 0, 95, 1, 50, 5, 11, 
    8, 38, 3, 16, 5, 25, 1, 19, 6, 18, 2, 11, 7, 45, 0,  3, 4, 37
  };
  const int q9970[] = {
    9, 9, // Number of jobs and machines
    2,  5, 4, 32, 0, 19, 1, 50, 3, 48, 5, 31, 6, 91, 7, 47, 8, 92, 
    2, 32, 6,  8, 7, 63, 5, 30, 3, 85, 8, 88, 1, 30, 0, 65, 4, 16, 
    3, 67, 5, 57, 0, 67, 7, 77, 2, 33, 1, 85, 4, 95, 6, 81, 8, 63, 
    3, 96, 5, 37, 6, 63, 7, 30, 2, 47, 1, 86, 4,  9, 8, 24, 0, 45, 
    5,  6, 4, 37, 0, 50, 6, 46, 1, 56, 2, 95, 3, 10, 7, 34, 8, 10, 
    1, 79, 6, 21, 5, 20, 4, 97, 8, 65, 0, 48, 7, 43, 2, 44, 3, 25, 
    5,  1, 0, 67, 8, 16, 6,  5, 7, 15, 1, 43, 4, 12, 3, 59, 2, 74, 
    1, 89, 7,  2, 8, 90, 5, 89, 3, 75, 6, 50, 4, 43, 2, 36, 0, 90, 
    7, 42, 8,  9, 4, 12, 1, 82, 0, 13, 3, 83, 2, 19, 6, 51, 5, 67
  };
  const int q9971[] = {
    9, 9, // Number of jobs and machines
    5, 61, 7, 86, 6, 60, 2,  1, 4, 54, 8, 75, 3, 92, 1, 33, 0, 44, 
    4,  4, 1, 18, 0, 16, 3, 10, 7, 38, 2,  5, 8, 15, 5, 47, 6, 28, 
    8, 47, 4, 99, 2, 56, 7, 29, 5, 96, 1, 94, 6, 74, 0, 76, 3, 31, 
    6,  5, 7, 75, 8, 73, 0, 99, 3, 93, 4, 21, 1, 66, 5, 60, 2, 47, 
    0, 77, 4, 45, 8, 95, 7, 68, 1, 54, 6, 43, 3, 55, 2, 62, 5, 81, 
    3, 20, 5, 70, 6, 58, 1, 30, 0, 93, 8, 37, 7, 47, 2, 93, 4, 76, 
    2, 90, 3, 54, 6, 98, 8, 51, 0, 46, 4, 19, 5, 86, 1, 60, 7, 39, 
    5, 71, 6, 76, 4, 37, 3, 12, 0, 81, 2, 78, 1, 47, 8, 58, 7, 22, 
    2, 40, 0, 45, 6, 21, 8, 86, 1, 18, 5, 56, 4, 27, 3, 67, 7, 51
  };
  const int q9972[] = {
    9, 9, // Number of jobs and machines
    8, 69, 3, 93, 6, 57, 5, 73, 4, 98, 1, 53, 7, 44, 0, 29, 2, 66, 
    7, 80, 1, 57, 8,  2, 4, 11, 0, 17, 3, 59, 5, 48, 6, 50, 2, 72, 
    5, 55, 6, 82, 0,  5, 1, 12, 3, 43, 7, 66, 8, 75, 2, 32, 4,  1, 
    4,  5, 7, 23, 3, 21, 8, 24, 2, 60, 0, 52, 6, 89, 1, 52, 5, 25, 
    2, 71, 8, 31, 1, 74, 4, 45, 3, 39, 7, 98, 6, 57, 0, 46, 5, 29, 
    5, 56, 1, 44, 3, 25, 8, 52, 2, 70, 7, 26, 6, 96, 0, 75, 4, 66, 
    4, 32, 1, 86, 7, 14, 0, 23, 2, 58, 5,  7, 3, 99, 8, 12, 6, 52, 
    4, 26, 8, 95, 2,  3, 5, 69, 7, 19, 0, 67, 1, 95, 6, 76, 3, 54, 
    7, 35, 1, 29, 2, 13, 0, 43, 6, 98, 4, 56, 5, 48, 3,  3, 8, 17
  };
  const int q9973[] = {
    9, 9, // Number of jobs and machines
    2, 12, 0, 37, 6, 99, 1,  4, 4, 55, 7, 15, 3, 96, 8, 19, 5, 66, 
    5, 73, 6,  5, 1, 37, 7, 60, 0, 31, 2, 45, 8, 97, 3, 75, 4, 49, 
    0, 41, 4, 67, 2,  9, 7, 33, 3, 18, 1, 27, 8, 30, 6, 64, 5, 34, 
    8, 83, 2, 62, 6, 48, 7, 57, 4, 34, 1, 47, 5, 27, 0, 21, 3, 76, 
    3, 81, 5, 84, 1, 97, 7, 57, 4, 90, 0, 78, 8, 87, 2, 35, 6, 17, 
    5, 70, 3,  3, 7, 69, 4, 22, 6, 96, 0,  2, 2, 69, 1, 43, 8, 98, 
    7, 34, 1, 14, 6, 90, 5, 25, 8, 50, 3, 77, 0,  4, 2, 48, 4, 43, 
    7, 68, 3, 36, 1, 47, 0,  9, 4, 43, 8, 36, 5, 83, 6, 77, 2, 99, 
    1, 93, 6, 77, 5, 12, 8, 45, 7, 94, 2, 76, 3, 86, 4, 14, 0, 13
  };
  const int q9974[] = {
    9, 9, // Number of jobs and machines
    7, 11, 0, 89, 3, 48, 4, 13, 6, 54, 2, 86, 5, 23, 1, 73, 8, 96, 
    6, 77, 3,  7, 4, 29, 5, 76, 7, 70, 8, 35, 0, 75, 2, 98, 1, 41, 
    7, 58, 0, 58, 6, 69, 1, 47, 5, 72, 4, 18, 8, 18, 3, 80, 2, 70, 
    6, 84, 1, 54, 5, 80, 7, 80, 2, 91, 0, 76, 3, 75, 8, 15, 4, 41, 
    2, 46, 0, 81, 7, 78, 4, 73, 3, 91, 1, 10, 5, 58, 6, 97, 8,  9, 
    1, 58, 3, 83, 6,  6, 0, 54, 5,  5, 8, 46, 7,  1, 4, 85, 2, 20, 
    2, 88, 8, 54, 1, 14, 0, 54, 5, 56, 7, 90, 6, 25, 3, 30, 4, 48, 
    8, 67, 3, 70, 7, 26, 0, 53, 2, 49, 1, 13, 4,  1, 6,  8, 5,  9, 
    1, 48, 5, 67, 2, 95, 3, 87, 7, 14, 8, 36, 6, 23, 0,  7, 4, 83
  };
  const int q9975[] = {
    9, 9, // Number of jobs and machines
    2, 71, 5, 83, 8, 27, 3, 87, 1, 63, 6, 10, 0, 38, 7, 38, 4, 23, 
    2, 37, 1, 19, 6, 93, 0, 56, 8, 75, 7, 45, 3, 96, 4, 86, 5, 94, 
    3, 14, 0, 41, 6,  9, 1, 39, 4, 30, 7, 65, 5, 95, 8, 46, 2, 51, 
    3, 26, 5, 52, 8, 84, 6, 82, 0, 18, 7, 59, 4, 68, 1, 70, 2, 84, 
    7, 51, 4,  5, 8, 52, 0, 88, 5, 58, 3, 74, 1, 68, 2, 69, 6, 15, 
    3, 69, 5, 77, 0, 87, 6, 73, 2, 63, 8, 72, 1, 36, 7, 83, 4, 30, 
    5, 95, 2, 81, 8, 39, 1,  2, 0, 23, 3,  3, 6, 72, 4, 91, 7, 86, 
    1, 25, 4, 51, 3, 68, 2, 65, 5, 74, 8, 43, 7, 59, 6, 29, 0, 55, 
    1, 81, 4,  4, 3, 14, 8, 57, 0, 56, 5, 94, 7, 81, 6, 89, 2, 55
  };
  const int q9976[] = {
    9, 9, // Number of jobs and machines
    3, 64, 1, 45, 5, 58, 8, 72, 4, 47, 7, 67, 0, 47, 2, 44, 6, 93, 
    5, 76, 0, 54, 7, 27, 6, 68, 3, 29, 4, 41, 1, 90, 2, 24, 8, 73, 
    0, 63, 1, 10, 3, 51, 4, 90, 2, 87, 6, 96, 8, 26, 7, 25, 5, 63, 
    5, 62, 3, 11, 2, 73, 8, 60, 7, 76, 4,  8, 0, 60, 1, 36, 6,  5, 
    2, 98, 7, 53, 8, 19, 5, 57, 3, 59, 4,  2, 0, 36, 1, 45, 6, 56, 
    6, 93, 5, 64, 2, 70, 0, 26, 8, 55, 1, 48, 4, 54, 7, 55, 3, 74, 
    6, 89, 5, 97, 1, 84, 4, 18, 2, 75, 7, 55, 8, 35, 3,  6, 0,  1, 
    0, 44, 6, 86, 3, 94, 4, 46, 8, 43, 1, 31, 7, 14, 2, 51, 5, 87, 
    6, 18, 1, 87, 0, 74, 4, 29, 5, 48, 8, 67, 3, 13, 2, 84, 7, 23
  };
  const int q9977[] = {
    9, 9, // Number of jobs and machines
    6,  7, 3, 54, 1, 22, 7,  6, 2, 55, 4, 83, 0, 85, 5, 77, 8,  8, 
    5, 37, 1, 11, 7, 66, 3, 48, 4, 59, 6, 95, 8, 80, 2, 58, 0, 98, 
    8, 81, 7, 77, 5, 97, 4, 12, 3, 43, 2, 93, 1, 78, 6,  4, 0, 80, 
    6, 11, 1, 12, 5, 41, 3, 45, 2, 17, 7, 83, 4, 99, 0,  8, 8, 84, 
    1,  7, 0,  3, 5, 94, 6, 93, 8,  5, 3, 44, 7, 49, 2, 79, 4, 15, 
    1, 67, 0,  2, 7, 47, 4, 42, 2, 75, 6,  4, 5, 82, 8, 20, 3, 37, 
    3, 95, 2, 99, 0, 58, 4, 87, 7, 27, 5, 72, 8, 60, 6, 14, 1, 48, 
    8, 73, 4, 78, 1, 85, 3, 94, 2, 32, 5, 32, 0, 70, 6, 13, 7, 38, 
    3, 94, 8, 91, 5, 32, 2, 12, 6, 69, 0, 56, 1, 79, 7,  8, 4, 44
  };
  const int q9978[] = {
    9, 9, // Number of jobs and machines
    6, 24, 2, 94, 1, 11, 8, 67, 3, 91, 5, 50, 0, 67, 4, 81, 7, 75, 
    1, 21, 6, 17, 2, 59, 7, 48, 5, 65, 8,  4, 4, 48, 0, 87, 3, 78, 
    1, 73, 4, 31, 8, 32, 3, 43, 0, 89, 7, 70, 6, 78, 2, 91, 5, 61, 
    2, 52, 3, 30, 5, 56, 0, 21, 1, 93, 7, 79, 8, 26, 6, 30, 4, 86, 
    8, 69, 2, 31, 5, 14, 1, 92, 0,  7, 7, 71, 4, 45, 6, 65, 3, 92, 
    0, 94, 8, 45, 4, 49, 3, 31, 2,  7, 7, 48, 6, 88, 1, 45, 5, 54, 
    3, 11, 2, 11, 4, 14, 1, 52, 7, 13, 0, 70, 6, 71, 5,  4, 8, 28, 
    5, 78, 8, 97, 3, 11, 0,  9, 6, 69, 4, 44, 2, 87, 7, 85, 1, 13, 
    3, 89, 7, 22, 0, 74, 1, 72, 2, 26, 5, 67, 4, 65, 6,  2, 8, 31
  };
  const int q9979[] = {
    9, 9, // Number of jobs and machines
    1, 11, 4, 15, 7,  2, 6, 81, 0, 62, 8,  7, 2, 83, 5, 98, 3, 73, 
    6, 86, 3, 86, 2, 68, 7, 48, 4, 79, 5, 55, 8, 35, 1, 40, 0, 28, 
    2, 59, 4, 72, 0, 65, 3,  1, 5, 53, 7, 50, 6, 73, 8, 86, 1, 84, 
    1, 47, 7, 30, 0, 26, 5, 56, 2,  2, 6, 22, 3,  8, 8, 34, 4, 25, 
    3, 42, 7, 81, 5, 28, 4, 53, 6, 89, 1, 15, 8, 43, 0, 99, 2, 10, 
    1, 32, 6, 26, 7, 41, 3, 99, 0,  3, 5, 52, 2, 28, 4, 10, 8, 53, 
    0, 36, 2,  4, 5, 21, 8, 41, 6, 22, 3, 27, 7, 96, 1, 40, 4, 60, 
    8, 58, 5, 22, 2, 41, 6, 92, 0, 35, 4, 62, 3, 38, 7, 10, 1, 28, 
    2, 65, 1, 88, 5, 51, 3, 91, 4, 33, 6, 79, 0, 28, 8, 33, 7, 82
  };
  const int q9980[] = {
    9, 9, // Number of jobs and machines
    4, 86, 1, 11, 7, 16, 6, 40, 3, 96, 2, 47, 5, 30, 8, 84, 0, 92, 
    0, 88, 1, 23, 7, 52, 2, 42, 8, 37, 5, 53, 3, 76, 4, 95, 6, 38, 
    1, 18, 6,  6, 3, 39, 7, 80, 8, 93, 5, 95, 4, 55, 2, 35, 0, 56, 
    4, 99, 1, 37, 5, 30, 6, 28, 8, 75, 3, 25, 7, 97, 2, 38, 0, 21, 
    1, 75, 8, 22, 5, 12, 3,  7, 4, 25, 0, 23, 2,  6, 7, 47, 6, 14, 
    6, 71, 4, 89, 2, 87, 0, 47, 8, 32, 5, 79, 1,  7, 7, 84, 3, 61, 
    8, 97, 3, 92, 1,  5, 7, 56, 6, 41, 0, 85, 4, 56, 5, 65, 2, 81, 
    6, 37, 4, 45, 5, 76, 7, 25, 8, 14, 2, 87, 3, 39, 0, 38, 1, 96, 
    8, 43, 0, 18, 3, 21, 7, 19, 5, 58, 1,  6, 4, 46, 6,  3, 2, 21
  };
  const int q9981[] = {
    9, 9, // Number of jobs and machines
    8,  2, 2, 63, 1, 41, 6, 66, 7, 94, 3, 31, 5, 23, 0, 90, 4, 14, 
    0, 11, 7, 70, 2, 87, 3, 62, 5, 97, 4, 19, 1, 83, 6,  5, 8, 28, 
    3, 80, 0, 71, 5, 14, 2, 75, 1,  4, 6, 13, 8, 17, 7, 45, 4, 36, 
    2, 81, 7, 53, 8, 18, 0, 41, 4, 27, 5, 36, 3,  3, 1, 70, 6, 57, 
    2, 81, 0, 59, 5, 70, 7, 53, 3, 14, 6, 29, 8, 54, 1, 85, 4, 85, 
    6, 75, 8, 76, 3,  9, 0, 44, 4, 12, 7, 92, 2, 16, 5, 23, 1, 10, 
    1, 22, 6, 60, 0, 87, 3, 79, 4, 94, 8, 27, 7, 61, 2, 48, 5, 76, 
    5, 69, 4,  7, 2, 96, 6, 41, 1, 49, 7, 36, 0, 40, 3, 31, 8, 26, 
    0,  2, 7, 68, 2, 30, 5, 11, 8, 71, 3, 59, 6, 81, 1, 46, 4, 33
  };
  const int q9982[] = {
    9, 9, // Number of jobs and machines
    7, 75, 3, 76, 2, 36, 1,  8, 6, 44, 0, 71, 4, 86, 5, 14, 8,  1, 
    7, 45, 4, 71, 2, 29, 1, 63, 8, 55, 0, 23, 5, 59, 3, 36, 6, 97, 
    8, 46, 1, 51, 5, 66, 2, 15, 4, 39, 7,  8, 6, 62, 3, 52, 0, 49, 
    7, 22, 8,  3, 2, 29, 6, 42, 4, 77, 1, 81, 0, 78, 5, 10, 3, 36, 
    0, 97, 7, 82, 4, 55, 8, 17, 2, 12, 5,  2, 1, 32, 6, 74, 3, 40, 
    1,  9, 5, 11, 7, 97, 2,  9, 8, 86, 4, 43, 3, 44, 0, 64, 6, 79, 
    2, 91, 0, 85, 3, 24, 7, 92, 8, 27, 4, 82, 6, 93, 5, 98, 1, 80, 
    2, 98, 3, 87, 5, 96, 8, 42, 6, 80, 1, 89, 4, 89, 7,  2, 0, 91, 
    2, 72, 4, 75, 8, 79, 7, 70, 6, 67, 5, 72, 3, 61, 1, 21, 0, 90
  };
  const int q9983[] = {
    9, 9, // Number of jobs and machines
    6, 29, 1,  1, 5, 57, 3, 27, 7, 28, 2, 27, 4, 86, 0, 96, 8, 86, 
    1, 82, 4, 31, 2, 63, 7, 81, 5, 25, 0, 94, 3, 99, 6, 37, 8, 40, 
    5, 53, 6, 25, 1, 91, 0, 70, 8, 68, 3, 56, 7, 10, 4, 91, 2, 67, 
    1, 77, 2, 70, 8, 53, 6, 20, 0, 24, 7, 75, 5, 78, 3, 32, 4, 58, 
    0, 78, 3, 72, 5, 30, 7,  5, 6, 12, 8, 58, 4, 99, 2,  1, 1, 96, 
    0, 79, 1, 18, 7, 12, 2, 49, 8, 46, 6, 30, 5, 99, 3, 31, 4, 19, 
    3,  6, 2, 75, 7, 11, 8, 92, 5, 46, 1, 38, 0,  5, 4, 49, 6,  7, 
    2, 70, 6, 86, 4, 88, 5, 78, 3,  6, 8, 85, 7, 66, 0,  9, 1, 41, 
    8, 90, 3,  1, 6, 13, 7, 29, 5, 75, 2, 35, 4, 64, 1, 29, 0, 31
  };
  const int q9984[] = {
    9, 9, // Number of jobs and machines
    6, 75, 8, 55, 0, 91, 3, 18, 7, 64, 5, 19, 4,  5, 1, 90, 2, 78, 
    7, 16, 2, 25, 4, 88, 5, 76, 1, 53, 8, 52, 3, 62, 6, 93, 0, 64, 
    1, 58, 7, 62, 5, 49, 8,  5, 6, 82, 3, 73, 0,  4, 4, 21, 2, 13, 
    4, 94, 1, 83, 6, 59, 2, 14, 5, 36, 8,  2, 0, 18, 7, 55, 3, 81, 
    2, 20, 7, 20, 3, 85, 4, 21, 8, 68, 1, 45, 0, 94, 6, 39, 5, 70, 
    2, 54, 0, 99, 7, 53, 3, 84, 1, 31, 4, 65, 5, 70, 8, 31, 6, 82, 
    4, 15, 8, 77, 7, 70, 6, 19, 0, 96, 5, 29, 2, 49, 1, 37, 3, 12, 
    4, 58, 7, 36, 5, 13, 0, 75, 3, 68, 8, 91, 1,  3, 2, 37, 6, 18, 
    0, 31, 5, 71, 7, 64, 6, 36, 1, 12, 4, 28, 3, 16, 8,  2, 2, 95
  };
  const int q9985[] = {
    9, 9, // Number of jobs and machines
    3, 22, 6, 81, 8,  7, 7,  3, 0, 97, 1, 36, 4, 64, 2, 33, 5, 10, 
    8, 14, 1, 73, 2, 58, 4, 34, 0, 56, 6, 11, 3, 71, 5, 94, 7, 59, 
    5, 11, 7, 81, 3, 35, 4, 82, 2, 10, 8, 11, 6, 65, 0, 90, 1, 68, 
    0, 11, 2, 63, 4, 28, 6, 44, 5, 11, 1,  1, 7, 39, 8, 44, 3, 97, 
    1, 54, 6, 46, 4, 85, 2, 89, 3, 76, 0, 58, 5, 25, 7, 73, 8, 66, 
    3, 93, 8, 75, 7,  2, 6, 87, 1, 97, 0, 51, 2,  1, 5, 40, 4,  6, 
    3, 70, 0, 42, 7, 69, 6, 37, 4,  1, 8, 60, 2, 83, 1, 15, 5, 62, 
    7, 88, 3, 97, 4, 46, 0, 43, 5, 47, 2, 47, 1, 73, 8, 67, 6, 87, 
    1, 24, 5, 91, 0, 35, 4, 11, 2, 68, 8, 53, 6, 61, 7, 72, 3, 40
  };
  const int q9986[] = {
    9, 9, // Number of jobs and machines
    5, 67, 7, 80, 2, 43, 1, 46, 3, 29, 8,  8, 6,  2, 0, 50, 4, 30, 
    0, 92, 8, 91, 1, 79, 5,  9, 6,  6, 7, 66, 4, 95, 3,  9, 2, 33, 
    8, 80, 0, 98, 5, 44, 1, 70, 4, 31, 3, 85, 2,  6, 7, 54, 6, 50, 
    0, 74, 4, 90, 7, 94, 3, 89, 5, 40, 2, 40, 6,  8, 1, 96, 8, 57, 
    6, 23, 5, 49, 7, 36, 4, 40, 1, 39, 8, 91, 2, 83, 0, 64, 3, 28, 
    6, 97, 0, 82, 7, 31, 5, 28, 2, 92, 3, 39, 8, 91, 4, 84, 1, 65, 
    4,  7, 6, 72, 8, 65, 3, 21, 5, 87, 1, 65, 7, 26, 2, 84, 0, 20, 
    5, 69, 7, 10, 1, 52, 6, 66, 3, 52, 2, 26, 4, 43, 8, 26, 0, 75, 
    4, 96, 0, 97, 8, 50, 3, 34, 2, 42, 6, 86, 5, 79, 7, 76, 1, 62
  };
  const int q9987[] = {
    9, 9, // Number of jobs and machines
    2, 97, 8, 29, 3, 83, 5, 57, 7, 18, 4, 15, 0, 75, 1, 95, 6, 54, 
    2, 84, 3, 58, 7, 59, 8, 97, 6, 93, 1, 16, 4, 71, 0, 26, 5, 11, 
    3, 59, 0, 20, 7, 57, 4,  9, 8, 67, 2, 41, 5, 56, 1, 25, 6, 76, 
    8, 35, 2, 68, 3,  5, 5, 32, 6, 28, 1, 51, 7, 57, 0, 75, 4, 38, 
    5, 43, 2, 16, 4, 91, 0, 91, 7, 78, 3, 84, 1, 34, 8, 69, 6, 64, 
    3, 28, 6,  8, 0, 52, 4, 17, 2, 14, 5, 50, 8, 57, 7, 73, 1, 92, 
    8, 71, 7, 20, 4, 74, 1, 81, 3, 99, 2,  5, 0, 46, 5, 41, 6, 62, 
    6, 39, 1, 65, 5, 77, 4, 80, 0, 85, 7, 24, 3, 99, 8, 25, 2, 32, 
    2, 96, 4,  8, 7, 40, 0,  9, 3,  5, 6, 87, 1, 32, 8, 97, 5, 87
  };
  const int q9988[] = {
    9, 9, // Number of jobs and machines
    3, 64, 2,  9, 0, 89, 8, 35, 1, 52, 7, 26, 5, 71, 6, 31, 4, 25, 
    1,  4, 5,  1, 4, 74, 0, 62, 7,  1, 3, 57, 8, 25, 6, 94, 2, 31, 
    4, 87, 5, 51, 0, 62, 2, 31, 6, 78, 8, 18, 3,  9, 7,  2, 1, 89, 
    8, 96, 7, 98, 6, 51, 3, 87, 5, 43, 2, 99, 1, 60, 0, 29, 4, 96, 
    7, 95, 5, 52, 6, 81, 1, 70, 3, 18, 2, 14, 4,  7, 0, 82, 8, 52, 
    1, 75, 2, 49, 7, 96, 4, 74, 8, 19, 6, 89, 0, 28, 5, 31, 3, 73, 
    8, 45, 5, 94, 3, 27, 0, 78, 6, 78, 7, 33, 2, 79, 1, 34, 4, 46, 
    6, 28, 4, 98, 2, 35, 3, 37, 1, 79, 5, 58, 0, 48, 7, 23, 8, 68, 
    7, 59, 4, 39, 8, 70, 3, 97, 0, 10, 5, 94, 2, 72, 6, 96, 1, 80
  };
  const int q9989[] = {
    9, 9, // Number of jobs and machines
    1, 39, 7, 75, 0,  5, 6, 70, 4, 25, 5, 76, 3, 15, 8, 10, 2, 23, 
    1, 10, 2, 80, 4, 68, 6, 31, 8, 78, 3, 19, 7, 18, 5, 71, 0, 66, 
    1, 68, 2, 82, 7, 47, 3, 26, 0, 70, 8, 24, 5, 65, 4,  6, 6, 53, 
    6, 21, 7, 70, 0, 32, 8, 94, 1, 14, 5,  8, 4, 75, 2, 48, 3, 68, 
    4, 78, 6,  1, 7, 85, 5, 44, 1, 36, 8, 11, 0, 64, 2, 19, 3, 70, 
    1,  4, 4, 98, 7, 56, 2, 75, 3, 33, 0, 65, 5, 17, 6, 79, 8, 22, 
    8, 57, 5, 96, 2, 31, 7, 12, 3, 11, 6, 19, 1, 54, 4, 28, 0, 44, 
    3, 70, 4, 80, 1, 13, 7, 98, 6, 86, 8, 38, 5, 21, 2, 14, 0, 36, 
    3, 66, 1, 48, 0, 99, 7, 61, 5, 42, 6, 20, 8,  2, 2, 77, 4, 18
  };
  const int q9990[] = {
    9, 9, // Number of jobs and machines
    5, 61, 3, 96, 2, 34, 4, 56, 8, 96, 6, 67, 1, 41, 7, 46, 0, 42, 
    7, 76, 2, 79, 1, 27, 0, 92, 4, 97, 5, 31, 8, 27, 3, 58, 6,  1, 
    4,  2, 0, 75, 5, 98, 3, 31, 6,  6, 2, 97, 8,  4, 7, 31, 1, 73, 
    0, 70, 7, 34, 8, 18, 6,  1, 3, 66, 4, 66, 1, 82, 2, 54, 5, 16, 
    4, 89, 8, 85, 3, 46, 0, 39, 1, 46, 7, 38, 5, 75, 6,  5, 2, 15, 
    1, 61, 2, 40, 3, 35, 5, 65, 0, 40, 8, 46, 7, 35, 6, 20, 4, 84, 
    1, 73, 3, 50, 0, 66, 2, 39, 6, 80, 5, 43, 4, 99, 7, 73, 8, 19, 
    3, 21, 1, 85, 0, 66, 7, 12, 2, 75, 8, 23, 6, 11, 5, 38, 4, 15, 
    0, 40, 3, 67, 8, 53, 2, 82, 6, 90, 7, 77, 4, 59, 1,  1, 5, 22
  };
  const int q9991[] = {
    9, 9, // Number of jobs and machines
    1, 42, 7, 48, 3, 77, 5, 60, 6, 12, 8, 26, 0, 12, 2, 14, 4, 89, 
    7, 95, 6, 18, 1,  1, 8, 25, 4, 65, 0,  6, 2, 75, 5, 26, 3,  2, 
    4, 92, 2, 22, 7, 91, 0, 14, 8,  1, 5, 29, 1, 46, 3, 63, 6, 75, 
    8, 96, 2, 47, 0, 36, 3, 79, 5,  3, 7, 41, 1, 98, 4, 50, 6, 57, 
    7, 31, 8, 86, 2, 68, 1, 82, 6, 89, 4, 37, 0, 61, 3, 25, 5, 27, 
    2, 71, 0, 41, 7, 40, 8, 27, 1, 63, 3, 75, 4, 61, 6, 64, 5, 85, 
    4, 76, 3, 40, 7, 22, 8,  7, 6, 63, 5, 60, 2, 93, 1, 85, 0, 36, 
    1, 83, 3, 94, 5, 74, 6, 66, 2, 63, 7, 16, 0, 74, 4, 12, 8, 63, 
    1, 98, 5, 42, 0, 10, 7,  8, 6, 92, 3, 31, 2, 63, 4, 37, 8, 10
  };
  const int q9992[] = {
    9, 9, // Number of jobs and machines
    1, 93, 6, 52, 2, 31, 3, 18, 8, 42, 5, 55, 7, 28, 0, 11, 4,  6, 
    6, 41, 8, 22, 2, 97, 7, 92, 1, 45, 5, 48, 0, 78, 3, 92, 4,  6, 
    8, 49, 6, 66, 0, 77, 2, 76, 5, 74, 1, 43, 7, 19, 4, 87, 3, 15, 
    1, 81, 3, 38, 0, 78, 6, 82, 7, 85, 2, 63, 4,  5, 5, 34, 8, 28, 
    7, 62, 0, 16, 8, 39, 3, 39, 4, 78, 2, 37, 5, 91, 6, 93, 1, 90, 
    7, 15, 1, 30, 0, 48, 8,  7, 3, 40, 2, 88, 4, 48, 6, 53, 5, 31, 
    3, 31, 6, 31, 8, 19, 7, 29, 1, 11, 0, 70, 2, 91, 4, 22, 5, 99, 
    6, 95, 0, 80, 1, 40, 8, 21, 4, 64, 7, 89, 5, 87, 2, 22, 3, 53, 
    8, 48, 3, 32, 1,  5, 4, 93, 6, 81, 5, 74, 7, 99, 0, 98, 2, 86
  };
  const int q9993[] = {
    9, 9, // Number of jobs and machines
    5, 59, 7, 69, 1, 94, 3, 99, 8, 67, 6, 33, 2, 95, 0,  6, 4, 82, 
    3, 40, 7, 62, 5, 69, 6, 63, 0, 31, 1, 93, 4, 79, 2, 28, 8, 69, 
    0, 56, 8, 54, 1, 33, 3,  9, 6, 63, 2, 39, 5, 43, 7, 49, 4, 23, 
    4, 34, 6, 89, 2, 20, 7, 21, 3, 14, 1, 78, 5, 81, 8, 81, 0, 57, 
    2, 10, 7, 61, 8,  3, 5, 31, 4, 13, 0, 87, 1, 95, 6, 40, 3, 46, 
    8, 98, 6, 69, 3,  7, 4, 35, 7,  8, 5, 12, 2, 94, 0, 35, 1, 17, 
    3, 48, 8, 41, 2, 42, 4,  2, 5, 31, 7, 90, 0, 37, 6, 40, 1, 26, 
    3, 61, 0, 18, 4, 19, 8, 89, 1, 87, 6, 67, 5, 45, 7, 75, 2, 51, 
    7, 20, 5, 32, 6, 10, 0, 60, 1, 60, 3, 18, 4,  2, 8, 23, 2, 38
  };
  const int q9994[] = {
    9, 9, // Number of jobs and machines
    7, 45, 5, 60, 3, 50, 1, 54, 0, 15, 2,  6, 4, 28, 8, 28, 6, 35, 
    5, 73, 4, 88, 3, 88, 6, 91, 7, 50, 8, 23, 2, 50, 1, 10, 0, 71, 
    7, 86, 3, 88, 0, 24, 6, 68, 5, 57, 8,  4, 4, 55, 2, 50, 1, 41, 
    3, 29, 1, 64, 2, 27, 5, 47, 6,  3, 8, 49, 0, 94, 7, 16, 4, 15, 
    2, 94, 4, 46, 0, 97, 1, 25, 6, 90, 7, 78, 3, 46, 5, 82, 8, 25, 
    4, 51, 0, 10, 2, 79, 3, 28, 8, 38, 7, 20, 1, 44, 6, 93, 5, 59, 
    8, 78, 3, 67, 0, 68, 7, 88, 2, 38, 4, 33, 1, 19, 5, 91, 6, 32, 
    1, 46, 4, 34, 2, 37, 8, 66, 6, 13, 3, 58, 7, 39, 0, 33, 5, 76, 
    8, 56, 1, 54, 3, 44, 2, 67, 5, 80, 0, 74, 6, 33, 7, 11, 4, 26
  };
  const int q9995[] = {
    9, 9, // Number of jobs and machines
    7, 65, 8, 82, 5, 17, 4, 99, 3, 38, 2, 91, 6, 61, 1, 99, 0, 38, 
    0, 10, 8, 75, 3,  5, 1, 16, 6, 25, 2, 52, 5,  7, 4, 32, 7, 74, 
    8, 24, 0, 53, 7, 43, 1, 57, 3, 61, 6, 29, 5, 72, 4, 67, 2, 72, 
    8, 16, 3, 45, 0, 17, 2, 41, 5, 56, 6, 49, 7, 35, 1, 94, 4, 19, 
    0, 39, 8, 84, 6, 91, 5, 50, 2,  1, 4, 15, 3, 83, 7, 11, 1, 22, 
    4, 14, 0, 56, 3,  4, 8, 17, 6, 15, 2, 29, 5, 32, 7, 91, 1,  3, 
    1, 56, 2, 53, 6, 32, 0, 80, 3, 56, 8, 58, 7, 30, 4, 78, 5, 71, 
    2, 84, 5, 31, 4, 54, 6,  3, 0, 37, 1, 87, 8, 17, 7, 76, 3, 38, 
    3, 20, 0, 56, 5,  3, 2, 68, 1,  4, 8, 55, 7, 62, 4, 63, 6, 60
  };
  const int q9996[] = {
    9, 9, // Number of jobs and machines
    0, 87, 5, 84, 8, 73, 6,  8, 2, 92, 4, 70, 3, 51, 7, 29, 1, 81, 
    0, 83, 6, 67, 2, 71, 5, 61, 4, 54, 3, 11, 8, 67, 7, 95, 1, 89, 
    0, 29, 7, 66, 4, 64, 5, 32, 2, 99, 3, 13, 8, 70, 6,  2, 1, 65, 
    4, 55, 8, 69, 7,  8, 1, 14, 5, 90, 0, 62, 3, 72, 2, 45, 6, 54, 
    5, 36, 6, 53, 3, 88, 1, 87, 0, 13, 8, 44, 7, 51, 4, 29, 2, 55, 
    7, 10, 8, 32, 0, 42, 4, 24, 3,  3, 5, 71, 1, 35, 2, 73, 6, 59, 
    3,  8, 5, 73, 4, 98, 0, 41, 1, 72, 8, 51, 6, 91, 7, 77, 2, 29, 
    3, 15, 2, 61, 1, 45, 0, 13, 8, 90, 6, 53, 7,  8, 5, 13, 4, 24, 
    4, 59, 8, 36, 6, 29, 0, 15, 1, 61, 3, 71, 2, 29, 5,  1, 7, 46
  };
  const int q9997[] = {
    9, 9, // Number of jobs and machines
    8, 61, 2, 15, 3, 97, 0, 23, 1, 18, 7, 61, 5, 57, 4, 14, 6, 57, 
    8, 78, 7, 67, 3, 24, 6, 46, 0, 30, 2,  6, 4, 42, 1, 49, 5, 74, 
    8, 41, 2, 74, 1, 81, 7, 62, 0, 35, 5, 14, 4, 16, 6, 22, 3, 68, 
    0, 73, 3, 55, 8, 81, 1, 82, 7, 41, 4, 57, 6, 78, 5, 94, 2,  7, 
    2, 97, 8, 80, 6, 58, 7, 97, 4, 20, 0, 54, 1,  9, 3, 45, 5, 24, 
    5, 10, 6, 75, 4, 19, 1,  1, 2,  5, 3, 36, 8, 74, 7, 15, 0,  6, 
    3, 10, 2, 54, 7, 43, 1, 57, 6, 83, 0, 24, 8, 23, 5, 87, 4, 87, 
    2, 24, 5, 46, 0, 58, 3, 63, 1, 68, 4, 77, 8, 81, 6,  1, 7, 64, 
    6,  9, 3, 31, 1, 15, 0, 82, 4, 50, 8, 84, 7, 33, 5, 59, 2,  5
  };
  const int q9998[] = {
    9, 9, // Number of jobs and machines
    8, 54, 7, 24, 3, 25, 5, 61, 0,  2, 2,  9, 6, 52, 1, 81, 4, 68, 
    7, 98, 0, 28, 1, 86, 3, 84, 6, 93, 5,  8, 2, 21, 4, 28, 8, 22, 
    7, 65, 0, 15, 6, 37, 3, 54, 8,  3, 1, 16, 2,  8, 5, 73, 4, 68, 
    2, 85, 8, 48, 6, 37, 5, 40, 1, 61, 0, 86, 4, 60, 7, 11, 3, 25, 
    1, 45, 2, 81, 5, 85, 7,  4, 8, 80, 4, 71, 0, 67, 6, 76, 3, 22, 
    3, 37, 4, 66, 1, 91, 2, 40, 5, 26, 8, 43, 6,  7, 0, 53, 7, 40, 
    7, 29, 0, 23, 3, 47, 6, 95, 1, 11, 2, 12, 5, 51, 4,  6, 8, 47, 
    2, 44, 3, 79, 4, 26, 7,  8, 8, 57, 1, 90, 5, 14, 6, 59, 0, 85, 
    6,  3, 3, 90, 0, 30, 7, 83, 2, 30, 4, 65, 5, 14, 8, 76, 1, 14
  };
  const int q9999[] = {
    9, 9, // Number of jobs and machines
    3, 30, 7, 48, 0, 24, 8, 50, 2, 56, 6, 60, 1, 89, 5,  6, 4, 58, 
    7,  2, 2,  7, 8, 16, 5, 48, 6, 81, 0, 93, 3, 64, 4, 58, 1,  3, 
    7, 48, 8, 36, 4, 25, 3, 46, 6, 87, 5, 22, 2, 89, 1, 96, 0, 71, 
    6,  5, 7,  6, 1, 74, 8, 99, 3, 98, 2, 69, 5, 84, 0, 70, 4,  8, 
    7, 70, 1, 41, 2, 85, 8, 79, 0,  4, 6, 57, 5, 47, 3, 87, 4, 59, 
    4, 64, 2, 10, 6, 42, 1, 91, 7, 45, 8, 36, 0, 48, 5, 57, 3, 71, 
    6, 37, 4, 32, 5, 24, 3, 96, 7, 66, 8, 41, 2, 55, 0, 21, 1, 80, 
    0, 15, 7, 31, 4, 21, 1, 80, 8, 19, 6, 10, 2, 37, 3, 74, 5, 45, 
    6, 70, 7, 13, 5, 98, 4, 55, 1, 48, 2,  6, 3, 49, 0,  7, 8, 24
  };


  const int* js[] = {
    &abz5[0], &abz6[0], &abz7[0], &abz8[0], &abz9[0],
    &ft06[0], &ft10[0], &ft20[0],
    &la01[0], &la02[0], &la03[0], &la04[0], &la05[0], &la06[0], &la07[0], &la08[0],
    &la09[0], &la10[0], &la11[0], &la12[0], &la13[0], &la14[0], &la15[0], &la16[0],
    &la17[0], &la18[0], &la19[0], &la20[0], &la21[0], &la22[0], &la23[0], &la24[0],
    &la25[0], &la26[0], &la27[0], &la28[0], &la29[0], &la30[0], &la31[0], &la32[0],
    &la33[0], &la34[0], &la35[0], &la36[0], &la37[0], &la38[0], &la39[0], &la40[0],
    &orb01[0], &orb02[0], &orb03[0], &orb04[0], &orb05[0],
    &orb06[0], &orb07[0], &orb08[0], &orb09[0], &orb10[0],
    &swv01[0], &swv02[0], &swv03[0], &swv04[0], &swv05[0],
    &swv06[0], &swv07[0], &swv08[0], &swv09[0], &swv10[0],
    &swv11[0], &swv12[0], &swv13[0], &swv14[0], &swv15[0],
    &swv16[0], &swv17[0], &swv18[0], &swv19[0], &swv20[0],
    &yn1[0], &yn2[0], &yn3[0], &yn4[0],
    &tai_15_15_0[0], &tai_15_15_1[0], &tai_15_15_2[0], &tai_15_15_3[0],
    &tai_15_15_4[0], &tai_15_15_5[0], &tai_15_15_6[0], &tai_15_15_7[0],
    &tai_15_15_8[0], &tai_15_15_9[0],
    &tai_20_15_0[0], &tai_20_15_1[0], &tai_20_15_2[0], &tai_20_15_3[0],
    &tai_20_15_4[0], &tai_20_15_5[0], &tai_20_15_6[0], &tai_20_15_7[0],
    &tai_20_15_8[0], &tai_20_15_9[0],
    &tai_20_20_0[0], &tai_20_20_1[0], &tai_20_20_2[0], &tai_20_20_3[0],
    &tai_20_20_4[0], &tai_20_20_5[0], &tai_20_20_6[0], &tai_20_20_7[0],
    &tai_20_20_8[0], &tai_20_20_9[0],
    &tai_30_15_0[0], &tai_30_15_1[0], &tai_30_15_2[0], &tai_30_15_3[0],
    &tai_30_15_4[0], &tai_30_15_5[0], &tai_30_15_6[0], &tai_30_15_7[0],
    &tai_30_15_8[0], &tai_30_15_9[0],
    &tai_30_20_0[0], &tai_30_20_1[0], &tai_30_20_2[0], &tai_30_20_3[0],
    &tai_30_20_4[0], &tai_30_20_5[0], &tai_30_20_6[0], &tai_30_20_7[0],
    &tai_30_20_8[0], &tai_30_20_9[0],
    &tai_50_15_0[0], &tai_50_15_1[0], &tai_50_15_2[0], &tai_50_15_3[0],
    &tai_50_15_4[0], &tai_50_15_5[0], &tai_50_15_6[0], &tai_50_15_7[0],
    &tai_50_15_8[0], &tai_50_15_9[0],
    &tai_50_20_0[0], &tai_50_20_1[0], &tai_50_20_2[0], &tai_50_20_3[0],
    &tai_50_20_4[0], &tai_50_20_5[0], &tai_50_20_6[0], &tai_50_20_7[0],
    &tai_50_20_8[0], &tai_50_20_9[0],
    &tai_100_20_0[0], &tai_100_20_1[0], &tai_100_20_2[0], &tai_100_20_3[0],
    &tai_100_20_4[0], &tai_100_20_5[0], &tai_100_20_6[0], &tai_100_20_7[0],
    &tai_100_20_8[0], &tai_100_20_9[0],
    &r000[0], &r001[0], &r002[0], &r003[0], &r004[0], &r005[0], &r006[0], &r007[0], 
    &r008[0], &r009[0], &r010[0], &r011[0], &r012[0], &r013[0], &r014[0], &r015[0], 
    &r016[0], &r017[0], &r018[0], &r019[0], &r020[0], &r021[0], &r022[0], &r023[0], 
    &r024[0], &r025[0], &r026[0], &r027[0], &r028[0], &r029[0], &r030[0], &r031[0], 
    &r032[0], &r033[0], &r034[0], &r035[0], &r036[0], &r037[0], &r038[0], &r039[0], 
    &r040[0], &r041[0], &r042[0], &r043[0], &r044[0], &r045[0], &r046[0], &r047[0], 
    &r048[0], &r049[0], &r050[0], &r051[0], &r052[0], &r053[0], &r054[0], &r055[0], 
    &r056[0], &r057[0], &r058[0], &r059[0], &r060[0], &r061[0], &r062[0], &r063[0], 
    &r064[0], &r065[0], &r066[0], &r067[0], &r068[0], &r069[0], &r070[0], &r071[0], 
    &r072[0], &r073[0], &r074[0], &r075[0], &r076[0], &r077[0], &r078[0], &r079[0], 
    &r080[0], &r081[0], &r082[0], &r083[0], &r084[0], &r085[0], &r086[0], &r087[0], 
    &r088[0], &r089[0], &r090[0], &r091[0], &r092[0], &r093[0], &r094[0], &r095[0], 
    &r096[0], &r097[0], &r098[0], &r099[0], &r100[0], &r101[0], &r102[0], &r103[0], 
    &r104[0], &r105[0], &r106[0], &r107[0], &r108[0], &r109[0], &r110[0], &r111[0], 
    &r112[0], &r113[0], &r114[0], &r115[0], &r116[0], &r117[0], &r118[0], &r119[0], 
    &r120[0], &r121[0], &r122[0], &r123[0], &r124[0], &r125[0], &r126[0], &r127[0], 
    &r128[0], &r129[0], &r130[0], &r131[0], &r132[0], &r133[0], &r134[0], &r135[0], 
    &r136[0], &r137[0], &r138[0], &r139[0], &r140[0], &r141[0], &r142[0], &r143[0], 
    &r144[0], &r145[0], &r146[0], &r147[0], &r148[0], &r149[0], &r150[0], &r151[0], 
    &r152[0], &r153[0], &r154[0], &r155[0], &r156[0], &r157[0], &r158[0], &r159[0], 
    &r160[0], &r161[0], &r162[0], &r163[0], &r164[0], &r165[0], &r166[0], &r167[0], 
    &r168[0], &r169[0], &r170[0], &r171[0], &r172[0], &r173[0], &r174[0], &r175[0], 
    &r176[0], &r177[0], &r178[0], &r179[0], &r180[0], &r181[0], &r182[0], &r183[0], 
    &r184[0], &r185[0], &r186[0], &r187[0], &r188[0], &r189[0], &r190[0], &r191[0], 
    &r192[0], &r193[0], &r194[0], &r195[0], &r196[0], &r197[0], &r198[0], &r199[0], 
    &r200[0], &r201[0], &r202[0], &r203[0], &r204[0], &r205[0], &r206[0], &r207[0], 
    &r208[0], &r209[0], &r210[0], &r211[0], &r212[0], &r213[0], &r214[0], &r215[0], 
    &r216[0], &r217[0], &r218[0], &r219[0], &r220[0], &r221[0], &r222[0], &r223[0], 
    &r224[0], &r225[0], &r226[0], &r227[0], &r228[0], &r229[0], &r230[0], &r231[0], 
    &r232[0], &r233[0], &r234[0], &r235[0], &r236[0], &r237[0], &r238[0], &r239[0], 
    &r240[0], &r241[0], &r242[0], &r243[0], &r244[0], &r245[0], &r246[0], &r247[0], 
    &r248[0], &r249[0], &r250[0], &r251[0], &r252[0], &r253[0], &r254[0], &r255[0], 
    &r256[0], &r257[0], &r258[0], &r259[0], &r260[0], &r261[0], &r262[0], &r263[0], 
    &r264[0], &r265[0], &r266[0], &r267[0], &r268[0], &r269[0], &r270[0], &r271[0], 
    &r272[0], &r273[0], &r274[0], &r275[0], &r276[0], &r277[0], &r278[0], &r279[0], 
    &r280[0], &r281[0], &r282[0], &r283[0], &r284[0], &r285[0], &r286[0], &r287[0], 
    &r288[0], &r289[0], &r290[0], &r291[0], &r292[0], &r293[0], &r294[0], &r295[0], 
    &r296[0], &r297[0], &r298[0], &r299[0], &r300[0], &r301[0], &r302[0], &r303[0], 
    &r304[0], &r305[0], &r306[0], &r307[0], &r308[0], &r309[0], &r310[0], &r311[0], 
    &r312[0], &r313[0], &r314[0], &r315[0], &r316[0], &r317[0], &r318[0], &r319[0], 
    &r320[0], &r321[0], &r322[0], &r323[0], &r324[0], &r325[0], &r326[0], &r327[0], 
    &r328[0], &r329[0], &r330[0], &r331[0], &r332[0], &r333[0], &r334[0], &r335[0], 
    &r336[0], &r337[0], &r338[0], &r339[0], &r340[0], &r341[0], &r342[0], &r343[0], 
    &r344[0], &r345[0], &r346[0], &r347[0], &r348[0], &r349[0], &r350[0], &r351[0], 
    &r352[0], &r353[0], &r354[0], &r355[0], &r356[0], &r357[0], &r358[0], &r359[0], 
    &r360[0], &r361[0], &r362[0], &r363[0], &r364[0], &r365[0], &r366[0], &r367[0], 
    &r368[0], &r369[0], &r370[0], &r371[0], &r372[0], &r373[0], &r374[0], &r375[0], 
    &r376[0], &r377[0], &r378[0], &r379[0], &r380[0], &r381[0], &r382[0], &r383[0], 
    &r384[0], &r385[0], &r386[0], &r387[0], &r388[0], &r389[0], &r390[0], &r391[0], 
    &r392[0], &r393[0], &r394[0], &r395[0], &r396[0], &r397[0], &r398[0], &r399[0], 
    &r400[0], &r401[0], &r402[0], &r403[0], &r404[0], &r405[0], &r406[0], &r407[0], 
    &r408[0], &r409[0], &r410[0], &r411[0], &r412[0], &r413[0], &r414[0], &r415[0], 
    &r416[0], &r417[0], &r418[0], &r419[0], &r420[0], &r421[0], &r422[0], &r423[0], 
    &r424[0], &r425[0], &r426[0], &r427[0], &r428[0], &r429[0], &r430[0], &r431[0], 
    &r432[0], &r433[0], &r434[0], &r435[0], &r436[0], &r437[0], &r438[0], &r439[0], 
    &r440[0], &r441[0], &r442[0], &r443[0], &r444[0], &r445[0], &r446[0], &r447[0], 
    &r448[0], &r449[0], &r450[0], &r451[0], &r452[0], &r453[0], &r454[0], &r455[0], 
    &r456[0], &r457[0], &r458[0], &r459[0], &r460[0], &r461[0], &r462[0], &r463[0], 
    &r464[0], &r465[0], &r466[0], &r467[0], &r468[0], &r469[0], &r470[0], &r471[0], 
    &r472[0], &r473[0], &r474[0], &r475[0], &r476[0], &r477[0], &r478[0], &r479[0], 
    &r480[0], &r481[0], &r482[0], &r483[0], &r484[0], &r485[0], &r486[0], &r487[0], 
    &r488[0], &r489[0], &r490[0], &r491[0], &r492[0], &r493[0], &r494[0], &r495[0], 
    &r496[0], &r497[0], &r498[0], &r499[0], &r500[0], &r501[0], &r502[0], &r503[0], 
    &r504[0], &r505[0], &r506[0], &r507[0], &r508[0], &r509[0], &r510[0], &r511[0], 
    &r512[0], &r513[0], &r514[0], &r515[0], &r516[0], &r517[0], &r518[0], &r519[0], 
    &r520[0], &r521[0], &r522[0], &r523[0], &r524[0], &r525[0], &r526[0], &r527[0], 
    &r528[0], &r529[0], &r530[0], &r531[0], &r532[0], &r533[0], &r534[0], &r535[0], 
    &r536[0], &r537[0], &r538[0], &r539[0], &r540[0], &r541[0], &r542[0], &r543[0], 
    &r544[0], &r545[0], &r546[0], &r547[0], &r548[0], &r549[0], &r550[0], &r551[0], 
    &r552[0], &r553[0], &r554[0], &r555[0], &r556[0], &r557[0], &r558[0], &r559[0], 
    &r560[0], &r561[0], &r562[0], &r563[0], &r564[0], &r565[0], &r566[0], &r567[0], 
    &r568[0], &r569[0], &r570[0], &r571[0], &r572[0], &r573[0], &r574[0], &r575[0], 
    &r576[0], &r577[0], &r578[0], &r579[0], &r580[0], &r581[0], &r582[0], &r583[0], 
    &r584[0], &r585[0], &r586[0], &r587[0], &r588[0], &r589[0], &r590[0], &r591[0], 
    &r592[0], &r593[0], &r594[0], &r595[0], &r596[0], &r597[0], &r598[0], &r599[0], 
    &r600[0], &r601[0], &r602[0], &r603[0], &r604[0], &r605[0], &r606[0], &r607[0], 
    &r608[0], &r609[0], &r610[0], &r611[0], &r612[0], &r613[0], &r614[0], &r615[0], 
    &r616[0], &r617[0], &r618[0], &r619[0], &r620[0], &r621[0], &r622[0], &r623[0], 
    &r624[0], &r625[0], &r626[0], &r627[0], &r628[0], &r629[0], &r630[0], &r631[0], 
    &r632[0], &r633[0], &r634[0], &r635[0], &r636[0], &r637[0], &r638[0], &r639[0], 
    &r640[0], &r641[0], &r642[0], &r643[0], &r644[0], &r645[0], &r646[0], &r647[0], 
    &r648[0], &r649[0], &r650[0], &r651[0], &r652[0], &r653[0], &r654[0], &r655[0], 
    &r656[0], &r657[0], &r658[0], &r659[0], &r660[0], &r661[0], &r662[0], &r663[0], 
    &r664[0], &r665[0], &r666[0], &r667[0], &r668[0], &r669[0], &r670[0], &r671[0], 
    &r672[0], &r673[0], &r674[0], &r675[0], &r676[0], &r677[0], &r678[0], &r679[0], 
    &r680[0], &r681[0], &r682[0], &r683[0], &r684[0], &r685[0], &r686[0], &r687[0], 
    &r688[0], &r689[0], &r690[0], &r691[0], &r692[0], &r693[0], &r694[0], &r695[0], 
    &r696[0], &r697[0], &r698[0], &r699[0], &r700[0], &r701[0], &r702[0], &r703[0], 
    &r704[0], &r705[0], &r706[0], &r707[0], &r708[0], &r709[0], &r710[0], &r711[0], 
    &r712[0], &r713[0], &r714[0], &r715[0], &r716[0], &r717[0], &r718[0], &r719[0], 
    &r720[0], &r721[0], &r722[0], &r723[0], &r724[0], &r725[0], &r726[0], &r727[0], 
    &r728[0], &r729[0], &r730[0], &r731[0], &r732[0], &r733[0], &r734[0], &r735[0], 
    &r736[0], &r737[0], &r738[0], &r739[0], &r740[0], &r741[0], &r742[0], &r743[0], 
    &r744[0], &r745[0], &r746[0], &r747[0], &r748[0], &r749[0], &r750[0], &r751[0], 
    &r752[0], &r753[0], &r754[0], &r755[0], &r756[0], &r757[0], &r758[0], &r759[0], 
    &r760[0], &r761[0], &r762[0], &r763[0], &r764[0], &r765[0], &r766[0], &r767[0], 
    &r768[0], &r769[0], &r770[0], &r771[0], &r772[0], &r773[0], &r774[0], &r775[0], 
    &r776[0], &r777[0], &r778[0], &r779[0], &r780[0], &r781[0], &r782[0], &r783[0], 
    &r784[0], &r785[0], &r786[0], &r787[0], &r788[0], &r789[0], &r790[0], &r791[0], 
    &r792[0], &r793[0], &r794[0], &r795[0], &r796[0], &r797[0], &r798[0], &r799[0], 
    &r800[0], &r801[0], &r802[0], &r803[0], &r804[0], &r805[0], &r806[0], &r807[0], 
    &r808[0], &r809[0], &r810[0], &r811[0], &r812[0], &r813[0], &r814[0], &r815[0], 
    &r816[0], &r817[0], &r818[0], &r819[0], &r820[0], &r821[0], &r822[0], &r823[0], 
    &r824[0], &r825[0], &r826[0], &r827[0], &r828[0], &r829[0], &r830[0], &r831[0], 
    &r832[0], &r833[0], &r834[0], &r835[0], &r836[0], &r837[0], &r838[0], &r839[0], 
    &r840[0], &r841[0], &r842[0], &r843[0], &r844[0], &r845[0], &r846[0], &r847[0], 
    &r848[0], &r849[0], &r850[0], &r851[0], &r852[0], &r853[0], &r854[0], &r855[0], 
    &r856[0], &r857[0], &r858[0], &r859[0], &r860[0], &r861[0], &r862[0], &r863[0], 
    &r864[0], &r865[0], &r866[0], &r867[0], &r868[0], &r869[0], &r870[0], &r871[0], 
    &r872[0], &r873[0], &r874[0], &r875[0], &r876[0], &r877[0], &r878[0], &r879[0], 
    &r880[0], &r881[0], &r882[0], &r883[0], &r884[0], &r885[0], &r886[0], &r887[0], 
    &r888[0], &r889[0], &r890[0], &r891[0], &r892[0], &r893[0], &r894[0], &r895[0], 
    &r896[0], &r897[0], &r898[0], &r899[0], &r900[0], &r901[0], &r902[0], &r903[0], 
    &r904[0], &r905[0], &r906[0], &r907[0], &r908[0], &r909[0], &r910[0], &r911[0], 
    &r912[0], &r913[0], &r914[0], &r915[0], &r916[0], &r917[0], &r918[0], &r919[0], 
    &r920[0], &r921[0], &r922[0], &r923[0], &r924[0], &r925[0], &r926[0], &r927[0], 
    &r928[0], &r929[0], &r930[0], &r931[0], &r932[0], &r933[0], &r934[0], &r935[0], 
    &r936[0], &r937[0], &r938[0], &r939[0], &r940[0], &r941[0], &r942[0], &r943[0], 
    &r944[0], &r945[0], &r946[0], &r947[0], &r948[0], &r949[0], &r950[0], &r951[0], 
    &r952[0], &r953[0], &r954[0], &r955[0], &r956[0], &r957[0], &r958[0], &r959[0], 
    &r960[0], &r961[0], &r962[0], &r963[0], &r964[0], &r965[0], &r966[0], &r967[0], 
    &r968[0], &r969[0], &r970[0], &r971[0], &r972[0], &r973[0], &r974[0], &r975[0], 
    &r976[0], &r977[0], &r978[0], &r979[0], &r980[0], &r981[0], &r982[0], &r983[0], 
    &r984[0], &r985[0], &r986[0], &r987[0], &r988[0], &r989[0], &r990[0], &r991[0], 
    &r992[0], &r993[0], &r994[0], &r995[0], &r996[0], &r997[0], &r998[0], &r999[0],
    &q0000[0], &q0001[0], &q0002[0], &q0003[0], &q0004[0], &q0005[0], &q0006[0], &q0007[0], 
    &q0008[0], &q0009[0], &q0010[0], &q0011[0], &q0012[0], &q0013[0], &q0014[0], &q0015[0], 
    &q0016[0], &q0017[0], &q0018[0], &q0019[0], &q0020[0], &q0021[0], &q0022[0], &q0023[0], 
    &q0024[0], &q0025[0], &q0026[0], &q0027[0], &q0028[0], &q0029[0], &q0030[0], &q0031[0], 
    &q0032[0], &q0033[0], &q0034[0], &q0035[0], &q0036[0], &q0037[0], &q0038[0], &q0039[0], 
    &q0040[0], &q0041[0], &q0042[0], &q0043[0], &q0044[0], &q0045[0], &q0046[0], &q0047[0], 
    &q0048[0], &q0049[0], &q0050[0], &q0051[0], &q0052[0], &q0053[0], &q0054[0], &q0055[0], 
    &q0056[0], &q0057[0], &q0058[0], &q0059[0], &q0060[0], &q0061[0], &q0062[0], &q0063[0], 
    &q0064[0], &q0065[0], &q0066[0], &q0067[0], &q0068[0], &q0069[0], &q0070[0], &q0071[0], 
    &q0072[0], &q0073[0], &q0074[0], &q0075[0], &q0076[0], &q0077[0], &q0078[0], &q0079[0], 
    &q0080[0], &q0081[0], &q0082[0], &q0083[0], &q0084[0], &q0085[0], &q0086[0], &q0087[0], 
    &q0088[0], &q0089[0], &q0090[0], &q0091[0], &q0092[0], &q0093[0], &q0094[0], &q0095[0], 
    &q0096[0], &q0097[0], &q0098[0], &q0099[0], &q0100[0], &q0101[0], &q0102[0], &q0103[0], 
    &q0104[0], &q0105[0], &q0106[0], &q0107[0], &q0108[0], &q0109[0], &q0110[0], &q0111[0], 
    &q0112[0], &q0113[0], &q0114[0], &q0115[0], &q0116[0], &q0117[0], &q0118[0], &q0119[0], 
    &q0120[0], &q0121[0], &q0122[0], &q0123[0], &q0124[0], &q0125[0], &q0126[0], &q0127[0], 
    &q0128[0], &q0129[0], &q0130[0], &q0131[0], &q0132[0], &q0133[0], &q0134[0], &q0135[0], 
    &q0136[0], &q0137[0], &q0138[0], &q0139[0], &q0140[0], &q0141[0], &q0142[0], &q0143[0], 
    &q0144[0], &q0145[0], &q0146[0], &q0147[0], &q0148[0], &q0149[0], &q0150[0], &q0151[0], 
    &q0152[0], &q0153[0], &q0154[0], &q0155[0], &q0156[0], &q0157[0], &q0158[0], &q0159[0], 
    &q0160[0], &q0161[0], &q0162[0], &q0163[0], &q0164[0], &q0165[0], &q0166[0], &q0167[0], 
    &q0168[0], &q0169[0], &q0170[0], &q0171[0], &q0172[0], &q0173[0], &q0174[0], &q0175[0], 
    &q0176[0], &q0177[0], &q0178[0], &q0179[0], &q0180[0], &q0181[0], &q0182[0], &q0183[0], 
    &q0184[0], &q0185[0], &q0186[0], &q0187[0], &q0188[0], &q0189[0], &q0190[0], &q0191[0], 
    &q0192[0], &q0193[0], &q0194[0], &q0195[0], &q0196[0], &q0197[0], &q0198[0], &q0199[0], 
    &q0200[0], &q0201[0], &q0202[0], &q0203[0], &q0204[0], &q0205[0], &q0206[0], &q0207[0], 
    &q0208[0], &q0209[0], &q0210[0], &q0211[0], &q0212[0], &q0213[0], &q0214[0], &q0215[0], 
    &q0216[0], &q0217[0], &q0218[0], &q0219[0], &q0220[0], &q0221[0], &q0222[0], &q0223[0], 
    &q0224[0], &q0225[0], &q0226[0], &q0227[0], &q0228[0], &q0229[0], &q0230[0], &q0231[0], 
    &q0232[0], &q0233[0], &q0234[0], &q0235[0], &q0236[0], &q0237[0], &q0238[0], &q0239[0], 
    &q0240[0], &q0241[0], &q0242[0], &q0243[0], &q0244[0], &q0245[0], &q0246[0], &q0247[0], 
    &q0248[0], &q0249[0], &q0250[0], &q0251[0], &q0252[0], &q0253[0], &q0254[0], &q0255[0], 
    &q0256[0], &q0257[0], &q0258[0], &q0259[0], &q0260[0], &q0261[0], &q0262[0], &q0263[0], 
    &q0264[0], &q0265[0], &q0266[0], &q0267[0], &q0268[0], &q0269[0], &q0270[0], &q0271[0], 
    &q0272[0], &q0273[0], &q0274[0], &q0275[0], &q0276[0], &q0277[0], &q0278[0], &q0279[0], 
    &q0280[0], &q0281[0], &q0282[0], &q0283[0], &q0284[0], &q0285[0], &q0286[0], &q0287[0], 
    &q0288[0], &q0289[0], &q0290[0], &q0291[0], &q0292[0], &q0293[0], &q0294[0], &q0295[0], 
    &q0296[0], &q0297[0], &q0298[0], &q0299[0], &q0300[0], &q0301[0], &q0302[0], &q0303[0], 
    &q0304[0], &q0305[0], &q0306[0], &q0307[0], &q0308[0], &q0309[0], &q0310[0], &q0311[0], 
    &q0312[0], &q0313[0], &q0314[0], &q0315[0], &q0316[0], &q0317[0], &q0318[0], &q0319[0], 
    &q0320[0], &q0321[0], &q0322[0], &q0323[0], &q0324[0], &q0325[0], &q0326[0], &q0327[0], 
    &q0328[0], &q0329[0], &q0330[0], &q0331[0], &q0332[0], &q0333[0], &q0334[0], &q0335[0], 
    &q0336[0], &q0337[0], &q0338[0], &q0339[0], &q0340[0], &q0341[0], &q0342[0], &q0343[0], 
    &q0344[0], &q0345[0], &q0346[0], &q0347[0], &q0348[0], &q0349[0], &q0350[0], &q0351[0], 
    &q0352[0], &q0353[0], &q0354[0], &q0355[0], &q0356[0], &q0357[0], &q0358[0], &q0359[0], 
    &q0360[0], &q0361[0], &q0362[0], &q0363[0], &q0364[0], &q0365[0], &q0366[0], &q0367[0], 
    &q0368[0], &q0369[0], &q0370[0], &q0371[0], &q0372[0], &q0373[0], &q0374[0], &q0375[0], 
    &q0376[0], &q0377[0], &q0378[0], &q0379[0], &q0380[0], &q0381[0], &q0382[0], &q0383[0], 
    &q0384[0], &q0385[0], &q0386[0], &q0387[0], &q0388[0], &q0389[0], &q0390[0], &q0391[0], 
    &q0392[0], &q0393[0], &q0394[0], &q0395[0], &q0396[0], &q0397[0], &q0398[0], &q0399[0], 
    &q0400[0], &q0401[0], &q0402[0], &q0403[0], &q0404[0], &q0405[0], &q0406[0], &q0407[0], 
    &q0408[0], &q0409[0], &q0410[0], &q0411[0], &q0412[0], &q0413[0], &q0414[0], &q0415[0], 
    &q0416[0], &q0417[0], &q0418[0], &q0419[0], &q0420[0], &q0421[0], &q0422[0], &q0423[0], 
    &q0424[0], &q0425[0], &q0426[0], &q0427[0], &q0428[0], &q0429[0], &q0430[0], &q0431[0], 
    &q0432[0], &q0433[0], &q0434[0], &q0435[0], &q0436[0], &q0437[0], &q0438[0], &q0439[0], 
    &q0440[0], &q0441[0], &q0442[0], &q0443[0], &q0444[0], &q0445[0], &q0446[0], &q0447[0], 
    &q0448[0], &q0449[0], &q0450[0], &q0451[0], &q0452[0], &q0453[0], &q0454[0], &q0455[0], 
    &q0456[0], &q0457[0], &q0458[0], &q0459[0], &q0460[0], &q0461[0], &q0462[0], &q0463[0], 
    &q0464[0], &q0465[0], &q0466[0], &q0467[0], &q0468[0], &q0469[0], &q0470[0], &q0471[0], 
    &q0472[0], &q0473[0], &q0474[0], &q0475[0], &q0476[0], &q0477[0], &q0478[0], &q0479[0], 
    &q0480[0], &q0481[0], &q0482[0], &q0483[0], &q0484[0], &q0485[0], &q0486[0], &q0487[0], 
    &q0488[0], &q0489[0], &q0490[0], &q0491[0], &q0492[0], &q0493[0], &q0494[0], &q0495[0], 
    &q0496[0], &q0497[0], &q0498[0], &q0499[0], &q0500[0], &q0501[0], &q0502[0], &q0503[0], 
    &q0504[0], &q0505[0], &q0506[0], &q0507[0], &q0508[0], &q0509[0], &q0510[0], &q0511[0], 
    &q0512[0], &q0513[0], &q0514[0], &q0515[0], &q0516[0], &q0517[0], &q0518[0], &q0519[0], 
    &q0520[0], &q0521[0], &q0522[0], &q0523[0], &q0524[0], &q0525[0], &q0526[0], &q0527[0], 
    &q0528[0], &q0529[0], &q0530[0], &q0531[0], &q0532[0], &q0533[0], &q0534[0], &q0535[0], 
    &q0536[0], &q0537[0], &q0538[0], &q0539[0], &q0540[0], &q0541[0], &q0542[0], &q0543[0], 
    &q0544[0], &q0545[0], &q0546[0], &q0547[0], &q0548[0], &q0549[0], &q0550[0], &q0551[0], 
    &q0552[0], &q0553[0], &q0554[0], &q0555[0], &q0556[0], &q0557[0], &q0558[0], &q0559[0], 
    &q0560[0], &q0561[0], &q0562[0], &q0563[0], &q0564[0], &q0565[0], &q0566[0], &q0567[0], 
    &q0568[0], &q0569[0], &q0570[0], &q0571[0], &q0572[0], &q0573[0], &q0574[0], &q0575[0], 
    &q0576[0], &q0577[0], &q0578[0], &q0579[0], &q0580[0], &q0581[0], &q0582[0], &q0583[0], 
    &q0584[0], &q0585[0], &q0586[0], &q0587[0], &q0588[0], &q0589[0], &q0590[0], &q0591[0], 
    &q0592[0], &q0593[0], &q0594[0], &q0595[0], &q0596[0], &q0597[0], &q0598[0], &q0599[0], 
    &q0600[0], &q0601[0], &q0602[0], &q0603[0], &q0604[0], &q0605[0], &q0606[0], &q0607[0], 
    &q0608[0], &q0609[0], &q0610[0], &q0611[0], &q0612[0], &q0613[0], &q0614[0], &q0615[0], 
    &q0616[0], &q0617[0], &q0618[0], &q0619[0], &q0620[0], &q0621[0], &q0622[0], &q0623[0], 
    &q0624[0], &q0625[0], &q0626[0], &q0627[0], &q0628[0], &q0629[0], &q0630[0], &q0631[0], 
    &q0632[0], &q0633[0], &q0634[0], &q0635[0], &q0636[0], &q0637[0], &q0638[0], &q0639[0], 
    &q0640[0], &q0641[0], &q0642[0], &q0643[0], &q0644[0], &q0645[0], &q0646[0], &q0647[0], 
    &q0648[0], &q0649[0], &q0650[0], &q0651[0], &q0652[0], &q0653[0], &q0654[0], &q0655[0], 
    &q0656[0], &q0657[0], &q0658[0], &q0659[0], &q0660[0], &q0661[0], &q0662[0], &q0663[0], 
    &q0664[0], &q0665[0], &q0666[0], &q0667[0], &q0668[0], &q0669[0], &q0670[0], &q0671[0], 
    &q0672[0], &q0673[0], &q0674[0], &q0675[0], &q0676[0], &q0677[0], &q0678[0], &q0679[0], 
    &q0680[0], &q0681[0], &q0682[0], &q0683[0], &q0684[0], &q0685[0], &q0686[0], &q0687[0], 
    &q0688[0], &q0689[0], &q0690[0], &q0691[0], &q0692[0], &q0693[0], &q0694[0], &q0695[0], 
    &q0696[0], &q0697[0], &q0698[0], &q0699[0], &q0700[0], &q0701[0], &q0702[0], &q0703[0], 
    &q0704[0], &q0705[0], &q0706[0], &q0707[0], &q0708[0], &q0709[0], &q0710[0], &q0711[0], 
    &q0712[0], &q0713[0], &q0714[0], &q0715[0], &q0716[0], &q0717[0], &q0718[0], &q0719[0], 
    &q0720[0], &q0721[0], &q0722[0], &q0723[0], &q0724[0], &q0725[0], &q0726[0], &q0727[0], 
    &q0728[0], &q0729[0], &q0730[0], &q0731[0], &q0732[0], &q0733[0], &q0734[0], &q0735[0], 
    &q0736[0], &q0737[0], &q0738[0], &q0739[0], &q0740[0], &q0741[0], &q0742[0], &q0743[0], 
    &q0744[0], &q0745[0], &q0746[0], &q0747[0], &q0748[0], &q0749[0], &q0750[0], &q0751[0], 
    &q0752[0], &q0753[0], &q0754[0], &q0755[0], &q0756[0], &q0757[0], &q0758[0], &q0759[0], 
    &q0760[0], &q0761[0], &q0762[0], &q0763[0], &q0764[0], &q0765[0], &q0766[0], &q0767[0], 
    &q0768[0], &q0769[0], &q0770[0], &q0771[0], &q0772[0], &q0773[0], &q0774[0], &q0775[0], 
    &q0776[0], &q0777[0], &q0778[0], &q0779[0], &q0780[0], &q0781[0], &q0782[0], &q0783[0], 
    &q0784[0], &q0785[0], &q0786[0], &q0787[0], &q0788[0], &q0789[0], &q0790[0], &q0791[0], 
    &q0792[0], &q0793[0], &q0794[0], &q0795[0], &q0796[0], &q0797[0], &q0798[0], &q0799[0], 
    &q0800[0], &q0801[0], &q0802[0], &q0803[0], &q0804[0], &q0805[0], &q0806[0], &q0807[0], 
    &q0808[0], &q0809[0], &q0810[0], &q0811[0], &q0812[0], &q0813[0], &q0814[0], &q0815[0], 
    &q0816[0], &q0817[0], &q0818[0], &q0819[0], &q0820[0], &q0821[0], &q0822[0], &q0823[0], 
    &q0824[0], &q0825[0], &q0826[0], &q0827[0], &q0828[0], &q0829[0], &q0830[0], &q0831[0], 
    &q0832[0], &q0833[0], &q0834[0], &q0835[0], &q0836[0], &q0837[0], &q0838[0], &q0839[0], 
    &q0840[0], &q0841[0], &q0842[0], &q0843[0], &q0844[0], &q0845[0], &q0846[0], &q0847[0], 
    &q0848[0], &q0849[0], &q0850[0], &q0851[0], &q0852[0], &q0853[0], &q0854[0], &q0855[0], 
    &q0856[0], &q0857[0], &q0858[0], &q0859[0], &q0860[0], &q0861[0], &q0862[0], &q0863[0], 
    &q0864[0], &q0865[0], &q0866[0], &q0867[0], &q0868[0], &q0869[0], &q0870[0], &q0871[0], 
    &q0872[0], &q0873[0], &q0874[0], &q0875[0], &q0876[0], &q0877[0], &q0878[0], &q0879[0], 
    &q0880[0], &q0881[0], &q0882[0], &q0883[0], &q0884[0], &q0885[0], &q0886[0], &q0887[0], 
    &q0888[0], &q0889[0], &q0890[0], &q0891[0], &q0892[0], &q0893[0], &q0894[0], &q0895[0], 
    &q0896[0], &q0897[0], &q0898[0], &q0899[0], &q0900[0], &q0901[0], &q0902[0], &q0903[0], 
    &q0904[0], &q0905[0], &q0906[0], &q0907[0], &q0908[0], &q0909[0], &q0910[0], &q0911[0], 
    &q0912[0], &q0913[0], &q0914[0], &q0915[0], &q0916[0], &q0917[0], &q0918[0], &q0919[0], 
    &q0920[0], &q0921[0], &q0922[0], &q0923[0], &q0924[0], &q0925[0], &q0926[0], &q0927[0], 
    &q0928[0], &q0929[0], &q0930[0], &q0931[0], &q0932[0], &q0933[0], &q0934[0], &q0935[0], 
    &q0936[0], &q0937[0], &q0938[0], &q0939[0], &q0940[0], &q0941[0], &q0942[0], &q0943[0], 
    &q0944[0], &q0945[0], &q0946[0], &q0947[0], &q0948[0], &q0949[0], &q0950[0], &q0951[0], 
    &q0952[0], &q0953[0], &q0954[0], &q0955[0], &q0956[0], &q0957[0], &q0958[0], &q0959[0], 
    &q0960[0], &q0961[0], &q0962[0], &q0963[0], &q0964[0], &q0965[0], &q0966[0], &q0967[0], 
    &q0968[0], &q0969[0], &q0970[0], &q0971[0], &q0972[0], &q0973[0], &q0974[0], &q0975[0], 
    &q0976[0], &q0977[0], &q0978[0], &q0979[0], &q0980[0], &q0981[0], &q0982[0], &q0983[0], 
    &q0984[0], &q0985[0], &q0986[0], &q0987[0], &q0988[0], &q0989[0], &q0990[0], &q0991[0], 
    &q0992[0], &q0993[0], &q0994[0], &q0995[0], &q0996[0], &q0997[0], &q0998[0], &q0999[0], 
    &q1000[0], &q1001[0], &q1002[0], &q1003[0], &q1004[0], &q1005[0], &q1006[0], &q1007[0], 
    &q1008[0], &q1009[0], &q1010[0], &q1011[0], &q1012[0], &q1013[0], &q1014[0], &q1015[0], 
    &q1016[0], &q1017[0], &q1018[0], &q1019[0], &q1020[0], &q1021[0], &q1022[0], &q1023[0], 
    &q1024[0], &q1025[0], &q1026[0], &q1027[0], &q1028[0], &q1029[0], &q1030[0], &q1031[0], 
    &q1032[0], &q1033[0], &q1034[0], &q1035[0], &q1036[0], &q1037[0], &q1038[0], &q1039[0], 
    &q1040[0], &q1041[0], &q1042[0], &q1043[0], &q1044[0], &q1045[0], &q1046[0], &q1047[0], 
    &q1048[0], &q1049[0], &q1050[0], &q1051[0], &q1052[0], &q1053[0], &q1054[0], &q1055[0], 
    &q1056[0], &q1057[0], &q1058[0], &q1059[0], &q1060[0], &q1061[0], &q1062[0], &q1063[0], 
    &q1064[0], &q1065[0], &q1066[0], &q1067[0], &q1068[0], &q1069[0], &q1070[0], &q1071[0], 
    &q1072[0], &q1073[0], &q1074[0], &q1075[0], &q1076[0], &q1077[0], &q1078[0], &q1079[0], 
    &q1080[0], &q1081[0], &q1082[0], &q1083[0], &q1084[0], &q1085[0], &q1086[0], &q1087[0], 
    &q1088[0], &q1089[0], &q1090[0], &q1091[0], &q1092[0], &q1093[0], &q1094[0], &q1095[0], 
    &q1096[0], &q1097[0], &q1098[0], &q1099[0], &q1100[0], &q1101[0], &q1102[0], &q1103[0], 
    &q1104[0], &q1105[0], &q1106[0], &q1107[0], &q1108[0], &q1109[0], &q1110[0], &q1111[0], 
    &q1112[0], &q1113[0], &q1114[0], &q1115[0], &q1116[0], &q1117[0], &q1118[0], &q1119[0], 
    &q1120[0], &q1121[0], &q1122[0], &q1123[0], &q1124[0], &q1125[0], &q1126[0], &q1127[0], 
    &q1128[0], &q1129[0], &q1130[0], &q1131[0], &q1132[0], &q1133[0], &q1134[0], &q1135[0], 
    &q1136[0], &q1137[0], &q1138[0], &q1139[0], &q1140[0], &q1141[0], &q1142[0], &q1143[0], 
    &q1144[0], &q1145[0], &q1146[0], &q1147[0], &q1148[0], &q1149[0], &q1150[0], &q1151[0], 
    &q1152[0], &q1153[0], &q1154[0], &q1155[0], &q1156[0], &q1157[0], &q1158[0], &q1159[0], 
    &q1160[0], &q1161[0], &q1162[0], &q1163[0], &q1164[0], &q1165[0], &q1166[0], &q1167[0], 
    &q1168[0], &q1169[0], &q1170[0], &q1171[0], &q1172[0], &q1173[0], &q1174[0], &q1175[0], 
    &q1176[0], &q1177[0], &q1178[0], &q1179[0], &q1180[0], &q1181[0], &q1182[0], &q1183[0], 
    &q1184[0], &q1185[0], &q1186[0], &q1187[0], &q1188[0], &q1189[0], &q1190[0], &q1191[0], 
    &q1192[0], &q1193[0], &q1194[0], &q1195[0], &q1196[0], &q1197[0], &q1198[0], &q1199[0], 
    &q1200[0], &q1201[0], &q1202[0], &q1203[0], &q1204[0], &q1205[0], &q1206[0], &q1207[0], 
    &q1208[0], &q1209[0], &q1210[0], &q1211[0], &q1212[0], &q1213[0], &q1214[0], &q1215[0], 
    &q1216[0], &q1217[0], &q1218[0], &q1219[0], &q1220[0], &q1221[0], &q1222[0], &q1223[0], 
    &q1224[0], &q1225[0], &q1226[0], &q1227[0], &q1228[0], &q1229[0], &q1230[0], &q1231[0], 
    &q1232[0], &q1233[0], &q1234[0], &q1235[0], &q1236[0], &q1237[0], &q1238[0], &q1239[0], 
    &q1240[0], &q1241[0], &q1242[0], &q1243[0], &q1244[0], &q1245[0], &q1246[0], &q1247[0], 
    &q1248[0], &q1249[0], &q1250[0], &q1251[0], &q1252[0], &q1253[0], &q1254[0], &q1255[0], 
    &q1256[0], &q1257[0], &q1258[0], &q1259[0], &q1260[0], &q1261[0], &q1262[0], &q1263[0], 
    &q1264[0], &q1265[0], &q1266[0], &q1267[0], &q1268[0], &q1269[0], &q1270[0], &q1271[0], 
    &q1272[0], &q1273[0], &q1274[0], &q1275[0], &q1276[0], &q1277[0], &q1278[0], &q1279[0], 
    &q1280[0], &q1281[0], &q1282[0], &q1283[0], &q1284[0], &q1285[0], &q1286[0], &q1287[0], 
    &q1288[0], &q1289[0], &q1290[0], &q1291[0], &q1292[0], &q1293[0], &q1294[0], &q1295[0], 
    &q1296[0], &q1297[0], &q1298[0], &q1299[0], &q1300[0], &q1301[0], &q1302[0], &q1303[0], 
    &q1304[0], &q1305[0], &q1306[0], &q1307[0], &q1308[0], &q1309[0], &q1310[0], &q1311[0], 
    &q1312[0], &q1313[0], &q1314[0], &q1315[0], &q1316[0], &q1317[0], &q1318[0], &q1319[0], 
    &q1320[0], &q1321[0], &q1322[0], &q1323[0], &q1324[0], &q1325[0], &q1326[0], &q1327[0], 
    &q1328[0], &q1329[0], &q1330[0], &q1331[0], &q1332[0], &q1333[0], &q1334[0], &q1335[0], 
    &q1336[0], &q1337[0], &q1338[0], &q1339[0], &q1340[0], &q1341[0], &q1342[0], &q1343[0], 
    &q1344[0], &q1345[0], &q1346[0], &q1347[0], &q1348[0], &q1349[0], &q1350[0], &q1351[0], 
    &q1352[0], &q1353[0], &q1354[0], &q1355[0], &q1356[0], &q1357[0], &q1358[0], &q1359[0], 
    &q1360[0], &q1361[0], &q1362[0], &q1363[0], &q1364[0], &q1365[0], &q1366[0], &q1367[0], 
    &q1368[0], &q1369[0], &q1370[0], &q1371[0], &q1372[0], &q1373[0], &q1374[0], &q1375[0], 
    &q1376[0], &q1377[0], &q1378[0], &q1379[0], &q1380[0], &q1381[0], &q1382[0], &q1383[0], 
    &q1384[0], &q1385[0], &q1386[0], &q1387[0], &q1388[0], &q1389[0], &q1390[0], &q1391[0], 
    &q1392[0], &q1393[0], &q1394[0], &q1395[0], &q1396[0], &q1397[0], &q1398[0], &q1399[0], 
    &q1400[0], &q1401[0], &q1402[0], &q1403[0], &q1404[0], &q1405[0], &q1406[0], &q1407[0], 
    &q1408[0], &q1409[0], &q1410[0], &q1411[0], &q1412[0], &q1413[0], &q1414[0], &q1415[0], 
    &q1416[0], &q1417[0], &q1418[0], &q1419[0], &q1420[0], &q1421[0], &q1422[0], &q1423[0], 
    &q1424[0], &q1425[0], &q1426[0], &q1427[0], &q1428[0], &q1429[0], &q1430[0], &q1431[0], 
    &q1432[0], &q1433[0], &q1434[0], &q1435[0], &q1436[0], &q1437[0], &q1438[0], &q1439[0], 
    &q1440[0], &q1441[0], &q1442[0], &q1443[0], &q1444[0], &q1445[0], &q1446[0], &q1447[0], 
    &q1448[0], &q1449[0], &q1450[0], &q1451[0], &q1452[0], &q1453[0], &q1454[0], &q1455[0], 
    &q1456[0], &q1457[0], &q1458[0], &q1459[0], &q1460[0], &q1461[0], &q1462[0], &q1463[0], 
    &q1464[0], &q1465[0], &q1466[0], &q1467[0], &q1468[0], &q1469[0], &q1470[0], &q1471[0], 
    &q1472[0], &q1473[0], &q1474[0], &q1475[0], &q1476[0], &q1477[0], &q1478[0], &q1479[0], 
    &q1480[0], &q1481[0], &q1482[0], &q1483[0], &q1484[0], &q1485[0], &q1486[0], &q1487[0], 
    &q1488[0], &q1489[0], &q1490[0], &q1491[0], &q1492[0], &q1493[0], &q1494[0], &q1495[0], 
    &q1496[0], &q1497[0], &q1498[0], &q1499[0], &q1500[0], &q1501[0], &q1502[0], &q1503[0], 
    &q1504[0], &q1505[0], &q1506[0], &q1507[0], &q1508[0], &q1509[0], &q1510[0], &q1511[0], 
    &q1512[0], &q1513[0], &q1514[0], &q1515[0], &q1516[0], &q1517[0], &q1518[0], &q1519[0], 
    &q1520[0], &q1521[0], &q1522[0], &q1523[0], &q1524[0], &q1525[0], &q1526[0], &q1527[0], 
    &q1528[0], &q1529[0], &q1530[0], &q1531[0], &q1532[0], &q1533[0], &q1534[0], &q1535[0], 
    &q1536[0], &q1537[0], &q1538[0], &q1539[0], &q1540[0], &q1541[0], &q1542[0], &q1543[0], 
    &q1544[0], &q1545[0], &q1546[0], &q1547[0], &q1548[0], &q1549[0], &q1550[0], &q1551[0], 
    &q1552[0], &q1553[0], &q1554[0], &q1555[0], &q1556[0], &q1557[0], &q1558[0], &q1559[0], 
    &q1560[0], &q1561[0], &q1562[0], &q1563[0], &q1564[0], &q1565[0], &q1566[0], &q1567[0], 
    &q1568[0], &q1569[0], &q1570[0], &q1571[0], &q1572[0], &q1573[0], &q1574[0], &q1575[0], 
    &q1576[0], &q1577[0], &q1578[0], &q1579[0], &q1580[0], &q1581[0], &q1582[0], &q1583[0], 
    &q1584[0], &q1585[0], &q1586[0], &q1587[0], &q1588[0], &q1589[0], &q1590[0], &q1591[0], 
    &q1592[0], &q1593[0], &q1594[0], &q1595[0], &q1596[0], &q1597[0], &q1598[0], &q1599[0], 
    &q1600[0], &q1601[0], &q1602[0], &q1603[0], &q1604[0], &q1605[0], &q1606[0], &q1607[0], 
    &q1608[0], &q1609[0], &q1610[0], &q1611[0], &q1612[0], &q1613[0], &q1614[0], &q1615[0], 
    &q1616[0], &q1617[0], &q1618[0], &q1619[0], &q1620[0], &q1621[0], &q1622[0], &q1623[0], 
    &q1624[0], &q1625[0], &q1626[0], &q1627[0], &q1628[0], &q1629[0], &q1630[0], &q1631[0], 
    &q1632[0], &q1633[0], &q1634[0], &q1635[0], &q1636[0], &q1637[0], &q1638[0], &q1639[0], 
    &q1640[0], &q1641[0], &q1642[0], &q1643[0], &q1644[0], &q1645[0], &q1646[0], &q1647[0], 
    &q1648[0], &q1649[0], &q1650[0], &q1651[0], &q1652[0], &q1653[0], &q1654[0], &q1655[0], 
    &q1656[0], &q1657[0], &q1658[0], &q1659[0], &q1660[0], &q1661[0], &q1662[0], &q1663[0], 
    &q1664[0], &q1665[0], &q1666[0], &q1667[0], &q1668[0], &q1669[0], &q1670[0], &q1671[0], 
    &q1672[0], &q1673[0], &q1674[0], &q1675[0], &q1676[0], &q1677[0], &q1678[0], &q1679[0], 
    &q1680[0], &q1681[0], &q1682[0], &q1683[0], &q1684[0], &q1685[0], &q1686[0], &q1687[0], 
    &q1688[0], &q1689[0], &q1690[0], &q1691[0], &q1692[0], &q1693[0], &q1694[0], &q1695[0], 
    &q1696[0], &q1697[0], &q1698[0], &q1699[0], &q1700[0], &q1701[0], &q1702[0], &q1703[0], 
    &q1704[0], &q1705[0], &q1706[0], &q1707[0], &q1708[0], &q1709[0], &q1710[0], &q1711[0], 
    &q1712[0], &q1713[0], &q1714[0], &q1715[0], &q1716[0], &q1717[0], &q1718[0], &q1719[0], 
    &q1720[0], &q1721[0], &q1722[0], &q1723[0], &q1724[0], &q1725[0], &q1726[0], &q1727[0], 
    &q1728[0], &q1729[0], &q1730[0], &q1731[0], &q1732[0], &q1733[0], &q1734[0], &q1735[0], 
    &q1736[0], &q1737[0], &q1738[0], &q1739[0], &q1740[0], &q1741[0], &q1742[0], &q1743[0], 
    &q1744[0], &q1745[0], &q1746[0], &q1747[0], &q1748[0], &q1749[0], &q1750[0], &q1751[0], 
    &q1752[0], &q1753[0], &q1754[0], &q1755[0], &q1756[0], &q1757[0], &q1758[0], &q1759[0], 
    &q1760[0], &q1761[0], &q1762[0], &q1763[0], &q1764[0], &q1765[0], &q1766[0], &q1767[0], 
    &q1768[0], &q1769[0], &q1770[0], &q1771[0], &q1772[0], &q1773[0], &q1774[0], &q1775[0], 
    &q1776[0], &q1777[0], &q1778[0], &q1779[0], &q1780[0], &q1781[0], &q1782[0], &q1783[0], 
    &q1784[0], &q1785[0], &q1786[0], &q1787[0], &q1788[0], &q1789[0], &q1790[0], &q1791[0], 
    &q1792[0], &q1793[0], &q1794[0], &q1795[0], &q1796[0], &q1797[0], &q1798[0], &q1799[0], 
    &q1800[0], &q1801[0], &q1802[0], &q1803[0], &q1804[0], &q1805[0], &q1806[0], &q1807[0], 
    &q1808[0], &q1809[0], &q1810[0], &q1811[0], &q1812[0], &q1813[0], &q1814[0], &q1815[0], 
    &q1816[0], &q1817[0], &q1818[0], &q1819[0], &q1820[0], &q1821[0], &q1822[0], &q1823[0], 
    &q1824[0], &q1825[0], &q1826[0], &q1827[0], &q1828[0], &q1829[0], &q1830[0], &q1831[0], 
    &q1832[0], &q1833[0], &q1834[0], &q1835[0], &q1836[0], &q1837[0], &q1838[0], &q1839[0], 
    &q1840[0], &q1841[0], &q1842[0], &q1843[0], &q1844[0], &q1845[0], &q1846[0], &q1847[0], 
    &q1848[0], &q1849[0], &q1850[0], &q1851[0], &q1852[0], &q1853[0], &q1854[0], &q1855[0], 
    &q1856[0], &q1857[0], &q1858[0], &q1859[0], &q1860[0], &q1861[0], &q1862[0], &q1863[0], 
    &q1864[0], &q1865[0], &q1866[0], &q1867[0], &q1868[0], &q1869[0], &q1870[0], &q1871[0], 
    &q1872[0], &q1873[0], &q1874[0], &q1875[0], &q1876[0], &q1877[0], &q1878[0], &q1879[0], 
    &q1880[0], &q1881[0], &q1882[0], &q1883[0], &q1884[0], &q1885[0], &q1886[0], &q1887[0], 
    &q1888[0], &q1889[0], &q1890[0], &q1891[0], &q1892[0], &q1893[0], &q1894[0], &q1895[0], 
    &q1896[0], &q1897[0], &q1898[0], &q1899[0], &q1900[0], &q1901[0], &q1902[0], &q1903[0], 
    &q1904[0], &q1905[0], &q1906[0], &q1907[0], &q1908[0], &q1909[0], &q1910[0], &q1911[0], 
    &q1912[0], &q1913[0], &q1914[0], &q1915[0], &q1916[0], &q1917[0], &q1918[0], &q1919[0], 
    &q1920[0], &q1921[0], &q1922[0], &q1923[0], &q1924[0], &q1925[0], &q1926[0], &q1927[0], 
    &q1928[0], &q1929[0], &q1930[0], &q1931[0], &q1932[0], &q1933[0], &q1934[0], &q1935[0], 
    &q1936[0], &q1937[0], &q1938[0], &q1939[0], &q1940[0], &q1941[0], &q1942[0], &q1943[0], 
    &q1944[0], &q1945[0], &q1946[0], &q1947[0], &q1948[0], &q1949[0], &q1950[0], &q1951[0], 
    &q1952[0], &q1953[0], &q1954[0], &q1955[0], &q1956[0], &q1957[0], &q1958[0], &q1959[0], 
    &q1960[0], &q1961[0], &q1962[0], &q1963[0], &q1964[0], &q1965[0], &q1966[0], &q1967[0], 
    &q1968[0], &q1969[0], &q1970[0], &q1971[0], &q1972[0], &q1973[0], &q1974[0], &q1975[0], 
    &q1976[0], &q1977[0], &q1978[0], &q1979[0], &q1980[0], &q1981[0], &q1982[0], &q1983[0], 
    &q1984[0], &q1985[0], &q1986[0], &q1987[0], &q1988[0], &q1989[0], &q1990[0], &q1991[0], 
    &q1992[0], &q1993[0], &q1994[0], &q1995[0], &q1996[0], &q1997[0], &q1998[0], &q1999[0], 
    &q2000[0], &q2001[0], &q2002[0], &q2003[0], &q2004[0], &q2005[0], &q2006[0], &q2007[0], 
    &q2008[0], &q2009[0], &q2010[0], &q2011[0], &q2012[0], &q2013[0], &q2014[0], &q2015[0], 
    &q2016[0], &q2017[0], &q2018[0], &q2019[0], &q2020[0], &q2021[0], &q2022[0], &q2023[0], 
    &q2024[0], &q2025[0], &q2026[0], &q2027[0], &q2028[0], &q2029[0], &q2030[0], &q2031[0], 
    &q2032[0], &q2033[0], &q2034[0], &q2035[0], &q2036[0], &q2037[0], &q2038[0], &q2039[0], 
    &q2040[0], &q2041[0], &q2042[0], &q2043[0], &q2044[0], &q2045[0], &q2046[0], &q2047[0], 
    &q2048[0], &q2049[0], &q2050[0], &q2051[0], &q2052[0], &q2053[0], &q2054[0], &q2055[0], 
    &q2056[0], &q2057[0], &q2058[0], &q2059[0], &q2060[0], &q2061[0], &q2062[0], &q2063[0], 
    &q2064[0], &q2065[0], &q2066[0], &q2067[0], &q2068[0], &q2069[0], &q2070[0], &q2071[0], 
    &q2072[0], &q2073[0], &q2074[0], &q2075[0], &q2076[0], &q2077[0], &q2078[0], &q2079[0], 
    &q2080[0], &q2081[0], &q2082[0], &q2083[0], &q2084[0], &q2085[0], &q2086[0], &q2087[0], 
    &q2088[0], &q2089[0], &q2090[0], &q2091[0], &q2092[0], &q2093[0], &q2094[0], &q2095[0], 
    &q2096[0], &q2097[0], &q2098[0], &q2099[0], &q2100[0], &q2101[0], &q2102[0], &q2103[0], 
    &q2104[0], &q2105[0], &q2106[0], &q2107[0], &q2108[0], &q2109[0], &q2110[0], &q2111[0], 
    &q2112[0], &q2113[0], &q2114[0], &q2115[0], &q2116[0], &q2117[0], &q2118[0], &q2119[0], 
    &q2120[0], &q2121[0], &q2122[0], &q2123[0], &q2124[0], &q2125[0], &q2126[0], &q2127[0], 
    &q2128[0], &q2129[0], &q2130[0], &q2131[0], &q2132[0], &q2133[0], &q2134[0], &q2135[0], 
    &q2136[0], &q2137[0], &q2138[0], &q2139[0], &q2140[0], &q2141[0], &q2142[0], &q2143[0], 
    &q2144[0], &q2145[0], &q2146[0], &q2147[0], &q2148[0], &q2149[0], &q2150[0], &q2151[0], 
    &q2152[0], &q2153[0], &q2154[0], &q2155[0], &q2156[0], &q2157[0], &q2158[0], &q2159[0], 
    &q2160[0], &q2161[0], &q2162[0], &q2163[0], &q2164[0], &q2165[0], &q2166[0], &q2167[0], 
    &q2168[0], &q2169[0], &q2170[0], &q2171[0], &q2172[0], &q2173[0], &q2174[0], &q2175[0], 
    &q2176[0], &q2177[0], &q2178[0], &q2179[0], &q2180[0], &q2181[0], &q2182[0], &q2183[0], 
    &q2184[0], &q2185[0], &q2186[0], &q2187[0], &q2188[0], &q2189[0], &q2190[0], &q2191[0], 
    &q2192[0], &q2193[0], &q2194[0], &q2195[0], &q2196[0], &q2197[0], &q2198[0], &q2199[0], 
    &q2200[0], &q2201[0], &q2202[0], &q2203[0], &q2204[0], &q2205[0], &q2206[0], &q2207[0], 
    &q2208[0], &q2209[0], &q2210[0], &q2211[0], &q2212[0], &q2213[0], &q2214[0], &q2215[0], 
    &q2216[0], &q2217[0], &q2218[0], &q2219[0], &q2220[0], &q2221[0], &q2222[0], &q2223[0], 
    &q2224[0], &q2225[0], &q2226[0], &q2227[0], &q2228[0], &q2229[0], &q2230[0], &q2231[0], 
    &q2232[0], &q2233[0], &q2234[0], &q2235[0], &q2236[0], &q2237[0], &q2238[0], &q2239[0], 
    &q2240[0], &q2241[0], &q2242[0], &q2243[0], &q2244[0], &q2245[0], &q2246[0], &q2247[0], 
    &q2248[0], &q2249[0], &q2250[0], &q2251[0], &q2252[0], &q2253[0], &q2254[0], &q2255[0], 
    &q2256[0], &q2257[0], &q2258[0], &q2259[0], &q2260[0], &q2261[0], &q2262[0], &q2263[0], 
    &q2264[0], &q2265[0], &q2266[0], &q2267[0], &q2268[0], &q2269[0], &q2270[0], &q2271[0], 
    &q2272[0], &q2273[0], &q2274[0], &q2275[0], &q2276[0], &q2277[0], &q2278[0], &q2279[0], 
    &q2280[0], &q2281[0], &q2282[0], &q2283[0], &q2284[0], &q2285[0], &q2286[0], &q2287[0], 
    &q2288[0], &q2289[0], &q2290[0], &q2291[0], &q2292[0], &q2293[0], &q2294[0], &q2295[0], 
    &q2296[0], &q2297[0], &q2298[0], &q2299[0], &q2300[0], &q2301[0], &q2302[0], &q2303[0], 
    &q2304[0], &q2305[0], &q2306[0], &q2307[0], &q2308[0], &q2309[0], &q2310[0], &q2311[0], 
    &q2312[0], &q2313[0], &q2314[0], &q2315[0], &q2316[0], &q2317[0], &q2318[0], &q2319[0], 
    &q2320[0], &q2321[0], &q2322[0], &q2323[0], &q2324[0], &q2325[0], &q2326[0], &q2327[0], 
    &q2328[0], &q2329[0], &q2330[0], &q2331[0], &q2332[0], &q2333[0], &q2334[0], &q2335[0], 
    &q2336[0], &q2337[0], &q2338[0], &q2339[0], &q2340[0], &q2341[0], &q2342[0], &q2343[0], 
    &q2344[0], &q2345[0], &q2346[0], &q2347[0], &q2348[0], &q2349[0], &q2350[0], &q2351[0], 
    &q2352[0], &q2353[0], &q2354[0], &q2355[0], &q2356[0], &q2357[0], &q2358[0], &q2359[0], 
    &q2360[0], &q2361[0], &q2362[0], &q2363[0], &q2364[0], &q2365[0], &q2366[0], &q2367[0], 
    &q2368[0], &q2369[0], &q2370[0], &q2371[0], &q2372[0], &q2373[0], &q2374[0], &q2375[0], 
    &q2376[0], &q2377[0], &q2378[0], &q2379[0], &q2380[0], &q2381[0], &q2382[0], &q2383[0], 
    &q2384[0], &q2385[0], &q2386[0], &q2387[0], &q2388[0], &q2389[0], &q2390[0], &q2391[0], 
    &q2392[0], &q2393[0], &q2394[0], &q2395[0], &q2396[0], &q2397[0], &q2398[0], &q2399[0], 
    &q2400[0], &q2401[0], &q2402[0], &q2403[0], &q2404[0], &q2405[0], &q2406[0], &q2407[0], 
    &q2408[0], &q2409[0], &q2410[0], &q2411[0], &q2412[0], &q2413[0], &q2414[0], &q2415[0], 
    &q2416[0], &q2417[0], &q2418[0], &q2419[0], &q2420[0], &q2421[0], &q2422[0], &q2423[0], 
    &q2424[0], &q2425[0], &q2426[0], &q2427[0], &q2428[0], &q2429[0], &q2430[0], &q2431[0], 
    &q2432[0], &q2433[0], &q2434[0], &q2435[0], &q2436[0], &q2437[0], &q2438[0], &q2439[0], 
    &q2440[0], &q2441[0], &q2442[0], &q2443[0], &q2444[0], &q2445[0], &q2446[0], &q2447[0], 
    &q2448[0], &q2449[0], &q2450[0], &q2451[0], &q2452[0], &q2453[0], &q2454[0], &q2455[0], 
    &q2456[0], &q2457[0], &q2458[0], &q2459[0], &q2460[0], &q2461[0], &q2462[0], &q2463[0], 
    &q2464[0], &q2465[0], &q2466[0], &q2467[0], &q2468[0], &q2469[0], &q2470[0], &q2471[0], 
    &q2472[0], &q2473[0], &q2474[0], &q2475[0], &q2476[0], &q2477[0], &q2478[0], &q2479[0], 
    &q2480[0], &q2481[0], &q2482[0], &q2483[0], &q2484[0], &q2485[0], &q2486[0], &q2487[0], 
    &q2488[0], &q2489[0], &q2490[0], &q2491[0], &q2492[0], &q2493[0], &q2494[0], &q2495[0], 
    &q2496[0], &q2497[0], &q2498[0], &q2499[0], &q2500[0], &q2501[0], &q2502[0], &q2503[0], 
    &q2504[0], &q2505[0], &q2506[0], &q2507[0], &q2508[0], &q2509[0], &q2510[0], &q2511[0], 
    &q2512[0], &q2513[0], &q2514[0], &q2515[0], &q2516[0], &q2517[0], &q2518[0], &q2519[0], 
    &q2520[0], &q2521[0], &q2522[0], &q2523[0], &q2524[0], &q2525[0], &q2526[0], &q2527[0], 
    &q2528[0], &q2529[0], &q2530[0], &q2531[0], &q2532[0], &q2533[0], &q2534[0], &q2535[0], 
    &q2536[0], &q2537[0], &q2538[0], &q2539[0], &q2540[0], &q2541[0], &q2542[0], &q2543[0], 
    &q2544[0], &q2545[0], &q2546[0], &q2547[0], &q2548[0], &q2549[0], &q2550[0], &q2551[0], 
    &q2552[0], &q2553[0], &q2554[0], &q2555[0], &q2556[0], &q2557[0], &q2558[0], &q2559[0], 
    &q2560[0], &q2561[0], &q2562[0], &q2563[0], &q2564[0], &q2565[0], &q2566[0], &q2567[0], 
    &q2568[0], &q2569[0], &q2570[0], &q2571[0], &q2572[0], &q2573[0], &q2574[0], &q2575[0], 
    &q2576[0], &q2577[0], &q2578[0], &q2579[0], &q2580[0], &q2581[0], &q2582[0], &q2583[0], 
    &q2584[0], &q2585[0], &q2586[0], &q2587[0], &q2588[0], &q2589[0], &q2590[0], &q2591[0], 
    &q2592[0], &q2593[0], &q2594[0], &q2595[0], &q2596[0], &q2597[0], &q2598[0], &q2599[0], 
    &q2600[0], &q2601[0], &q2602[0], &q2603[0], &q2604[0], &q2605[0], &q2606[0], &q2607[0], 
    &q2608[0], &q2609[0], &q2610[0], &q2611[0], &q2612[0], &q2613[0], &q2614[0], &q2615[0], 
    &q2616[0], &q2617[0], &q2618[0], &q2619[0], &q2620[0], &q2621[0], &q2622[0], &q2623[0], 
    &q2624[0], &q2625[0], &q2626[0], &q2627[0], &q2628[0], &q2629[0], &q2630[0], &q2631[0], 
    &q2632[0], &q2633[0], &q2634[0], &q2635[0], &q2636[0], &q2637[0], &q2638[0], &q2639[0], 
    &q2640[0], &q2641[0], &q2642[0], &q2643[0], &q2644[0], &q2645[0], &q2646[0], &q2647[0], 
    &q2648[0], &q2649[0], &q2650[0], &q2651[0], &q2652[0], &q2653[0], &q2654[0], &q2655[0], 
    &q2656[0], &q2657[0], &q2658[0], &q2659[0], &q2660[0], &q2661[0], &q2662[0], &q2663[0], 
    &q2664[0], &q2665[0], &q2666[0], &q2667[0], &q2668[0], &q2669[0], &q2670[0], &q2671[0], 
    &q2672[0], &q2673[0], &q2674[0], &q2675[0], &q2676[0], &q2677[0], &q2678[0], &q2679[0], 
    &q2680[0], &q2681[0], &q2682[0], &q2683[0], &q2684[0], &q2685[0], &q2686[0], &q2687[0], 
    &q2688[0], &q2689[0], &q2690[0], &q2691[0], &q2692[0], &q2693[0], &q2694[0], &q2695[0], 
    &q2696[0], &q2697[0], &q2698[0], &q2699[0], &q2700[0], &q2701[0], &q2702[0], &q2703[0], 
    &q2704[0], &q2705[0], &q2706[0], &q2707[0], &q2708[0], &q2709[0], &q2710[0], &q2711[0], 
    &q2712[0], &q2713[0], &q2714[0], &q2715[0], &q2716[0], &q2717[0], &q2718[0], &q2719[0], 
    &q2720[0], &q2721[0], &q2722[0], &q2723[0], &q2724[0], &q2725[0], &q2726[0], &q2727[0], 
    &q2728[0], &q2729[0], &q2730[0], &q2731[0], &q2732[0], &q2733[0], &q2734[0], &q2735[0], 
    &q2736[0], &q2737[0], &q2738[0], &q2739[0], &q2740[0], &q2741[0], &q2742[0], &q2743[0], 
    &q2744[0], &q2745[0], &q2746[0], &q2747[0], &q2748[0], &q2749[0], &q2750[0], &q2751[0], 
    &q2752[0], &q2753[0], &q2754[0], &q2755[0], &q2756[0], &q2757[0], &q2758[0], &q2759[0], 
    &q2760[0], &q2761[0], &q2762[0], &q2763[0], &q2764[0], &q2765[0], &q2766[0], &q2767[0], 
    &q2768[0], &q2769[0], &q2770[0], &q2771[0], &q2772[0], &q2773[0], &q2774[0], &q2775[0], 
    &q2776[0], &q2777[0], &q2778[0], &q2779[0], &q2780[0], &q2781[0], &q2782[0], &q2783[0], 
    &q2784[0], &q2785[0], &q2786[0], &q2787[0], &q2788[0], &q2789[0], &q2790[0], &q2791[0], 
    &q2792[0], &q2793[0], &q2794[0], &q2795[0], &q2796[0], &q2797[0], &q2798[0], &q2799[0], 
    &q2800[0], &q2801[0], &q2802[0], &q2803[0], &q2804[0], &q2805[0], &q2806[0], &q2807[0], 
    &q2808[0], &q2809[0], &q2810[0], &q2811[0], &q2812[0], &q2813[0], &q2814[0], &q2815[0], 
    &q2816[0], &q2817[0], &q2818[0], &q2819[0], &q2820[0], &q2821[0], &q2822[0], &q2823[0], 
    &q2824[0], &q2825[0], &q2826[0], &q2827[0], &q2828[0], &q2829[0], &q2830[0], &q2831[0], 
    &q2832[0], &q2833[0], &q2834[0], &q2835[0], &q2836[0], &q2837[0], &q2838[0], &q2839[0], 
    &q2840[0], &q2841[0], &q2842[0], &q2843[0], &q2844[0], &q2845[0], &q2846[0], &q2847[0], 
    &q2848[0], &q2849[0], &q2850[0], &q2851[0], &q2852[0], &q2853[0], &q2854[0], &q2855[0], 
    &q2856[0], &q2857[0], &q2858[0], &q2859[0], &q2860[0], &q2861[0], &q2862[0], &q2863[0], 
    &q2864[0], &q2865[0], &q2866[0], &q2867[0], &q2868[0], &q2869[0], &q2870[0], &q2871[0], 
    &q2872[0], &q2873[0], &q2874[0], &q2875[0], &q2876[0], &q2877[0], &q2878[0], &q2879[0], 
    &q2880[0], &q2881[0], &q2882[0], &q2883[0], &q2884[0], &q2885[0], &q2886[0], &q2887[0], 
    &q2888[0], &q2889[0], &q2890[0], &q2891[0], &q2892[0], &q2893[0], &q2894[0], &q2895[0], 
    &q2896[0], &q2897[0], &q2898[0], &q2899[0], &q2900[0], &q2901[0], &q2902[0], &q2903[0], 
    &q2904[0], &q2905[0], &q2906[0], &q2907[0], &q2908[0], &q2909[0], &q2910[0], &q2911[0], 
    &q2912[0], &q2913[0], &q2914[0], &q2915[0], &q2916[0], &q2917[0], &q2918[0], &q2919[0], 
    &q2920[0], &q2921[0], &q2922[0], &q2923[0], &q2924[0], &q2925[0], &q2926[0], &q2927[0], 
    &q2928[0], &q2929[0], &q2930[0], &q2931[0], &q2932[0], &q2933[0], &q2934[0], &q2935[0], 
    &q2936[0], &q2937[0], &q2938[0], &q2939[0], &q2940[0], &q2941[0], &q2942[0], &q2943[0], 
    &q2944[0], &q2945[0], &q2946[0], &q2947[0], &q2948[0], &q2949[0], &q2950[0], &q2951[0], 
    &q2952[0], &q2953[0], &q2954[0], &q2955[0], &q2956[0], &q2957[0], &q2958[0], &q2959[0], 
    &q2960[0], &q2961[0], &q2962[0], &q2963[0], &q2964[0], &q2965[0], &q2966[0], &q2967[0], 
    &q2968[0], &q2969[0], &q2970[0], &q2971[0], &q2972[0], &q2973[0], &q2974[0], &q2975[0], 
    &q2976[0], &q2977[0], &q2978[0], &q2979[0], &q2980[0], &q2981[0], &q2982[0], &q2983[0], 
    &q2984[0], &q2985[0], &q2986[0], &q2987[0], &q2988[0], &q2989[0], &q2990[0], &q2991[0], 
    &q2992[0], &q2993[0], &q2994[0], &q2995[0], &q2996[0], &q2997[0], &q2998[0], &q2999[0], 
    &q3000[0], &q3001[0], &q3002[0], &q3003[0], &q3004[0], &q3005[0], &q3006[0], &q3007[0], 
    &q3008[0], &q3009[0], &q3010[0], &q3011[0], &q3012[0], &q3013[0], &q3014[0], &q3015[0], 
    &q3016[0], &q3017[0], &q3018[0], &q3019[0], &q3020[0], &q3021[0], &q3022[0], &q3023[0], 
    &q3024[0], &q3025[0], &q3026[0], &q3027[0], &q3028[0], &q3029[0], &q3030[0], &q3031[0], 
    &q3032[0], &q3033[0], &q3034[0], &q3035[0], &q3036[0], &q3037[0], &q3038[0], &q3039[0], 
    &q3040[0], &q3041[0], &q3042[0], &q3043[0], &q3044[0], &q3045[0], &q3046[0], &q3047[0], 
    &q3048[0], &q3049[0], &q3050[0], &q3051[0], &q3052[0], &q3053[0], &q3054[0], &q3055[0], 
    &q3056[0], &q3057[0], &q3058[0], &q3059[0], &q3060[0], &q3061[0], &q3062[0], &q3063[0], 
    &q3064[0], &q3065[0], &q3066[0], &q3067[0], &q3068[0], &q3069[0], &q3070[0], &q3071[0], 
    &q3072[0], &q3073[0], &q3074[0], &q3075[0], &q3076[0], &q3077[0], &q3078[0], &q3079[0], 
    &q3080[0], &q3081[0], &q3082[0], &q3083[0], &q3084[0], &q3085[0], &q3086[0], &q3087[0], 
    &q3088[0], &q3089[0], &q3090[0], &q3091[0], &q3092[0], &q3093[0], &q3094[0], &q3095[0], 
    &q3096[0], &q3097[0], &q3098[0], &q3099[0], &q3100[0], &q3101[0], &q3102[0], &q3103[0], 
    &q3104[0], &q3105[0], &q3106[0], &q3107[0], &q3108[0], &q3109[0], &q3110[0], &q3111[0], 
    &q3112[0], &q3113[0], &q3114[0], &q3115[0], &q3116[0], &q3117[0], &q3118[0], &q3119[0], 
    &q3120[0], &q3121[0], &q3122[0], &q3123[0], &q3124[0], &q3125[0], &q3126[0], &q3127[0], 
    &q3128[0], &q3129[0], &q3130[0], &q3131[0], &q3132[0], &q3133[0], &q3134[0], &q3135[0], 
    &q3136[0], &q3137[0], &q3138[0], &q3139[0], &q3140[0], &q3141[0], &q3142[0], &q3143[0], 
    &q3144[0], &q3145[0], &q3146[0], &q3147[0], &q3148[0], &q3149[0], &q3150[0], &q3151[0], 
    &q3152[0], &q3153[0], &q3154[0], &q3155[0], &q3156[0], &q3157[0], &q3158[0], &q3159[0], 
    &q3160[0], &q3161[0], &q3162[0], &q3163[0], &q3164[0], &q3165[0], &q3166[0], &q3167[0], 
    &q3168[0], &q3169[0], &q3170[0], &q3171[0], &q3172[0], &q3173[0], &q3174[0], &q3175[0], 
    &q3176[0], &q3177[0], &q3178[0], &q3179[0], &q3180[0], &q3181[0], &q3182[0], &q3183[0], 
    &q3184[0], &q3185[0], &q3186[0], &q3187[0], &q3188[0], &q3189[0], &q3190[0], &q3191[0], 
    &q3192[0], &q3193[0], &q3194[0], &q3195[0], &q3196[0], &q3197[0], &q3198[0], &q3199[0], 
    &q3200[0], &q3201[0], &q3202[0], &q3203[0], &q3204[0], &q3205[0], &q3206[0], &q3207[0], 
    &q3208[0], &q3209[0], &q3210[0], &q3211[0], &q3212[0], &q3213[0], &q3214[0], &q3215[0], 
    &q3216[0], &q3217[0], &q3218[0], &q3219[0], &q3220[0], &q3221[0], &q3222[0], &q3223[0], 
    &q3224[0], &q3225[0], &q3226[0], &q3227[0], &q3228[0], &q3229[0], &q3230[0], &q3231[0], 
    &q3232[0], &q3233[0], &q3234[0], &q3235[0], &q3236[0], &q3237[0], &q3238[0], &q3239[0], 
    &q3240[0], &q3241[0], &q3242[0], &q3243[0], &q3244[0], &q3245[0], &q3246[0], &q3247[0], 
    &q3248[0], &q3249[0], &q3250[0], &q3251[0], &q3252[0], &q3253[0], &q3254[0], &q3255[0], 
    &q3256[0], &q3257[0], &q3258[0], &q3259[0], &q3260[0], &q3261[0], &q3262[0], &q3263[0], 
    &q3264[0], &q3265[0], &q3266[0], &q3267[0], &q3268[0], &q3269[0], &q3270[0], &q3271[0], 
    &q3272[0], &q3273[0], &q3274[0], &q3275[0], &q3276[0], &q3277[0], &q3278[0], &q3279[0], 
    &q3280[0], &q3281[0], &q3282[0], &q3283[0], &q3284[0], &q3285[0], &q3286[0], &q3287[0], 
    &q3288[0], &q3289[0], &q3290[0], &q3291[0], &q3292[0], &q3293[0], &q3294[0], &q3295[0], 
    &q3296[0], &q3297[0], &q3298[0], &q3299[0], &q3300[0], &q3301[0], &q3302[0], &q3303[0], 
    &q3304[0], &q3305[0], &q3306[0], &q3307[0], &q3308[0], &q3309[0], &q3310[0], &q3311[0], 
    &q3312[0], &q3313[0], &q3314[0], &q3315[0], &q3316[0], &q3317[0], &q3318[0], &q3319[0], 
    &q3320[0], &q3321[0], &q3322[0], &q3323[0], &q3324[0], &q3325[0], &q3326[0], &q3327[0], 
    &q3328[0], &q3329[0], &q3330[0], &q3331[0], &q3332[0], &q3333[0], &q3334[0], &q3335[0], 
    &q3336[0], &q3337[0], &q3338[0], &q3339[0], &q3340[0], &q3341[0], &q3342[0], &q3343[0], 
    &q3344[0], &q3345[0], &q3346[0], &q3347[0], &q3348[0], &q3349[0], &q3350[0], &q3351[0], 
    &q3352[0], &q3353[0], &q3354[0], &q3355[0], &q3356[0], &q3357[0], &q3358[0], &q3359[0], 
    &q3360[0], &q3361[0], &q3362[0], &q3363[0], &q3364[0], &q3365[0], &q3366[0], &q3367[0], 
    &q3368[0], &q3369[0], &q3370[0], &q3371[0], &q3372[0], &q3373[0], &q3374[0], &q3375[0], 
    &q3376[0], &q3377[0], &q3378[0], &q3379[0], &q3380[0], &q3381[0], &q3382[0], &q3383[0], 
    &q3384[0], &q3385[0], &q3386[0], &q3387[0], &q3388[0], &q3389[0], &q3390[0], &q3391[0], 
    &q3392[0], &q3393[0], &q3394[0], &q3395[0], &q3396[0], &q3397[0], &q3398[0], &q3399[0], 
    &q3400[0], &q3401[0], &q3402[0], &q3403[0], &q3404[0], &q3405[0], &q3406[0], &q3407[0], 
    &q3408[0], &q3409[0], &q3410[0], &q3411[0], &q3412[0], &q3413[0], &q3414[0], &q3415[0], 
    &q3416[0], &q3417[0], &q3418[0], &q3419[0], &q3420[0], &q3421[0], &q3422[0], &q3423[0], 
    &q3424[0], &q3425[0], &q3426[0], &q3427[0], &q3428[0], &q3429[0], &q3430[0], &q3431[0], 
    &q3432[0], &q3433[0], &q3434[0], &q3435[0], &q3436[0], &q3437[0], &q3438[0], &q3439[0], 
    &q3440[0], &q3441[0], &q3442[0], &q3443[0], &q3444[0], &q3445[0], &q3446[0], &q3447[0], 
    &q3448[0], &q3449[0], &q3450[0], &q3451[0], &q3452[0], &q3453[0], &q3454[0], &q3455[0], 
    &q3456[0], &q3457[0], &q3458[0], &q3459[0], &q3460[0], &q3461[0], &q3462[0], &q3463[0], 
    &q3464[0], &q3465[0], &q3466[0], &q3467[0], &q3468[0], &q3469[0], &q3470[0], &q3471[0], 
    &q3472[0], &q3473[0], &q3474[0], &q3475[0], &q3476[0], &q3477[0], &q3478[0], &q3479[0], 
    &q3480[0], &q3481[0], &q3482[0], &q3483[0], &q3484[0], &q3485[0], &q3486[0], &q3487[0], 
    &q3488[0], &q3489[0], &q3490[0], &q3491[0], &q3492[0], &q3493[0], &q3494[0], &q3495[0], 
    &q3496[0], &q3497[0], &q3498[0], &q3499[0], &q3500[0], &q3501[0], &q3502[0], &q3503[0], 
    &q3504[0], &q3505[0], &q3506[0], &q3507[0], &q3508[0], &q3509[0], &q3510[0], &q3511[0], 
    &q3512[0], &q3513[0], &q3514[0], &q3515[0], &q3516[0], &q3517[0], &q3518[0], &q3519[0], 
    &q3520[0], &q3521[0], &q3522[0], &q3523[0], &q3524[0], &q3525[0], &q3526[0], &q3527[0], 
    &q3528[0], &q3529[0], &q3530[0], &q3531[0], &q3532[0], &q3533[0], &q3534[0], &q3535[0], 
    &q3536[0], &q3537[0], &q3538[0], &q3539[0], &q3540[0], &q3541[0], &q3542[0], &q3543[0], 
    &q3544[0], &q3545[0], &q3546[0], &q3547[0], &q3548[0], &q3549[0], &q3550[0], &q3551[0], 
    &q3552[0], &q3553[0], &q3554[0], &q3555[0], &q3556[0], &q3557[0], &q3558[0], &q3559[0], 
    &q3560[0], &q3561[0], &q3562[0], &q3563[0], &q3564[0], &q3565[0], &q3566[0], &q3567[0], 
    &q3568[0], &q3569[0], &q3570[0], &q3571[0], &q3572[0], &q3573[0], &q3574[0], &q3575[0], 
    &q3576[0], &q3577[0], &q3578[0], &q3579[0], &q3580[0], &q3581[0], &q3582[0], &q3583[0], 
    &q3584[0], &q3585[0], &q3586[0], &q3587[0], &q3588[0], &q3589[0], &q3590[0], &q3591[0], 
    &q3592[0], &q3593[0], &q3594[0], &q3595[0], &q3596[0], &q3597[0], &q3598[0], &q3599[0], 
    &q3600[0], &q3601[0], &q3602[0], &q3603[0], &q3604[0], &q3605[0], &q3606[0], &q3607[0], 
    &q3608[0], &q3609[0], &q3610[0], &q3611[0], &q3612[0], &q3613[0], &q3614[0], &q3615[0], 
    &q3616[0], &q3617[0], &q3618[0], &q3619[0], &q3620[0], &q3621[0], &q3622[0], &q3623[0], 
    &q3624[0], &q3625[0], &q3626[0], &q3627[0], &q3628[0], &q3629[0], &q3630[0], &q3631[0], 
    &q3632[0], &q3633[0], &q3634[0], &q3635[0], &q3636[0], &q3637[0], &q3638[0], &q3639[0], 
    &q3640[0], &q3641[0], &q3642[0], &q3643[0], &q3644[0], &q3645[0], &q3646[0], &q3647[0], 
    &q3648[0], &q3649[0], &q3650[0], &q3651[0], &q3652[0], &q3653[0], &q3654[0], &q3655[0], 
    &q3656[0], &q3657[0], &q3658[0], &q3659[0], &q3660[0], &q3661[0], &q3662[0], &q3663[0], 
    &q3664[0], &q3665[0], &q3666[0], &q3667[0], &q3668[0], &q3669[0], &q3670[0], &q3671[0], 
    &q3672[0], &q3673[0], &q3674[0], &q3675[0], &q3676[0], &q3677[0], &q3678[0], &q3679[0], 
    &q3680[0], &q3681[0], &q3682[0], &q3683[0], &q3684[0], &q3685[0], &q3686[0], &q3687[0], 
    &q3688[0], &q3689[0], &q3690[0], &q3691[0], &q3692[0], &q3693[0], &q3694[0], &q3695[0], 
    &q3696[0], &q3697[0], &q3698[0], &q3699[0], &q3700[0], &q3701[0], &q3702[0], &q3703[0], 
    &q3704[0], &q3705[0], &q3706[0], &q3707[0], &q3708[0], &q3709[0], &q3710[0], &q3711[0], 
    &q3712[0], &q3713[0], &q3714[0], &q3715[0], &q3716[0], &q3717[0], &q3718[0], &q3719[0], 
    &q3720[0], &q3721[0], &q3722[0], &q3723[0], &q3724[0], &q3725[0], &q3726[0], &q3727[0], 
    &q3728[0], &q3729[0], &q3730[0], &q3731[0], &q3732[0], &q3733[0], &q3734[0], &q3735[0], 
    &q3736[0], &q3737[0], &q3738[0], &q3739[0], &q3740[0], &q3741[0], &q3742[0], &q3743[0], 
    &q3744[0], &q3745[0], &q3746[0], &q3747[0], &q3748[0], &q3749[0], &q3750[0], &q3751[0], 
    &q3752[0], &q3753[0], &q3754[0], &q3755[0], &q3756[0], &q3757[0], &q3758[0], &q3759[0], 
    &q3760[0], &q3761[0], &q3762[0], &q3763[0], &q3764[0], &q3765[0], &q3766[0], &q3767[0], 
    &q3768[0], &q3769[0], &q3770[0], &q3771[0], &q3772[0], &q3773[0], &q3774[0], &q3775[0], 
    &q3776[0], &q3777[0], &q3778[0], &q3779[0], &q3780[0], &q3781[0], &q3782[0], &q3783[0], 
    &q3784[0], &q3785[0], &q3786[0], &q3787[0], &q3788[0], &q3789[0], &q3790[0], &q3791[0], 
    &q3792[0], &q3793[0], &q3794[0], &q3795[0], &q3796[0], &q3797[0], &q3798[0], &q3799[0], 
    &q3800[0], &q3801[0], &q3802[0], &q3803[0], &q3804[0], &q3805[0], &q3806[0], &q3807[0], 
    &q3808[0], &q3809[0], &q3810[0], &q3811[0], &q3812[0], &q3813[0], &q3814[0], &q3815[0], 
    &q3816[0], &q3817[0], &q3818[0], &q3819[0], &q3820[0], &q3821[0], &q3822[0], &q3823[0], 
    &q3824[0], &q3825[0], &q3826[0], &q3827[0], &q3828[0], &q3829[0], &q3830[0], &q3831[0], 
    &q3832[0], &q3833[0], &q3834[0], &q3835[0], &q3836[0], &q3837[0], &q3838[0], &q3839[0], 
    &q3840[0], &q3841[0], &q3842[0], &q3843[0], &q3844[0], &q3845[0], &q3846[0], &q3847[0], 
    &q3848[0], &q3849[0], &q3850[0], &q3851[0], &q3852[0], &q3853[0], &q3854[0], &q3855[0], 
    &q3856[0], &q3857[0], &q3858[0], &q3859[0], &q3860[0], &q3861[0], &q3862[0], &q3863[0], 
    &q3864[0], &q3865[0], &q3866[0], &q3867[0], &q3868[0], &q3869[0], &q3870[0], &q3871[0], 
    &q3872[0], &q3873[0], &q3874[0], &q3875[0], &q3876[0], &q3877[0], &q3878[0], &q3879[0], 
    &q3880[0], &q3881[0], &q3882[0], &q3883[0], &q3884[0], &q3885[0], &q3886[0], &q3887[0], 
    &q3888[0], &q3889[0], &q3890[0], &q3891[0], &q3892[0], &q3893[0], &q3894[0], &q3895[0], 
    &q3896[0], &q3897[0], &q3898[0], &q3899[0], &q3900[0], &q3901[0], &q3902[0], &q3903[0], 
    &q3904[0], &q3905[0], &q3906[0], &q3907[0], &q3908[0], &q3909[0], &q3910[0], &q3911[0], 
    &q3912[0], &q3913[0], &q3914[0], &q3915[0], &q3916[0], &q3917[0], &q3918[0], &q3919[0], 
    &q3920[0], &q3921[0], &q3922[0], &q3923[0], &q3924[0], &q3925[0], &q3926[0], &q3927[0], 
    &q3928[0], &q3929[0], &q3930[0], &q3931[0], &q3932[0], &q3933[0], &q3934[0], &q3935[0], 
    &q3936[0], &q3937[0], &q3938[0], &q3939[0], &q3940[0], &q3941[0], &q3942[0], &q3943[0], 
    &q3944[0], &q3945[0], &q3946[0], &q3947[0], &q3948[0], &q3949[0], &q3950[0], &q3951[0], 
    &q3952[0], &q3953[0], &q3954[0], &q3955[0], &q3956[0], &q3957[0], &q3958[0], &q3959[0], 
    &q3960[0], &q3961[0], &q3962[0], &q3963[0], &q3964[0], &q3965[0], &q3966[0], &q3967[0], 
    &q3968[0], &q3969[0], &q3970[0], &q3971[0], &q3972[0], &q3973[0], &q3974[0], &q3975[0], 
    &q3976[0], &q3977[0], &q3978[0], &q3979[0], &q3980[0], &q3981[0], &q3982[0], &q3983[0], 
    &q3984[0], &q3985[0], &q3986[0], &q3987[0], &q3988[0], &q3989[0], &q3990[0], &q3991[0], 
    &q3992[0], &q3993[0], &q3994[0], &q3995[0], &q3996[0], &q3997[0], &q3998[0], &q3999[0], 
    &q4000[0], &q4001[0], &q4002[0], &q4003[0], &q4004[0], &q4005[0], &q4006[0], &q4007[0], 
    &q4008[0], &q4009[0], &q4010[0], &q4011[0], &q4012[0], &q4013[0], &q4014[0], &q4015[0], 
    &q4016[0], &q4017[0], &q4018[0], &q4019[0], &q4020[0], &q4021[0], &q4022[0], &q4023[0], 
    &q4024[0], &q4025[0], &q4026[0], &q4027[0], &q4028[0], &q4029[0], &q4030[0], &q4031[0], 
    &q4032[0], &q4033[0], &q4034[0], &q4035[0], &q4036[0], &q4037[0], &q4038[0], &q4039[0], 
    &q4040[0], &q4041[0], &q4042[0], &q4043[0], &q4044[0], &q4045[0], &q4046[0], &q4047[0], 
    &q4048[0], &q4049[0], &q4050[0], &q4051[0], &q4052[0], &q4053[0], &q4054[0], &q4055[0], 
    &q4056[0], &q4057[0], &q4058[0], &q4059[0], &q4060[0], &q4061[0], &q4062[0], &q4063[0], 
    &q4064[0], &q4065[0], &q4066[0], &q4067[0], &q4068[0], &q4069[0], &q4070[0], &q4071[0], 
    &q4072[0], &q4073[0], &q4074[0], &q4075[0], &q4076[0], &q4077[0], &q4078[0], &q4079[0], 
    &q4080[0], &q4081[0], &q4082[0], &q4083[0], &q4084[0], &q4085[0], &q4086[0], &q4087[0], 
    &q4088[0], &q4089[0], &q4090[0], &q4091[0], &q4092[0], &q4093[0], &q4094[0], &q4095[0], 
    &q4096[0], &q4097[0], &q4098[0], &q4099[0], &q4100[0], &q4101[0], &q4102[0], &q4103[0], 
    &q4104[0], &q4105[0], &q4106[0], &q4107[0], &q4108[0], &q4109[0], &q4110[0], &q4111[0], 
    &q4112[0], &q4113[0], &q4114[0], &q4115[0], &q4116[0], &q4117[0], &q4118[0], &q4119[0], 
    &q4120[0], &q4121[0], &q4122[0], &q4123[0], &q4124[0], &q4125[0], &q4126[0], &q4127[0], 
    &q4128[0], &q4129[0], &q4130[0], &q4131[0], &q4132[0], &q4133[0], &q4134[0], &q4135[0], 
    &q4136[0], &q4137[0], &q4138[0], &q4139[0], &q4140[0], &q4141[0], &q4142[0], &q4143[0], 
    &q4144[0], &q4145[0], &q4146[0], &q4147[0], &q4148[0], &q4149[0], &q4150[0], &q4151[0], 
    &q4152[0], &q4153[0], &q4154[0], &q4155[0], &q4156[0], &q4157[0], &q4158[0], &q4159[0], 
    &q4160[0], &q4161[0], &q4162[0], &q4163[0], &q4164[0], &q4165[0], &q4166[0], &q4167[0], 
    &q4168[0], &q4169[0], &q4170[0], &q4171[0], &q4172[0], &q4173[0], &q4174[0], &q4175[0], 
    &q4176[0], &q4177[0], &q4178[0], &q4179[0], &q4180[0], &q4181[0], &q4182[0], &q4183[0], 
    &q4184[0], &q4185[0], &q4186[0], &q4187[0], &q4188[0], &q4189[0], &q4190[0], &q4191[0], 
    &q4192[0], &q4193[0], &q4194[0], &q4195[0], &q4196[0], &q4197[0], &q4198[0], &q4199[0], 
    &q4200[0], &q4201[0], &q4202[0], &q4203[0], &q4204[0], &q4205[0], &q4206[0], &q4207[0], 
    &q4208[0], &q4209[0], &q4210[0], &q4211[0], &q4212[0], &q4213[0], &q4214[0], &q4215[0], 
    &q4216[0], &q4217[0], &q4218[0], &q4219[0], &q4220[0], &q4221[0], &q4222[0], &q4223[0], 
    &q4224[0], &q4225[0], &q4226[0], &q4227[0], &q4228[0], &q4229[0], &q4230[0], &q4231[0], 
    &q4232[0], &q4233[0], &q4234[0], &q4235[0], &q4236[0], &q4237[0], &q4238[0], &q4239[0], 
    &q4240[0], &q4241[0], &q4242[0], &q4243[0], &q4244[0], &q4245[0], &q4246[0], &q4247[0], 
    &q4248[0], &q4249[0], &q4250[0], &q4251[0], &q4252[0], &q4253[0], &q4254[0], &q4255[0], 
    &q4256[0], &q4257[0], &q4258[0], &q4259[0], &q4260[0], &q4261[0], &q4262[0], &q4263[0], 
    &q4264[0], &q4265[0], &q4266[0], &q4267[0], &q4268[0], &q4269[0], &q4270[0], &q4271[0], 
    &q4272[0], &q4273[0], &q4274[0], &q4275[0], &q4276[0], &q4277[0], &q4278[0], &q4279[0], 
    &q4280[0], &q4281[0], &q4282[0], &q4283[0], &q4284[0], &q4285[0], &q4286[0], &q4287[0], 
    &q4288[0], &q4289[0], &q4290[0], &q4291[0], &q4292[0], &q4293[0], &q4294[0], &q4295[0], 
    &q4296[0], &q4297[0], &q4298[0], &q4299[0], &q4300[0], &q4301[0], &q4302[0], &q4303[0], 
    &q4304[0], &q4305[0], &q4306[0], &q4307[0], &q4308[0], &q4309[0], &q4310[0], &q4311[0], 
    &q4312[0], &q4313[0], &q4314[0], &q4315[0], &q4316[0], &q4317[0], &q4318[0], &q4319[0], 
    &q4320[0], &q4321[0], &q4322[0], &q4323[0], &q4324[0], &q4325[0], &q4326[0], &q4327[0], 
    &q4328[0], &q4329[0], &q4330[0], &q4331[0], &q4332[0], &q4333[0], &q4334[0], &q4335[0], 
    &q4336[0], &q4337[0], &q4338[0], &q4339[0], &q4340[0], &q4341[0], &q4342[0], &q4343[0], 
    &q4344[0], &q4345[0], &q4346[0], &q4347[0], &q4348[0], &q4349[0], &q4350[0], &q4351[0], 
    &q4352[0], &q4353[0], &q4354[0], &q4355[0], &q4356[0], &q4357[0], &q4358[0], &q4359[0], 
    &q4360[0], &q4361[0], &q4362[0], &q4363[0], &q4364[0], &q4365[0], &q4366[0], &q4367[0], 
    &q4368[0], &q4369[0], &q4370[0], &q4371[0], &q4372[0], &q4373[0], &q4374[0], &q4375[0], 
    &q4376[0], &q4377[0], &q4378[0], &q4379[0], &q4380[0], &q4381[0], &q4382[0], &q4383[0], 
    &q4384[0], &q4385[0], &q4386[0], &q4387[0], &q4388[0], &q4389[0], &q4390[0], &q4391[0], 
    &q4392[0], &q4393[0], &q4394[0], &q4395[0], &q4396[0], &q4397[0], &q4398[0], &q4399[0], 
    &q4400[0], &q4401[0], &q4402[0], &q4403[0], &q4404[0], &q4405[0], &q4406[0], &q4407[0], 
    &q4408[0], &q4409[0], &q4410[0], &q4411[0], &q4412[0], &q4413[0], &q4414[0], &q4415[0], 
    &q4416[0], &q4417[0], &q4418[0], &q4419[0], &q4420[0], &q4421[0], &q4422[0], &q4423[0], 
    &q4424[0], &q4425[0], &q4426[0], &q4427[0], &q4428[0], &q4429[0], &q4430[0], &q4431[0], 
    &q4432[0], &q4433[0], &q4434[0], &q4435[0], &q4436[0], &q4437[0], &q4438[0], &q4439[0], 
    &q4440[0], &q4441[0], &q4442[0], &q4443[0], &q4444[0], &q4445[0], &q4446[0], &q4447[0], 
    &q4448[0], &q4449[0], &q4450[0], &q4451[0], &q4452[0], &q4453[0], &q4454[0], &q4455[0], 
    &q4456[0], &q4457[0], &q4458[0], &q4459[0], &q4460[0], &q4461[0], &q4462[0], &q4463[0], 
    &q4464[0], &q4465[0], &q4466[0], &q4467[0], &q4468[0], &q4469[0], &q4470[0], &q4471[0], 
    &q4472[0], &q4473[0], &q4474[0], &q4475[0], &q4476[0], &q4477[0], &q4478[0], &q4479[0], 
    &q4480[0], &q4481[0], &q4482[0], &q4483[0], &q4484[0], &q4485[0], &q4486[0], &q4487[0], 
    &q4488[0], &q4489[0], &q4490[0], &q4491[0], &q4492[0], &q4493[0], &q4494[0], &q4495[0], 
    &q4496[0], &q4497[0], &q4498[0], &q4499[0], &q4500[0], &q4501[0], &q4502[0], &q4503[0], 
    &q4504[0], &q4505[0], &q4506[0], &q4507[0], &q4508[0], &q4509[0], &q4510[0], &q4511[0], 
    &q4512[0], &q4513[0], &q4514[0], &q4515[0], &q4516[0], &q4517[0], &q4518[0], &q4519[0], 
    &q4520[0], &q4521[0], &q4522[0], &q4523[0], &q4524[0], &q4525[0], &q4526[0], &q4527[0], 
    &q4528[0], &q4529[0], &q4530[0], &q4531[0], &q4532[0], &q4533[0], &q4534[0], &q4535[0], 
    &q4536[0], &q4537[0], &q4538[0], &q4539[0], &q4540[0], &q4541[0], &q4542[0], &q4543[0], 
    &q4544[0], &q4545[0], &q4546[0], &q4547[0], &q4548[0], &q4549[0], &q4550[0], &q4551[0], 
    &q4552[0], &q4553[0], &q4554[0], &q4555[0], &q4556[0], &q4557[0], &q4558[0], &q4559[0], 
    &q4560[0], &q4561[0], &q4562[0], &q4563[0], &q4564[0], &q4565[0], &q4566[0], &q4567[0], 
    &q4568[0], &q4569[0], &q4570[0], &q4571[0], &q4572[0], &q4573[0], &q4574[0], &q4575[0], 
    &q4576[0], &q4577[0], &q4578[0], &q4579[0], &q4580[0], &q4581[0], &q4582[0], &q4583[0], 
    &q4584[0], &q4585[0], &q4586[0], &q4587[0], &q4588[0], &q4589[0], &q4590[0], &q4591[0], 
    &q4592[0], &q4593[0], &q4594[0], &q4595[0], &q4596[0], &q4597[0], &q4598[0], &q4599[0], 
    &q4600[0], &q4601[0], &q4602[0], &q4603[0], &q4604[0], &q4605[0], &q4606[0], &q4607[0], 
    &q4608[0], &q4609[0], &q4610[0], &q4611[0], &q4612[0], &q4613[0], &q4614[0], &q4615[0], 
    &q4616[0], &q4617[0], &q4618[0], &q4619[0], &q4620[0], &q4621[0], &q4622[0], &q4623[0], 
    &q4624[0], &q4625[0], &q4626[0], &q4627[0], &q4628[0], &q4629[0], &q4630[0], &q4631[0], 
    &q4632[0], &q4633[0], &q4634[0], &q4635[0], &q4636[0], &q4637[0], &q4638[0], &q4639[0], 
    &q4640[0], &q4641[0], &q4642[0], &q4643[0], &q4644[0], &q4645[0], &q4646[0], &q4647[0], 
    &q4648[0], &q4649[0], &q4650[0], &q4651[0], &q4652[0], &q4653[0], &q4654[0], &q4655[0], 
    &q4656[0], &q4657[0], &q4658[0], &q4659[0], &q4660[0], &q4661[0], &q4662[0], &q4663[0], 
    &q4664[0], &q4665[0], &q4666[0], &q4667[0], &q4668[0], &q4669[0], &q4670[0], &q4671[0], 
    &q4672[0], &q4673[0], &q4674[0], &q4675[0], &q4676[0], &q4677[0], &q4678[0], &q4679[0], 
    &q4680[0], &q4681[0], &q4682[0], &q4683[0], &q4684[0], &q4685[0], &q4686[0], &q4687[0], 
    &q4688[0], &q4689[0], &q4690[0], &q4691[0], &q4692[0], &q4693[0], &q4694[0], &q4695[0], 
    &q4696[0], &q4697[0], &q4698[0], &q4699[0], &q4700[0], &q4701[0], &q4702[0], &q4703[0], 
    &q4704[0], &q4705[0], &q4706[0], &q4707[0], &q4708[0], &q4709[0], &q4710[0], &q4711[0], 
    &q4712[0], &q4713[0], &q4714[0], &q4715[0], &q4716[0], &q4717[0], &q4718[0], &q4719[0], 
    &q4720[0], &q4721[0], &q4722[0], &q4723[0], &q4724[0], &q4725[0], &q4726[0], &q4727[0], 
    &q4728[0], &q4729[0], &q4730[0], &q4731[0], &q4732[0], &q4733[0], &q4734[0], &q4735[0], 
    &q4736[0], &q4737[0], &q4738[0], &q4739[0], &q4740[0], &q4741[0], &q4742[0], &q4743[0], 
    &q4744[0], &q4745[0], &q4746[0], &q4747[0], &q4748[0], &q4749[0], &q4750[0], &q4751[0], 
    &q4752[0], &q4753[0], &q4754[0], &q4755[0], &q4756[0], &q4757[0], &q4758[0], &q4759[0], 
    &q4760[0], &q4761[0], &q4762[0], &q4763[0], &q4764[0], &q4765[0], &q4766[0], &q4767[0], 
    &q4768[0], &q4769[0], &q4770[0], &q4771[0], &q4772[0], &q4773[0], &q4774[0], &q4775[0], 
    &q4776[0], &q4777[0], &q4778[0], &q4779[0], &q4780[0], &q4781[0], &q4782[0], &q4783[0], 
    &q4784[0], &q4785[0], &q4786[0], &q4787[0], &q4788[0], &q4789[0], &q4790[0], &q4791[0], 
    &q4792[0], &q4793[0], &q4794[0], &q4795[0], &q4796[0], &q4797[0], &q4798[0], &q4799[0], 
    &q4800[0], &q4801[0], &q4802[0], &q4803[0], &q4804[0], &q4805[0], &q4806[0], &q4807[0], 
    &q4808[0], &q4809[0], &q4810[0], &q4811[0], &q4812[0], &q4813[0], &q4814[0], &q4815[0], 
    &q4816[0], &q4817[0], &q4818[0], &q4819[0], &q4820[0], &q4821[0], &q4822[0], &q4823[0], 
    &q4824[0], &q4825[0], &q4826[0], &q4827[0], &q4828[0], &q4829[0], &q4830[0], &q4831[0], 
    &q4832[0], &q4833[0], &q4834[0], &q4835[0], &q4836[0], &q4837[0], &q4838[0], &q4839[0], 
    &q4840[0], &q4841[0], &q4842[0], &q4843[0], &q4844[0], &q4845[0], &q4846[0], &q4847[0], 
    &q4848[0], &q4849[0], &q4850[0], &q4851[0], &q4852[0], &q4853[0], &q4854[0], &q4855[0], 
    &q4856[0], &q4857[0], &q4858[0], &q4859[0], &q4860[0], &q4861[0], &q4862[0], &q4863[0], 
    &q4864[0], &q4865[0], &q4866[0], &q4867[0], &q4868[0], &q4869[0], &q4870[0], &q4871[0], 
    &q4872[0], &q4873[0], &q4874[0], &q4875[0], &q4876[0], &q4877[0], &q4878[0], &q4879[0], 
    &q4880[0], &q4881[0], &q4882[0], &q4883[0], &q4884[0], &q4885[0], &q4886[0], &q4887[0], 
    &q4888[0], &q4889[0], &q4890[0], &q4891[0], &q4892[0], &q4893[0], &q4894[0], &q4895[0], 
    &q4896[0], &q4897[0], &q4898[0], &q4899[0], &q4900[0], &q4901[0], &q4902[0], &q4903[0], 
    &q4904[0], &q4905[0], &q4906[0], &q4907[0], &q4908[0], &q4909[0], &q4910[0], &q4911[0], 
    &q4912[0], &q4913[0], &q4914[0], &q4915[0], &q4916[0], &q4917[0], &q4918[0], &q4919[0], 
    &q4920[0], &q4921[0], &q4922[0], &q4923[0], &q4924[0], &q4925[0], &q4926[0], &q4927[0], 
    &q4928[0], &q4929[0], &q4930[0], &q4931[0], &q4932[0], &q4933[0], &q4934[0], &q4935[0], 
    &q4936[0], &q4937[0], &q4938[0], &q4939[0], &q4940[0], &q4941[0], &q4942[0], &q4943[0], 
    &q4944[0], &q4945[0], &q4946[0], &q4947[0], &q4948[0], &q4949[0], &q4950[0], &q4951[0], 
    &q4952[0], &q4953[0], &q4954[0], &q4955[0], &q4956[0], &q4957[0], &q4958[0], &q4959[0], 
    &q4960[0], &q4961[0], &q4962[0], &q4963[0], &q4964[0], &q4965[0], &q4966[0], &q4967[0], 
    &q4968[0], &q4969[0], &q4970[0], &q4971[0], &q4972[0], &q4973[0], &q4974[0], &q4975[0], 
    &q4976[0], &q4977[0], &q4978[0], &q4979[0], &q4980[0], &q4981[0], &q4982[0], &q4983[0], 
    &q4984[0], &q4985[0], &q4986[0], &q4987[0], &q4988[0], &q4989[0], &q4990[0], &q4991[0], 
    &q4992[0], &q4993[0], &q4994[0], &q4995[0], &q4996[0], &q4997[0], &q4998[0], &q4999[0], 
    &q5000[0], &q5001[0], &q5002[0], &q5003[0], &q5004[0], &q5005[0], &q5006[0], &q5007[0], 
    &q5008[0], &q5009[0], &q5010[0], &q5011[0], &q5012[0], &q5013[0], &q5014[0], &q5015[0], 
    &q5016[0], &q5017[0], &q5018[0], &q5019[0], &q5020[0], &q5021[0], &q5022[0], &q5023[0], 
    &q5024[0], &q5025[0], &q5026[0], &q5027[0], &q5028[0], &q5029[0], &q5030[0], &q5031[0], 
    &q5032[0], &q5033[0], &q5034[0], &q5035[0], &q5036[0], &q5037[0], &q5038[0], &q5039[0], 
    &q5040[0], &q5041[0], &q5042[0], &q5043[0], &q5044[0], &q5045[0], &q5046[0], &q5047[0], 
    &q5048[0], &q5049[0], &q5050[0], &q5051[0], &q5052[0], &q5053[0], &q5054[0], &q5055[0], 
    &q5056[0], &q5057[0], &q5058[0], &q5059[0], &q5060[0], &q5061[0], &q5062[0], &q5063[0], 
    &q5064[0], &q5065[0], &q5066[0], &q5067[0], &q5068[0], &q5069[0], &q5070[0], &q5071[0], 
    &q5072[0], &q5073[0], &q5074[0], &q5075[0], &q5076[0], &q5077[0], &q5078[0], &q5079[0], 
    &q5080[0], &q5081[0], &q5082[0], &q5083[0], &q5084[0], &q5085[0], &q5086[0], &q5087[0], 
    &q5088[0], &q5089[0], &q5090[0], &q5091[0], &q5092[0], &q5093[0], &q5094[0], &q5095[0], 
    &q5096[0], &q5097[0], &q5098[0], &q5099[0], &q5100[0], &q5101[0], &q5102[0], &q5103[0], 
    &q5104[0], &q5105[0], &q5106[0], &q5107[0], &q5108[0], &q5109[0], &q5110[0], &q5111[0], 
    &q5112[0], &q5113[0], &q5114[0], &q5115[0], &q5116[0], &q5117[0], &q5118[0], &q5119[0], 
    &q5120[0], &q5121[0], &q5122[0], &q5123[0], &q5124[0], &q5125[0], &q5126[0], &q5127[0], 
    &q5128[0], &q5129[0], &q5130[0], &q5131[0], &q5132[0], &q5133[0], &q5134[0], &q5135[0], 
    &q5136[0], &q5137[0], &q5138[0], &q5139[0], &q5140[0], &q5141[0], &q5142[0], &q5143[0], 
    &q5144[0], &q5145[0], &q5146[0], &q5147[0], &q5148[0], &q5149[0], &q5150[0], &q5151[0], 
    &q5152[0], &q5153[0], &q5154[0], &q5155[0], &q5156[0], &q5157[0], &q5158[0], &q5159[0], 
    &q5160[0], &q5161[0], &q5162[0], &q5163[0], &q5164[0], &q5165[0], &q5166[0], &q5167[0], 
    &q5168[0], &q5169[0], &q5170[0], &q5171[0], &q5172[0], &q5173[0], &q5174[0], &q5175[0], 
    &q5176[0], &q5177[0], &q5178[0], &q5179[0], &q5180[0], &q5181[0], &q5182[0], &q5183[0], 
    &q5184[0], &q5185[0], &q5186[0], &q5187[0], &q5188[0], &q5189[0], &q5190[0], &q5191[0], 
    &q5192[0], &q5193[0], &q5194[0], &q5195[0], &q5196[0], &q5197[0], &q5198[0], &q5199[0], 
    &q5200[0], &q5201[0], &q5202[0], &q5203[0], &q5204[0], &q5205[0], &q5206[0], &q5207[0], 
    &q5208[0], &q5209[0], &q5210[0], &q5211[0], &q5212[0], &q5213[0], &q5214[0], &q5215[0], 
    &q5216[0], &q5217[0], &q5218[0], &q5219[0], &q5220[0], &q5221[0], &q5222[0], &q5223[0], 
    &q5224[0], &q5225[0], &q5226[0], &q5227[0], &q5228[0], &q5229[0], &q5230[0], &q5231[0], 
    &q5232[0], &q5233[0], &q5234[0], &q5235[0], &q5236[0], &q5237[0], &q5238[0], &q5239[0], 
    &q5240[0], &q5241[0], &q5242[0], &q5243[0], &q5244[0], &q5245[0], &q5246[0], &q5247[0], 
    &q5248[0], &q5249[0], &q5250[0], &q5251[0], &q5252[0], &q5253[0], &q5254[0], &q5255[0], 
    &q5256[0], &q5257[0], &q5258[0], &q5259[0], &q5260[0], &q5261[0], &q5262[0], &q5263[0], 
    &q5264[0], &q5265[0], &q5266[0], &q5267[0], &q5268[0], &q5269[0], &q5270[0], &q5271[0], 
    &q5272[0], &q5273[0], &q5274[0], &q5275[0], &q5276[0], &q5277[0], &q5278[0], &q5279[0], 
    &q5280[0], &q5281[0], &q5282[0], &q5283[0], &q5284[0], &q5285[0], &q5286[0], &q5287[0], 
    &q5288[0], &q5289[0], &q5290[0], &q5291[0], &q5292[0], &q5293[0], &q5294[0], &q5295[0], 
    &q5296[0], &q5297[0], &q5298[0], &q5299[0], &q5300[0], &q5301[0], &q5302[0], &q5303[0], 
    &q5304[0], &q5305[0], &q5306[0], &q5307[0], &q5308[0], &q5309[0], &q5310[0], &q5311[0], 
    &q5312[0], &q5313[0], &q5314[0], &q5315[0], &q5316[0], &q5317[0], &q5318[0], &q5319[0], 
    &q5320[0], &q5321[0], &q5322[0], &q5323[0], &q5324[0], &q5325[0], &q5326[0], &q5327[0], 
    &q5328[0], &q5329[0], &q5330[0], &q5331[0], &q5332[0], &q5333[0], &q5334[0], &q5335[0], 
    &q5336[0], &q5337[0], &q5338[0], &q5339[0], &q5340[0], &q5341[0], &q5342[0], &q5343[0], 
    &q5344[0], &q5345[0], &q5346[0], &q5347[0], &q5348[0], &q5349[0], &q5350[0], &q5351[0], 
    &q5352[0], &q5353[0], &q5354[0], &q5355[0], &q5356[0], &q5357[0], &q5358[0], &q5359[0], 
    &q5360[0], &q5361[0], &q5362[0], &q5363[0], &q5364[0], &q5365[0], &q5366[0], &q5367[0], 
    &q5368[0], &q5369[0], &q5370[0], &q5371[0], &q5372[0], &q5373[0], &q5374[0], &q5375[0], 
    &q5376[0], &q5377[0], &q5378[0], &q5379[0], &q5380[0], &q5381[0], &q5382[0], &q5383[0], 
    &q5384[0], &q5385[0], &q5386[0], &q5387[0], &q5388[0], &q5389[0], &q5390[0], &q5391[0], 
    &q5392[0], &q5393[0], &q5394[0], &q5395[0], &q5396[0], &q5397[0], &q5398[0], &q5399[0], 
    &q5400[0], &q5401[0], &q5402[0], &q5403[0], &q5404[0], &q5405[0], &q5406[0], &q5407[0], 
    &q5408[0], &q5409[0], &q5410[0], &q5411[0], &q5412[0], &q5413[0], &q5414[0], &q5415[0], 
    &q5416[0], &q5417[0], &q5418[0], &q5419[0], &q5420[0], &q5421[0], &q5422[0], &q5423[0], 
    &q5424[0], &q5425[0], &q5426[0], &q5427[0], &q5428[0], &q5429[0], &q5430[0], &q5431[0], 
    &q5432[0], &q5433[0], &q5434[0], &q5435[0], &q5436[0], &q5437[0], &q5438[0], &q5439[0], 
    &q5440[0], &q5441[0], &q5442[0], &q5443[0], &q5444[0], &q5445[0], &q5446[0], &q5447[0], 
    &q5448[0], &q5449[0], &q5450[0], &q5451[0], &q5452[0], &q5453[0], &q5454[0], &q5455[0], 
    &q5456[0], &q5457[0], &q5458[0], &q5459[0], &q5460[0], &q5461[0], &q5462[0], &q5463[0], 
    &q5464[0], &q5465[0], &q5466[0], &q5467[0], &q5468[0], &q5469[0], &q5470[0], &q5471[0], 
    &q5472[0], &q5473[0], &q5474[0], &q5475[0], &q5476[0], &q5477[0], &q5478[0], &q5479[0], 
    &q5480[0], &q5481[0], &q5482[0], &q5483[0], &q5484[0], &q5485[0], &q5486[0], &q5487[0], 
    &q5488[0], &q5489[0], &q5490[0], &q5491[0], &q5492[0], &q5493[0], &q5494[0], &q5495[0], 
    &q5496[0], &q5497[0], &q5498[0], &q5499[0], &q5500[0], &q5501[0], &q5502[0], &q5503[0], 
    &q5504[0], &q5505[0], &q5506[0], &q5507[0], &q5508[0], &q5509[0], &q5510[0], &q5511[0], 
    &q5512[0], &q5513[0], &q5514[0], &q5515[0], &q5516[0], &q5517[0], &q5518[0], &q5519[0], 
    &q5520[0], &q5521[0], &q5522[0], &q5523[0], &q5524[0], &q5525[0], &q5526[0], &q5527[0], 
    &q5528[0], &q5529[0], &q5530[0], &q5531[0], &q5532[0], &q5533[0], &q5534[0], &q5535[0], 
    &q5536[0], &q5537[0], &q5538[0], &q5539[0], &q5540[0], &q5541[0], &q5542[0], &q5543[0], 
    &q5544[0], &q5545[0], &q5546[0], &q5547[0], &q5548[0], &q5549[0], &q5550[0], &q5551[0], 
    &q5552[0], &q5553[0], &q5554[0], &q5555[0], &q5556[0], &q5557[0], &q5558[0], &q5559[0], 
    &q5560[0], &q5561[0], &q5562[0], &q5563[0], &q5564[0], &q5565[0], &q5566[0], &q5567[0], 
    &q5568[0], &q5569[0], &q5570[0], &q5571[0], &q5572[0], &q5573[0], &q5574[0], &q5575[0], 
    &q5576[0], &q5577[0], &q5578[0], &q5579[0], &q5580[0], &q5581[0], &q5582[0], &q5583[0], 
    &q5584[0], &q5585[0], &q5586[0], &q5587[0], &q5588[0], &q5589[0], &q5590[0], &q5591[0], 
    &q5592[0], &q5593[0], &q5594[0], &q5595[0], &q5596[0], &q5597[0], &q5598[0], &q5599[0], 
    &q5600[0], &q5601[0], &q5602[0], &q5603[0], &q5604[0], &q5605[0], &q5606[0], &q5607[0], 
    &q5608[0], &q5609[0], &q5610[0], &q5611[0], &q5612[0], &q5613[0], &q5614[0], &q5615[0], 
    &q5616[0], &q5617[0], &q5618[0], &q5619[0], &q5620[0], &q5621[0], &q5622[0], &q5623[0], 
    &q5624[0], &q5625[0], &q5626[0], &q5627[0], &q5628[0], &q5629[0], &q5630[0], &q5631[0], 
    &q5632[0], &q5633[0], &q5634[0], &q5635[0], &q5636[0], &q5637[0], &q5638[0], &q5639[0], 
    &q5640[0], &q5641[0], &q5642[0], &q5643[0], &q5644[0], &q5645[0], &q5646[0], &q5647[0], 
    &q5648[0], &q5649[0], &q5650[0], &q5651[0], &q5652[0], &q5653[0], &q5654[0], &q5655[0], 
    &q5656[0], &q5657[0], &q5658[0], &q5659[0], &q5660[0], &q5661[0], &q5662[0], &q5663[0], 
    &q5664[0], &q5665[0], &q5666[0], &q5667[0], &q5668[0], &q5669[0], &q5670[0], &q5671[0], 
    &q5672[0], &q5673[0], &q5674[0], &q5675[0], &q5676[0], &q5677[0], &q5678[0], &q5679[0], 
    &q5680[0], &q5681[0], &q5682[0], &q5683[0], &q5684[0], &q5685[0], &q5686[0], &q5687[0], 
    &q5688[0], &q5689[0], &q5690[0], &q5691[0], &q5692[0], &q5693[0], &q5694[0], &q5695[0], 
    &q5696[0], &q5697[0], &q5698[0], &q5699[0], &q5700[0], &q5701[0], &q5702[0], &q5703[0], 
    &q5704[0], &q5705[0], &q5706[0], &q5707[0], &q5708[0], &q5709[0], &q5710[0], &q5711[0], 
    &q5712[0], &q5713[0], &q5714[0], &q5715[0], &q5716[0], &q5717[0], &q5718[0], &q5719[0], 
    &q5720[0], &q5721[0], &q5722[0], &q5723[0], &q5724[0], &q5725[0], &q5726[0], &q5727[0], 
    &q5728[0], &q5729[0], &q5730[0], &q5731[0], &q5732[0], &q5733[0], &q5734[0], &q5735[0], 
    &q5736[0], &q5737[0], &q5738[0], &q5739[0], &q5740[0], &q5741[0], &q5742[0], &q5743[0], 
    &q5744[0], &q5745[0], &q5746[0], &q5747[0], &q5748[0], &q5749[0], &q5750[0], &q5751[0], 
    &q5752[0], &q5753[0], &q5754[0], &q5755[0], &q5756[0], &q5757[0], &q5758[0], &q5759[0], 
    &q5760[0], &q5761[0], &q5762[0], &q5763[0], &q5764[0], &q5765[0], &q5766[0], &q5767[0], 
    &q5768[0], &q5769[0], &q5770[0], &q5771[0], &q5772[0], &q5773[0], &q5774[0], &q5775[0], 
    &q5776[0], &q5777[0], &q5778[0], &q5779[0], &q5780[0], &q5781[0], &q5782[0], &q5783[0], 
    &q5784[0], &q5785[0], &q5786[0], &q5787[0], &q5788[0], &q5789[0], &q5790[0], &q5791[0], 
    &q5792[0], &q5793[0], &q5794[0], &q5795[0], &q5796[0], &q5797[0], &q5798[0], &q5799[0], 
    &q5800[0], &q5801[0], &q5802[0], &q5803[0], &q5804[0], &q5805[0], &q5806[0], &q5807[0], 
    &q5808[0], &q5809[0], &q5810[0], &q5811[0], &q5812[0], &q5813[0], &q5814[0], &q5815[0], 
    &q5816[0], &q5817[0], &q5818[0], &q5819[0], &q5820[0], &q5821[0], &q5822[0], &q5823[0], 
    &q5824[0], &q5825[0], &q5826[0], &q5827[0], &q5828[0], &q5829[0], &q5830[0], &q5831[0], 
    &q5832[0], &q5833[0], &q5834[0], &q5835[0], &q5836[0], &q5837[0], &q5838[0], &q5839[0], 
    &q5840[0], &q5841[0], &q5842[0], &q5843[0], &q5844[0], &q5845[0], &q5846[0], &q5847[0], 
    &q5848[0], &q5849[0], &q5850[0], &q5851[0], &q5852[0], &q5853[0], &q5854[0], &q5855[0], 
    &q5856[0], &q5857[0], &q5858[0], &q5859[0], &q5860[0], &q5861[0], &q5862[0], &q5863[0], 
    &q5864[0], &q5865[0], &q5866[0], &q5867[0], &q5868[0], &q5869[0], &q5870[0], &q5871[0], 
    &q5872[0], &q5873[0], &q5874[0], &q5875[0], &q5876[0], &q5877[0], &q5878[0], &q5879[0], 
    &q5880[0], &q5881[0], &q5882[0], &q5883[0], &q5884[0], &q5885[0], &q5886[0], &q5887[0], 
    &q5888[0], &q5889[0], &q5890[0], &q5891[0], &q5892[0], &q5893[0], &q5894[0], &q5895[0], 
    &q5896[0], &q5897[0], &q5898[0], &q5899[0], &q5900[0], &q5901[0], &q5902[0], &q5903[0], 
    &q5904[0], &q5905[0], &q5906[0], &q5907[0], &q5908[0], &q5909[0], &q5910[0], &q5911[0], 
    &q5912[0], &q5913[0], &q5914[0], &q5915[0], &q5916[0], &q5917[0], &q5918[0], &q5919[0], 
    &q5920[0], &q5921[0], &q5922[0], &q5923[0], &q5924[0], &q5925[0], &q5926[0], &q5927[0], 
    &q5928[0], &q5929[0], &q5930[0], &q5931[0], &q5932[0], &q5933[0], &q5934[0], &q5935[0], 
    &q5936[0], &q5937[0], &q5938[0], &q5939[0], &q5940[0], &q5941[0], &q5942[0], &q5943[0], 
    &q5944[0], &q5945[0], &q5946[0], &q5947[0], &q5948[0], &q5949[0], &q5950[0], &q5951[0], 
    &q5952[0], &q5953[0], &q5954[0], &q5955[0], &q5956[0], &q5957[0], &q5958[0], &q5959[0], 
    &q5960[0], &q5961[0], &q5962[0], &q5963[0], &q5964[0], &q5965[0], &q5966[0], &q5967[0], 
    &q5968[0], &q5969[0], &q5970[0], &q5971[0], &q5972[0], &q5973[0], &q5974[0], &q5975[0], 
    &q5976[0], &q5977[0], &q5978[0], &q5979[0], &q5980[0], &q5981[0], &q5982[0], &q5983[0], 
    &q5984[0], &q5985[0], &q5986[0], &q5987[0], &q5988[0], &q5989[0], &q5990[0], &q5991[0], 
    &q5992[0], &q5993[0], &q5994[0], &q5995[0], &q5996[0], &q5997[0], &q5998[0], &q5999[0], 
    &q6000[0], &q6001[0], &q6002[0], &q6003[0], &q6004[0], &q6005[0], &q6006[0], &q6007[0], 
    &q6008[0], &q6009[0], &q6010[0], &q6011[0], &q6012[0], &q6013[0], &q6014[0], &q6015[0], 
    &q6016[0], &q6017[0], &q6018[0], &q6019[0], &q6020[0], &q6021[0], &q6022[0], &q6023[0], 
    &q6024[0], &q6025[0], &q6026[0], &q6027[0], &q6028[0], &q6029[0], &q6030[0], &q6031[0], 
    &q6032[0], &q6033[0], &q6034[0], &q6035[0], &q6036[0], &q6037[0], &q6038[0], &q6039[0], 
    &q6040[0], &q6041[0], &q6042[0], &q6043[0], &q6044[0], &q6045[0], &q6046[0], &q6047[0], 
    &q6048[0], &q6049[0], &q6050[0], &q6051[0], &q6052[0], &q6053[0], &q6054[0], &q6055[0], 
    &q6056[0], &q6057[0], &q6058[0], &q6059[0], &q6060[0], &q6061[0], &q6062[0], &q6063[0], 
    &q6064[0], &q6065[0], &q6066[0], &q6067[0], &q6068[0], &q6069[0], &q6070[0], &q6071[0], 
    &q6072[0], &q6073[0], &q6074[0], &q6075[0], &q6076[0], &q6077[0], &q6078[0], &q6079[0], 
    &q6080[0], &q6081[0], &q6082[0], &q6083[0], &q6084[0], &q6085[0], &q6086[0], &q6087[0], 
    &q6088[0], &q6089[0], &q6090[0], &q6091[0], &q6092[0], &q6093[0], &q6094[0], &q6095[0], 
    &q6096[0], &q6097[0], &q6098[0], &q6099[0], &q6100[0], &q6101[0], &q6102[0], &q6103[0], 
    &q6104[0], &q6105[0], &q6106[0], &q6107[0], &q6108[0], &q6109[0], &q6110[0], &q6111[0], 
    &q6112[0], &q6113[0], &q6114[0], &q6115[0], &q6116[0], &q6117[0], &q6118[0], &q6119[0], 
    &q6120[0], &q6121[0], &q6122[0], &q6123[0], &q6124[0], &q6125[0], &q6126[0], &q6127[0], 
    &q6128[0], &q6129[0], &q6130[0], &q6131[0], &q6132[0], &q6133[0], &q6134[0], &q6135[0], 
    &q6136[0], &q6137[0], &q6138[0], &q6139[0], &q6140[0], &q6141[0], &q6142[0], &q6143[0], 
    &q6144[0], &q6145[0], &q6146[0], &q6147[0], &q6148[0], &q6149[0], &q6150[0], &q6151[0], 
    &q6152[0], &q6153[0], &q6154[0], &q6155[0], &q6156[0], &q6157[0], &q6158[0], &q6159[0], 
    &q6160[0], &q6161[0], &q6162[0], &q6163[0], &q6164[0], &q6165[0], &q6166[0], &q6167[0], 
    &q6168[0], &q6169[0], &q6170[0], &q6171[0], &q6172[0], &q6173[0], &q6174[0], &q6175[0], 
    &q6176[0], &q6177[0], &q6178[0], &q6179[0], &q6180[0], &q6181[0], &q6182[0], &q6183[0], 
    &q6184[0], &q6185[0], &q6186[0], &q6187[0], &q6188[0], &q6189[0], &q6190[0], &q6191[0], 
    &q6192[0], &q6193[0], &q6194[0], &q6195[0], &q6196[0], &q6197[0], &q6198[0], &q6199[0], 
    &q6200[0], &q6201[0], &q6202[0], &q6203[0], &q6204[0], &q6205[0], &q6206[0], &q6207[0], 
    &q6208[0], &q6209[0], &q6210[0], &q6211[0], &q6212[0], &q6213[0], &q6214[0], &q6215[0], 
    &q6216[0], &q6217[0], &q6218[0], &q6219[0], &q6220[0], &q6221[0], &q6222[0], &q6223[0], 
    &q6224[0], &q6225[0], &q6226[0], &q6227[0], &q6228[0], &q6229[0], &q6230[0], &q6231[0], 
    &q6232[0], &q6233[0], &q6234[0], &q6235[0], &q6236[0], &q6237[0], &q6238[0], &q6239[0], 
    &q6240[0], &q6241[0], &q6242[0], &q6243[0], &q6244[0], &q6245[0], &q6246[0], &q6247[0], 
    &q6248[0], &q6249[0], &q6250[0], &q6251[0], &q6252[0], &q6253[0], &q6254[0], &q6255[0], 
    &q6256[0], &q6257[0], &q6258[0], &q6259[0], &q6260[0], &q6261[0], &q6262[0], &q6263[0], 
    &q6264[0], &q6265[0], &q6266[0], &q6267[0], &q6268[0], &q6269[0], &q6270[0], &q6271[0], 
    &q6272[0], &q6273[0], &q6274[0], &q6275[0], &q6276[0], &q6277[0], &q6278[0], &q6279[0], 
    &q6280[0], &q6281[0], &q6282[0], &q6283[0], &q6284[0], &q6285[0], &q6286[0], &q6287[0], 
    &q6288[0], &q6289[0], &q6290[0], &q6291[0], &q6292[0], &q6293[0], &q6294[0], &q6295[0], 
    &q6296[0], &q6297[0], &q6298[0], &q6299[0], &q6300[0], &q6301[0], &q6302[0], &q6303[0], 
    &q6304[0], &q6305[0], &q6306[0], &q6307[0], &q6308[0], &q6309[0], &q6310[0], &q6311[0], 
    &q6312[0], &q6313[0], &q6314[0], &q6315[0], &q6316[0], &q6317[0], &q6318[0], &q6319[0], 
    &q6320[0], &q6321[0], &q6322[0], &q6323[0], &q6324[0], &q6325[0], &q6326[0], &q6327[0], 
    &q6328[0], &q6329[0], &q6330[0], &q6331[0], &q6332[0], &q6333[0], &q6334[0], &q6335[0], 
    &q6336[0], &q6337[0], &q6338[0], &q6339[0], &q6340[0], &q6341[0], &q6342[0], &q6343[0], 
    &q6344[0], &q6345[0], &q6346[0], &q6347[0], &q6348[0], &q6349[0], &q6350[0], &q6351[0], 
    &q6352[0], &q6353[0], &q6354[0], &q6355[0], &q6356[0], &q6357[0], &q6358[0], &q6359[0], 
    &q6360[0], &q6361[0], &q6362[0], &q6363[0], &q6364[0], &q6365[0], &q6366[0], &q6367[0], 
    &q6368[0], &q6369[0], &q6370[0], &q6371[0], &q6372[0], &q6373[0], &q6374[0], &q6375[0], 
    &q6376[0], &q6377[0], &q6378[0], &q6379[0], &q6380[0], &q6381[0], &q6382[0], &q6383[0], 
    &q6384[0], &q6385[0], &q6386[0], &q6387[0], &q6388[0], &q6389[0], &q6390[0], &q6391[0], 
    &q6392[0], &q6393[0], &q6394[0], &q6395[0], &q6396[0], &q6397[0], &q6398[0], &q6399[0], 
    &q6400[0], &q6401[0], &q6402[0], &q6403[0], &q6404[0], &q6405[0], &q6406[0], &q6407[0], 
    &q6408[0], &q6409[0], &q6410[0], &q6411[0], &q6412[0], &q6413[0], &q6414[0], &q6415[0], 
    &q6416[0], &q6417[0], &q6418[0], &q6419[0], &q6420[0], &q6421[0], &q6422[0], &q6423[0], 
    &q6424[0], &q6425[0], &q6426[0], &q6427[0], &q6428[0], &q6429[0], &q6430[0], &q6431[0], 
    &q6432[0], &q6433[0], &q6434[0], &q6435[0], &q6436[0], &q6437[0], &q6438[0], &q6439[0], 
    &q6440[0], &q6441[0], &q6442[0], &q6443[0], &q6444[0], &q6445[0], &q6446[0], &q6447[0], 
    &q6448[0], &q6449[0], &q6450[0], &q6451[0], &q6452[0], &q6453[0], &q6454[0], &q6455[0], 
    &q6456[0], &q6457[0], &q6458[0], &q6459[0], &q6460[0], &q6461[0], &q6462[0], &q6463[0], 
    &q6464[0], &q6465[0], &q6466[0], &q6467[0], &q6468[0], &q6469[0], &q6470[0], &q6471[0], 
    &q6472[0], &q6473[0], &q6474[0], &q6475[0], &q6476[0], &q6477[0], &q6478[0], &q6479[0], 
    &q6480[0], &q6481[0], &q6482[0], &q6483[0], &q6484[0], &q6485[0], &q6486[0], &q6487[0], 
    &q6488[0], &q6489[0], &q6490[0], &q6491[0], &q6492[0], &q6493[0], &q6494[0], &q6495[0], 
    &q6496[0], &q6497[0], &q6498[0], &q6499[0], &q6500[0], &q6501[0], &q6502[0], &q6503[0], 
    &q6504[0], &q6505[0], &q6506[0], &q6507[0], &q6508[0], &q6509[0], &q6510[0], &q6511[0], 
    &q6512[0], &q6513[0], &q6514[0], &q6515[0], &q6516[0], &q6517[0], &q6518[0], &q6519[0], 
    &q6520[0], &q6521[0], &q6522[0], &q6523[0], &q6524[0], &q6525[0], &q6526[0], &q6527[0], 
    &q6528[0], &q6529[0], &q6530[0], &q6531[0], &q6532[0], &q6533[0], &q6534[0], &q6535[0], 
    &q6536[0], &q6537[0], &q6538[0], &q6539[0], &q6540[0], &q6541[0], &q6542[0], &q6543[0], 
    &q6544[0], &q6545[0], &q6546[0], &q6547[0], &q6548[0], &q6549[0], &q6550[0], &q6551[0], 
    &q6552[0], &q6553[0], &q6554[0], &q6555[0], &q6556[0], &q6557[0], &q6558[0], &q6559[0], 
    &q6560[0], &q6561[0], &q6562[0], &q6563[0], &q6564[0], &q6565[0], &q6566[0], &q6567[0], 
    &q6568[0], &q6569[0], &q6570[0], &q6571[0], &q6572[0], &q6573[0], &q6574[0], &q6575[0], 
    &q6576[0], &q6577[0], &q6578[0], &q6579[0], &q6580[0], &q6581[0], &q6582[0], &q6583[0], 
    &q6584[0], &q6585[0], &q6586[0], &q6587[0], &q6588[0], &q6589[0], &q6590[0], &q6591[0], 
    &q6592[0], &q6593[0], &q6594[0], &q6595[0], &q6596[0], &q6597[0], &q6598[0], &q6599[0], 
    &q6600[0], &q6601[0], &q6602[0], &q6603[0], &q6604[0], &q6605[0], &q6606[0], &q6607[0], 
    &q6608[0], &q6609[0], &q6610[0], &q6611[0], &q6612[0], &q6613[0], &q6614[0], &q6615[0], 
    &q6616[0], &q6617[0], &q6618[0], &q6619[0], &q6620[0], &q6621[0], &q6622[0], &q6623[0], 
    &q6624[0], &q6625[0], &q6626[0], &q6627[0], &q6628[0], &q6629[0], &q6630[0], &q6631[0], 
    &q6632[0], &q6633[0], &q6634[0], &q6635[0], &q6636[0], &q6637[0], &q6638[0], &q6639[0], 
    &q6640[0], &q6641[0], &q6642[0], &q6643[0], &q6644[0], &q6645[0], &q6646[0], &q6647[0], 
    &q6648[0], &q6649[0], &q6650[0], &q6651[0], &q6652[0], &q6653[0], &q6654[0], &q6655[0], 
    &q6656[0], &q6657[0], &q6658[0], &q6659[0], &q6660[0], &q6661[0], &q6662[0], &q6663[0], 
    &q6664[0], &q6665[0], &q6666[0], &q6667[0], &q6668[0], &q6669[0], &q6670[0], &q6671[0], 
    &q6672[0], &q6673[0], &q6674[0], &q6675[0], &q6676[0], &q6677[0], &q6678[0], &q6679[0], 
    &q6680[0], &q6681[0], &q6682[0], &q6683[0], &q6684[0], &q6685[0], &q6686[0], &q6687[0], 
    &q6688[0], &q6689[0], &q6690[0], &q6691[0], &q6692[0], &q6693[0], &q6694[0], &q6695[0], 
    &q6696[0], &q6697[0], &q6698[0], &q6699[0], &q6700[0], &q6701[0], &q6702[0], &q6703[0], 
    &q6704[0], &q6705[0], &q6706[0], &q6707[0], &q6708[0], &q6709[0], &q6710[0], &q6711[0], 
    &q6712[0], &q6713[0], &q6714[0], &q6715[0], &q6716[0], &q6717[0], &q6718[0], &q6719[0], 
    &q6720[0], &q6721[0], &q6722[0], &q6723[0], &q6724[0], &q6725[0], &q6726[0], &q6727[0], 
    &q6728[0], &q6729[0], &q6730[0], &q6731[0], &q6732[0], &q6733[0], &q6734[0], &q6735[0], 
    &q6736[0], &q6737[0], &q6738[0], &q6739[0], &q6740[0], &q6741[0], &q6742[0], &q6743[0], 
    &q6744[0], &q6745[0], &q6746[0], &q6747[0], &q6748[0], &q6749[0], &q6750[0], &q6751[0], 
    &q6752[0], &q6753[0], &q6754[0], &q6755[0], &q6756[0], &q6757[0], &q6758[0], &q6759[0], 
    &q6760[0], &q6761[0], &q6762[0], &q6763[0], &q6764[0], &q6765[0], &q6766[0], &q6767[0], 
    &q6768[0], &q6769[0], &q6770[0], &q6771[0], &q6772[0], &q6773[0], &q6774[0], &q6775[0], 
    &q6776[0], &q6777[0], &q6778[0], &q6779[0], &q6780[0], &q6781[0], &q6782[0], &q6783[0], 
    &q6784[0], &q6785[0], &q6786[0], &q6787[0], &q6788[0], &q6789[0], &q6790[0], &q6791[0], 
    &q6792[0], &q6793[0], &q6794[0], &q6795[0], &q6796[0], &q6797[0], &q6798[0], &q6799[0], 
    &q6800[0], &q6801[0], &q6802[0], &q6803[0], &q6804[0], &q6805[0], &q6806[0], &q6807[0], 
    &q6808[0], &q6809[0], &q6810[0], &q6811[0], &q6812[0], &q6813[0], &q6814[0], &q6815[0], 
    &q6816[0], &q6817[0], &q6818[0], &q6819[0], &q6820[0], &q6821[0], &q6822[0], &q6823[0], 
    &q6824[0], &q6825[0], &q6826[0], &q6827[0], &q6828[0], &q6829[0], &q6830[0], &q6831[0], 
    &q6832[0], &q6833[0], &q6834[0], &q6835[0], &q6836[0], &q6837[0], &q6838[0], &q6839[0], 
    &q6840[0], &q6841[0], &q6842[0], &q6843[0], &q6844[0], &q6845[0], &q6846[0], &q6847[0], 
    &q6848[0], &q6849[0], &q6850[0], &q6851[0], &q6852[0], &q6853[0], &q6854[0], &q6855[0], 
    &q6856[0], &q6857[0], &q6858[0], &q6859[0], &q6860[0], &q6861[0], &q6862[0], &q6863[0], 
    &q6864[0], &q6865[0], &q6866[0], &q6867[0], &q6868[0], &q6869[0], &q6870[0], &q6871[0], 
    &q6872[0], &q6873[0], &q6874[0], &q6875[0], &q6876[0], &q6877[0], &q6878[0], &q6879[0], 
    &q6880[0], &q6881[0], &q6882[0], &q6883[0], &q6884[0], &q6885[0], &q6886[0], &q6887[0], 
    &q6888[0], &q6889[0], &q6890[0], &q6891[0], &q6892[0], &q6893[0], &q6894[0], &q6895[0], 
    &q6896[0], &q6897[0], &q6898[0], &q6899[0], &q6900[0], &q6901[0], &q6902[0], &q6903[0], 
    &q6904[0], &q6905[0], &q6906[0], &q6907[0], &q6908[0], &q6909[0], &q6910[0], &q6911[0], 
    &q6912[0], &q6913[0], &q6914[0], &q6915[0], &q6916[0], &q6917[0], &q6918[0], &q6919[0], 
    &q6920[0], &q6921[0], &q6922[0], &q6923[0], &q6924[0], &q6925[0], &q6926[0], &q6927[0], 
    &q6928[0], &q6929[0], &q6930[0], &q6931[0], &q6932[0], &q6933[0], &q6934[0], &q6935[0], 
    &q6936[0], &q6937[0], &q6938[0], &q6939[0], &q6940[0], &q6941[0], &q6942[0], &q6943[0], 
    &q6944[0], &q6945[0], &q6946[0], &q6947[0], &q6948[0], &q6949[0], &q6950[0], &q6951[0], 
    &q6952[0], &q6953[0], &q6954[0], &q6955[0], &q6956[0], &q6957[0], &q6958[0], &q6959[0], 
    &q6960[0], &q6961[0], &q6962[0], &q6963[0], &q6964[0], &q6965[0], &q6966[0], &q6967[0], 
    &q6968[0], &q6969[0], &q6970[0], &q6971[0], &q6972[0], &q6973[0], &q6974[0], &q6975[0], 
    &q6976[0], &q6977[0], &q6978[0], &q6979[0], &q6980[0], &q6981[0], &q6982[0], &q6983[0], 
    &q6984[0], &q6985[0], &q6986[0], &q6987[0], &q6988[0], &q6989[0], &q6990[0], &q6991[0], 
    &q6992[0], &q6993[0], &q6994[0], &q6995[0], &q6996[0], &q6997[0], &q6998[0], &q6999[0], 
    &q7000[0], &q7001[0], &q7002[0], &q7003[0], &q7004[0], &q7005[0], &q7006[0], &q7007[0], 
    &q7008[0], &q7009[0], &q7010[0], &q7011[0], &q7012[0], &q7013[0], &q7014[0], &q7015[0], 
    &q7016[0], &q7017[0], &q7018[0], &q7019[0], &q7020[0], &q7021[0], &q7022[0], &q7023[0], 
    &q7024[0], &q7025[0], &q7026[0], &q7027[0], &q7028[0], &q7029[0], &q7030[0], &q7031[0], 
    &q7032[0], &q7033[0], &q7034[0], &q7035[0], &q7036[0], &q7037[0], &q7038[0], &q7039[0], 
    &q7040[0], &q7041[0], &q7042[0], &q7043[0], &q7044[0], &q7045[0], &q7046[0], &q7047[0], 
    &q7048[0], &q7049[0], &q7050[0], &q7051[0], &q7052[0], &q7053[0], &q7054[0], &q7055[0], 
    &q7056[0], &q7057[0], &q7058[0], &q7059[0], &q7060[0], &q7061[0], &q7062[0], &q7063[0], 
    &q7064[0], &q7065[0], &q7066[0], &q7067[0], &q7068[0], &q7069[0], &q7070[0], &q7071[0], 
    &q7072[0], &q7073[0], &q7074[0], &q7075[0], &q7076[0], &q7077[0], &q7078[0], &q7079[0], 
    &q7080[0], &q7081[0], &q7082[0], &q7083[0], &q7084[0], &q7085[0], &q7086[0], &q7087[0], 
    &q7088[0], &q7089[0], &q7090[0], &q7091[0], &q7092[0], &q7093[0], &q7094[0], &q7095[0], 
    &q7096[0], &q7097[0], &q7098[0], &q7099[0], &q7100[0], &q7101[0], &q7102[0], &q7103[0], 
    &q7104[0], &q7105[0], &q7106[0], &q7107[0], &q7108[0], &q7109[0], &q7110[0], &q7111[0], 
    &q7112[0], &q7113[0], &q7114[0], &q7115[0], &q7116[0], &q7117[0], &q7118[0], &q7119[0], 
    &q7120[0], &q7121[0], &q7122[0], &q7123[0], &q7124[0], &q7125[0], &q7126[0], &q7127[0], 
    &q7128[0], &q7129[0], &q7130[0], &q7131[0], &q7132[0], &q7133[0], &q7134[0], &q7135[0], 
    &q7136[0], &q7137[0], &q7138[0], &q7139[0], &q7140[0], &q7141[0], &q7142[0], &q7143[0], 
    &q7144[0], &q7145[0], &q7146[0], &q7147[0], &q7148[0], &q7149[0], &q7150[0], &q7151[0], 
    &q7152[0], &q7153[0], &q7154[0], &q7155[0], &q7156[0], &q7157[0], &q7158[0], &q7159[0], 
    &q7160[0], &q7161[0], &q7162[0], &q7163[0], &q7164[0], &q7165[0], &q7166[0], &q7167[0], 
    &q7168[0], &q7169[0], &q7170[0], &q7171[0], &q7172[0], &q7173[0], &q7174[0], &q7175[0], 
    &q7176[0], &q7177[0], &q7178[0], &q7179[0], &q7180[0], &q7181[0], &q7182[0], &q7183[0], 
    &q7184[0], &q7185[0], &q7186[0], &q7187[0], &q7188[0], &q7189[0], &q7190[0], &q7191[0], 
    &q7192[0], &q7193[0], &q7194[0], &q7195[0], &q7196[0], &q7197[0], &q7198[0], &q7199[0], 
    &q7200[0], &q7201[0], &q7202[0], &q7203[0], &q7204[0], &q7205[0], &q7206[0], &q7207[0], 
    &q7208[0], &q7209[0], &q7210[0], &q7211[0], &q7212[0], &q7213[0], &q7214[0], &q7215[0], 
    &q7216[0], &q7217[0], &q7218[0], &q7219[0], &q7220[0], &q7221[0], &q7222[0], &q7223[0], 
    &q7224[0], &q7225[0], &q7226[0], &q7227[0], &q7228[0], &q7229[0], &q7230[0], &q7231[0], 
    &q7232[0], &q7233[0], &q7234[0], &q7235[0], &q7236[0], &q7237[0], &q7238[0], &q7239[0], 
    &q7240[0], &q7241[0], &q7242[0], &q7243[0], &q7244[0], &q7245[0], &q7246[0], &q7247[0], 
    &q7248[0], &q7249[0], &q7250[0], &q7251[0], &q7252[0], &q7253[0], &q7254[0], &q7255[0], 
    &q7256[0], &q7257[0], &q7258[0], &q7259[0], &q7260[0], &q7261[0], &q7262[0], &q7263[0], 
    &q7264[0], &q7265[0], &q7266[0], &q7267[0], &q7268[0], &q7269[0], &q7270[0], &q7271[0], 
    &q7272[0], &q7273[0], &q7274[0], &q7275[0], &q7276[0], &q7277[0], &q7278[0], &q7279[0], 
    &q7280[0], &q7281[0], &q7282[0], &q7283[0], &q7284[0], &q7285[0], &q7286[0], &q7287[0], 
    &q7288[0], &q7289[0], &q7290[0], &q7291[0], &q7292[0], &q7293[0], &q7294[0], &q7295[0], 
    &q7296[0], &q7297[0], &q7298[0], &q7299[0], &q7300[0], &q7301[0], &q7302[0], &q7303[0], 
    &q7304[0], &q7305[0], &q7306[0], &q7307[0], &q7308[0], &q7309[0], &q7310[0], &q7311[0], 
    &q7312[0], &q7313[0], &q7314[0], &q7315[0], &q7316[0], &q7317[0], &q7318[0], &q7319[0], 
    &q7320[0], &q7321[0], &q7322[0], &q7323[0], &q7324[0], &q7325[0], &q7326[0], &q7327[0], 
    &q7328[0], &q7329[0], &q7330[0], &q7331[0], &q7332[0], &q7333[0], &q7334[0], &q7335[0], 
    &q7336[0], &q7337[0], &q7338[0], &q7339[0], &q7340[0], &q7341[0], &q7342[0], &q7343[0], 
    &q7344[0], &q7345[0], &q7346[0], &q7347[0], &q7348[0], &q7349[0], &q7350[0], &q7351[0], 
    &q7352[0], &q7353[0], &q7354[0], &q7355[0], &q7356[0], &q7357[0], &q7358[0], &q7359[0], 
    &q7360[0], &q7361[0], &q7362[0], &q7363[0], &q7364[0], &q7365[0], &q7366[0], &q7367[0], 
    &q7368[0], &q7369[0], &q7370[0], &q7371[0], &q7372[0], &q7373[0], &q7374[0], &q7375[0], 
    &q7376[0], &q7377[0], &q7378[0], &q7379[0], &q7380[0], &q7381[0], &q7382[0], &q7383[0], 
    &q7384[0], &q7385[0], &q7386[0], &q7387[0], &q7388[0], &q7389[0], &q7390[0], &q7391[0], 
    &q7392[0], &q7393[0], &q7394[0], &q7395[0], &q7396[0], &q7397[0], &q7398[0], &q7399[0], 
    &q7400[0], &q7401[0], &q7402[0], &q7403[0], &q7404[0], &q7405[0], &q7406[0], &q7407[0], 
    &q7408[0], &q7409[0], &q7410[0], &q7411[0], &q7412[0], &q7413[0], &q7414[0], &q7415[0], 
    &q7416[0], &q7417[0], &q7418[0], &q7419[0], &q7420[0], &q7421[0], &q7422[0], &q7423[0], 
    &q7424[0], &q7425[0], &q7426[0], &q7427[0], &q7428[0], &q7429[0], &q7430[0], &q7431[0], 
    &q7432[0], &q7433[0], &q7434[0], &q7435[0], &q7436[0], &q7437[0], &q7438[0], &q7439[0], 
    &q7440[0], &q7441[0], &q7442[0], &q7443[0], &q7444[0], &q7445[0], &q7446[0], &q7447[0], 
    &q7448[0], &q7449[0], &q7450[0], &q7451[0], &q7452[0], &q7453[0], &q7454[0], &q7455[0], 
    &q7456[0], &q7457[0], &q7458[0], &q7459[0], &q7460[0], &q7461[0], &q7462[0], &q7463[0], 
    &q7464[0], &q7465[0], &q7466[0], &q7467[0], &q7468[0], &q7469[0], &q7470[0], &q7471[0], 
    &q7472[0], &q7473[0], &q7474[0], &q7475[0], &q7476[0], &q7477[0], &q7478[0], &q7479[0], 
    &q7480[0], &q7481[0], &q7482[0], &q7483[0], &q7484[0], &q7485[0], &q7486[0], &q7487[0], 
    &q7488[0], &q7489[0], &q7490[0], &q7491[0], &q7492[0], &q7493[0], &q7494[0], &q7495[0], 
    &q7496[0], &q7497[0], &q7498[0], &q7499[0], &q7500[0], &q7501[0], &q7502[0], &q7503[0], 
    &q7504[0], &q7505[0], &q7506[0], &q7507[0], &q7508[0], &q7509[0], &q7510[0], &q7511[0], 
    &q7512[0], &q7513[0], &q7514[0], &q7515[0], &q7516[0], &q7517[0], &q7518[0], &q7519[0], 
    &q7520[0], &q7521[0], &q7522[0], &q7523[0], &q7524[0], &q7525[0], &q7526[0], &q7527[0], 
    &q7528[0], &q7529[0], &q7530[0], &q7531[0], &q7532[0], &q7533[0], &q7534[0], &q7535[0], 
    &q7536[0], &q7537[0], &q7538[0], &q7539[0], &q7540[0], &q7541[0], &q7542[0], &q7543[0], 
    &q7544[0], &q7545[0], &q7546[0], &q7547[0], &q7548[0], &q7549[0], &q7550[0], &q7551[0], 
    &q7552[0], &q7553[0], &q7554[0], &q7555[0], &q7556[0], &q7557[0], &q7558[0], &q7559[0], 
    &q7560[0], &q7561[0], &q7562[0], &q7563[0], &q7564[0], &q7565[0], &q7566[0], &q7567[0], 
    &q7568[0], &q7569[0], &q7570[0], &q7571[0], &q7572[0], &q7573[0], &q7574[0], &q7575[0], 
    &q7576[0], &q7577[0], &q7578[0], &q7579[0], &q7580[0], &q7581[0], &q7582[0], &q7583[0], 
    &q7584[0], &q7585[0], &q7586[0], &q7587[0], &q7588[0], &q7589[0], &q7590[0], &q7591[0], 
    &q7592[0], &q7593[0], &q7594[0], &q7595[0], &q7596[0], &q7597[0], &q7598[0], &q7599[0], 
    &q7600[0], &q7601[0], &q7602[0], &q7603[0], &q7604[0], &q7605[0], &q7606[0], &q7607[0], 
    &q7608[0], &q7609[0], &q7610[0], &q7611[0], &q7612[0], &q7613[0], &q7614[0], &q7615[0], 
    &q7616[0], &q7617[0], &q7618[0], &q7619[0], &q7620[0], &q7621[0], &q7622[0], &q7623[0], 
    &q7624[0], &q7625[0], &q7626[0], &q7627[0], &q7628[0], &q7629[0], &q7630[0], &q7631[0], 
    &q7632[0], &q7633[0], &q7634[0], &q7635[0], &q7636[0], &q7637[0], &q7638[0], &q7639[0], 
    &q7640[0], &q7641[0], &q7642[0], &q7643[0], &q7644[0], &q7645[0], &q7646[0], &q7647[0], 
    &q7648[0], &q7649[0], &q7650[0], &q7651[0], &q7652[0], &q7653[0], &q7654[0], &q7655[0], 
    &q7656[0], &q7657[0], &q7658[0], &q7659[0], &q7660[0], &q7661[0], &q7662[0], &q7663[0], 
    &q7664[0], &q7665[0], &q7666[0], &q7667[0], &q7668[0], &q7669[0], &q7670[0], &q7671[0], 
    &q7672[0], &q7673[0], &q7674[0], &q7675[0], &q7676[0], &q7677[0], &q7678[0], &q7679[0], 
    &q7680[0], &q7681[0], &q7682[0], &q7683[0], &q7684[0], &q7685[0], &q7686[0], &q7687[0], 
    &q7688[0], &q7689[0], &q7690[0], &q7691[0], &q7692[0], &q7693[0], &q7694[0], &q7695[0], 
    &q7696[0], &q7697[0], &q7698[0], &q7699[0], &q7700[0], &q7701[0], &q7702[0], &q7703[0], 
    &q7704[0], &q7705[0], &q7706[0], &q7707[0], &q7708[0], &q7709[0], &q7710[0], &q7711[0], 
    &q7712[0], &q7713[0], &q7714[0], &q7715[0], &q7716[0], &q7717[0], &q7718[0], &q7719[0], 
    &q7720[0], &q7721[0], &q7722[0], &q7723[0], &q7724[0], &q7725[0], &q7726[0], &q7727[0], 
    &q7728[0], &q7729[0], &q7730[0], &q7731[0], &q7732[0], &q7733[0], &q7734[0], &q7735[0], 
    &q7736[0], &q7737[0], &q7738[0], &q7739[0], &q7740[0], &q7741[0], &q7742[0], &q7743[0], 
    &q7744[0], &q7745[0], &q7746[0], &q7747[0], &q7748[0], &q7749[0], &q7750[0], &q7751[0], 
    &q7752[0], &q7753[0], &q7754[0], &q7755[0], &q7756[0], &q7757[0], &q7758[0], &q7759[0], 
    &q7760[0], &q7761[0], &q7762[0], &q7763[0], &q7764[0], &q7765[0], &q7766[0], &q7767[0], 
    &q7768[0], &q7769[0], &q7770[0], &q7771[0], &q7772[0], &q7773[0], &q7774[0], &q7775[0], 
    &q7776[0], &q7777[0], &q7778[0], &q7779[0], &q7780[0], &q7781[0], &q7782[0], &q7783[0], 
    &q7784[0], &q7785[0], &q7786[0], &q7787[0], &q7788[0], &q7789[0], &q7790[0], &q7791[0], 
    &q7792[0], &q7793[0], &q7794[0], &q7795[0], &q7796[0], &q7797[0], &q7798[0], &q7799[0], 
    &q7800[0], &q7801[0], &q7802[0], &q7803[0], &q7804[0], &q7805[0], &q7806[0], &q7807[0], 
    &q7808[0], &q7809[0], &q7810[0], &q7811[0], &q7812[0], &q7813[0], &q7814[0], &q7815[0], 
    &q7816[0], &q7817[0], &q7818[0], &q7819[0], &q7820[0], &q7821[0], &q7822[0], &q7823[0], 
    &q7824[0], &q7825[0], &q7826[0], &q7827[0], &q7828[0], &q7829[0], &q7830[0], &q7831[0], 
    &q7832[0], &q7833[0], &q7834[0], &q7835[0], &q7836[0], &q7837[0], &q7838[0], &q7839[0], 
    &q7840[0], &q7841[0], &q7842[0], &q7843[0], &q7844[0], &q7845[0], &q7846[0], &q7847[0], 
    &q7848[0], &q7849[0], &q7850[0], &q7851[0], &q7852[0], &q7853[0], &q7854[0], &q7855[0], 
    &q7856[0], &q7857[0], &q7858[0], &q7859[0], &q7860[0], &q7861[0], &q7862[0], &q7863[0], 
    &q7864[0], &q7865[0], &q7866[0], &q7867[0], &q7868[0], &q7869[0], &q7870[0], &q7871[0], 
    &q7872[0], &q7873[0], &q7874[0], &q7875[0], &q7876[0], &q7877[0], &q7878[0], &q7879[0], 
    &q7880[0], &q7881[0], &q7882[0], &q7883[0], &q7884[0], &q7885[0], &q7886[0], &q7887[0], 
    &q7888[0], &q7889[0], &q7890[0], &q7891[0], &q7892[0], &q7893[0], &q7894[0], &q7895[0], 
    &q7896[0], &q7897[0], &q7898[0], &q7899[0], &q7900[0], &q7901[0], &q7902[0], &q7903[0], 
    &q7904[0], &q7905[0], &q7906[0], &q7907[0], &q7908[0], &q7909[0], &q7910[0], &q7911[0], 
    &q7912[0], &q7913[0], &q7914[0], &q7915[0], &q7916[0], &q7917[0], &q7918[0], &q7919[0], 
    &q7920[0], &q7921[0], &q7922[0], &q7923[0], &q7924[0], &q7925[0], &q7926[0], &q7927[0], 
    &q7928[0], &q7929[0], &q7930[0], &q7931[0], &q7932[0], &q7933[0], &q7934[0], &q7935[0], 
    &q7936[0], &q7937[0], &q7938[0], &q7939[0], &q7940[0], &q7941[0], &q7942[0], &q7943[0], 
    &q7944[0], &q7945[0], &q7946[0], &q7947[0], &q7948[0], &q7949[0], &q7950[0], &q7951[0], 
    &q7952[0], &q7953[0], &q7954[0], &q7955[0], &q7956[0], &q7957[0], &q7958[0], &q7959[0], 
    &q7960[0], &q7961[0], &q7962[0], &q7963[0], &q7964[0], &q7965[0], &q7966[0], &q7967[0], 
    &q7968[0], &q7969[0], &q7970[0], &q7971[0], &q7972[0], &q7973[0], &q7974[0], &q7975[0], 
    &q7976[0], &q7977[0], &q7978[0], &q7979[0], &q7980[0], &q7981[0], &q7982[0], &q7983[0], 
    &q7984[0], &q7985[0], &q7986[0], &q7987[0], &q7988[0], &q7989[0], &q7990[0], &q7991[0], 
    &q7992[0], &q7993[0], &q7994[0], &q7995[0], &q7996[0], &q7997[0], &q7998[0], &q7999[0], 
    &q8000[0], &q8001[0], &q8002[0], &q8003[0], &q8004[0], &q8005[0], &q8006[0], &q8007[0], 
    &q8008[0], &q8009[0], &q8010[0], &q8011[0], &q8012[0], &q8013[0], &q8014[0], &q8015[0], 
    &q8016[0], &q8017[0], &q8018[0], &q8019[0], &q8020[0], &q8021[0], &q8022[0], &q8023[0], 
    &q8024[0], &q8025[0], &q8026[0], &q8027[0], &q8028[0], &q8029[0], &q8030[0], &q8031[0], 
    &q8032[0], &q8033[0], &q8034[0], &q8035[0], &q8036[0], &q8037[0], &q8038[0], &q8039[0], 
    &q8040[0], &q8041[0], &q8042[0], &q8043[0], &q8044[0], &q8045[0], &q8046[0], &q8047[0], 
    &q8048[0], &q8049[0], &q8050[0], &q8051[0], &q8052[0], &q8053[0], &q8054[0], &q8055[0], 
    &q8056[0], &q8057[0], &q8058[0], &q8059[0], &q8060[0], &q8061[0], &q8062[0], &q8063[0], 
    &q8064[0], &q8065[0], &q8066[0], &q8067[0], &q8068[0], &q8069[0], &q8070[0], &q8071[0], 
    &q8072[0], &q8073[0], &q8074[0], &q8075[0], &q8076[0], &q8077[0], &q8078[0], &q8079[0], 
    &q8080[0], &q8081[0], &q8082[0], &q8083[0], &q8084[0], &q8085[0], &q8086[0], &q8087[0], 
    &q8088[0], &q8089[0], &q8090[0], &q8091[0], &q8092[0], &q8093[0], &q8094[0], &q8095[0], 
    &q8096[0], &q8097[0], &q8098[0], &q8099[0], &q8100[0], &q8101[0], &q8102[0], &q8103[0], 
    &q8104[0], &q8105[0], &q8106[0], &q8107[0], &q8108[0], &q8109[0], &q8110[0], &q8111[0], 
    &q8112[0], &q8113[0], &q8114[0], &q8115[0], &q8116[0], &q8117[0], &q8118[0], &q8119[0], 
    &q8120[0], &q8121[0], &q8122[0], &q8123[0], &q8124[0], &q8125[0], &q8126[0], &q8127[0], 
    &q8128[0], &q8129[0], &q8130[0], &q8131[0], &q8132[0], &q8133[0], &q8134[0], &q8135[0], 
    &q8136[0], &q8137[0], &q8138[0], &q8139[0], &q8140[0], &q8141[0], &q8142[0], &q8143[0], 
    &q8144[0], &q8145[0], &q8146[0], &q8147[0], &q8148[0], &q8149[0], &q8150[0], &q8151[0], 
    &q8152[0], &q8153[0], &q8154[0], &q8155[0], &q8156[0], &q8157[0], &q8158[0], &q8159[0], 
    &q8160[0], &q8161[0], &q8162[0], &q8163[0], &q8164[0], &q8165[0], &q8166[0], &q8167[0], 
    &q8168[0], &q8169[0], &q8170[0], &q8171[0], &q8172[0], &q8173[0], &q8174[0], &q8175[0], 
    &q8176[0], &q8177[0], &q8178[0], &q8179[0], &q8180[0], &q8181[0], &q8182[0], &q8183[0], 
    &q8184[0], &q8185[0], &q8186[0], &q8187[0], &q8188[0], &q8189[0], &q8190[0], &q8191[0], 
    &q8192[0], &q8193[0], &q8194[0], &q8195[0], &q8196[0], &q8197[0], &q8198[0], &q8199[0], 
    &q8200[0], &q8201[0], &q8202[0], &q8203[0], &q8204[0], &q8205[0], &q8206[0], &q8207[0], 
    &q8208[0], &q8209[0], &q8210[0], &q8211[0], &q8212[0], &q8213[0], &q8214[0], &q8215[0], 
    &q8216[0], &q8217[0], &q8218[0], &q8219[0], &q8220[0], &q8221[0], &q8222[0], &q8223[0], 
    &q8224[0], &q8225[0], &q8226[0], &q8227[0], &q8228[0], &q8229[0], &q8230[0], &q8231[0], 
    &q8232[0], &q8233[0], &q8234[0], &q8235[0], &q8236[0], &q8237[0], &q8238[0], &q8239[0], 
    &q8240[0], &q8241[0], &q8242[0], &q8243[0], &q8244[0], &q8245[0], &q8246[0], &q8247[0], 
    &q8248[0], &q8249[0], &q8250[0], &q8251[0], &q8252[0], &q8253[0], &q8254[0], &q8255[0], 
    &q8256[0], &q8257[0], &q8258[0], &q8259[0], &q8260[0], &q8261[0], &q8262[0], &q8263[0], 
    &q8264[0], &q8265[0], &q8266[0], &q8267[0], &q8268[0], &q8269[0], &q8270[0], &q8271[0], 
    &q8272[0], &q8273[0], &q8274[0], &q8275[0], &q8276[0], &q8277[0], &q8278[0], &q8279[0], 
    &q8280[0], &q8281[0], &q8282[0], &q8283[0], &q8284[0], &q8285[0], &q8286[0], &q8287[0], 
    &q8288[0], &q8289[0], &q8290[0], &q8291[0], &q8292[0], &q8293[0], &q8294[0], &q8295[0], 
    &q8296[0], &q8297[0], &q8298[0], &q8299[0], &q8300[0], &q8301[0], &q8302[0], &q8303[0], 
    &q8304[0], &q8305[0], &q8306[0], &q8307[0], &q8308[0], &q8309[0], &q8310[0], &q8311[0], 
    &q8312[0], &q8313[0], &q8314[0], &q8315[0], &q8316[0], &q8317[0], &q8318[0], &q8319[0], 
    &q8320[0], &q8321[0], &q8322[0], &q8323[0], &q8324[0], &q8325[0], &q8326[0], &q8327[0], 
    &q8328[0], &q8329[0], &q8330[0], &q8331[0], &q8332[0], &q8333[0], &q8334[0], &q8335[0], 
    &q8336[0], &q8337[0], &q8338[0], &q8339[0], &q8340[0], &q8341[0], &q8342[0], &q8343[0], 
    &q8344[0], &q8345[0], &q8346[0], &q8347[0], &q8348[0], &q8349[0], &q8350[0], &q8351[0], 
    &q8352[0], &q8353[0], &q8354[0], &q8355[0], &q8356[0], &q8357[0], &q8358[0], &q8359[0], 
    &q8360[0], &q8361[0], &q8362[0], &q8363[0], &q8364[0], &q8365[0], &q8366[0], &q8367[0], 
    &q8368[0], &q8369[0], &q8370[0], &q8371[0], &q8372[0], &q8373[0], &q8374[0], &q8375[0], 
    &q8376[0], &q8377[0], &q8378[0], &q8379[0], &q8380[0], &q8381[0], &q8382[0], &q8383[0], 
    &q8384[0], &q8385[0], &q8386[0], &q8387[0], &q8388[0], &q8389[0], &q8390[0], &q8391[0], 
    &q8392[0], &q8393[0], &q8394[0], &q8395[0], &q8396[0], &q8397[0], &q8398[0], &q8399[0], 
    &q8400[0], &q8401[0], &q8402[0], &q8403[0], &q8404[0], &q8405[0], &q8406[0], &q8407[0], 
    &q8408[0], &q8409[0], &q8410[0], &q8411[0], &q8412[0], &q8413[0], &q8414[0], &q8415[0], 
    &q8416[0], &q8417[0], &q8418[0], &q8419[0], &q8420[0], &q8421[0], &q8422[0], &q8423[0], 
    &q8424[0], &q8425[0], &q8426[0], &q8427[0], &q8428[0], &q8429[0], &q8430[0], &q8431[0], 
    &q8432[0], &q8433[0], &q8434[0], &q8435[0], &q8436[0], &q8437[0], &q8438[0], &q8439[0], 
    &q8440[0], &q8441[0], &q8442[0], &q8443[0], &q8444[0], &q8445[0], &q8446[0], &q8447[0], 
    &q8448[0], &q8449[0], &q8450[0], &q8451[0], &q8452[0], &q8453[0], &q8454[0], &q8455[0], 
    &q8456[0], &q8457[0], &q8458[0], &q8459[0], &q8460[0], &q8461[0], &q8462[0], &q8463[0], 
    &q8464[0], &q8465[0], &q8466[0], &q8467[0], &q8468[0], &q8469[0], &q8470[0], &q8471[0], 
    &q8472[0], &q8473[0], &q8474[0], &q8475[0], &q8476[0], &q8477[0], &q8478[0], &q8479[0], 
    &q8480[0], &q8481[0], &q8482[0], &q8483[0], &q8484[0], &q8485[0], &q8486[0], &q8487[0], 
    &q8488[0], &q8489[0], &q8490[0], &q8491[0], &q8492[0], &q8493[0], &q8494[0], &q8495[0], 
    &q8496[0], &q8497[0], &q8498[0], &q8499[0], &q8500[0], &q8501[0], &q8502[0], &q8503[0], 
    &q8504[0], &q8505[0], &q8506[0], &q8507[0], &q8508[0], &q8509[0], &q8510[0], &q8511[0], 
    &q8512[0], &q8513[0], &q8514[0], &q8515[0], &q8516[0], &q8517[0], &q8518[0], &q8519[0], 
    &q8520[0], &q8521[0], &q8522[0], &q8523[0], &q8524[0], &q8525[0], &q8526[0], &q8527[0], 
    &q8528[0], &q8529[0], &q8530[0], &q8531[0], &q8532[0], &q8533[0], &q8534[0], &q8535[0], 
    &q8536[0], &q8537[0], &q8538[0], &q8539[0], &q8540[0], &q8541[0], &q8542[0], &q8543[0], 
    &q8544[0], &q8545[0], &q8546[0], &q8547[0], &q8548[0], &q8549[0], &q8550[0], &q8551[0], 
    &q8552[0], &q8553[0], &q8554[0], &q8555[0], &q8556[0], &q8557[0], &q8558[0], &q8559[0], 
    &q8560[0], &q8561[0], &q8562[0], &q8563[0], &q8564[0], &q8565[0], &q8566[0], &q8567[0], 
    &q8568[0], &q8569[0], &q8570[0], &q8571[0], &q8572[0], &q8573[0], &q8574[0], &q8575[0], 
    &q8576[0], &q8577[0], &q8578[0], &q8579[0], &q8580[0], &q8581[0], &q8582[0], &q8583[0], 
    &q8584[0], &q8585[0], &q8586[0], &q8587[0], &q8588[0], &q8589[0], &q8590[0], &q8591[0], 
    &q8592[0], &q8593[0], &q8594[0], &q8595[0], &q8596[0], &q8597[0], &q8598[0], &q8599[0], 
    &q8600[0], &q8601[0], &q8602[0], &q8603[0], &q8604[0], &q8605[0], &q8606[0], &q8607[0], 
    &q8608[0], &q8609[0], &q8610[0], &q8611[0], &q8612[0], &q8613[0], &q8614[0], &q8615[0], 
    &q8616[0], &q8617[0], &q8618[0], &q8619[0], &q8620[0], &q8621[0], &q8622[0], &q8623[0], 
    &q8624[0], &q8625[0], &q8626[0], &q8627[0], &q8628[0], &q8629[0], &q8630[0], &q8631[0], 
    &q8632[0], &q8633[0], &q8634[0], &q8635[0], &q8636[0], &q8637[0], &q8638[0], &q8639[0], 
    &q8640[0], &q8641[0], &q8642[0], &q8643[0], &q8644[0], &q8645[0], &q8646[0], &q8647[0], 
    &q8648[0], &q8649[0], &q8650[0], &q8651[0], &q8652[0], &q8653[0], &q8654[0], &q8655[0], 
    &q8656[0], &q8657[0], &q8658[0], &q8659[0], &q8660[0], &q8661[0], &q8662[0], &q8663[0], 
    &q8664[0], &q8665[0], &q8666[0], &q8667[0], &q8668[0], &q8669[0], &q8670[0], &q8671[0], 
    &q8672[0], &q8673[0], &q8674[0], &q8675[0], &q8676[0], &q8677[0], &q8678[0], &q8679[0], 
    &q8680[0], &q8681[0], &q8682[0], &q8683[0], &q8684[0], &q8685[0], &q8686[0], &q8687[0], 
    &q8688[0], &q8689[0], &q8690[0], &q8691[0], &q8692[0], &q8693[0], &q8694[0], &q8695[0], 
    &q8696[0], &q8697[0], &q8698[0], &q8699[0], &q8700[0], &q8701[0], &q8702[0], &q8703[0], 
    &q8704[0], &q8705[0], &q8706[0], &q8707[0], &q8708[0], &q8709[0], &q8710[0], &q8711[0], 
    &q8712[0], &q8713[0], &q8714[0], &q8715[0], &q8716[0], &q8717[0], &q8718[0], &q8719[0], 
    &q8720[0], &q8721[0], &q8722[0], &q8723[0], &q8724[0], &q8725[0], &q8726[0], &q8727[0], 
    &q8728[0], &q8729[0], &q8730[0], &q8731[0], &q8732[0], &q8733[0], &q8734[0], &q8735[0], 
    &q8736[0], &q8737[0], &q8738[0], &q8739[0], &q8740[0], &q8741[0], &q8742[0], &q8743[0], 
    &q8744[0], &q8745[0], &q8746[0], &q8747[0], &q8748[0], &q8749[0], &q8750[0], &q8751[0], 
    &q8752[0], &q8753[0], &q8754[0], &q8755[0], &q8756[0], &q8757[0], &q8758[0], &q8759[0], 
    &q8760[0], &q8761[0], &q8762[0], &q8763[0], &q8764[0], &q8765[0], &q8766[0], &q8767[0], 
    &q8768[0], &q8769[0], &q8770[0], &q8771[0], &q8772[0], &q8773[0], &q8774[0], &q8775[0], 
    &q8776[0], &q8777[0], &q8778[0], &q8779[0], &q8780[0], &q8781[0], &q8782[0], &q8783[0], 
    &q8784[0], &q8785[0], &q8786[0], &q8787[0], &q8788[0], &q8789[0], &q8790[0], &q8791[0], 
    &q8792[0], &q8793[0], &q8794[0], &q8795[0], &q8796[0], &q8797[0], &q8798[0], &q8799[0], 
    &q8800[0], &q8801[0], &q8802[0], &q8803[0], &q8804[0], &q8805[0], &q8806[0], &q8807[0], 
    &q8808[0], &q8809[0], &q8810[0], &q8811[0], &q8812[0], &q8813[0], &q8814[0], &q8815[0], 
    &q8816[0], &q8817[0], &q8818[0], &q8819[0], &q8820[0], &q8821[0], &q8822[0], &q8823[0], 
    &q8824[0], &q8825[0], &q8826[0], &q8827[0], &q8828[0], &q8829[0], &q8830[0], &q8831[0], 
    &q8832[0], &q8833[0], &q8834[0], &q8835[0], &q8836[0], &q8837[0], &q8838[0], &q8839[0], 
    &q8840[0], &q8841[0], &q8842[0], &q8843[0], &q8844[0], &q8845[0], &q8846[0], &q8847[0], 
    &q8848[0], &q8849[0], &q8850[0], &q8851[0], &q8852[0], &q8853[0], &q8854[0], &q8855[0], 
    &q8856[0], &q8857[0], &q8858[0], &q8859[0], &q8860[0], &q8861[0], &q8862[0], &q8863[0], 
    &q8864[0], &q8865[0], &q8866[0], &q8867[0], &q8868[0], &q8869[0], &q8870[0], &q8871[0], 
    &q8872[0], &q8873[0], &q8874[0], &q8875[0], &q8876[0], &q8877[0], &q8878[0], &q8879[0], 
    &q8880[0], &q8881[0], &q8882[0], &q8883[0], &q8884[0], &q8885[0], &q8886[0], &q8887[0], 
    &q8888[0], &q8889[0], &q8890[0], &q8891[0], &q8892[0], &q8893[0], &q8894[0], &q8895[0], 
    &q8896[0], &q8897[0], &q8898[0], &q8899[0], &q8900[0], &q8901[0], &q8902[0], &q8903[0], 
    &q8904[0], &q8905[0], &q8906[0], &q8907[0], &q8908[0], &q8909[0], &q8910[0], &q8911[0], 
    &q8912[0], &q8913[0], &q8914[0], &q8915[0], &q8916[0], &q8917[0], &q8918[0], &q8919[0], 
    &q8920[0], &q8921[0], &q8922[0], &q8923[0], &q8924[0], &q8925[0], &q8926[0], &q8927[0], 
    &q8928[0], &q8929[0], &q8930[0], &q8931[0], &q8932[0], &q8933[0], &q8934[0], &q8935[0], 
    &q8936[0], &q8937[0], &q8938[0], &q8939[0], &q8940[0], &q8941[0], &q8942[0], &q8943[0], 
    &q8944[0], &q8945[0], &q8946[0], &q8947[0], &q8948[0], &q8949[0], &q8950[0], &q8951[0], 
    &q8952[0], &q8953[0], &q8954[0], &q8955[0], &q8956[0], &q8957[0], &q8958[0], &q8959[0], 
    &q8960[0], &q8961[0], &q8962[0], &q8963[0], &q8964[0], &q8965[0], &q8966[0], &q8967[0], 
    &q8968[0], &q8969[0], &q8970[0], &q8971[0], &q8972[0], &q8973[0], &q8974[0], &q8975[0], 
    &q8976[0], &q8977[0], &q8978[0], &q8979[0], &q8980[0], &q8981[0], &q8982[0], &q8983[0], 
    &q8984[0], &q8985[0], &q8986[0], &q8987[0], &q8988[0], &q8989[0], &q8990[0], &q8991[0], 
    &q8992[0], &q8993[0], &q8994[0], &q8995[0], &q8996[0], &q8997[0], &q8998[0], &q8999[0], 
    &q9000[0], &q9001[0], &q9002[0], &q9003[0], &q9004[0], &q9005[0], &q9006[0], &q9007[0], 
    &q9008[0], &q9009[0], &q9010[0], &q9011[0], &q9012[0], &q9013[0], &q9014[0], &q9015[0], 
    &q9016[0], &q9017[0], &q9018[0], &q9019[0], &q9020[0], &q9021[0], &q9022[0], &q9023[0], 
    &q9024[0], &q9025[0], &q9026[0], &q9027[0], &q9028[0], &q9029[0], &q9030[0], &q9031[0], 
    &q9032[0], &q9033[0], &q9034[0], &q9035[0], &q9036[0], &q9037[0], &q9038[0], &q9039[0], 
    &q9040[0], &q9041[0], &q9042[0], &q9043[0], &q9044[0], &q9045[0], &q9046[0], &q9047[0], 
    &q9048[0], &q9049[0], &q9050[0], &q9051[0], &q9052[0], &q9053[0], &q9054[0], &q9055[0], 
    &q9056[0], &q9057[0], &q9058[0], &q9059[0], &q9060[0], &q9061[0], &q9062[0], &q9063[0], 
    &q9064[0], &q9065[0], &q9066[0], &q9067[0], &q9068[0], &q9069[0], &q9070[0], &q9071[0], 
    &q9072[0], &q9073[0], &q9074[0], &q9075[0], &q9076[0], &q9077[0], &q9078[0], &q9079[0], 
    &q9080[0], &q9081[0], &q9082[0], &q9083[0], &q9084[0], &q9085[0], &q9086[0], &q9087[0], 
    &q9088[0], &q9089[0], &q9090[0], &q9091[0], &q9092[0], &q9093[0], &q9094[0], &q9095[0], 
    &q9096[0], &q9097[0], &q9098[0], &q9099[0], &q9100[0], &q9101[0], &q9102[0], &q9103[0], 
    &q9104[0], &q9105[0], &q9106[0], &q9107[0], &q9108[0], &q9109[0], &q9110[0], &q9111[0], 
    &q9112[0], &q9113[0], &q9114[0], &q9115[0], &q9116[0], &q9117[0], &q9118[0], &q9119[0], 
    &q9120[0], &q9121[0], &q9122[0], &q9123[0], &q9124[0], &q9125[0], &q9126[0], &q9127[0], 
    &q9128[0], &q9129[0], &q9130[0], &q9131[0], &q9132[0], &q9133[0], &q9134[0], &q9135[0], 
    &q9136[0], &q9137[0], &q9138[0], &q9139[0], &q9140[0], &q9141[0], &q9142[0], &q9143[0], 
    &q9144[0], &q9145[0], &q9146[0], &q9147[0], &q9148[0], &q9149[0], &q9150[0], &q9151[0], 
    &q9152[0], &q9153[0], &q9154[0], &q9155[0], &q9156[0], &q9157[0], &q9158[0], &q9159[0], 
    &q9160[0], &q9161[0], &q9162[0], &q9163[0], &q9164[0], &q9165[0], &q9166[0], &q9167[0], 
    &q9168[0], &q9169[0], &q9170[0], &q9171[0], &q9172[0], &q9173[0], &q9174[0], &q9175[0], 
    &q9176[0], &q9177[0], &q9178[0], &q9179[0], &q9180[0], &q9181[0], &q9182[0], &q9183[0], 
    &q9184[0], &q9185[0], &q9186[0], &q9187[0], &q9188[0], &q9189[0], &q9190[0], &q9191[0], 
    &q9192[0], &q9193[0], &q9194[0], &q9195[0], &q9196[0], &q9197[0], &q9198[0], &q9199[0], 
    &q9200[0], &q9201[0], &q9202[0], &q9203[0], &q9204[0], &q9205[0], &q9206[0], &q9207[0], 
    &q9208[0], &q9209[0], &q9210[0], &q9211[0], &q9212[0], &q9213[0], &q9214[0], &q9215[0], 
    &q9216[0], &q9217[0], &q9218[0], &q9219[0], &q9220[0], &q9221[0], &q9222[0], &q9223[0], 
    &q9224[0], &q9225[0], &q9226[0], &q9227[0], &q9228[0], &q9229[0], &q9230[0], &q9231[0], 
    &q9232[0], &q9233[0], &q9234[0], &q9235[0], &q9236[0], &q9237[0], &q9238[0], &q9239[0], 
    &q9240[0], &q9241[0], &q9242[0], &q9243[0], &q9244[0], &q9245[0], &q9246[0], &q9247[0], 
    &q9248[0], &q9249[0], &q9250[0], &q9251[0], &q9252[0], &q9253[0], &q9254[0], &q9255[0], 
    &q9256[0], &q9257[0], &q9258[0], &q9259[0], &q9260[0], &q9261[0], &q9262[0], &q9263[0], 
    &q9264[0], &q9265[0], &q9266[0], &q9267[0], &q9268[0], &q9269[0], &q9270[0], &q9271[0], 
    &q9272[0], &q9273[0], &q9274[0], &q9275[0], &q9276[0], &q9277[0], &q9278[0], &q9279[0], 
    &q9280[0], &q9281[0], &q9282[0], &q9283[0], &q9284[0], &q9285[0], &q9286[0], &q9287[0], 
    &q9288[0], &q9289[0], &q9290[0], &q9291[0], &q9292[0], &q9293[0], &q9294[0], &q9295[0], 
    &q9296[0], &q9297[0], &q9298[0], &q9299[0], &q9300[0], &q9301[0], &q9302[0], &q9303[0], 
    &q9304[0], &q9305[0], &q9306[0], &q9307[0], &q9308[0], &q9309[0], &q9310[0], &q9311[0], 
    &q9312[0], &q9313[0], &q9314[0], &q9315[0], &q9316[0], &q9317[0], &q9318[0], &q9319[0], 
    &q9320[0], &q9321[0], &q9322[0], &q9323[0], &q9324[0], &q9325[0], &q9326[0], &q9327[0], 
    &q9328[0], &q9329[0], &q9330[0], &q9331[0], &q9332[0], &q9333[0], &q9334[0], &q9335[0], 
    &q9336[0], &q9337[0], &q9338[0], &q9339[0], &q9340[0], &q9341[0], &q9342[0], &q9343[0], 
    &q9344[0], &q9345[0], &q9346[0], &q9347[0], &q9348[0], &q9349[0], &q9350[0], &q9351[0], 
    &q9352[0], &q9353[0], &q9354[0], &q9355[0], &q9356[0], &q9357[0], &q9358[0], &q9359[0], 
    &q9360[0], &q9361[0], &q9362[0], &q9363[0], &q9364[0], &q9365[0], &q9366[0], &q9367[0], 
    &q9368[0], &q9369[0], &q9370[0], &q9371[0], &q9372[0], &q9373[0], &q9374[0], &q9375[0], 
    &q9376[0], &q9377[0], &q9378[0], &q9379[0], &q9380[0], &q9381[0], &q9382[0], &q9383[0], 
    &q9384[0], &q9385[0], &q9386[0], &q9387[0], &q9388[0], &q9389[0], &q9390[0], &q9391[0], 
    &q9392[0], &q9393[0], &q9394[0], &q9395[0], &q9396[0], &q9397[0], &q9398[0], &q9399[0], 
    &q9400[0], &q9401[0], &q9402[0], &q9403[0], &q9404[0], &q9405[0], &q9406[0], &q9407[0], 
    &q9408[0], &q9409[0], &q9410[0], &q9411[0], &q9412[0], &q9413[0], &q9414[0], &q9415[0], 
    &q9416[0], &q9417[0], &q9418[0], &q9419[0], &q9420[0], &q9421[0], &q9422[0], &q9423[0], 
    &q9424[0], &q9425[0], &q9426[0], &q9427[0], &q9428[0], &q9429[0], &q9430[0], &q9431[0], 
    &q9432[0], &q9433[0], &q9434[0], &q9435[0], &q9436[0], &q9437[0], &q9438[0], &q9439[0], 
    &q9440[0], &q9441[0], &q9442[0], &q9443[0], &q9444[0], &q9445[0], &q9446[0], &q9447[0], 
    &q9448[0], &q9449[0], &q9450[0], &q9451[0], &q9452[0], &q9453[0], &q9454[0], &q9455[0], 
    &q9456[0], &q9457[0], &q9458[0], &q9459[0], &q9460[0], &q9461[0], &q9462[0], &q9463[0], 
    &q9464[0], &q9465[0], &q9466[0], &q9467[0], &q9468[0], &q9469[0], &q9470[0], &q9471[0], 
    &q9472[0], &q9473[0], &q9474[0], &q9475[0], &q9476[0], &q9477[0], &q9478[0], &q9479[0], 
    &q9480[0], &q9481[0], &q9482[0], &q9483[0], &q9484[0], &q9485[0], &q9486[0], &q9487[0], 
    &q9488[0], &q9489[0], &q9490[0], &q9491[0], &q9492[0], &q9493[0], &q9494[0], &q9495[0], 
    &q9496[0], &q9497[0], &q9498[0], &q9499[0], &q9500[0], &q9501[0], &q9502[0], &q9503[0], 
    &q9504[0], &q9505[0], &q9506[0], &q9507[0], &q9508[0], &q9509[0], &q9510[0], &q9511[0], 
    &q9512[0], &q9513[0], &q9514[0], &q9515[0], &q9516[0], &q9517[0], &q9518[0], &q9519[0], 
    &q9520[0], &q9521[0], &q9522[0], &q9523[0], &q9524[0], &q9525[0], &q9526[0], &q9527[0], 
    &q9528[0], &q9529[0], &q9530[0], &q9531[0], &q9532[0], &q9533[0], &q9534[0], &q9535[0], 
    &q9536[0], &q9537[0], &q9538[0], &q9539[0], &q9540[0], &q9541[0], &q9542[0], &q9543[0], 
    &q9544[0], &q9545[0], &q9546[0], &q9547[0], &q9548[0], &q9549[0], &q9550[0], &q9551[0], 
    &q9552[0], &q9553[0], &q9554[0], &q9555[0], &q9556[0], &q9557[0], &q9558[0], &q9559[0], 
    &q9560[0], &q9561[0], &q9562[0], &q9563[0], &q9564[0], &q9565[0], &q9566[0], &q9567[0], 
    &q9568[0], &q9569[0], &q9570[0], &q9571[0], &q9572[0], &q9573[0], &q9574[0], &q9575[0], 
    &q9576[0], &q9577[0], &q9578[0], &q9579[0], &q9580[0], &q9581[0], &q9582[0], &q9583[0], 
    &q9584[0], &q9585[0], &q9586[0], &q9587[0], &q9588[0], &q9589[0], &q9590[0], &q9591[0], 
    &q9592[0], &q9593[0], &q9594[0], &q9595[0], &q9596[0], &q9597[0], &q9598[0], &q9599[0], 
    &q9600[0], &q9601[0], &q9602[0], &q9603[0], &q9604[0], &q9605[0], &q9606[0], &q9607[0], 
    &q9608[0], &q9609[0], &q9610[0], &q9611[0], &q9612[0], &q9613[0], &q9614[0], &q9615[0], 
    &q9616[0], &q9617[0], &q9618[0], &q9619[0], &q9620[0], &q9621[0], &q9622[0], &q9623[0], 
    &q9624[0], &q9625[0], &q9626[0], &q9627[0], &q9628[0], &q9629[0], &q9630[0], &q9631[0], 
    &q9632[0], &q9633[0], &q9634[0], &q9635[0], &q9636[0], &q9637[0], &q9638[0], &q9639[0], 
    &q9640[0], &q9641[0], &q9642[0], &q9643[0], &q9644[0], &q9645[0], &q9646[0], &q9647[0], 
    &q9648[0], &q9649[0], &q9650[0], &q9651[0], &q9652[0], &q9653[0], &q9654[0], &q9655[0], 
    &q9656[0], &q9657[0], &q9658[0], &q9659[0], &q9660[0], &q9661[0], &q9662[0], &q9663[0], 
    &q9664[0], &q9665[0], &q9666[0], &q9667[0], &q9668[0], &q9669[0], &q9670[0], &q9671[0], 
    &q9672[0], &q9673[0], &q9674[0], &q9675[0], &q9676[0], &q9677[0], &q9678[0], &q9679[0], 
    &q9680[0], &q9681[0], &q9682[0], &q9683[0], &q9684[0], &q9685[0], &q9686[0], &q9687[0], 
    &q9688[0], &q9689[0], &q9690[0], &q9691[0], &q9692[0], &q9693[0], &q9694[0], &q9695[0], 
    &q9696[0], &q9697[0], &q9698[0], &q9699[0], &q9700[0], &q9701[0], &q9702[0], &q9703[0], 
    &q9704[0], &q9705[0], &q9706[0], &q9707[0], &q9708[0], &q9709[0], &q9710[0], &q9711[0], 
    &q9712[0], &q9713[0], &q9714[0], &q9715[0], &q9716[0], &q9717[0], &q9718[0], &q9719[0], 
    &q9720[0], &q9721[0], &q9722[0], &q9723[0], &q9724[0], &q9725[0], &q9726[0], &q9727[0], 
    &q9728[0], &q9729[0], &q9730[0], &q9731[0], &q9732[0], &q9733[0], &q9734[0], &q9735[0], 
    &q9736[0], &q9737[0], &q9738[0], &q9739[0], &q9740[0], &q9741[0], &q9742[0], &q9743[0], 
    &q9744[0], &q9745[0], &q9746[0], &q9747[0], &q9748[0], &q9749[0], &q9750[0], &q9751[0], 
    &q9752[0], &q9753[0], &q9754[0], &q9755[0], &q9756[0], &q9757[0], &q9758[0], &q9759[0], 
    &q9760[0], &q9761[0], &q9762[0], &q9763[0], &q9764[0], &q9765[0], &q9766[0], &q9767[0], 
    &q9768[0], &q9769[0], &q9770[0], &q9771[0], &q9772[0], &q9773[0], &q9774[0], &q9775[0], 
    &q9776[0], &q9777[0], &q9778[0], &q9779[0], &q9780[0], &q9781[0], &q9782[0], &q9783[0], 
    &q9784[0], &q9785[0], &q9786[0], &q9787[0], &q9788[0], &q9789[0], &q9790[0], &q9791[0], 
    &q9792[0], &q9793[0], &q9794[0], &q9795[0], &q9796[0], &q9797[0], &q9798[0], &q9799[0], 
    &q9800[0], &q9801[0], &q9802[0], &q9803[0], &q9804[0], &q9805[0], &q9806[0], &q9807[0], 
    &q9808[0], &q9809[0], &q9810[0], &q9811[0], &q9812[0], &q9813[0], &q9814[0], &q9815[0], 
    &q9816[0], &q9817[0], &q9818[0], &q9819[0], &q9820[0], &q9821[0], &q9822[0], &q9823[0], 
    &q9824[0], &q9825[0], &q9826[0], &q9827[0], &q9828[0], &q9829[0], &q9830[0], &q9831[0], 
    &q9832[0], &q9833[0], &q9834[0], &q9835[0], &q9836[0], &q9837[0], &q9838[0], &q9839[0], 
    &q9840[0], &q9841[0], &q9842[0], &q9843[0], &q9844[0], &q9845[0], &q9846[0], &q9847[0], 
    &q9848[0], &q9849[0], &q9850[0], &q9851[0], &q9852[0], &q9853[0], &q9854[0], &q9855[0], 
    &q9856[0], &q9857[0], &q9858[0], &q9859[0], &q9860[0], &q9861[0], &q9862[0], &q9863[0], 
    &q9864[0], &q9865[0], &q9866[0], &q9867[0], &q9868[0], &q9869[0], &q9870[0], &q9871[0], 
    &q9872[0], &q9873[0], &q9874[0], &q9875[0], &q9876[0], &q9877[0], &q9878[0], &q9879[0], 
    &q9880[0], &q9881[0], &q9882[0], &q9883[0], &q9884[0], &q9885[0], &q9886[0], &q9887[0], 
    &q9888[0], &q9889[0], &q9890[0], &q9891[0], &q9892[0], &q9893[0], &q9894[0], &q9895[0], 
    &q9896[0], &q9897[0], &q9898[0], &q9899[0], &q9900[0], &q9901[0], &q9902[0], &q9903[0], 
    &q9904[0], &q9905[0], &q9906[0], &q9907[0], &q9908[0], &q9909[0], &q9910[0], &q9911[0], 
    &q9912[0], &q9913[0], &q9914[0], &q9915[0], &q9916[0], &q9917[0], &q9918[0], &q9919[0], 
    &q9920[0], &q9921[0], &q9922[0], &q9923[0], &q9924[0], &q9925[0], &q9926[0], &q9927[0], 
    &q9928[0], &q9929[0], &q9930[0], &q9931[0], &q9932[0], &q9933[0], &q9934[0], &q9935[0], 
    &q9936[0], &q9937[0], &q9938[0], &q9939[0], &q9940[0], &q9941[0], &q9942[0], &q9943[0], 
    &q9944[0], &q9945[0], &q9946[0], &q9947[0], &q9948[0], &q9949[0], &q9950[0], &q9951[0], 
    &q9952[0], &q9953[0], &q9954[0], &q9955[0], &q9956[0], &q9957[0], &q9958[0], &q9959[0], 
    &q9960[0], &q9961[0], &q9962[0], &q9963[0], &q9964[0], &q9965[0], &q9966[0], &q9967[0], 
    &q9968[0], &q9969[0], &q9970[0], &q9971[0], &q9972[0], &q9973[0], &q9974[0], &q9975[0], 
    &q9976[0], &q9977[0], &q9978[0], &q9979[0], &q9980[0], &q9981[0], &q9982[0], &q9983[0], 
    &q9984[0], &q9985[0], &q9986[0], &q9987[0], &q9988[0], &q9989[0], &q9990[0], &q9991[0], 
    &q9992[0], &q9993[0], &q9994[0], &q9995[0], &q9996[0], &q9997[0], &q9998[0], &q9999[0]
  };

  const char* name[] = {
    "abz5", "abz6", "abz7", "abz8", "abz9",
    "ft06", "ft10", "ft20",
    "la01", "la02", "la03", "la04", "la05", "la06", "la07", "la08",
    "la09", "la10", "la11", "la12", "la13", "la14", "la15", "la16",
    "la17", "la18", "la19", "la20", "la21", "la22", "la23", "la24",
    "la25", "la26", "la27", "la28", "la29", "la30", "la31", "la32",
    "la33", "la34", "la35", "la36", "la37", "la38", "la39", "la40",
    "orb01", "orb02", "orb03", "orb04", "orb05",
    "orb06", "orb07", "orb08", "orb09", "orb10",
    "swv01", "swv02", "swv03", "swv04", "swv05",
    "swv06", "swv07", "swv08", "swv09", "swv10",
    "swv11", "swv12", "swv13", "swv14", "swv15",
    "swv16", "swv17", "swv18", "swv19", "swv20",
    "yn1", "yn2", "yn3", "yn4", 
    "tai-15-15-0", "tai-15-15-1", "tai-15-15-2", "tai-15-15-3", "tai-15-15-4",
    "tai-15-15-5", "tai-15-15-6", "tai-15-15-7", "tai-15-15-8", "tai-15-15-9",
    "tai-20-15-0", "tai-20-15-1", "tai-20-15-2", "tai-20-15-3", "tai-20-15-4",
    "tai-20-15-5", "tai-20-15-6", "tai-20-15-7", "tai-20-15-8", "tai-20-15-9",
    "tai-20-20-0", "tai-20-20-1", "tai-20-20-2", "tai-20-20-3", "tai-20-20-4",
    "tai-20-20-5", "tai-20-20-6", "tai-20-20-7", "tai-20-20-8", "tai-20-20-9",
    "tai-30-15-0", "tai-30-15-1", "tai-30-15-2", "tai-30-15-3", "tai-30-15-4",
    "tai-30-15-5", "tai-30-15-6", "tai-30-15-7", "tai-30-15-8", "tai-30-15-9",
    "tai-30-20-0", "tai-30-20-1", "tai-30-20-2", "tai-30-20-3", "tai-30-20-4",
    "tai-30-20-5", "tai-30-20-6", "tai-30-20-7", "tai-30-20-8", "tai-30-20-9",
    "tai-50-15-0", "tai-50-15-1", "tai-50-15-2", "tai-50-15-3", "tai-50-15-4",
    "tai-50-15-5", "tai-50-15-6", "tai-50-15-7", "tai-50-15-8", "tai-50-15-9",
    "tai-50-20-0", "tai-50-20-1", "tai-50-20-2", "tai-50-20-3", "tai-50-20-4",
    "tai-50-20-5", "tai-50-20-6", "tai-50-20-7", "tai-50-20-8", "tai-50-20-9", 
    "tai-100-20-0", "tai-100-20-1", "tai-100-20-2", "tai-100-20-3",
    "tai-100-20-4", "tai-100-20-5", "tai-100-20-6", "tai-100-20-7",
    "tai-100-20-8", "tai-100-20-9",
    "r000", "r001", "r002", "r003", "r004", "r005", "r006", "r007", 
    "r008", "r009", "r010", "r011", "r012", "r013", "r014", "r015", 
    "r016", "r017", "r018", "r019", "r020", "r021", "r022", "r023", 
    "r024", "r025", "r026", "r027", "r028", "r029", "r030", "r031", 
    "r032", "r033", "r034", "r035", "r036", "r037", "r038", "r039", 
    "r040", "r041", "r042", "r043", "r044", "r045", "r046", "r047", 
    "r048", "r049", "r050", "r051", "r052", "r053", "r054", "r055", 
    "r056", "r057", "r058", "r059", "r060", "r061", "r062", "r063", 
    "r064", "r065", "r066", "r067", "r068", "r069", "r070", "r071", 
    "r072", "r073", "r074", "r075", "r076", "r077", "r078", "r079", 
    "r080", "r081", "r082", "r083", "r084", "r085", "r086", "r087", 
    "r088", "r089", "r090", "r091", "r092", "r093", "r094", "r095", 
    "r096", "r097", "r098", "r099", "r100", "r101", "r102", "r103", 
    "r104", "r105", "r106", "r107", "r108", "r109", "r110", "r111", 
    "r112", "r113", "r114", "r115", "r116", "r117", "r118", "r119", 
    "r120", "r121", "r122", "r123", "r124", "r125", "r126", "r127", 
    "r128", "r129", "r130", "r131", "r132", "r133", "r134", "r135", 
    "r136", "r137", "r138", "r139", "r140", "r141", "r142", "r143", 
    "r144", "r145", "r146", "r147", "r148", "r149", "r150", "r151", 
    "r152", "r153", "r154", "r155", "r156", "r157", "r158", "r159", 
    "r160", "r161", "r162", "r163", "r164", "r165", "r166", "r167", 
    "r168", "r169", "r170", "r171", "r172", "r173", "r174", "r175", 
    "r176", "r177", "r178", "r179", "r180", "r181", "r182", "r183", 
    "r184", "r185", "r186", "r187", "r188", "r189", "r190", "r191", 
    "r192", "r193", "r194", "r195", "r196", "r197", "r198", "r199", 
    "r200", "r201", "r202", "r203", "r204", "r205", "r206", "r207", 
    "r208", "r209", "r210", "r211", "r212", "r213", "r214", "r215", 
    "r216", "r217", "r218", "r219", "r220", "r221", "r222", "r223", 
    "r224", "r225", "r226", "r227", "r228", "r229", "r230", "r231", 
    "r232", "r233", "r234", "r235", "r236", "r237", "r238", "r239", 
    "r240", "r241", "r242", "r243", "r244", "r245", "r246", "r247", 
    "r248", "r249", "r250", "r251", "r252", "r253", "r254", "r255", 
    "r256", "r257", "r258", "r259", "r260", "r261", "r262", "r263", 
    "r264", "r265", "r266", "r267", "r268", "r269", "r270", "r271", 
    "r272", "r273", "r274", "r275", "r276", "r277", "r278", "r279", 
    "r280", "r281", "r282", "r283", "r284", "r285", "r286", "r287", 
    "r288", "r289", "r290", "r291", "r292", "r293", "r294", "r295", 
    "r296", "r297", "r298", "r299", "r300", "r301", "r302", "r303", 
    "r304", "r305", "r306", "r307", "r308", "r309", "r310", "r311", 
    "r312", "r313", "r314", "r315", "r316", "r317", "r318", "r319", 
    "r320", "r321", "r322", "r323", "r324", "r325", "r326", "r327", 
    "r328", "r329", "r330", "r331", "r332", "r333", "r334", "r335", 
    "r336", "r337", "r338", "r339", "r340", "r341", "r342", "r343", 
    "r344", "r345", "r346", "r347", "r348", "r349", "r350", "r351", 
    "r352", "r353", "r354", "r355", "r356", "r357", "r358", "r359", 
    "r360", "r361", "r362", "r363", "r364", "r365", "r366", "r367", 
    "r368", "r369", "r370", "r371", "r372", "r373", "r374", "r375", 
    "r376", "r377", "r378", "r379", "r380", "r381", "r382", "r383", 
    "r384", "r385", "r386", "r387", "r388", "r389", "r390", "r391", 
    "r392", "r393", "r394", "r395", "r396", "r397", "r398", "r399", 
    "r400", "r401", "r402", "r403", "r404", "r405", "r406", "r407", 
    "r408", "r409", "r410", "r411", "r412", "r413", "r414", "r415", 
    "r416", "r417", "r418", "r419", "r420", "r421", "r422", "r423", 
    "r424", "r425", "r426", "r427", "r428", "r429", "r430", "r431", 
    "r432", "r433", "r434", "r435", "r436", "r437", "r438", "r439", 
    "r440", "r441", "r442", "r443", "r444", "r445", "r446", "r447", 
    "r448", "r449", "r450", "r451", "r452", "r453", "r454", "r455", 
    "r456", "r457", "r458", "r459", "r460", "r461", "r462", "r463", 
    "r464", "r465", "r466", "r467", "r468", "r469", "r470", "r471", 
    "r472", "r473", "r474", "r475", "r476", "r477", "r478", "r479", 
    "r480", "r481", "r482", "r483", "r484", "r485", "r486", "r487", 
    "r488", "r489", "r490", "r491", "r492", "r493", "r494", "r495", 
    "r496", "r497", "r498", "r499", "r500", "r501", "r502", "r503", 
    "r504", "r505", "r506", "r507", "r508", "r509", "r510", "r511", 
    "r512", "r513", "r514", "r515", "r516", "r517", "r518", "r519", 
    "r520", "r521", "r522", "r523", "r524", "r525", "r526", "r527", 
    "r528", "r529", "r530", "r531", "r532", "r533", "r534", "r535", 
    "r536", "r537", "r538", "r539", "r540", "r541", "r542", "r543", 
    "r544", "r545", "r546", "r547", "r548", "r549", "r550", "r551", 
    "r552", "r553", "r554", "r555", "r556", "r557", "r558", "r559", 
    "r560", "r561", "r562", "r563", "r564", "r565", "r566", "r567", 
    "r568", "r569", "r570", "r571", "r572", "r573", "r574", "r575", 
    "r576", "r577", "r578", "r579", "r580", "r581", "r582", "r583", 
    "r584", "r585", "r586", "r587", "r588", "r589", "r590", "r591", 
    "r592", "r593", "r594", "r595", "r596", "r597", "r598", "r599", 
    "r600", "r601", "r602", "r603", "r604", "r605", "r606", "r607", 
    "r608", "r609", "r610", "r611", "r612", "r613", "r614", "r615", 
    "r616", "r617", "r618", "r619", "r620", "r621", "r622", "r623", 
    "r624", "r625", "r626", "r627", "r628", "r629", "r630", "r631", 
    "r632", "r633", "r634", "r635", "r636", "r637", "r638", "r639", 
    "r640", "r641", "r642", "r643", "r644", "r645", "r646", "r647", 
    "r648", "r649", "r650", "r651", "r652", "r653", "r654", "r655", 
    "r656", "r657", "r658", "r659", "r660", "r661", "r662", "r663", 
    "r664", "r665", "r666", "r667", "r668", "r669", "r670", "r671", 
    "r672", "r673", "r674", "r675", "r676", "r677", "r678", "r679", 
    "r680", "r681", "r682", "r683", "r684", "r685", "r686", "r687", 
    "r688", "r689", "r690", "r691", "r692", "r693", "r694", "r695", 
    "r696", "r697", "r698", "r699", "r700", "r701", "r702", "r703", 
    "r704", "r705", "r706", "r707", "r708", "r709", "r710", "r711", 
    "r712", "r713", "r714", "r715", "r716", "r717", "r718", "r719", 
    "r720", "r721", "r722", "r723", "r724", "r725", "r726", "r727", 
    "r728", "r729", "r730", "r731", "r732", "r733", "r734", "r735", 
    "r736", "r737", "r738", "r739", "r740", "r741", "r742", "r743", 
    "r744", "r745", "r746", "r747", "r748", "r749", "r750", "r751", 
    "r752", "r753", "r754", "r755", "r756", "r757", "r758", "r759", 
    "r760", "r761", "r762", "r763", "r764", "r765", "r766", "r767", 
    "r768", "r769", "r770", "r771", "r772", "r773", "r774", "r775", 
    "r776", "r777", "r778", "r779", "r780", "r781", "r782", "r783", 
    "r784", "r785", "r786", "r787", "r788", "r789", "r790", "r791", 
    "r792", "r793", "r794", "r795", "r796", "r797", "r798", "r799", 
    "r800", "r801", "r802", "r803", "r804", "r805", "r806", "r807", 
    "r808", "r809", "r810", "r811", "r812", "r813", "r814", "r815", 
    "r816", "r817", "r818", "r819", "r820", "r821", "r822", "r823", 
    "r824", "r825", "r826", "r827", "r828", "r829", "r830", "r831", 
    "r832", "r833", "r834", "r835", "r836", "r837", "r838", "r839", 
    "r840", "r841", "r842", "r843", "r844", "r845", "r846", "r847", 
    "r848", "r849", "r850", "r851", "r852", "r853", "r854", "r855", 
    "r856", "r857", "r858", "r859", "r860", "r861", "r862", "r863", 
    "r864", "r865", "r866", "r867", "r868", "r869", "r870", "r871", 
    "r872", "r873", "r874", "r875", "r876", "r877", "r878", "r879", 
    "r880", "r881", "r882", "r883", "r884", "r885", "r886", "r887", 
    "r888", "r889", "r890", "r891", "r892", "r893", "r894", "r895", 
    "r896", "r897", "r898", "r899", "r900", "r901", "r902", "r903", 
    "r904", "r905", "r906", "r907", "r908", "r909", "r910", "r911", 
    "r912", "r913", "r914", "r915", "r916", "r917", "r918", "r919", 
    "r920", "r921", "r922", "r923", "r924", "r925", "r926", "r927", 
    "r928", "r929", "r930", "r931", "r932", "r933", "r934", "r935", 
    "r936", "r937", "r938", "r939", "r940", "r941", "r942", "r943", 
    "r944", "r945", "r946", "r947", "r948", "r949", "r950", "r951", 
    "r952", "r953", "r954", "r955", "r956", "r957", "r958", "r959", 
    "r960", "r961", "r962", "r963", "r964", "r965", "r966", "r967", 
    "r968", "r969", "r970", "r971", "r972", "r973", "r974", "r975", 
    "r976", "r977", "r978", "r979", "r980", "r981", "r982", "r983", 
    "r984", "r985", "r986", "r987", "r988", "r989", "r990", "r991", 
    "r992", "r993", "r994", "r995", "r996", "r997", "r998", "r999", 
    "q0000", "q0001", "q0002", "q0003", "q0004", "q0005", "q0006", "q0007", 
    "q0008", "q0009", "q0010", "q0011", "q0012", "q0013", "q0014", "q0015", 
    "q0016", "q0017", "q0018", "q0019", "q0020", "q0021", "q0022", "q0023", 
    "q0024", "q0025", "q0026", "q0027", "q0028", "q0029", "q0030", "q0031", 
    "q0032", "q0033", "q0034", "q0035", "q0036", "q0037", "q0038", "q0039", 
    "q0040", "q0041", "q0042", "q0043", "q0044", "q0045", "q0046", "q0047", 
    "q0048", "q0049", "q0050", "q0051", "q0052", "q0053", "q0054", "q0055", 
    "q0056", "q0057", "q0058", "q0059", "q0060", "q0061", "q0062", "q0063", 
    "q0064", "q0065", "q0066", "q0067", "q0068", "q0069", "q0070", "q0071", 
    "q0072", "q0073", "q0074", "q0075", "q0076", "q0077", "q0078", "q0079", 
    "q0080", "q0081", "q0082", "q0083", "q0084", "q0085", "q0086", "q0087", 
    "q0088", "q0089", "q0090", "q0091", "q0092", "q0093", "q0094", "q0095", 
    "q0096", "q0097", "q0098", "q0099", "q0100", "q0101", "q0102", "q0103", 
    "q0104", "q0105", "q0106", "q0107", "q0108", "q0109", "q0110", "q0111", 
    "q0112", "q0113", "q0114", "q0115", "q0116", "q0117", "q0118", "q0119", 
    "q0120", "q0121", "q0122", "q0123", "q0124", "q0125", "q0126", "q0127", 
    "q0128", "q0129", "q0130", "q0131", "q0132", "q0133", "q0134", "q0135", 
    "q0136", "q0137", "q0138", "q0139", "q0140", "q0141", "q0142", "q0143", 
    "q0144", "q0145", "q0146", "q0147", "q0148", "q0149", "q0150", "q0151", 
    "q0152", "q0153", "q0154", "q0155", "q0156", "q0157", "q0158", "q0159", 
    "q0160", "q0161", "q0162", "q0163", "q0164", "q0165", "q0166", "q0167", 
    "q0168", "q0169", "q0170", "q0171", "q0172", "q0173", "q0174", "q0175", 
    "q0176", "q0177", "q0178", "q0179", "q0180", "q0181", "q0182", "q0183", 
    "q0184", "q0185", "q0186", "q0187", "q0188", "q0189", "q0190", "q0191", 
    "q0192", "q0193", "q0194", "q0195", "q0196", "q0197", "q0198", "q0199", 
    "q0200", "q0201", "q0202", "q0203", "q0204", "q0205", "q0206", "q0207", 
    "q0208", "q0209", "q0210", "q0211", "q0212", "q0213", "q0214", "q0215", 
    "q0216", "q0217", "q0218", "q0219", "q0220", "q0221", "q0222", "q0223", 
    "q0224", "q0225", "q0226", "q0227", "q0228", "q0229", "q0230", "q0231", 
    "q0232", "q0233", "q0234", "q0235", "q0236", "q0237", "q0238", "q0239", 
    "q0240", "q0241", "q0242", "q0243", "q0244", "q0245", "q0246", "q0247", 
    "q0248", "q0249", "q0250", "q0251", "q0252", "q0253", "q0254", "q0255", 
    "q0256", "q0257", "q0258", "q0259", "q0260", "q0261", "q0262", "q0263", 
    "q0264", "q0265", "q0266", "q0267", "q0268", "q0269", "q0270", "q0271", 
    "q0272", "q0273", "q0274", "q0275", "q0276", "q0277", "q0278", "q0279", 
    "q0280", "q0281", "q0282", "q0283", "q0284", "q0285", "q0286", "q0287", 
    "q0288", "q0289", "q0290", "q0291", "q0292", "q0293", "q0294", "q0295", 
    "q0296", "q0297", "q0298", "q0299", "q0300", "q0301", "q0302", "q0303", 
    "q0304", "q0305", "q0306", "q0307", "q0308", "q0309", "q0310", "q0311", 
    "q0312", "q0313", "q0314", "q0315", "q0316", "q0317", "q0318", "q0319", 
    "q0320", "q0321", "q0322", "q0323", "q0324", "q0325", "q0326", "q0327", 
    "q0328", "q0329", "q0330", "q0331", "q0332", "q0333", "q0334", "q0335", 
    "q0336", "q0337", "q0338", "q0339", "q0340", "q0341", "q0342", "q0343", 
    "q0344", "q0345", "q0346", "q0347", "q0348", "q0349", "q0350", "q0351", 
    "q0352", "q0353", "q0354", "q0355", "q0356", "q0357", "q0358", "q0359", 
    "q0360", "q0361", "q0362", "q0363", "q0364", "q0365", "q0366", "q0367", 
    "q0368", "q0369", "q0370", "q0371", "q0372", "q0373", "q0374", "q0375", 
    "q0376", "q0377", "q0378", "q0379", "q0380", "q0381", "q0382", "q0383", 
    "q0384", "q0385", "q0386", "q0387", "q0388", "q0389", "q0390", "q0391", 
    "q0392", "q0393", "q0394", "q0395", "q0396", "q0397", "q0398", "q0399", 
    "q0400", "q0401", "q0402", "q0403", "q0404", "q0405", "q0406", "q0407", 
    "q0408", "q0409", "q0410", "q0411", "q0412", "q0413", "q0414", "q0415", 
    "q0416", "q0417", "q0418", "q0419", "q0420", "q0421", "q0422", "q0423", 
    "q0424", "q0425", "q0426", "q0427", "q0428", "q0429", "q0430", "q0431", 
    "q0432", "q0433", "q0434", "q0435", "q0436", "q0437", "q0438", "q0439", 
    "q0440", "q0441", "q0442", "q0443", "q0444", "q0445", "q0446", "q0447", 
    "q0448", "q0449", "q0450", "q0451", "q0452", "q0453", "q0454", "q0455", 
    "q0456", "q0457", "q0458", "q0459", "q0460", "q0461", "q0462", "q0463", 
    "q0464", "q0465", "q0466", "q0467", "q0468", "q0469", "q0470", "q0471", 
    "q0472", "q0473", "q0474", "q0475", "q0476", "q0477", "q0478", "q0479", 
    "q0480", "q0481", "q0482", "q0483", "q0484", "q0485", "q0486", "q0487", 
    "q0488", "q0489", "q0490", "q0491", "q0492", "q0493", "q0494", "q0495", 
    "q0496", "q0497", "q0498", "q0499", "q0500", "q0501", "q0502", "q0503", 
    "q0504", "q0505", "q0506", "q0507", "q0508", "q0509", "q0510", "q0511", 
    "q0512", "q0513", "q0514", "q0515", "q0516", "q0517", "q0518", "q0519", 
    "q0520", "q0521", "q0522", "q0523", "q0524", "q0525", "q0526", "q0527", 
    "q0528", "q0529", "q0530", "q0531", "q0532", "q0533", "q0534", "q0535", 
    "q0536", "q0537", "q0538", "q0539", "q0540", "q0541", "q0542", "q0543", 
    "q0544", "q0545", "q0546", "q0547", "q0548", "q0549", "q0550", "q0551", 
    "q0552", "q0553", "q0554", "q0555", "q0556", "q0557", "q0558", "q0559", 
    "q0560", "q0561", "q0562", "q0563", "q0564", "q0565", "q0566", "q0567", 
    "q0568", "q0569", "q0570", "q0571", "q0572", "q0573", "q0574", "q0575", 
    "q0576", "q0577", "q0578", "q0579", "q0580", "q0581", "q0582", "q0583", 
    "q0584", "q0585", "q0586", "q0587", "q0588", "q0589", "q0590", "q0591", 
    "q0592", "q0593", "q0594", "q0595", "q0596", "q0597", "q0598", "q0599", 
    "q0600", "q0601", "q0602", "q0603", "q0604", "q0605", "q0606", "q0607", 
    "q0608", "q0609", "q0610", "q0611", "q0612", "q0613", "q0614", "q0615", 
    "q0616", "q0617", "q0618", "q0619", "q0620", "q0621", "q0622", "q0623", 
    "q0624", "q0625", "q0626", "q0627", "q0628", "q0629", "q0630", "q0631", 
    "q0632", "q0633", "q0634", "q0635", "q0636", "q0637", "q0638", "q0639", 
    "q0640", "q0641", "q0642", "q0643", "q0644", "q0645", "q0646", "q0647", 
    "q0648", "q0649", "q0650", "q0651", "q0652", "q0653", "q0654", "q0655", 
    "q0656", "q0657", "q0658", "q0659", "q0660", "q0661", "q0662", "q0663", 
    "q0664", "q0665", "q0666", "q0667", "q0668", "q0669", "q0670", "q0671", 
    "q0672", "q0673", "q0674", "q0675", "q0676", "q0677", "q0678", "q0679", 
    "q0680", "q0681", "q0682", "q0683", "q0684", "q0685", "q0686", "q0687", 
    "q0688", "q0689", "q0690", "q0691", "q0692", "q0693", "q0694", "q0695", 
    "q0696", "q0697", "q0698", "q0699", "q0700", "q0701", "q0702", "q0703", 
    "q0704", "q0705", "q0706", "q0707", "q0708", "q0709", "q0710", "q0711", 
    "q0712", "q0713", "q0714", "q0715", "q0716", "q0717", "q0718", "q0719", 
    "q0720", "q0721", "q0722", "q0723", "q0724", "q0725", "q0726", "q0727", 
    "q0728", "q0729", "q0730", "q0731", "q0732", "q0733", "q0734", "q0735", 
    "q0736", "q0737", "q0738", "q0739", "q0740", "q0741", "q0742", "q0743", 
    "q0744", "q0745", "q0746", "q0747", "q0748", "q0749", "q0750", "q0751", 
    "q0752", "q0753", "q0754", "q0755", "q0756", "q0757", "q0758", "q0759", 
    "q0760", "q0761", "q0762", "q0763", "q0764", "q0765", "q0766", "q0767", 
    "q0768", "q0769", "q0770", "q0771", "q0772", "q0773", "q0774", "q0775", 
    "q0776", "q0777", "q0778", "q0779", "q0780", "q0781", "q0782", "q0783", 
    "q0784", "q0785", "q0786", "q0787", "q0788", "q0789", "q0790", "q0791", 
    "q0792", "q0793", "q0794", "q0795", "q0796", "q0797", "q0798", "q0799", 
    "q0800", "q0801", "q0802", "q0803", "q0804", "q0805", "q0806", "q0807", 
    "q0808", "q0809", "q0810", "q0811", "q0812", "q0813", "q0814", "q0815", 
    "q0816", "q0817", "q0818", "q0819", "q0820", "q0821", "q0822", "q0823", 
    "q0824", "q0825", "q0826", "q0827", "q0828", "q0829", "q0830", "q0831", 
    "q0832", "q0833", "q0834", "q0835", "q0836", "q0837", "q0838", "q0839", 
    "q0840", "q0841", "q0842", "q0843", "q0844", "q0845", "q0846", "q0847", 
    "q0848", "q0849", "q0850", "q0851", "q0852", "q0853", "q0854", "q0855", 
    "q0856", "q0857", "q0858", "q0859", "q0860", "q0861", "q0862", "q0863", 
    "q0864", "q0865", "q0866", "q0867", "q0868", "q0869", "q0870", "q0871", 
    "q0872", "q0873", "q0874", "q0875", "q0876", "q0877", "q0878", "q0879", 
    "q0880", "q0881", "q0882", "q0883", "q0884", "q0885", "q0886", "q0887", 
    "q0888", "q0889", "q0890", "q0891", "q0892", "q0893", "q0894", "q0895", 
    "q0896", "q0897", "q0898", "q0899", "q0900", "q0901", "q0902", "q0903", 
    "q0904", "q0905", "q0906", "q0907", "q0908", "q0909", "q0910", "q0911", 
    "q0912", "q0913", "q0914", "q0915", "q0916", "q0917", "q0918", "q0919", 
    "q0920", "q0921", "q0922", "q0923", "q0924", "q0925", "q0926", "q0927", 
    "q0928", "q0929", "q0930", "q0931", "q0932", "q0933", "q0934", "q0935", 
    "q0936", "q0937", "q0938", "q0939", "q0940", "q0941", "q0942", "q0943", 
    "q0944", "q0945", "q0946", "q0947", "q0948", "q0949", "q0950", "q0951", 
    "q0952", "q0953", "q0954", "q0955", "q0956", "q0957", "q0958", "q0959", 
    "q0960", "q0961", "q0962", "q0963", "q0964", "q0965", "q0966", "q0967", 
    "q0968", "q0969", "q0970", "q0971", "q0972", "q0973", "q0974", "q0975", 
    "q0976", "q0977", "q0978", "q0979", "q0980", "q0981", "q0982", "q0983", 
    "q0984", "q0985", "q0986", "q0987", "q0988", "q0989", "q0990", "q0991", 
    "q0992", "q0993", "q0994", "q0995", "q0996", "q0997", "q0998", "q0999", 
    "q1000", "q1001", "q1002", "q1003", "q1004", "q1005", "q1006", "q1007", 
    "q1008", "q1009", "q1010", "q1011", "q1012", "q1013", "q1014", "q1015", 
    "q1016", "q1017", "q1018", "q1019", "q1020", "q1021", "q1022", "q1023", 
    "q1024", "q1025", "q1026", "q1027", "q1028", "q1029", "q1030", "q1031", 
    "q1032", "q1033", "q1034", "q1035", "q1036", "q1037", "q1038", "q1039", 
    "q1040", "q1041", "q1042", "q1043", "q1044", "q1045", "q1046", "q1047", 
    "q1048", "q1049", "q1050", "q1051", "q1052", "q1053", "q1054", "q1055", 
    "q1056", "q1057", "q1058", "q1059", "q1060", "q1061", "q1062", "q1063", 
    "q1064", "q1065", "q1066", "q1067", "q1068", "q1069", "q1070", "q1071", 
    "q1072", "q1073", "q1074", "q1075", "q1076", "q1077", "q1078", "q1079", 
    "q1080", "q1081", "q1082", "q1083", "q1084", "q1085", "q1086", "q1087", 
    "q1088", "q1089", "q1090", "q1091", "q1092", "q1093", "q1094", "q1095", 
    "q1096", "q1097", "q1098", "q1099", "q1100", "q1101", "q1102", "q1103", 
    "q1104", "q1105", "q1106", "q1107", "q1108", "q1109", "q1110", "q1111", 
    "q1112", "q1113", "q1114", "q1115", "q1116", "q1117", "q1118", "q1119", 
    "q1120", "q1121", "q1122", "q1123", "q1124", "q1125", "q1126", "q1127", 
    "q1128", "q1129", "q1130", "q1131", "q1132", "q1133", "q1134", "q1135", 
    "q1136", "q1137", "q1138", "q1139", "q1140", "q1141", "q1142", "q1143", 
    "q1144", "q1145", "q1146", "q1147", "q1148", "q1149", "q1150", "q1151", 
    "q1152", "q1153", "q1154", "q1155", "q1156", "q1157", "q1158", "q1159", 
    "q1160", "q1161", "q1162", "q1163", "q1164", "q1165", "q1166", "q1167", 
    "q1168", "q1169", "q1170", "q1171", "q1172", "q1173", "q1174", "q1175", 
    "q1176", "q1177", "q1178", "q1179", "q1180", "q1181", "q1182", "q1183", 
    "q1184", "q1185", "q1186", "q1187", "q1188", "q1189", "q1190", "q1191", 
    "q1192", "q1193", "q1194", "q1195", "q1196", "q1197", "q1198", "q1199", 
    "q1200", "q1201", "q1202", "q1203", "q1204", "q1205", "q1206", "q1207", 
    "q1208", "q1209", "q1210", "q1211", "q1212", "q1213", "q1214", "q1215", 
    "q1216", "q1217", "q1218", "q1219", "q1220", "q1221", "q1222", "q1223", 
    "q1224", "q1225", "q1226", "q1227", "q1228", "q1229", "q1230", "q1231", 
    "q1232", "q1233", "q1234", "q1235", "q1236", "q1237", "q1238", "q1239", 
    "q1240", "q1241", "q1242", "q1243", "q1244", "q1245", "q1246", "q1247", 
    "q1248", "q1249", "q1250", "q1251", "q1252", "q1253", "q1254", "q1255", 
    "q1256", "q1257", "q1258", "q1259", "q1260", "q1261", "q1262", "q1263", 
    "q1264", "q1265", "q1266", "q1267", "q1268", "q1269", "q1270", "q1271", 
    "q1272", "q1273", "q1274", "q1275", "q1276", "q1277", "q1278", "q1279", 
    "q1280", "q1281", "q1282", "q1283", "q1284", "q1285", "q1286", "q1287", 
    "q1288", "q1289", "q1290", "q1291", "q1292", "q1293", "q1294", "q1295", 
    "q1296", "q1297", "q1298", "q1299", "q1300", "q1301", "q1302", "q1303", 
    "q1304", "q1305", "q1306", "q1307", "q1308", "q1309", "q1310", "q1311", 
    "q1312", "q1313", "q1314", "q1315", "q1316", "q1317", "q1318", "q1319", 
    "q1320", "q1321", "q1322", "q1323", "q1324", "q1325", "q1326", "q1327", 
    "q1328", "q1329", "q1330", "q1331", "q1332", "q1333", "q1334", "q1335", 
    "q1336", "q1337", "q1338", "q1339", "q1340", "q1341", "q1342", "q1343", 
    "q1344", "q1345", "q1346", "q1347", "q1348", "q1349", "q1350", "q1351", 
    "q1352", "q1353", "q1354", "q1355", "q1356", "q1357", "q1358", "q1359", 
    "q1360", "q1361", "q1362", "q1363", "q1364", "q1365", "q1366", "q1367", 
    "q1368", "q1369", "q1370", "q1371", "q1372", "q1373", "q1374", "q1375", 
    "q1376", "q1377", "q1378", "q1379", "q1380", "q1381", "q1382", "q1383", 
    "q1384", "q1385", "q1386", "q1387", "q1388", "q1389", "q1390", "q1391", 
    "q1392", "q1393", "q1394", "q1395", "q1396", "q1397", "q1398", "q1399", 
    "q1400", "q1401", "q1402", "q1403", "q1404", "q1405", "q1406", "q1407", 
    "q1408", "q1409", "q1410", "q1411", "q1412", "q1413", "q1414", "q1415", 
    "q1416", "q1417", "q1418", "q1419", "q1420", "q1421", "q1422", "q1423", 
    "q1424", "q1425", "q1426", "q1427", "q1428", "q1429", "q1430", "q1431", 
    "q1432", "q1433", "q1434", "q1435", "q1436", "q1437", "q1438", "q1439", 
    "q1440", "q1441", "q1442", "q1443", "q1444", "q1445", "q1446", "q1447", 
    "q1448", "q1449", "q1450", "q1451", "q1452", "q1453", "q1454", "q1455", 
    "q1456", "q1457", "q1458", "q1459", "q1460", "q1461", "q1462", "q1463", 
    "q1464", "q1465", "q1466", "q1467", "q1468", "q1469", "q1470", "q1471", 
    "q1472", "q1473", "q1474", "q1475", "q1476", "q1477", "q1478", "q1479", 
    "q1480", "q1481", "q1482", "q1483", "q1484", "q1485", "q1486", "q1487", 
    "q1488", "q1489", "q1490", "q1491", "q1492", "q1493", "q1494", "q1495", 
    "q1496", "q1497", "q1498", "q1499", "q1500", "q1501", "q1502", "q1503", 
    "q1504", "q1505", "q1506", "q1507", "q1508", "q1509", "q1510", "q1511", 
    "q1512", "q1513", "q1514", "q1515", "q1516", "q1517", "q1518", "q1519", 
    "q1520", "q1521", "q1522", "q1523", "q1524", "q1525", "q1526", "q1527", 
    "q1528", "q1529", "q1530", "q1531", "q1532", "q1533", "q1534", "q1535", 
    "q1536", "q1537", "q1538", "q1539", "q1540", "q1541", "q1542", "q1543", 
    "q1544", "q1545", "q1546", "q1547", "q1548", "q1549", "q1550", "q1551", 
    "q1552", "q1553", "q1554", "q1555", "q1556", "q1557", "q1558", "q1559", 
    "q1560", "q1561", "q1562", "q1563", "q1564", "q1565", "q1566", "q1567", 
    "q1568", "q1569", "q1570", "q1571", "q1572", "q1573", "q1574", "q1575", 
    "q1576", "q1577", "q1578", "q1579", "q1580", "q1581", "q1582", "q1583", 
    "q1584", "q1585", "q1586", "q1587", "q1588", "q1589", "q1590", "q1591", 
    "q1592", "q1593", "q1594", "q1595", "q1596", "q1597", "q1598", "q1599", 
    "q1600", "q1601", "q1602", "q1603", "q1604", "q1605", "q1606", "q1607", 
    "q1608", "q1609", "q1610", "q1611", "q1612", "q1613", "q1614", "q1615", 
    "q1616", "q1617", "q1618", "q1619", "q1620", "q1621", "q1622", "q1623", 
    "q1624", "q1625", "q1626", "q1627", "q1628", "q1629", "q1630", "q1631", 
    "q1632", "q1633", "q1634", "q1635", "q1636", "q1637", "q1638", "q1639", 
    "q1640", "q1641", "q1642", "q1643", "q1644", "q1645", "q1646", "q1647", 
    "q1648", "q1649", "q1650", "q1651", "q1652", "q1653", "q1654", "q1655", 
    "q1656", "q1657", "q1658", "q1659", "q1660", "q1661", "q1662", "q1663", 
    "q1664", "q1665", "q1666", "q1667", "q1668", "q1669", "q1670", "q1671", 
    "q1672", "q1673", "q1674", "q1675", "q1676", "q1677", "q1678", "q1679", 
    "q1680", "q1681", "q1682", "q1683", "q1684", "q1685", "q1686", "q1687", 
    "q1688", "q1689", "q1690", "q1691", "q1692", "q1693", "q1694", "q1695", 
    "q1696", "q1697", "q1698", "q1699", "q1700", "q1701", "q1702", "q1703", 
    "q1704", "q1705", "q1706", "q1707", "q1708", "q1709", "q1710", "q1711", 
    "q1712", "q1713", "q1714", "q1715", "q1716", "q1717", "q1718", "q1719", 
    "q1720", "q1721", "q1722", "q1723", "q1724", "q1725", "q1726", "q1727", 
    "q1728", "q1729", "q1730", "q1731", "q1732", "q1733", "q1734", "q1735", 
    "q1736", "q1737", "q1738", "q1739", "q1740", "q1741", "q1742", "q1743", 
    "q1744", "q1745", "q1746", "q1747", "q1748", "q1749", "q1750", "q1751", 
    "q1752", "q1753", "q1754", "q1755", "q1756", "q1757", "q1758", "q1759", 
    "q1760", "q1761", "q1762", "q1763", "q1764", "q1765", "q1766", "q1767", 
    "q1768", "q1769", "q1770", "q1771", "q1772", "q1773", "q1774", "q1775", 
    "q1776", "q1777", "q1778", "q1779", "q1780", "q1781", "q1782", "q1783", 
    "q1784", "q1785", "q1786", "q1787", "q1788", "q1789", "q1790", "q1791", 
    "q1792", "q1793", "q1794", "q1795", "q1796", "q1797", "q1798", "q1799", 
    "q1800", "q1801", "q1802", "q1803", "q1804", "q1805", "q1806", "q1807", 
    "q1808", "q1809", "q1810", "q1811", "q1812", "q1813", "q1814", "q1815", 
    "q1816", "q1817", "q1818", "q1819", "q1820", "q1821", "q1822", "q1823", 
    "q1824", "q1825", "q1826", "q1827", "q1828", "q1829", "q1830", "q1831", 
    "q1832", "q1833", "q1834", "q1835", "q1836", "q1837", "q1838", "q1839", 
    "q1840", "q1841", "q1842", "q1843", "q1844", "q1845", "q1846", "q1847", 
    "q1848", "q1849", "q1850", "q1851", "q1852", "q1853", "q1854", "q1855", 
    "q1856", "q1857", "q1858", "q1859", "q1860", "q1861", "q1862", "q1863", 
    "q1864", "q1865", "q1866", "q1867", "q1868", "q1869", "q1870", "q1871", 
    "q1872", "q1873", "q1874", "q1875", "q1876", "q1877", "q1878", "q1879", 
    "q1880", "q1881", "q1882", "q1883", "q1884", "q1885", "q1886", "q1887", 
    "q1888", "q1889", "q1890", "q1891", "q1892", "q1893", "q1894", "q1895", 
    "q1896", "q1897", "q1898", "q1899", "q1900", "q1901", "q1902", "q1903", 
    "q1904", "q1905", "q1906", "q1907", "q1908", "q1909", "q1910", "q1911", 
    "q1912", "q1913", "q1914", "q1915", "q1916", "q1917", "q1918", "q1919", 
    "q1920", "q1921", "q1922", "q1923", "q1924", "q1925", "q1926", "q1927", 
    "q1928", "q1929", "q1930", "q1931", "q1932", "q1933", "q1934", "q1935", 
    "q1936", "q1937", "q1938", "q1939", "q1940", "q1941", "q1942", "q1943", 
    "q1944", "q1945", "q1946", "q1947", "q1948", "q1949", "q1950", "q1951", 
    "q1952", "q1953", "q1954", "q1955", "q1956", "q1957", "q1958", "q1959", 
    "q1960", "q1961", "q1962", "q1963", "q1964", "q1965", "q1966", "q1967", 
    "q1968", "q1969", "q1970", "q1971", "q1972", "q1973", "q1974", "q1975", 
    "q1976", "q1977", "q1978", "q1979", "q1980", "q1981", "q1982", "q1983", 
    "q1984", "q1985", "q1986", "q1987", "q1988", "q1989", "q1990", "q1991", 
    "q1992", "q1993", "q1994", "q1995", "q1996", "q1997", "q1998", "q1999", 
    "q2000", "q2001", "q2002", "q2003", "q2004", "q2005", "q2006", "q2007", 
    "q2008", "q2009", "q2010", "q2011", "q2012", "q2013", "q2014", "q2015", 
    "q2016", "q2017", "q2018", "q2019", "q2020", "q2021", "q2022", "q2023", 
    "q2024", "q2025", "q2026", "q2027", "q2028", "q2029", "q2030", "q2031", 
    "q2032", "q2033", "q2034", "q2035", "q2036", "q2037", "q2038", "q2039", 
    "q2040", "q2041", "q2042", "q2043", "q2044", "q2045", "q2046", "q2047", 
    "q2048", "q2049", "q2050", "q2051", "q2052", "q2053", "q2054", "q2055", 
    "q2056", "q2057", "q2058", "q2059", "q2060", "q2061", "q2062", "q2063", 
    "q2064", "q2065", "q2066", "q2067", "q2068", "q2069", "q2070", "q2071", 
    "q2072", "q2073", "q2074", "q2075", "q2076", "q2077", "q2078", "q2079", 
    "q2080", "q2081", "q2082", "q2083", "q2084", "q2085", "q2086", "q2087", 
    "q2088", "q2089", "q2090", "q2091", "q2092", "q2093", "q2094", "q2095", 
    "q2096", "q2097", "q2098", "q2099", "q2100", "q2101", "q2102", "q2103", 
    "q2104", "q2105", "q2106", "q2107", "q2108", "q2109", "q2110", "q2111", 
    "q2112", "q2113", "q2114", "q2115", "q2116", "q2117", "q2118", "q2119", 
    "q2120", "q2121", "q2122", "q2123", "q2124", "q2125", "q2126", "q2127", 
    "q2128", "q2129", "q2130", "q2131", "q2132", "q2133", "q2134", "q2135", 
    "q2136", "q2137", "q2138", "q2139", "q2140", "q2141", "q2142", "q2143", 
    "q2144", "q2145", "q2146", "q2147", "q2148", "q2149", "q2150", "q2151", 
    "q2152", "q2153", "q2154", "q2155", "q2156", "q2157", "q2158", "q2159", 
    "q2160", "q2161", "q2162", "q2163", "q2164", "q2165", "q2166", "q2167", 
    "q2168", "q2169", "q2170", "q2171", "q2172", "q2173", "q2174", "q2175", 
    "q2176", "q2177", "q2178", "q2179", "q2180", "q2181", "q2182", "q2183", 
    "q2184", "q2185", "q2186", "q2187", "q2188", "q2189", "q2190", "q2191", 
    "q2192", "q2193", "q2194", "q2195", "q2196", "q2197", "q2198", "q2199", 
    "q2200", "q2201", "q2202", "q2203", "q2204", "q2205", "q2206", "q2207", 
    "q2208", "q2209", "q2210", "q2211", "q2212", "q2213", "q2214", "q2215", 
    "q2216", "q2217", "q2218", "q2219", "q2220", "q2221", "q2222", "q2223", 
    "q2224", "q2225", "q2226", "q2227", "q2228", "q2229", "q2230", "q2231", 
    "q2232", "q2233", "q2234", "q2235", "q2236", "q2237", "q2238", "q2239", 
    "q2240", "q2241", "q2242", "q2243", "q2244", "q2245", "q2246", "q2247", 
    "q2248", "q2249", "q2250", "q2251", "q2252", "q2253", "q2254", "q2255", 
    "q2256", "q2257", "q2258", "q2259", "q2260", "q2261", "q2262", "q2263", 
    "q2264", "q2265", "q2266", "q2267", "q2268", "q2269", "q2270", "q2271", 
    "q2272", "q2273", "q2274", "q2275", "q2276", "q2277", "q2278", "q2279", 
    "q2280", "q2281", "q2282", "q2283", "q2284", "q2285", "q2286", "q2287", 
    "q2288", "q2289", "q2290", "q2291", "q2292", "q2293", "q2294", "q2295", 
    "q2296", "q2297", "q2298", "q2299", "q2300", "q2301", "q2302", "q2303", 
    "q2304", "q2305", "q2306", "q2307", "q2308", "q2309", "q2310", "q2311", 
    "q2312", "q2313", "q2314", "q2315", "q2316", "q2317", "q2318", "q2319", 
    "q2320", "q2321", "q2322", "q2323", "q2324", "q2325", "q2326", "q2327", 
    "q2328", "q2329", "q2330", "q2331", "q2332", "q2333", "q2334", "q2335", 
    "q2336", "q2337", "q2338", "q2339", "q2340", "q2341", "q2342", "q2343", 
    "q2344", "q2345", "q2346", "q2347", "q2348", "q2349", "q2350", "q2351", 
    "q2352", "q2353", "q2354", "q2355", "q2356", "q2357", "q2358", "q2359", 
    "q2360", "q2361", "q2362", "q2363", "q2364", "q2365", "q2366", "q2367", 
    "q2368", "q2369", "q2370", "q2371", "q2372", "q2373", "q2374", "q2375", 
    "q2376", "q2377", "q2378", "q2379", "q2380", "q2381", "q2382", "q2383", 
    "q2384", "q2385", "q2386", "q2387", "q2388", "q2389", "q2390", "q2391", 
    "q2392", "q2393", "q2394", "q2395", "q2396", "q2397", "q2398", "q2399", 
    "q2400", "q2401", "q2402", "q2403", "q2404", "q2405", "q2406", "q2407", 
    "q2408", "q2409", "q2410", "q2411", "q2412", "q2413", "q2414", "q2415", 
    "q2416", "q2417", "q2418", "q2419", "q2420", "q2421", "q2422", "q2423", 
    "q2424", "q2425", "q2426", "q2427", "q2428", "q2429", "q2430", "q2431", 
    "q2432", "q2433", "q2434", "q2435", "q2436", "q2437", "q2438", "q2439", 
    "q2440", "q2441", "q2442", "q2443", "q2444", "q2445", "q2446", "q2447", 
    "q2448", "q2449", "q2450", "q2451", "q2452", "q2453", "q2454", "q2455", 
    "q2456", "q2457", "q2458", "q2459", "q2460", "q2461", "q2462", "q2463", 
    "q2464", "q2465", "q2466", "q2467", "q2468", "q2469", "q2470", "q2471", 
    "q2472", "q2473", "q2474", "q2475", "q2476", "q2477", "q2478", "q2479", 
    "q2480", "q2481", "q2482", "q2483", "q2484", "q2485", "q2486", "q2487", 
    "q2488", "q2489", "q2490", "q2491", "q2492", "q2493", "q2494", "q2495", 
    "q2496", "q2497", "q2498", "q2499", "q2500", "q2501", "q2502", "q2503", 
    "q2504", "q2505", "q2506", "q2507", "q2508", "q2509", "q2510", "q2511", 
    "q2512", "q2513", "q2514", "q2515", "q2516", "q2517", "q2518", "q2519", 
    "q2520", "q2521", "q2522", "q2523", "q2524", "q2525", "q2526", "q2527", 
    "q2528", "q2529", "q2530", "q2531", "q2532", "q2533", "q2534", "q2535", 
    "q2536", "q2537", "q2538", "q2539", "q2540", "q2541", "q2542", "q2543", 
    "q2544", "q2545", "q2546", "q2547", "q2548", "q2549", "q2550", "q2551", 
    "q2552", "q2553", "q2554", "q2555", "q2556", "q2557", "q2558", "q2559", 
    "q2560", "q2561", "q2562", "q2563", "q2564", "q2565", "q2566", "q2567", 
    "q2568", "q2569", "q2570", "q2571", "q2572", "q2573", "q2574", "q2575", 
    "q2576", "q2577", "q2578", "q2579", "q2580", "q2581", "q2582", "q2583", 
    "q2584", "q2585", "q2586", "q2587", "q2588", "q2589", "q2590", "q2591", 
    "q2592", "q2593", "q2594", "q2595", "q2596", "q2597", "q2598", "q2599", 
    "q2600", "q2601", "q2602", "q2603", "q2604", "q2605", "q2606", "q2607", 
    "q2608", "q2609", "q2610", "q2611", "q2612", "q2613", "q2614", "q2615", 
    "q2616", "q2617", "q2618", "q2619", "q2620", "q2621", "q2622", "q2623", 
    "q2624", "q2625", "q2626", "q2627", "q2628", "q2629", "q2630", "q2631", 
    "q2632", "q2633", "q2634", "q2635", "q2636", "q2637", "q2638", "q2639", 
    "q2640", "q2641", "q2642", "q2643", "q2644", "q2645", "q2646", "q2647", 
    "q2648", "q2649", "q2650", "q2651", "q2652", "q2653", "q2654", "q2655", 
    "q2656", "q2657", "q2658", "q2659", "q2660", "q2661", "q2662", "q2663", 
    "q2664", "q2665", "q2666", "q2667", "q2668", "q2669", "q2670", "q2671", 
    "q2672", "q2673", "q2674", "q2675", "q2676", "q2677", "q2678", "q2679", 
    "q2680", "q2681", "q2682", "q2683", "q2684", "q2685", "q2686", "q2687", 
    "q2688", "q2689", "q2690", "q2691", "q2692", "q2693", "q2694", "q2695", 
    "q2696", "q2697", "q2698", "q2699", "q2700", "q2701", "q2702", "q2703", 
    "q2704", "q2705", "q2706", "q2707", "q2708", "q2709", "q2710", "q2711", 
    "q2712", "q2713", "q2714", "q2715", "q2716", "q2717", "q2718", "q2719", 
    "q2720", "q2721", "q2722", "q2723", "q2724", "q2725", "q2726", "q2727", 
    "q2728", "q2729", "q2730", "q2731", "q2732", "q2733", "q2734", "q2735", 
    "q2736", "q2737", "q2738", "q2739", "q2740", "q2741", "q2742", "q2743", 
    "q2744", "q2745", "q2746", "q2747", "q2748", "q2749", "q2750", "q2751", 
    "q2752", "q2753", "q2754", "q2755", "q2756", "q2757", "q2758", "q2759", 
    "q2760", "q2761", "q2762", "q2763", "q2764", "q2765", "q2766", "q2767", 
    "q2768", "q2769", "q2770", "q2771", "q2772", "q2773", "q2774", "q2775", 
    "q2776", "q2777", "q2778", "q2779", "q2780", "q2781", "q2782", "q2783", 
    "q2784", "q2785", "q2786", "q2787", "q2788", "q2789", "q2790", "q2791", 
    "q2792", "q2793", "q2794", "q2795", "q2796", "q2797", "q2798", "q2799", 
    "q2800", "q2801", "q2802", "q2803", "q2804", "q2805", "q2806", "q2807", 
    "q2808", "q2809", "q2810", "q2811", "q2812", "q2813", "q2814", "q2815", 
    "q2816", "q2817", "q2818", "q2819", "q2820", "q2821", "q2822", "q2823", 
    "q2824", "q2825", "q2826", "q2827", "q2828", "q2829", "q2830", "q2831", 
    "q2832", "q2833", "q2834", "q2835", "q2836", "q2837", "q2838", "q2839", 
    "q2840", "q2841", "q2842", "q2843", "q2844", "q2845", "q2846", "q2847", 
    "q2848", "q2849", "q2850", "q2851", "q2852", "q2853", "q2854", "q2855", 
    "q2856", "q2857", "q2858", "q2859", "q2860", "q2861", "q2862", "q2863", 
    "q2864", "q2865", "q2866", "q2867", "q2868", "q2869", "q2870", "q2871", 
    "q2872", "q2873", "q2874", "q2875", "q2876", "q2877", "q2878", "q2879", 
    "q2880", "q2881", "q2882", "q2883", "q2884", "q2885", "q2886", "q2887", 
    "q2888", "q2889", "q2890", "q2891", "q2892", "q2893", "q2894", "q2895", 
    "q2896", "q2897", "q2898", "q2899", "q2900", "q2901", "q2902", "q2903", 
    "q2904", "q2905", "q2906", "q2907", "q2908", "q2909", "q2910", "q2911", 
    "q2912", "q2913", "q2914", "q2915", "q2916", "q2917", "q2918", "q2919", 
    "q2920", "q2921", "q2922", "q2923", "q2924", "q2925", "q2926", "q2927", 
    "q2928", "q2929", "q2930", "q2931", "q2932", "q2933", "q2934", "q2935", 
    "q2936", "q2937", "q2938", "q2939", "q2940", "q2941", "q2942", "q2943", 
    "q2944", "q2945", "q2946", "q2947", "q2948", "q2949", "q2950", "q2951", 
    "q2952", "q2953", "q2954", "q2955", "q2956", "q2957", "q2958", "q2959", 
    "q2960", "q2961", "q2962", "q2963", "q2964", "q2965", "q2966", "q2967", 
    "q2968", "q2969", "q2970", "q2971", "q2972", "q2973", "q2974", "q2975", 
    "q2976", "q2977", "q2978", "q2979", "q2980", "q2981", "q2982", "q2983", 
    "q2984", "q2985", "q2986", "q2987", "q2988", "q2989", "q2990", "q2991", 
    "q2992", "q2993", "q2994", "q2995", "q2996", "q2997", "q2998", "q2999", 
    "q3000", "q3001", "q3002", "q3003", "q3004", "q3005", "q3006", "q3007", 
    "q3008", "q3009", "q3010", "q3011", "q3012", "q3013", "q3014", "q3015", 
    "q3016", "q3017", "q3018", "q3019", "q3020", "q3021", "q3022", "q3023", 
    "q3024", "q3025", "q3026", "q3027", "q3028", "q3029", "q3030", "q3031", 
    "q3032", "q3033", "q3034", "q3035", "q3036", "q3037", "q3038", "q3039", 
    "q3040", "q3041", "q3042", "q3043", "q3044", "q3045", "q3046", "q3047", 
    "q3048", "q3049", "q3050", "q3051", "q3052", "q3053", "q3054", "q3055", 
    "q3056", "q3057", "q3058", "q3059", "q3060", "q3061", "q3062", "q3063", 
    "q3064", "q3065", "q3066", "q3067", "q3068", "q3069", "q3070", "q3071", 
    "q3072", "q3073", "q3074", "q3075", "q3076", "q3077", "q3078", "q3079", 
    "q3080", "q3081", "q3082", "q3083", "q3084", "q3085", "q3086", "q3087", 
    "q3088", "q3089", "q3090", "q3091", "q3092", "q3093", "q3094", "q3095", 
    "q3096", "q3097", "q3098", "q3099", "q3100", "q3101", "q3102", "q3103", 
    "q3104", "q3105", "q3106", "q3107", "q3108", "q3109", "q3110", "q3111", 
    "q3112", "q3113", "q3114", "q3115", "q3116", "q3117", "q3118", "q3119", 
    "q3120", "q3121", "q3122", "q3123", "q3124", "q3125", "q3126", "q3127", 
    "q3128", "q3129", "q3130", "q3131", "q3132", "q3133", "q3134", "q3135", 
    "q3136", "q3137", "q3138", "q3139", "q3140", "q3141", "q3142", "q3143", 
    "q3144", "q3145", "q3146", "q3147", "q3148", "q3149", "q3150", "q3151", 
    "q3152", "q3153", "q3154", "q3155", "q3156", "q3157", "q3158", "q3159", 
    "q3160", "q3161", "q3162", "q3163", "q3164", "q3165", "q3166", "q3167", 
    "q3168", "q3169", "q3170", "q3171", "q3172", "q3173", "q3174", "q3175", 
    "q3176", "q3177", "q3178", "q3179", "q3180", "q3181", "q3182", "q3183", 
    "q3184", "q3185", "q3186", "q3187", "q3188", "q3189", "q3190", "q3191", 
    "q3192", "q3193", "q3194", "q3195", "q3196", "q3197", "q3198", "q3199", 
    "q3200", "q3201", "q3202", "q3203", "q3204", "q3205", "q3206", "q3207", 
    "q3208", "q3209", "q3210", "q3211", "q3212", "q3213", "q3214", "q3215", 
    "q3216", "q3217", "q3218", "q3219", "q3220", "q3221", "q3222", "q3223", 
    "q3224", "q3225", "q3226", "q3227", "q3228", "q3229", "q3230", "q3231", 
    "q3232", "q3233", "q3234", "q3235", "q3236", "q3237", "q3238", "q3239", 
    "q3240", "q3241", "q3242", "q3243", "q3244", "q3245", "q3246", "q3247", 
    "q3248", "q3249", "q3250", "q3251", "q3252", "q3253", "q3254", "q3255", 
    "q3256", "q3257", "q3258", "q3259", "q3260", "q3261", "q3262", "q3263", 
    "q3264", "q3265", "q3266", "q3267", "q3268", "q3269", "q3270", "q3271", 
    "q3272", "q3273", "q3274", "q3275", "q3276", "q3277", "q3278", "q3279", 
    "q3280", "q3281", "q3282", "q3283", "q3284", "q3285", "q3286", "q3287", 
    "q3288", "q3289", "q3290", "q3291", "q3292", "q3293", "q3294", "q3295", 
    "q3296", "q3297", "q3298", "q3299", "q3300", "q3301", "q3302", "q3303", 
    "q3304", "q3305", "q3306", "q3307", "q3308", "q3309", "q3310", "q3311", 
    "q3312", "q3313", "q3314", "q3315", "q3316", "q3317", "q3318", "q3319", 
    "q3320", "q3321", "q3322", "q3323", "q3324", "q3325", "q3326", "q3327", 
    "q3328", "q3329", "q3330", "q3331", "q3332", "q3333", "q3334", "q3335", 
    "q3336", "q3337", "q3338", "q3339", "q3340", "q3341", "q3342", "q3343", 
    "q3344", "q3345", "q3346", "q3347", "q3348", "q3349", "q3350", "q3351", 
    "q3352", "q3353", "q3354", "q3355", "q3356", "q3357", "q3358", "q3359", 
    "q3360", "q3361", "q3362", "q3363", "q3364", "q3365", "q3366", "q3367", 
    "q3368", "q3369", "q3370", "q3371", "q3372", "q3373", "q3374", "q3375", 
    "q3376", "q3377", "q3378", "q3379", "q3380", "q3381", "q3382", "q3383", 
    "q3384", "q3385", "q3386", "q3387", "q3388", "q3389", "q3390", "q3391", 
    "q3392", "q3393", "q3394", "q3395", "q3396", "q3397", "q3398", "q3399", 
    "q3400", "q3401", "q3402", "q3403", "q3404", "q3405", "q3406", "q3407", 
    "q3408", "q3409", "q3410", "q3411", "q3412", "q3413", "q3414", "q3415", 
    "q3416", "q3417", "q3418", "q3419", "q3420", "q3421", "q3422", "q3423", 
    "q3424", "q3425", "q3426", "q3427", "q3428", "q3429", "q3430", "q3431", 
    "q3432", "q3433", "q3434", "q3435", "q3436", "q3437", "q3438", "q3439", 
    "q3440", "q3441", "q3442", "q3443", "q3444", "q3445", "q3446", "q3447", 
    "q3448", "q3449", "q3450", "q3451", "q3452", "q3453", "q3454", "q3455", 
    "q3456", "q3457", "q3458", "q3459", "q3460", "q3461", "q3462", "q3463", 
    "q3464", "q3465", "q3466", "q3467", "q3468", "q3469", "q3470", "q3471", 
    "q3472", "q3473", "q3474", "q3475", "q3476", "q3477", "q3478", "q3479", 
    "q3480", "q3481", "q3482", "q3483", "q3484", "q3485", "q3486", "q3487", 
    "q3488", "q3489", "q3490", "q3491", "q3492", "q3493", "q3494", "q3495", 
    "q3496", "q3497", "q3498", "q3499", "q3500", "q3501", "q3502", "q3503", 
    "q3504", "q3505", "q3506", "q3507", "q3508", "q3509", "q3510", "q3511", 
    "q3512", "q3513", "q3514", "q3515", "q3516", "q3517", "q3518", "q3519", 
    "q3520", "q3521", "q3522", "q3523", "q3524", "q3525", "q3526", "q3527", 
    "q3528", "q3529", "q3530", "q3531", "q3532", "q3533", "q3534", "q3535", 
    "q3536", "q3537", "q3538", "q3539", "q3540", "q3541", "q3542", "q3543", 
    "q3544", "q3545", "q3546", "q3547", "q3548", "q3549", "q3550", "q3551", 
    "q3552", "q3553", "q3554", "q3555", "q3556", "q3557", "q3558", "q3559", 
    "q3560", "q3561", "q3562", "q3563", "q3564", "q3565", "q3566", "q3567", 
    "q3568", "q3569", "q3570", "q3571", "q3572", "q3573", "q3574", "q3575", 
    "q3576", "q3577", "q3578", "q3579", "q3580", "q3581", "q3582", "q3583", 
    "q3584", "q3585", "q3586", "q3587", "q3588", "q3589", "q3590", "q3591", 
    "q3592", "q3593", "q3594", "q3595", "q3596", "q3597", "q3598", "q3599", 
    "q3600", "q3601", "q3602", "q3603", "q3604", "q3605", "q3606", "q3607", 
    "q3608", "q3609", "q3610", "q3611", "q3612", "q3613", "q3614", "q3615", 
    "q3616", "q3617", "q3618", "q3619", "q3620", "q3621", "q3622", "q3623", 
    "q3624", "q3625", "q3626", "q3627", "q3628", "q3629", "q3630", "q3631", 
    "q3632", "q3633", "q3634", "q3635", "q3636", "q3637", "q3638", "q3639", 
    "q3640", "q3641", "q3642", "q3643", "q3644", "q3645", "q3646", "q3647", 
    "q3648", "q3649", "q3650", "q3651", "q3652", "q3653", "q3654", "q3655", 
    "q3656", "q3657", "q3658", "q3659", "q3660", "q3661", "q3662", "q3663", 
    "q3664", "q3665", "q3666", "q3667", "q3668", "q3669", "q3670", "q3671", 
    "q3672", "q3673", "q3674", "q3675", "q3676", "q3677", "q3678", "q3679", 
    "q3680", "q3681", "q3682", "q3683", "q3684", "q3685", "q3686", "q3687", 
    "q3688", "q3689", "q3690", "q3691", "q3692", "q3693", "q3694", "q3695", 
    "q3696", "q3697", "q3698", "q3699", "q3700", "q3701", "q3702", "q3703", 
    "q3704", "q3705", "q3706", "q3707", "q3708", "q3709", "q3710", "q3711", 
    "q3712", "q3713", "q3714", "q3715", "q3716", "q3717", "q3718", "q3719", 
    "q3720", "q3721", "q3722", "q3723", "q3724", "q3725", "q3726", "q3727", 
    "q3728", "q3729", "q3730", "q3731", "q3732", "q3733", "q3734", "q3735", 
    "q3736", "q3737", "q3738", "q3739", "q3740", "q3741", "q3742", "q3743", 
    "q3744", "q3745", "q3746", "q3747", "q3748", "q3749", "q3750", "q3751", 
    "q3752", "q3753", "q3754", "q3755", "q3756", "q3757", "q3758", "q3759", 
    "q3760", "q3761", "q3762", "q3763", "q3764", "q3765", "q3766", "q3767", 
    "q3768", "q3769", "q3770", "q3771", "q3772", "q3773", "q3774", "q3775", 
    "q3776", "q3777", "q3778", "q3779", "q3780", "q3781", "q3782", "q3783", 
    "q3784", "q3785", "q3786", "q3787", "q3788", "q3789", "q3790", "q3791", 
    "q3792", "q3793", "q3794", "q3795", "q3796", "q3797", "q3798", "q3799", 
    "q3800", "q3801", "q3802", "q3803", "q3804", "q3805", "q3806", "q3807", 
    "q3808", "q3809", "q3810", "q3811", "q3812", "q3813", "q3814", "q3815", 
    "q3816", "q3817", "q3818", "q3819", "q3820", "q3821", "q3822", "q3823", 
    "q3824", "q3825", "q3826", "q3827", "q3828", "q3829", "q3830", "q3831", 
    "q3832", "q3833", "q3834", "q3835", "q3836", "q3837", "q3838", "q3839", 
    "q3840", "q3841", "q3842", "q3843", "q3844", "q3845", "q3846", "q3847", 
    "q3848", "q3849", "q3850", "q3851", "q3852", "q3853", "q3854", "q3855", 
    "q3856", "q3857", "q3858", "q3859", "q3860", "q3861", "q3862", "q3863", 
    "q3864", "q3865", "q3866", "q3867", "q3868", "q3869", "q3870", "q3871", 
    "q3872", "q3873", "q3874", "q3875", "q3876", "q3877", "q3878", "q3879", 
    "q3880", "q3881", "q3882", "q3883", "q3884", "q3885", "q3886", "q3887", 
    "q3888", "q3889", "q3890", "q3891", "q3892", "q3893", "q3894", "q3895", 
    "q3896", "q3897", "q3898", "q3899", "q3900", "q3901", "q3902", "q3903", 
    "q3904", "q3905", "q3906", "q3907", "q3908", "q3909", "q3910", "q3911", 
    "q3912", "q3913", "q3914", "q3915", "q3916", "q3917", "q3918", "q3919", 
    "q3920", "q3921", "q3922", "q3923", "q3924", "q3925", "q3926", "q3927", 
    "q3928", "q3929", "q3930", "q3931", "q3932", "q3933", "q3934", "q3935", 
    "q3936", "q3937", "q3938", "q3939", "q3940", "q3941", "q3942", "q3943", 
    "q3944", "q3945", "q3946", "q3947", "q3948", "q3949", "q3950", "q3951", 
    "q3952", "q3953", "q3954", "q3955", "q3956", "q3957", "q3958", "q3959", 
    "q3960", "q3961", "q3962", "q3963", "q3964", "q3965", "q3966", "q3967", 
    "q3968", "q3969", "q3970", "q3971", "q3972", "q3973", "q3974", "q3975", 
    "q3976", "q3977", "q3978", "q3979", "q3980", "q3981", "q3982", "q3983", 
    "q3984", "q3985", "q3986", "q3987", "q3988", "q3989", "q3990", "q3991", 
    "q3992", "q3993", "q3994", "q3995", "q3996", "q3997", "q3998", "q3999", 
    "q4000", "q4001", "q4002", "q4003", "q4004", "q4005", "q4006", "q4007", 
    "q4008", "q4009", "q4010", "q4011", "q4012", "q4013", "q4014", "q4015", 
    "q4016", "q4017", "q4018", "q4019", "q4020", "q4021", "q4022", "q4023", 
    "q4024", "q4025", "q4026", "q4027", "q4028", "q4029", "q4030", "q4031", 
    "q4032", "q4033", "q4034", "q4035", "q4036", "q4037", "q4038", "q4039", 
    "q4040", "q4041", "q4042", "q4043", "q4044", "q4045", "q4046", "q4047", 
    "q4048", "q4049", "q4050", "q4051", "q4052", "q4053", "q4054", "q4055", 
    "q4056", "q4057", "q4058", "q4059", "q4060", "q4061", "q4062", "q4063", 
    "q4064", "q4065", "q4066", "q4067", "q4068", "q4069", "q4070", "q4071", 
    "q4072", "q4073", "q4074", "q4075", "q4076", "q4077", "q4078", "q4079", 
    "q4080", "q4081", "q4082", "q4083", "q4084", "q4085", "q4086", "q4087", 
    "q4088", "q4089", "q4090", "q4091", "q4092", "q4093", "q4094", "q4095", 
    "q4096", "q4097", "q4098", "q4099", "q4100", "q4101", "q4102", "q4103", 
    "q4104", "q4105", "q4106", "q4107", "q4108", "q4109", "q4110", "q4111", 
    "q4112", "q4113", "q4114", "q4115", "q4116", "q4117", "q4118", "q4119", 
    "q4120", "q4121", "q4122", "q4123", "q4124", "q4125", "q4126", "q4127", 
    "q4128", "q4129", "q4130", "q4131", "q4132", "q4133", "q4134", "q4135", 
    "q4136", "q4137", "q4138", "q4139", "q4140", "q4141", "q4142", "q4143", 
    "q4144", "q4145", "q4146", "q4147", "q4148", "q4149", "q4150", "q4151", 
    "q4152", "q4153", "q4154", "q4155", "q4156", "q4157", "q4158", "q4159", 
    "q4160", "q4161", "q4162", "q4163", "q4164", "q4165", "q4166", "q4167", 
    "q4168", "q4169", "q4170", "q4171", "q4172", "q4173", "q4174", "q4175", 
    "q4176", "q4177", "q4178", "q4179", "q4180", "q4181", "q4182", "q4183", 
    "q4184", "q4185", "q4186", "q4187", "q4188", "q4189", "q4190", "q4191", 
    "q4192", "q4193", "q4194", "q4195", "q4196", "q4197", "q4198", "q4199", 
    "q4200", "q4201", "q4202", "q4203", "q4204", "q4205", "q4206", "q4207", 
    "q4208", "q4209", "q4210", "q4211", "q4212", "q4213", "q4214", "q4215", 
    "q4216", "q4217", "q4218", "q4219", "q4220", "q4221", "q4222", "q4223", 
    "q4224", "q4225", "q4226", "q4227", "q4228", "q4229", "q4230", "q4231", 
    "q4232", "q4233", "q4234", "q4235", "q4236", "q4237", "q4238", "q4239", 
    "q4240", "q4241", "q4242", "q4243", "q4244", "q4245", "q4246", "q4247", 
    "q4248", "q4249", "q4250", "q4251", "q4252", "q4253", "q4254", "q4255", 
    "q4256", "q4257", "q4258", "q4259", "q4260", "q4261", "q4262", "q4263", 
    "q4264", "q4265", "q4266", "q4267", "q4268", "q4269", "q4270", "q4271", 
    "q4272", "q4273", "q4274", "q4275", "q4276", "q4277", "q4278", "q4279", 
    "q4280", "q4281", "q4282", "q4283", "q4284", "q4285", "q4286", "q4287", 
    "q4288", "q4289", "q4290", "q4291", "q4292", "q4293", "q4294", "q4295", 
    "q4296", "q4297", "q4298", "q4299", "q4300", "q4301", "q4302", "q4303", 
    "q4304", "q4305", "q4306", "q4307", "q4308", "q4309", "q4310", "q4311", 
    "q4312", "q4313", "q4314", "q4315", "q4316", "q4317", "q4318", "q4319", 
    "q4320", "q4321", "q4322", "q4323", "q4324", "q4325", "q4326", "q4327", 
    "q4328", "q4329", "q4330", "q4331", "q4332", "q4333", "q4334", "q4335", 
    "q4336", "q4337", "q4338", "q4339", "q4340", "q4341", "q4342", "q4343", 
    "q4344", "q4345", "q4346", "q4347", "q4348", "q4349", "q4350", "q4351", 
    "q4352", "q4353", "q4354", "q4355", "q4356", "q4357", "q4358", "q4359", 
    "q4360", "q4361", "q4362", "q4363", "q4364", "q4365", "q4366", "q4367", 
    "q4368", "q4369", "q4370", "q4371", "q4372", "q4373", "q4374", "q4375", 
    "q4376", "q4377", "q4378", "q4379", "q4380", "q4381", "q4382", "q4383", 
    "q4384", "q4385", "q4386", "q4387", "q4388", "q4389", "q4390", "q4391", 
    "q4392", "q4393", "q4394", "q4395", "q4396", "q4397", "q4398", "q4399", 
    "q4400", "q4401", "q4402", "q4403", "q4404", "q4405", "q4406", "q4407", 
    "q4408", "q4409", "q4410", "q4411", "q4412", "q4413", "q4414", "q4415", 
    "q4416", "q4417", "q4418", "q4419", "q4420", "q4421", "q4422", "q4423", 
    "q4424", "q4425", "q4426", "q4427", "q4428", "q4429", "q4430", "q4431", 
    "q4432", "q4433", "q4434", "q4435", "q4436", "q4437", "q4438", "q4439", 
    "q4440", "q4441", "q4442", "q4443", "q4444", "q4445", "q4446", "q4447", 
    "q4448", "q4449", "q4450", "q4451", "q4452", "q4453", "q4454", "q4455", 
    "q4456", "q4457", "q4458", "q4459", "q4460", "q4461", "q4462", "q4463", 
    "q4464", "q4465", "q4466", "q4467", "q4468", "q4469", "q4470", "q4471", 
    "q4472", "q4473", "q4474", "q4475", "q4476", "q4477", "q4478", "q4479", 
    "q4480", "q4481", "q4482", "q4483", "q4484", "q4485", "q4486", "q4487", 
    "q4488", "q4489", "q4490", "q4491", "q4492", "q4493", "q4494", "q4495", 
    "q4496", "q4497", "q4498", "q4499", "q4500", "q4501", "q4502", "q4503", 
    "q4504", "q4505", "q4506", "q4507", "q4508", "q4509", "q4510", "q4511", 
    "q4512", "q4513", "q4514", "q4515", "q4516", "q4517", "q4518", "q4519", 
    "q4520", "q4521", "q4522", "q4523", "q4524", "q4525", "q4526", "q4527", 
    "q4528", "q4529", "q4530", "q4531", "q4532", "q4533", "q4534", "q4535", 
    "q4536", "q4537", "q4538", "q4539", "q4540", "q4541", "q4542", "q4543", 
    "q4544", "q4545", "q4546", "q4547", "q4548", "q4549", "q4550", "q4551", 
    "q4552", "q4553", "q4554", "q4555", "q4556", "q4557", "q4558", "q4559", 
    "q4560", "q4561", "q4562", "q4563", "q4564", "q4565", "q4566", "q4567", 
    "q4568", "q4569", "q4570", "q4571", "q4572", "q4573", "q4574", "q4575", 
    "q4576", "q4577", "q4578", "q4579", "q4580", "q4581", "q4582", "q4583", 
    "q4584", "q4585", "q4586", "q4587", "q4588", "q4589", "q4590", "q4591", 
    "q4592", "q4593", "q4594", "q4595", "q4596", "q4597", "q4598", "q4599", 
    "q4600", "q4601", "q4602", "q4603", "q4604", "q4605", "q4606", "q4607", 
    "q4608", "q4609", "q4610", "q4611", "q4612", "q4613", "q4614", "q4615", 
    "q4616", "q4617", "q4618", "q4619", "q4620", "q4621", "q4622", "q4623", 
    "q4624", "q4625", "q4626", "q4627", "q4628", "q4629", "q4630", "q4631", 
    "q4632", "q4633", "q4634", "q4635", "q4636", "q4637", "q4638", "q4639", 
    "q4640", "q4641", "q4642", "q4643", "q4644", "q4645", "q4646", "q4647", 
    "q4648", "q4649", "q4650", "q4651", "q4652", "q4653", "q4654", "q4655", 
    "q4656", "q4657", "q4658", "q4659", "q4660", "q4661", "q4662", "q4663", 
    "q4664", "q4665", "q4666", "q4667", "q4668", "q4669", "q4670", "q4671", 
    "q4672", "q4673", "q4674", "q4675", "q4676", "q4677", "q4678", "q4679", 
    "q4680", "q4681", "q4682", "q4683", "q4684", "q4685", "q4686", "q4687", 
    "q4688", "q4689", "q4690", "q4691", "q4692", "q4693", "q4694", "q4695", 
    "q4696", "q4697", "q4698", "q4699", "q4700", "q4701", "q4702", "q4703", 
    "q4704", "q4705", "q4706", "q4707", "q4708", "q4709", "q4710", "q4711", 
    "q4712", "q4713", "q4714", "q4715", "q4716", "q4717", "q4718", "q4719", 
    "q4720", "q4721", "q4722", "q4723", "q4724", "q4725", "q4726", "q4727", 
    "q4728", "q4729", "q4730", "q4731", "q4732", "q4733", "q4734", "q4735", 
    "q4736", "q4737", "q4738", "q4739", "q4740", "q4741", "q4742", "q4743", 
    "q4744", "q4745", "q4746", "q4747", "q4748", "q4749", "q4750", "q4751", 
    "q4752", "q4753", "q4754", "q4755", "q4756", "q4757", "q4758", "q4759", 
    "q4760", "q4761", "q4762", "q4763", "q4764", "q4765", "q4766", "q4767", 
    "q4768", "q4769", "q4770", "q4771", "q4772", "q4773", "q4774", "q4775", 
    "q4776", "q4777", "q4778", "q4779", "q4780", "q4781", "q4782", "q4783", 
    "q4784", "q4785", "q4786", "q4787", "q4788", "q4789", "q4790", "q4791", 
    "q4792", "q4793", "q4794", "q4795", "q4796", "q4797", "q4798", "q4799", 
    "q4800", "q4801", "q4802", "q4803", "q4804", "q4805", "q4806", "q4807", 
    "q4808", "q4809", "q4810", "q4811", "q4812", "q4813", "q4814", "q4815", 
    "q4816", "q4817", "q4818", "q4819", "q4820", "q4821", "q4822", "q4823", 
    "q4824", "q4825", "q4826", "q4827", "q4828", "q4829", "q4830", "q4831", 
    "q4832", "q4833", "q4834", "q4835", "q4836", "q4837", "q4838", "q4839", 
    "q4840", "q4841", "q4842", "q4843", "q4844", "q4845", "q4846", "q4847", 
    "q4848", "q4849", "q4850", "q4851", "q4852", "q4853", "q4854", "q4855", 
    "q4856", "q4857", "q4858", "q4859", "q4860", "q4861", "q4862", "q4863", 
    "q4864", "q4865", "q4866", "q4867", "q4868", "q4869", "q4870", "q4871", 
    "q4872", "q4873", "q4874", "q4875", "q4876", "q4877", "q4878", "q4879", 
    "q4880", "q4881", "q4882", "q4883", "q4884", "q4885", "q4886", "q4887", 
    "q4888", "q4889", "q4890", "q4891", "q4892", "q4893", "q4894", "q4895", 
    "q4896", "q4897", "q4898", "q4899", "q4900", "q4901", "q4902", "q4903", 
    "q4904", "q4905", "q4906", "q4907", "q4908", "q4909", "q4910", "q4911", 
    "q4912", "q4913", "q4914", "q4915", "q4916", "q4917", "q4918", "q4919", 
    "q4920", "q4921", "q4922", "q4923", "q4924", "q4925", "q4926", "q4927", 
    "q4928", "q4929", "q4930", "q4931", "q4932", "q4933", "q4934", "q4935", 
    "q4936", "q4937", "q4938", "q4939", "q4940", "q4941", "q4942", "q4943", 
    "q4944", "q4945", "q4946", "q4947", "q4948", "q4949", "q4950", "q4951", 
    "q4952", "q4953", "q4954", "q4955", "q4956", "q4957", "q4958", "q4959", 
    "q4960", "q4961", "q4962", "q4963", "q4964", "q4965", "q4966", "q4967", 
    "q4968", "q4969", "q4970", "q4971", "q4972", "q4973", "q4974", "q4975", 
    "q4976", "q4977", "q4978", "q4979", "q4980", "q4981", "q4982", "q4983", 
    "q4984", "q4985", "q4986", "q4987", "q4988", "q4989", "q4990", "q4991", 
    "q4992", "q4993", "q4994", "q4995", "q4996", "q4997", "q4998", "q4999", 
    "q5000", "q5001", "q5002", "q5003", "q5004", "q5005", "q5006", "q5007", 
    "q5008", "q5009", "q5010", "q5011", "q5012", "q5013", "q5014", "q5015", 
    "q5016", "q5017", "q5018", "q5019", "q5020", "q5021", "q5022", "q5023", 
    "q5024", "q5025", "q5026", "q5027", "q5028", "q5029", "q5030", "q5031", 
    "q5032", "q5033", "q5034", "q5035", "q5036", "q5037", "q5038", "q5039", 
    "q5040", "q5041", "q5042", "q5043", "q5044", "q5045", "q5046", "q5047", 
    "q5048", "q5049", "q5050", "q5051", "q5052", "q5053", "q5054", "q5055", 
    "q5056", "q5057", "q5058", "q5059", "q5060", "q5061", "q5062", "q5063", 
    "q5064", "q5065", "q5066", "q5067", "q5068", "q5069", "q5070", "q5071", 
    "q5072", "q5073", "q5074", "q5075", "q5076", "q5077", "q5078", "q5079", 
    "q5080", "q5081", "q5082", "q5083", "q5084", "q5085", "q5086", "q5087", 
    "q5088", "q5089", "q5090", "q5091", "q5092", "q5093", "q5094", "q5095", 
    "q5096", "q5097", "q5098", "q5099", "q5100", "q5101", "q5102", "q5103", 
    "q5104", "q5105", "q5106", "q5107", "q5108", "q5109", "q5110", "q5111", 
    "q5112", "q5113", "q5114", "q5115", "q5116", "q5117", "q5118", "q5119", 
    "q5120", "q5121", "q5122", "q5123", "q5124", "q5125", "q5126", "q5127", 
    "q5128", "q5129", "q5130", "q5131", "q5132", "q5133", "q5134", "q5135", 
    "q5136", "q5137", "q5138", "q5139", "q5140", "q5141", "q5142", "q5143", 
    "q5144", "q5145", "q5146", "q5147", "q5148", "q5149", "q5150", "q5151", 
    "q5152", "q5153", "q5154", "q5155", "q5156", "q5157", "q5158", "q5159", 
    "q5160", "q5161", "q5162", "q5163", "q5164", "q5165", "q5166", "q5167", 
    "q5168", "q5169", "q5170", "q5171", "q5172", "q5173", "q5174", "q5175", 
    "q5176", "q5177", "q5178", "q5179", "q5180", "q5181", "q5182", "q5183", 
    "q5184", "q5185", "q5186", "q5187", "q5188", "q5189", "q5190", "q5191", 
    "q5192", "q5193", "q5194", "q5195", "q5196", "q5197", "q5198", "q5199", 
    "q5200", "q5201", "q5202", "q5203", "q5204", "q5205", "q5206", "q5207", 
    "q5208", "q5209", "q5210", "q5211", "q5212", "q5213", "q5214", "q5215", 
    "q5216", "q5217", "q5218", "q5219", "q5220", "q5221", "q5222", "q5223", 
    "q5224", "q5225", "q5226", "q5227", "q5228", "q5229", "q5230", "q5231", 
    "q5232", "q5233", "q5234", "q5235", "q5236", "q5237", "q5238", "q5239", 
    "q5240", "q5241", "q5242", "q5243", "q5244", "q5245", "q5246", "q5247", 
    "q5248", "q5249", "q5250", "q5251", "q5252", "q5253", "q5254", "q5255", 
    "q5256", "q5257", "q5258", "q5259", "q5260", "q5261", "q5262", "q5263", 
    "q5264", "q5265", "q5266", "q5267", "q5268", "q5269", "q5270", "q5271", 
    "q5272", "q5273", "q5274", "q5275", "q5276", "q5277", "q5278", "q5279", 
    "q5280", "q5281", "q5282", "q5283", "q5284", "q5285", "q5286", "q5287", 
    "q5288", "q5289", "q5290", "q5291", "q5292", "q5293", "q5294", "q5295", 
    "q5296", "q5297", "q5298", "q5299", "q5300", "q5301", "q5302", "q5303", 
    "q5304", "q5305", "q5306", "q5307", "q5308", "q5309", "q5310", "q5311", 
    "q5312", "q5313", "q5314", "q5315", "q5316", "q5317", "q5318", "q5319", 
    "q5320", "q5321", "q5322", "q5323", "q5324", "q5325", "q5326", "q5327", 
    "q5328", "q5329", "q5330", "q5331", "q5332", "q5333", "q5334", "q5335", 
    "q5336", "q5337", "q5338", "q5339", "q5340", "q5341", "q5342", "q5343", 
    "q5344", "q5345", "q5346", "q5347", "q5348", "q5349", "q5350", "q5351", 
    "q5352", "q5353", "q5354", "q5355", "q5356", "q5357", "q5358", "q5359", 
    "q5360", "q5361", "q5362", "q5363", "q5364", "q5365", "q5366", "q5367", 
    "q5368", "q5369", "q5370", "q5371", "q5372", "q5373", "q5374", "q5375", 
    "q5376", "q5377", "q5378", "q5379", "q5380", "q5381", "q5382", "q5383", 
    "q5384", "q5385", "q5386", "q5387", "q5388", "q5389", "q5390", "q5391", 
    "q5392", "q5393", "q5394", "q5395", "q5396", "q5397", "q5398", "q5399", 
    "q5400", "q5401", "q5402", "q5403", "q5404", "q5405", "q5406", "q5407", 
    "q5408", "q5409", "q5410", "q5411", "q5412", "q5413", "q5414", "q5415", 
    "q5416", "q5417", "q5418", "q5419", "q5420", "q5421", "q5422", "q5423", 
    "q5424", "q5425", "q5426", "q5427", "q5428", "q5429", "q5430", "q5431", 
    "q5432", "q5433", "q5434", "q5435", "q5436", "q5437", "q5438", "q5439", 
    "q5440", "q5441", "q5442", "q5443", "q5444", "q5445", "q5446", "q5447", 
    "q5448", "q5449", "q5450", "q5451", "q5452", "q5453", "q5454", "q5455", 
    "q5456", "q5457", "q5458", "q5459", "q5460", "q5461", "q5462", "q5463", 
    "q5464", "q5465", "q5466", "q5467", "q5468", "q5469", "q5470", "q5471", 
    "q5472", "q5473", "q5474", "q5475", "q5476", "q5477", "q5478", "q5479", 
    "q5480", "q5481", "q5482", "q5483", "q5484", "q5485", "q5486", "q5487", 
    "q5488", "q5489", "q5490", "q5491", "q5492", "q5493", "q5494", "q5495", 
    "q5496", "q5497", "q5498", "q5499", "q5500", "q5501", "q5502", "q5503", 
    "q5504", "q5505", "q5506", "q5507", "q5508", "q5509", "q5510", "q5511", 
    "q5512", "q5513", "q5514", "q5515", "q5516", "q5517", "q5518", "q5519", 
    "q5520", "q5521", "q5522", "q5523", "q5524", "q5525", "q5526", "q5527", 
    "q5528", "q5529", "q5530", "q5531", "q5532", "q5533", "q5534", "q5535", 
    "q5536", "q5537", "q5538", "q5539", "q5540", "q5541", "q5542", "q5543", 
    "q5544", "q5545", "q5546", "q5547", "q5548", "q5549", "q5550", "q5551", 
    "q5552", "q5553", "q5554", "q5555", "q5556", "q5557", "q5558", "q5559", 
    "q5560", "q5561", "q5562", "q5563", "q5564", "q5565", "q5566", "q5567", 
    "q5568", "q5569", "q5570", "q5571", "q5572", "q5573", "q5574", "q5575", 
    "q5576", "q5577", "q5578", "q5579", "q5580", "q5581", "q5582", "q5583", 
    "q5584", "q5585", "q5586", "q5587", "q5588", "q5589", "q5590", "q5591", 
    "q5592", "q5593", "q5594", "q5595", "q5596", "q5597", "q5598", "q5599", 
    "q5600", "q5601", "q5602", "q5603", "q5604", "q5605", "q5606", "q5607", 
    "q5608", "q5609", "q5610", "q5611", "q5612", "q5613", "q5614", "q5615", 
    "q5616", "q5617", "q5618", "q5619", "q5620", "q5621", "q5622", "q5623", 
    "q5624", "q5625", "q5626", "q5627", "q5628", "q5629", "q5630", "q5631", 
    "q5632", "q5633", "q5634", "q5635", "q5636", "q5637", "q5638", "q5639", 
    "q5640", "q5641", "q5642", "q5643", "q5644", "q5645", "q5646", "q5647", 
    "q5648", "q5649", "q5650", "q5651", "q5652", "q5653", "q5654", "q5655", 
    "q5656", "q5657", "q5658", "q5659", "q5660", "q5661", "q5662", "q5663", 
    "q5664", "q5665", "q5666", "q5667", "q5668", "q5669", "q5670", "q5671", 
    "q5672", "q5673", "q5674", "q5675", "q5676", "q5677", "q5678", "q5679", 
    "q5680", "q5681", "q5682", "q5683", "q5684", "q5685", "q5686", "q5687", 
    "q5688", "q5689", "q5690", "q5691", "q5692", "q5693", "q5694", "q5695", 
    "q5696", "q5697", "q5698", "q5699", "q5700", "q5701", "q5702", "q5703", 
    "q5704", "q5705", "q5706", "q5707", "q5708", "q5709", "q5710", "q5711", 
    "q5712", "q5713", "q5714", "q5715", "q5716", "q5717", "q5718", "q5719", 
    "q5720", "q5721", "q5722", "q5723", "q5724", "q5725", "q5726", "q5727", 
    "q5728", "q5729", "q5730", "q5731", "q5732", "q5733", "q5734", "q5735", 
    "q5736", "q5737", "q5738", "q5739", "q5740", "q5741", "q5742", "q5743", 
    "q5744", "q5745", "q5746", "q5747", "q5748", "q5749", "q5750", "q5751", 
    "q5752", "q5753", "q5754", "q5755", "q5756", "q5757", "q5758", "q5759", 
    "q5760", "q5761", "q5762", "q5763", "q5764", "q5765", "q5766", "q5767", 
    "q5768", "q5769", "q5770", "q5771", "q5772", "q5773", "q5774", "q5775", 
    "q5776", "q5777", "q5778", "q5779", "q5780", "q5781", "q5782", "q5783", 
    "q5784", "q5785", "q5786", "q5787", "q5788", "q5789", "q5790", "q5791", 
    "q5792", "q5793", "q5794", "q5795", "q5796", "q5797", "q5798", "q5799", 
    "q5800", "q5801", "q5802", "q5803", "q5804", "q5805", "q5806", "q5807", 
    "q5808", "q5809", "q5810", "q5811", "q5812", "q5813", "q5814", "q5815", 
    "q5816", "q5817", "q5818", "q5819", "q5820", "q5821", "q5822", "q5823", 
    "q5824", "q5825", "q5826", "q5827", "q5828", "q5829", "q5830", "q5831", 
    "q5832", "q5833", "q5834", "q5835", "q5836", "q5837", "q5838", "q5839", 
    "q5840", "q5841", "q5842", "q5843", "q5844", "q5845", "q5846", "q5847", 
    "q5848", "q5849", "q5850", "q5851", "q5852", "q5853", "q5854", "q5855", 
    "q5856", "q5857", "q5858", "q5859", "q5860", "q5861", "q5862", "q5863", 
    "q5864", "q5865", "q5866", "q5867", "q5868", "q5869", "q5870", "q5871", 
    "q5872", "q5873", "q5874", "q5875", "q5876", "q5877", "q5878", "q5879", 
    "q5880", "q5881", "q5882", "q5883", "q5884", "q5885", "q5886", "q5887", 
    "q5888", "q5889", "q5890", "q5891", "q5892", "q5893", "q5894", "q5895", 
    "q5896", "q5897", "q5898", "q5899", "q5900", "q5901", "q5902", "q5903", 
    "q5904", "q5905", "q5906", "q5907", "q5908", "q5909", "q5910", "q5911", 
    "q5912", "q5913", "q5914", "q5915", "q5916", "q5917", "q5918", "q5919", 
    "q5920", "q5921", "q5922", "q5923", "q5924", "q5925", "q5926", "q5927", 
    "q5928", "q5929", "q5930", "q5931", "q5932", "q5933", "q5934", "q5935", 
    "q5936", "q5937", "q5938", "q5939", "q5940", "q5941", "q5942", "q5943", 
    "q5944", "q5945", "q5946", "q5947", "q5948", "q5949", "q5950", "q5951", 
    "q5952", "q5953", "q5954", "q5955", "q5956", "q5957", "q5958", "q5959", 
    "q5960", "q5961", "q5962", "q5963", "q5964", "q5965", "q5966", "q5967", 
    "q5968", "q5969", "q5970", "q5971", "q5972", "q5973", "q5974", "q5975", 
    "q5976", "q5977", "q5978", "q5979", "q5980", "q5981", "q5982", "q5983", 
    "q5984", "q5985", "q5986", "q5987", "q5988", "q5989", "q5990", "q5991", 
    "q5992", "q5993", "q5994", "q5995", "q5996", "q5997", "q5998", "q5999", 
    "q6000", "q6001", "q6002", "q6003", "q6004", "q6005", "q6006", "q6007", 
    "q6008", "q6009", "q6010", "q6011", "q6012", "q6013", "q6014", "q6015", 
    "q6016", "q6017", "q6018", "q6019", "q6020", "q6021", "q6022", "q6023", 
    "q6024", "q6025", "q6026", "q6027", "q6028", "q6029", "q6030", "q6031", 
    "q6032", "q6033", "q6034", "q6035", "q6036", "q6037", "q6038", "q6039", 
    "q6040", "q6041", "q6042", "q6043", "q6044", "q6045", "q6046", "q6047", 
    "q6048", "q6049", "q6050", "q6051", "q6052", "q6053", "q6054", "q6055", 
    "q6056", "q6057", "q6058", "q6059", "q6060", "q6061", "q6062", "q6063", 
    "q6064", "q6065", "q6066", "q6067", "q6068", "q6069", "q6070", "q6071", 
    "q6072", "q6073", "q6074", "q6075", "q6076", "q6077", "q6078", "q6079", 
    "q6080", "q6081", "q6082", "q6083", "q6084", "q6085", "q6086", "q6087", 
    "q6088", "q6089", "q6090", "q6091", "q6092", "q6093", "q6094", "q6095", 
    "q6096", "q6097", "q6098", "q6099", "q6100", "q6101", "q6102", "q6103", 
    "q6104", "q6105", "q6106", "q6107", "q6108", "q6109", "q6110", "q6111", 
    "q6112", "q6113", "q6114", "q6115", "q6116", "q6117", "q6118", "q6119", 
    "q6120", "q6121", "q6122", "q6123", "q6124", "q6125", "q6126", "q6127", 
    "q6128", "q6129", "q6130", "q6131", "q6132", "q6133", "q6134", "q6135", 
    "q6136", "q6137", "q6138", "q6139", "q6140", "q6141", "q6142", "q6143", 
    "q6144", "q6145", "q6146", "q6147", "q6148", "q6149", "q6150", "q6151", 
    "q6152", "q6153", "q6154", "q6155", "q6156", "q6157", "q6158", "q6159", 
    "q6160", "q6161", "q6162", "q6163", "q6164", "q6165", "q6166", "q6167", 
    "q6168", "q6169", "q6170", "q6171", "q6172", "q6173", "q6174", "q6175", 
    "q6176", "q6177", "q6178", "q6179", "q6180", "q6181", "q6182", "q6183", 
    "q6184", "q6185", "q6186", "q6187", "q6188", "q6189", "q6190", "q6191", 
    "q6192", "q6193", "q6194", "q6195", "q6196", "q6197", "q6198", "q6199", 
    "q6200", "q6201", "q6202", "q6203", "q6204", "q6205", "q6206", "q6207", 
    "q6208", "q6209", "q6210", "q6211", "q6212", "q6213", "q6214", "q6215", 
    "q6216", "q6217", "q6218", "q6219", "q6220", "q6221", "q6222", "q6223", 
    "q6224", "q6225", "q6226", "q6227", "q6228", "q6229", "q6230", "q6231", 
    "q6232", "q6233", "q6234", "q6235", "q6236", "q6237", "q6238", "q6239", 
    "q6240", "q6241", "q6242", "q6243", "q6244", "q6245", "q6246", "q6247", 
    "q6248", "q6249", "q6250", "q6251", "q6252", "q6253", "q6254", "q6255", 
    "q6256", "q6257", "q6258", "q6259", "q6260", "q6261", "q6262", "q6263", 
    "q6264", "q6265", "q6266", "q6267", "q6268", "q6269", "q6270", "q6271", 
    "q6272", "q6273", "q6274", "q6275", "q6276", "q6277", "q6278", "q6279", 
    "q6280", "q6281", "q6282", "q6283", "q6284", "q6285", "q6286", "q6287", 
    "q6288", "q6289", "q6290", "q6291", "q6292", "q6293", "q6294", "q6295", 
    "q6296", "q6297", "q6298", "q6299", "q6300", "q6301", "q6302", "q6303", 
    "q6304", "q6305", "q6306", "q6307", "q6308", "q6309", "q6310", "q6311", 
    "q6312", "q6313", "q6314", "q6315", "q6316", "q6317", "q6318", "q6319", 
    "q6320", "q6321", "q6322", "q6323", "q6324", "q6325", "q6326", "q6327", 
    "q6328", "q6329", "q6330", "q6331", "q6332", "q6333", "q6334", "q6335", 
    "q6336", "q6337", "q6338", "q6339", "q6340", "q6341", "q6342", "q6343", 
    "q6344", "q6345", "q6346", "q6347", "q6348", "q6349", "q6350", "q6351", 
    "q6352", "q6353", "q6354", "q6355", "q6356", "q6357", "q6358", "q6359", 
    "q6360", "q6361", "q6362", "q6363", "q6364", "q6365", "q6366", "q6367", 
    "q6368", "q6369", "q6370", "q6371", "q6372", "q6373", "q6374", "q6375", 
    "q6376", "q6377", "q6378", "q6379", "q6380", "q6381", "q6382", "q6383", 
    "q6384", "q6385", "q6386", "q6387", "q6388", "q6389", "q6390", "q6391", 
    "q6392", "q6393", "q6394", "q6395", "q6396", "q6397", "q6398", "q6399", 
    "q6400", "q6401", "q6402", "q6403", "q6404", "q6405", "q6406", "q6407", 
    "q6408", "q6409", "q6410", "q6411", "q6412", "q6413", "q6414", "q6415", 
    "q6416", "q6417", "q6418", "q6419", "q6420", "q6421", "q6422", "q6423", 
    "q6424", "q6425", "q6426", "q6427", "q6428", "q6429", "q6430", "q6431", 
    "q6432", "q6433", "q6434", "q6435", "q6436", "q6437", "q6438", "q6439", 
    "q6440", "q6441", "q6442", "q6443", "q6444", "q6445", "q6446", "q6447", 
    "q6448", "q6449", "q6450", "q6451", "q6452", "q6453", "q6454", "q6455", 
    "q6456", "q6457", "q6458", "q6459", "q6460", "q6461", "q6462", "q6463", 
    "q6464", "q6465", "q6466", "q6467", "q6468", "q6469", "q6470", "q6471", 
    "q6472", "q6473", "q6474", "q6475", "q6476", "q6477", "q6478", "q6479", 
    "q6480", "q6481", "q6482", "q6483", "q6484", "q6485", "q6486", "q6487", 
    "q6488", "q6489", "q6490", "q6491", "q6492", "q6493", "q6494", "q6495", 
    "q6496", "q6497", "q6498", "q6499", "q6500", "q6501", "q6502", "q6503", 
    "q6504", "q6505", "q6506", "q6507", "q6508", "q6509", "q6510", "q6511", 
    "q6512", "q6513", "q6514", "q6515", "q6516", "q6517", "q6518", "q6519", 
    "q6520", "q6521", "q6522", "q6523", "q6524", "q6525", "q6526", "q6527", 
    "q6528", "q6529", "q6530", "q6531", "q6532", "q6533", "q6534", "q6535", 
    "q6536", "q6537", "q6538", "q6539", "q6540", "q6541", "q6542", "q6543", 
    "q6544", "q6545", "q6546", "q6547", "q6548", "q6549", "q6550", "q6551", 
    "q6552", "q6553", "q6554", "q6555", "q6556", "q6557", "q6558", "q6559", 
    "q6560", "q6561", "q6562", "q6563", "q6564", "q6565", "q6566", "q6567", 
    "q6568", "q6569", "q6570", "q6571", "q6572", "q6573", "q6574", "q6575", 
    "q6576", "q6577", "q6578", "q6579", "q6580", "q6581", "q6582", "q6583", 
    "q6584", "q6585", "q6586", "q6587", "q6588", "q6589", "q6590", "q6591", 
    "q6592", "q6593", "q6594", "q6595", "q6596", "q6597", "q6598", "q6599", 
    "q6600", "q6601", "q6602", "q6603", "q6604", "q6605", "q6606", "q6607", 
    "q6608", "q6609", "q6610", "q6611", "q6612", "q6613", "q6614", "q6615", 
    "q6616", "q6617", "q6618", "q6619", "q6620", "q6621", "q6622", "q6623", 
    "q6624", "q6625", "q6626", "q6627", "q6628", "q6629", "q6630", "q6631", 
    "q6632", "q6633", "q6634", "q6635", "q6636", "q6637", "q6638", "q6639", 
    "q6640", "q6641", "q6642", "q6643", "q6644", "q6645", "q6646", "q6647", 
    "q6648", "q6649", "q6650", "q6651", "q6652", "q6653", "q6654", "q6655", 
    "q6656", "q6657", "q6658", "q6659", "q6660", "q6661", "q6662", "q6663", 
    "q6664", "q6665", "q6666", "q6667", "q6668", "q6669", "q6670", "q6671", 
    "q6672", "q6673", "q6674", "q6675", "q6676", "q6677", "q6678", "q6679", 
    "q6680", "q6681", "q6682", "q6683", "q6684", "q6685", "q6686", "q6687", 
    "q6688", "q6689", "q6690", "q6691", "q6692", "q6693", "q6694", "q6695", 
    "q6696", "q6697", "q6698", "q6699", "q6700", "q6701", "q6702", "q6703", 
    "q6704", "q6705", "q6706", "q6707", "q6708", "q6709", "q6710", "q6711", 
    "q6712", "q6713", "q6714", "q6715", "q6716", "q6717", "q6718", "q6719", 
    "q6720", "q6721", "q6722", "q6723", "q6724", "q6725", "q6726", "q6727", 
    "q6728", "q6729", "q6730", "q6731", "q6732", "q6733", "q6734", "q6735", 
    "q6736", "q6737", "q6738", "q6739", "q6740", "q6741", "q6742", "q6743", 
    "q6744", "q6745", "q6746", "q6747", "q6748", "q6749", "q6750", "q6751", 
    "q6752", "q6753", "q6754", "q6755", "q6756", "q6757", "q6758", "q6759", 
    "q6760", "q6761", "q6762", "q6763", "q6764", "q6765", "q6766", "q6767", 
    "q6768", "q6769", "q6770", "q6771", "q6772", "q6773", "q6774", "q6775", 
    "q6776", "q6777", "q6778", "q6779", "q6780", "q6781", "q6782", "q6783", 
    "q6784", "q6785", "q6786", "q6787", "q6788", "q6789", "q6790", "q6791", 
    "q6792", "q6793", "q6794", "q6795", "q6796", "q6797", "q6798", "q6799", 
    "q6800", "q6801", "q6802", "q6803", "q6804", "q6805", "q6806", "q6807", 
    "q6808", "q6809", "q6810", "q6811", "q6812", "q6813", "q6814", "q6815", 
    "q6816", "q6817", "q6818", "q6819", "q6820", "q6821", "q6822", "q6823", 
    "q6824", "q6825", "q6826", "q6827", "q6828", "q6829", "q6830", "q6831", 
    "q6832", "q6833", "q6834", "q6835", "q6836", "q6837", "q6838", "q6839", 
    "q6840", "q6841", "q6842", "q6843", "q6844", "q6845", "q6846", "q6847", 
    "q6848", "q6849", "q6850", "q6851", "q6852", "q6853", "q6854", "q6855", 
    "q6856", "q6857", "q6858", "q6859", "q6860", "q6861", "q6862", "q6863", 
    "q6864", "q6865", "q6866", "q6867", "q6868", "q6869", "q6870", "q6871", 
    "q6872", "q6873", "q6874", "q6875", "q6876", "q6877", "q6878", "q6879", 
    "q6880", "q6881", "q6882", "q6883", "q6884", "q6885", "q6886", "q6887", 
    "q6888", "q6889", "q6890", "q6891", "q6892", "q6893", "q6894", "q6895", 
    "q6896", "q6897", "q6898", "q6899", "q6900", "q6901", "q6902", "q6903", 
    "q6904", "q6905", "q6906", "q6907", "q6908", "q6909", "q6910", "q6911", 
    "q6912", "q6913", "q6914", "q6915", "q6916", "q6917", "q6918", "q6919", 
    "q6920", "q6921", "q6922", "q6923", "q6924", "q6925", "q6926", "q6927", 
    "q6928", "q6929", "q6930", "q6931", "q6932", "q6933", "q6934", "q6935", 
    "q6936", "q6937", "q6938", "q6939", "q6940", "q6941", "q6942", "q6943", 
    "q6944", "q6945", "q6946", "q6947", "q6948", "q6949", "q6950", "q6951", 
    "q6952", "q6953", "q6954", "q6955", "q6956", "q6957", "q6958", "q6959", 
    "q6960", "q6961", "q6962", "q6963", "q6964", "q6965", "q6966", "q6967", 
    "q6968", "q6969", "q6970", "q6971", "q6972", "q6973", "q6974", "q6975", 
    "q6976", "q6977", "q6978", "q6979", "q6980", "q6981", "q6982", "q6983", 
    "q6984", "q6985", "q6986", "q6987", "q6988", "q6989", "q6990", "q6991", 
    "q6992", "q6993", "q6994", "q6995", "q6996", "q6997", "q6998", "q6999", 
    "q7000", "q7001", "q7002", "q7003", "q7004", "q7005", "q7006", "q7007", 
    "q7008", "q7009", "q7010", "q7011", "q7012", "q7013", "q7014", "q7015", 
    "q7016", "q7017", "q7018", "q7019", "q7020", "q7021", "q7022", "q7023", 
    "q7024", "q7025", "q7026", "q7027", "q7028", "q7029", "q7030", "q7031", 
    "q7032", "q7033", "q7034", "q7035", "q7036", "q7037", "q7038", "q7039", 
    "q7040", "q7041", "q7042", "q7043", "q7044", "q7045", "q7046", "q7047", 
    "q7048", "q7049", "q7050", "q7051", "q7052", "q7053", "q7054", "q7055", 
    "q7056", "q7057", "q7058", "q7059", "q7060", "q7061", "q7062", "q7063", 
    "q7064", "q7065", "q7066", "q7067", "q7068", "q7069", "q7070", "q7071", 
    "q7072", "q7073", "q7074", "q7075", "q7076", "q7077", "q7078", "q7079", 
    "q7080", "q7081", "q7082", "q7083", "q7084", "q7085", "q7086", "q7087", 
    "q7088", "q7089", "q7090", "q7091", "q7092", "q7093", "q7094", "q7095", 
    "q7096", "q7097", "q7098", "q7099", "q7100", "q7101", "q7102", "q7103", 
    "q7104", "q7105", "q7106", "q7107", "q7108", "q7109", "q7110", "q7111", 
    "q7112", "q7113", "q7114", "q7115", "q7116", "q7117", "q7118", "q7119", 
    "q7120", "q7121", "q7122", "q7123", "q7124", "q7125", "q7126", "q7127", 
    "q7128", "q7129", "q7130", "q7131", "q7132", "q7133", "q7134", "q7135", 
    "q7136", "q7137", "q7138", "q7139", "q7140", "q7141", "q7142", "q7143", 
    "q7144", "q7145", "q7146", "q7147", "q7148", "q7149", "q7150", "q7151", 
    "q7152", "q7153", "q7154", "q7155", "q7156", "q7157", "q7158", "q7159", 
    "q7160", "q7161", "q7162", "q7163", "q7164", "q7165", "q7166", "q7167", 
    "q7168", "q7169", "q7170", "q7171", "q7172", "q7173", "q7174", "q7175", 
    "q7176", "q7177", "q7178", "q7179", "q7180", "q7181", "q7182", "q7183", 
    "q7184", "q7185", "q7186", "q7187", "q7188", "q7189", "q7190", "q7191", 
    "q7192", "q7193", "q7194", "q7195", "q7196", "q7197", "q7198", "q7199", 
    "q7200", "q7201", "q7202", "q7203", "q7204", "q7205", "q7206", "q7207", 
    "q7208", "q7209", "q7210", "q7211", "q7212", "q7213", "q7214", "q7215", 
    "q7216", "q7217", "q7218", "q7219", "q7220", "q7221", "q7222", "q7223", 
    "q7224", "q7225", "q7226", "q7227", "q7228", "q7229", "q7230", "q7231", 
    "q7232", "q7233", "q7234", "q7235", "q7236", "q7237", "q7238", "q7239", 
    "q7240", "q7241", "q7242", "q7243", "q7244", "q7245", "q7246", "q7247", 
    "q7248", "q7249", "q7250", "q7251", "q7252", "q7253", "q7254", "q7255", 
    "q7256", "q7257", "q7258", "q7259", "q7260", "q7261", "q7262", "q7263", 
    "q7264", "q7265", "q7266", "q7267", "q7268", "q7269", "q7270", "q7271", 
    "q7272", "q7273", "q7274", "q7275", "q7276", "q7277", "q7278", "q7279", 
    "q7280", "q7281", "q7282", "q7283", "q7284", "q7285", "q7286", "q7287", 
    "q7288", "q7289", "q7290", "q7291", "q7292", "q7293", "q7294", "q7295", 
    "q7296", "q7297", "q7298", "q7299", "q7300", "q7301", "q7302", "q7303", 
    "q7304", "q7305", "q7306", "q7307", "q7308", "q7309", "q7310", "q7311", 
    "q7312", "q7313", "q7314", "q7315", "q7316", "q7317", "q7318", "q7319", 
    "q7320", "q7321", "q7322", "q7323", "q7324", "q7325", "q7326", "q7327", 
    "q7328", "q7329", "q7330", "q7331", "q7332", "q7333", "q7334", "q7335", 
    "q7336", "q7337", "q7338", "q7339", "q7340", "q7341", "q7342", "q7343", 
    "q7344", "q7345", "q7346", "q7347", "q7348", "q7349", "q7350", "q7351", 
    "q7352", "q7353", "q7354", "q7355", "q7356", "q7357", "q7358", "q7359", 
    "q7360", "q7361", "q7362", "q7363", "q7364", "q7365", "q7366", "q7367", 
    "q7368", "q7369", "q7370", "q7371", "q7372", "q7373", "q7374", "q7375", 
    "q7376", "q7377", "q7378", "q7379", "q7380", "q7381", "q7382", "q7383", 
    "q7384", "q7385", "q7386", "q7387", "q7388", "q7389", "q7390", "q7391", 
    "q7392", "q7393", "q7394", "q7395", "q7396", "q7397", "q7398", "q7399", 
    "q7400", "q7401", "q7402", "q7403", "q7404", "q7405", "q7406", "q7407", 
    "q7408", "q7409", "q7410", "q7411", "q7412", "q7413", "q7414", "q7415", 
    "q7416", "q7417", "q7418", "q7419", "q7420", "q7421", "q7422", "q7423", 
    "q7424", "q7425", "q7426", "q7427", "q7428", "q7429", "q7430", "q7431", 
    "q7432", "q7433", "q7434", "q7435", "q7436", "q7437", "q7438", "q7439", 
    "q7440", "q7441", "q7442", "q7443", "q7444", "q7445", "q7446", "q7447", 
    "q7448", "q7449", "q7450", "q7451", "q7452", "q7453", "q7454", "q7455", 
    "q7456", "q7457", "q7458", "q7459", "q7460", "q7461", "q7462", "q7463", 
    "q7464", "q7465", "q7466", "q7467", "q7468", "q7469", "q7470", "q7471", 
    "q7472", "q7473", "q7474", "q7475", "q7476", "q7477", "q7478", "q7479", 
    "q7480", "q7481", "q7482", "q7483", "q7484", "q7485", "q7486", "q7487", 
    "q7488", "q7489", "q7490", "q7491", "q7492", "q7493", "q7494", "q7495", 
    "q7496", "q7497", "q7498", "q7499", "q7500", "q7501", "q7502", "q7503", 
    "q7504", "q7505", "q7506", "q7507", "q7508", "q7509", "q7510", "q7511", 
    "q7512", "q7513", "q7514", "q7515", "q7516", "q7517", "q7518", "q7519", 
    "q7520", "q7521", "q7522", "q7523", "q7524", "q7525", "q7526", "q7527", 
    "q7528", "q7529", "q7530", "q7531", "q7532", "q7533", "q7534", "q7535", 
    "q7536", "q7537", "q7538", "q7539", "q7540", "q7541", "q7542", "q7543", 
    "q7544", "q7545", "q7546", "q7547", "q7548", "q7549", "q7550", "q7551", 
    "q7552", "q7553", "q7554", "q7555", "q7556", "q7557", "q7558", "q7559", 
    "q7560", "q7561", "q7562", "q7563", "q7564", "q7565", "q7566", "q7567", 
    "q7568", "q7569", "q7570", "q7571", "q7572", "q7573", "q7574", "q7575", 
    "q7576", "q7577", "q7578", "q7579", "q7580", "q7581", "q7582", "q7583", 
    "q7584", "q7585", "q7586", "q7587", "q7588", "q7589", "q7590", "q7591", 
    "q7592", "q7593", "q7594", "q7595", "q7596", "q7597", "q7598", "q7599", 
    "q7600", "q7601", "q7602", "q7603", "q7604", "q7605", "q7606", "q7607", 
    "q7608", "q7609", "q7610", "q7611", "q7612", "q7613", "q7614", "q7615", 
    "q7616", "q7617", "q7618", "q7619", "q7620", "q7621", "q7622", "q7623", 
    "q7624", "q7625", "q7626", "q7627", "q7628", "q7629", "q7630", "q7631", 
    "q7632", "q7633", "q7634", "q7635", "q7636", "q7637", "q7638", "q7639", 
    "q7640", "q7641", "q7642", "q7643", "q7644", "q7645", "q7646", "q7647", 
    "q7648", "q7649", "q7650", "q7651", "q7652", "q7653", "q7654", "q7655", 
    "q7656", "q7657", "q7658", "q7659", "q7660", "q7661", "q7662", "q7663", 
    "q7664", "q7665", "q7666", "q7667", "q7668", "q7669", "q7670", "q7671", 
    "q7672", "q7673", "q7674", "q7675", "q7676", "q7677", "q7678", "q7679", 
    "q7680", "q7681", "q7682", "q7683", "q7684", "q7685", "q7686", "q7687", 
    "q7688", "q7689", "q7690", "q7691", "q7692", "q7693", "q7694", "q7695", 
    "q7696", "q7697", "q7698", "q7699", "q7700", "q7701", "q7702", "q7703", 
    "q7704", "q7705", "q7706", "q7707", "q7708", "q7709", "q7710", "q7711", 
    "q7712", "q7713", "q7714", "q7715", "q7716", "q7717", "q7718", "q7719", 
    "q7720", "q7721", "q7722", "q7723", "q7724", "q7725", "q7726", "q7727", 
    "q7728", "q7729", "q7730", "q7731", "q7732", "q7733", "q7734", "q7735", 
    "q7736", "q7737", "q7738", "q7739", "q7740", "q7741", "q7742", "q7743", 
    "q7744", "q7745", "q7746", "q7747", "q7748", "q7749", "q7750", "q7751", 
    "q7752", "q7753", "q7754", "q7755", "q7756", "q7757", "q7758", "q7759", 
    "q7760", "q7761", "q7762", "q7763", "q7764", "q7765", "q7766", "q7767", 
    "q7768", "q7769", "q7770", "q7771", "q7772", "q7773", "q7774", "q7775", 
    "q7776", "q7777", "q7778", "q7779", "q7780", "q7781", "q7782", "q7783", 
    "q7784", "q7785", "q7786", "q7787", "q7788", "q7789", "q7790", "q7791", 
    "q7792", "q7793", "q7794", "q7795", "q7796", "q7797", "q7798", "q7799", 
    "q7800", "q7801", "q7802", "q7803", "q7804", "q7805", "q7806", "q7807", 
    "q7808", "q7809", "q7810", "q7811", "q7812", "q7813", "q7814", "q7815", 
    "q7816", "q7817", "q7818", "q7819", "q7820", "q7821", "q7822", "q7823", 
    "q7824", "q7825", "q7826", "q7827", "q7828", "q7829", "q7830", "q7831", 
    "q7832", "q7833", "q7834", "q7835", "q7836", "q7837", "q7838", "q7839", 
    "q7840", "q7841", "q7842", "q7843", "q7844", "q7845", "q7846", "q7847", 
    "q7848", "q7849", "q7850", "q7851", "q7852", "q7853", "q7854", "q7855", 
    "q7856", "q7857", "q7858", "q7859", "q7860", "q7861", "q7862", "q7863", 
    "q7864", "q7865", "q7866", "q7867", "q7868", "q7869", "q7870", "q7871", 
    "q7872", "q7873", "q7874", "q7875", "q7876", "q7877", "q7878", "q7879", 
    "q7880", "q7881", "q7882", "q7883", "q7884", "q7885", "q7886", "q7887", 
    "q7888", "q7889", "q7890", "q7891", "q7892", "q7893", "q7894", "q7895", 
    "q7896", "q7897", "q7898", "q7899", "q7900", "q7901", "q7902", "q7903", 
    "q7904", "q7905", "q7906", "q7907", "q7908", "q7909", "q7910", "q7911", 
    "q7912", "q7913", "q7914", "q7915", "q7916", "q7917", "q7918", "q7919", 
    "q7920", "q7921", "q7922", "q7923", "q7924", "q7925", "q7926", "q7927", 
    "q7928", "q7929", "q7930", "q7931", "q7932", "q7933", "q7934", "q7935", 
    "q7936", "q7937", "q7938", "q7939", "q7940", "q7941", "q7942", "q7943", 
    "q7944", "q7945", "q7946", "q7947", "q7948", "q7949", "q7950", "q7951", 
    "q7952", "q7953", "q7954", "q7955", "q7956", "q7957", "q7958", "q7959", 
    "q7960", "q7961", "q7962", "q7963", "q7964", "q7965", "q7966", "q7967", 
    "q7968", "q7969", "q7970", "q7971", "q7972", "q7973", "q7974", "q7975", 
    "q7976", "q7977", "q7978", "q7979", "q7980", "q7981", "q7982", "q7983", 
    "q7984", "q7985", "q7986", "q7987", "q7988", "q7989", "q7990", "q7991", 
    "q7992", "q7993", "q7994", "q7995", "q7996", "q7997", "q7998", "q7999", 
    "q8000", "q8001", "q8002", "q8003", "q8004", "q8005", "q8006", "q8007", 
    "q8008", "q8009", "q8010", "q8011", "q8012", "q8013", "q8014", "q8015", 
    "q8016", "q8017", "q8018", "q8019", "q8020", "q8021", "q8022", "q8023", 
    "q8024", "q8025", "q8026", "q8027", "q8028", "q8029", "q8030", "q8031", 
    "q8032", "q8033", "q8034", "q8035", "q8036", "q8037", "q8038", "q8039", 
    "q8040", "q8041", "q8042", "q8043", "q8044", "q8045", "q8046", "q8047", 
    "q8048", "q8049", "q8050", "q8051", "q8052", "q8053", "q8054", "q8055", 
    "q8056", "q8057", "q8058", "q8059", "q8060", "q8061", "q8062", "q8063", 
    "q8064", "q8065", "q8066", "q8067", "q8068", "q8069", "q8070", "q8071", 
    "q8072", "q8073", "q8074", "q8075", "q8076", "q8077", "q8078", "q8079", 
    "q8080", "q8081", "q8082", "q8083", "q8084", "q8085", "q8086", "q8087", 
    "q8088", "q8089", "q8090", "q8091", "q8092", "q8093", "q8094", "q8095", 
    "q8096", "q8097", "q8098", "q8099", "q8100", "q8101", "q8102", "q8103", 
    "q8104", "q8105", "q8106", "q8107", "q8108", "q8109", "q8110", "q8111", 
    "q8112", "q8113", "q8114", "q8115", "q8116", "q8117", "q8118", "q8119", 
    "q8120", "q8121", "q8122", "q8123", "q8124", "q8125", "q8126", "q8127", 
    "q8128", "q8129", "q8130", "q8131", "q8132", "q8133", "q8134", "q8135", 
    "q8136", "q8137", "q8138", "q8139", "q8140", "q8141", "q8142", "q8143", 
    "q8144", "q8145", "q8146", "q8147", "q8148", "q8149", "q8150", "q8151", 
    "q8152", "q8153", "q8154", "q8155", "q8156", "q8157", "q8158", "q8159", 
    "q8160", "q8161", "q8162", "q8163", "q8164", "q8165", "q8166", "q8167", 
    "q8168", "q8169", "q8170", "q8171", "q8172", "q8173", "q8174", "q8175", 
    "q8176", "q8177", "q8178", "q8179", "q8180", "q8181", "q8182", "q8183", 
    "q8184", "q8185", "q8186", "q8187", "q8188", "q8189", "q8190", "q8191", 
    "q8192", "q8193", "q8194", "q8195", "q8196", "q8197", "q8198", "q8199", 
    "q8200", "q8201", "q8202", "q8203", "q8204", "q8205", "q8206", "q8207", 
    "q8208", "q8209", "q8210", "q8211", "q8212", "q8213", "q8214", "q8215", 
    "q8216", "q8217", "q8218", "q8219", "q8220", "q8221", "q8222", "q8223", 
    "q8224", "q8225", "q8226", "q8227", "q8228", "q8229", "q8230", "q8231", 
    "q8232", "q8233", "q8234", "q8235", "q8236", "q8237", "q8238", "q8239", 
    "q8240", "q8241", "q8242", "q8243", "q8244", "q8245", "q8246", "q8247", 
    "q8248", "q8249", "q8250", "q8251", "q8252", "q8253", "q8254", "q8255", 
    "q8256", "q8257", "q8258", "q8259", "q8260", "q8261", "q8262", "q8263", 
    "q8264", "q8265", "q8266", "q8267", "q8268", "q8269", "q8270", "q8271", 
    "q8272", "q8273", "q8274", "q8275", "q8276", "q8277", "q8278", "q8279", 
    "q8280", "q8281", "q8282", "q8283", "q8284", "q8285", "q8286", "q8287", 
    "q8288", "q8289", "q8290", "q8291", "q8292", "q8293", "q8294", "q8295", 
    "q8296", "q8297", "q8298", "q8299", "q8300", "q8301", "q8302", "q8303", 
    "q8304", "q8305", "q8306", "q8307", "q8308", "q8309", "q8310", "q8311", 
    "q8312", "q8313", "q8314", "q8315", "q8316", "q8317", "q8318", "q8319", 
    "q8320", "q8321", "q8322", "q8323", "q8324", "q8325", "q8326", "q8327", 
    "q8328", "q8329", "q8330", "q8331", "q8332", "q8333", "q8334", "q8335", 
    "q8336", "q8337", "q8338", "q8339", "q8340", "q8341", "q8342", "q8343", 
    "q8344", "q8345", "q8346", "q8347", "q8348", "q8349", "q8350", "q8351", 
    "q8352", "q8353", "q8354", "q8355", "q8356", "q8357", "q8358", "q8359", 
    "q8360", "q8361", "q8362", "q8363", "q8364", "q8365", "q8366", "q8367", 
    "q8368", "q8369", "q8370", "q8371", "q8372", "q8373", "q8374", "q8375", 
    "q8376", "q8377", "q8378", "q8379", "q8380", "q8381", "q8382", "q8383", 
    "q8384", "q8385", "q8386", "q8387", "q8388", "q8389", "q8390", "q8391", 
    "q8392", "q8393", "q8394", "q8395", "q8396", "q8397", "q8398", "q8399", 
    "q8400", "q8401", "q8402", "q8403", "q8404", "q8405", "q8406", "q8407", 
    "q8408", "q8409", "q8410", "q8411", "q8412", "q8413", "q8414", "q8415", 
    "q8416", "q8417", "q8418", "q8419", "q8420", "q8421", "q8422", "q8423", 
    "q8424", "q8425", "q8426", "q8427", "q8428", "q8429", "q8430", "q8431", 
    "q8432", "q8433", "q8434", "q8435", "q8436", "q8437", "q8438", "q8439", 
    "q8440", "q8441", "q8442", "q8443", "q8444", "q8445", "q8446", "q8447", 
    "q8448", "q8449", "q8450", "q8451", "q8452", "q8453", "q8454", "q8455", 
    "q8456", "q8457", "q8458", "q8459", "q8460", "q8461", "q8462", "q8463", 
    "q8464", "q8465", "q8466", "q8467", "q8468", "q8469", "q8470", "q8471", 
    "q8472", "q8473", "q8474", "q8475", "q8476", "q8477", "q8478", "q8479", 
    "q8480", "q8481", "q8482", "q8483", "q8484", "q8485", "q8486", "q8487", 
    "q8488", "q8489", "q8490", "q8491", "q8492", "q8493", "q8494", "q8495", 
    "q8496", "q8497", "q8498", "q8499", "q8500", "q8501", "q8502", "q8503", 
    "q8504", "q8505", "q8506", "q8507", "q8508", "q8509", "q8510", "q8511", 
    "q8512", "q8513", "q8514", "q8515", "q8516", "q8517", "q8518", "q8519", 
    "q8520", "q8521", "q8522", "q8523", "q8524", "q8525", "q8526", "q8527", 
    "q8528", "q8529", "q8530", "q8531", "q8532", "q8533", "q8534", "q8535", 
    "q8536", "q8537", "q8538", "q8539", "q8540", "q8541", "q8542", "q8543", 
    "q8544", "q8545", "q8546", "q8547", "q8548", "q8549", "q8550", "q8551", 
    "q8552", "q8553", "q8554", "q8555", "q8556", "q8557", "q8558", "q8559", 
    "q8560", "q8561", "q8562", "q8563", "q8564", "q8565", "q8566", "q8567", 
    "q8568", "q8569", "q8570", "q8571", "q8572", "q8573", "q8574", "q8575", 
    "q8576", "q8577", "q8578", "q8579", "q8580", "q8581", "q8582", "q8583", 
    "q8584", "q8585", "q8586", "q8587", "q8588", "q8589", "q8590", "q8591", 
    "q8592", "q8593", "q8594", "q8595", "q8596", "q8597", "q8598", "q8599", 
    "q8600", "q8601", "q8602", "q8603", "q8604", "q8605", "q8606", "q8607", 
    "q8608", "q8609", "q8610", "q8611", "q8612", "q8613", "q8614", "q8615", 
    "q8616", "q8617", "q8618", "q8619", "q8620", "q8621", "q8622", "q8623", 
    "q8624", "q8625", "q8626", "q8627", "q8628", "q8629", "q8630", "q8631", 
    "q8632", "q8633", "q8634", "q8635", "q8636", "q8637", "q8638", "q8639", 
    "q8640", "q8641", "q8642", "q8643", "q8644", "q8645", "q8646", "q8647", 
    "q8648", "q8649", "q8650", "q8651", "q8652", "q8653", "q8654", "q8655", 
    "q8656", "q8657", "q8658", "q8659", "q8660", "q8661", "q8662", "q8663", 
    "q8664", "q8665", "q8666", "q8667", "q8668", "q8669", "q8670", "q8671", 
    "q8672", "q8673", "q8674", "q8675", "q8676", "q8677", "q8678", "q8679", 
    "q8680", "q8681", "q8682", "q8683", "q8684", "q8685", "q8686", "q8687", 
    "q8688", "q8689", "q8690", "q8691", "q8692", "q8693", "q8694", "q8695", 
    "q8696", "q8697", "q8698", "q8699", "q8700", "q8701", "q8702", "q8703", 
    "q8704", "q8705", "q8706", "q8707", "q8708", "q8709", "q8710", "q8711", 
    "q8712", "q8713", "q8714", "q8715", "q8716", "q8717", "q8718", "q8719", 
    "q8720", "q8721", "q8722", "q8723", "q8724", "q8725", "q8726", "q8727", 
    "q8728", "q8729", "q8730", "q8731", "q8732", "q8733", "q8734", "q8735", 
    "q8736", "q8737", "q8738", "q8739", "q8740", "q8741", "q8742", "q8743", 
    "q8744", "q8745", "q8746", "q8747", "q8748", "q8749", "q8750", "q8751", 
    "q8752", "q8753", "q8754", "q8755", "q8756", "q8757", "q8758", "q8759", 
    "q8760", "q8761", "q8762", "q8763", "q8764", "q8765", "q8766", "q8767", 
    "q8768", "q8769", "q8770", "q8771", "q8772", "q8773", "q8774", "q8775", 
    "q8776", "q8777", "q8778", "q8779", "q8780", "q8781", "q8782", "q8783", 
    "q8784", "q8785", "q8786", "q8787", "q8788", "q8789", "q8790", "q8791", 
    "q8792", "q8793", "q8794", "q8795", "q8796", "q8797", "q8798", "q8799", 
    "q8800", "q8801", "q8802", "q8803", "q8804", "q8805", "q8806", "q8807", 
    "q8808", "q8809", "q8810", "q8811", "q8812", "q8813", "q8814", "q8815", 
    "q8816", "q8817", "q8818", "q8819", "q8820", "q8821", "q8822", "q8823", 
    "q8824", "q8825", "q8826", "q8827", "q8828", "q8829", "q8830", "q8831", 
    "q8832", "q8833", "q8834", "q8835", "q8836", "q8837", "q8838", "q8839", 
    "q8840", "q8841", "q8842", "q8843", "q8844", "q8845", "q8846", "q8847", 
    "q8848", "q8849", "q8850", "q8851", "q8852", "q8853", "q8854", "q8855", 
    "q8856", "q8857", "q8858", "q8859", "q8860", "q8861", "q8862", "q8863", 
    "q8864", "q8865", "q8866", "q8867", "q8868", "q8869", "q8870", "q8871", 
    "q8872", "q8873", "q8874", "q8875", "q8876", "q8877", "q8878", "q8879", 
    "q8880", "q8881", "q8882", "q8883", "q8884", "q8885", "q8886", "q8887", 
    "q8888", "q8889", "q8890", "q8891", "q8892", "q8893", "q8894", "q8895", 
    "q8896", "q8897", "q8898", "q8899", "q8900", "q8901", "q8902", "q8903", 
    "q8904", "q8905", "q8906", "q8907", "q8908", "q8909", "q8910", "q8911", 
    "q8912", "q8913", "q8914", "q8915", "q8916", "q8917", "q8918", "q8919", 
    "q8920", "q8921", "q8922", "q8923", "q8924", "q8925", "q8926", "q8927", 
    "q8928", "q8929", "q8930", "q8931", "q8932", "q8933", "q8934", "q8935", 
    "q8936", "q8937", "q8938", "q8939", "q8940", "q8941", "q8942", "q8943", 
    "q8944", "q8945", "q8946", "q8947", "q8948", "q8949", "q8950", "q8951", 
    "q8952", "q8953", "q8954", "q8955", "q8956", "q8957", "q8958", "q8959", 
    "q8960", "q8961", "q8962", "q8963", "q8964", "q8965", "q8966", "q8967", 
    "q8968", "q8969", "q8970", "q8971", "q8972", "q8973", "q8974", "q8975", 
    "q8976", "q8977", "q8978", "q8979", "q8980", "q8981", "q8982", "q8983", 
    "q8984", "q8985", "q8986", "q8987", "q8988", "q8989", "q8990", "q8991", 
    "q8992", "q8993", "q8994", "q8995", "q8996", "q8997", "q8998", "q8999", 
    "q9000", "q9001", "q9002", "q9003", "q9004", "q9005", "q9006", "q9007", 
    "q9008", "q9009", "q9010", "q9011", "q9012", "q9013", "q9014", "q9015", 
    "q9016", "q9017", "q9018", "q9019", "q9020", "q9021", "q9022", "q9023", 
    "q9024", "q9025", "q9026", "q9027", "q9028", "q9029", "q9030", "q9031", 
    "q9032", "q9033", "q9034", "q9035", "q9036", "q9037", "q9038", "q9039", 
    "q9040", "q9041", "q9042", "q9043", "q9044", "q9045", "q9046", "q9047", 
    "q9048", "q9049", "q9050", "q9051", "q9052", "q9053", "q9054", "q9055", 
    "q9056", "q9057", "q9058", "q9059", "q9060", "q9061", "q9062", "q9063", 
    "q9064", "q9065", "q9066", "q9067", "q9068", "q9069", "q9070", "q9071", 
    "q9072", "q9073", "q9074", "q9075", "q9076", "q9077", "q9078", "q9079", 
    "q9080", "q9081", "q9082", "q9083", "q9084", "q9085", "q9086", "q9087", 
    "q9088", "q9089", "q9090", "q9091", "q9092", "q9093", "q9094", "q9095", 
    "q9096", "q9097", "q9098", "q9099", "q9100", "q9101", "q9102", "q9103", 
    "q9104", "q9105", "q9106", "q9107", "q9108", "q9109", "q9110", "q9111", 
    "q9112", "q9113", "q9114", "q9115", "q9116", "q9117", "q9118", "q9119", 
    "q9120", "q9121", "q9122", "q9123", "q9124", "q9125", "q9126", "q9127", 
    "q9128", "q9129", "q9130", "q9131", "q9132", "q9133", "q9134", "q9135", 
    "q9136", "q9137", "q9138", "q9139", "q9140", "q9141", "q9142", "q9143", 
    "q9144", "q9145", "q9146", "q9147", "q9148", "q9149", "q9150", "q9151", 
    "q9152", "q9153", "q9154", "q9155", "q9156", "q9157", "q9158", "q9159", 
    "q9160", "q9161", "q9162", "q9163", "q9164", "q9165", "q9166", "q9167", 
    "q9168", "q9169", "q9170", "q9171", "q9172", "q9173", "q9174", "q9175", 
    "q9176", "q9177", "q9178", "q9179", "q9180", "q9181", "q9182", "q9183", 
    "q9184", "q9185", "q9186", "q9187", "q9188", "q9189", "q9190", "q9191", 
    "q9192", "q9193", "q9194", "q9195", "q9196", "q9197", "q9198", "q9199", 
    "q9200", "q9201", "q9202", "q9203", "q9204", "q9205", "q9206", "q9207", 
    "q9208", "q9209", "q9210", "q9211", "q9212", "q9213", "q9214", "q9215", 
    "q9216", "q9217", "q9218", "q9219", "q9220", "q9221", "q9222", "q9223", 
    "q9224", "q9225", "q9226", "q9227", "q9228", "q9229", "q9230", "q9231", 
    "q9232", "q9233", "q9234", "q9235", "q9236", "q9237", "q9238", "q9239", 
    "q9240", "q9241", "q9242", "q9243", "q9244", "q9245", "q9246", "q9247", 
    "q9248", "q9249", "q9250", "q9251", "q9252", "q9253", "q9254", "q9255", 
    "q9256", "q9257", "q9258", "q9259", "q9260", "q9261", "q9262", "q9263", 
    "q9264", "q9265", "q9266", "q9267", "q9268", "q9269", "q9270", "q9271", 
    "q9272", "q9273", "q9274", "q9275", "q9276", "q9277", "q9278", "q9279", 
    "q9280", "q9281", "q9282", "q9283", "q9284", "q9285", "q9286", "q9287", 
    "q9288", "q9289", "q9290", "q9291", "q9292", "q9293", "q9294", "q9295", 
    "q9296", "q9297", "q9298", "q9299", "q9300", "q9301", "q9302", "q9303", 
    "q9304", "q9305", "q9306", "q9307", "q9308", "q9309", "q9310", "q9311", 
    "q9312", "q9313", "q9314", "q9315", "q9316", "q9317", "q9318", "q9319", 
    "q9320", "q9321", "q9322", "q9323", "q9324", "q9325", "q9326", "q9327", 
    "q9328", "q9329", "q9330", "q9331", "q9332", "q9333", "q9334", "q9335", 
    "q9336", "q9337", "q9338", "q9339", "q9340", "q9341", "q9342", "q9343", 
    "q9344", "q9345", "q9346", "q9347", "q9348", "q9349", "q9350", "q9351", 
    "q9352", "q9353", "q9354", "q9355", "q9356", "q9357", "q9358", "q9359", 
    "q9360", "q9361", "q9362", "q9363", "q9364", "q9365", "q9366", "q9367", 
    "q9368", "q9369", "q9370", "q9371", "q9372", "q9373", "q9374", "q9375", 
    "q9376", "q9377", "q9378", "q9379", "q9380", "q9381", "q9382", "q9383", 
    "q9384", "q9385", "q9386", "q9387", "q9388", "q9389", "q9390", "q9391", 
    "q9392", "q9393", "q9394", "q9395", "q9396", "q9397", "q9398", "q9399", 
    "q9400", "q9401", "q9402", "q9403", "q9404", "q9405", "q9406", "q9407", 
    "q9408", "q9409", "q9410", "q9411", "q9412", "q9413", "q9414", "q9415", 
    "q9416", "q9417", "q9418", "q9419", "q9420", "q9421", "q9422", "q9423", 
    "q9424", "q9425", "q9426", "q9427", "q9428", "q9429", "q9430", "q9431", 
    "q9432", "q9433", "q9434", "q9435", "q9436", "q9437", "q9438", "q9439", 
    "q9440", "q9441", "q9442", "q9443", "q9444", "q9445", "q9446", "q9447", 
    "q9448", "q9449", "q9450", "q9451", "q9452", "q9453", "q9454", "q9455", 
    "q9456", "q9457", "q9458", "q9459", "q9460", "q9461", "q9462", "q9463", 
    "q9464", "q9465", "q9466", "q9467", "q9468", "q9469", "q9470", "q9471", 
    "q9472", "q9473", "q9474", "q9475", "q9476", "q9477", "q9478", "q9479", 
    "q9480", "q9481", "q9482", "q9483", "q9484", "q9485", "q9486", "q9487", 
    "q9488", "q9489", "q9490", "q9491", "q9492", "q9493", "q9494", "q9495", 
    "q9496", "q9497", "q9498", "q9499", "q9500", "q9501", "q9502", "q9503", 
    "q9504", "q9505", "q9506", "q9507", "q9508", "q9509", "q9510", "q9511", 
    "q9512", "q9513", "q9514", "q9515", "q9516", "q9517", "q9518", "q9519", 
    "q9520", "q9521", "q9522", "q9523", "q9524", "q9525", "q9526", "q9527", 
    "q9528", "q9529", "q9530", "q9531", "q9532", "q9533", "q9534", "q9535", 
    "q9536", "q9537", "q9538", "q9539", "q9540", "q9541", "q9542", "q9543", 
    "q9544", "q9545", "q9546", "q9547", "q9548", "q9549", "q9550", "q9551", 
    "q9552", "q9553", "q9554", "q9555", "q9556", "q9557", "q9558", "q9559", 
    "q9560", "q9561", "q9562", "q9563", "q9564", "q9565", "q9566", "q9567", 
    "q9568", "q9569", "q9570", "q9571", "q9572", "q9573", "q9574", "q9575", 
    "q9576", "q9577", "q9578", "q9579", "q9580", "q9581", "q9582", "q9583", 
    "q9584", "q9585", "q9586", "q9587", "q9588", "q9589", "q9590", "q9591", 
    "q9592", "q9593", "q9594", "q9595", "q9596", "q9597", "q9598", "q9599", 
    "q9600", "q9601", "q9602", "q9603", "q9604", "q9605", "q9606", "q9607", 
    "q9608", "q9609", "q9610", "q9611", "q9612", "q9613", "q9614", "q9615", 
    "q9616", "q9617", "q9618", "q9619", "q9620", "q9621", "q9622", "q9623", 
    "q9624", "q9625", "q9626", "q9627", "q9628", "q9629", "q9630", "q9631", 
    "q9632", "q9633", "q9634", "q9635", "q9636", "q9637", "q9638", "q9639", 
    "q9640", "q9641", "q9642", "q9643", "q9644", "q9645", "q9646", "q9647", 
    "q9648", "q9649", "q9650", "q9651", "q9652", "q9653", "q9654", "q9655", 
    "q9656", "q9657", "q9658", "q9659", "q9660", "q9661", "q9662", "q9663", 
    "q9664", "q9665", "q9666", "q9667", "q9668", "q9669", "q9670", "q9671", 
    "q9672", "q9673", "q9674", "q9675", "q9676", "q9677", "q9678", "q9679", 
    "q9680", "q9681", "q9682", "q9683", "q9684", "q9685", "q9686", "q9687", 
    "q9688", "q9689", "q9690", "q9691", "q9692", "q9693", "q9694", "q9695", 
    "q9696", "q9697", "q9698", "q9699", "q9700", "q9701", "q9702", "q9703", 
    "q9704", "q9705", "q9706", "q9707", "q9708", "q9709", "q9710", "q9711", 
    "q9712", "q9713", "q9714", "q9715", "q9716", "q9717", "q9718", "q9719", 
    "q9720", "q9721", "q9722", "q9723", "q9724", "q9725", "q9726", "q9727", 
    "q9728", "q9729", "q9730", "q9731", "q9732", "q9733", "q9734", "q9735", 
    "q9736", "q9737", "q9738", "q9739", "q9740", "q9741", "q9742", "q9743", 
    "q9744", "q9745", "q9746", "q9747", "q9748", "q9749", "q9750", "q9751", 
    "q9752", "q9753", "q9754", "q9755", "q9756", "q9757", "q9758", "q9759", 
    "q9760", "q9761", "q9762", "q9763", "q9764", "q9765", "q9766", "q9767", 
    "q9768", "q9769", "q9770", "q9771", "q9772", "q9773", "q9774", "q9775", 
    "q9776", "q9777", "q9778", "q9779", "q9780", "q9781", "q9782", "q9783", 
    "q9784", "q9785", "q9786", "q9787", "q9788", "q9789", "q9790", "q9791", 
    "q9792", "q9793", "q9794", "q9795", "q9796", "q9797", "q9798", "q9799", 
    "q9800", "q9801", "q9802", "q9803", "q9804", "q9805", "q9806", "q9807", 
    "q9808", "q9809", "q9810", "q9811", "q9812", "q9813", "q9814", "q9815", 
    "q9816", "q9817", "q9818", "q9819", "q9820", "q9821", "q9822", "q9823", 
    "q9824", "q9825", "q9826", "q9827", "q9828", "q9829", "q9830", "q9831", 
    "q9832", "q9833", "q9834", "q9835", "q9836", "q9837", "q9838", "q9839", 
    "q9840", "q9841", "q9842", "q9843", "q9844", "q9845", "q9846", "q9847", 
    "q9848", "q9849", "q9850", "q9851", "q9852", "q9853", "q9854", "q9855", 
    "q9856", "q9857", "q9858", "q9859", "q9860", "q9861", "q9862", "q9863", 
    "q9864", "q9865", "q9866", "q9867", "q9868", "q9869", "q9870", "q9871", 
    "q9872", "q9873", "q9874", "q9875", "q9876", "q9877", "q9878", "q9879", 
    "q9880", "q9881", "q9882", "q9883", "q9884", "q9885", "q9886", "q9887", 
    "q9888", "q9889", "q9890", "q9891", "q9892", "q9893", "q9894", "q9895", 
    "q9896", "q9897", "q9898", "q9899", "q9900", "q9901", "q9902", "q9903", 
    "q9904", "q9905", "q9906", "q9907", "q9908", "q9909", "q9910", "q9911", 
    "q9912", "q9913", "q9914", "q9915", "q9916", "q9917", "q9918", "q9919", 
    "q9920", "q9921", "q9922", "q9923", "q9924", "q9925", "q9926", "q9927", 
    "q9928", "q9929", "q9930", "q9931", "q9932", "q9933", "q9934", "q9935", 
    "q9936", "q9937", "q9938", "q9939", "q9940", "q9941", "q9942", "q9943", 
    "q9944", "q9945", "q9946", "q9947", "q9948", "q9949", "q9950", "q9951", 
    "q9952", "q9953", "q9954", "q9955", "q9956", "q9957", "q9958", "q9959", 
    "q9960", "q9961", "q9962", "q9963", "q9964", "q9965", "q9966", "q9967", 
    "q9968", "q9969", "q9970", "q9971", "q9972", "q9973", "q9974", "q9975", 
    "q9976", "q9977", "q9978", "q9979", "q9980", "q9981", "q9982", "q9983", 
    "q9984", "q9985", "q9986", "q9987", "q9988", "q9989", "q9990", "q9991", 
    "q9992", "q9993", "q9994", "q9995", "q9996", "q9997", "q9998", "q9999", 
    nullptr
  };

}

// STATISTICS: example-any

